[
  (expandable_here_string_literal)
  (verbatim_here_string_characters)
  (function_statement)
  (param_block)
  (script_block_expression)
  (statement_block)
  (switch_body)
  (array_expression)
  (hash_literal_expression)
  (class_statement)
  (class_method_definition)
] @fold
