[
  (razor_if)
  (razor_switch)
  (razor_for)
  (razor_foreach)
  (razor_while)
  (razor_do_while)
  (razor_try)
  (razor_catch)
  (razor_finally)
  (razor_compound_using)
  (razor_section)
  (razor_block)
] @fold
