[
  (import_list)
  (when_expression)
  (control_structure_body)
  (lambda_literal)
  (function_body)
  (primary_constructor)
  (secondary_constructor)
  (anonymous_initializer)
  (class_body)
  (enum_class_body)
  (interpolated_expression)
] @fold
