import { ZodOptionalDef } from 'zod/v3';
import { JsonSchema7Type } from "../parseDef.js";
import { Refs } from "../Refs.js";
export declare const parseOptionalDef: (def: ZodOptionalDef, refs: Refs, forceResolution: boolean) => JsonSchema7Type | undefined;
//# sourceMappingURL=optional.d.ts.map