import { default_format, formatters, RFC1738, RFC3986 } from "./formats.mjs";
const formats = {
    formatters,
    RFC1738,
    RFC3986,
    default: default_format,
};
export { stringify } from "./stringify.mjs";
export { formats };
//# sourceMappingURL=index.mjs.map