"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.parseBrandedDef = parseBrandedDef;
const parseDef_1 = require("../parseDef.js");
function parseBrandedDef(_def, refs, forceResolution) {
    return (0, parseDef_1.parseDef)(_def.type._def, refs, forceResolution);
}
//# sourceMappingURL=branded.js.map