import { ZodBrandedDef } from 'zod/v3';
import { Refs } from "../Refs.js";
export declare function parseBrandedDef(_def: ZodBrandedDef<any>, refs: Refs, forceResolution: boolean): import("../parseDef.js").JsonSchema7Type | undefined;
//# sourceMappingURL=branded.d.ts.map