import { ZodPromiseDef } from 'zod/v3';
import { JsonSchema7Type } from "../parseDef.js";
import { Refs } from "../Refs.js";
export declare function parsePromiseDef(def: ZodPromiseDef, refs: Refs, forceResolution: boolean): JsonSchema7Type | undefined;
//# sourceMappingURL=promise.d.ts.map