import { parseDef } from "../parseDef.mjs";
export function parsePromiseDef(def, refs, forceResolution) {
    return parseDef(def.type._def, refs, forceResolution);
}
//# sourceMappingURL=promise.mjs.map