[
  (block)
  (switch_expression)
  (initializer_list)
  (asm_expression)
  (multiline_string)
  (if_statement)
  (while_statement)
  (for_statement)
  (if_expression)
  (else_clause)
  (for_expression)
  (while_expression)
  (if_type_expression)
  (function_signature)
  (parameters)
  (struct_declaration)
  (opaque_declaration)
  (enum_declaration)
  (union_declaration)
  (error_set_declaration)
] @fold

