"use strict";
// File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.
Object.defineProperty(exports, "__esModule", { value: true });
exports.Realtime = exports.ClientSecrets = exports.Calls = void 0;
var calls_1 = require("./calls.js");
Object.defineProperty(exports, "Calls", { enumerable: true, get: function () { return calls_1.Calls; } });
var client_secrets_1 = require("./client-secrets.js");
Object.defineProperty(exports, "ClientSecrets", { enumerable: true, get: function () { return client_secrets_1.ClientSecrets; } });
var realtime_1 = require("./realtime.js");
Object.defineProperty(exports, "Realtime", { enumerable: true, get: function () { return realtime_1.Realtime; } });
//# sourceMappingURL=index.js.map