"use strict";
// File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.
Object.defineProperty(exports, "__esModule", { value: true });
exports.Tunnels = exports.Certificates = void 0;
var certificates_1 = require("./certificates.js");
Object.defineProperty(exports, "Certificates", { enumerable: true, get: function () { return certificates_1.Certificates; } });
var tunnels_1 = require("./tunnels.js");
Object.defineProperty(exports, "Tunnels", { enumerable: true, get: function () { return tunnels_1.Tunnels; } });
//# sourceMappingURL=index.js.map