export declare const START = "<!-- graft:start -->";
export declare const END = "<!-- graft:end -->";
export type UpsertAction = 'created' | 'appended' | 'replaced' | 'unchanged';
type LineEnding = '\n' | '\r\n';
export declare function fencedBlock(body: string, eol?: LineEnding): string;
export declare function upsertSection(filePath: string, body: string): {
    action: UpsertAction;
};
export {};
//# sourceMappingURL=sections.d.ts.map