import type { ZodSchema, ZodTypeDef } from 'zod/v3';
export declare const zodDef: (zodSchema: ZodSchema | ZodTypeDef) => ZodTypeDef;
export declare function isEmptyObj(obj: Object | null | undefined): boolean;
//# sourceMappingURL=util.d.ts.map