"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.parseBooleanDef = parseBooleanDef;
function parseBooleanDef() {
    return {
        type: 'boolean',
    };
}
//# sourceMappingURL=boolean.js.map