import { ZodEnumDef } from 'zod/v3';
export type JsonSchema7EnumType = {
    type: 'string';
    enum: string[];
};
export declare function parseEnumDef(def: ZodEnumDef): JsonSchema7EnumType;
//# sourceMappingURL=enum.d.ts.map