[
  (class_definition)
  (enum_declaration)
  (extension_declaration)
  (arguments)
  (function_body)
  (block)
  (switch_block)
  (list_literal)
  (set_or_map_literal)
  (string_literal)
  (import_or_export)+
] @fold
