import type { Provider } from "../internal/provider.js";
import { type BedrockBearerOptions, type BedrockEndpointOptions } from "../internal/bedrock.js";
export interface BedrockProviderOptions extends BedrockEndpointOptions, BedrockBearerOptions {
}
/** Configure the standard OpenAI client for Amazon Bedrock using bearer authentication. */
export declare function bedrock(options?: BedrockProviderOptions): Provider;
//# sourceMappingURL=bedrock.d.ts.map