"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.$JSONSchema = void 0;
var $JSONSchema = Symbol("$JSONSchema");
/**
 * Symbol used to make extended JSON schemas actually extend the JSONSchema type constraint at all time
 */

/**
 * JSON Schema type
 */

/**
 * JSON Schema type constraint
 */

/**
 * JSON Schema with reference type constraint
 */

exports.$JSONSchema = $JSONSchema;
//# sourceMappingURL=jsonSchema.js.map