import { parseDef } from "../parseDef.mjs";
export const parseReadonlyDef = (def, refs, forceResolution) => {
    return parseDef(def.innerType._def, refs, forceResolution);
};
//# sourceMappingURL=readonly.mjs.map