export declare function concatBytes(buffers: Uint8Array[]): Uint8Array;
export declare function encodeUTF8(str: string): Uint8Array<ArrayBufferLike>;
export declare function decodeUTF8(bytes: Uint8Array): string;
//# sourceMappingURL=bytes.d.ts.map