#include "tree_sitter/parser.h"

#if defined(__GNUC__) || defined(__clang__)
#pragma GCC diagnostic ignored "-Wmissing-field-initializers"
#endif

#define LANGUAGE_VERSION 14
#define STATE_COUNT 5870
#define LARGE_STATE_COUNT 1193
#define SYMBOL_COUNT 376
#define ALIAS_COUNT 7
#define TOKEN_COUNT 166
#define EXTERNAL_TOKEN_COUNT 10
#define FIELD_COUNT 40
#define MAX_ALIAS_SEQUENCE_LENGTH 10
#define PRODUCTION_ID_COUNT 340

enum ts_symbol_identifiers {
  sym_identifier = 1,
  sym_hash_bang_line = 2,
  anon_sym_export = 3,
  anon_sym_STAR = 4,
  anon_sym_default = 5,
  anon_sym_type = 6,
  anon_sym_EQ = 7,
  anon_sym_as = 8,
  anon_sym_namespace = 9,
  anon_sym_LBRACE = 10,
  anon_sym_COMMA = 11,
  anon_sym_RBRACE = 12,
  anon_sym_typeof = 13,
  anon_sym_import = 14,
  anon_sym_from = 15,
  anon_sym_with = 16,
  anon_sym_assert = 17,
  anon_sym_var = 18,
  anon_sym_let = 19,
  anon_sym_const = 20,
  anon_sym_BANG = 21,
  anon_sym_else = 22,
  anon_sym_if = 23,
  anon_sym_switch = 24,
  anon_sym_for = 25,
  anon_sym_LPAREN = 26,
  anon_sym_SEMI = 27,
  anon_sym_RPAREN = 28,
  anon_sym_await = 29,
  anon_sym_in = 30,
  anon_sym_of = 31,
  anon_sym_while = 32,
  anon_sym_do = 33,
  anon_sym_try = 34,
  anon_sym_break = 35,
  anon_sym_continue = 36,
  anon_sym_debugger = 37,
  anon_sym_return = 38,
  anon_sym_throw = 39,
  anon_sym_COLON = 40,
  anon_sym_case = 41,
  anon_sym_catch = 42,
  anon_sym_finally = 43,
  anon_sym_yield = 44,
  anon_sym_LBRACK = 45,
  anon_sym_RBRACK = 46,
  anon_sym_DOT = 47,
  anon_sym_class = 48,
  anon_sym_async = 49,
  anon_sym_function = 50,
  anon_sym_EQ_GT = 51,
  anon_sym_QMARK_DOT = 52,
  anon_sym_new = 53,
  anon_sym_using = 54,
  anon_sym_PLUS_EQ = 55,
  anon_sym_DASH_EQ = 56,
  anon_sym_STAR_EQ = 57,
  anon_sym_SLASH_EQ = 58,
  anon_sym_PERCENT_EQ = 59,
  anon_sym_CARET_EQ = 60,
  anon_sym_AMP_EQ = 61,
  anon_sym_PIPE_EQ = 62,
  anon_sym_GT_GT_EQ = 63,
  anon_sym_GT_GT_GT_EQ = 64,
  anon_sym_LT_LT_EQ = 65,
  anon_sym_STAR_STAR_EQ = 66,
  anon_sym_AMP_AMP_EQ = 67,
  anon_sym_PIPE_PIPE_EQ = 68,
  anon_sym_QMARK_QMARK_EQ = 69,
  anon_sym_DOT_DOT_DOT = 70,
  anon_sym_AMP_AMP = 71,
  anon_sym_PIPE_PIPE = 72,
  anon_sym_GT_GT = 73,
  anon_sym_GT_GT_GT = 74,
  anon_sym_LT_LT = 75,
  anon_sym_AMP = 76,
  anon_sym_CARET = 77,
  anon_sym_PIPE = 78,
  anon_sym_PLUS = 79,
  anon_sym_DASH = 80,
  anon_sym_SLASH = 81,
  anon_sym_PERCENT = 82,
  anon_sym_STAR_STAR = 83,
  anon_sym_LT = 84,
  anon_sym_LT_EQ = 85,
  anon_sym_EQ_EQ = 86,
  anon_sym_EQ_EQ_EQ = 87,
  anon_sym_BANG_EQ = 88,
  anon_sym_BANG_EQ_EQ = 89,
  anon_sym_GT_EQ = 90,
  anon_sym_GT = 91,
  anon_sym_QMARK_QMARK = 92,
  anon_sym_instanceof = 93,
  anon_sym_TILDE = 94,
  anon_sym_void = 95,
  anon_sym_delete = 96,
  anon_sym_PLUS_PLUS = 97,
  anon_sym_DASH_DASH = 98,
  anon_sym_DQUOTE = 99,
  anon_sym_SQUOTE = 100,
  sym_unescaped_double_string_fragment = 101,
  sym_unescaped_single_string_fragment = 102,
  sym_escape_sequence = 103,
  sym_comment = 104,
  anon_sym_BQUOTE = 105,
  anon_sym_DOLLAR_LBRACE = 106,
  anon_sym_SLASH2 = 107,
  sym_regex_pattern = 108,
  sym_regex_flags = 109,
  sym_number = 110,
  sym_private_property_identifier = 111,
  anon_sym_target = 112,
  anon_sym_meta = 113,
  sym_this = 114,
  sym_super = 115,
  sym_true = 116,
  sym_false = 117,
  sym_null = 118,
  sym_undefined = 119,
  anon_sym_AT = 120,
  anon_sym_static = 121,
  anon_sym_readonly = 122,
  anon_sym_get = 123,
  anon_sym_set = 124,
  anon_sym_QMARK = 125,
  anon_sym_declare = 126,
  anon_sym_public = 127,
  anon_sym_private = 128,
  anon_sym_protected = 129,
  anon_sym_override = 130,
  anon_sym_module = 131,
  anon_sym_any = 132,
  anon_sym_number = 133,
  anon_sym_boolean = 134,
  anon_sym_string = 135,
  anon_sym_symbol = 136,
  anon_sym_object = 137,
  anon_sym_abstract = 138,
  anon_sym_accessor = 139,
  anon_sym_satisfies = 140,
  anon_sym_require = 141,
  anon_sym_extends = 142,
  anon_sym_implements = 143,
  anon_sym_global = 144,
  anon_sym_interface = 145,
  anon_sym_enum = 146,
  anon_sym_DASH_QMARK_COLON = 147,
  anon_sym_PLUS_QMARK_COLON = 148,
  anon_sym_QMARK_COLON = 149,
  anon_sym_asserts = 150,
  anon_sym_infer = 151,
  anon_sym_is = 152,
  anon_sym_keyof = 153,
  anon_sym_unique = 154,
  anon_sym_unknown = 155,
  anon_sym_never = 156,
  anon_sym_LBRACE_PIPE = 157,
  anon_sym_PIPE_RBRACE = 158,
  sym__automatic_semicolon = 159,
  sym__template_chars = 160,
  sym__ternary_qmark = 161,
  sym_html_comment = 162,
  sym_jsx_text = 163,
  sym__function_signature_automatic_semicolon = 164,
  sym___error_recovery = 165,
  sym_program = 166,
  sym_export_statement = 167,
  sym_namespace_export = 168,
  sym_export_clause = 169,
  sym_export_specifier = 170,
  sym__module_export_name = 171,
  sym_declaration = 172,
  sym_import = 173,
  sym_import_statement = 174,
  sym_import_clause = 175,
  sym__from_clause = 176,
  sym_namespace_import = 177,
  sym_named_imports = 178,
  sym_import_specifier = 179,
  sym_import_attribute = 180,
  sym_statement = 181,
  sym_expression_statement = 182,
  sym_variable_declaration = 183,
  sym_lexical_declaration = 184,
  sym_variable_declarator = 185,
  sym_statement_block = 186,
  sym_else_clause = 187,
  sym_if_statement = 188,
  sym_switch_statement = 189,
  sym_for_statement = 190,
  sym_for_in_statement = 191,
  sym__for_header = 192,
  sym_while_statement = 193,
  sym_do_statement = 194,
  sym_try_statement = 195,
  sym_with_statement = 196,
  sym_break_statement = 197,
  sym_continue_statement = 198,
  sym_debugger_statement = 199,
  sym_return_statement = 200,
  sym_throw_statement = 201,
  sym_empty_statement = 202,
  sym_labeled_statement = 203,
  sym_switch_body = 204,
  sym_switch_case = 205,
  sym_switch_default = 206,
  sym_catch_clause = 207,
  sym_finally_clause = 208,
  sym_parenthesized_expression = 209,
  sym_expression = 210,
  sym_primary_expression = 211,
  sym_yield_expression = 212,
  sym_object = 213,
  sym_object_pattern = 214,
  sym_assignment_pattern = 215,
  sym_object_assignment_pattern = 216,
  sym_array = 217,
  sym_array_pattern = 218,
  sym_nested_identifier = 219,
  sym_class = 220,
  sym_class_declaration = 221,
  sym_class_heritage = 222,
  sym_function_expression = 223,
  sym_function_declaration = 224,
  sym_generator_function = 225,
  sym_generator_function_declaration = 226,
  sym_arrow_function = 227,
  sym__call_signature = 228,
  sym__formal_parameter = 229,
  sym_optional_chain = 230,
  sym_call_expression = 231,
  sym_new_expression = 232,
  sym_await_expression = 233,
  sym_member_expression = 234,
  sym_subscript_expression = 235,
  sym_assignment_expression = 236,
  sym__augmented_assignment_lhs = 237,
  sym_augmented_assignment_expression = 238,
  sym__initializer = 239,
  sym__destructuring_pattern = 240,
  sym_spread_element = 241,
  sym_ternary_expression = 242,
  sym_binary_expression = 243,
  sym_unary_expression = 244,
  sym_update_expression = 245,
  sym_sequence_expression = 246,
  sym_string = 247,
  sym_template_string = 248,
  sym_template_substitution = 249,
  sym_regex = 250,
  sym_meta_property = 251,
  sym_arguments = 252,
  sym_decorator = 253,
  sym_decorator_member_expression = 254,
  sym_decorator_call_expression = 255,
  sym_class_body = 256,
  sym_formal_parameters = 257,
  sym_class_static_block = 258,
  sym_pattern = 259,
  sym_rest_pattern = 260,
  sym_method_definition = 261,
  sym_pair = 262,
  sym_pair_pattern = 263,
  sym__property_name = 264,
  sym_computed_property_name = 265,
  sym_public_field_definition = 266,
  sym__import_identifier = 267,
  sym_non_null_expression = 268,
  sym_method_signature = 269,
  sym_abstract_method_signature = 270,
  sym_function_signature = 271,
  sym_decorator_parenthesized_expression = 272,
  sym_type_assertion = 273,
  sym_as_expression = 274,
  sym_satisfies_expression = 275,
  sym_instantiation_expression = 276,
  sym_import_require_clause = 277,
  sym_extends_clause = 278,
  sym__extends_clause_single = 279,
  sym_implements_clause = 280,
  sym_ambient_declaration = 281,
  sym_abstract_class_declaration = 282,
  sym_module = 283,
  sym_internal_module = 284,
  sym__module = 285,
  sym_import_alias = 286,
  sym_nested_type_identifier = 287,
  sym_interface_declaration = 288,
  sym_extends_type_clause = 289,
  sym_enum_declaration = 290,
  sym_enum_body = 291,
  sym_enum_assignment = 292,
  sym_type_alias_declaration = 293,
  sym_accessibility_modifier = 294,
  sym_override_modifier = 295,
  sym_required_parameter = 296,
  sym_optional_parameter = 297,
  sym__parameter_name = 298,
  sym_omitting_type_annotation = 299,
  sym_adding_type_annotation = 300,
  sym_opting_type_annotation = 301,
  sym_type_annotation = 302,
  sym__type_query_member_expression_in_type_annotation = 303,
  sym__type_query_call_expression_in_type_annotation = 304,
  sym_asserts = 305,
  sym_asserts_annotation = 306,
  sym_type = 307,
  sym_tuple_parameter = 308,
  sym_optional_tuple_parameter = 309,
  sym_optional_type = 310,
  sym_rest_type = 311,
  sym__tuple_type_member = 312,
  sym_constructor_type = 313,
  sym_primary_type = 314,
  sym_template_type = 315,
  sym_template_literal_type = 316,
  sym_infer_type = 317,
  sym_conditional_type = 318,
  sym_generic_type = 319,
  sym_type_predicate = 320,
  sym_type_predicate_annotation = 321,
  sym__type_query_member_expression = 322,
  sym__type_query_subscript_expression = 323,
  sym__type_query_call_expression = 324,
  sym__type_query_instantiation_expression = 325,
  sym_type_query = 326,
  sym_index_type_query = 327,
  sym_lookup_type = 328,
  sym_mapped_type_clause = 329,
  sym_literal_type = 330,
  sym__number = 331,
  sym_existential_type = 332,
  sym_flow_maybe_type = 333,
  sym_parenthesized_type = 334,
  sym_predefined_type = 335,
  sym_type_arguments = 336,
  sym_object_type = 337,
  sym_call_signature = 338,
  sym_property_signature = 339,
  sym_type_parameters = 340,
  sym_type_parameter = 341,
  sym_default_type = 342,
  sym_constraint = 343,
  sym_construct_signature = 344,
  sym_index_signature = 345,
  sym_array_type = 346,
  sym_tuple_type = 347,
  sym_readonly_type = 348,
  sym_union_type = 349,
  sym_intersection_type = 350,
  sym_function_type = 351,
  aux_sym_program_repeat1 = 352,
  aux_sym_export_statement_repeat1 = 353,
  aux_sym_export_clause_repeat1 = 354,
  aux_sym_named_imports_repeat1 = 355,
  aux_sym_variable_declaration_repeat1 = 356,
  aux_sym_switch_body_repeat1 = 357,
  aux_sym_object_repeat1 = 358,
  aux_sym_object_pattern_repeat1 = 359,
  aux_sym_array_repeat1 = 360,
  aux_sym_array_pattern_repeat1 = 361,
  aux_sym_sequence_expression_repeat1 = 362,
  aux_sym_string_repeat1 = 363,
  aux_sym_string_repeat2 = 364,
  aux_sym_template_string_repeat1 = 365,
  aux_sym_class_body_repeat1 = 366,
  aux_sym_formal_parameters_repeat1 = 367,
  aux_sym_extends_clause_repeat1 = 368,
  aux_sym_implements_clause_repeat1 = 369,
  aux_sym_extends_type_clause_repeat1 = 370,
  aux_sym_enum_body_repeat1 = 371,
  aux_sym_template_literal_type_repeat1 = 372,
  aux_sym_object_type_repeat1 = 373,
  aux_sym_type_parameters_repeat1 = 374,
  aux_sym_tuple_type_repeat1 = 375,
  alias_sym_interface_body = 376,
  alias_sym_property_identifier = 377,
  alias_sym_shorthand_property_identifier = 378,
  alias_sym_shorthand_property_identifier_pattern = 379,
  alias_sym_statement_identifier = 380,
  alias_sym_this_type = 381,
  alias_sym_type_identifier = 382,
};

static const char * const ts_symbol_names[] = {
  [ts_builtin_sym_end] = "end",
  [sym_identifier] = "identifier",
  [sym_hash_bang_line] = "hash_bang_line",
  [anon_sym_export] = "export",
  [anon_sym_STAR] = "*",
  [anon_sym_default] = "default",
  [anon_sym_type] = "type",
  [anon_sym_EQ] = "=",
  [anon_sym_as] = "as",
  [anon_sym_namespace] = "namespace",
  [anon_sym_LBRACE] = "{",
  [anon_sym_COMMA] = ",",
  [anon_sym_RBRACE] = "}",
  [anon_sym_typeof] = "typeof",
  [anon_sym_import] = "import",
  [anon_sym_from] = "from",
  [anon_sym_with] = "with",
  [anon_sym_assert] = "assert",
  [anon_sym_var] = "var",
  [anon_sym_let] = "let",
  [anon_sym_const] = "const",
  [anon_sym_BANG] = "!",
  [anon_sym_else] = "else",
  [anon_sym_if] = "if",
  [anon_sym_switch] = "switch",
  [anon_sym_for] = "for",
  [anon_sym_LPAREN] = "(",
  [anon_sym_SEMI] = ";",
  [anon_sym_RPAREN] = ")",
  [anon_sym_await] = "await",
  [anon_sym_in] = "in",
  [anon_sym_of] = "of",
  [anon_sym_while] = "while",
  [anon_sym_do] = "do",
  [anon_sym_try] = "try",
  [anon_sym_break] = "break",
  [anon_sym_continue] = "continue",
  [anon_sym_debugger] = "debugger",
  [anon_sym_return] = "return",
  [anon_sym_throw] = "throw",
  [anon_sym_COLON] = ":",
  [anon_sym_case] = "case",
  [anon_sym_catch] = "catch",
  [anon_sym_finally] = "finally",
  [anon_sym_yield] = "yield",
  [anon_sym_LBRACK] = "[",
  [anon_sym_RBRACK] = "]",
  [anon_sym_DOT] = ".",
  [anon_sym_class] = "class",
  [anon_sym_async] = "async",
  [anon_sym_function] = "function",
  [anon_sym_EQ_GT] = "=>",
  [anon_sym_QMARK_DOT] = "\?.",
  [anon_sym_new] = "new",
  [anon_sym_using] = "using",
  [anon_sym_PLUS_EQ] = "+=",
  [anon_sym_DASH_EQ] = "-=",
  [anon_sym_STAR_EQ] = "*=",
  [anon_sym_SLASH_EQ] = "/=",
  [anon_sym_PERCENT_EQ] = "%=",
  [anon_sym_CARET_EQ] = "^=",
  [anon_sym_AMP_EQ] = "&=",
  [anon_sym_PIPE_EQ] = "|=",
  [anon_sym_GT_GT_EQ] = ">>=",
  [anon_sym_GT_GT_GT_EQ] = ">>>=",
  [anon_sym_LT_LT_EQ] = "<<=",
  [anon_sym_STAR_STAR_EQ] = "**=",
  [anon_sym_AMP_AMP_EQ] = "&&=",
  [anon_sym_PIPE_PIPE_EQ] = "||=",
  [anon_sym_QMARK_QMARK_EQ] = "\?\?=",
  [anon_sym_DOT_DOT_DOT] = "...",
  [anon_sym_AMP_AMP] = "&&",
  [anon_sym_PIPE_PIPE] = "||",
  [anon_sym_GT_GT] = ">>",
  [anon_sym_GT_GT_GT] = ">>>",
  [anon_sym_LT_LT] = "<<",
  [anon_sym_AMP] = "&",
  [anon_sym_CARET] = "^",
  [anon_sym_PIPE] = "|",
  [anon_sym_PLUS] = "+",
  [anon_sym_DASH] = "-",
  [anon_sym_SLASH] = "/",
  [anon_sym_PERCENT] = "%",
  [anon_sym_STAR_STAR] = "**",
  [anon_sym_LT] = "<",
  [anon_sym_LT_EQ] = "<=",
  [anon_sym_EQ_EQ] = "==",
  [anon_sym_EQ_EQ_EQ] = "===",
  [anon_sym_BANG_EQ] = "!=",
  [anon_sym_BANG_EQ_EQ] = "!==",
  [anon_sym_GT_EQ] = ">=",
  [anon_sym_GT] = ">",
  [anon_sym_QMARK_QMARK] = "\?\?",
  [anon_sym_instanceof] = "instanceof",
  [anon_sym_TILDE] = "~",
  [anon_sym_void] = "void",
  [anon_sym_delete] = "delete",
  [anon_sym_PLUS_PLUS] = "++",
  [anon_sym_DASH_DASH] = "--",
  [anon_sym_DQUOTE] = "\"",
  [anon_sym_SQUOTE] = "'",
  [sym_unescaped_double_string_fragment] = "string_fragment",
  [sym_unescaped_single_string_fragment] = "string_fragment",
  [sym_escape_sequence] = "escape_sequence",
  [sym_comment] = "comment",
  [anon_sym_BQUOTE] = "`",
  [anon_sym_DOLLAR_LBRACE] = "${",
  [anon_sym_SLASH2] = "/",
  [sym_regex_pattern] = "regex_pattern",
  [sym_regex_flags] = "regex_flags",
  [sym_number] = "number",
  [sym_private_property_identifier] = "private_property_identifier",
  [anon_sym_target] = "target",
  [anon_sym_meta] = "meta",
  [sym_this] = "this",
  [sym_super] = "super",
  [sym_true] = "true",
  [sym_false] = "false",
  [sym_null] = "null",
  [sym_undefined] = "undefined",
  [anon_sym_AT] = "@",
  [anon_sym_static] = "static",
  [anon_sym_readonly] = "readonly",
  [anon_sym_get] = "get",
  [anon_sym_set] = "set",
  [anon_sym_QMARK] = "\?",
  [anon_sym_declare] = "declare",
  [anon_sym_public] = "public",
  [anon_sym_private] = "private",
  [anon_sym_protected] = "protected",
  [anon_sym_override] = "override",
  [anon_sym_module] = "module",
  [anon_sym_any] = "any",
  [anon_sym_number] = "number",
  [anon_sym_boolean] = "boolean",
  [anon_sym_string] = "string",
  [anon_sym_symbol] = "symbol",
  [anon_sym_object] = "object",
  [anon_sym_abstract] = "abstract",
  [anon_sym_accessor] = "accessor",
  [anon_sym_satisfies] = "satisfies",
  [anon_sym_require] = "require",
  [anon_sym_extends] = "extends",
  [anon_sym_implements] = "implements",
  [anon_sym_global] = "global",
  [anon_sym_interface] = "interface",
  [anon_sym_enum] = "enum",
  [anon_sym_DASH_QMARK_COLON] = "-\?:",
  [anon_sym_PLUS_QMARK_COLON] = "+\?:",
  [anon_sym_QMARK_COLON] = "\?:",
  [anon_sym_asserts] = "asserts",
  [anon_sym_infer] = "infer",
  [anon_sym_is] = "is",
  [anon_sym_keyof] = "keyof",
  [anon_sym_unique] = "unique symbol",
  [anon_sym_unknown] = "unknown",
  [anon_sym_never] = "never",
  [anon_sym_LBRACE_PIPE] = "{|",
  [anon_sym_PIPE_RBRACE] = "|}",
  [sym__automatic_semicolon] = "_automatic_semicolon",
  [sym__template_chars] = "string_fragment",
  [sym__ternary_qmark] = "\?",
  [sym_html_comment] = "html_comment",
  [sym_jsx_text] = "jsx_text",
  [sym__function_signature_automatic_semicolon] = "_function_signature_automatic_semicolon",
  [sym___error_recovery] = "__error_recovery",
  [sym_program] = "program",
  [sym_export_statement] = "export_statement",
  [sym_namespace_export] = "namespace_export",
  [sym_export_clause] = "export_clause",
  [sym_export_specifier] = "export_specifier",
  [sym__module_export_name] = "_module_export_name",
  [sym_declaration] = "declaration",
  [sym_import] = "import",
  [sym_import_statement] = "import_statement",
  [sym_import_clause] = "import_clause",
  [sym__from_clause] = "_from_clause",
  [sym_namespace_import] = "namespace_import",
  [sym_named_imports] = "named_imports",
  [sym_import_specifier] = "import_specifier",
  [sym_import_attribute] = "import_attribute",
  [sym_statement] = "statement",
  [sym_expression_statement] = "expression_statement",
  [sym_variable_declaration] = "variable_declaration",
  [sym_lexical_declaration] = "lexical_declaration",
  [sym_variable_declarator] = "variable_declarator",
  [sym_statement_block] = "statement_block",
  [sym_else_clause] = "else_clause",
  [sym_if_statement] = "if_statement",
  [sym_switch_statement] = "switch_statement",
  [sym_for_statement] = "for_statement",
  [sym_for_in_statement] = "for_in_statement",
  [sym__for_header] = "_for_header",
  [sym_while_statement] = "while_statement",
  [sym_do_statement] = "do_statement",
  [sym_try_statement] = "try_statement",
  [sym_with_statement] = "with_statement",
  [sym_break_statement] = "break_statement",
  [sym_continue_statement] = "continue_statement",
  [sym_debugger_statement] = "debugger_statement",
  [sym_return_statement] = "return_statement",
  [sym_throw_statement] = "throw_statement",
  [sym_empty_statement] = "empty_statement",
  [sym_labeled_statement] = "labeled_statement",
  [sym_switch_body] = "switch_body",
  [sym_switch_case] = "switch_case",
  [sym_switch_default] = "switch_default",
  [sym_catch_clause] = "catch_clause",
  [sym_finally_clause] = "finally_clause",
  [sym_parenthesized_expression] = "parenthesized_expression",
  [sym_expression] = "expression",
  [sym_primary_expression] = "primary_expression",
  [sym_yield_expression] = "yield_expression",
  [sym_object] = "object",
  [sym_object_pattern] = "object_pattern",
  [sym_assignment_pattern] = "assignment_pattern",
  [sym_object_assignment_pattern] = "object_assignment_pattern",
  [sym_array] = "array",
  [sym_array_pattern] = "array_pattern",
  [sym_nested_identifier] = "nested_identifier",
  [sym_class] = "class",
  [sym_class_declaration] = "class_declaration",
  [sym_class_heritage] = "class_heritage",
  [sym_function_expression] = "function_expression",
  [sym_function_declaration] = "function_declaration",
  [sym_generator_function] = "generator_function",
  [sym_generator_function_declaration] = "generator_function_declaration",
  [sym_arrow_function] = "arrow_function",
  [sym__call_signature] = "_call_signature",
  [sym__formal_parameter] = "_formal_parameter",
  [sym_optional_chain] = "optional_chain",
  [sym_call_expression] = "call_expression",
  [sym_new_expression] = "new_expression",
  [sym_await_expression] = "await_expression",
  [sym_member_expression] = "member_expression",
  [sym_subscript_expression] = "subscript_expression",
  [sym_assignment_expression] = "assignment_expression",
  [sym__augmented_assignment_lhs] = "_augmented_assignment_lhs",
  [sym_augmented_assignment_expression] = "augmented_assignment_expression",
  [sym__initializer] = "_initializer",
  [sym__destructuring_pattern] = "_destructuring_pattern",
  [sym_spread_element] = "spread_element",
  [sym_ternary_expression] = "ternary_expression",
  [sym_binary_expression] = "binary_expression",
  [sym_unary_expression] = "unary_expression",
  [sym_update_expression] = "update_expression",
  [sym_sequence_expression] = "sequence_expression",
  [sym_string] = "string",
  [sym_template_string] = "template_string",
  [sym_template_substitution] = "template_substitution",
  [sym_regex] = "regex",
  [sym_meta_property] = "meta_property",
  [sym_arguments] = "arguments",
  [sym_decorator] = "decorator",
  [sym_decorator_member_expression] = "member_expression",
  [sym_decorator_call_expression] = "call_expression",
  [sym_class_body] = "class_body",
  [sym_formal_parameters] = "formal_parameters",
  [sym_class_static_block] = "class_static_block",
  [sym_pattern] = "pattern",
  [sym_rest_pattern] = "rest_pattern",
  [sym_method_definition] = "method_definition",
  [sym_pair] = "pair",
  [sym_pair_pattern] = "pair_pattern",
  [sym__property_name] = "_property_name",
  [sym_computed_property_name] = "computed_property_name",
  [sym_public_field_definition] = "public_field_definition",
  [sym__import_identifier] = "_import_identifier",
  [sym_non_null_expression] = "non_null_expression",
  [sym_method_signature] = "method_signature",
  [sym_abstract_method_signature] = "abstract_method_signature",
  [sym_function_signature] = "function_signature",
  [sym_decorator_parenthesized_expression] = "parenthesized_expression",
  [sym_type_assertion] = "type_assertion",
  [sym_as_expression] = "as_expression",
  [sym_satisfies_expression] = "satisfies_expression",
  [sym_instantiation_expression] = "instantiation_expression",
  [sym_import_require_clause] = "import_require_clause",
  [sym_extends_clause] = "extends_clause",
  [sym__extends_clause_single] = "_extends_clause_single",
  [sym_implements_clause] = "implements_clause",
  [sym_ambient_declaration] = "ambient_declaration",
  [sym_abstract_class_declaration] = "abstract_class_declaration",
  [sym_module] = "module",
  [sym_internal_module] = "internal_module",
  [sym__module] = "_module",
  [sym_import_alias] = "import_alias",
  [sym_nested_type_identifier] = "nested_type_identifier",
  [sym_interface_declaration] = "interface_declaration",
  [sym_extends_type_clause] = "extends_type_clause",
  [sym_enum_declaration] = "enum_declaration",
  [sym_enum_body] = "enum_body",
  [sym_enum_assignment] = "enum_assignment",
  [sym_type_alias_declaration] = "type_alias_declaration",
  [sym_accessibility_modifier] = "accessibility_modifier",
  [sym_override_modifier] = "override_modifier",
  [sym_required_parameter] = "required_parameter",
  [sym_optional_parameter] = "optional_parameter",
  [sym__parameter_name] = "_parameter_name",
  [sym_omitting_type_annotation] = "omitting_type_annotation",
  [sym_adding_type_annotation] = "adding_type_annotation",
  [sym_opting_type_annotation] = "opting_type_annotation",
  [sym_type_annotation] = "type_annotation",
  [sym__type_query_member_expression_in_type_annotation] = "member_expression",
  [sym__type_query_call_expression_in_type_annotation] = "call_expression",
  [sym_asserts] = "asserts",
  [sym_asserts_annotation] = "asserts_annotation",
  [sym_type] = "type",
  [sym_tuple_parameter] = "required_parameter",
  [sym_optional_tuple_parameter] = "optional_parameter",
  [sym_optional_type] = "optional_type",
  [sym_rest_type] = "rest_type",
  [sym__tuple_type_member] = "_tuple_type_member",
  [sym_constructor_type] = "constructor_type",
  [sym_primary_type] = "primary_type",
  [sym_template_type] = "template_type",
  [sym_template_literal_type] = "template_literal_type",
  [sym_infer_type] = "infer_type",
  [sym_conditional_type] = "conditional_type",
  [sym_generic_type] = "generic_type",
  [sym_type_predicate] = "type_predicate",
  [sym_type_predicate_annotation] = "type_predicate_annotation",
  [sym__type_query_member_expression] = "member_expression",
  [sym__type_query_subscript_expression] = "subscript_expression",
  [sym__type_query_call_expression] = "call_expression",
  [sym__type_query_instantiation_expression] = "instantiation_expression",
  [sym_type_query] = "type_query",
  [sym_index_type_query] = "index_type_query",
  [sym_lookup_type] = "lookup_type",
  [sym_mapped_type_clause] = "mapped_type_clause",
  [sym_literal_type] = "literal_type",
  [sym__number] = "unary_expression",
  [sym_existential_type] = "existential_type",
  [sym_flow_maybe_type] = "flow_maybe_type",
  [sym_parenthesized_type] = "parenthesized_type",
  [sym_predefined_type] = "predefined_type",
  [sym_type_arguments] = "type_arguments",
  [sym_object_type] = "object_type",
  [sym_call_signature] = "call_signature",
  [sym_property_signature] = "property_signature",
  [sym_type_parameters] = "type_parameters",
  [sym_type_parameter] = "type_parameter",
  [sym_default_type] = "default_type",
  [sym_constraint] = "constraint",
  [sym_construct_signature] = "construct_signature",
  [sym_index_signature] = "index_signature",
  [sym_array_type] = "array_type",
  [sym_tuple_type] = "tuple_type",
  [sym_readonly_type] = "readonly_type",
  [sym_union_type] = "union_type",
  [sym_intersection_type] = "intersection_type",
  [sym_function_type] = "function_type",
  [aux_sym_program_repeat1] = "program_repeat1",
  [aux_sym_export_statement_repeat1] = "export_statement_repeat1",
  [aux_sym_export_clause_repeat1] = "export_clause_repeat1",
  [aux_sym_named_imports_repeat1] = "named_imports_repeat1",
  [aux_sym_variable_declaration_repeat1] = "variable_declaration_repeat1",
  [aux_sym_switch_body_repeat1] = "switch_body_repeat1",
  [aux_sym_object_repeat1] = "object_repeat1",
  [aux_sym_object_pattern_repeat1] = "object_pattern_repeat1",
  [aux_sym_array_repeat1] = "array_repeat1",
  [aux_sym_array_pattern_repeat1] = "array_pattern_repeat1",
  [aux_sym_sequence_expression_repeat1] = "sequence_expression_repeat1",
  [aux_sym_string_repeat1] = "string_repeat1",
  [aux_sym_string_repeat2] = "string_repeat2",
  [aux_sym_template_string_repeat1] = "template_string_repeat1",
  [aux_sym_class_body_repeat1] = "class_body_repeat1",
  [aux_sym_formal_parameters_repeat1] = "formal_parameters_repeat1",
  [aux_sym_extends_clause_repeat1] = "extends_clause_repeat1",
  [aux_sym_implements_clause_repeat1] = "implements_clause_repeat1",
  [aux_sym_extends_type_clause_repeat1] = "extends_type_clause_repeat1",
  [aux_sym_enum_body_repeat1] = "enum_body_repeat1",
  [aux_sym_template_literal_type_repeat1] = "template_literal_type_repeat1",
  [aux_sym_object_type_repeat1] = "object_type_repeat1",
  [aux_sym_type_parameters_repeat1] = "type_parameters_repeat1",
  [aux_sym_tuple_type_repeat1] = "tuple_type_repeat1",
  [alias_sym_interface_body] = "interface_body",
  [alias_sym_property_identifier] = "property_identifier",
  [alias_sym_shorthand_property_identifier] = "shorthand_property_identifier",
  [alias_sym_shorthand_property_identifier_pattern] = "shorthand_property_identifier_pattern",
  [alias_sym_statement_identifier] = "statement_identifier",
  [alias_sym_this_type] = "this_type",
  [alias_sym_type_identifier] = "type_identifier",
};

static const TSSymbol ts_symbol_map[] = {
  [ts_builtin_sym_end] = ts_builtin_sym_end,
  [sym_identifier] = sym_identifier,
  [sym_hash_bang_line] = sym_hash_bang_line,
  [anon_sym_export] = anon_sym_export,
  [anon_sym_STAR] = anon_sym_STAR,
  [anon_sym_default] = anon_sym_default,
  [anon_sym_type] = anon_sym_type,
  [anon_sym_EQ] = anon_sym_EQ,
  [anon_sym_as] = anon_sym_as,
  [anon_sym_namespace] = anon_sym_namespace,
  [anon_sym_LBRACE] = anon_sym_LBRACE,
  [anon_sym_COMMA] = anon_sym_COMMA,
  [anon_sym_RBRACE] = anon_sym_RBRACE,
  [anon_sym_typeof] = anon_sym_typeof,
  [anon_sym_import] = anon_sym_import,
  [anon_sym_from] = anon_sym_from,
  [anon_sym_with] = anon_sym_with,
  [anon_sym_assert] = anon_sym_assert,
  [anon_sym_var] = anon_sym_var,
  [anon_sym_let] = anon_sym_let,
  [anon_sym_const] = anon_sym_const,
  [anon_sym_BANG] = anon_sym_BANG,
  [anon_sym_else] = anon_sym_else,
  [anon_sym_if] = anon_sym_if,
  [anon_sym_switch] = anon_sym_switch,
  [anon_sym_for] = anon_sym_for,
  [anon_sym_LPAREN] = anon_sym_LPAREN,
  [anon_sym_SEMI] = anon_sym_SEMI,
  [anon_sym_RPAREN] = anon_sym_RPAREN,
  [anon_sym_await] = anon_sym_await,
  [anon_sym_in] = anon_sym_in,
  [anon_sym_of] = anon_sym_of,
  [anon_sym_while] = anon_sym_while,
  [anon_sym_do] = anon_sym_do,
  [anon_sym_try] = anon_sym_try,
  [anon_sym_break] = anon_sym_break,
  [anon_sym_continue] = anon_sym_continue,
  [anon_sym_debugger] = anon_sym_debugger,
  [anon_sym_return] = anon_sym_return,
  [anon_sym_throw] = anon_sym_throw,
  [anon_sym_COLON] = anon_sym_COLON,
  [anon_sym_case] = anon_sym_case,
  [anon_sym_catch] = anon_sym_catch,
  [anon_sym_finally] = anon_sym_finally,
  [anon_sym_yield] = anon_sym_yield,
  [anon_sym_LBRACK] = anon_sym_LBRACK,
  [anon_sym_RBRACK] = anon_sym_RBRACK,
  [anon_sym_DOT] = anon_sym_DOT,
  [anon_sym_class] = anon_sym_class,
  [anon_sym_async] = anon_sym_async,
  [anon_sym_function] = anon_sym_function,
  [anon_sym_EQ_GT] = anon_sym_EQ_GT,
  [anon_sym_QMARK_DOT] = anon_sym_QMARK_DOT,
  [anon_sym_new] = anon_sym_new,
  [anon_sym_using] = anon_sym_using,
  [anon_sym_PLUS_EQ] = anon_sym_PLUS_EQ,
  [anon_sym_DASH_EQ] = anon_sym_DASH_EQ,
  [anon_sym_STAR_EQ] = anon_sym_STAR_EQ,
  [anon_sym_SLASH_EQ] = anon_sym_SLASH_EQ,
  [anon_sym_PERCENT_EQ] = anon_sym_PERCENT_EQ,
  [anon_sym_CARET_EQ] = anon_sym_CARET_EQ,
  [anon_sym_AMP_EQ] = anon_sym_AMP_EQ,
  [anon_sym_PIPE_EQ] = anon_sym_PIPE_EQ,
  [anon_sym_GT_GT_EQ] = anon_sym_GT_GT_EQ,
  [anon_sym_GT_GT_GT_EQ] = anon_sym_GT_GT_GT_EQ,
  [anon_sym_LT_LT_EQ] = anon_sym_LT_LT_EQ,
  [anon_sym_STAR_STAR_EQ] = anon_sym_STAR_STAR_EQ,
  [anon_sym_AMP_AMP_EQ] = anon_sym_AMP_AMP_EQ,
  [anon_sym_PIPE_PIPE_EQ] = anon_sym_PIPE_PIPE_EQ,
  [anon_sym_QMARK_QMARK_EQ] = anon_sym_QMARK_QMARK_EQ,
  [anon_sym_DOT_DOT_DOT] = anon_sym_DOT_DOT_DOT,
  [anon_sym_AMP_AMP] = anon_sym_AMP_AMP,
  [anon_sym_PIPE_PIPE] = anon_sym_PIPE_PIPE,
  [anon_sym_GT_GT] = anon_sym_GT_GT,
  [anon_sym_GT_GT_GT] = anon_sym_GT_GT_GT,
  [anon_sym_LT_LT] = anon_sym_LT_LT,
  [anon_sym_AMP] = anon_sym_AMP,
  [anon_sym_CARET] = anon_sym_CARET,
  [anon_sym_PIPE] = anon_sym_PIPE,
  [anon_sym_PLUS] = anon_sym_PLUS,
  [anon_sym_DASH] = anon_sym_DASH,
  [anon_sym_SLASH] = anon_sym_SLASH,
  [anon_sym_PERCENT] = anon_sym_PERCENT,
  [anon_sym_STAR_STAR] = anon_sym_STAR_STAR,
  [anon_sym_LT] = anon_sym_LT,
  [anon_sym_LT_EQ] = anon_sym_LT_EQ,
  [anon_sym_EQ_EQ] = anon_sym_EQ_EQ,
  [anon_sym_EQ_EQ_EQ] = anon_sym_EQ_EQ_EQ,
  [anon_sym_BANG_EQ] = anon_sym_BANG_EQ,
  [anon_sym_BANG_EQ_EQ] = anon_sym_BANG_EQ_EQ,
  [anon_sym_GT_EQ] = anon_sym_GT_EQ,
  [anon_sym_GT] = anon_sym_GT,
  [anon_sym_QMARK_QMARK] = anon_sym_QMARK_QMARK,
  [anon_sym_instanceof] = anon_sym_instanceof,
  [anon_sym_TILDE] = anon_sym_TILDE,
  [anon_sym_void] = anon_sym_void,
  [anon_sym_delete] = anon_sym_delete,
  [anon_sym_PLUS_PLUS] = anon_sym_PLUS_PLUS,
  [anon_sym_DASH_DASH] = anon_sym_DASH_DASH,
  [anon_sym_DQUOTE] = anon_sym_DQUOTE,
  [anon_sym_SQUOTE] = anon_sym_SQUOTE,
  [sym_unescaped_double_string_fragment] = sym__template_chars,
  [sym_unescaped_single_string_fragment] = sym__template_chars,
  [sym_escape_sequence] = sym_escape_sequence,
  [sym_comment] = sym_comment,
  [anon_sym_BQUOTE] = anon_sym_BQUOTE,
  [anon_sym_DOLLAR_LBRACE] = anon_sym_DOLLAR_LBRACE,
  [anon_sym_SLASH2] = anon_sym_SLASH,
  [sym_regex_pattern] = sym_regex_pattern,
  [sym_regex_flags] = sym_regex_flags,
  [sym_number] = sym_number,
  [sym_private_property_identifier] = sym_private_property_identifier,
  [anon_sym_target] = anon_sym_target,
  [anon_sym_meta] = anon_sym_meta,
  [sym_this] = sym_this,
  [sym_super] = sym_super,
  [sym_true] = sym_true,
  [sym_false] = sym_false,
  [sym_null] = sym_null,
  [sym_undefined] = sym_undefined,
  [anon_sym_AT] = anon_sym_AT,
  [anon_sym_static] = anon_sym_static,
  [anon_sym_readonly] = anon_sym_readonly,
  [anon_sym_get] = anon_sym_get,
  [anon_sym_set] = anon_sym_set,
  [anon_sym_QMARK] = anon_sym_QMARK,
  [anon_sym_declare] = anon_sym_declare,
  [anon_sym_public] = anon_sym_public,
  [anon_sym_private] = anon_sym_private,
  [anon_sym_protected] = anon_sym_protected,
  [anon_sym_override] = anon_sym_override,
  [anon_sym_module] = anon_sym_module,
  [anon_sym_any] = anon_sym_any,
  [anon_sym_number] = anon_sym_number,
  [anon_sym_boolean] = anon_sym_boolean,
  [anon_sym_string] = anon_sym_string,
  [anon_sym_symbol] = anon_sym_symbol,
  [anon_sym_object] = anon_sym_object,
  [anon_sym_abstract] = anon_sym_abstract,
  [anon_sym_accessor] = anon_sym_accessor,
  [anon_sym_satisfies] = anon_sym_satisfies,
  [anon_sym_require] = anon_sym_require,
  [anon_sym_extends] = anon_sym_extends,
  [anon_sym_implements] = anon_sym_implements,
  [anon_sym_global] = anon_sym_global,
  [anon_sym_interface] = anon_sym_interface,
  [anon_sym_enum] = anon_sym_enum,
  [anon_sym_DASH_QMARK_COLON] = anon_sym_DASH_QMARK_COLON,
  [anon_sym_PLUS_QMARK_COLON] = anon_sym_PLUS_QMARK_COLON,
  [anon_sym_QMARK_COLON] = anon_sym_QMARK_COLON,
  [anon_sym_asserts] = anon_sym_asserts,
  [anon_sym_infer] = anon_sym_infer,
  [anon_sym_is] = anon_sym_is,
  [anon_sym_keyof] = anon_sym_keyof,
  [anon_sym_unique] = anon_sym_unique,
  [anon_sym_unknown] = anon_sym_unknown,
  [anon_sym_never] = anon_sym_never,
  [anon_sym_LBRACE_PIPE] = anon_sym_LBRACE_PIPE,
  [anon_sym_PIPE_RBRACE] = anon_sym_PIPE_RBRACE,
  [sym__automatic_semicolon] = sym__automatic_semicolon,
  [sym__template_chars] = sym__template_chars,
  [sym__ternary_qmark] = anon_sym_QMARK,
  [sym_html_comment] = sym_html_comment,
  [sym_jsx_text] = sym_jsx_text,
  [sym__function_signature_automatic_semicolon] = sym__function_signature_automatic_semicolon,
  [sym___error_recovery] = sym___error_recovery,
  [sym_program] = sym_program,
  [sym_export_statement] = sym_export_statement,
  [sym_namespace_export] = sym_namespace_export,
  [sym_export_clause] = sym_export_clause,
  [sym_export_specifier] = sym_export_specifier,
  [sym__module_export_name] = sym__module_export_name,
  [sym_declaration] = sym_declaration,
  [sym_import] = sym_import,
  [sym_import_statement] = sym_import_statement,
  [sym_import_clause] = sym_import_clause,
  [sym__from_clause] = sym__from_clause,
  [sym_namespace_import] = sym_namespace_import,
  [sym_named_imports] = sym_named_imports,
  [sym_import_specifier] = sym_import_specifier,
  [sym_import_attribute] = sym_import_attribute,
  [sym_statement] = sym_statement,
  [sym_expression_statement] = sym_expression_statement,
  [sym_variable_declaration] = sym_variable_declaration,
  [sym_lexical_declaration] = sym_lexical_declaration,
  [sym_variable_declarator] = sym_variable_declarator,
  [sym_statement_block] = sym_statement_block,
  [sym_else_clause] = sym_else_clause,
  [sym_if_statement] = sym_if_statement,
  [sym_switch_statement] = sym_switch_statement,
  [sym_for_statement] = sym_for_statement,
  [sym_for_in_statement] = sym_for_in_statement,
  [sym__for_header] = sym__for_header,
  [sym_while_statement] = sym_while_statement,
  [sym_do_statement] = sym_do_statement,
  [sym_try_statement] = sym_try_statement,
  [sym_with_statement] = sym_with_statement,
  [sym_break_statement] = sym_break_statement,
  [sym_continue_statement] = sym_continue_statement,
  [sym_debugger_statement] = sym_debugger_statement,
  [sym_return_statement] = sym_return_statement,
  [sym_throw_statement] = sym_throw_statement,
  [sym_empty_statement] = sym_empty_statement,
  [sym_labeled_statement] = sym_labeled_statement,
  [sym_switch_body] = sym_switch_body,
  [sym_switch_case] = sym_switch_case,
  [sym_switch_default] = sym_switch_default,
  [sym_catch_clause] = sym_catch_clause,
  [sym_finally_clause] = sym_finally_clause,
  [sym_parenthesized_expression] = sym_parenthesized_expression,
  [sym_expression] = sym_expression,
  [sym_primary_expression] = sym_primary_expression,
  [sym_yield_expression] = sym_yield_expression,
  [sym_object] = sym_object,
  [sym_object_pattern] = sym_object_pattern,
  [sym_assignment_pattern] = sym_assignment_pattern,
  [sym_object_assignment_pattern] = sym_object_assignment_pattern,
  [sym_array] = sym_array,
  [sym_array_pattern] = sym_array_pattern,
  [sym_nested_identifier] = sym_nested_identifier,
  [sym_class] = sym_class,
  [sym_class_declaration] = sym_class_declaration,
  [sym_class_heritage] = sym_class_heritage,
  [sym_function_expression] = sym_function_expression,
  [sym_function_declaration] = sym_function_declaration,
  [sym_generator_function] = sym_generator_function,
  [sym_generator_function_declaration] = sym_generator_function_declaration,
  [sym_arrow_function] = sym_arrow_function,
  [sym__call_signature] = sym__call_signature,
  [sym__formal_parameter] = sym__formal_parameter,
  [sym_optional_chain] = sym_optional_chain,
  [sym_call_expression] = sym_call_expression,
  [sym_new_expression] = sym_new_expression,
  [sym_await_expression] = sym_await_expression,
  [sym_member_expression] = sym_member_expression,
  [sym_subscript_expression] = sym_subscript_expression,
  [sym_assignment_expression] = sym_assignment_expression,
  [sym__augmented_assignment_lhs] = sym__augmented_assignment_lhs,
  [sym_augmented_assignment_expression] = sym_augmented_assignment_expression,
  [sym__initializer] = sym__initializer,
  [sym__destructuring_pattern] = sym__destructuring_pattern,
  [sym_spread_element] = sym_spread_element,
  [sym_ternary_expression] = sym_ternary_expression,
  [sym_binary_expression] = sym_binary_expression,
  [sym_unary_expression] = sym_unary_expression,
  [sym_update_expression] = sym_update_expression,
  [sym_sequence_expression] = sym_sequence_expression,
  [sym_string] = sym_string,
  [sym_template_string] = sym_template_string,
  [sym_template_substitution] = sym_template_substitution,
  [sym_regex] = sym_regex,
  [sym_meta_property] = sym_meta_property,
  [sym_arguments] = sym_arguments,
  [sym_decorator] = sym_decorator,
  [sym_decorator_member_expression] = sym_member_expression,
  [sym_decorator_call_expression] = sym_call_expression,
  [sym_class_body] = sym_class_body,
  [sym_formal_parameters] = sym_formal_parameters,
  [sym_class_static_block] = sym_class_static_block,
  [sym_pattern] = sym_pattern,
  [sym_rest_pattern] = sym_rest_pattern,
  [sym_method_definition] = sym_method_definition,
  [sym_pair] = sym_pair,
  [sym_pair_pattern] = sym_pair_pattern,
  [sym__property_name] = sym__property_name,
  [sym_computed_property_name] = sym_computed_property_name,
  [sym_public_field_definition] = sym_public_field_definition,
  [sym__import_identifier] = sym__import_identifier,
  [sym_non_null_expression] = sym_non_null_expression,
  [sym_method_signature] = sym_method_signature,
  [sym_abstract_method_signature] = sym_abstract_method_signature,
  [sym_function_signature] = sym_function_signature,
  [sym_decorator_parenthesized_expression] = sym_parenthesized_expression,
  [sym_type_assertion] = sym_type_assertion,
  [sym_as_expression] = sym_as_expression,
  [sym_satisfies_expression] = sym_satisfies_expression,
  [sym_instantiation_expression] = sym_instantiation_expression,
  [sym_import_require_clause] = sym_import_require_clause,
  [sym_extends_clause] = sym_extends_clause,
  [sym__extends_clause_single] = sym__extends_clause_single,
  [sym_implements_clause] = sym_implements_clause,
  [sym_ambient_declaration] = sym_ambient_declaration,
  [sym_abstract_class_declaration] = sym_abstract_class_declaration,
  [sym_module] = sym_module,
  [sym_internal_module] = sym_internal_module,
  [sym__module] = sym__module,
  [sym_import_alias] = sym_import_alias,
  [sym_nested_type_identifier] = sym_nested_type_identifier,
  [sym_interface_declaration] = sym_interface_declaration,
  [sym_extends_type_clause] = sym_extends_type_clause,
  [sym_enum_declaration] = sym_enum_declaration,
  [sym_enum_body] = sym_enum_body,
  [sym_enum_assignment] = sym_enum_assignment,
  [sym_type_alias_declaration] = sym_type_alias_declaration,
  [sym_accessibility_modifier] = sym_accessibility_modifier,
  [sym_override_modifier] = sym_override_modifier,
  [sym_required_parameter] = sym_required_parameter,
  [sym_optional_parameter] = sym_optional_parameter,
  [sym__parameter_name] = sym__parameter_name,
  [sym_omitting_type_annotation] = sym_omitting_type_annotation,
  [sym_adding_type_annotation] = sym_adding_type_annotation,
  [sym_opting_type_annotation] = sym_opting_type_annotation,
  [sym_type_annotation] = sym_type_annotation,
  [sym__type_query_member_expression_in_type_annotation] = sym_member_expression,
  [sym__type_query_call_expression_in_type_annotation] = sym_call_expression,
  [sym_asserts] = sym_asserts,
  [sym_asserts_annotation] = sym_asserts_annotation,
  [sym_type] = sym_type,
  [sym_tuple_parameter] = sym_required_parameter,
  [sym_optional_tuple_parameter] = sym_optional_parameter,
  [sym_optional_type] = sym_optional_type,
  [sym_rest_type] = sym_rest_type,
  [sym__tuple_type_member] = sym__tuple_type_member,
  [sym_constructor_type] = sym_constructor_type,
  [sym_primary_type] = sym_primary_type,
  [sym_template_type] = sym_template_type,
  [sym_template_literal_type] = sym_template_literal_type,
  [sym_infer_type] = sym_infer_type,
  [sym_conditional_type] = sym_conditional_type,
  [sym_generic_type] = sym_generic_type,
  [sym_type_predicate] = sym_type_predicate,
  [sym_type_predicate_annotation] = sym_type_predicate_annotation,
  [sym__type_query_member_expression] = sym_member_expression,
  [sym__type_query_subscript_expression] = sym_subscript_expression,
  [sym__type_query_call_expression] = sym_call_expression,
  [sym__type_query_instantiation_expression] = sym_instantiation_expression,
  [sym_type_query] = sym_type_query,
  [sym_index_type_query] = sym_index_type_query,
  [sym_lookup_type] = sym_lookup_type,
  [sym_mapped_type_clause] = sym_mapped_type_clause,
  [sym_literal_type] = sym_literal_type,
  [sym__number] = sym_unary_expression,
  [sym_existential_type] = sym_existential_type,
  [sym_flow_maybe_type] = sym_flow_maybe_type,
  [sym_parenthesized_type] = sym_parenthesized_type,
  [sym_predefined_type] = sym_predefined_type,
  [sym_type_arguments] = sym_type_arguments,
  [sym_object_type] = sym_object_type,
  [sym_call_signature] = sym_call_signature,
  [sym_property_signature] = sym_property_signature,
  [sym_type_parameters] = sym_type_parameters,
  [sym_type_parameter] = sym_type_parameter,
  [sym_default_type] = sym_default_type,
  [sym_constraint] = sym_constraint,
  [sym_construct_signature] = sym_construct_signature,
  [sym_index_signature] = sym_index_signature,
  [sym_array_type] = sym_array_type,
  [sym_tuple_type] = sym_tuple_type,
  [sym_readonly_type] = sym_readonly_type,
  [sym_union_type] = sym_union_type,
  [sym_intersection_type] = sym_intersection_type,
  [sym_function_type] = sym_function_type,
  [aux_sym_program_repeat1] = aux_sym_program_repeat1,
  [aux_sym_export_statement_repeat1] = aux_sym_export_statement_repeat1,
  [aux_sym_export_clause_repeat1] = aux_sym_export_clause_repeat1,
  [aux_sym_named_imports_repeat1] = aux_sym_named_imports_repeat1,
  [aux_sym_variable_declaration_repeat1] = aux_sym_variable_declaration_repeat1,
  [aux_sym_switch_body_repeat1] = aux_sym_switch_body_repeat1,
  [aux_sym_object_repeat1] = aux_sym_object_repeat1,
  [aux_sym_object_pattern_repeat1] = aux_sym_object_pattern_repeat1,
  [aux_sym_array_repeat1] = aux_sym_array_repeat1,
  [aux_sym_array_pattern_repeat1] = aux_sym_array_pattern_repeat1,
  [aux_sym_sequence_expression_repeat1] = aux_sym_sequence_expression_repeat1,
  [aux_sym_string_repeat1] = aux_sym_string_repeat1,
  [aux_sym_string_repeat2] = aux_sym_string_repeat2,
  [aux_sym_template_string_repeat1] = aux_sym_template_string_repeat1,
  [aux_sym_class_body_repeat1] = aux_sym_class_body_repeat1,
  [aux_sym_formal_parameters_repeat1] = aux_sym_formal_parameters_repeat1,
  [aux_sym_extends_clause_repeat1] = aux_sym_extends_clause_repeat1,
  [aux_sym_implements_clause_repeat1] = aux_sym_implements_clause_repeat1,
  [aux_sym_extends_type_clause_repeat1] = aux_sym_extends_type_clause_repeat1,
  [aux_sym_enum_body_repeat1] = aux_sym_enum_body_repeat1,
  [aux_sym_template_literal_type_repeat1] = aux_sym_template_literal_type_repeat1,
  [aux_sym_object_type_repeat1] = aux_sym_object_type_repeat1,
  [aux_sym_type_parameters_repeat1] = aux_sym_type_parameters_repeat1,
  [aux_sym_tuple_type_repeat1] = aux_sym_tuple_type_repeat1,
  [alias_sym_interface_body] = alias_sym_interface_body,
  [alias_sym_property_identifier] = alias_sym_property_identifier,
  [alias_sym_shorthand_property_identifier] = alias_sym_shorthand_property_identifier,
  [alias_sym_shorthand_property_identifier_pattern] = alias_sym_shorthand_property_identifier_pattern,
  [alias_sym_statement_identifier] = alias_sym_statement_identifier,
  [alias_sym_this_type] = alias_sym_this_type,
  [alias_sym_type_identifier] = alias_sym_type_identifier,
};

static const TSSymbolMetadata ts_symbol_metadata[] = {
  [ts_builtin_sym_end] = {
    .visible = false,
    .named = true,
  },
  [sym_identifier] = {
    .visible = true,
    .named = true,
  },
  [sym_hash_bang_line] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_export] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_STAR] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_default] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_type] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_as] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_namespace] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LBRACE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_COMMA] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_RBRACE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_typeof] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_import] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_from] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_with] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_assert] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_var] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_let] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_const] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_BANG] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_else] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_if] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_switch] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_for] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LPAREN] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_SEMI] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_RPAREN] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_await] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_in] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_of] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_while] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_do] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_try] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_break] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_continue] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_debugger] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_return] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_throw] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_COLON] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_case] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_catch] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_finally] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_yield] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LBRACK] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_RBRACK] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DOT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_class] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_async] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_function] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_EQ_GT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_QMARK_DOT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_new] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_using] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PLUS_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DASH_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_STAR_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_SLASH_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PERCENT_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_CARET_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_AMP_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PIPE_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_GT_GT_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_GT_GT_GT_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LT_LT_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_STAR_STAR_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_AMP_AMP_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PIPE_PIPE_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_QMARK_QMARK_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DOT_DOT_DOT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_AMP_AMP] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PIPE_PIPE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_GT_GT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_GT_GT_GT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LT_LT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_AMP] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_CARET] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PIPE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PLUS] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DASH] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_SLASH] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PERCENT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_STAR_STAR] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LT_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_EQ_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_EQ_EQ_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_BANG_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_BANG_EQ_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_GT_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_GT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_QMARK_QMARK] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_instanceof] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_TILDE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_void] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_delete] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PLUS_PLUS] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DASH_DASH] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DQUOTE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_SQUOTE] = {
    .visible = true,
    .named = false,
  },
  [sym_unescaped_double_string_fragment] = {
    .visible = true,
    .named = true,
  },
  [sym_unescaped_single_string_fragment] = {
    .visible = true,
    .named = true,
  },
  [sym_escape_sequence] = {
    .visible = true,
    .named = true,
  },
  [sym_comment] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_BQUOTE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DOLLAR_LBRACE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_SLASH2] = {
    .visible = true,
    .named = false,
  },
  [sym_regex_pattern] = {
    .visible = true,
    .named = true,
  },
  [sym_regex_flags] = {
    .visible = true,
    .named = true,
  },
  [sym_number] = {
    .visible = true,
    .named = true,
  },
  [sym_private_property_identifier] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_target] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_meta] = {
    .visible = true,
    .named = false,
  },
  [sym_this] = {
    .visible = true,
    .named = true,
  },
  [sym_super] = {
    .visible = true,
    .named = true,
  },
  [sym_true] = {
    .visible = true,
    .named = true,
  },
  [sym_false] = {
    .visible = true,
    .named = true,
  },
  [sym_null] = {
    .visible = true,
    .named = true,
  },
  [sym_undefined] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_AT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_static] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_readonly] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_get] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_set] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_QMARK] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_declare] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_public] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_private] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_protected] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_override] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_module] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_any] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_number] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_boolean] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_string] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_symbol] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_object] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_abstract] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_accessor] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_satisfies] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_require] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_extends] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_implements] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_global] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_interface] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_enum] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DASH_QMARK_COLON] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PLUS_QMARK_COLON] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_QMARK_COLON] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_asserts] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_infer] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_is] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_keyof] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_unique] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_unknown] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_never] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LBRACE_PIPE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PIPE_RBRACE] = {
    .visible = true,
    .named = false,
  },
  [sym__automatic_semicolon] = {
    .visible = false,
    .named = true,
  },
  [sym__template_chars] = {
    .visible = true,
    .named = true,
  },
  [sym__ternary_qmark] = {
    .visible = true,
    .named = false,
  },
  [sym_html_comment] = {
    .visible = true,
    .named = true,
  },
  [sym_jsx_text] = {
    .visible = true,
    .named = true,
  },
  [sym__function_signature_automatic_semicolon] = {
    .visible = false,
    .named = true,
  },
  [sym___error_recovery] = {
    .visible = false,
    .named = true,
  },
  [sym_program] = {
    .visible = true,
    .named = true,
  },
  [sym_export_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_namespace_export] = {
    .visible = true,
    .named = true,
  },
  [sym_export_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_export_specifier] = {
    .visible = true,
    .named = true,
  },
  [sym__module_export_name] = {
    .visible = false,
    .named = true,
  },
  [sym_declaration] = {
    .visible = false,
    .named = true,
    .supertype = true,
  },
  [sym_import] = {
    .visible = true,
    .named = true,
  },
  [sym_import_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_import_clause] = {
    .visible = true,
    .named = true,
  },
  [sym__from_clause] = {
    .visible = false,
    .named = true,
  },
  [sym_namespace_import] = {
    .visible = true,
    .named = true,
  },
  [sym_named_imports] = {
    .visible = true,
    .named = true,
  },
  [sym_import_specifier] = {
    .visible = true,
    .named = true,
  },
  [sym_import_attribute] = {
    .visible = true,
    .named = true,
  },
  [sym_statement] = {
    .visible = false,
    .named = true,
    .supertype = true,
  },
  [sym_expression_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_variable_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_lexical_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_variable_declarator] = {
    .visible = true,
    .named = true,
  },
  [sym_statement_block] = {
    .visible = true,
    .named = true,
  },
  [sym_else_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_if_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_switch_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_for_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_for_in_statement] = {
    .visible = true,
    .named = true,
  },
  [sym__for_header] = {
    .visible = false,
    .named = true,
  },
  [sym_while_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_do_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_try_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_with_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_break_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_continue_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_debugger_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_return_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_throw_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_empty_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_labeled_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_switch_body] = {
    .visible = true,
    .named = true,
  },
  [sym_switch_case] = {
    .visible = true,
    .named = true,
  },
  [sym_switch_default] = {
    .visible = true,
    .named = true,
  },
  [sym_catch_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_finally_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_parenthesized_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_expression] = {
    .visible = false,
    .named = true,
    .supertype = true,
  },
  [sym_primary_expression] = {
    .visible = false,
    .named = true,
    .supertype = true,
  },
  [sym_yield_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_object] = {
    .visible = true,
    .named = true,
  },
  [sym_object_pattern] = {
    .visible = true,
    .named = true,
  },
  [sym_assignment_pattern] = {
    .visible = true,
    .named = true,
  },
  [sym_object_assignment_pattern] = {
    .visible = true,
    .named = true,
  },
  [sym_array] = {
    .visible = true,
    .named = true,
  },
  [sym_array_pattern] = {
    .visible = true,
    .named = true,
  },
  [sym_nested_identifier] = {
    .visible = true,
    .named = true,
  },
  [sym_class] = {
    .visible = true,
    .named = true,
  },
  [sym_class_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_class_heritage] = {
    .visible = true,
    .named = true,
  },
  [sym_function_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_function_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_generator_function] = {
    .visible = true,
    .named = true,
  },
  [sym_generator_function_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_arrow_function] = {
    .visible = true,
    .named = true,
  },
  [sym__call_signature] = {
    .visible = false,
    .named = true,
  },
  [sym__formal_parameter] = {
    .visible = false,
    .named = true,
  },
  [sym_optional_chain] = {
    .visible = true,
    .named = true,
  },
  [sym_call_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_new_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_await_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_member_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_subscript_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_assignment_expression] = {
    .visible = true,
    .named = true,
  },
  [sym__augmented_assignment_lhs] = {
    .visible = false,
    .named = true,
  },
  [sym_augmented_assignment_expression] = {
    .visible = true,
    .named = true,
  },
  [sym__initializer] = {
    .visible = false,
    .named = true,
  },
  [sym__destructuring_pattern] = {
    .visible = false,
    .named = true,
  },
  [sym_spread_element] = {
    .visible = true,
    .named = true,
  },
  [sym_ternary_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_binary_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_unary_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_update_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_sequence_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_string] = {
    .visible = true,
    .named = true,
  },
  [sym_template_string] = {
    .visible = true,
    .named = true,
  },
  [sym_template_substitution] = {
    .visible = true,
    .named = true,
  },
  [sym_regex] = {
    .visible = true,
    .named = true,
  },
  [sym_meta_property] = {
    .visible = true,
    .named = true,
  },
  [sym_arguments] = {
    .visible = true,
    .named = true,
  },
  [sym_decorator] = {
    .visible = true,
    .named = true,
  },
  [sym_decorator_member_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_decorator_call_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_class_body] = {
    .visible = true,
    .named = true,
  },
  [sym_formal_parameters] = {
    .visible = true,
    .named = true,
  },
  [sym_class_static_block] = {
    .visible = true,
    .named = true,
  },
  [sym_pattern] = {
    .visible = false,
    .named = true,
    .supertype = true,
  },
  [sym_rest_pattern] = {
    .visible = true,
    .named = true,
  },
  [sym_method_definition] = {
    .visible = true,
    .named = true,
  },
  [sym_pair] = {
    .visible = true,
    .named = true,
  },
  [sym_pair_pattern] = {
    .visible = true,
    .named = true,
  },
  [sym__property_name] = {
    .visible = false,
    .named = true,
  },
  [sym_computed_property_name] = {
    .visible = true,
    .named = true,
  },
  [sym_public_field_definition] = {
    .visible = true,
    .named = true,
  },
  [sym__import_identifier] = {
    .visible = false,
    .named = true,
  },
  [sym_non_null_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_method_signature] = {
    .visible = true,
    .named = true,
  },
  [sym_abstract_method_signature] = {
    .visible = true,
    .named = true,
  },
  [sym_function_signature] = {
    .visible = true,
    .named = true,
  },
  [sym_decorator_parenthesized_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_type_assertion] = {
    .visible = true,
    .named = true,
  },
  [sym_as_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_satisfies_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_instantiation_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_import_require_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_extends_clause] = {
    .visible = true,
    .named = true,
  },
  [sym__extends_clause_single] = {
    .visible = false,
    .named = true,
  },
  [sym_implements_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_ambient_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_abstract_class_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_module] = {
    .visible = true,
    .named = true,
  },
  [sym_internal_module] = {
    .visible = true,
    .named = true,
  },
  [sym__module] = {
    .visible = false,
    .named = true,
  },
  [sym_import_alias] = {
    .visible = true,
    .named = true,
  },
  [sym_nested_type_identifier] = {
    .visible = true,
    .named = true,
  },
  [sym_interface_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_extends_type_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_enum_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_enum_body] = {
    .visible = true,
    .named = true,
  },
  [sym_enum_assignment] = {
    .visible = true,
    .named = true,
  },
  [sym_type_alias_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_accessibility_modifier] = {
    .visible = true,
    .named = true,
  },
  [sym_override_modifier] = {
    .visible = true,
    .named = true,
  },
  [sym_required_parameter] = {
    .visible = true,
    .named = true,
  },
  [sym_optional_parameter] = {
    .visible = true,
    .named = true,
  },
  [sym__parameter_name] = {
    .visible = false,
    .named = true,
  },
  [sym_omitting_type_annotation] = {
    .visible = true,
    .named = true,
  },
  [sym_adding_type_annotation] = {
    .visible = true,
    .named = true,
  },
  [sym_opting_type_annotation] = {
    .visible = true,
    .named = true,
  },
  [sym_type_annotation] = {
    .visible = true,
    .named = true,
  },
  [sym__type_query_member_expression_in_type_annotation] = {
    .visible = true,
    .named = true,
  },
  [sym__type_query_call_expression_in_type_annotation] = {
    .visible = true,
    .named = true,
  },
  [sym_asserts] = {
    .visible = true,
    .named = true,
  },
  [sym_asserts_annotation] = {
    .visible = true,
    .named = true,
  },
  [sym_type] = {
    .visible = false,
    .named = true,
    .supertype = true,
  },
  [sym_tuple_parameter] = {
    .visible = true,
    .named = true,
  },
  [sym_optional_tuple_parameter] = {
    .visible = true,
    .named = true,
  },
  [sym_optional_type] = {
    .visible = true,
    .named = true,
  },
  [sym_rest_type] = {
    .visible = true,
    .named = true,
  },
  [sym__tuple_type_member] = {
    .visible = false,
    .named = true,
  },
  [sym_constructor_type] = {
    .visible = true,
    .named = true,
  },
  [sym_primary_type] = {
    .visible = false,
    .named = true,
    .supertype = true,
  },
  [sym_template_type] = {
    .visible = true,
    .named = true,
  },
  [sym_template_literal_type] = {
    .visible = true,
    .named = true,
  },
  [sym_infer_type] = {
    .visible = true,
    .named = true,
  },
  [sym_conditional_type] = {
    .visible = true,
    .named = true,
  },
  [sym_generic_type] = {
    .visible = true,
    .named = true,
  },
  [sym_type_predicate] = {
    .visible = true,
    .named = true,
  },
  [sym_type_predicate_annotation] = {
    .visible = true,
    .named = true,
  },
  [sym__type_query_member_expression] = {
    .visible = true,
    .named = true,
  },
  [sym__type_query_subscript_expression] = {
    .visible = true,
    .named = true,
  },
  [sym__type_query_call_expression] = {
    .visible = true,
    .named = true,
  },
  [sym__type_query_instantiation_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_type_query] = {
    .visible = true,
    .named = true,
  },
  [sym_index_type_query] = {
    .visible = true,
    .named = true,
  },
  [sym_lookup_type] = {
    .visible = true,
    .named = true,
  },
  [sym_mapped_type_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_literal_type] = {
    .visible = true,
    .named = true,
  },
  [sym__number] = {
    .visible = true,
    .named = true,
  },
  [sym_existential_type] = {
    .visible = true,
    .named = true,
  },
  [sym_flow_maybe_type] = {
    .visible = true,
    .named = true,
  },
  [sym_parenthesized_type] = {
    .visible = true,
    .named = true,
  },
  [sym_predefined_type] = {
    .visible = true,
    .named = true,
  },
  [sym_type_arguments] = {
    .visible = true,
    .named = true,
  },
  [sym_object_type] = {
    .visible = true,
    .named = true,
  },
  [sym_call_signature] = {
    .visible = true,
    .named = true,
  },
  [sym_property_signature] = {
    .visible = true,
    .named = true,
  },
  [sym_type_parameters] = {
    .visible = true,
    .named = true,
  },
  [sym_type_parameter] = {
    .visible = true,
    .named = true,
  },
  [sym_default_type] = {
    .visible = true,
    .named = true,
  },
  [sym_constraint] = {
    .visible = true,
    .named = true,
  },
  [sym_construct_signature] = {
    .visible = true,
    .named = true,
  },
  [sym_index_signature] = {
    .visible = true,
    .named = true,
  },
  [sym_array_type] = {
    .visible = true,
    .named = true,
  },
  [sym_tuple_type] = {
    .visible = true,
    .named = true,
  },
  [sym_readonly_type] = {
    .visible = true,
    .named = true,
  },
  [sym_union_type] = {
    .visible = true,
    .named = true,
  },
  [sym_intersection_type] = {
    .visible = true,
    .named = true,
  },
  [sym_function_type] = {
    .visible = true,
    .named = true,
  },
  [aux_sym_program_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_export_statement_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_export_clause_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_named_imports_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_variable_declaration_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_switch_body_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_object_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_object_pattern_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_array_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_array_pattern_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_sequence_expression_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_string_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_string_repeat2] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_template_string_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_class_body_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_formal_parameters_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_extends_clause_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_implements_clause_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_extends_type_clause_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_enum_body_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_template_literal_type_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_object_type_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_type_parameters_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_tuple_type_repeat1] = {
    .visible = false,
    .named = false,
  },
  [alias_sym_interface_body] = {
    .visible = true,
    .named = true,
  },
  [alias_sym_property_identifier] = {
    .visible = true,
    .named = true,
  },
  [alias_sym_shorthand_property_identifier] = {
    .visible = true,
    .named = true,
  },
  [alias_sym_shorthand_property_identifier_pattern] = {
    .visible = true,
    .named = true,
  },
  [alias_sym_statement_identifier] = {
    .visible = true,
    .named = true,
  },
  [alias_sym_this_type] = {
    .visible = true,
    .named = true,
  },
  [alias_sym_type_identifier] = {
    .visible = true,
    .named = true,
  },
};

enum ts_field_identifiers {
  field_alias = 1,
  field_alternative = 2,
  field_argument = 3,
  field_arguments = 4,
  field_body = 5,
  field_condition = 6,
  field_consequence = 7,
  field_constraint = 8,
  field_constructor = 9,
  field_declaration = 10,
  field_decorator = 11,
  field_finalizer = 12,
  field_flags = 13,
  field_function = 14,
  field_handler = 15,
  field_increment = 16,
  field_index = 17,
  field_index_type = 18,
  field_initializer = 19,
  field_key = 20,
  field_kind = 21,
  field_label = 22,
  field_left = 23,
  field_module = 24,
  field_name = 25,
  field_object = 26,
  field_operator = 27,
  field_optional_chain = 28,
  field_parameter = 29,
  field_parameters = 30,
  field_pattern = 31,
  field_property = 32,
  field_return_type = 33,
  field_right = 34,
  field_sign = 35,
  field_source = 36,
  field_type = 37,
  field_type_arguments = 38,
  field_type_parameters = 39,
  field_value = 40,
};

static const char * const ts_field_names[] = {
  [0] = NULL,
  [field_alias] = "alias",
  [field_alternative] = "alternative",
  [field_argument] = "argument",
  [field_arguments] = "arguments",
  [field_body] = "body",
  [field_condition] = "condition",
  [field_consequence] = "consequence",
  [field_constraint] = "constraint",
  [field_constructor] = "constructor",
  [field_declaration] = "declaration",
  [field_decorator] = "decorator",
  [field_finalizer] = "finalizer",
  [field_flags] = "flags",
  [field_function] = "function",
  [field_handler] = "handler",
  [field_increment] = "increment",
  [field_index] = "index",
  [field_index_type] = "index_type",
  [field_initializer] = "initializer",
  [field_key] = "key",
  [field_kind] = "kind",
  [field_label] = "label",
  [field_left] = "left",
  [field_module] = "module",
  [field_name] = "name",
  [field_object] = "object",
  [field_operator] = "operator",
  [field_optional_chain] = "optional_chain",
  [field_parameter] = "parameter",
  [field_parameters] = "parameters",
  [field_pattern] = "pattern",
  [field_property] = "property",
  [field_return_type] = "return_type",
  [field_right] = "right",
  [field_sign] = "sign",
  [field_source] = "source",
  [field_type] = "type",
  [field_type_arguments] = "type_arguments",
  [field_type_parameters] = "type_parameters",
  [field_value] = "value",
};

static const TSFieldMapSlice ts_field_map_slices[PRODUCTION_ID_COUNT] = {
  [2] = {.index = 0, .length = 1},
  [3] = {.index = 1, .length = 1},
  [4] = {.index = 2, .length = 1},
  [5] = {.index = 3, .length = 1},
  [6] = {.index = 4, .length = 2},
  [8] = {.index = 6, .length = 2},
  [9] = {.index = 8, .length = 1},
  [10] = {.index = 9, .length = 2},
  [11] = {.index = 11, .length = 1},
  [12] = {.index = 12, .length = 1},
  [14] = {.index = 3, .length = 1},
  [16] = {.index = 13, .length = 2},
  [17] = {.index = 15, .length = 2},
  [18] = {.index = 17, .length = 2},
  [19] = {.index = 19, .length = 2},
  [20] = {.index = 21, .length = 2},
  [21] = {.index = 23, .length = 1},
  [22] = {.index = 24, .length = 2},
  [23] = {.index = 26, .length = 2},
  [24] = {.index = 28, .length = 2},
  [25] = {.index = 30, .length = 1},
  [26] = {.index = 31, .length = 2},
  [27] = {.index = 33, .length = 2},
  [28] = {.index = 35, .length = 2},
  [29] = {.index = 37, .length = 2},
  [33] = {.index = 39, .length = 1},
  [34] = {.index = 40, .length = 2},
  [35] = {.index = 42, .length = 2},
  [36] = {.index = 44, .length = 2},
  [37] = {.index = 46, .length = 1},
  [38] = {.index = 47, .length = 2},
  [39] = {.index = 49, .length = 2},
  [40] = {.index = 51, .length = 6},
  [41] = {.index = 57, .length = 1},
  [42] = {.index = 58, .length = 3},
  [43] = {.index = 61, .length = 3},
  [44] = {.index = 64, .length = 2},
  [45] = {.index = 66, .length = 2},
  [46] = {.index = 68, .length = 2},
  [47] = {.index = 70, .length = 2},
  [48] = {.index = 72, .length = 1},
  [49] = {.index = 73, .length = 2},
  [50] = {.index = 75, .length = 1},
  [51] = {.index = 76, .length = 2},
  [52] = {.index = 78, .length = 1},
  [53] = {.index = 79, .length = 2},
  [54] = {.index = 81, .length = 4},
  [55] = {.index = 85, .length = 2},
  [56] = {.index = 87, .length = 2},
  [57] = {.index = 89, .length = 3},
  [58] = {.index = 92, .length = 2},
  [59] = {.index = 94, .length = 2},
  [60] = {.index = 96, .length = 2},
  [61] = {.index = 98, .length = 2},
  [62] = {.index = 100, .length = 1},
  [63] = {.index = 101, .length = 2},
  [64] = {.index = 103, .length = 2},
  [65] = {.index = 105, .length = 2},
  [68] = {.index = 101, .length = 2},
  [69] = {.index = 107, .length = 4},
  [70] = {.index = 31, .length = 2},
  [71] = {.index = 35, .length = 2},
  [72] = {.index = 111, .length = 3},
  [73] = {.index = 73, .length = 2},
  [74] = {.index = 73, .length = 2},
  [75] = {.index = 114, .length = 2},
  [76] = {.index = 114, .length = 2},
  [77] = {.index = 116, .length = 3},
  [78] = {.index = 116, .length = 3},
  [79] = {.index = 119, .length = 3},
  [80] = {.index = 122, .length = 2},
  [81] = {.index = 124, .length = 4},
  [82] = {.index = 128, .length = 3},
  [83] = {.index = 131, .length = 2},
  [84] = {.index = 133, .length = 2},
  [85] = {.index = 135, .length = 1},
  [86] = {.index = 136, .length = 1},
  [87] = {.index = 100, .length = 1},
  [88] = {.index = 114, .length = 2},
  [89] = {.index = 31, .length = 2},
  [90] = {.index = 137, .length = 2},
  [91] = {.index = 139, .length = 5},
  [92] = {.index = 144, .length = 1},
  [93] = {.index = 145, .length = 1},
  [94] = {.index = 146, .length = 2},
  [95] = {.index = 148, .length = 3},
  [96] = {.index = 151, .length = 2},
  [97] = {.index = 153, .length = 3},
  [98] = {.index = 156, .length = 6},
  [99] = {.index = 162, .length = 1},
  [100] = {.index = 163, .length = 1},
  [101] = {.index = 164, .length = 3},
  [102] = {.index = 167, .length = 3},
  [103] = {.index = 170, .length = 4},
  [104] = {.index = 174, .length = 2},
  [105] = {.index = 176, .length = 2},
  [106] = {.index = 178, .length = 3},
  [107] = {.index = 181, .length = 4},
  [108] = {.index = 185, .length = 1},
  [109] = {.index = 186, .length = 2},
  [110] = {.index = 188, .length = 1},
  [111] = {.index = 189, .length = 2},
  [112] = {.index = 191, .length = 3},
  [113] = {.index = 194, .length = 2},
  [114] = {.index = 196, .length = 4},
  [115] = {.index = 200, .length = 2},
  [116] = {.index = 202, .length = 2},
  [117] = {.index = 204, .length = 4},
  [118] = {.index = 202, .length = 2},
  [119] = {.index = 208, .length = 4},
  [120] = {.index = 212, .length = 4},
  [121] = {.index = 216, .length = 5},
  [122] = {.index = 221, .length = 3},
  [123] = {.index = 224, .length = 2},
  [124] = {.index = 224, .length = 2},
  [125] = {.index = 226, .length = 2},
  [126] = {.index = 228, .length = 1},
  [127] = {.index = 229, .length = 2},
  [128] = {.index = 231, .length = 4},
  [129] = {.index = 235, .length = 4},
  [130] = {.index = 239, .length = 4},
  [131] = {.index = 243, .length = 2},
  [132] = {.index = 245, .length = 2},
  [133] = {.index = 247, .length = 2},
  [134] = {.index = 249, .length = 3},
  [135] = {.index = 252, .length = 2},
  [136] = {.index = 254, .length = 4},
  [137] = {.index = 254, .length = 4},
  [138] = {.index = 258, .length = 4},
  [139] = {.index = 258, .length = 4},
  [140] = {.index = 151, .length = 2},
  [141] = {.index = 262, .length = 1},
  [142] = {.index = 262, .length = 1},
  [143] = {.index = 189, .length = 2},
  [144] = {.index = 191, .length = 3},
  [145] = {.index = 263, .length = 2},
  [146] = {.index = 265, .length = 3},
  [147] = {.index = 268, .length = 2},
  [148] = {.index = 270, .length = 3},
  [149] = {.index = 273, .length = 2},
  [150] = {.index = 275, .length = 3},
  [151] = {.index = 278, .length = 1},
  [152] = {.index = 279, .length = 2},
  [153] = {.index = 281, .length = 2},
  [154] = {.index = 283, .length = 5},
  [155] = {.index = 279, .length = 2},
  [156] = {.index = 288, .length = 1},
  [157] = {.index = 289, .length = 4},
  [158] = {.index = 293, .length = 2},
  [159] = {.index = 295, .length = 1},
  [160] = {.index = 296, .length = 2},
  [161] = {.index = 298, .length = 2},
  [162] = {.index = 300, .length = 2},
  [163] = {.index = 302, .length = 4},
  [164] = {.index = 306, .length = 2},
  [165] = {.index = 308, .length = 3},
  [166] = {.index = 311, .length = 3},
  [167] = {.index = 314, .length = 3},
  [168] = {.index = 317, .length = 4},
  [169] = {.index = 321, .length = 4},
  [170] = {.index = 325, .length = 4},
  [171] = {.index = 329, .length = 5},
  [172] = {.index = 334, .length = 2},
  [173] = {.index = 336, .length = 2},
  [174] = {.index = 338, .length = 1},
  [175] = {.index = 339, .length = 4},
  [176] = {.index = 339, .length = 4},
  [177] = {.index = 343, .length = 3},
  [178] = {.index = 346, .length = 2},
  [179] = {.index = 348, .length = 3},
  [180] = {.index = 351, .length = 2},
  [181] = {.index = 353, .length = 3},
  [182] = {.index = 356, .length = 2},
  [183] = {.index = 356, .length = 2},
  [184] = {.index = 314, .length = 3},
  [185] = {.index = 358, .length = 3},
  [186] = {.index = 361, .length = 3},
  [187] = {.index = 146, .length = 2},
  [188] = {.index = 364, .length = 2},
  [189] = {.index = 366, .length = 3},
  [190] = {.index = 369, .length = 4},
  [191] = {.index = 373, .length = 3},
  [192] = {.index = 376, .length = 3},
  [193] = {.index = 379, .length = 2},
  [194] = {.index = 381, .length = 3},
  [195] = {.index = 384, .length = 5},
  [196] = {.index = 379, .length = 2},
  [197] = {.index = 389, .length = 3},
  [198] = {.index = 389, .length = 3},
  [199] = {.index = 392, .length = 3},
  [200] = {.index = 395, .length = 2},
  [201] = {.index = 397, .length = 4},
  [202] = {.index = 146, .length = 2},
  [203] = {.index = 401, .length = 1},
  [204] = {.index = 402, .length = 2},
  [205] = {.index = 404, .length = 2},
  [206] = {.index = 406, .length = 2},
  [207] = {.index = 408, .length = 2},
  [208] = {.index = 410, .length = 3},
  [209] = {.index = 413, .length = 1},
  [210] = {.index = 414, .length = 3},
  [211] = {.index = 417, .length = 2},
  [212] = {.index = 419, .length = 3},
  [213] = {.index = 422, .length = 3},
  [214] = {.index = 425, .length = 3},
  [215] = {.index = 428, .length = 3},
  [216] = {.index = 431, .length = 4},
  [217] = {.index = 435, .length = 5},
  [218] = {.index = 440, .length = 3},
  [219] = {.index = 443, .length = 2},
  [220] = {.index = 445, .length = 2},
  [221] = {.index = 447, .length = 4},
  [222] = {.index = 451, .length = 4},
  [223] = {.index = 455, .length = 4},
  [224] = {.index = 459, .length = 3},
  [225] = {.index = 462, .length = 2},
  [226] = {.index = 464, .length = 3},
  [227] = {.index = 467, .length = 2},
  [228] = {.index = 469, .length = 2},
  [229] = {.index = 471, .length = 2},
  [230] = {.index = 473, .length = 1},
  [231] = {.index = 474, .length = 4},
  [232] = {.index = 478, .length = 3},
  [233] = {.index = 481, .length = 4},
  [234] = {.index = 485, .length = 5},
  [235] = {.index = 490, .length = 1},
  [236] = {.index = 491, .length = 2},
  [237] = {.index = 493, .length = 4},
  [238] = {.index = 497, .length = 4},
  [239] = {.index = 501, .length = 4},
  [240] = {.index = 505, .length = 3},
  [241] = {.index = 508, .length = 2},
  [242] = {.index = 510, .length = 4},
  [243] = {.index = 514, .length = 4},
  [244] = {.index = 518, .length = 2},
  [245] = {.index = 520, .length = 2},
  [246] = {.index = 522, .length = 3},
  [247] = {.index = 525, .length = 3},
  [248] = {.index = 528, .length = 2},
  [249] = {.index = 530, .length = 2},
  [250] = {.index = 532, .length = 1},
  [251] = {.index = 533, .length = 1},
  [252] = {.index = 534, .length = 3},
  [253] = {.index = 537, .length = 3},
  [254] = {.index = 540, .length = 3},
  [255] = {.index = 543, .length = 3},
  [256] = {.index = 546, .length = 4},
  [257] = {.index = 550, .length = 2},
  [258] = {.index = 552, .length = 4},
  [259] = {.index = 556, .length = 3},
  [260] = {.index = 559, .length = 2},
  [261] = {.index = 561, .length = 4},
  [262] = {.index = 565, .length = 4},
  [263] = {.index = 569, .length = 4},
  [264] = {.index = 573, .length = 3},
  [266] = {.index = 576, .length = 4},
  [267] = {.index = 580, .length = 5},
  [268] = {.index = 585, .length = 5},
  [269] = {.index = 590, .length = 5},
  [270] = {.index = 595, .length = 4},
  [271] = {.index = 599, .length = 5},
  [272] = {.index = 604, .length = 4},
  [273] = {.index = 608, .length = 4},
  [274] = {.index = 612, .length = 3},
  [275] = {.index = 615, .length = 3},
  [276] = {.index = 618, .length = 3},
  [277] = {.index = 615, .length = 3},
  [278] = {.index = 621, .length = 2},
  [279] = {.index = 623, .length = 4},
  [280] = {.index = 627, .length = 4},
  [281] = {.index = 631, .length = 3},
  [282] = {.index = 634, .length = 2},
  [283] = {.index = 636, .length = 2},
  [284] = {.index = 638, .length = 3},
  [285] = {.index = 641, .length = 2},
  [286] = {.index = 643, .length = 2},
  [287] = {.index = 645, .length = 1},
  [288] = {.index = 646, .length = 3},
  [289] = {.index = 649, .length = 3},
  [290] = {.index = 652, .length = 4},
  [291] = {.index = 656, .length = 4},
  [292] = {.index = 660, .length = 3},
  [293] = {.index = 663, .length = 3},
  [294] = {.index = 666, .length = 2},
  [295] = {.index = 668, .length = 4},
  [296] = {.index = 672, .length = 5},
  [297] = {.index = 677, .length = 5},
  [298] = {.index = 682, .length = 5},
  [299] = {.index = 687, .length = 4},
  [300] = {.index = 691, .length = 4},
  [301] = {.index = 695, .length = 3},
  [302] = {.index = 698, .length = 3},
  [303] = {.index = 698, .length = 3},
  [304] = {.index = 701, .length = 2},
  [305] = {.index = 703, .length = 2},
  [306] = {.index = 705, .length = 3},
  [307] = {.index = 708, .length = 2},
  [308] = {.index = 710, .length = 2},
  [309] = {.index = 712, .length = 4},
  [310] = {.index = 716, .length = 3},
  [311] = {.index = 719, .length = 3},
  [312] = {.index = 722, .length = 4},
  [313] = {.index = 726, .length = 3},
  [314] = {.index = 729, .length = 3},
  [315] = {.index = 732, .length = 2},
  [316] = {.index = 734, .length = 5},
  [317] = {.index = 739, .length = 5},
  [318] = {.index = 744, .length = 4},
  [319] = {.index = 744, .length = 4},
  [320] = {.index = 748, .length = 4},
  [321] = {.index = 752, .length = 3},
  [322] = {.index = 755, .length = 2},
  [323] = {.index = 757, .length = 2},
  [324] = {.index = 759, .length = 3},
  [325] = {.index = 762, .length = 4},
  [326] = {.index = 766, .length = 4},
  [327] = {.index = 770, .length = 3},
  [328] = {.index = 773, .length = 3},
  [329] = {.index = 776, .length = 4},
  [330] = {.index = 780, .length = 3},
  [331] = {.index = 783, .length = 3},
  [332] = {.index = 786, .length = 5},
  [333] = {.index = 791, .length = 3},
  [334] = {.index = 794, .length = 4},
  [335] = {.index = 798, .length = 4},
  [336] = {.index = 802, .length = 3},
  [337] = {.index = 805, .length = 3},
  [338] = {.index = 808, .length = 4},
  [339] = {.index = 812, .length = 4},
};

static const TSFieldMapEntry ts_field_map_entries[] = {
  [0] =
    {field_decorator, 0},
  [1] =
    {field_parameters, 0},
  [2] =
    {field_declaration, 1},
  [3] =
    {field_name, 0},
  [4] =
    {field_body, 1, .inherited = true},
    {field_name, 1, .inherited = true},
  [6] =
    {field_argument, 1},
    {field_operator, 0},
  [8] =
    {field_pattern, 0},
  [9] =
    {field_decorator, 0, .inherited = true},
    {field_pattern, 0, .inherited = true},
  [11] =
    {field_body, 1},
  [12] =
    {field_constructor, 1},
  [13] =
    {field_object, 0, .inherited = true},
    {field_property, 0, .inherited = true},
  [15] =
    {field_arguments, 0, .inherited = true},
    {field_function, 0, .inherited = true},
  [17] =
    {field_argument, 0, .inherited = true},
    {field_operator, 0, .inherited = true},
  [19] =
    {field_arguments, 1},
    {field_function, 0},
  [21] =
    {field_argument, 0},
    {field_operator, 1},
  [23] =
    {field_type_arguments, 1},
  [24] =
    {field_parameters, 0},
    {field_return_type, 1},
  [26] =
    {field_parameters, 1},
    {field_type_parameters, 0},
  [28] =
    {field_decorator, 0, .inherited = true},
    {field_decorator, 1, .inherited = true},
  [30] =
    {field_declaration, 2},
  [31] =
    {field_left, 0},
    {field_right, 2},
  [33] =
    {field_body, 2},
    {field_label, 0},
  [35] =
    {field_body, 2},
    {field_parameter, 0},
  [37] =
    {field_body, 1},
    {field_name, 0},
  [39] =
    {field_source, 1},
  [40] =
    {field_body, 2},
    {field_object, 1},
  [42] =
    {field_name, 0},
    {field_value, 1, .inherited = true},
  [44] =
    {field_name, 0},
    {field_type, 1},
  [46] =
    {field_kind, 0},
  [47] =
    {field_condition, 1},
    {field_consequence, 2},
  [49] =
    {field_body, 2},
    {field_value, 1},
  [51] =
    {field_body, 2},
    {field_kind, 1, .inherited = true},
    {field_left, 1, .inherited = true},
    {field_operator, 1, .inherited = true},
    {field_right, 1, .inherited = true},
    {field_value, 1, .inherited = true},
  [57] =
    {field_pattern, 1},
  [58] =
    {field_decorator, 0, .inherited = true},
    {field_pattern, 0, .inherited = true},
    {field_value, 1, .inherited = true},
  [61] =
    {field_decorator, 0, .inherited = true},
    {field_pattern, 0, .inherited = true},
    {field_type, 1},
  [64] =
    {field_decorator, 0, .inherited = true},
    {field_pattern, 1},
  [66] =
    {field_body, 2},
    {field_condition, 1},
  [68] =
    {field_body, 1},
    {field_handler, 2},
  [70] =
    {field_body, 1},
    {field_finalizer, 2},
  [72] =
    {field_label, 1},
  [73] =
    {field_body, 2},
    {field_name, 1},
  [75] =
    {field_value, 0},
  [76] =
    {field_type_arguments, 1, .inherited = true},
    {field_value, 1, .inherited = true},
  [78] =
    {field_body, 2},
  [79] =
    {field_body, 2},
    {field_type_parameters, 1},
  [81] =
    {field_body, 2},
    {field_parameters, 1, .inherited = true},
    {field_return_type, 1, .inherited = true},
    {field_type_parameters, 1, .inherited = true},
  [85] =
    {field_arguments, 2},
    {field_constructor, 1},
  [87] =
    {field_constructor, 1},
    {field_type_arguments, 2},
  [89] =
    {field_parameters, 0, .inherited = true},
    {field_return_type, 0, .inherited = true},
    {field_type_parameters, 0, .inherited = true},
  [92] =
    {field_object, 1, .inherited = true},
    {field_property, 1, .inherited = true},
  [94] =
    {field_index, 1, .inherited = true},
    {field_object, 1, .inherited = true},
  [96] =
    {field_arguments, 1, .inherited = true},
    {field_function, 1, .inherited = true},
  [98] =
    {field_function, 1, .inherited = true},
    {field_type_arguments, 1, .inherited = true},
  [100] =
    {field_name, 1},
  [101] =
    {field_name, 0},
    {field_type_arguments, 1},
  [103] =
    {field_name, 0},
    {field_value, 1},
  [105] =
    {field_constraint, 1},
    {field_name, 0},
  [107] =
    {field_arguments, 1},
    {field_function, 0},
    {field_object, 0, .inherited = true},
    {field_property, 0, .inherited = true},
  [111] =
    {field_left, 0},
    {field_operator, 1},
    {field_right, 2},
  [114] =
    {field_object, 0},
    {field_property, 2},
  [116] =
    {field_object, 0},
    {field_optional_chain, 1},
    {field_property, 2},
  [119] =
    {field_arguments, 2},
    {field_function, 0},
    {field_type_arguments, 1},
  [122] =
    {field_arguments, 2},
    {field_function, 0},
  [124] =
    {field_body, 2},
    {field_parameters, 0, .inherited = true},
    {field_return_type, 0, .inherited = true},
    {field_type_parameters, 0, .inherited = true},
  [128] =
    {field_parameters, 1},
    {field_return_type, 2},
    {field_type_parameters, 0},
  [131] =
    {field_declaration, 2},
    {field_decorator, 0, .inherited = true},
  [133] =
    {field_body, 2},
    {field_decorator, 0, .inherited = true},
  [135] =
    {field_source, 2, .inherited = true},
  [136] =
    {field_value, 2},
  [137] =
    {field_key, 0},
    {field_value, 2},
  [139] =
    {field_body, 2},
    {field_name, 0},
    {field_parameters, 1, .inherited = true},
    {field_return_type, 1, .inherited = true},
    {field_type_parameters, 1, .inherited = true},
  [144] =
    {field_source, 2},
  [145] =
    {field_value, 1},
  [146] =
    {field_name, 0},
    {field_type, 2},
  [148] =
    {field_name, 0},
    {field_type, 1},
    {field_value, 2, .inherited = true},
  [151] =
    {field_body, 3},
    {field_name, 2},
  [153] =
    {field_alternative, 3},
    {field_condition, 1},
    {field_consequence, 2},
  [156] =
    {field_body, 3},
    {field_kind, 2, .inherited = true},
    {field_left, 2, .inherited = true},
    {field_operator, 2, .inherited = true},
    {field_right, 2, .inherited = true},
    {field_value, 2, .inherited = true},
  [162] =
    {field_type, 2},
  [163] =
    {field_pattern, 2},
  [164] =
    {field_decorator, 0, .inherited = true},
    {field_pattern, 0, .inherited = true},
    {field_value, 2, .inherited = true},
  [167] =
    {field_decorator, 0, .inherited = true},
    {field_pattern, 0, .inherited = true},
    {field_type, 2},
  [170] =
    {field_decorator, 0, .inherited = true},
    {field_pattern, 0, .inherited = true},
    {field_type, 1},
    {field_value, 2, .inherited = true},
  [174] =
    {field_decorator, 0, .inherited = true},
    {field_pattern, 2},
  [176] =
    {field_body, 1},
    {field_condition, 3},
  [178] =
    {field_body, 1},
    {field_finalizer, 3},
    {field_handler, 2},
  [181] =
    {field_name, 0},
    {field_parameters, 1, .inherited = true},
    {field_return_type, 1, .inherited = true},
    {field_type_parameters, 1, .inherited = true},
  [185] =
    {field_decorator, 0, .inherited = true},
  [186] =
    {field_decorator, 0, .inherited = true},
    {field_name, 1},
  [188] =
    {field_decorator, 1, .inherited = true},
  [189] =
    {field_body, 3},
    {field_name, 1},
  [191] =
    {field_body, 3},
    {field_name, 1},
    {field_type_parameters, 2},
  [194] =
    {field_type_arguments, 1},
    {field_value, 0},
  [196] =
    {field_type_arguments, 1, .inherited = true},
    {field_type_arguments, 2, .inherited = true},
    {field_value, 1, .inherited = true},
    {field_value, 2, .inherited = true},
  [200] =
    {field_body, 3},
    {field_type_parameters, 1},
  [202] =
    {field_body, 3},
    {field_parameter, 1},
  [204] =
    {field_body, 3},
    {field_parameters, 2, .inherited = true},
    {field_return_type, 2, .inherited = true},
    {field_type_parameters, 2, .inherited = true},
  [208] =
    {field_body, 3},
    {field_parameters, 1, .inherited = true},
    {field_return_type, 1, .inherited = true},
    {field_type_parameters, 1, .inherited = true},
  [212] =
    {field_name, 1},
    {field_parameters, 2, .inherited = true},
    {field_return_type, 2, .inherited = true},
    {field_type_parameters, 2, .inherited = true},
  [216] =
    {field_body, 3},
    {field_name, 1},
    {field_parameters, 2, .inherited = true},
    {field_return_type, 2, .inherited = true},
    {field_type_parameters, 2, .inherited = true},
  [221] =
    {field_arguments, 3},
    {field_constructor, 1},
    {field_type_arguments, 2},
  [224] =
    {field_left, 1},
    {field_right, 3},
  [226] =
    {field_flags, 3},
    {field_pattern, 1},
  [228] =
    {field_parameters, 1},
  [229] =
    {field_function, 0},
    {field_type_arguments, 1},
  [231] =
    {field_function, 0},
    {field_object, 0, .inherited = true},
    {field_property, 0, .inherited = true},
    {field_type_arguments, 1},
  [235] =
    {field_arguments, 1},
    {field_function, 0},
    {field_index, 0, .inherited = true},
    {field_object, 0, .inherited = true},
  [239] =
    {field_function, 0},
    {field_index, 0, .inherited = true},
    {field_object, 0, .inherited = true},
    {field_type_arguments, 1},
  [243] =
    {field_name, 1},
    {field_value, 2},
  [245] =
    {field_constraint, 2},
    {field_name, 1},
  [247] =
    {field_module, 0},
    {field_name, 2},
  [249] =
    {field_constraint, 1},
    {field_name, 0},
    {field_value, 2},
  [252] =
    {field_parameters, 0},
    {field_return_type, 2},
  [254] =
    {field_object, 0},
    {field_object, 0, .inherited = true},
    {field_property, 0, .inherited = true},
    {field_property, 2},
  [258] =
    {field_arguments, 0, .inherited = true},
    {field_function, 0, .inherited = true},
    {field_object, 0},
    {field_property, 2},
  [262] =
    {field_type, 1},
  [263] =
    {field_index, 2},
    {field_object, 0},
  [265] =
    {field_arguments, 3},
    {field_function, 0},
    {field_type_arguments, 2},
  [268] =
    {field_declaration, 3},
    {field_decorator, 0, .inherited = true},
  [270] =
    {field_body, 3},
    {field_decorator, 0, .inherited = true},
    {field_name, 2},
  [273] =
    {field_body, 3},
    {field_decorator, 0, .inherited = true},
  [275] =
    {field_body, 3},
    {field_decorator, 0, .inherited = true},
    {field_type_parameters, 2},
  [278] =
    {field_source, 3, .inherited = true},
  [279] =
    {field_alias, 2},
    {field_name, 0},
  [281] =
    {field_name, 1},
    {field_value, 3},
  [283] =
    {field_body, 3},
    {field_name, 0},
    {field_parameters, 2, .inherited = true},
    {field_return_type, 2, .inherited = true},
    {field_type_parameters, 2, .inherited = true},
  [288] =
    {field_pattern, 3},
  [289] =
    {field_decorator, 0, .inherited = true},
    {field_pattern, 0, .inherited = true},
    {field_type, 2},
    {field_value, 3, .inherited = true},
  [293] =
    {field_decorator, 0, .inherited = true},
    {field_pattern, 3},
  [295] =
    {field_name, 2},
  [296] =
    {field_name, 1},
    {field_value, 2, .inherited = true},
  [298] =
    {field_name, 1},
    {field_type, 2},
  [300] =
    {field_name, 0},
    {field_value, 2, .inherited = true},
  [302] =
    {field_name, 0},
    {field_parameters, 2, .inherited = true},
    {field_return_type, 2, .inherited = true},
    {field_type_parameters, 2, .inherited = true},
  [306] =
    {field_decorator, 0, .inherited = true},
    {field_name, 2},
  [308] =
    {field_decorator, 0, .inherited = true},
    {field_name, 1},
    {field_value, 2, .inherited = true},
  [311] =
    {field_decorator, 0, .inherited = true},
    {field_name, 1},
    {field_type, 2},
  [314] =
    {field_body, 4},
    {field_name, 1},
    {field_type_parameters, 2},
  [317] =
    {field_type_arguments, 0, .inherited = true},
    {field_type_arguments, 1, .inherited = true},
    {field_value, 0, .inherited = true},
    {field_value, 1, .inherited = true},
  [321] =
    {field_body, 4},
    {field_parameters, 3, .inherited = true},
    {field_return_type, 3, .inherited = true},
    {field_type_parameters, 3, .inherited = true},
  [325] =
    {field_name, 2},
    {field_parameters, 3, .inherited = true},
    {field_return_type, 3, .inherited = true},
    {field_type_parameters, 3, .inherited = true},
  [329] =
    {field_body, 4},
    {field_name, 2},
    {field_parameters, 3, .inherited = true},
    {field_return_type, 3, .inherited = true},
    {field_type_parameters, 3, .inherited = true},
  [334] =
    {field_parameters, 1},
    {field_type, 2},
  [336] =
    {field_parameters, 2},
    {field_type_parameters, 1},
  [338] =
    {field_parameters, 2},
  [339] =
    {field_index, 0, .inherited = true},
    {field_object, 0},
    {field_object, 0, .inherited = true},
    {field_property, 2},
  [343] =
    {field_constraint, 2},
    {field_name, 1},
    {field_value, 3},
  [346] =
    {field_parameters, 1},
    {field_type, 3},
  [348] =
    {field_parameters, 1},
    {field_return_type, 3},
    {field_type_parameters, 0},
  [351] =
    {field_body, 4},
    {field_name, 2},
  [353] =
    {field_body, 4},
    {field_name, 2},
    {field_type_parameters, 3},
  [356] =
    {field_type, 1},
    {field_type, 2, .inherited = true},
  [358] =
    {field_alternative, 4},
    {field_condition, 0},
    {field_consequence, 2},
  [361] =
    {field_index, 3},
    {field_object, 0},
    {field_optional_chain, 1},
  [364] =
    {field_decorator, 0, .inherited = true},
    {field_value, 3},
  [366] =
    {field_body, 4},
    {field_decorator, 0, .inherited = true},
    {field_name, 2},
  [369] =
    {field_body, 4},
    {field_decorator, 0, .inherited = true},
    {field_name, 2},
    {field_type_parameters, 3},
  [373] =
    {field_body, 4},
    {field_decorator, 0, .inherited = true},
    {field_type_parameters, 2},
  [376] =
    {field_body, 4},
    {field_decorator, 0, .inherited = true},
    {field_name, 3},
  [379] =
    {field_alias, 3},
    {field_name, 1},
  [381] =
    {field_name, 1},
    {field_type_parameters, 2},
    {field_value, 4},
  [384] =
    {field_body, 4},
    {field_name, 1},
    {field_parameters, 3, .inherited = true},
    {field_return_type, 3, .inherited = true},
    {field_type_parameters, 3, .inherited = true},
  [389] =
    {field_left, 1},
    {field_operator, 2},
    {field_right, 3},
  [392] =
    {field_body, 5},
    {field_condition, 3},
    {field_initializer, 2},
  [395] =
    {field_decorator, 0, .inherited = true},
    {field_pattern, 4},
  [397] =
    {field_name, 1},
    {field_parameters, 3, .inherited = true},
    {field_return_type, 3, .inherited = true},
    {field_type_parameters, 3, .inherited = true},
  [401] =
    {field_type, 3},
  [402] =
    {field_name, 2},
    {field_value, 3, .inherited = true},
  [404] =
    {field_name, 2},
    {field_type, 3},
  [406] =
    {field_name, 1},
    {field_value, 3, .inherited = true},
  [408] =
    {field_name, 1},
    {field_type, 3},
  [410] =
    {field_name, 1},
    {field_type, 2},
    {field_value, 3, .inherited = true},
  [413] =
    {field_name, 3},
  [414] =
    {field_name, 0},
    {field_type, 2},
    {field_value, 3, .inherited = true},
  [417] =
    {field_decorator, 0, .inherited = true},
    {field_name, 3},
  [419] =
    {field_decorator, 0, .inherited = true},
    {field_name, 2},
    {field_value, 3, .inherited = true},
  [422] =
    {field_decorator, 0, .inherited = true},
    {field_name, 2},
    {field_type, 3},
  [425] =
    {field_decorator, 0, .inherited = true},
    {field_name, 1},
    {field_value, 3, .inherited = true},
  [428] =
    {field_decorator, 0, .inherited = true},
    {field_name, 1},
    {field_type, 3},
  [431] =
    {field_decorator, 0, .inherited = true},
    {field_name, 1},
    {field_type, 2},
    {field_value, 3, .inherited = true},
  [435] =
    {field_body, 5},
    {field_name, 3},
    {field_parameters, 4, .inherited = true},
    {field_return_type, 4, .inherited = true},
    {field_type_parameters, 4, .inherited = true},
  [440] =
    {field_parameters, 2},
    {field_type, 3},
    {field_type_parameters, 1},
  [443] =
    {field_parameters, 2},
    {field_type, 3},
  [445] =
    {field_parameters, 3},
    {field_type_parameters, 2},
  [447] =
    {field_index, 2},
    {field_object, 0},
    {field_object, 0, .inherited = true},
    {field_property, 0, .inherited = true},
  [451] =
    {field_index, 0, .inherited = true},
    {field_index, 2},
    {field_object, 0},
    {field_object, 0, .inherited = true},
  [455] =
    {field_arguments, 0, .inherited = true},
    {field_function, 0, .inherited = true},
    {field_index, 2},
    {field_object, 0},
  [459] =
    {field_parameters, 2},
    {field_type, 4},
    {field_type_parameters, 1},
  [462] =
    {field_parameters, 2},
    {field_type, 4},
  [464] =
    {field_body, 5},
    {field_name, 2},
    {field_type_parameters, 3},
  [467] =
    {field_type, 0, .inherited = true},
    {field_type, 1, .inherited = true},
  [469] =
    {field_name, 1},
    {field_name, 2, .inherited = true},
  [471] =
    {field_name, 0, .inherited = true},
    {field_name, 1, .inherited = true},
  [473] =
    {field_name, 2, .inherited = true},
  [474] =
    {field_body, 5},
    {field_decorator, 0, .inherited = true},
    {field_name, 2},
    {field_type_parameters, 3},
  [478] =
    {field_body, 5},
    {field_decorator, 0, .inherited = true},
    {field_name, 3},
  [481] =
    {field_body, 5},
    {field_decorator, 0, .inherited = true},
    {field_name, 3},
    {field_type_parameters, 4},
  [485] =
    {field_body, 5},
    {field_name, 2},
    {field_parameters, 4, .inherited = true},
    {field_return_type, 4, .inherited = true},
    {field_type_parameters, 4, .inherited = true},
  [490] =
    {field_source, 4},
  [491] =
    {field_body, 3},
    {field_value, 1},
  [493] =
    {field_kind, 1},
    {field_left, 2},
    {field_operator, 3},
    {field_right, 4},
  [497] =
    {field_body, 6},
    {field_condition, 3},
    {field_increment, 4},
    {field_initializer, 2},
  [501] =
    {field_body, 6},
    {field_condition, 3},
    {field_condition, 4},
    {field_initializer, 2},
  [505] =
    {field_body, 6},
    {field_condition, 4},
    {field_initializer, 2},
  [508] =
    {field_body, 4},
    {field_parameter, 2},
  [510] =
    {field_name, 2},
    {field_parameters, 4, .inherited = true},
    {field_return_type, 4, .inherited = true},
    {field_type_parameters, 4, .inherited = true},
  [514] =
    {field_name, 3},
    {field_parameters, 4, .inherited = true},
    {field_return_type, 4, .inherited = true},
    {field_type_parameters, 4, .inherited = true},
  [518] =
    {field_name, 2},
    {field_value, 4, .inherited = true},
  [520] =
    {field_name, 2},
    {field_type, 4},
  [522] =
    {field_name, 2},
    {field_type, 3},
    {field_value, 4, .inherited = true},
  [525] =
    {field_name, 1},
    {field_type, 3},
    {field_value, 4, .inherited = true},
  [528] =
    {field_name, 3},
    {field_value, 4, .inherited = true},
  [530] =
    {field_name, 3},
    {field_type, 4},
  [532] =
    {field_type, 4},
  [533] =
    {field_name, 4},
  [534] =
    {field_decorator, 0, .inherited = true},
    {field_name, 3},
    {field_value, 4, .inherited = true},
  [537] =
    {field_decorator, 0, .inherited = true},
    {field_name, 3},
    {field_type, 4},
  [540] =
    {field_decorator, 0, .inherited = true},
    {field_name, 2},
    {field_value, 4, .inherited = true},
  [543] =
    {field_decorator, 0, .inherited = true},
    {field_name, 2},
    {field_type, 4},
  [546] =
    {field_decorator, 0, .inherited = true},
    {field_name, 2},
    {field_type, 3},
    {field_value, 4, .inherited = true},
  [550] =
    {field_decorator, 0, .inherited = true},
    {field_name, 4},
  [552] =
    {field_decorator, 0, .inherited = true},
    {field_name, 1},
    {field_type, 3},
    {field_value, 4, .inherited = true},
  [556] =
    {field_parameters, 3},
    {field_type, 4},
    {field_type_parameters, 2},
  [559] =
    {field_index, 3},
    {field_object, 0},
  [561] =
    {field_index, 3},
    {field_object, 0},
    {field_object, 0, .inherited = true},
    {field_property, 0, .inherited = true},
  [565] =
    {field_index, 0, .inherited = true},
    {field_index, 3},
    {field_object, 0},
    {field_object, 0, .inherited = true},
  [569] =
    {field_arguments, 0, .inherited = true},
    {field_function, 0, .inherited = true},
    {field_index, 3},
    {field_object, 0},
  [573] =
    {field_parameters, 3},
    {field_type, 5},
    {field_type_parameters, 2},
  [576] =
    {field_body, 6},
    {field_decorator, 0, .inherited = true},
    {field_name, 3},
    {field_type_parameters, 4},
  [580] =
    {field_body, 6},
    {field_name, 3},
    {field_parameters, 5, .inherited = true},
    {field_return_type, 5, .inherited = true},
    {field_type_parameters, 5, .inherited = true},
  [585] =
    {field_body, 6},
    {field_name, 4},
    {field_parameters, 5, .inherited = true},
    {field_return_type, 5, .inherited = true},
    {field_type_parameters, 5, .inherited = true},
  [590] =
    {field_kind, 1},
    {field_left, 2},
    {field_operator, 4},
    {field_right, 5},
    {field_value, 3, .inherited = true},
  [595] =
    {field_kind, 1},
    {field_left, 2},
    {field_operator, 4},
    {field_right, 5},
  [599] =
    {field_body, 7},
    {field_condition, 3},
    {field_condition, 4},
    {field_increment, 5},
    {field_initializer, 2},
  [604] =
    {field_body, 7},
    {field_condition, 4},
    {field_increment, 5},
    {field_initializer, 2},
  [608] =
    {field_body, 7},
    {field_condition, 4},
    {field_condition, 5},
    {field_initializer, 2},
  [612] =
    {field_body, 5},
    {field_parameter, 2},
    {field_type, 3},
  [615] =
    {field_index_type, 3},
    {field_name, 1},
    {field_type, 5},
  [618] =
    {field_alias, 4},
    {field_name, 0},
    {field_type, 2},
  [621] =
    {field_sign, 0},
    {field_type, 5},
  [623] =
    {field_name, 3},
    {field_parameters, 5, .inherited = true},
    {field_return_type, 5, .inherited = true},
    {field_type_parameters, 5, .inherited = true},
  [627] =
    {field_name, 4},
    {field_parameters, 5, .inherited = true},
    {field_return_type, 5, .inherited = true},
    {field_type_parameters, 5, .inherited = true},
  [631] =
    {field_name, 2},
    {field_type, 4},
    {field_value, 5, .inherited = true},
  [634] =
    {field_name, 3},
    {field_value, 5, .inherited = true},
  [636] =
    {field_name, 3},
    {field_type, 5},
  [638] =
    {field_name, 3},
    {field_type, 4},
    {field_value, 5, .inherited = true},
  [641] =
    {field_name, 4},
    {field_value, 5, .inherited = true},
  [643] =
    {field_name, 4},
    {field_type, 5},
  [645] =
    {field_name, 5},
  [646] =
    {field_decorator, 0, .inherited = true},
    {field_name, 3},
    {field_value, 5, .inherited = true},
  [649] =
    {field_decorator, 0, .inherited = true},
    {field_name, 3},
    {field_type, 5},
  [652] =
    {field_decorator, 0, .inherited = true},
    {field_name, 3},
    {field_type, 4},
    {field_value, 5, .inherited = true},
  [656] =
    {field_decorator, 0, .inherited = true},
    {field_name, 2},
    {field_type, 4},
    {field_value, 5, .inherited = true},
  [660] =
    {field_decorator, 0, .inherited = true},
    {field_name, 4},
    {field_value, 5, .inherited = true},
  [663] =
    {field_decorator, 0, .inherited = true},
    {field_name, 4},
    {field_type, 5},
  [666] =
    {field_decorator, 0, .inherited = true},
    {field_name, 5},
  [668] =
    {field_alternative, 6},
    {field_consequence, 4},
    {field_left, 0},
    {field_right, 2},
  [672] =
    {field_body, 7},
    {field_name, 4},
    {field_parameters, 6, .inherited = true},
    {field_return_type, 6, .inherited = true},
    {field_type_parameters, 6, .inherited = true},
  [677] =
    {field_body, 7},
    {field_name, 5},
    {field_parameters, 6, .inherited = true},
    {field_return_type, 6, .inherited = true},
    {field_type_parameters, 6, .inherited = true},
  [682] =
    {field_body, 8},
    {field_condition, 4},
    {field_condition, 5},
    {field_increment, 6},
    {field_initializer, 2},
  [687] =
    {field_name, 4},
    {field_parameters, 6, .inherited = true},
    {field_return_type, 6, .inherited = true},
    {field_type_parameters, 6, .inherited = true},
  [691] =
    {field_name, 5},
    {field_parameters, 6, .inherited = true},
    {field_return_type, 6, .inherited = true},
    {field_type_parameters, 6, .inherited = true},
  [695] =
    {field_name, 3},
    {field_type, 5},
    {field_value, 6, .inherited = true},
  [698] =
    {field_index_type, 4},
    {field_name, 2},
    {field_type, 6},
  [701] =
    {field_name, 4},
    {field_value, 6, .inherited = true},
  [703] =
    {field_name, 4},
    {field_type, 6},
  [705] =
    {field_name, 4},
    {field_type, 5},
    {field_value, 6, .inherited = true},
  [708] =
    {field_name, 5},
    {field_value, 6, .inherited = true},
  [710] =
    {field_name, 5},
    {field_type, 6},
  [712] =
    {field_decorator, 0, .inherited = true},
    {field_name, 3},
    {field_type, 5},
    {field_value, 6, .inherited = true},
  [716] =
    {field_decorator, 0, .inherited = true},
    {field_name, 4},
    {field_value, 6, .inherited = true},
  [719] =
    {field_decorator, 0, .inherited = true},
    {field_name, 4},
    {field_type, 6},
  [722] =
    {field_decorator, 0, .inherited = true},
    {field_name, 4},
    {field_type, 5},
    {field_value, 6, .inherited = true},
  [726] =
    {field_decorator, 0, .inherited = true},
    {field_name, 5},
    {field_value, 6, .inherited = true},
  [729] =
    {field_decorator, 0, .inherited = true},
    {field_name, 5},
    {field_type, 6},
  [732] =
    {field_decorator, 0, .inherited = true},
    {field_name, 6},
  [734] =
    {field_body, 8},
    {field_name, 5},
    {field_parameters, 7, .inherited = true},
    {field_return_type, 7, .inherited = true},
    {field_type_parameters, 7, .inherited = true},
  [739] =
    {field_body, 8},
    {field_name, 6},
    {field_parameters, 7, .inherited = true},
    {field_return_type, 7, .inherited = true},
    {field_type_parameters, 7, .inherited = true},
  [744] =
    {field_index_type, 5},
    {field_name, 3},
    {field_sign, 0},
    {field_type, 7},
  [748] =
    {field_name, 5},
    {field_parameters, 7, .inherited = true},
    {field_return_type, 7, .inherited = true},
    {field_type_parameters, 7, .inherited = true},
  [752] =
    {field_name, 4},
    {field_type, 6},
    {field_value, 7, .inherited = true},
  [755] =
    {field_name, 5},
    {field_value, 7, .inherited = true},
  [757] =
    {field_name, 5},
    {field_type, 7},
  [759] =
    {field_name, 5},
    {field_type, 6},
    {field_value, 7, .inherited = true},
  [762] =
    {field_name, 6},
    {field_parameters, 7, .inherited = true},
    {field_return_type, 7, .inherited = true},
    {field_type_parameters, 7, .inherited = true},
  [766] =
    {field_decorator, 0, .inherited = true},
    {field_name, 4},
    {field_type, 6},
    {field_value, 7, .inherited = true},
  [770] =
    {field_decorator, 0, .inherited = true},
    {field_name, 5},
    {field_value, 7, .inherited = true},
  [773] =
    {field_decorator, 0, .inherited = true},
    {field_name, 5},
    {field_type, 7},
  [776] =
    {field_decorator, 0, .inherited = true},
    {field_name, 5},
    {field_type, 6},
    {field_value, 7, .inherited = true},
  [780] =
    {field_decorator, 0, .inherited = true},
    {field_name, 6},
    {field_value, 7, .inherited = true},
  [783] =
    {field_decorator, 0, .inherited = true},
    {field_name, 6},
    {field_type, 7},
  [786] =
    {field_body, 9},
    {field_name, 6},
    {field_parameters, 8, .inherited = true},
    {field_return_type, 8, .inherited = true},
    {field_type_parameters, 8, .inherited = true},
  [791] =
    {field_name, 5},
    {field_type, 7},
    {field_value, 8, .inherited = true},
  [794] =
    {field_name, 6},
    {field_parameters, 8, .inherited = true},
    {field_return_type, 8, .inherited = true},
    {field_type_parameters, 8, .inherited = true},
  [798] =
    {field_decorator, 0, .inherited = true},
    {field_name, 5},
    {field_type, 7},
    {field_value, 8, .inherited = true},
  [802] =
    {field_decorator, 0, .inherited = true},
    {field_name, 6},
    {field_value, 8, .inherited = true},
  [805] =
    {field_decorator, 0, .inherited = true},
    {field_name, 6},
    {field_type, 8},
  [808] =
    {field_decorator, 0, .inherited = true},
    {field_name, 6},
    {field_type, 7},
    {field_value, 8, .inherited = true},
  [812] =
    {field_decorator, 0, .inherited = true},
    {field_name, 6},
    {field_type, 8},
    {field_value, 9, .inherited = true},
};

static const TSSymbol ts_alias_sequences[PRODUCTION_ID_COUNT][MAX_ALIAS_SEQUENCE_LENGTH] = {
  [0] = {0},
  [1] = {
    [0] = sym_identifier,
  },
  [7] = {
    [0] = alias_sym_property_identifier,
  },
  [13] = {
    [0] = alias_sym_type_identifier,
  },
  [14] = {
    [0] = alias_sym_type_identifier,
  },
  [15] = {
    [0] = alias_sym_this_type,
  },
  [26] = {
    [0] = sym_identifier,
  },
  [27] = {
    [0] = alias_sym_statement_identifier,
  },
  [28] = {
    [0] = sym_identifier,
  },
  [30] = {
    [1] = alias_sym_shorthand_property_identifier,
  },
  [31] = {
    [1] = alias_sym_shorthand_property_identifier_pattern,
  },
  [32] = {
    [1] = sym_identifier,
  },
  [48] = {
    [1] = alias_sym_statement_identifier,
  },
  [49] = {
    [1] = alias_sym_type_identifier,
  },
  [62] = {
    [1] = alias_sym_type_identifier,
  },
  [63] = {
    [0] = alias_sym_type_identifier,
  },
  [64] = {
    [0] = alias_sym_type_identifier,
  },
  [65] = {
    [0] = alias_sym_type_identifier,
  },
  [66] = {
    [1] = alias_sym_type_identifier,
  },
  [67] = {
    [1] = anon_sym_unique,
  },
  [73] = {
    [1] = alias_sym_type_identifier,
    [2] = alias_sym_interface_body,
  },
  [75] = {
    [2] = alias_sym_property_identifier,
  },
  [77] = {
    [2] = alias_sym_property_identifier,
  },
  [88] = {
    [0] = sym_member_expression,
    [2] = alias_sym_property_identifier,
  },
  [89] = {
    [0] = alias_sym_shorthand_property_identifier_pattern,
  },
  [111] = {
    [1] = alias_sym_type_identifier,
  },
  [112] = {
    [1] = alias_sym_type_identifier,
  },
  [116] = {
    [1] = sym_identifier,
  },
  [123] = {
    [1] = sym_identifier,
  },
  [131] = {
    [1] = alias_sym_type_identifier,
  },
  [132] = {
    [1] = alias_sym_type_identifier,
  },
  [133] = {
    [2] = alias_sym_type_identifier,
  },
  [134] = {
    [0] = alias_sym_type_identifier,
  },
  [136] = {
    [2] = alias_sym_property_identifier,
  },
  [138] = {
    [2] = alias_sym_property_identifier,
  },
  [140] = {
    [2] = alias_sym_type_identifier,
  },
  [141] = {
    [1] = alias_sym_type_identifier,
  },
  [143] = {
    [1] = alias_sym_type_identifier,
    [3] = alias_sym_interface_body,
  },
  [144] = {
    [1] = alias_sym_type_identifier,
    [3] = alias_sym_interface_body,
  },
  [148] = {
    [2] = alias_sym_type_identifier,
  },
  [153] = {
    [1] = alias_sym_type_identifier,
  },
  [155] = {
    [0] = sym_identifier,
  },
  [167] = {
    [1] = alias_sym_type_identifier,
  },
  [175] = {
    [2] = alias_sym_property_identifier,
  },
  [177] = {
    [1] = alias_sym_type_identifier,
  },
  [180] = {
    [2] = alias_sym_type_identifier,
  },
  [181] = {
    [2] = alias_sym_type_identifier,
  },
  [182] = {
    [1] = alias_sym_type_identifier,
  },
  [184] = {
    [1] = alias_sym_type_identifier,
    [4] = alias_sym_interface_body,
  },
  [187] = {
    [0] = sym_identifier,
  },
  [189] = {
    [2] = alias_sym_type_identifier,
  },
  [190] = {
    [2] = alias_sym_type_identifier,
  },
  [192] = {
    [3] = alias_sym_type_identifier,
  },
  [194] = {
    [1] = alias_sym_type_identifier,
  },
  [196] = {
    [1] = sym_identifier,
  },
  [197] = {
    [1] = sym_identifier,
  },
  [202] = {
    [0] = alias_sym_type_identifier,
  },
  [226] = {
    [2] = alias_sym_type_identifier,
  },
  [231] = {
    [2] = alias_sym_type_identifier,
  },
  [232] = {
    [3] = alias_sym_type_identifier,
  },
  [233] = {
    [3] = alias_sym_type_identifier,
  },
  [265] = {
    [3] = alias_sym_property_identifier,
  },
  [266] = {
    [3] = alias_sym_type_identifier,
  },
  [275] = {
    [1] = sym_identifier,
  },
  [276] = {
    [0] = alias_sym_type_identifier,
  },
  [302] = {
    [2] = sym_identifier,
  },
  [318] = {
    [3] = sym_identifier,
  },
};

static const uint16_t ts_non_terminal_alias_map[] = {
  sym_nested_identifier, 2,
    sym_nested_identifier,
    sym_member_expression,
  sym_predefined_type, 2,
    sym_predefined_type,
    sym_identifier,
  sym_object_type, 2,
    sym_object_type,
    alias_sym_interface_body,
  0,
};

static const TSStateId ts_primary_state_ids[STATE_COUNT] = {
  [0] = 0,
  [1] = 1,
  [2] = 2,
  [3] = 2,
  [4] = 4,
  [5] = 4,
  [6] = 4,
  [7] = 4,
  [8] = 4,
  [9] = 9,
  [10] = 10,
  [11] = 11,
  [12] = 12,
  [13] = 13,
  [14] = 14,
  [15] = 14,
  [16] = 16,
  [17] = 17,
  [18] = 14,
  [19] = 19,
  [20] = 14,
  [21] = 19,
  [22] = 14,
  [23] = 19,
  [24] = 14,
  [25] = 19,
  [26] = 19,
  [27] = 14,
  [28] = 19,
  [29] = 19,
  [30] = 30,
  [31] = 31,
  [32] = 32,
  [33] = 33,
  [34] = 34,
  [35] = 35,
  [36] = 36,
  [37] = 37,
  [38] = 31,
  [39] = 39,
  [40] = 31,
  [41] = 33,
  [42] = 42,
  [43] = 43,
  [44] = 44,
  [45] = 45,
  [46] = 46,
  [47] = 47,
  [48] = 48,
  [49] = 49,
  [50] = 39,
  [51] = 42,
  [52] = 32,
  [53] = 31,
  [54] = 54,
  [55] = 43,
  [56] = 31,
  [57] = 37,
  [58] = 44,
  [59] = 45,
  [60] = 46,
  [61] = 47,
  [62] = 48,
  [63] = 31,
  [64] = 49,
  [65] = 34,
  [66] = 31,
  [67] = 31,
  [68] = 31,
  [69] = 31,
  [70] = 35,
  [71] = 36,
  [72] = 72,
  [73] = 72,
  [74] = 72,
  [75] = 75,
  [76] = 76,
  [77] = 76,
  [78] = 78,
  [79] = 79,
  [80] = 80,
  [81] = 76,
  [82] = 75,
  [83] = 83,
  [84] = 84,
  [85] = 85,
  [86] = 86,
  [87] = 87,
  [88] = 88,
  [89] = 86,
  [90] = 86,
  [91] = 86,
  [92] = 86,
  [93] = 93,
  [94] = 94,
  [95] = 94,
  [96] = 87,
  [97] = 94,
  [98] = 98,
  [99] = 99,
  [100] = 93,
  [101] = 98,
  [102] = 94,
  [103] = 94,
  [104] = 94,
  [105] = 93,
  [106] = 99,
  [107] = 93,
  [108] = 94,
  [109] = 109,
  [110] = 88,
  [111] = 111,
  [112] = 112,
  [113] = 94,
  [114] = 87,
  [115] = 115,
  [116] = 93,
  [117] = 117,
  [118] = 94,
  [119] = 98,
  [120] = 94,
  [121] = 93,
  [122] = 98,
  [123] = 87,
  [124] = 94,
  [125] = 94,
  [126] = 93,
  [127] = 111,
  [128] = 93,
  [129] = 112,
  [130] = 94,
  [131] = 94,
  [132] = 93,
  [133] = 94,
  [134] = 94,
  [135] = 94,
  [136] = 94,
  [137] = 137,
  [138] = 137,
  [139] = 93,
  [140] = 137,
  [141] = 137,
  [142] = 137,
  [143] = 143,
  [144] = 137,
  [145] = 94,
  [146] = 137,
  [147] = 137,
  [148] = 137,
  [149] = 137,
  [150] = 150,
  [151] = 151,
  [152] = 151,
  [153] = 151,
  [154] = 151,
  [155] = 151,
  [156] = 156,
  [157] = 151,
  [158] = 151,
  [159] = 159,
  [160] = 151,
  [161] = 151,
  [162] = 151,
  [163] = 163,
  [164] = 163,
  [165] = 163,
  [166] = 163,
  [167] = 163,
  [168] = 163,
  [169] = 163,
  [170] = 163,
  [171] = 163,
  [172] = 163,
  [173] = 173,
  [174] = 173,
  [175] = 173,
  [176] = 176,
  [177] = 173,
  [178] = 178,
  [179] = 179,
  [180] = 180,
  [181] = 180,
  [182] = 176,
  [183] = 173,
  [184] = 179,
  [185] = 176,
  [186] = 180,
  [187] = 173,
  [188] = 179,
  [189] = 178,
  [190] = 173,
  [191] = 173,
  [192] = 173,
  [193] = 173,
  [194] = 194,
  [195] = 194,
  [196] = 196,
  [197] = 197,
  [198] = 197,
  [199] = 197,
  [200] = 200,
  [201] = 201,
  [202] = 196,
  [203] = 203,
  [204] = 204,
  [205] = 204,
  [206] = 206,
  [207] = 204,
  [208] = 196,
  [209] = 209,
  [210] = 210,
  [211] = 211,
  [212] = 212,
  [213] = 213,
  [214] = 214,
  [215] = 215,
  [216] = 215,
  [217] = 217,
  [218] = 218,
  [219] = 219,
  [220] = 220,
  [221] = 215,
  [222] = 222,
  [223] = 223,
  [224] = 224,
  [225] = 225,
  [226] = 226,
  [227] = 227,
  [228] = 228,
  [229] = 215,
  [230] = 230,
  [231] = 231,
  [232] = 232,
  [233] = 233,
  [234] = 215,
  [235] = 235,
  [236] = 236,
  [237] = 237,
  [238] = 238,
  [239] = 239,
  [240] = 240,
  [241] = 215,
  [242] = 242,
  [243] = 243,
  [244] = 242,
  [245] = 245,
  [246] = 246,
  [247] = 247,
  [248] = 246,
  [249] = 249,
  [250] = 250,
  [251] = 242,
  [252] = 245,
  [253] = 249,
  [254] = 254,
  [255] = 242,
  [256] = 256,
  [257] = 257,
  [258] = 256,
  [259] = 257,
  [260] = 242,
  [261] = 242,
  [262] = 242,
  [263] = 242,
  [264] = 264,
  [265] = 264,
  [266] = 264,
  [267] = 267,
  [268] = 264,
  [269] = 264,
  [270] = 242,
  [271] = 264,
  [272] = 242,
  [273] = 264,
  [274] = 242,
  [275] = 275,
  [276] = 275,
  [277] = 275,
  [278] = 278,
  [279] = 279,
  [280] = 280,
  [281] = 275,
  [282] = 275,
  [283] = 275,
  [284] = 275,
  [285] = 275,
  [286] = 275,
  [287] = 287,
  [288] = 288,
  [289] = 280,
  [290] = 275,
  [291] = 275,
  [292] = 275,
  [293] = 275,
  [294] = 275,
  [295] = 275,
  [296] = 275,
  [297] = 297,
  [298] = 298,
  [299] = 299,
  [300] = 300,
  [301] = 301,
  [302] = 302,
  [303] = 303,
  [304] = 299,
  [305] = 301,
  [306] = 306,
  [307] = 307,
  [308] = 308,
  [309] = 306,
  [310] = 307,
  [311] = 308,
  [312] = 312,
  [313] = 313,
  [314] = 313,
  [315] = 315,
  [316] = 316,
  [317] = 317,
  [318] = 318,
  [319] = 319,
  [320] = 320,
  [321] = 321,
  [322] = 322,
  [323] = 323,
  [324] = 324,
  [325] = 325,
  [326] = 315,
  [327] = 319,
  [328] = 328,
  [329] = 321,
  [330] = 330,
  [331] = 331,
  [332] = 318,
  [333] = 321,
  [334] = 334,
  [335] = 317,
  [336] = 324,
  [337] = 330,
  [338] = 318,
  [339] = 321,
  [340] = 324,
  [341] = 325,
  [342] = 325,
  [343] = 315,
  [344] = 324,
  [345] = 345,
  [346] = 330,
  [347] = 318,
  [348] = 321,
  [349] = 324,
  [350] = 325,
  [351] = 315,
  [352] = 325,
  [353] = 353,
  [354] = 330,
  [355] = 355,
  [356] = 318,
  [357] = 321,
  [358] = 324,
  [359] = 318,
  [360] = 315,
  [361] = 330,
  [362] = 331,
  [363] = 330,
  [364] = 318,
  [365] = 321,
  [366] = 324,
  [367] = 325,
  [368] = 315,
  [369] = 369,
  [370] = 330,
  [371] = 318,
  [372] = 321,
  [373] = 324,
  [374] = 325,
  [375] = 315,
  [376] = 330,
  [377] = 318,
  [378] = 321,
  [379] = 324,
  [380] = 325,
  [381] = 315,
  [382] = 330,
  [383] = 318,
  [384] = 321,
  [385] = 324,
  [386] = 325,
  [387] = 315,
  [388] = 315,
  [389] = 389,
  [390] = 390,
  [391] = 391,
  [392] = 392,
  [393] = 393,
  [394] = 330,
  [395] = 325,
  [396] = 396,
  [397] = 397,
  [398] = 398,
  [399] = 399,
  [400] = 400,
  [401] = 401,
  [402] = 402,
  [403] = 403,
  [404] = 404,
  [405] = 405,
  [406] = 406,
  [407] = 407,
  [408] = 408,
  [409] = 409,
  [410] = 410,
  [411] = 411,
  [412] = 412,
  [413] = 413,
  [414] = 414,
  [415] = 415,
  [416] = 416,
  [417] = 417,
  [418] = 418,
  [419] = 419,
  [420] = 420,
  [421] = 421,
  [422] = 422,
  [423] = 412,
  [424] = 424,
  [425] = 425,
  [426] = 396,
  [427] = 427,
  [428] = 428,
  [429] = 412,
  [430] = 418,
  [431] = 431,
  [432] = 399,
  [433] = 400,
  [434] = 415,
  [435] = 416,
  [436] = 412,
  [437] = 425,
  [438] = 418,
  [439] = 439,
  [440] = 427,
  [441] = 418,
  [442] = 442,
  [443] = 443,
  [444] = 418,
  [445] = 418,
  [446] = 446,
  [447] = 447,
  [448] = 448,
  [449] = 418,
  [450] = 450,
  [451] = 451,
  [452] = 428,
  [453] = 401,
  [454] = 446,
  [455] = 455,
  [456] = 397,
  [457] = 398,
  [458] = 398,
  [459] = 396,
  [460] = 399,
  [461] = 401,
  [462] = 402,
  [463] = 403,
  [464] = 404,
  [465] = 405,
  [466] = 406,
  [467] = 407,
  [468] = 408,
  [469] = 409,
  [470] = 410,
  [471] = 411,
  [472] = 417,
  [473] = 402,
  [474] = 403,
  [475] = 404,
  [476] = 415,
  [477] = 416,
  [478] = 418,
  [479] = 405,
  [480] = 442,
  [481] = 422,
  [482] = 424,
  [483] = 451,
  [484] = 428,
  [485] = 446,
  [486] = 450,
  [487] = 455,
  [488] = 397,
  [489] = 398,
  [490] = 399,
  [491] = 400,
  [492] = 401,
  [493] = 402,
  [494] = 403,
  [495] = 404,
  [496] = 405,
  [497] = 406,
  [498] = 407,
  [499] = 408,
  [500] = 409,
  [501] = 410,
  [502] = 411,
  [503] = 412,
  [504] = 406,
  [505] = 415,
  [506] = 416,
  [507] = 418,
  [508] = 422,
  [509] = 424,
  [510] = 425,
  [511] = 418,
  [512] = 450,
  [513] = 428,
  [514] = 407,
  [515] = 446,
  [516] = 455,
  [517] = 397,
  [518] = 398,
  [519] = 396,
  [520] = 399,
  [521] = 401,
  [522] = 402,
  [523] = 403,
  [524] = 404,
  [525] = 405,
  [526] = 397,
  [527] = 407,
  [528] = 408,
  [529] = 409,
  [530] = 410,
  [531] = 411,
  [532] = 408,
  [533] = 415,
  [534] = 416,
  [535] = 418,
  [536] = 409,
  [537] = 422,
  [538] = 451,
  [539] = 428,
  [540] = 446,
  [541] = 455,
  [542] = 397,
  [543] = 398,
  [544] = 399,
  [545] = 401,
  [546] = 402,
  [547] = 403,
  [548] = 404,
  [549] = 405,
  [550] = 406,
  [551] = 407,
  [552] = 408,
  [553] = 409,
  [554] = 410,
  [555] = 411,
  [556] = 415,
  [557] = 416,
  [558] = 418,
  [559] = 422,
  [560] = 424,
  [561] = 425,
  [562] = 562,
  [563] = 418,
  [564] = 450,
  [565] = 396,
  [566] = 428,
  [567] = 446,
  [568] = 455,
  [569] = 397,
  [570] = 398,
  [571] = 399,
  [572] = 401,
  [573] = 402,
  [574] = 403,
  [575] = 404,
  [576] = 405,
  [577] = 406,
  [578] = 407,
  [579] = 408,
  [580] = 409,
  [581] = 410,
  [582] = 411,
  [583] = 415,
  [584] = 416,
  [585] = 455,
  [586] = 451,
  [587] = 422,
  [588] = 424,
  [589] = 425,
  [590] = 427,
  [591] = 418,
  [592] = 450,
  [593] = 396,
  [594] = 428,
  [595] = 446,
  [596] = 455,
  [597] = 397,
  [598] = 398,
  [599] = 399,
  [600] = 401,
  [601] = 402,
  [602] = 403,
  [603] = 404,
  [604] = 405,
  [605] = 406,
  [606] = 407,
  [607] = 408,
  [608] = 409,
  [609] = 410,
  [610] = 411,
  [611] = 410,
  [612] = 415,
  [613] = 416,
  [614] = 422,
  [615] = 424,
  [616] = 425,
  [617] = 418,
  [618] = 450,
  [619] = 396,
  [620] = 428,
  [621] = 446,
  [622] = 455,
  [623] = 397,
  [624] = 398,
  [625] = 399,
  [626] = 401,
  [627] = 402,
  [628] = 403,
  [629] = 404,
  [630] = 405,
  [631] = 406,
  [632] = 407,
  [633] = 408,
  [634] = 409,
  [635] = 410,
  [636] = 451,
  [637] = 411,
  [638] = 428,
  [639] = 446,
  [640] = 415,
  [641] = 416,
  [642] = 422,
  [643] = 422,
  [644] = 424,
  [645] = 425,
  [646] = 450,
  [647] = 428,
  [648] = 446,
  [649] = 455,
  [650] = 397,
  [651] = 398,
  [652] = 399,
  [653] = 401,
  [654] = 402,
  [655] = 403,
  [656] = 404,
  [657] = 405,
  [658] = 406,
  [659] = 407,
  [660] = 408,
  [661] = 409,
  [662] = 410,
  [663] = 411,
  [664] = 411,
  [665] = 415,
  [666] = 416,
  [667] = 422,
  [668] = 424,
  [669] = 425,
  [670] = 450,
  [671] = 396,
  [672] = 672,
  [673] = 424,
  [674] = 425,
  [675] = 451,
  [676] = 451,
  [677] = 677,
  [678] = 418,
  [679] = 424,
  [680] = 425,
  [681] = 451,
  [682] = 455,
  [683] = 451,
  [684] = 451,
  [685] = 450,
  [686] = 396,
  [687] = 450,
  [688] = 396,
  [689] = 406,
  [690] = 690,
  [691] = 690,
  [692] = 690,
  [693] = 693,
  [694] = 693,
  [695] = 693,
  [696] = 696,
  [697] = 696,
  [698] = 698,
  [699] = 698,
  [700] = 698,
  [701] = 701,
  [702] = 701,
  [703] = 703,
  [704] = 703,
  [705] = 703,
  [706] = 701,
  [707] = 707,
  [708] = 213,
  [709] = 219,
  [710] = 707,
  [711] = 711,
  [712] = 712,
  [713] = 713,
  [714] = 714,
  [715] = 715,
  [716] = 716,
  [717] = 716,
  [718] = 718,
  [719] = 718,
  [720] = 720,
  [721] = 720,
  [722] = 716,
  [723] = 718,
  [724] = 724,
  [725] = 725,
  [726] = 726,
  [727] = 726,
  [728] = 728,
  [729] = 728,
  [730] = 726,
  [731] = 724,
  [732] = 726,
  [733] = 725,
  [734] = 726,
  [735] = 726,
  [736] = 736,
  [737] = 726,
  [738] = 725,
  [739] = 726,
  [740] = 726,
  [741] = 726,
  [742] = 742,
  [743] = 726,
  [744] = 744,
  [745] = 745,
  [746] = 746,
  [747] = 212,
  [748] = 726,
  [749] = 749,
  [750] = 749,
  [751] = 725,
  [752] = 749,
  [753] = 236,
  [754] = 236,
  [755] = 235,
  [756] = 238,
  [757] = 211,
  [758] = 235,
  [759] = 212,
  [760] = 210,
  [761] = 726,
  [762] = 726,
  [763] = 726,
  [764] = 726,
  [765] = 742,
  [766] = 726,
  [767] = 726,
  [768] = 724,
  [769] = 210,
  [770] = 770,
  [771] = 771,
  [772] = 771,
  [773] = 771,
  [774] = 771,
  [775] = 771,
  [776] = 771,
  [777] = 726,
  [778] = 771,
  [779] = 771,
  [780] = 200,
  [781] = 771,
  [782] = 771,
  [783] = 201,
  [784] = 784,
  [785] = 785,
  [786] = 786,
  [787] = 787,
  [788] = 788,
  [789] = 239,
  [790] = 790,
  [791] = 791,
  [792] = 792,
  [793] = 784,
  [794] = 794,
  [795] = 784,
  [796] = 796,
  [797] = 797,
  [798] = 203,
  [799] = 799,
  [800] = 784,
  [801] = 801,
  [802] = 240,
  [803] = 803,
  [804] = 804,
  [805] = 784,
  [806] = 806,
  [807] = 807,
  [808] = 808,
  [809] = 809,
  [810] = 810,
  [811] = 811,
  [812] = 812,
  [813] = 813,
  [814] = 814,
  [815] = 815,
  [816] = 816,
  [817] = 817,
  [818] = 818,
  [819] = 819,
  [820] = 820,
  [821] = 821,
  [822] = 822,
  [823] = 823,
  [824] = 824,
  [825] = 825,
  [826] = 826,
  [827] = 827,
  [828] = 828,
  [829] = 829,
  [830] = 830,
  [831] = 831,
  [832] = 832,
  [833] = 833,
  [834] = 834,
  [835] = 835,
  [836] = 836,
  [837] = 837,
  [838] = 838,
  [839] = 839,
  [840] = 840,
  [841] = 841,
  [842] = 842,
  [843] = 843,
  [844] = 844,
  [845] = 845,
  [846] = 846,
  [847] = 847,
  [848] = 820,
  [849] = 849,
  [850] = 850,
  [851] = 851,
  [852] = 852,
  [853] = 853,
  [854] = 854,
  [855] = 855,
  [856] = 856,
  [857] = 857,
  [858] = 858,
  [859] = 859,
  [860] = 860,
  [861] = 861,
  [862] = 862,
  [863] = 863,
  [864] = 864,
  [865] = 238,
  [866] = 866,
  [867] = 867,
  [868] = 820,
  [869] = 869,
  [870] = 870,
  [871] = 871,
  [872] = 211,
  [873] = 873,
  [874] = 874,
  [875] = 875,
  [876] = 821,
  [877] = 877,
  [878] = 878,
  [879] = 879,
  [880] = 880,
  [881] = 881,
  [882] = 217,
  [883] = 883,
  [884] = 884,
  [885] = 885,
  [886] = 886,
  [887] = 231,
  [888] = 888,
  [889] = 821,
  [890] = 890,
  [891] = 891,
  [892] = 892,
  [893] = 893,
  [894] = 894,
  [895] = 895,
  [896] = 896,
  [897] = 897,
  [898] = 898,
  [899] = 899,
  [900] = 820,
  [901] = 901,
  [902] = 902,
  [903] = 903,
  [904] = 904,
  [905] = 905,
  [906] = 821,
  [907] = 907,
  [908] = 908,
  [909] = 909,
  [910] = 910,
  [911] = 911,
  [912] = 912,
  [913] = 913,
  [914] = 914,
  [915] = 915,
  [916] = 916,
  [917] = 917,
  [918] = 918,
  [919] = 919,
  [920] = 920,
  [921] = 921,
  [922] = 922,
  [923] = 923,
  [924] = 924,
  [925] = 925,
  [926] = 926,
  [927] = 927,
  [928] = 928,
  [929] = 929,
  [930] = 930,
  [931] = 931,
  [932] = 932,
  [933] = 820,
  [934] = 934,
  [935] = 821,
  [936] = 936,
  [937] = 937,
  [938] = 938,
  [939] = 939,
  [940] = 940,
  [941] = 941,
  [942] = 942,
  [943] = 943,
  [944] = 944,
  [945] = 945,
  [946] = 946,
  [947] = 947,
  [948] = 948,
  [949] = 946,
  [950] = 950,
  [951] = 948,
  [952] = 952,
  [953] = 946,
  [954] = 803,
  [955] = 955,
  [956] = 956,
  [957] = 948,
  [958] = 958,
  [959] = 959,
  [960] = 960,
  [961] = 959,
  [962] = 946,
  [963] = 959,
  [964] = 948,
  [965] = 965,
  [966] = 966,
  [967] = 948,
  [968] = 946,
  [969] = 787,
  [970] = 970,
  [971] = 948,
  [972] = 972,
  [973] = 948,
  [974] = 946,
  [975] = 975,
  [976] = 946,
  [977] = 977,
  [978] = 978,
  [979] = 979,
  [980] = 978,
  [981] = 981,
  [982] = 978,
  [983] = 977,
  [984] = 979,
  [985] = 978,
  [986] = 979,
  [987] = 978,
  [988] = 988,
  [989] = 977,
  [990] = 977,
  [991] = 991,
  [992] = 992,
  [993] = 977,
  [994] = 979,
  [995] = 978,
  [996] = 977,
  [997] = 979,
  [998] = 998,
  [999] = 999,
  [1000] = 1000,
  [1001] = 1001,
  [1002] = 1002,
  [1003] = 1003,
  [1004] = 1004,
  [1005] = 1005,
  [1006] = 1006,
  [1007] = 1007,
  [1008] = 1008,
  [1009] = 1001,
  [1010] = 1010,
  [1011] = 1011,
  [1012] = 1012,
  [1013] = 1013,
  [1014] = 1001,
  [1015] = 1015,
  [1016] = 1016,
  [1017] = 1017,
  [1018] = 1018,
  [1019] = 1019,
  [1020] = 998,
  [1021] = 1000,
  [1022] = 1002,
  [1023] = 1003,
  [1024] = 1024,
  [1025] = 1025,
  [1026] = 1010,
  [1027] = 1007,
  [1028] = 1008,
  [1029] = 1011,
  [1030] = 1012,
  [1031] = 1013,
  [1032] = 1015,
  [1033] = 1016,
  [1034] = 1034,
  [1035] = 1035,
  [1036] = 1036,
  [1037] = 1017,
  [1038] = 1018,
  [1039] = 998,
  [1040] = 1000,
  [1041] = 1015,
  [1042] = 1016,
  [1043] = 1002,
  [1044] = 1003,
  [1045] = 1004,
  [1046] = 1005,
  [1047] = 1024,
  [1048] = 1025,
  [1049] = 1049,
  [1050] = 1050,
  [1051] = 1051,
  [1052] = 1052,
  [1053] = 1017,
  [1054] = 1018,
  [1055] = 1055,
  [1056] = 1056,
  [1057] = 998,
  [1058] = 1000,
  [1059] = 1002,
  [1060] = 1003,
  [1061] = 1024,
  [1062] = 1025,
  [1063] = 1007,
  [1064] = 1008,
  [1065] = 1011,
  [1066] = 1012,
  [1067] = 1013,
  [1068] = 1015,
  [1069] = 1015,
  [1070] = 1016,
  [1071] = 1004,
  [1072] = 1017,
  [1073] = 1018,
  [1074] = 1004,
  [1075] = 1002,
  [1076] = 1003,
  [1077] = 1024,
  [1078] = 1025,
  [1079] = 1007,
  [1080] = 1008,
  [1081] = 1011,
  [1082] = 1012,
  [1083] = 1004,
  [1084] = 1001,
  [1085] = 1024,
  [1086] = 1016,
  [1087] = 1015,
  [1088] = 1016,
  [1089] = 1017,
  [1090] = 1018,
  [1091] = 999,
  [1092] = 1002,
  [1093] = 1003,
  [1094] = 1024,
  [1095] = 1025,
  [1096] = 1017,
  [1097] = 1018,
  [1098] = 1001,
  [1099] = 998,
  [1100] = 1000,
  [1101] = 1101,
  [1102] = 1102,
  [1103] = 1103,
  [1104] = 1025,
  [1105] = 1007,
  [1106] = 1008,
  [1107] = 1011,
  [1108] = 1012,
  [1109] = 1013,
  [1110] = 1006,
  [1111] = 1001,
  [1112] = 1112,
  [1113] = 1112,
  [1114] = 1114,
  [1115] = 1035,
  [1116] = 1015,
  [1117] = 1016,
  [1118] = 1017,
  [1119] = 1018,
  [1120] = 998,
  [1121] = 1000,
  [1122] = 1002,
  [1123] = 1003,
  [1124] = 1124,
  [1125] = 1125,
  [1126] = 1126,
  [1127] = 1024,
  [1128] = 1128,
  [1129] = 1025,
  [1130] = 1007,
  [1131] = 1008,
  [1132] = 1011,
  [1133] = 1012,
  [1134] = 1013,
  [1135] = 1004,
  [1136] = 998,
  [1137] = 1000,
  [1138] = 1114,
  [1139] = 1007,
  [1140] = 1008,
  [1141] = 1011,
  [1142] = 1012,
  [1143] = 999,
  [1144] = 1004,
  [1145] = 1013,
  [1146] = 999,
  [1147] = 999,
  [1148] = 999,
  [1149] = 999,
  [1150] = 1013,
  [1151] = 1151,
  [1152] = 1151,
  [1153] = 1151,
  [1154] = 1151,
  [1155] = 1151,
  [1156] = 1151,
  [1157] = 1151,
  [1158] = 1151,
  [1159] = 1151,
  [1160] = 1151,
  [1161] = 1151,
  [1162] = 1151,
  [1163] = 1163,
  [1164] = 1164,
  [1165] = 1163,
  [1166] = 1166,
  [1167] = 1167,
  [1168] = 1164,
  [1169] = 1163,
  [1170] = 1170,
  [1171] = 1171,
  [1172] = 1167,
  [1173] = 1167,
  [1174] = 1164,
  [1175] = 1175,
  [1176] = 1176,
  [1177] = 1177,
  [1178] = 1177,
  [1179] = 1179,
  [1180] = 1179,
  [1181] = 1177,
  [1182] = 1182,
  [1183] = 1183,
  [1184] = 1184,
  [1185] = 1175,
  [1186] = 1176,
  [1187] = 1177,
  [1188] = 1177,
  [1189] = 1177,
  [1190] = 1184,
  [1191] = 1183,
  [1192] = 1182,
  [1193] = 1193,
  [1194] = 1193,
  [1195] = 1195,
  [1196] = 1193,
  [1197] = 1197,
  [1198] = 1198,
  [1199] = 1199,
  [1200] = 1200,
  [1201] = 1177,
  [1202] = 1202,
  [1203] = 1203,
  [1204] = 1204,
  [1205] = 1205,
  [1206] = 1206,
  [1207] = 1207,
  [1208] = 1177,
  [1209] = 1177,
  [1210] = 1176,
  [1211] = 1177,
  [1212] = 1212,
  [1213] = 1213,
  [1214] = 1214,
  [1215] = 1215,
  [1216] = 1216,
  [1217] = 787,
  [1218] = 1177,
  [1219] = 803,
  [1220] = 1177,
  [1221] = 1221,
  [1222] = 1221,
  [1223] = 1223,
  [1224] = 1224,
  [1225] = 1225,
  [1226] = 1224,
  [1227] = 1216,
  [1228] = 1216,
  [1229] = 1176,
  [1230] = 1177,
  [1231] = 1223,
  [1232] = 1215,
  [1233] = 1215,
  [1234] = 1177,
  [1235] = 1177,
  [1236] = 1177,
  [1237] = 1177,
  [1238] = 1238,
  [1239] = 1177,
  [1240] = 1177,
  [1241] = 1241,
  [1242] = 1175,
  [1243] = 1203,
  [1244] = 1223,
  [1245] = 1245,
  [1246] = 1246,
  [1247] = 1223,
  [1248] = 1248,
  [1249] = 1223,
  [1250] = 1248,
  [1251] = 1248,
  [1252] = 1252,
  [1253] = 1248,
  [1254] = 1223,
  [1255] = 1255,
  [1256] = 1238,
  [1257] = 1248,
  [1258] = 1223,
  [1259] = 1248,
  [1260] = 1260,
  [1261] = 1223,
  [1262] = 1262,
  [1263] = 1223,
  [1264] = 1245,
  [1265] = 1265,
  [1266] = 1248,
  [1267] = 1177,
  [1268] = 1248,
  [1269] = 1269,
  [1270] = 1238,
  [1271] = 1248,
  [1272] = 1272,
  [1273] = 1273,
  [1274] = 1248,
  [1275] = 1245,
  [1276] = 1276,
  [1277] = 1277,
  [1278] = 1278,
  [1279] = 1279,
  [1280] = 1279,
  [1281] = 1223,
  [1282] = 1202,
  [1283] = 1223,
  [1284] = 1205,
  [1285] = 1285,
  [1286] = 1262,
  [1287] = 1287,
  [1288] = 1288,
  [1289] = 1238,
  [1290] = 1202,
  [1291] = 1205,
  [1292] = 1285,
  [1293] = 1223,
  [1294] = 1238,
  [1295] = 1295,
  [1296] = 1223,
  [1297] = 1297,
  [1298] = 1223,
  [1299] = 1299,
  [1300] = 1276,
  [1301] = 1277,
  [1302] = 1238,
  [1303] = 1276,
  [1304] = 1299,
  [1305] = 1262,
  [1306] = 1276,
  [1307] = 1299,
  [1308] = 1299,
  [1309] = 1238,
  [1310] = 1206,
  [1311] = 1207,
  [1312] = 1299,
  [1313] = 1277,
  [1314] = 1265,
  [1315] = 1315,
  [1316] = 1316,
  [1317] = 1317,
  [1318] = 1318,
  [1319] = 1260,
  [1320] = 1277,
  [1321] = 1197,
  [1322] = 1213,
  [1323] = 1238,
  [1324] = 1277,
  [1325] = 1198,
  [1326] = 1316,
  [1327] = 1223,
  [1328] = 1276,
  [1329] = 1277,
  [1330] = 1200,
  [1331] = 787,
  [1332] = 1332,
  [1333] = 1318,
  [1334] = 1213,
  [1335] = 803,
  [1336] = 1238,
  [1337] = 1299,
  [1338] = 1262,
  [1339] = 1202,
  [1340] = 1238,
  [1341] = 1273,
  [1342] = 1315,
  [1343] = 1276,
  [1344] = 1344,
  [1345] = 1205,
  [1346] = 1223,
  [1347] = 1212,
  [1348] = 1199,
  [1349] = 1277,
  [1350] = 1202,
  [1351] = 1351,
  [1352] = 1295,
  [1353] = 1299,
  [1354] = 1205,
  [1355] = 1299,
  [1356] = 1356,
  [1357] = 1238,
  [1358] = 1252,
  [1359] = 1351,
  [1360] = 1277,
  [1361] = 1276,
  [1362] = 1213,
  [1363] = 1278,
  [1364] = 1213,
  [1365] = 1365,
  [1366] = 1299,
  [1367] = 1205,
  [1368] = 1299,
  [1369] = 1202,
  [1370] = 1276,
  [1371] = 1260,
  [1372] = 1372,
  [1373] = 1276,
  [1374] = 1277,
  [1375] = 1277,
  [1376] = 1265,
  [1377] = 1377,
  [1378] = 1276,
  [1379] = 1379,
  [1380] = 1380,
  [1381] = 1381,
  [1382] = 1380,
  [1383] = 1299,
  [1384] = 1277,
  [1385] = 1299,
  [1386] = 1380,
  [1387] = 1213,
  [1388] = 1388,
  [1389] = 1380,
  [1390] = 1260,
  [1391] = 1265,
  [1392] = 1392,
  [1393] = 1276,
  [1394] = 1380,
  [1395] = 1380,
  [1396] = 1295,
  [1397] = 1202,
  [1398] = 1213,
  [1399] = 1399,
  [1400] = 1277,
  [1401] = 1205,
  [1402] = 1277,
  [1403] = 1277,
  [1404] = 1299,
  [1405] = 1277,
  [1406] = 1277,
  [1407] = 1277,
  [1408] = 1277,
  [1409] = 1273,
  [1410] = 1213,
  [1411] = 1356,
  [1412] = 1299,
  [1413] = 1365,
  [1414] = 1295,
  [1415] = 1299,
  [1416] = 1299,
  [1417] = 1299,
  [1418] = 1299,
  [1419] = 1419,
  [1420] = 1420,
  [1421] = 1421,
  [1422] = 1420,
  [1423] = 1423,
  [1424] = 1419,
  [1425] = 1421,
  [1426] = 1426,
  [1427] = 1299,
  [1428] = 1421,
  [1429] = 1421,
  [1430] = 1420,
  [1431] = 1420,
  [1432] = 1419,
  [1433] = 1426,
  [1434] = 1421,
  [1435] = 1420,
  [1436] = 1426,
  [1437] = 1423,
  [1438] = 1421,
  [1439] = 1426,
  [1440] = 1420,
  [1441] = 1426,
  [1442] = 1423,
  [1443] = 1423,
  [1444] = 1421,
  [1445] = 1420,
  [1446] = 1278,
  [1447] = 1381,
  [1448] = 1421,
  [1449] = 1421,
  [1450] = 1423,
  [1451] = 1420,
  [1452] = 1421,
  [1453] = 1420,
  [1454] = 1426,
  [1455] = 1419,
  [1456] = 1213,
  [1457] = 1213,
  [1458] = 1277,
  [1459] = 1213,
  [1460] = 1423,
  [1461] = 1420,
  [1462] = 1419,
  [1463] = 1419,
  [1464] = 1464,
  [1465] = 1464,
  [1466] = 1464,
  [1467] = 1464,
  [1468] = 1464,
  [1469] = 1464,
  [1470] = 1464,
  [1471] = 1464,
  [1472] = 1464,
  [1473] = 1464,
  [1474] = 1474,
  [1475] = 1474,
  [1476] = 1474,
  [1477] = 1477,
  [1478] = 1474,
  [1479] = 1474,
  [1480] = 1474,
  [1481] = 1481,
  [1482] = 1482,
  [1483] = 1483,
  [1484] = 1482,
  [1485] = 1485,
  [1486] = 1481,
  [1487] = 1481,
  [1488] = 1481,
  [1489] = 1483,
  [1490] = 1483,
  [1491] = 1482,
  [1492] = 1483,
  [1493] = 1481,
  [1494] = 1483,
  [1495] = 1482,
  [1496] = 1482,
  [1497] = 1497,
  [1498] = 1497,
  [1499] = 1497,
  [1500] = 1497,
  [1501] = 1501,
  [1502] = 1497,
  [1503] = 1497,
  [1504] = 1504,
  [1505] = 1505,
  [1506] = 1506,
  [1507] = 1507,
  [1508] = 219,
  [1509] = 1509,
  [1510] = 1510,
  [1511] = 213,
  [1512] = 1512,
  [1513] = 988,
  [1514] = 1514,
  [1515] = 1515,
  [1516] = 1516,
  [1517] = 213,
  [1518] = 992,
  [1519] = 219,
  [1520] = 1520,
  [1521] = 206,
  [1522] = 1522,
  [1523] = 1523,
  [1524] = 1524,
  [1525] = 1525,
  [1526] = 991,
  [1527] = 1527,
  [1528] = 1528,
  [1529] = 1529,
  [1530] = 1530,
  [1531] = 1531,
  [1532] = 1532,
  [1533] = 1533,
  [1534] = 212,
  [1535] = 1535,
  [1536] = 1536,
  [1537] = 1537,
  [1538] = 1538,
  [1539] = 1539,
  [1540] = 1540,
  [1541] = 714,
  [1542] = 1542,
  [1543] = 1543,
  [1544] = 1544,
  [1545] = 1545,
  [1546] = 1546,
  [1547] = 1547,
  [1548] = 1548,
  [1549] = 1549,
  [1550] = 1550,
  [1551] = 1551,
  [1552] = 1552,
  [1553] = 1553,
  [1554] = 1554,
  [1555] = 1166,
  [1556] = 1556,
  [1557] = 1557,
  [1558] = 1558,
  [1559] = 1559,
  [1560] = 1560,
  [1561] = 1561,
  [1562] = 1562,
  [1563] = 1563,
  [1564] = 713,
  [1565] = 1565,
  [1566] = 1566,
  [1567] = 1567,
  [1568] = 1568,
  [1569] = 1569,
  [1570] = 1570,
  [1571] = 1571,
  [1572] = 1572,
  [1573] = 1573,
  [1574] = 1574,
  [1575] = 1575,
  [1576] = 1576,
  [1577] = 1577,
  [1578] = 1578,
  [1579] = 236,
  [1580] = 1580,
  [1581] = 1581,
  [1582] = 711,
  [1583] = 1583,
  [1584] = 1584,
  [1585] = 1585,
  [1586] = 1586,
  [1587] = 1587,
  [1588] = 1588,
  [1589] = 1589,
  [1590] = 1170,
  [1591] = 1591,
  [1592] = 1592,
  [1593] = 1593,
  [1594] = 1594,
  [1595] = 1595,
  [1596] = 1596,
  [1597] = 1597,
  [1598] = 1598,
  [1599] = 1599,
  [1600] = 1600,
  [1601] = 715,
  [1602] = 1602,
  [1603] = 1603,
  [1604] = 1604,
  [1605] = 1605,
  [1606] = 200,
  [1607] = 1171,
  [1608] = 201,
  [1609] = 1609,
  [1610] = 1610,
  [1611] = 1611,
  [1612] = 203,
  [1613] = 1613,
  [1614] = 1614,
  [1615] = 200,
  [1616] = 201,
  [1617] = 203,
  [1618] = 712,
  [1619] = 1619,
  [1620] = 1620,
  [1621] = 1621,
  [1622] = 1622,
  [1623] = 1623,
  [1624] = 1624,
  [1625] = 1625,
  [1626] = 1626,
  [1627] = 1627,
  [1628] = 1628,
  [1629] = 1629,
  [1630] = 1630,
  [1631] = 1631,
  [1632] = 1632,
  [1633] = 1633,
  [1634] = 1634,
  [1635] = 1635,
  [1636] = 1636,
  [1637] = 1637,
  [1638] = 1638,
  [1639] = 1639,
  [1640] = 1640,
  [1641] = 1641,
  [1642] = 1642,
  [1643] = 1643,
  [1644] = 1644,
  [1645] = 1645,
  [1646] = 1646,
  [1647] = 1647,
  [1648] = 1648,
  [1649] = 1649,
  [1650] = 1650,
  [1651] = 1651,
  [1652] = 1652,
  [1653] = 1653,
  [1654] = 1654,
  [1655] = 1655,
  [1656] = 1656,
  [1657] = 1657,
  [1658] = 1658,
  [1659] = 1659,
  [1660] = 1660,
  [1661] = 1661,
  [1662] = 238,
  [1663] = 1663,
  [1664] = 1664,
  [1665] = 1665,
  [1666] = 1666,
  [1667] = 1667,
  [1668] = 1668,
  [1669] = 1669,
  [1670] = 1670,
  [1671] = 1671,
  [1672] = 1672,
  [1673] = 1673,
  [1674] = 1674,
  [1675] = 1675,
  [1676] = 1676,
  [1677] = 1677,
  [1678] = 211,
  [1679] = 1679,
  [1680] = 1680,
  [1681] = 1681,
  [1682] = 1682,
  [1683] = 1683,
  [1684] = 1684,
  [1685] = 1685,
  [1686] = 1686,
  [1687] = 1687,
  [1688] = 1688,
  [1689] = 1689,
  [1690] = 1690,
  [1691] = 1691,
  [1692] = 1692,
  [1693] = 1693,
  [1694] = 1694,
  [1695] = 1695,
  [1696] = 1501,
  [1697] = 1697,
  [1698] = 1698,
  [1699] = 1699,
  [1700] = 1700,
  [1701] = 1701,
  [1702] = 1702,
  [1703] = 1703,
  [1704] = 1704,
  [1705] = 1705,
  [1706] = 1706,
  [1707] = 1707,
  [1708] = 239,
  [1709] = 240,
  [1710] = 1710,
  [1711] = 231,
  [1712] = 217,
  [1713] = 235,
  [1714] = 239,
  [1715] = 240,
  [1716] = 210,
  [1717] = 1717,
  [1718] = 1717,
  [1719] = 1717,
  [1720] = 1717,
  [1721] = 1717,
  [1722] = 1722,
  [1723] = 1705,
  [1724] = 212,
  [1725] = 1725,
  [1726] = 1706,
  [1727] = 235,
  [1728] = 1728,
  [1729] = 236,
  [1730] = 1504,
  [1731] = 1731,
  [1732] = 1505,
  [1733] = 210,
  [1734] = 1734,
  [1735] = 1509,
  [1736] = 1731,
  [1737] = 1506,
  [1738] = 1734,
  [1739] = 1739,
  [1740] = 1740,
  [1741] = 1741,
  [1742] = 1742,
  [1743] = 1743,
  [1744] = 1744,
  [1745] = 1745,
  [1746] = 1746,
  [1747] = 1747,
  [1748] = 1748,
  [1749] = 1749,
  [1750] = 217,
  [1751] = 1751,
  [1752] = 1752,
  [1753] = 1753,
  [1754] = 1754,
  [1755] = 1755,
  [1756] = 1756,
  [1757] = 1757,
  [1758] = 1758,
  [1759] = 1759,
  [1760] = 1760,
  [1761] = 1761,
  [1762] = 1762,
  [1763] = 1763,
  [1764] = 1764,
  [1765] = 1765,
  [1766] = 211,
  [1767] = 1731,
  [1768] = 1651,
  [1769] = 1734,
  [1770] = 1731,
  [1771] = 231,
  [1772] = 1734,
  [1773] = 1731,
  [1774] = 238,
  [1775] = 1734,
  [1776] = 1776,
  [1777] = 1777,
  [1778] = 1778,
  [1779] = 1779,
  [1780] = 1525,
  [1781] = 1514,
  [1782] = 1743,
  [1783] = 1783,
  [1784] = 1784,
  [1785] = 1531,
  [1786] = 1516,
  [1787] = 1787,
  [1788] = 1512,
  [1789] = 1744,
  [1790] = 1745,
  [1791] = 1746,
  [1792] = 1783,
  [1793] = 1705,
  [1794] = 1794,
  [1795] = 988,
  [1796] = 1539,
  [1797] = 1706,
  [1798] = 1722,
  [1799] = 1651,
  [1800] = 1747,
  [1801] = 1801,
  [1802] = 1748,
  [1803] = 1749,
  [1804] = 1779,
  [1805] = 1751,
  [1806] = 1752,
  [1807] = 1753,
  [1808] = 1754,
  [1809] = 1755,
  [1810] = 1515,
  [1811] = 1756,
  [1812] = 1757,
  [1813] = 1813,
  [1814] = 1776,
  [1815] = 1760,
  [1816] = 1816,
  [1817] = 1761,
  [1818] = 1762,
  [1819] = 1763,
  [1820] = 1764,
  [1821] = 1523,
  [1822] = 1524,
  [1823] = 1778,
  [1824] = 1783,
  [1825] = 1816,
  [1826] = 1522,
  [1827] = 1827,
  [1828] = 1758,
  [1829] = 1783,
  [1830] = 1759,
  [1831] = 1777,
  [1832] = 1816,
  [1833] = 1783,
  [1834] = 1739,
  [1835] = 1739,
  [1836] = 1740,
  [1837] = 1741,
  [1838] = 991,
  [1839] = 1743,
  [1840] = 1744,
  [1841] = 1745,
  [1842] = 1746,
  [1843] = 1747,
  [1844] = 1748,
  [1845] = 1749,
  [1846] = 1779,
  [1847] = 1751,
  [1848] = 1752,
  [1849] = 1753,
  [1850] = 1754,
  [1851] = 1755,
  [1852] = 1756,
  [1853] = 1757,
  [1854] = 1758,
  [1855] = 1759,
  [1856] = 1760,
  [1857] = 1761,
  [1858] = 1762,
  [1859] = 1763,
  [1860] = 1764,
  [1861] = 1765,
  [1862] = 1531,
  [1863] = 1539,
  [1864] = 1816,
  [1865] = 1527,
  [1866] = 1740,
  [1867] = 1867,
  [1868] = 1741,
  [1869] = 1869,
  [1870] = 1870,
  [1871] = 992,
  [1872] = 1765,
  [1873] = 1776,
  [1874] = 1722,
  [1875] = 1778,
  [1876] = 1777,
  [1877] = 1877,
  [1878] = 1591,
  [1879] = 1650,
  [1880] = 1596,
  [1881] = 1597,
  [1882] = 1600,
  [1883] = 1605,
  [1884] = 1170,
  [1885] = 206,
  [1886] = 1740,
  [1887] = 1744,
  [1888] = 1741,
  [1889] = 1877,
  [1890] = 1745,
  [1891] = 1746,
  [1892] = 1892,
  [1893] = 1893,
  [1894] = 1894,
  [1895] = 1747,
  [1896] = 1748,
  [1897] = 1749,
  [1898] = 1779,
  [1899] = 1751,
  [1900] = 1752,
  [1901] = 1753,
  [1902] = 1902,
  [1903] = 1754,
  [1904] = 1755,
  [1905] = 1905,
  [1906] = 1756,
  [1907] = 1528,
  [1908] = 1757,
  [1909] = 1593,
  [1910] = 1619,
  [1911] = 1574,
  [1912] = 1544,
  [1913] = 1758,
  [1914] = 1759,
  [1915] = 1554,
  [1916] = 1556,
  [1917] = 1877,
  [1918] = 1536,
  [1919] = 1743,
  [1920] = 1670,
  [1921] = 1867,
  [1922] = 1777,
  [1923] = 1722,
  [1924] = 1778,
  [1925] = 1581,
  [1926] = 206,
  [1927] = 1760,
  [1928] = 1705,
  [1929] = 1929,
  [1930] = 1761,
  [1931] = 1620,
  [1932] = 1762,
  [1933] = 1933,
  [1934] = 1531,
  [1935] = 1535,
  [1936] = 1539,
  [1937] = 1549,
  [1938] = 714,
  [1939] = 1637,
  [1940] = 1940,
  [1941] = 1643,
  [1942] = 1645,
  [1943] = 1943,
  [1944] = 1944,
  [1945] = 1945,
  [1946] = 1763,
  [1947] = 1877,
  [1948] = 1648,
  [1949] = 1531,
  [1950] = 1539,
  [1951] = 1588,
  [1952] = 1647,
  [1953] = 1877,
  [1954] = 1531,
  [1955] = 1539,
  [1956] = 1707,
  [1957] = 1710,
  [1958] = 1670,
  [1959] = 1764,
  [1960] = 1776,
  [1961] = 1528,
  [1962] = 1962,
  [1963] = 715,
  [1964] = 1602,
  [1965] = 1603,
  [1966] = 1604,
  [1967] = 1609,
  [1968] = 1968,
  [1969] = 1969,
  [1970] = 1610,
  [1971] = 1971,
  [1972] = 1972,
  [1973] = 1611,
  [1974] = 1550,
  [1975] = 1632,
  [1976] = 1739,
  [1977] = 1562,
  [1978] = 1563,
  [1979] = 1535,
  [1980] = 1707,
  [1981] = 1549,
  [1982] = 1710,
  [1983] = 1588,
  [1984] = 1613,
  [1985] = 1614,
  [1986] = 1621,
  [1987] = 1624,
  [1988] = 1628,
  [1989] = 1629,
  [1990] = 1630,
  [1991] = 1631,
  [1992] = 1634,
  [1993] = 1638,
  [1994] = 1639,
  [1995] = 1640,
  [1996] = 1641,
  [1997] = 1166,
  [1998] = 1642,
  [1999] = 1644,
  [2000] = 1646,
  [2001] = 1627,
  [2002] = 2002,
  [2003] = 1801,
  [2004] = 1580,
  [2005] = 2005,
  [2006] = 1595,
  [2007] = 1598,
  [2008] = 1622,
  [2009] = 712,
  [2010] = 1540,
  [2011] = 1599,
  [2012] = 1623,
  [2013] = 1625,
  [2014] = 2014,
  [2015] = 1636,
  [2016] = 1530,
  [2017] = 1532,
  [2018] = 1533,
  [2019] = 1633,
  [2020] = 1531,
  [2021] = 1537,
  [2022] = 1538,
  [2023] = 1542,
  [2024] = 1543,
  [2025] = 1539,
  [2026] = 1546,
  [2027] = 2027,
  [2028] = 1962,
  [2029] = 1547,
  [2030] = 1647,
  [2031] = 1626,
  [2032] = 1551,
  [2033] = 1553,
  [2034] = 2002,
  [2035] = 1801,
  [2036] = 1557,
  [2037] = 1171,
  [2038] = 1559,
  [2039] = 1560,
  [2040] = 1561,
  [2041] = 1765,
  [2042] = 1592,
  [2043] = 1649,
  [2044] = 1552,
  [2045] = 1558,
  [2046] = 1867,
  [2047] = 1635,
  [2048] = 1529,
  [2049] = 713,
  [2050] = 1565,
  [2051] = 1566,
  [2052] = 1567,
  [2053] = 1568,
  [2054] = 1569,
  [2055] = 1570,
  [2056] = 1571,
  [2057] = 1572,
  [2058] = 1573,
  [2059] = 1575,
  [2060] = 1576,
  [2061] = 1577,
  [2062] = 1578,
  [2063] = 1545,
  [2064] = 1706,
  [2065] = 2065,
  [2066] = 2066,
  [2067] = 1548,
  [2068] = 2068,
  [2069] = 711,
  [2070] = 2070,
  [2071] = 2071,
  [2072] = 1583,
  [2073] = 1584,
  [2074] = 1651,
  [2075] = 1877,
  [2076] = 1585,
  [2077] = 1586,
  [2078] = 1587,
  [2079] = 1589,
  [2080] = 1739,
  [2081] = 1740,
  [2082] = 1741,
  [2083] = 1743,
  [2084] = 1744,
  [2085] = 1745,
  [2086] = 1746,
  [2087] = 1747,
  [2088] = 1748,
  [2089] = 1749,
  [2090] = 1779,
  [2091] = 1751,
  [2092] = 1752,
  [2093] = 1753,
  [2094] = 1754,
  [2095] = 1755,
  [2096] = 1756,
  [2097] = 1757,
  [2098] = 1758,
  [2099] = 1759,
  [2100] = 1760,
  [2101] = 1761,
  [2102] = 1762,
  [2103] = 1763,
  [2104] = 1764,
  [2105] = 1765,
  [2106] = 1776,
  [2107] = 1722,
  [2108] = 1778,
  [2109] = 1777,
  [2110] = 1594,
  [2111] = 2111,
  [2112] = 1531,
  [2113] = 1539,
  [2114] = 2114,
  [2115] = 1531,
  [2116] = 1539,
  [2117] = 2117,
  [2118] = 2118,
  [2119] = 2117,
  [2120] = 2118,
  [2121] = 2121,
  [2122] = 2117,
  [2123] = 2118,
  [2124] = 2124,
  [2125] = 2125,
  [2126] = 2126,
  [2127] = 2127,
  [2128] = 2128,
  [2129] = 2129,
  [2130] = 1655,
  [2131] = 1739,
  [2132] = 1740,
  [2133] = 1741,
  [2134] = 1677,
  [2135] = 2135,
  [2136] = 1743,
  [2137] = 2137,
  [2138] = 2138,
  [2139] = 1744,
  [2140] = 1745,
  [2141] = 1746,
  [2142] = 2142,
  [2143] = 1747,
  [2144] = 2144,
  [2145] = 1748,
  [2146] = 1749,
  [2147] = 1779,
  [2148] = 1751,
  [2149] = 1752,
  [2150] = 1753,
  [2151] = 1754,
  [2152] = 1755,
  [2153] = 1756,
  [2154] = 1757,
  [2155] = 1758,
  [2156] = 1759,
  [2157] = 2157,
  [2158] = 1760,
  [2159] = 1761,
  [2160] = 1762,
  [2161] = 1763,
  [2162] = 1764,
  [2163] = 220,
  [2164] = 224,
  [2165] = 222,
  [2166] = 2166,
  [2167] = 1765,
  [2168] = 223,
  [2169] = 2169,
  [2170] = 225,
  [2171] = 2171,
  [2172] = 2172,
  [2173] = 230,
  [2174] = 2174,
  [2175] = 1801,
  [2176] = 1670,
  [2177] = 2177,
  [2178] = 2178,
  [2179] = 2179,
  [2180] = 224,
  [2181] = 225,
  [2182] = 226,
  [2183] = 2183,
  [2184] = 209,
  [2185] = 220,
  [2186] = 222,
  [2187] = 223,
  [2188] = 2188,
  [2189] = 1667,
  [2190] = 227,
  [2191] = 228,
  [2192] = 232,
  [2193] = 1661,
  [2194] = 233,
  [2195] = 1668,
  [2196] = 2196,
  [2197] = 1679,
  [2198] = 1680,
  [2199] = 226,
  [2200] = 1681,
  [2201] = 1682,
  [2202] = 2202,
  [2203] = 2203,
  [2204] = 1683,
  [2205] = 2205,
  [2206] = 1684,
  [2207] = 1685,
  [2208] = 2142,
  [2209] = 1827,
  [2210] = 1686,
  [2211] = 1656,
  [2212] = 2142,
  [2213] = 1707,
  [2214] = 2169,
  [2215] = 2215,
  [2216] = 2216,
  [2217] = 2169,
  [2218] = 2172,
  [2219] = 2142,
  [2220] = 1669,
  [2221] = 1827,
  [2222] = 1687,
  [2223] = 2172,
  [2224] = 1794,
  [2225] = 2144,
  [2226] = 1707,
  [2227] = 2227,
  [2228] = 1657,
  [2229] = 1535,
  [2230] = 1663,
  [2231] = 2142,
  [2232] = 1549,
  [2233] = 1710,
  [2234] = 1664,
  [2235] = 2235,
  [2236] = 2236,
  [2237] = 2142,
  [2238] = 2142,
  [2239] = 1776,
  [2240] = 1722,
  [2241] = 1778,
  [2242] = 1777,
  [2243] = 2243,
  [2244] = 2244,
  [2245] = 1660,
  [2246] = 227,
  [2247] = 228,
  [2248] = 2248,
  [2249] = 2249,
  [2250] = 2166,
  [2251] = 1688,
  [2252] = 2252,
  [2253] = 2253,
  [2254] = 230,
  [2255] = 1671,
  [2256] = 1867,
  [2257] = 2257,
  [2258] = 1689,
  [2259] = 232,
  [2260] = 1690,
  [2261] = 2261,
  [2262] = 1672,
  [2263] = 2138,
  [2264] = 2236,
  [2265] = 1703,
  [2266] = 1653,
  [2267] = 1528,
  [2268] = 2268,
  [2269] = 2269,
  [2270] = 2270,
  [2271] = 1710,
  [2272] = 2272,
  [2273] = 2273,
  [2274] = 2274,
  [2275] = 2174,
  [2276] = 2177,
  [2277] = 1673,
  [2278] = 1867,
  [2279] = 1704,
  [2280] = 1658,
  [2281] = 1691,
  [2282] = 1692,
  [2283] = 1693,
  [2284] = 1694,
  [2285] = 2285,
  [2286] = 1674,
  [2287] = 2287,
  [2288] = 2288,
  [2289] = 2289,
  [2290] = 2269,
  [2291] = 2291,
  [2292] = 2292,
  [2293] = 2293,
  [2294] = 2294,
  [2295] = 2295,
  [2296] = 2296,
  [2297] = 2270,
  [2298] = 2298,
  [2299] = 1867,
  [2300] = 2300,
  [2301] = 2126,
  [2302] = 2302,
  [2303] = 2303,
  [2304] = 1695,
  [2305] = 2305,
  [2306] = 2306,
  [2307] = 2307,
  [2308] = 2308,
  [2309] = 233,
  [2310] = 1675,
  [2311] = 2227,
  [2312] = 2312,
  [2313] = 2313,
  [2314] = 2314,
  [2315] = 2315,
  [2316] = 1787,
  [2317] = 1659,
  [2318] = 1665,
  [2319] = 1697,
  [2320] = 1676,
  [2321] = 2169,
  [2322] = 2172,
  [2323] = 1698,
  [2324] = 1699,
  [2325] = 1700,
  [2326] = 1701,
  [2327] = 1702,
  [2328] = 2328,
  [2329] = 2272,
  [2330] = 2273,
  [2331] = 2331,
  [2332] = 2169,
  [2333] = 1666,
  [2334] = 2172,
  [2335] = 2274,
  [2336] = 2124,
  [2337] = 2292,
  [2338] = 1707,
  [2339] = 1710,
  [2340] = 2340,
  [2341] = 2341,
  [2342] = 1654,
  [2343] = 2343,
  [2344] = 2169,
  [2345] = 209,
  [2346] = 2172,
  [2347] = 2117,
  [2348] = 2118,
  [2349] = 2314,
  [2350] = 1588,
  [2351] = 1647,
  [2352] = 2352,
  [2353] = 1894,
  [2354] = 2117,
  [2355] = 2118,
  [2356] = 1528,
  [2357] = 2357,
  [2358] = 1652,
  [2359] = 2312,
  [2360] = 1755,
  [2361] = 1756,
  [2362] = 1757,
  [2363] = 1758,
  [2364] = 1759,
  [2365] = 1760,
  [2366] = 1761,
  [2367] = 1762,
  [2368] = 1763,
  [2369] = 1764,
  [2370] = 2370,
  [2371] = 2371,
  [2372] = 1588,
  [2373] = 1765,
  [2374] = 2374,
  [2375] = 2375,
  [2376] = 1588,
  [2377] = 2377,
  [2378] = 2374,
  [2379] = 2379,
  [2380] = 2380,
  [2381] = 1647,
  [2382] = 1647,
  [2383] = 2383,
  [2384] = 2384,
  [2385] = 1827,
  [2386] = 1894,
  [2387] = 1739,
  [2388] = 1740,
  [2389] = 1741,
  [2390] = 1743,
  [2391] = 1744,
  [2392] = 1745,
  [2393] = 1746,
  [2394] = 1747,
  [2395] = 1748,
  [2396] = 1749,
  [2397] = 2397,
  [2398] = 2398,
  [2399] = 1779,
  [2400] = 1751,
  [2401] = 2401,
  [2402] = 1752,
  [2403] = 1753,
  [2404] = 1776,
  [2405] = 1722,
  [2406] = 1778,
  [2407] = 1777,
  [2408] = 1754,
  [2409] = 1755,
  [2410] = 1756,
  [2411] = 2411,
  [2412] = 1757,
  [2413] = 1758,
  [2414] = 1776,
  [2415] = 1722,
  [2416] = 1778,
  [2417] = 1777,
  [2418] = 1759,
  [2419] = 1760,
  [2420] = 1761,
  [2421] = 1762,
  [2422] = 1813,
  [2423] = 1763,
  [2424] = 1764,
  [2425] = 2425,
  [2426] = 1765,
  [2427] = 1894,
  [2428] = 2383,
  [2429] = 2429,
  [2430] = 1531,
  [2431] = 2431,
  [2432] = 1705,
  [2433] = 2433,
  [2434] = 2434,
  [2435] = 2435,
  [2436] = 1706,
  [2437] = 2437,
  [2438] = 2374,
  [2439] = 2439,
  [2440] = 2440,
  [2441] = 2377,
  [2442] = 1539,
  [2443] = 2443,
  [2444] = 2444,
  [2445] = 2374,
  [2446] = 1753,
  [2447] = 1754,
  [2448] = 1651,
  [2449] = 1787,
  [2450] = 2439,
  [2451] = 2451,
  [2452] = 2440,
  [2453] = 214,
  [2454] = 2435,
  [2455] = 2455,
  [2456] = 1867,
  [2457] = 2374,
  [2458] = 1739,
  [2459] = 2444,
  [2460] = 1867,
  [2461] = 2461,
  [2462] = 1535,
  [2463] = 2463,
  [2464] = 1549,
  [2465] = 1740,
  [2466] = 2466,
  [2467] = 1794,
  [2468] = 1741,
  [2469] = 1743,
  [2470] = 1670,
  [2471] = 1744,
  [2472] = 1528,
  [2473] = 2374,
  [2474] = 1745,
  [2475] = 2443,
  [2476] = 1707,
  [2477] = 1670,
  [2478] = 2478,
  [2479] = 1746,
  [2480] = 1710,
  [2481] = 1747,
  [2482] = 1748,
  [2483] = 1749,
  [2484] = 1739,
  [2485] = 1740,
  [2486] = 1741,
  [2487] = 1743,
  [2488] = 1744,
  [2489] = 1745,
  [2490] = 1746,
  [2491] = 1747,
  [2492] = 1748,
  [2493] = 1749,
  [2494] = 1779,
  [2495] = 1751,
  [2496] = 1752,
  [2497] = 1753,
  [2498] = 1754,
  [2499] = 1755,
  [2500] = 1756,
  [2501] = 1757,
  [2502] = 1758,
  [2503] = 1759,
  [2504] = 1760,
  [2505] = 1761,
  [2506] = 1762,
  [2507] = 1763,
  [2508] = 1764,
  [2509] = 1765,
  [2510] = 2510,
  [2511] = 1706,
  [2512] = 1779,
  [2513] = 214,
  [2514] = 1776,
  [2515] = 1722,
  [2516] = 1778,
  [2517] = 1777,
  [2518] = 1751,
  [2519] = 1752,
  [2520] = 2520,
  [2521] = 1867,
  [2522] = 1528,
  [2523] = 1867,
  [2524] = 2524,
  [2525] = 991,
  [2526] = 2526,
  [2527] = 1739,
  [2528] = 1740,
  [2529] = 1743,
  [2530] = 1744,
  [2531] = 1745,
  [2532] = 1746,
  [2533] = 1747,
  [2534] = 1748,
  [2535] = 1749,
  [2536] = 1779,
  [2537] = 1751,
  [2538] = 1752,
  [2539] = 1753,
  [2540] = 1754,
  [2541] = 1755,
  [2542] = 1756,
  [2543] = 1757,
  [2544] = 1758,
  [2545] = 1759,
  [2546] = 1760,
  [2547] = 1761,
  [2548] = 1762,
  [2549] = 1763,
  [2550] = 1764,
  [2551] = 1765,
  [2552] = 1894,
  [2553] = 2553,
  [2554] = 2554,
  [2555] = 2555,
  [2556] = 2556,
  [2557] = 1670,
  [2558] = 1705,
  [2559] = 1706,
  [2560] = 1651,
  [2561] = 988,
  [2562] = 1787,
  [2563] = 992,
  [2564] = 1670,
  [2565] = 1588,
  [2566] = 1647,
  [2567] = 1707,
  [2568] = 1710,
  [2569] = 2569,
  [2570] = 2570,
  [2571] = 1867,
  [2572] = 2572,
  [2573] = 2573,
  [2574] = 2574,
  [2575] = 2575,
  [2576] = 2576,
  [2577] = 1776,
  [2578] = 1722,
  [2579] = 1778,
  [2580] = 1777,
  [2581] = 2581,
  [2582] = 2582,
  [2583] = 2583,
  [2584] = 2584,
  [2585] = 2585,
  [2586] = 2586,
  [2587] = 2572,
  [2588] = 2572,
  [2589] = 2572,
  [2590] = 2572,
  [2591] = 2553,
  [2592] = 2572,
  [2593] = 2593,
  [2594] = 2594,
  [2595] = 2572,
  [2596] = 2596,
  [2597] = 2597,
  [2598] = 2598,
  [2599] = 1528,
  [2600] = 2600,
  [2601] = 2572,
  [2602] = 2602,
  [2603] = 2603,
  [2604] = 2572,
  [2605] = 2605,
  [2606] = 2572,
  [2607] = 2607,
  [2608] = 1741,
  [2609] = 2118,
  [2610] = 2610,
  [2611] = 2611,
  [2612] = 2612,
  [2613] = 2117,
  [2614] = 2118,
  [2615] = 2117,
  [2616] = 2118,
  [2617] = 2117,
  [2618] = 2118,
  [2619] = 2619,
  [2620] = 2117,
  [2621] = 2621,
  [2622] = 2433,
  [2623] = 2623,
  [2624] = 2624,
  [2625] = 2625,
  [2626] = 2117,
  [2627] = 2117,
  [2628] = 2118,
  [2629] = 2118,
  [2630] = 2630,
  [2631] = 2631,
  [2632] = 2632,
  [2633] = 2633,
  [2634] = 2634,
  [2635] = 2635,
  [2636] = 2636,
  [2637] = 2637,
  [2638] = 1827,
  [2639] = 2639,
  [2640] = 2640,
  [2641] = 2641,
  [2642] = 1528,
  [2643] = 1528,
  [2644] = 2611,
  [2645] = 2645,
  [2646] = 1528,
  [2647] = 2647,
  [2648] = 236,
  [2649] = 2649,
  [2650] = 2650,
  [2651] = 2651,
  [2652] = 2652,
  [2653] = 2653,
  [2654] = 2654,
  [2655] = 2655,
  [2656] = 2656,
  [2657] = 2657,
  [2658] = 2658,
  [2659] = 2659,
  [2660] = 2660,
  [2661] = 2661,
  [2662] = 2662,
  [2663] = 2663,
  [2664] = 2664,
  [2665] = 2665,
  [2666] = 2666,
  [2667] = 2652,
  [2668] = 2668,
  [2669] = 2669,
  [2670] = 2670,
  [2671] = 2671,
  [2672] = 2672,
  [2673] = 2673,
  [2674] = 2674,
  [2675] = 2652,
  [2676] = 2652,
  [2677] = 2652,
  [2678] = 235,
  [2679] = 2679,
  [2680] = 2680,
  [2681] = 212,
  [2682] = 2652,
  [2683] = 2683,
  [2684] = 210,
  [2685] = 2685,
  [2686] = 2652,
  [2687] = 2687,
  [2688] = 2688,
  [2689] = 2652,
  [2690] = 2690,
  [2691] = 2691,
  [2692] = 2692,
  [2693] = 2693,
  [2694] = 1648,
  [2695] = 2695,
  [2696] = 2696,
  [2697] = 212,
  [2698] = 236,
  [2699] = 2699,
  [2700] = 2700,
  [2701] = 2701,
  [2702] = 2702,
  [2703] = 2703,
  [2704] = 2704,
  [2705] = 2705,
  [2706] = 2652,
  [2707] = 2707,
  [2708] = 2708,
  [2709] = 2652,
  [2710] = 2710,
  [2711] = 1246,
  [2712] = 2712,
  [2713] = 2554,
  [2714] = 2555,
  [2715] = 235,
  [2716] = 2716,
  [2717] = 2717,
  [2718] = 2718,
  [2719] = 1633,
  [2720] = 2720,
  [2721] = 2721,
  [2722] = 2722,
  [2723] = 210,
  [2724] = 2724,
  [2725] = 2725,
  [2726] = 2726,
  [2727] = 2727,
  [2728] = 2728,
  [2729] = 1272,
  [2730] = 2196,
  [2731] = 2731,
  [2732] = 2732,
  [2733] = 2340,
  [2734] = 2114,
  [2735] = 2735,
  [2736] = 2736,
  [2737] = 2252,
  [2738] = 2738,
  [2739] = 2380,
  [2740] = 2461,
  [2741] = 2524,
  [2742] = 2443,
  [2743] = 2443,
  [2744] = 2463,
  [2745] = 2375,
  [2746] = 2444,
  [2747] = 2383,
  [2748] = 2461,
  [2749] = 2434,
  [2750] = 2750,
  [2751] = 2444,
  [2752] = 2752,
  [2753] = 2524,
  [2754] = 2520,
  [2755] = 2520,
  [2756] = 2455,
  [2757] = 2757,
  [2758] = 2758,
  [2759] = 2455,
  [2760] = 2757,
  [2761] = 1269,
  [2762] = 2510,
  [2763] = 2750,
  [2764] = 2440,
  [2765] = 2440,
  [2766] = 2766,
  [2767] = 2767,
  [2768] = 2383,
  [2769] = 2769,
  [2770] = 2770,
  [2771] = 2771,
  [2772] = 2769,
  [2773] = 2773,
  [2774] = 2774,
  [2775] = 2775,
  [2776] = 2776,
  [2777] = 2775,
  [2778] = 2776,
  [2779] = 2779,
  [2780] = 2780,
  [2781] = 2781,
  [2782] = 2779,
  [2783] = 2780,
  [2784] = 2784,
  [2785] = 2784,
  [2786] = 2786,
  [2787] = 2770,
  [2788] = 2770,
  [2789] = 2789,
  [2790] = 1287,
  [2791] = 2791,
  [2792] = 2792,
  [2793] = 2793,
  [2794] = 2794,
  [2795] = 2795,
  [2796] = 2796,
  [2797] = 2797,
  [2798] = 2798,
  [2799] = 2799,
  [2800] = 2800,
  [2801] = 2801,
  [2802] = 1344,
  [2803] = 2803,
  [2804] = 1332,
  [2805] = 2805,
  [2806] = 1317,
  [2807] = 2807,
  [2808] = 2808,
  [2809] = 2809,
  [2810] = 1288,
  [2811] = 2811,
  [2812] = 2451,
  [2813] = 2813,
  [2814] = 2814,
  [2815] = 2815,
  [2816] = 2816,
  [2817] = 2817,
  [2818] = 2818,
  [2819] = 2819,
  [2820] = 2820,
  [2821] = 2821,
  [2822] = 2822,
  [2823] = 2823,
  [2824] = 2824,
  [2825] = 2825,
  [2826] = 2826,
  [2827] = 2827,
  [2828] = 2825,
  [2829] = 2829,
  [2830] = 2830,
  [2831] = 2831,
  [2832] = 2832,
  [2833] = 2833,
  [2834] = 2834,
  [2835] = 2835,
  [2836] = 2831,
  [2837] = 2817,
  [2838] = 2838,
  [2839] = 2839,
  [2840] = 2839,
  [2841] = 2841,
  [2842] = 2838,
  [2843] = 2843,
  [2844] = 2827,
  [2845] = 2845,
  [2846] = 2841,
  [2847] = 2847,
  [2848] = 2848,
  [2849] = 2849,
  [2850] = 2850,
  [2851] = 2851,
  [2852] = 2852,
  [2853] = 2853,
  [2854] = 2854,
  [2855] = 2845,
  [2856] = 2856,
  [2857] = 2857,
  [2858] = 2858,
  [2859] = 2859,
  [2860] = 2835,
  [2861] = 2832,
  [2862] = 2862,
  [2863] = 2863,
  [2864] = 2864,
  [2865] = 2865,
  [2866] = 2866,
  [2867] = 2834,
  [2868] = 2868,
  [2869] = 2822,
  [2870] = 2870,
  [2871] = 2871,
  [2872] = 2872,
  [2873] = 2873,
  [2874] = 2874,
  [2875] = 2875,
  [2876] = 1509,
  [2877] = 1506,
  [2878] = 1504,
  [2879] = 1623,
  [2880] = 1587,
  [2881] = 1591,
  [2882] = 1597,
  [2883] = 1572,
  [2884] = 1570,
  [2885] = 1573,
  [2886] = 1575,
  [2887] = 1571,
  [2888] = 1583,
  [2889] = 1540,
  [2890] = 1599,
  [2891] = 1585,
  [2892] = 1625,
  [2893] = 1584,
  [2894] = 1596,
  [2895] = 1530,
  [2896] = 1532,
  [2897] = 1533,
  [2898] = 1589,
  [2899] = 1537,
  [2900] = 1538,
  [2901] = 1542,
  [2902] = 1565,
  [2903] = 1566,
  [2904] = 1567,
  [2905] = 1543,
  [2906] = 1568,
  [2907] = 1546,
  [2908] = 1547,
  [2909] = 1569,
  [2910] = 1650,
  [2911] = 1586,
  [2912] = 1636,
  [2913] = 213,
  [2914] = 219,
  [2915] = 1639,
  [2916] = 1550,
  [2917] = 1602,
  [2918] = 1604,
  [2919] = 1641,
  [2920] = 1610,
  [2921] = 2921,
  [2922] = 1562,
  [2923] = 1512,
  [2924] = 1624,
  [2925] = 1504,
  [2926] = 1628,
  [2927] = 1629,
  [2928] = 1638,
  [2929] = 1630,
  [2930] = 1640,
  [2931] = 1509,
  [2932] = 1505,
  [2933] = 1506,
  [2934] = 1548,
  [2935] = 1522,
  [2936] = 1529,
  [2937] = 1514,
  [2938] = 1574,
  [2939] = 1527,
  [2940] = 1516,
  [2941] = 1589,
  [2942] = 2942,
  [2943] = 1568,
  [2944] = 2944,
  [2945] = 2945,
  [2946] = 1569,
  [2947] = 1553,
  [2948] = 2948,
  [2949] = 1649,
  [2950] = 1636,
  [2951] = 1506,
  [2952] = 1530,
  [2953] = 1532,
  [2954] = 1533,
  [2955] = 1577,
  [2956] = 1583,
  [2957] = 1551,
  [2958] = 1584,
  [2959] = 1585,
  [2960] = 1599,
  [2961] = 1586,
  [2962] = 1600,
  [2963] = 1587,
  [2964] = 1626,
  [2965] = 1591,
  [2966] = 1650,
  [2967] = 1596,
  [2968] = 2942,
  [2969] = 1597,
  [2970] = 1620,
  [2971] = 1558,
  [2972] = 1578,
  [2973] = 1611,
  [2974] = 2948,
  [2975] = 1609,
  [2976] = 1646,
  [2977] = 2942,
  [2978] = 1637,
  [2979] = 2979,
  [2980] = 2979,
  [2981] = 1554,
  [2982] = 2944,
  [2983] = 1570,
  [2984] = 2944,
  [2985] = 2945,
  [2986] = 2979,
  [2987] = 1540,
  [2988] = 1598,
  [2989] = 1571,
  [2990] = 1572,
  [2991] = 1580,
  [2992] = 1576,
  [2993] = 1567,
  [2994] = 1632,
  [2995] = 1565,
  [2996] = 2948,
  [2997] = 1573,
  [2998] = 1559,
  [2999] = 1613,
  [3000] = 2942,
  [3001] = 1614,
  [3002] = 2944,
  [3003] = 2979,
  [3004] = 2979,
  [3005] = 1623,
  [3006] = 2945,
  [3007] = 1544,
  [3008] = 2945,
  [3009] = 2979,
  [3010] = 1563,
  [3011] = 1621,
  [3012] = 1625,
  [3013] = 2979,
  [3014] = 1537,
  [3015] = 1603,
  [3016] = 1505,
  [3017] = 1538,
  [3018] = 1560,
  [3019] = 1594,
  [3020] = 2979,
  [3021] = 1642,
  [3022] = 1575,
  [3023] = 1631,
  [3024] = 1635,
  [3025] = 2979,
  [3026] = 1504,
  [3027] = 1542,
  [3028] = 1543,
  [3029] = 2979,
  [3030] = 1545,
  [3031] = 1546,
  [3032] = 2948,
  [3033] = 1547,
  [3034] = 2948,
  [3035] = 2942,
  [3036] = 2944,
  [3037] = 1509,
  [3038] = 1566,
  [3039] = 1556,
  [3040] = 2945,
  [3041] = 1536,
  [3042] = 1622,
  [3043] = 3043,
  [3044] = 3044,
  [3045] = 3045,
  [3046] = 3046,
  [3047] = 3047,
  [3048] = 3048,
  [3049] = 3047,
  [3050] = 3048,
  [3051] = 3048,
  [3052] = 3048,
  [3053] = 3047,
  [3054] = 1523,
  [3055] = 3047,
  [3056] = 1524,
  [3057] = 3057,
  [3058] = 3058,
  [3059] = 1525,
  [3060] = 3060,
  [3061] = 3047,
  [3062] = 3062,
  [3063] = 3063,
  [3064] = 3064,
  [3065] = 3065,
  [3066] = 3066,
  [3067] = 3067,
  [3068] = 3048,
  [3069] = 3069,
  [3070] = 3070,
  [3071] = 3071,
  [3072] = 3072,
  [3073] = 3073,
  [3074] = 3074,
  [3075] = 3047,
  [3076] = 1514,
  [3077] = 1512,
  [3078] = 3047,
  [3079] = 3079,
  [3080] = 3080,
  [3081] = 3081,
  [3082] = 3082,
  [3083] = 3083,
  [3084] = 1538,
  [3085] = 3085,
  [3086] = 1602,
  [3087] = 3087,
  [3088] = 988,
  [3089] = 1604,
  [3090] = 1610,
  [3091] = 1624,
  [3092] = 1628,
  [3093] = 1629,
  [3094] = 991,
  [3095] = 1634,
  [3096] = 1644,
  [3097] = 3097,
  [3098] = 3098,
  [3099] = 992,
  [3100] = 1630,
  [3101] = 1638,
  [3102] = 1639,
  [3103] = 1640,
  [3104] = 1641,
  [3105] = 3105,
  [3106] = 1552,
  [3107] = 1540,
  [3108] = 1599,
  [3109] = 1623,
  [3110] = 1625,
  [3111] = 3111,
  [3112] = 1636,
  [3113] = 1530,
  [3114] = 1532,
  [3115] = 1533,
  [3116] = 1537,
  [3117] = 1542,
  [3118] = 1543,
  [3119] = 1546,
  [3120] = 1547,
  [3121] = 1565,
  [3122] = 1566,
  [3123] = 1567,
  [3124] = 1562,
  [3125] = 1569,
  [3126] = 1570,
  [3127] = 1571,
  [3128] = 1572,
  [3129] = 1505,
  [3130] = 1573,
  [3131] = 1575,
  [3132] = 1583,
  [3133] = 1584,
  [3134] = 1585,
  [3135] = 3135,
  [3136] = 1586,
  [3137] = 1587,
  [3138] = 1589,
  [3139] = 1591,
  [3140] = 1650,
  [3141] = 1596,
  [3142] = 1597,
  [3143] = 3143,
  [3144] = 3144,
  [3145] = 1557,
  [3146] = 1561,
  [3147] = 3147,
  [3148] = 1643,
  [3149] = 1645,
  [3150] = 1595,
  [3151] = 1527,
  [3152] = 3152,
  [3153] = 1592,
  [3154] = 1605,
  [3155] = 1550,
  [3156] = 1568,
  [3157] = 3157,
  [3158] = 1512,
  [3159] = 3159,
  [3160] = 3160,
  [3161] = 3161,
  [3162] = 3162,
  [3163] = 3163,
  [3164] = 3164,
  [3165] = 1170,
  [3166] = 1525,
  [3167] = 3167,
  [3168] = 1548,
  [3169] = 3169,
  [3170] = 3170,
  [3171] = 3171,
  [3172] = 3172,
  [3173] = 3173,
  [3174] = 3174,
  [3175] = 3167,
  [3176] = 3176,
  [3177] = 3177,
  [3178] = 3178,
  [3179] = 1166,
  [3180] = 3180,
  [3181] = 1514,
  [3182] = 3182,
  [3183] = 3183,
  [3184] = 3167,
  [3185] = 3185,
  [3186] = 3167,
  [3187] = 3187,
  [3188] = 3188,
  [3189] = 3189,
  [3190] = 3190,
  [3191] = 3191,
  [3192] = 3192,
  [3193] = 1522,
  [3194] = 3194,
  [3195] = 3195,
  [3196] = 1504,
  [3197] = 1509,
  [3198] = 1506,
  [3199] = 3199,
  [3200] = 1574,
  [3201] = 1171,
  [3202] = 3202,
  [3203] = 3203,
  [3204] = 1516,
  [3205] = 3205,
  [3206] = 1529,
  [3207] = 1523,
  [3208] = 3208,
  [3209] = 3209,
  [3210] = 3210,
  [3211] = 3211,
  [3212] = 1524,
  [3213] = 3213,
  [3214] = 3167,
  [3215] = 1603,
  [3216] = 1649,
  [3217] = 1545,
  [3218] = 713,
  [3219] = 1552,
  [3220] = 1550,
  [3221] = 1562,
  [3222] = 1592,
  [3223] = 988,
  [3224] = 1602,
  [3225] = 1604,
  [3226] = 1610,
  [3227] = 3227,
  [3228] = 1624,
  [3229] = 1631,
  [3230] = 1628,
  [3231] = 1629,
  [3232] = 1576,
  [3233] = 1630,
  [3234] = 1638,
  [3235] = 1639,
  [3236] = 1640,
  [3237] = 1641,
  [3238] = 991,
  [3239] = 1577,
  [3240] = 1578,
  [3241] = 711,
  [3242] = 1634,
  [3243] = 1600,
  [3244] = 1605,
  [3245] = 715,
  [3246] = 1642,
  [3247] = 992,
  [3248] = 1644,
  [3249] = 1646,
  [3250] = 1626,
  [3251] = 1645,
  [3252] = 712,
  [3253] = 3253,
  [3254] = 1558,
  [3255] = 1609,
  [3256] = 3256,
  [3257] = 1611,
  [3258] = 1613,
  [3259] = 1551,
  [3260] = 1614,
  [3261] = 1553,
  [3262] = 1505,
  [3263] = 1621,
  [3264] = 1620,
  [3265] = 1632,
  [3266] = 1635,
  [3267] = 1557,
  [3268] = 3174,
  [3269] = 1559,
  [3270] = 1560,
  [3271] = 1544,
  [3272] = 1554,
  [3273] = 1556,
  [3274] = 1536,
  [3275] = 1561,
  [3276] = 1643,
  [3277] = 714,
  [3278] = 1527,
  [3279] = 3279,
  [3280] = 1563,
  [3281] = 1580,
  [3282] = 1594,
  [3283] = 1595,
  [3284] = 1598,
  [3285] = 1622,
  [3286] = 1637,
  [3287] = 1522,
  [3288] = 1525,
  [3289] = 1548,
  [3290] = 3290,
  [3291] = 3291,
  [3292] = 3292,
  [3293] = 3291,
  [3294] = 3294,
  [3295] = 3295,
  [3296] = 3296,
  [3297] = 3290,
  [3298] = 3298,
  [3299] = 3299,
  [3300] = 3290,
  [3301] = 1523,
  [3302] = 3302,
  [3303] = 1514,
  [3304] = 3304,
  [3305] = 1524,
  [3306] = 1505,
  [3307] = 3307,
  [3308] = 3291,
  [3309] = 1516,
  [3310] = 3294,
  [3311] = 1574,
  [3312] = 3312,
  [3313] = 3313,
  [3314] = 3314,
  [3315] = 3315,
  [3316] = 3298,
  [3317] = 1529,
  [3318] = 3318,
  [3319] = 1626,
  [3320] = 3320,
  [3321] = 3321,
  [3322] = 1613,
  [3323] = 3323,
  [3324] = 3324,
  [3325] = 1614,
  [3326] = 3326,
  [3327] = 1576,
  [3328] = 1577,
  [3329] = 1578,
  [3330] = 3315,
  [3331] = 711,
  [3332] = 1621,
  [3333] = 3333,
  [3334] = 3334,
  [3335] = 1592,
  [3336] = 1637,
  [3337] = 714,
  [3338] = 1649,
  [3339] = 1552,
  [3340] = 3302,
  [3341] = 3341,
  [3342] = 3342,
  [3343] = 3343,
  [3344] = 1600,
  [3345] = 1605,
  [3346] = 213,
  [3347] = 1558,
  [3348] = 3348,
  [3349] = 3349,
  [3350] = 3350,
  [3351] = 1170,
  [3352] = 219,
  [3353] = 3167,
  [3354] = 1645,
  [3355] = 1631,
  [3356] = 1634,
  [3357] = 1166,
  [3358] = 3358,
  [3359] = 1171,
  [3360] = 3360,
  [3361] = 3304,
  [3362] = 3362,
  [3363] = 1545,
  [3364] = 3167,
  [3365] = 3365,
  [3366] = 3366,
  [3367] = 3367,
  [3368] = 3368,
  [3369] = 3369,
  [3370] = 3167,
  [3371] = 3371,
  [3372] = 1166,
  [3373] = 1642,
  [3374] = 3167,
  [3375] = 1644,
  [3376] = 3376,
  [3377] = 3377,
  [3378] = 1646,
  [3379] = 3379,
  [3380] = 3380,
  [3381] = 3381,
  [3382] = 1170,
  [3383] = 1563,
  [3384] = 1643,
  [3385] = 3385,
  [3386] = 712,
  [3387] = 3387,
  [3388] = 1514,
  [3389] = 3349,
  [3390] = 715,
  [3391] = 3391,
  [3392] = 3392,
  [3393] = 3393,
  [3394] = 3394,
  [3395] = 3341,
  [3396] = 3396,
  [3397] = 3397,
  [3398] = 1622,
  [3399] = 3399,
  [3400] = 3400,
  [3401] = 1603,
  [3402] = 3402,
  [3403] = 3403,
  [3404] = 3404,
  [3405] = 3405,
  [3406] = 1594,
  [3407] = 3381,
  [3408] = 3408,
  [3409] = 3409,
  [3410] = 3410,
  [3411] = 3341,
  [3412] = 1512,
  [3413] = 3413,
  [3414] = 3414,
  [3415] = 3415,
  [3416] = 3416,
  [3417] = 3167,
  [3418] = 3418,
  [3419] = 3419,
  [3420] = 1609,
  [3421] = 3416,
  [3422] = 3422,
  [3423] = 3423,
  [3424] = 3413,
  [3425] = 3425,
  [3426] = 3426,
  [3427] = 3167,
  [3428] = 3428,
  [3429] = 3429,
  [3430] = 1551,
  [3431] = 1620,
  [3432] = 1553,
  [3433] = 1557,
  [3434] = 3349,
  [3435] = 3365,
  [3436] = 1595,
  [3437] = 1632,
  [3438] = 3362,
  [3439] = 1635,
  [3440] = 3440,
  [3441] = 3404,
  [3442] = 3442,
  [3443] = 1171,
  [3444] = 1559,
  [3445] = 1560,
  [3446] = 3446,
  [3447] = 1561,
  [3448] = 1544,
  [3449] = 3449,
  [3450] = 1554,
  [3451] = 3451,
  [3452] = 3452,
  [3453] = 1556,
  [3454] = 1536,
  [3455] = 1598,
  [3456] = 713,
  [3457] = 1611,
  [3458] = 3458,
  [3459] = 3459,
  [3460] = 3460,
  [3461] = 3461,
  [3462] = 3462,
  [3463] = 1580,
  [3464] = 3464,
  [3465] = 3465,
  [3466] = 3466,
  [3467] = 3467,
  [3468] = 3468,
  [3469] = 3469,
  [3470] = 3470,
  [3471] = 3174,
  [3472] = 3472,
  [3473] = 3473,
  [3474] = 3472,
  [3475] = 3473,
  [3476] = 3473,
  [3477] = 3473,
  [3478] = 3473,
  [3479] = 3473,
  [3480] = 3469,
  [3481] = 3472,
  [3482] = 213,
  [3483] = 219,
  [3484] = 3473,
  [3485] = 3485,
  [3486] = 3472,
  [3487] = 1527,
  [3488] = 3488,
  [3489] = 991,
  [3490] = 992,
  [3491] = 3491,
  [3492] = 3492,
  [3493] = 1523,
  [3494] = 1524,
  [3495] = 3495,
  [3496] = 3472,
  [3497] = 3497,
  [3498] = 3498,
  [3499] = 200,
  [3500] = 201,
  [3501] = 3473,
  [3502] = 3302,
  [3503] = 1525,
  [3504] = 3472,
  [3505] = 3505,
  [3506] = 988,
  [3507] = 3507,
  [3508] = 3508,
  [3509] = 3509,
  [3510] = 3510,
  [3511] = 3511,
  [3512] = 3512,
  [3513] = 3513,
  [3514] = 3514,
  [3515] = 3515,
  [3516] = 3516,
  [3517] = 3517,
  [3518] = 3518,
  [3519] = 3519,
  [3520] = 3520,
  [3521] = 3521,
  [3522] = 3522,
  [3523] = 3523,
  [3524] = 3524,
  [3525] = 3299,
  [3526] = 3526,
  [3527] = 3527,
  [3528] = 3528,
  [3529] = 3529,
  [3530] = 3530,
  [3531] = 3531,
  [3532] = 3532,
  [3533] = 3533,
  [3534] = 3534,
  [3535] = 3535,
  [3536] = 3536,
  [3537] = 3537,
  [3538] = 3538,
  [3539] = 3539,
  [3540] = 3540,
  [3541] = 3541,
  [3542] = 1605,
  [3543] = 3508,
  [3544] = 3544,
  [3545] = 3545,
  [3546] = 3540,
  [3547] = 3547,
  [3548] = 3548,
  [3549] = 1525,
  [3550] = 3550,
  [3551] = 3551,
  [3552] = 3552,
  [3553] = 3553,
  [3554] = 3554,
  [3555] = 3555,
  [3556] = 3556,
  [3557] = 3557,
  [3558] = 3558,
  [3559] = 3559,
  [3560] = 3560,
  [3561] = 3561,
  [3562] = 3562,
  [3563] = 3508,
  [3564] = 3564,
  [3565] = 3565,
  [3566] = 3566,
  [3567] = 3567,
  [3568] = 3568,
  [3569] = 3569,
  [3570] = 3508,
  [3571] = 3571,
  [3572] = 3540,
  [3573] = 3573,
  [3574] = 3508,
  [3575] = 3540,
  [3576] = 3576,
  [3577] = 3577,
  [3578] = 3578,
  [3579] = 3579,
  [3580] = 3580,
  [3581] = 3555,
  [3582] = 3582,
  [3583] = 3583,
  [3584] = 3584,
  [3585] = 3585,
  [3586] = 3586,
  [3587] = 3366,
  [3588] = 3588,
  [3589] = 3589,
  [3590] = 3590,
  [3591] = 3591,
  [3592] = 3592,
  [3593] = 3508,
  [3594] = 3594,
  [3595] = 3595,
  [3596] = 3595,
  [3597] = 3597,
  [3598] = 3598,
  [3599] = 3540,
  [3600] = 3577,
  [3601] = 3601,
  [3602] = 3602,
  [3603] = 3603,
  [3604] = 3604,
  [3605] = 3605,
  [3606] = 3606,
  [3607] = 3607,
  [3608] = 3608,
  [3609] = 3540,
  [3610] = 3605,
  [3611] = 3611,
  [3612] = 3612,
  [3613] = 3613,
  [3614] = 3371,
  [3615] = 3615,
  [3616] = 3545,
  [3617] = 3617,
  [3618] = 3618,
  [3619] = 3619,
  [3620] = 3620,
  [3621] = 3594,
  [3622] = 3622,
  [3623] = 3623,
  [3624] = 3624,
  [3625] = 3625,
  [3626] = 3626,
  [3627] = 3627,
  [3628] = 3628,
  [3629] = 3629,
  [3630] = 3630,
  [3631] = 3631,
  [3632] = 3632,
  [3633] = 3633,
  [3634] = 3634,
  [3635] = 3635,
  [3636] = 3636,
  [3637] = 3637,
  [3638] = 3507,
  [3639] = 3636,
  [3640] = 3640,
  [3641] = 3641,
  [3642] = 3642,
  [3643] = 3643,
  [3644] = 3377,
  [3645] = 3619,
  [3646] = 3646,
  [3647] = 3647,
  [3648] = 3648,
  [3649] = 3649,
  [3650] = 3634,
  [3651] = 3651,
  [3652] = 3652,
  [3653] = 3653,
  [3654] = 3654,
  [3655] = 3655,
  [3656] = 3656,
  [3657] = 3657,
  [3658] = 3658,
  [3659] = 3659,
  [3660] = 1595,
  [3661] = 1592,
  [3662] = 1552,
  [3663] = 3508,
  [3664] = 3664,
  [3665] = 3665,
  [3666] = 3666,
  [3667] = 3410,
  [3668] = 3668,
  [3669] = 3669,
  [3670] = 3670,
  [3671] = 3671,
  [3672] = 3672,
  [3673] = 3673,
  [3674] = 3674,
  [3675] = 3545,
  [3676] = 3643,
  [3677] = 3652,
  [3678] = 3678,
  [3679] = 3679,
  [3680] = 3532,
  [3681] = 3681,
  [3682] = 3682,
  [3683] = 3683,
  [3684] = 3684,
  [3685] = 3666,
  [3686] = 3686,
  [3687] = 3687,
  [3688] = 3688,
  [3689] = 3555,
  [3690] = 3690,
  [3691] = 3691,
  [3692] = 3579,
  [3693] = 3642,
  [3694] = 3253,
  [3695] = 3508,
  [3696] = 1523,
  [3697] = 1524,
  [3698] = 203,
  [3699] = 3699,
  [3700] = 3700,
  [3701] = 3701,
  [3702] = 3409,
  [3703] = 3703,
  [3704] = 3704,
  [3705] = 3705,
  [3706] = 3706,
  [3707] = 3707,
  [3708] = 3708,
  [3709] = 3709,
  [3710] = 3710,
  [3711] = 1634,
  [3712] = 3712,
  [3713] = 1644,
  [3714] = 3714,
  [3715] = 3715,
  [3716] = 3578,
  [3717] = 3590,
  [3718] = 3718,
  [3719] = 3642,
  [3720] = 3709,
  [3721] = 3721,
  [3722] = 3722,
  [3723] = 3634,
  [3724] = 3724,
  [3725] = 3725,
  [3726] = 3726,
  [3727] = 3727,
  [3728] = 3728,
  [3729] = 3729,
  [3730] = 1557,
  [3731] = 1561,
  [3732] = 1643,
  [3733] = 1645,
  [3734] = 3734,
  [3735] = 3735,
  [3736] = 3736,
  [3737] = 3737,
  [3738] = 3738,
  [3739] = 3540,
  [3740] = 239,
  [3741] = 3741,
  [3742] = 3742,
  [3743] = 240,
  [3744] = 3558,
  [3745] = 3745,
  [3746] = 3746,
  [3747] = 3747,
  [3748] = 3748,
  [3749] = 3749,
  [3750] = 3750,
  [3751] = 3606,
  [3752] = 3752,
  [3753] = 3753,
  [3754] = 3524,
  [3755] = 3755,
  [3756] = 3749,
  [3757] = 3527,
  [3758] = 3758,
  [3759] = 3625,
  [3760] = 712,
  [3761] = 3761,
  [3762] = 3668,
  [3763] = 1643,
  [3764] = 3764,
  [3765] = 3304,
  [3766] = 1645,
  [3767] = 1595,
  [3768] = 3755,
  [3769] = 1592,
  [3770] = 3649,
  [3771] = 1552,
  [3772] = 713,
  [3773] = 3773,
  [3774] = 3774,
  [3775] = 3755,
  [3776] = 711,
  [3777] = 3777,
  [3778] = 3778,
  [3779] = 3227,
  [3780] = 3780,
  [3781] = 3781,
  [3782] = 3782,
  [3783] = 3626,
  [3784] = 3755,
  [3785] = 3764,
  [3786] = 3786,
  [3787] = 3787,
  [3788] = 3755,
  [3789] = 3707,
  [3790] = 3786,
  [3791] = 3791,
  [3792] = 3792,
  [3793] = 3786,
  [3794] = 3794,
  [3795] = 3795,
  [3796] = 3631,
  [3797] = 3794,
  [3798] = 3798,
  [3799] = 3589,
  [3800] = 3632,
  [3801] = 3750,
  [3802] = 3802,
  [3803] = 3794,
  [3804] = 3804,
  [3805] = 3547,
  [3806] = 3315,
  [3807] = 3807,
  [3808] = 3794,
  [3809] = 3777,
  [3810] = 3777,
  [3811] = 3811,
  [3812] = 3812,
  [3813] = 3640,
  [3814] = 3786,
  [3815] = 3777,
  [3816] = 3816,
  [3817] = 3817,
  [3818] = 3818,
  [3819] = 3627,
  [3820] = 3598,
  [3821] = 3761,
  [3822] = 3752,
  [3823] = 3823,
  [3824] = 1557,
  [3825] = 3825,
  [3826] = 3826,
  [3827] = 3827,
  [3828] = 3780,
  [3829] = 3829,
  [3830] = 3774,
  [3831] = 3831,
  [3832] = 3832,
  [3833] = 3833,
  [3834] = 3834,
  [3835] = 3835,
  [3836] = 3836,
  [3837] = 3837,
  [3838] = 1605,
  [3839] = 3601,
  [3840] = 3840,
  [3841] = 3841,
  [3842] = 3826,
  [3843] = 3843,
  [3844] = 3777,
  [3845] = 3845,
  [3846] = 3846,
  [3847] = 3604,
  [3848] = 3597,
  [3849] = 1561,
  [3850] = 1644,
  [3851] = 3851,
  [3852] = 3852,
  [3853] = 3816,
  [3854] = 3823,
  [3855] = 3633,
  [3856] = 3856,
  [3857] = 1634,
  [3858] = 3858,
  [3859] = 3831,
  [3860] = 3833,
  [3861] = 3852,
  [3862] = 3862,
  [3863] = 3863,
  [3864] = 3750,
  [3865] = 3761,
  [3866] = 3804,
  [3867] = 3858,
  [3868] = 3794,
  [3869] = 3869,
  [3870] = 3608,
  [3871] = 3782,
  [3872] = 3851,
  [3873] = 3812,
  [3874] = 3874,
  [3875] = 3786,
  [3876] = 714,
  [3877] = 3877,
  [3878] = 3837,
  [3879] = 3750,
  [3880] = 3880,
  [3881] = 3559,
  [3882] = 3863,
  [3883] = 3755,
  [3884] = 3786,
  [3885] = 3521,
  [3886] = 3886,
  [3887] = 3777,
  [3888] = 3840,
  [3889] = 3750,
  [3890] = 3753,
  [3891] = 3750,
  [3892] = 715,
  [3893] = 3637,
  [3894] = 3831,
  [3895] = 3522,
  [3896] = 3794,
  [3897] = 3880,
  [3898] = 3836,
  [3899] = 3899,
  [3900] = 3714,
  [3901] = 3901,
  [3902] = 3902,
  [3903] = 3903,
  [3904] = 3904,
  [3905] = 3905,
  [3906] = 3906,
  [3907] = 3907,
  [3908] = 3908,
  [3909] = 3909,
  [3910] = 3910,
  [3911] = 3911,
  [3912] = 3912,
  [3913] = 3913,
  [3914] = 3914,
  [3915] = 3915,
  [3916] = 3916,
  [3917] = 3917,
  [3918] = 3811,
  [3919] = 3862,
  [3920] = 3920,
  [3921] = 3886,
  [3922] = 3922,
  [3923] = 3923,
  [3924] = 3924,
  [3925] = 921,
  [3926] = 929,
  [3927] = 938,
  [3928] = 942,
  [3929] = 944,
  [3930] = 3930,
  [3931] = 794,
  [3932] = 814,
  [3933] = 816,
  [3934] = 818,
  [3935] = 822,
  [3936] = 3936,
  [3937] = 3937,
  [3938] = 3938,
  [3939] = 3939,
  [3940] = 3940,
  [3941] = 3592,
  [3942] = 3942,
  [3943] = 839,
  [3944] = 3944,
  [3945] = 842,
  [3946] = 846,
  [3947] = 3947,
  [3948] = 3948,
  [3949] = 3949,
  [3950] = 3950,
  [3951] = 3951,
  [3952] = 3952,
  [3953] = 902,
  [3954] = 903,
  [3955] = 904,
  [3956] = 3956,
  [3957] = 3957,
  [3958] = 3958,
  [3959] = 3959,
  [3960] = 3960,
  [3961] = 3961,
  [3962] = 3962,
  [3963] = 3963,
  [3964] = 3964,
  [3965] = 3965,
  [3966] = 3966,
  [3967] = 3967,
  [3968] = 3968,
  [3969] = 3969,
  [3970] = 3970,
  [3971] = 3971,
  [3972] = 3972,
  [3973] = 3973,
  [3974] = 3974,
  [3975] = 3975,
  [3976] = 3976,
  [3977] = 3977,
  [3978] = 3978,
  [3979] = 812,
  [3980] = 3980,
  [3981] = 786,
  [3982] = 851,
  [3983] = 3983,
  [3984] = 869,
  [3985] = 870,
  [3986] = 3986,
  [3987] = 3987,
  [3988] = 3988,
  [3989] = 3989,
  [3990] = 3990,
  [3991] = 3991,
  [3992] = 873,
  [3993] = 3993,
  [3994] = 893,
  [3995] = 896,
  [3996] = 899,
  [3997] = 799,
  [3998] = 796,
  [3999] = 804,
  [4000] = 811,
  [4001] = 4001,
  [4002] = 788,
  [4003] = 4003,
  [4004] = 909,
  [4005] = 4005,
  [4006] = 4006,
  [4007] = 801,
  [4008] = 4008,
  [4009] = 4009,
  [4010] = 4010,
  [4011] = 923,
  [4012] = 4012,
  [4013] = 4013,
  [4014] = 4014,
  [4015] = 4015,
  [4016] = 879,
  [4017] = 857,
  [4018] = 866,
  [4019] = 4019,
  [4020] = 910,
  [4021] = 4021,
  [4022] = 4022,
  [4023] = 4023,
  [4024] = 4024,
  [4025] = 4025,
  [4026] = 4026,
  [4027] = 4027,
  [4028] = 4028,
  [4029] = 4029,
  [4030] = 4030,
  [4031] = 4031,
  [4032] = 934,
  [4033] = 936,
  [4034] = 939,
  [4035] = 941,
  [4036] = 911,
  [4037] = 4037,
  [4038] = 4038,
  [4039] = 3964,
  [4040] = 862,
  [4041] = 875,
  [4042] = 4012,
  [4043] = 912,
  [4044] = 792,
  [4045] = 797,
  [4046] = 3923,
  [4047] = 791,
  [4048] = 925,
  [4049] = 4049,
  [4050] = 4050,
  [4051] = 4051,
  [4052] = 4052,
  [4053] = 3944,
  [4054] = 4054,
  [4055] = 4055,
  [4056] = 4056,
  [4057] = 3901,
  [4058] = 4058,
  [4059] = 4059,
  [4060] = 4060,
  [4061] = 883,
  [4062] = 3964,
  [4063] = 885,
  [4064] = 4064,
  [4065] = 4065,
  [4066] = 4066,
  [4067] = 890,
  [4068] = 891,
  [4069] = 894,
  [4070] = 901,
  [4071] = 927,
  [4072] = 863,
  [4073] = 825,
  [4074] = 806,
  [4075] = 4075,
  [4076] = 4076,
  [4077] = 4077,
  [4078] = 859,
  [4079] = 4079,
  [4080] = 4080,
  [4081] = 4081,
  [4082] = 4082,
  [4083] = 4083,
  [4084] = 4084,
  [4085] = 3923,
  [4086] = 4086,
  [4087] = 3948,
  [4088] = 881,
  [4089] = 886,
  [4090] = 888,
  [4091] = 898,
  [4092] = 3901,
  [4093] = 4093,
  [4094] = 4009,
  [4095] = 4095,
  [4096] = 4096,
  [4097] = 4097,
  [4098] = 4098,
  [4099] = 4099,
  [4100] = 4100,
  [4101] = 4101,
  [4102] = 4102,
  [4103] = 4103,
  [4104] = 4005,
  [4105] = 4105,
  [4106] = 4106,
  [4107] = 3923,
  [4108] = 3901,
  [4109] = 4109,
  [4110] = 4110,
  [4111] = 4111,
  [4112] = 3901,
  [4113] = 4113,
  [4114] = 4114,
  [4115] = 4115,
  [4116] = 3971,
  [4117] = 4117,
  [4118] = 4118,
  [4119] = 4119,
  [4120] = 4120,
  [4121] = 4121,
  [4122] = 4122,
  [4123] = 4123,
  [4124] = 4124,
  [4125] = 3972,
  [4126] = 4126,
  [4127] = 4127,
  [4128] = 4128,
  [4129] = 4129,
  [4130] = 4130,
  [4131] = 4131,
  [4132] = 4132,
  [4133] = 4133,
  [4134] = 4134,
  [4135] = 4135,
  [4136] = 4136,
  [4137] = 4137,
  [4138] = 4138,
  [4139] = 4139,
  [4140] = 4140,
  [4141] = 4141,
  [4142] = 4142,
  [4143] = 4143,
  [4144] = 4144,
  [4145] = 4145,
  [4146] = 4146,
  [4147] = 3987,
  [4148] = 4148,
  [4149] = 4149,
  [4150] = 4150,
  [4151] = 3976,
  [4152] = 4152,
  [4153] = 4150,
  [4154] = 4154,
  [4155] = 4155,
  [4156] = 4156,
  [4157] = 4157,
  [4158] = 4158,
  [4159] = 4159,
  [4160] = 4160,
  [4161] = 4161,
  [4162] = 4162,
  [4163] = 4163,
  [4164] = 4164,
  [4165] = 4165,
  [4166] = 4166,
  [4167] = 4167,
  [4168] = 4168,
  [4169] = 4169,
  [4170] = 4170,
  [4171] = 3939,
  [4172] = 4172,
  [4173] = 4173,
  [4174] = 4174,
  [4175] = 4175,
  [4176] = 4038,
  [4177] = 4177,
  [4178] = 4178,
  [4179] = 4179,
  [4180] = 4180,
  [4181] = 4181,
  [4182] = 4182,
  [4183] = 4183,
  [4184] = 4184,
  [4185] = 4185,
  [4186] = 4186,
  [4187] = 4187,
  [4188] = 4188,
  [4189] = 4013,
  [4190] = 4190,
  [4191] = 3980,
  [4192] = 4192,
  [4193] = 4193,
  [4194] = 4194,
  [4195] = 4195,
  [4196] = 4196,
  [4197] = 4197,
  [4198] = 4198,
  [4199] = 4199,
  [4200] = 4031,
  [4201] = 4154,
  [4202] = 3983,
  [4203] = 4184,
  [4204] = 4204,
  [4205] = 4205,
  [4206] = 4206,
  [4207] = 4185,
  [4208] = 3951,
  [4209] = 4209,
  [4210] = 4210,
  [4211] = 4211,
  [4212] = 4212,
  [4213] = 4213,
  [4214] = 4214,
  [4215] = 4215,
  [4216] = 4216,
  [4217] = 3987,
  [4218] = 3923,
  [4219] = 4219,
  [4220] = 4220,
  [4221] = 4221,
  [4222] = 4150,
  [4223] = 4223,
  [4224] = 4160,
  [4225] = 4161,
  [4226] = 4226,
  [4227] = 4227,
  [4228] = 3986,
  [4229] = 4038,
  [4230] = 4230,
  [4231] = 4231,
  [4232] = 4232,
  [4233] = 4233,
  [4234] = 4234,
  [4235] = 4235,
  [4236] = 4236,
  [4237] = 4237,
  [4238] = 4238,
  [4239] = 4239,
  [4240] = 4240,
  [4241] = 4241,
  [4242] = 4242,
  [4243] = 4243,
  [4244] = 4244,
  [4245] = 4245,
  [4246] = 4246,
  [4247] = 4247,
  [4248] = 4172,
  [4249] = 4249,
  [4250] = 3961,
  [4251] = 4251,
  [4252] = 4252,
  [4253] = 4253,
  [4254] = 3962,
  [4255] = 4255,
  [4256] = 4256,
  [4257] = 4257,
  [4258] = 4258,
  [4259] = 4259,
  [4260] = 4173,
  [4261] = 4261,
  [4262] = 4262,
  [4263] = 4263,
  [4264] = 4264,
  [4265] = 4265,
  [4266] = 4266,
  [4267] = 4267,
  [4268] = 4268,
  [4269] = 4269,
  [4270] = 231,
  [4271] = 4271,
  [4272] = 4272,
  [4273] = 4174,
  [4274] = 4274,
  [4275] = 831,
  [4276] = 3654,
  [4277] = 3989,
  [4278] = 4278,
  [4279] = 4175,
  [4280] = 217,
  [4281] = 4281,
  [4282] = 4282,
  [4283] = 4283,
  [4284] = 4284,
  [4285] = 4285,
  [4286] = 919,
  [4287] = 824,
  [4288] = 4288,
  [4289] = 4289,
  [4290] = 3903,
  [4291] = 4291,
  [4292] = 4292,
  [4293] = 4193,
  [4294] = 4294,
  [4295] = 4295,
  [4296] = 4296,
  [4297] = 4297,
  [4298] = 4157,
  [4299] = 4299,
  [4300] = 4300,
  [4301] = 4301,
  [4302] = 4302,
  [4303] = 4303,
  [4304] = 4301,
  [4305] = 4197,
  [4306] = 4306,
  [4307] = 4307,
  [4308] = 4001,
  [4309] = 3722,
  [4310] = 867,
  [4311] = 878,
  [4312] = 4312,
  [4313] = 4313,
  [4314] = 4314,
  [4315] = 4315,
  [4316] = 4316,
  [4317] = 3948,
  [4318] = 4318,
  [4319] = 4249,
  [4320] = 4010,
  [4321] = 3971,
  [4322] = 3972,
  [4323] = 4190,
  [4324] = 3825,
  [4325] = 4325,
  [4326] = 3989,
  [4327] = 937,
  [4328] = 4328,
  [4329] = 4329,
  [4330] = 844,
  [4331] = 4331,
  [4332] = 4332,
  [4333] = 4333,
  [4334] = 4334,
  [4335] = 4335,
  [4336] = 4336,
  [4337] = 4337,
  [4338] = 4338,
  [4339] = 4339,
  [4340] = 3607,
  [4341] = 3687,
  [4342] = 850,
  [4343] = 856,
  [4344] = 4344,
  [4345] = 4345,
  [4346] = 4346,
  [4347] = 4347,
  [4348] = 4160,
  [4349] = 4349,
  [4350] = 1624,
  [4351] = 1630,
  [4352] = 4352,
  [4353] = 4353,
  [4354] = 4161,
  [4355] = 3944,
  [4356] = 4356,
  [4357] = 4357,
  [4358] = 4358,
  [4359] = 4196,
  [4360] = 4360,
  [4361] = 4361,
  [4362] = 4362,
  [4363] = 4363,
  [4364] = 4364,
  [4365] = 4365,
  [4366] = 4366,
  [4367] = 4367,
  [4368] = 4368,
  [4369] = 4369,
  [4370] = 4370,
  [4371] = 877,
  [4372] = 4372,
  [4373] = 4145,
  [4374] = 897,
  [4375] = 907,
  [4376] = 4376,
  [4377] = 4377,
  [4378] = 4378,
  [4379] = 4379,
  [4380] = 4380,
  [4381] = 4381,
  [4382] = 4382,
  [4383] = 4383,
  [4384] = 4382,
  [4385] = 4385,
  [4386] = 4386,
  [4387] = 4387,
  [4388] = 4382,
  [4389] = 4389,
  [4390] = 4390,
  [4391] = 4391,
  [4392] = 4380,
  [4393] = 4390,
  [4394] = 4394,
  [4395] = 4381,
  [4396] = 4380,
  [4397] = 4387,
  [4398] = 4398,
  [4399] = 4399,
  [4400] = 4400,
  [4401] = 4401,
  [4402] = 4394,
  [4403] = 4403,
  [4404] = 4390,
  [4405] = 4387,
  [4406] = 4406,
  [4407] = 4407,
  [4408] = 4408,
  [4409] = 4409,
  [4410] = 4410,
  [4411] = 4380,
  [4412] = 4394,
  [4413] = 4413,
  [4414] = 4414,
  [4415] = 4391,
  [4416] = 4416,
  [4417] = 3792,
  [4418] = 4418,
  [4419] = 4419,
  [4420] = 4420,
  [4421] = 4389,
  [4422] = 4422,
  [4423] = 4423,
  [4424] = 4424,
  [4425] = 3722,
  [4426] = 4426,
  [4427] = 4427,
  [4428] = 4413,
  [4429] = 4408,
  [4430] = 4413,
  [4431] = 4431,
  [4432] = 4409,
  [4433] = 4391,
  [4434] = 4387,
  [4435] = 4409,
  [4436] = 4436,
  [4437] = 4391,
  [4438] = 4413,
  [4439] = 4439,
  [4440] = 4440,
  [4441] = 4441,
  [4442] = 4442,
  [4443] = 4381,
  [4444] = 4444,
  [4445] = 4445,
  [4446] = 4446,
  [4447] = 4447,
  [4448] = 4420,
  [4449] = 4439,
  [4450] = 4385,
  [4451] = 4416,
  [4452] = 4381,
  [4453] = 4390,
  [4454] = 4391,
  [4455] = 4455,
  [4456] = 4381,
  [4457] = 3807,
  [4458] = 4458,
  [4459] = 4459,
  [4460] = 4427,
  [4461] = 4409,
  [4462] = 4462,
  [4463] = 4444,
  [4464] = 4426,
  [4465] = 4394,
  [4466] = 4381,
  [4467] = 4467,
  [4468] = 4382,
  [4469] = 4469,
  [4470] = 4413,
  [4471] = 4390,
  [4472] = 4439,
  [4473] = 4420,
  [4474] = 4439,
  [4475] = 4407,
  [4476] = 4394,
  [4477] = 4387,
  [4478] = 4381,
  [4479] = 4406,
  [4480] = 4480,
  [4481] = 4481,
  [4482] = 4380,
  [4483] = 4483,
  [4484] = 4484,
  [4485] = 4485,
  [4486] = 4409,
  [4487] = 4487,
  [4488] = 4488,
  [4489] = 4420,
  [4490] = 4391,
  [4491] = 4491,
  [4492] = 4420,
  [4493] = 4390,
  [4494] = 4494,
  [4495] = 4495,
  [4496] = 4380,
  [4497] = 4420,
  [4498] = 4391,
  [4499] = 4499,
  [4500] = 4382,
  [4501] = 4413,
  [4502] = 4382,
  [4503] = 4439,
  [4504] = 4413,
  [4505] = 4505,
  [4506] = 4459,
  [4507] = 4439,
  [4508] = 4439,
  [4509] = 4390,
  [4510] = 4420,
  [4511] = 4380,
  [4512] = 4394,
  [4513] = 4394,
  [4514] = 4514,
  [4515] = 4458,
  [4516] = 4516,
  [4517] = 4517,
  [4518] = 4518,
  [4519] = 4519,
  [4520] = 4520,
  [4521] = 4521,
  [4522] = 4522,
  [4523] = 4523,
  [4524] = 4524,
  [4525] = 4525,
  [4526] = 4526,
  [4527] = 4527,
  [4528] = 4528,
  [4529] = 4529,
  [4530] = 4530,
  [4531] = 4531,
  [4532] = 4532,
  [4533] = 4533,
  [4534] = 4534,
  [4535] = 4535,
  [4536] = 4536,
  [4537] = 4537,
  [4538] = 4538,
  [4539] = 4539,
  [4540] = 4540,
  [4541] = 4541,
  [4542] = 4542,
  [4543] = 4543,
  [4544] = 4544,
  [4545] = 4545,
  [4546] = 4546,
  [4547] = 4547,
  [4548] = 4548,
  [4549] = 4549,
  [4550] = 4550,
  [4551] = 4551,
  [4552] = 4552,
  [4553] = 4553,
  [4554] = 4554,
  [4555] = 4555,
  [4556] = 4556,
  [4557] = 4557,
  [4558] = 4558,
  [4559] = 4559,
  [4560] = 4560,
  [4561] = 4561,
  [4562] = 4562,
  [4563] = 4563,
  [4564] = 4564,
  [4565] = 4565,
  [4566] = 4566,
  [4567] = 4567,
  [4568] = 4540,
  [4569] = 4569,
  [4570] = 4570,
  [4571] = 4571,
  [4572] = 4572,
  [4573] = 4573,
  [4574] = 4574,
  [4575] = 4575,
  [4576] = 4576,
  [4577] = 4577,
  [4578] = 4531,
  [4579] = 4579,
  [4580] = 4580,
  [4581] = 4581,
  [4582] = 4582,
  [4583] = 4583,
  [4584] = 4584,
  [4585] = 4585,
  [4586] = 4540,
  [4587] = 4541,
  [4588] = 4542,
  [4589] = 4589,
  [4590] = 4544,
  [4591] = 4545,
  [4592] = 4592,
  [4593] = 4593,
  [4594] = 4533,
  [4595] = 4537,
  [4596] = 4543,
  [4597] = 4553,
  [4598] = 4598,
  [4599] = 4552,
  [4600] = 4600,
  [4601] = 4601,
  [4602] = 4554,
  [4603] = 4603,
  [4604] = 4604,
  [4605] = 4605,
  [4606] = 4606,
  [4607] = 4607,
  [4608] = 4608,
  [4609] = 4609,
  [4610] = 4610,
  [4611] = 4611,
  [4612] = 4612,
  [4613] = 4613,
  [4614] = 4614,
  [4615] = 4615,
  [4616] = 4616,
  [4617] = 4617,
  [4618] = 4618,
  [4619] = 4619,
  [4620] = 4552,
  [4621] = 4621,
  [4622] = 4541,
  [4623] = 4623,
  [4624] = 4624,
  [4625] = 4625,
  [4626] = 4626,
  [4627] = 4627,
  [4628] = 4628,
  [4629] = 4629,
  [4630] = 4630,
  [4631] = 4631,
  [4632] = 4632,
  [4633] = 4633,
  [4634] = 4634,
  [4635] = 4635,
  [4636] = 4542,
  [4637] = 4637,
  [4638] = 4544,
  [4639] = 4545,
  [4640] = 4640,
  [4641] = 4641,
  [4642] = 4642,
  [4643] = 4643,
  [4644] = 4554,
  [4645] = 4645,
  [4646] = 4646,
  [4647] = 4554,
  [4648] = 4648,
  [4649] = 4552,
  [4650] = 4531,
  [4651] = 4148,
  [4652] = 4652,
  [4653] = 4544,
  [4654] = 4545,
  [4655] = 4655,
  [4656] = 4554,
  [4657] = 4657,
  [4658] = 4658,
  [4659] = 4659,
  [4660] = 4660,
  [4661] = 4661,
  [4662] = 4662,
  [4663] = 4663,
  [4664] = 4664,
  [4665] = 4665,
  [4666] = 4666,
  [4667] = 4667,
  [4668] = 4668,
  [4669] = 4669,
  [4670] = 4670,
  [4671] = 4671,
  [4672] = 4672,
  [4673] = 4673,
  [4674] = 4674,
  [4675] = 4675,
  [4676] = 4676,
  [4677] = 4677,
  [4678] = 4678,
  [4679] = 4679,
  [4680] = 4680,
  [4681] = 4531,
  [4682] = 4682,
  [4683] = 4683,
  [4684] = 4684,
  [4685] = 4685,
  [4686] = 4671,
  [4687] = 4663,
  [4688] = 4643,
  [4689] = 4689,
  [4690] = 4690,
  [4691] = 4691,
  [4692] = 4646,
  [4693] = 4542,
  [4694] = 4694,
  [4695] = 4695,
  [4696] = 4696,
  [4697] = 790,
  [4698] = 4554,
  [4699] = 4699,
  [4700] = 4700,
  [4701] = 4701,
  [4702] = 4702,
  [4703] = 4703,
  [4704] = 4704,
  [4705] = 4705,
  [4706] = 4706,
  [4707] = 4707,
  [4708] = 4541,
  [4709] = 4709,
  [4710] = 4710,
  [4711] = 4711,
  [4712] = 4712,
  [4713] = 4713,
  [4714] = 4555,
  [4715] = 4715,
  [4716] = 4716,
  [4717] = 4717,
  [4718] = 4718,
  [4719] = 4719,
  [4720] = 4720,
  [4721] = 4576,
  [4722] = 4722,
  [4723] = 4723,
  [4724] = 4724,
  [4725] = 4725,
  [4726] = 4726,
  [4727] = 4727,
  [4728] = 4728,
  [4729] = 4729,
  [4730] = 4730,
  [4731] = 4731,
  [4732] = 4732,
  [4733] = 4524,
  [4734] = 4734,
  [4735] = 4735,
  [4736] = 4736,
  [4737] = 4737,
  [4738] = 4738,
  [4739] = 4739,
  [4740] = 4685,
  [4741] = 4741,
  [4742] = 4742,
  [4743] = 4743,
  [4744] = 4734,
  [4745] = 4736,
  [4746] = 4746,
  [4747] = 4747,
  [4748] = 4748,
  [4749] = 4749,
  [4750] = 4750,
  [4751] = 4751,
  [4752] = 4752,
  [4753] = 4753,
  [4754] = 4754,
  [4755] = 4755,
  [4756] = 4756,
  [4757] = 4757,
  [4758] = 4758,
  [4759] = 4759,
  [4760] = 4760,
  [4761] = 4761,
  [4762] = 4762,
  [4763] = 4763,
  [4764] = 4764,
  [4765] = 4765,
  [4766] = 4766,
  [4767] = 4767,
  [4768] = 4768,
  [4769] = 4769,
  [4770] = 4770,
  [4771] = 4771,
  [4772] = 4772,
  [4773] = 4773,
  [4774] = 4774,
  [4775] = 4775,
  [4776] = 4776,
  [4777] = 4777,
  [4778] = 4778,
  [4779] = 4779,
  [4780] = 4780,
  [4781] = 4781,
  [4782] = 4782,
  [4783] = 4783,
  [4784] = 4784,
  [4785] = 4785,
  [4786] = 4786,
  [4787] = 4787,
  [4788] = 4788,
  [4789] = 4544,
  [4790] = 4545,
  [4791] = 4791,
  [4792] = 4792,
  [4793] = 4793,
  [4794] = 4794,
  [4795] = 4795,
  [4796] = 4796,
  [4797] = 4672,
  [4798] = 4798,
  [4799] = 4799,
  [4800] = 4800,
  [4801] = 4801,
  [4802] = 4802,
  [4803] = 4803,
  [4804] = 4804,
  [4805] = 4805,
  [4806] = 4806,
  [4807] = 4807,
  [4808] = 4531,
  [4809] = 4809,
  [4810] = 4792,
  [4811] = 4811,
  [4812] = 4812,
  [4813] = 4813,
  [4814] = 3559,
  [4815] = 4802,
  [4816] = 4816,
  [4817] = 4817,
  [4818] = 4818,
  [4819] = 4819,
  [4820] = 4820,
  [4821] = 4821,
  [4822] = 4822,
  [4823] = 4823,
  [4824] = 4824,
  [4825] = 4825,
  [4826] = 4826,
  [4827] = 4827,
  [4828] = 4828,
  [4829] = 4829,
  [4830] = 4830,
  [4831] = 4831,
  [4832] = 4832,
  [4833] = 4833,
  [4834] = 4834,
  [4835] = 4835,
  [4836] = 4836,
  [4837] = 4837,
  [4838] = 4838,
  [4839] = 4839,
  [4840] = 4840,
  [4841] = 4841,
  [4842] = 4842,
  [4843] = 4843,
  [4844] = 4844,
  [4845] = 4845,
  [4846] = 4846,
  [4847] = 4847,
  [4848] = 4848,
  [4849] = 4849,
  [4850] = 4850,
  [4851] = 4851,
  [4852] = 4852,
  [4853] = 4853,
  [4854] = 4854,
  [4855] = 4855,
  [4856] = 4856,
  [4857] = 4857,
  [4858] = 4858,
  [4859] = 4859,
  [4860] = 4860,
  [4861] = 4861,
  [4862] = 4862,
  [4863] = 4863,
  [4864] = 4864,
  [4865] = 4865,
  [4866] = 4866,
  [4867] = 4867,
  [4868] = 4868,
  [4869] = 4869,
  [4870] = 4870,
  [4871] = 4871,
  [4872] = 4872,
  [4873] = 4873,
  [4874] = 4874,
  [4875] = 4875,
  [4876] = 4876,
  [4877] = 4877,
  [4878] = 4531,
  [4879] = 4879,
  [4880] = 4880,
  [4881] = 4881,
  [4882] = 4882,
  [4883] = 4883,
  [4884] = 4884,
  [4885] = 4885,
  [4886] = 4886,
  [4887] = 4887,
  [4888] = 4888,
  [4889] = 4889,
  [4890] = 4890,
  [4891] = 4288,
  [4892] = 4892,
  [4893] = 4893,
  [4894] = 4894,
  [4895] = 4895,
  [4896] = 4896,
  [4897] = 3807,
  [4898] = 4898,
  [4899] = 4621,
  [4900] = 4900,
  [4901] = 4901,
  [4902] = 4902,
  [4903] = 4903,
  [4904] = 4904,
  [4905] = 4905,
  [4906] = 4906,
  [4907] = 4907,
  [4908] = 4668,
  [4909] = 4909,
  [4910] = 4576,
  [4911] = 4911,
  [4912] = 4912,
  [4913] = 4913,
  [4914] = 4914,
  [4915] = 4915,
  [4916] = 4916,
  [4917] = 4917,
  [4918] = 4918,
  [4919] = 4919,
  [4920] = 4920,
  [4921] = 4921,
  [4922] = 4922,
  [4923] = 4923,
  [4924] = 4924,
  [4925] = 4734,
  [4926] = 4926,
  [4927] = 4927,
  [4928] = 4928,
  [4929] = 4929,
  [4930] = 4930,
  [4931] = 4931,
  [4932] = 4932,
  [4933] = 4933,
  [4934] = 4934,
  [4935] = 3668,
  [4936] = 4936,
  [4937] = 4937,
  [4938] = 4938,
  [4939] = 4621,
  [4940] = 4940,
  [4941] = 4941,
  [4942] = 4942,
  [4943] = 4943,
  [4944] = 4944,
  [4945] = 4945,
  [4946] = 4946,
  [4947] = 4947,
  [4948] = 4948,
  [4949] = 4949,
  [4950] = 4531,
  [4951] = 4951,
  [4952] = 4952,
  [4953] = 4953,
  [4954] = 4954,
  [4955] = 4955,
  [4956] = 4540,
  [4957] = 4957,
  [4958] = 4958,
  [4959] = 4806,
  [4960] = 4792,
  [4961] = 4812,
  [4962] = 4712,
  [4963] = 4963,
  [4964] = 4869,
  [4965] = 4812,
  [4966] = 4716,
  [4967] = 4967,
  [4968] = 4968,
  [4969] = 4927,
  [4970] = 4970,
  [4971] = 4946,
  [4972] = 4972,
  [4973] = 4973,
  [4974] = 4974,
  [4975] = 4955,
  [4976] = 4976,
  [4977] = 4977,
  [4978] = 4978,
  [4979] = 4979,
  [4980] = 4980,
  [4981] = 4541,
  [4982] = 4982,
  [4983] = 4983,
  [4984] = 4984,
  [4985] = 4985,
  [4986] = 4986,
  [4987] = 4879,
  [4988] = 4988,
  [4989] = 4989,
  [4990] = 4890,
  [4991] = 4991,
  [4992] = 4992,
  [4993] = 4993,
  [4994] = 4994,
  [4995] = 4995,
  [4996] = 4678,
  [4997] = 4700,
  [4998] = 4998,
  [4999] = 4540,
  [5000] = 5000,
  [5001] = 4541,
  [5002] = 5002,
  [5003] = 5003,
  [5004] = 5004,
  [5005] = 5000,
  [5006] = 4542,
  [5007] = 5007,
  [5008] = 4544,
  [5009] = 5009,
  [5010] = 5010,
  [5011] = 4545,
  [5012] = 5012,
  [5013] = 3707,
  [5014] = 4869,
  [5015] = 5015,
  [5016] = 4542,
  [5017] = 5017,
  [5018] = 5018,
  [5019] = 5003,
  [5020] = 5020,
  [5021] = 5021,
  [5022] = 4541,
  [5023] = 4977,
  [5024] = 5024,
  [5025] = 5025,
  [5026] = 3792,
  [5027] = 4533,
  [5028] = 5028,
  [5029] = 5029,
  [5030] = 4537,
  [5031] = 5031,
  [5032] = 4543,
  [5033] = 4553,
  [5034] = 5034,
  [5035] = 5035,
  [5036] = 5036,
  [5037] = 5037,
  [5038] = 4713,
  [5039] = 4564,
  [5040] = 5040,
  [5041] = 4566,
  [5042] = 5042,
  [5043] = 5043,
  [5044] = 5044,
  [5045] = 5045,
  [5046] = 5046,
  [5047] = 5047,
  [5048] = 5048,
  [5049] = 5049,
  [5050] = 5050,
  [5051] = 5051,
  [5052] = 4552,
  [5053] = 5053,
  [5054] = 5054,
  [5055] = 5055,
  [5056] = 5056,
  [5057] = 5057,
  [5058] = 5058,
  [5059] = 5059,
  [5060] = 5060,
  [5061] = 5061,
  [5062] = 4554,
  [5063] = 5063,
  [5064] = 5064,
  [5065] = 5065,
  [5066] = 5066,
  [5067] = 5067,
  [5068] = 5068,
  [5069] = 5069,
  [5070] = 5070,
  [5071] = 5071,
  [5072] = 5072,
  [5073] = 5073,
  [5074] = 5074,
  [5075] = 1626,
  [5076] = 1545,
  [5077] = 5077,
  [5078] = 5078,
  [5079] = 5079,
  [5080] = 5080,
  [5081] = 5081,
  [5082] = 5082,
  [5083] = 5083,
  [5084] = 5084,
  [5085] = 5085,
  [5086] = 5086,
  [5087] = 5087,
  [5088] = 5088,
  [5089] = 5089,
  [5090] = 5090,
  [5091] = 5091,
  [5092] = 5092,
  [5093] = 5093,
  [5094] = 5094,
  [5095] = 5095,
  [5096] = 3722,
  [5097] = 5097,
  [5098] = 5098,
  [5099] = 5099,
  [5100] = 5100,
  [5101] = 5101,
  [5102] = 5102,
  [5103] = 5103,
  [5104] = 5104,
  [5105] = 5105,
  [5106] = 4164,
  [5107] = 5107,
  [5108] = 4780,
  [5109] = 5109,
  [5110] = 5110,
  [5111] = 5111,
  [5112] = 5112,
  [5113] = 5113,
  [5114] = 5114,
  [5115] = 4544,
  [5116] = 4545,
  [5117] = 5117,
  [5118] = 5118,
  [5119] = 5119,
  [5120] = 5120,
  [5121] = 5121,
  [5122] = 5122,
  [5123] = 5123,
  [5124] = 5124,
  [5125] = 3547,
  [5126] = 5126,
  [5127] = 5127,
  [5128] = 5128,
  [5129] = 5129,
  [5130] = 5130,
  [5131] = 5131,
  [5132] = 5132,
  [5133] = 5133,
  [5134] = 2650,
  [5135] = 5135,
  [5136] = 5136,
  [5137] = 5137,
  [5138] = 5138,
  [5139] = 5139,
  [5140] = 5140,
  [5141] = 5141,
  [5142] = 5142,
  [5143] = 5143,
  [5144] = 5144,
  [5145] = 5145,
  [5146] = 5146,
  [5147] = 2672,
  [5148] = 5148,
  [5149] = 5149,
  [5150] = 5150,
  [5151] = 5151,
  [5152] = 5152,
  [5153] = 5153,
  [5154] = 5130,
  [5155] = 5155,
  [5156] = 5156,
  [5157] = 5157,
  [5158] = 5158,
  [5159] = 5159,
  [5160] = 5160,
  [5161] = 5161,
  [5162] = 5162,
  [5163] = 5163,
  [5164] = 5164,
  [5165] = 5165,
  [5166] = 5166,
  [5167] = 5167,
  [5168] = 5168,
  [5169] = 5169,
  [5170] = 5170,
  [5171] = 5171,
  [5172] = 5172,
  [5173] = 5130,
  [5174] = 5163,
  [5175] = 5175,
  [5176] = 5166,
  [5177] = 5177,
  [5178] = 5178,
  [5179] = 5167,
  [5180] = 5180,
  [5181] = 5181,
  [5182] = 5182,
  [5183] = 5183,
  [5184] = 5184,
  [5185] = 5185,
  [5186] = 5186,
  [5187] = 5187,
  [5188] = 5188,
  [5189] = 5189,
  [5190] = 5190,
  [5191] = 5191,
  [5192] = 5192,
  [5193] = 3811,
  [5194] = 1674,
  [5195] = 1675,
  [5196] = 3862,
  [5197] = 5197,
  [5198] = 5182,
  [5199] = 3886,
  [5200] = 5184,
  [5201] = 5149,
  [5202] = 5202,
  [5203] = 5161,
  [5204] = 5204,
  [5205] = 5146,
  [5206] = 5202,
  [5207] = 5172,
  [5208] = 5163,
  [5209] = 5209,
  [5210] = 5167,
  [5211] = 5189,
  [5212] = 5212,
  [5213] = 5213,
  [5214] = 2655,
  [5215] = 5215,
  [5216] = 5216,
  [5217] = 5127,
  [5218] = 5218,
  [5219] = 5219,
  [5220] = 5220,
  [5221] = 2657,
  [5222] = 5168,
  [5223] = 5223,
  [5224] = 5224,
  [5225] = 5225,
  [5226] = 5226,
  [5227] = 5227,
  [5228] = 5228,
  [5229] = 5138,
  [5230] = 5230,
  [5231] = 5219,
  [5232] = 5232,
  [5233] = 5233,
  [5234] = 5234,
  [5235] = 5235,
  [5236] = 5236,
  [5237] = 5183,
  [5238] = 2662,
  [5239] = 5239,
  [5240] = 5128,
  [5241] = 5228,
  [5242] = 5133,
  [5243] = 5146,
  [5244] = 5244,
  [5245] = 5245,
  [5246] = 5246,
  [5247] = 5247,
  [5248] = 5146,
  [5249] = 5233,
  [5250] = 5187,
  [5251] = 5146,
  [5252] = 5163,
  [5253] = 5167,
  [5254] = 5190,
  [5255] = 5144,
  [5256] = 5256,
  [5257] = 5257,
  [5258] = 5258,
  [5259] = 2708,
  [5260] = 5260,
  [5261] = 5137,
  [5262] = 2693,
  [5263] = 5263,
  [5264] = 5162,
  [5265] = 5265,
  [5266] = 5143,
  [5267] = 5267,
  [5268] = 5145,
  [5269] = 5162,
  [5270] = 5270,
  [5271] = 5191,
  [5272] = 5272,
  [5273] = 5143,
  [5274] = 5274,
  [5275] = 5166,
  [5276] = 5224,
  [5277] = 5277,
  [5278] = 5278,
  [5279] = 5184,
  [5280] = 5280,
  [5281] = 5190,
  [5282] = 5191,
  [5283] = 5283,
  [5284] = 5284,
  [5285] = 5285,
  [5286] = 5280,
  [5287] = 5287,
  [5288] = 5150,
  [5289] = 5289,
  [5290] = 5290,
  [5291] = 5158,
  [5292] = 5163,
  [5293] = 5293,
  [5294] = 5283,
  [5295] = 5295,
  [5296] = 5287,
  [5297] = 2710,
  [5298] = 5181,
  [5299] = 5175,
  [5300] = 5227,
  [5301] = 5155,
  [5302] = 5302,
  [5303] = 5303,
  [5304] = 5304,
  [5305] = 5305,
  [5306] = 3825,
  [5307] = 5307,
  [5308] = 5162,
  [5309] = 5309,
  [5310] = 5310,
  [5311] = 5143,
  [5312] = 5312,
  [5313] = 5313,
  [5314] = 5314,
  [5315] = 5315,
  [5316] = 2669,
  [5317] = 5191,
  [5318] = 5318,
  [5319] = 5319,
  [5320] = 5283,
  [5321] = 5130,
  [5322] = 5322,
  [5323] = 5283,
  [5324] = 5324,
  [5325] = 5166,
  [5326] = 5326,
  [5327] = 5130,
  [5328] = 5233,
  [5329] = 5329,
  [5330] = 5330,
  [5331] = 5331,
  [5332] = 5188,
  [5333] = 5333,
  [5334] = 5334,
  [5335] = 5335,
  [5336] = 5336,
  [5337] = 5337,
  [5338] = 5184,
  [5339] = 5190,
  [5340] = 5303,
  [5341] = 5304,
  [5342] = 5342,
  [5343] = 5343,
  [5344] = 5344,
  [5345] = 2712,
  [5346] = 5346,
  [5347] = 5302,
  [5348] = 2653,
  [5349] = 5349,
  [5350] = 5350,
  [5351] = 5218,
  [5352] = 5166,
  [5353] = 5353,
  [5354] = 5184,
  [5355] = 5355,
  [5356] = 5356,
  [5357] = 5190,
  [5358] = 5358,
  [5359] = 5359,
  [5360] = 5360,
  [5361] = 5146,
  [5362] = 5312,
  [5363] = 5315,
  [5364] = 5364,
  [5365] = 5318,
  [5366] = 5324,
  [5367] = 5367,
  [5368] = 2690,
  [5369] = 5326,
  [5370] = 5370,
  [5371] = 5197,
  [5372] = 5344,
  [5373] = 5373,
  [5374] = 5183,
  [5375] = 5163,
  [5376] = 5293,
  [5377] = 5224,
  [5378] = 5167,
  [5379] = 5379,
  [5380] = 5162,
  [5381] = 5381,
  [5382] = 5143,
  [5383] = 1659,
  [5384] = 5384,
  [5385] = 5385,
  [5386] = 5191,
  [5387] = 5167,
  [5388] = 5283,
  [5389] = 2659,
  [5390] = 5390,
  [5391] = 5135,
  [5392] = 2660,
  [5393] = 5393,
  [5394] = 5192,
  [5395] = 5395,
  [5396] = 5130,
  [5397] = 5227,
  [5398] = 5398,
  [5399] = 5390,
  [5400] = 5400,
  [5401] = 5401,
  [5402] = 5402,
  [5403] = 5364,
  [5404] = 5274,
  [5405] = 5310,
  [5406] = 5406,
  [5407] = 5239,
  [5408] = 5204,
  [5409] = 5175,
  [5410] = 5228,
  [5411] = 5411,
  [5412] = 5412,
  [5413] = 5413,
  [5414] = 5234,
  [5415] = 5415,
  [5416] = 2687,
  [5417] = 5417,
  [5418] = 5418,
  [5419] = 5419,
  [5420] = 2707,
  [5421] = 5235,
  [5422] = 5395,
  [5423] = 5423,
  [5424] = 5424,
  [5425] = 5424,
  [5426] = 5426,
  [5427] = 5130,
  [5428] = 5428,
  [5429] = 5236,
  [5430] = 5303,
  [5431] = 5431,
  [5432] = 5212,
  [5433] = 2695,
  [5434] = 2688,
  [5435] = 5426,
  [5436] = 5436,
  [5437] = 5437,
  [5438] = 5213,
  [5439] = 5439,
  [5440] = 5440,
  [5441] = 2696,
  [5442] = 5440,
  [5443] = 5443,
  [5444] = 5180,
  [5445] = 5186,
  [5446] = 5215,
  [5447] = 5346,
  [5448] = 5216,
  [5449] = 5418,
  [5450] = 5220,
  [5451] = 5350,
  [5452] = 5223,
  [5453] = 5247,
  [5454] = 5146,
  [5455] = 5158,
  [5456] = 5163,
  [5457] = 5423,
  [5458] = 5344,
  [5459] = 5167,
  [5460] = 5460,
  [5461] = 5428,
  [5462] = 5462,
  [5463] = 2702,
  [5464] = 2704,
  [5465] = 2668,
  [5466] = 5466,
  [5467] = 5467,
  [5468] = 5468,
  [5469] = 5469,
  [5470] = 5470,
  [5471] = 5471,
  [5472] = 5472,
  [5473] = 5471,
  [5474] = 5474,
  [5475] = 5475,
  [5476] = 5476,
  [5477] = 5466,
  [5478] = 5472,
  [5479] = 5479,
  [5480] = 5480,
  [5481] = 5481,
  [5482] = 5482,
  [5483] = 5469,
  [5484] = 5484,
  [5485] = 5467,
  [5486] = 5474,
  [5487] = 5487,
  [5488] = 5488,
  [5489] = 5489,
  [5490] = 5490,
  [5491] = 5472,
  [5492] = 5492,
  [5493] = 5493,
  [5494] = 5482,
  [5495] = 5495,
  [5496] = 5496,
  [5497] = 5497,
  [5498] = 5498,
  [5499] = 5469,
  [5500] = 5500,
  [5501] = 5501,
  [5502] = 5502,
  [5503] = 5493,
  [5504] = 5480,
  [5505] = 5469,
  [5506] = 5506,
  [5507] = 5476,
  [5508] = 5466,
  [5509] = 5509,
  [5510] = 5510,
  [5511] = 5511,
  [5512] = 5512,
  [5513] = 5513,
  [5514] = 5512,
  [5515] = 5515,
  [5516] = 5516,
  [5517] = 5495,
  [5518] = 5472,
  [5519] = 5475,
  [5520] = 5495,
  [5521] = 5521,
  [5522] = 5492,
  [5523] = 5496,
  [5524] = 5521,
  [5525] = 5525,
  [5526] = 5526,
  [5527] = 5475,
  [5528] = 5476,
  [5529] = 5466,
  [5530] = 5530,
  [5531] = 5479,
  [5532] = 5480,
  [5533] = 5481,
  [5534] = 5534,
  [5535] = 5474,
  [5536] = 5536,
  [5537] = 5521,
  [5538] = 5538,
  [5539] = 5539,
  [5540] = 5540,
  [5541] = 5489,
  [5542] = 5542,
  [5543] = 5543,
  [5544] = 5492,
  [5545] = 5545,
  [5546] = 5546,
  [5547] = 5547,
  [5548] = 5548,
  [5549] = 5493,
  [5550] = 5550,
  [5551] = 5551,
  [5552] = 5547,
  [5553] = 5553,
  [5554] = 5554,
  [5555] = 5479,
  [5556] = 5493,
  [5557] = 5557,
  [5558] = 5466,
  [5559] = 5559,
  [5560] = 5547,
  [5561] = 5561,
  [5562] = 5562,
  [5563] = 5563,
  [5564] = 5471,
  [5565] = 5565,
  [5566] = 5566,
  [5567] = 5474,
  [5568] = 5467,
  [5569] = 5475,
  [5570] = 5501,
  [5571] = 5484,
  [5572] = 5521,
  [5573] = 5548,
  [5574] = 5476,
  [5575] = 5513,
  [5576] = 5557,
  [5577] = 5472,
  [5578] = 5480,
  [5579] = 5579,
  [5580] = 5492,
  [5581] = 5559,
  [5582] = 5476,
  [5583] = 5583,
  [5584] = 5584,
  [5585] = 5466,
  [5586] = 5480,
  [5587] = 5495,
  [5588] = 5588,
  [5589] = 5479,
  [5590] = 5480,
  [5591] = 5481,
  [5592] = 5521,
  [5593] = 5495,
  [5594] = 5481,
  [5595] = 5595,
  [5596] = 5596,
  [5597] = 5597,
  [5598] = 5479,
  [5599] = 5467,
  [5600] = 5480,
  [5601] = 5481,
  [5602] = 5602,
  [5603] = 5603,
  [5604] = 5604,
  [5605] = 5605,
  [5606] = 5606,
  [5607] = 5607,
  [5608] = 5608,
  [5609] = 5609,
  [5610] = 5489,
  [5611] = 5611,
  [5612] = 5612,
  [5613] = 5613,
  [5614] = 5614,
  [5615] = 5489,
  [5616] = 5538,
  [5617] = 5617,
  [5618] = 5469,
  [5619] = 5475,
  [5620] = 5620,
  [5621] = 5548,
  [5622] = 5622,
  [5623] = 5534,
  [5624] = 5497,
  [5625] = 5625,
  [5626] = 5626,
  [5627] = 5482,
  [5628] = 5614,
  [5629] = 5626,
  [5630] = 5470,
  [5631] = 5631,
  [5632] = 5547,
  [5633] = 5474,
  [5634] = 5476,
  [5635] = 5635,
  [5636] = 5470,
  [5637] = 5637,
  [5638] = 5638,
  [5639] = 5475,
  [5640] = 5640,
  [5641] = 5596,
  [5642] = 5642,
  [5643] = 5643,
  [5644] = 5644,
  [5645] = 5645,
  [5646] = 5469,
  [5647] = 5472,
  [5648] = 5648,
  [5649] = 5553,
  [5650] = 5650,
  [5651] = 5493,
  [5652] = 5617,
  [5653] = 5547,
  [5654] = 5469,
  [5655] = 5482,
  [5656] = 5656,
  [5657] = 5657,
  [5658] = 5489,
  [5659] = 5659,
  [5660] = 5660,
  [5661] = 5603,
  [5662] = 5553,
  [5663] = 5663,
  [5664] = 5500,
  [5665] = 5665,
  [5666] = 5515,
  [5667] = 5607,
  [5668] = 5482,
  [5669] = 5510,
  [5670] = 5493,
  [5671] = 5547,
  [5672] = 5596,
  [5673] = 5501,
  [5674] = 5656,
  [5675] = 5501,
  [5676] = 5611,
  [5677] = 5603,
  [5678] = 5622,
  [5679] = 5513,
  [5680] = 5561,
  [5681] = 5681,
  [5682] = 5665,
  [5683] = 5553,
  [5684] = 5540,
  [5685] = 5607,
  [5686] = 5611,
  [5687] = 5511,
  [5688] = 5688,
  [5689] = 5635,
  [5690] = 5690,
  [5691] = 5691,
  [5692] = 5645,
  [5693] = 5481,
  [5694] = 5510,
  [5695] = 5642,
  [5696] = 5681,
  [5697] = 5583,
  [5698] = 5492,
  [5699] = 5540,
  [5700] = 5635,
  [5701] = 5497,
  [5702] = 5502,
  [5703] = 5512,
  [5704] = 5665,
  [5705] = 5648,
  [5706] = 5546,
  [5707] = 5638,
  [5708] = 5489,
  [5709] = 5493,
  [5710] = 5710,
  [5711] = 5547,
  [5712] = 5650,
  [5713] = 5659,
  [5714] = 5660,
  [5715] = 5691,
  [5716] = 5645,
  [5717] = 5583,
  [5718] = 5583,
  [5719] = 5497,
  [5720] = 5502,
  [5721] = 5512,
  [5722] = 5722,
  [5723] = 5562,
  [5724] = 5501,
  [5725] = 5642,
  [5726] = 5565,
  [5727] = 5650,
  [5728] = 5546,
  [5729] = 5729,
  [5730] = 5730,
  [5731] = 5617,
  [5732] = 5484,
  [5733] = 5602,
  [5734] = 5490,
  [5735] = 5735,
  [5736] = 5736,
  [5737] = 5596,
  [5738] = 5530,
  [5739] = 5739,
  [5740] = 5603,
  [5741] = 5470,
  [5742] = 5607,
  [5743] = 5659,
  [5744] = 5645,
  [5745] = 5611,
  [5746] = 5484,
  [5747] = 5501,
  [5748] = 5748,
  [5749] = 5546,
  [5750] = 5750,
  [5751] = 5542,
  [5752] = 5476,
  [5753] = 5635,
  [5754] = 5638,
  [5755] = 5466,
  [5756] = 5691,
  [5757] = 5642,
  [5758] = 5489,
  [5759] = 5596,
  [5760] = 5479,
  [5761] = 5603,
  [5762] = 5480,
  [5763] = 5607,
  [5764] = 5481,
  [5765] = 5650,
  [5766] = 5659,
  [5767] = 5660,
  [5768] = 5476,
  [5769] = 5472,
  [5770] = 5496,
  [5771] = 5466,
  [5772] = 5660,
  [5773] = 5492,
  [5774] = 5476,
  [5775] = 5665,
  [5776] = 5479,
  [5777] = 5495,
  [5778] = 5480,
  [5779] = 5481,
  [5780] = 5513,
  [5781] = 5611,
  [5782] = 5644,
  [5783] = 5489,
  [5784] = 5510,
  [5785] = 5471,
  [5786] = 5681,
  [5787] = 5496,
  [5788] = 5489,
  [5789] = 5538,
  [5790] = 5476,
  [5791] = 5540,
  [5792] = 5792,
  [5793] = 5793,
  [5794] = 5691,
  [5795] = 5635,
  [5796] = 5474,
  [5797] = 5645,
  [5798] = 5638,
  [5799] = 5583,
  [5800] = 5466,
  [5801] = 5553,
  [5802] = 5642,
  [5803] = 5492,
  [5804] = 5650,
  [5805] = 5538,
  [5806] = 5497,
  [5807] = 5502,
  [5808] = 5659,
  [5809] = 5512,
  [5810] = 5660,
  [5811] = 5546,
  [5812] = 5812,
  [5813] = 5813,
  [5814] = 5481,
  [5815] = 5492,
  [5816] = 5538,
  [5817] = 5812,
  [5818] = 5617,
  [5819] = 5681,
  [5820] = 5820,
  [5821] = 5466,
  [5822] = 5813,
  [5823] = 5492,
  [5824] = 5496,
  [5825] = 5479,
  [5826] = 5826,
  [5827] = 5492,
  [5828] = 5521,
  [5829] = 5479,
  [5830] = 5617,
  [5831] = 5480,
  [5832] = 5665,
  [5833] = 5471,
  [5834] = 5481,
  [5835] = 5498,
  [5836] = 5729,
  [5837] = 5487,
  [5838] = 5750,
  [5839] = 5488,
  [5840] = 5475,
  [5841] = 5665,
  [5842] = 5538,
  [5843] = 5617,
  [5844] = 5844,
  [5845] = 5845,
  [5846] = 5510,
  [5847] = 5739,
  [5848] = 5548,
  [5849] = 5597,
  [5850] = 5793,
  [5851] = 5710,
  [5852] = 5681,
  [5853] = 5484,
  [5854] = 5826,
  [5855] = 5516,
  [5856] = 5617,
  [5857] = 5584,
  [5858] = 5665,
  [5859] = 5479,
  [5860] = 5467,
  [5861] = 5501,
  [5862] = 5540,
  [5863] = 5863,
  [5864] = 5691,
  [5865] = 5538,
  [5866] = 5502,
  [5867] = 5489,
  [5868] = 5548,
  [5869] = 5638,
};

static TSCharacterRange extras_character_set_1[] = {
  {'\t', '\r'}, {' ', ' '}, {0xa0, 0xa0}, {0x1680, 0x1680}, {0x2000, 0x200b}, {0x2028, 0x2029}, {0x202f, 0x202f}, {0x205f, 0x2060},
  {0x3000, 0x3000}, {0xfeff, 0xfeff},
};

static TSCharacterRange sym_identifier_character_set_1[] = {
  {'$', '$'}, {'A', 'Z'}, {'\\', '\\'}, {'_', '_'}, {'a', 'z'}, {0x7f, 0x9f}, {0xa1, 0x167f}, {0x1681, 0x1fff},
  {0x200c, 0x2027}, {0x202a, 0x202e}, {0x2030, 0x205e}, {0x2061, 0x2fff}, {0x3001, 0xfefe}, {0xff00, 0x10ffff},
};

static TSCharacterRange sym_identifier_character_set_2[] = {
  {'$', '$'}, {'0', '9'}, {'A', 'Z'}, {'\\', '\\'}, {'_', '_'}, {'a', 'z'}, {0x7f, 0x9f}, {0xa1, 0x167f},
  {0x1681, 0x1fff}, {0x200c, 0x2027}, {0x202a, 0x202e}, {0x2030, 0x205e}, {0x2061, 0x2fff}, {0x3001, 0xfefe}, {0xff00, 0x10ffff},
};

static bool ts_lex(TSLexer *lexer, TSStateId state) {
  START_LEXER();
  eof = lexer->eof(lexer);
  switch (state) {
    case 0:
      if (eof) ADVANCE(76);
      ADVANCE_MAP(
        '!', 89,
        '"', 169,
        '#', 6,
        '$', 206,
        '%', 149,
        '&', 128,
        '\'', 170,
        '(', 90,
        ')', 92,
        '*', 79,
        '+', 141,
        ',', 86,
        '-', 145,
        '.', 97,
        '/', 192,
        '0', 197,
        ':', 93,
        ';', 91,
        '<', 153,
        '=', 82,
        '>', 162,
        '?', 212,
        '@', 209,
        '[', 94,
        '\\', 33,
        ']', 95,
        '^', 131,
        '`', 190,
        '{', 85,
        '|', 134,
        '}', 87,
        '~', 166,
      );
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(198);
      if (set_contains(extras_character_set_1, 10, lookahead)) SKIP(73);
      if (lookahead > '@') ADVANCE(207);
      END_STATE();
    case 1:
      if (lookahead == '\n') SKIP(24);
      if (lookahead == '/') ADVANCE(17);
      if (lookahead == '[') ADVANCE(32);
      if (lookahead == '\\') ADVANCE(72);
      if (set_contains(extras_character_set_1, 10, lookahead)) ADVANCE(193);
      if (lookahead != 0) ADVANCE(194);
      END_STATE();
    case 2:
      ADVANCE_MAP(
        '!', 89,
        '"', 169,
        '#', 31,
        '%', 149,
        '&', 128,
        '\'', 170,
        '(', 90,
        ')', 92,
        '*', 79,
        '+', 140,
        ',', 86,
        '-', 144,
        '.', 97,
        '/', 147,
        '0', 197,
        ':', 93,
        ';', 91,
        '<', 153,
        '=', 82,
        '>', 162,
        '?', 212,
        '@', 209,
        '[', 94,
        '\\', 35,
        ']', 95,
        '^', 131,
        '`', 190,
        '{', 85,
        '|', 134,
        '}', 87,
        '~', 166,
      );
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(198);
      if (set_contains(extras_character_set_1, 10, lookahead)) SKIP(2);
      if (lookahead > '#') ADVANCE(207);
      END_STATE();
    case 3:
      ADVANCE_MAP(
        '!', 89,
        '"', 169,
        '#', 31,
        '%', 149,
        '&', 128,
        '\'', 170,
        '(', 90,
        ')', 92,
        '*', 79,
        '+', 140,
        ',', 86,
        '-', 144,
        '.', 97,
        '/', 147,
        '0', 197,
        ':', 93,
        ';', 91,
        '<', 153,
        '=', 82,
        '>', 162,
        '?', 212,
        '@', 209,
        '[', 94,
        '\\', 35,
        ']', 95,
        '^', 131,
        '`', 190,
        '{', 84,
        '|', 133,
        '}', 87,
        '~', 166,
      );
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(198);
      if (set_contains(extras_character_set_1, 10, lookahead)) SKIP(3);
      if (lookahead > '#') ADVANCE(207);
      END_STATE();
    case 4:
      ADVANCE_MAP(
        '!', 89,
        '%', 148,
        '&', 129,
        '(', 90,
        ')', 92,
        '*', 80,
        '+', 139,
        ',', 86,
        '-', 143,
        '.', 96,
        '/', 146,
        ':', 93,
        ';', 91,
        '<', 154,
        '=', 28,
        '>', 163,
        '?', 21,
        '[', 94,
        '\\', 35,
        ']', 95,
        '^', 130,
        '`', 190,
        '{', 84,
        '|', 135,
        '}', 87,
      );
      if (('a' <= lookahead && lookahead <= 'z')) ADVANCE(195);
      if (set_contains(extras_character_set_1, 10, lookahead)) SKIP(5);
      if (lookahead > '#' &&
          (lookahead < '%' || '@' < lookahead) &&
          (lookahead < '`' || '~' < lookahead)) ADVANCE(207);
      END_STATE();
    case 5:
      ADVANCE_MAP(
        '!', 89,
        '%', 148,
        '&', 129,
        '(', 90,
        ')', 92,
        '*', 80,
        '+', 139,
        ',', 86,
        '-', 143,
        '.', 96,
        '/', 146,
        ':', 93,
        ';', 91,
        '<', 154,
        '=', 28,
        '>', 163,
        '?', 21,
        '[', 94,
        '\\', 35,
        ']', 95,
        '^', 130,
        '`', 190,
        '{', 84,
        '|', 135,
        '}', 87,
      );
      if (set_contains(extras_character_set_1, 10, lookahead)) SKIP(5);
      if (lookahead > '#' &&
          (lookahead < '%' || '@' < lookahead) &&
          (lookahead < '{' || '~' < lookahead)) ADVANCE(207);
      END_STATE();
    case 6:
      if (lookahead == '!') ADVANCE(77);
      if (lookahead == '\\') ADVANCE(34);
      if (set_contains(sym_identifier_character_set_1, 14, lookahead)) ADVANCE(208);
      END_STATE();
    case 7:
      ADVANCE_MAP(
        '!', 88,
        '"', 169,
        '#', 31,
        '&', 127,
        '\'', 170,
        '(', 90,
        ')', 92,
        '*', 78,
        '+', 139,
        ',', 86,
        '-', 143,
        '.', 97,
        '/', 146,
        '0', 197,
        ':', 93,
        ';', 91,
        '<', 152,
        '=', 83,
        '>', 161,
        '?', 211,
        '@', 209,
        '[', 94,
        '\\', 35,
        ']', 95,
        '`', 190,
        '{', 84,
        '|', 137,
        '}', 87,
        '~', 166,
      );
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(198);
      if (set_contains(extras_character_set_1, 10, lookahead)) SKIP(7);
      if (lookahead > '#' &&
          (lookahead < '%' || '@' < lookahead) &&
          (lookahead < '[' || '^' < lookahead)) ADVANCE(207);
      END_STATE();
    case 8:
      ADVANCE_MAP(
        '!', 88,
        '"', 169,
        '#', 31,
        '&', 127,
        '\'', 170,
        '(', 90,
        ')', 92,
        '*', 78,
        '+', 139,
        ',', 86,
        '-', 143,
        '.', 97,
        '/', 146,
        '0', 197,
        '<', 152,
        '?', 210,
        '@', 209,
        '[', 94,
        '\\', 35,
        ']', 95,
        '`', 190,
        '{', 85,
        '|', 132,
        '~', 166,
      );
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(198);
      if (set_contains(extras_character_set_1, 10, lookahead)) SKIP(8);
      if (lookahead > '#' &&
          (lookahead < '%' || '@' < lookahead) &&
          (lookahead < '[' || '^' < lookahead) &&
          (lookahead < '{' || '~' < lookahead)) ADVANCE(207);
      END_STATE();
    case 9:
      ADVANCE_MAP(
        '"', 169,
        '#', 31,
        '&', 127,
        '\'', 170,
        '(', 90,
        '*', 78,
        '+', 138,
        ',', 86,
        '-', 142,
        '.', 20,
        '/', 17,
        '0', 197,
        ';', 91,
        '<', 152,
        '>', 161,
        '?', 210,
        '@', 209,
        '[', 94,
        '\\', 35,
        ']', 95,
        '`', 190,
        '{', 85,
        '|', 137,
        '}', 87,
      );
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(198);
      if (set_contains(extras_character_set_1, 10, lookahead)) SKIP(9);
      if (lookahead > '#' &&
          (lookahead < '%' || '@' < lookahead) &&
          (lookahead < '[' || '^' < lookahead) &&
          (lookahead < '{' || '~' < lookahead)) ADVANCE(207);
      END_STATE();
    case 10:
      ADVANCE_MAP(
        '"', 169,
        '#', 31,
        '\'', 170,
        '(', 90,
        '*', 78,
        '+', 138,
        ',', 86,
        '-', 142,
        '.', 20,
        '/', 17,
        '0', 197,
        ';', 91,
        '<', 152,
        '@', 209,
        '[', 94,
        '\\', 35,
        '{', 84,
        '|', 45,
        '}', 87,
      );
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(198);
      if (set_contains(extras_character_set_1, 10, lookahead)) SKIP(10);
      if (lookahead > '#' &&
          (lookahead < '%' || '@' < lookahead) &&
          (lookahead < '[' || '^' < lookahead) &&
          lookahead != '`' &&
          (lookahead < '{' || '~' < lookahead)) ADVANCE(207);
      END_STATE();
    case 11:
      if (lookahead == '"') ADVANCE(169);
      if (lookahead == '/') ADVANCE(17);
      if (set_contains(extras_character_set_1, 10, lookahead)) SKIP(11);
      END_STATE();
    case 12:
      if (lookahead == '"') ADVANCE(169);
      if (lookahead == '/') ADVANCE(171);
      if (lookahead == '\\') ADVANCE(36);
      if (lookahead == '\n' ||
          lookahead == '\r') SKIP(11);
      if (set_contains(extras_character_set_1, 10, lookahead)) ADVANCE(174);
      if (lookahead != 0) ADVANCE(176);
      END_STATE();
    case 13:
      ADVANCE_MAP(
        '$', 37,
        '+', 29,
        '-', 30,
        '/', 17,
        ':', 93,
        '?', 27,
        '\\', 36,
        '`', 190,
      );
      if (set_contains(extras_character_set_1, 10, lookahead)) SKIP(14);
      END_STATE();
    case 14:
      if (lookahead == '$') ADVANCE(37);
      if (lookahead == '+') ADVANCE(29);
      if (lookahead == '-') ADVANCE(30);
      if (lookahead == '/') ADVANCE(17);
      if (lookahead == ':') ADVANCE(93);
      if (lookahead == '?') ADVANCE(27);
      if (lookahead == '`') ADVANCE(190);
      if (set_contains(extras_character_set_1, 10, lookahead)) SKIP(14);
      END_STATE();
    case 15:
      if (lookahead == '\'') ADVANCE(170);
      if (lookahead == '/') ADVANCE(17);
      if (set_contains(extras_character_set_1, 10, lookahead)) SKIP(15);
      END_STATE();
    case 16:
      if (lookahead == '\'') ADVANCE(170);
      if (lookahead == '/') ADVANCE(177);
      if (lookahead == '\\') ADVANCE(36);
      if (lookahead == '\n' ||
          lookahead == '\r') SKIP(15);
      if (set_contains(extras_character_set_1, 10, lookahead)) ADVANCE(180);
      if (lookahead != 0) ADVANCE(182);
      END_STATE();
    case 17:
      if (lookahead == '*') ADVANCE(19);
      if (lookahead == '/') ADVANCE(189);
      END_STATE();
    case 18:
      if (lookahead == '*') ADVANCE(18);
      if (lookahead == '/') ADVANCE(188);
      if (lookahead != 0) ADVANCE(19);
      END_STATE();
    case 19:
      if (lookahead == '*') ADVANCE(18);
      if (lookahead != 0) ADVANCE(19);
      END_STATE();
    case 20:
      if (lookahead == '.') ADVANCE(22);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(203);
      END_STATE();
    case 21:
      if (lookahead == '.') ADVANCE(100);
      if (lookahead == '?') ADVANCE(164);
      END_STATE();
    case 22:
      if (lookahead == '.') ADVANCE(116);
      END_STATE();
    case 23:
      if (lookahead == '/') ADVANCE(192);
      if (set_contains(extras_character_set_1, 10, lookahead)) SKIP(24);
      END_STATE();
    case 24:
      if (lookahead == '/') ADVANCE(17);
      if (set_contains(extras_character_set_1, 10, lookahead)) SKIP(24);
      END_STATE();
    case 25:
      if (lookahead == ':') ADVANCE(215);
      END_STATE();
    case 26:
      if (lookahead == ':') ADVANCE(214);
      END_STATE();
    case 27:
      if (lookahead == ':') ADVANCE(216);
      END_STATE();
    case 28:
      if (lookahead == '=') ADVANCE(156);
      END_STATE();
    case 29:
      if (lookahead == '?') ADVANCE(25);
      END_STATE();
    case 30:
      if (lookahead == '?') ADVANCE(26);
      END_STATE();
    case 31:
      if (lookahead == '\\') ADVANCE(34);
      if (set_contains(sym_identifier_character_set_1, 14, lookahead)) ADVANCE(208);
      END_STATE();
    case 32:
      if (lookahead == '\\') ADVANCE(71);
      if (lookahead == ']') ADVANCE(194);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(32);
      END_STATE();
    case 33:
      if (lookahead == 'u') ADVANCE(38);
      if (lookahead == 'x') ADVANCE(63);
      if (lookahead == '\r' ||
          lookahead == '?') ADVANCE(185);
      if (('0' <= lookahead && lookahead <= '7')) ADVANCE(187);
      if (lookahead != 0) ADVANCE(183);
      END_STATE();
    case 34:
      if (lookahead == 'u') ADVANCE(39);
      END_STATE();
    case 35:
      if (lookahead == 'u') ADVANCE(40);
      END_STATE();
    case 36:
      if (lookahead == 'u') ADVANCE(41);
      if (lookahead == 'x') ADVANCE(63);
      if (lookahead == '\r' ||
          lookahead == '?') ADVANCE(185);
      if (('0' <= lookahead && lookahead <= '7')) ADVANCE(187);
      if (lookahead != 0) ADVANCE(183);
      END_STATE();
    case 37:
      if (lookahead == '{') ADVANCE(191);
      END_STATE();
    case 38:
      if (lookahead == '{') ADVANCE(58);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(68);
      END_STATE();
    case 39:
      if (lookahead == '{') ADVANCE(61);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(69);
      END_STATE();
    case 40:
      if (lookahead == '{') ADVANCE(62);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(70);
      END_STATE();
    case 41:
      if (lookahead == '{') ADVANCE(64);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(60);
      END_STATE();
    case 42:
      if (lookahead == '}') ADVANCE(207);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(42);
      END_STATE();
    case 43:
      if (lookahead == '}') ADVANCE(208);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(43);
      END_STATE();
    case 44:
      if (lookahead == '}') ADVANCE(183);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(44);
      END_STATE();
    case 45:
      if (lookahead == '}') ADVANCE(218);
      END_STATE();
    case 46:
      if (lookahead == '}') ADVANCE(184);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(46);
      END_STATE();
    case 47:
      if (lookahead == '+' ||
          lookahead == '-') ADVANCE(53);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(204);
      END_STATE();
    case 48:
      if (lookahead == '0' ||
          lookahead == '1') ADVANCE(200);
      END_STATE();
    case 49:
      if (('0' <= lookahead && lookahead <= '7')) ADVANCE(201);
      END_STATE();
    case 50:
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(198);
      END_STATE();
    case 51:
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(203);
      END_STATE();
    case 52:
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(199);
      END_STATE();
    case 53:
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(204);
      END_STATE();
    case 54:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(207);
      END_STATE();
    case 55:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(208);
      END_STATE();
    case 56:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(183);
      END_STATE();
    case 57:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(202);
      END_STATE();
    case 58:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(46);
      END_STATE();
    case 59:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(184);
      END_STATE();
    case 60:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(63);
      END_STATE();
    case 61:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(43);
      END_STATE();
    case 62:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(42);
      END_STATE();
    case 63:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(56);
      END_STATE();
    case 64:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(44);
      END_STATE();
    case 65:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(59);
      END_STATE();
    case 66:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(55);
      END_STATE();
    case 67:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(54);
      END_STATE();
    case 68:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(65);
      END_STATE();
    case 69:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(66);
      END_STATE();
    case 70:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(67);
      END_STATE();
    case 71:
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(32);
      END_STATE();
    case 72:
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(194);
      END_STATE();
    case 73:
      if (eof) ADVANCE(76);
      ADVANCE_MAP(
        '!', 89,
        '"', 169,
        '#', 6,
        '$', 206,
        '%', 149,
        '&', 128,
        '\'', 170,
        '(', 90,
        ')', 92,
        '*', 79,
        '+', 141,
        ',', 86,
        '-', 145,
        '.', 97,
        '/', 147,
        '0', 197,
        ':', 93,
        ';', 91,
        '<', 153,
        '=', 82,
        '>', 162,
        '?', 212,
        '@', 209,
        '[', 94,
        '\\', 35,
        ']', 95,
        '^', 131,
        '`', 190,
        '{', 85,
        '|', 134,
        '}', 87,
        '~', 166,
      );
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(198);
      if (set_contains(extras_character_set_1, 10, lookahead)) SKIP(73);
      if (lookahead > '@') ADVANCE(207);
      END_STATE();
    case 74:
      if (eof) ADVANCE(76);
      ADVANCE_MAP(
        '!', 89,
        '"', 169,
        '#', 31,
        '%', 148,
        '&', 129,
        '\'', 170,
        '(', 90,
        ')', 92,
        '*', 80,
        '+', 139,
        ',', 86,
        '-', 143,
        '.', 98,
        '/', 146,
        '0', 197,
        ':', 93,
        ';', 91,
        '<', 154,
        '=', 81,
        '>', 163,
        '?', 213,
        '@', 209,
        '[', 94,
        '\\', 35,
        ']', 95,
        '^', 130,
        '`', 190,
        '{', 84,
        '|', 136,
        '}', 87,
        '~', 166,
      );
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(198);
      if (set_contains(extras_character_set_1, 10, lookahead)) SKIP(74);
      if (lookahead > '#') ADVANCE(207);
      END_STATE();
    case 75:
      if (eof) ADVANCE(76);
      ADVANCE_MAP(
        '!', 88,
        '"', 169,
        '#', 6,
        '&', 127,
        '\'', 170,
        '(', 90,
        ')', 92,
        '*', 78,
        '+', 139,
        ',', 86,
        '-', 143,
        '.', 97,
        '/', 146,
        '0', 197,
        ':', 93,
        ';', 91,
        '<', 152,
        '=', 83,
        '>', 161,
        '?', 210,
        '@', 209,
        '[', 94,
        '\\', 35,
        ']', 95,
        '`', 190,
        '{', 84,
        '|', 137,
        '}', 87,
        '~', 166,
      );
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(198);
      if (set_contains(extras_character_set_1, 10, lookahead)) SKIP(75);
      if (lookahead > '#' &&
          (lookahead < '%' || '@' < lookahead) &&
          (lookahead < '[' || '^' < lookahead)) ADVANCE(207);
      END_STATE();
    case 76:
      ACCEPT_TOKEN(ts_builtin_sym_end);
      END_STATE();
    case 77:
      ACCEPT_TOKEN(sym_hash_bang_line);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(77);
      END_STATE();
    case 78:
      ACCEPT_TOKEN(anon_sym_STAR);
      END_STATE();
    case 79:
      ACCEPT_TOKEN(anon_sym_STAR);
      if (lookahead == '*') ADVANCE(151);
      if (lookahead == '=') ADVANCE(103);
      END_STATE();
    case 80:
      ACCEPT_TOKEN(anon_sym_STAR);
      if (lookahead == '*') ADVANCE(150);
      END_STATE();
    case 81:
      ACCEPT_TOKEN(anon_sym_EQ);
      if (lookahead == '=') ADVANCE(156);
      END_STATE();
    case 82:
      ACCEPT_TOKEN(anon_sym_EQ);
      if (lookahead == '=') ADVANCE(156);
      if (lookahead == '>') ADVANCE(99);
      END_STATE();
    case 83:
      ACCEPT_TOKEN(anon_sym_EQ);
      if (lookahead == '>') ADVANCE(99);
      END_STATE();
    case 84:
      ACCEPT_TOKEN(anon_sym_LBRACE);
      END_STATE();
    case 85:
      ACCEPT_TOKEN(anon_sym_LBRACE);
      if (lookahead == '|') ADVANCE(217);
      END_STATE();
    case 86:
      ACCEPT_TOKEN(anon_sym_COMMA);
      END_STATE();
    case 87:
      ACCEPT_TOKEN(anon_sym_RBRACE);
      END_STATE();
    case 88:
      ACCEPT_TOKEN(anon_sym_BANG);
      END_STATE();
    case 89:
      ACCEPT_TOKEN(anon_sym_BANG);
      if (lookahead == '=') ADVANCE(158);
      END_STATE();
    case 90:
      ACCEPT_TOKEN(anon_sym_LPAREN);
      END_STATE();
    case 91:
      ACCEPT_TOKEN(anon_sym_SEMI);
      END_STATE();
    case 92:
      ACCEPT_TOKEN(anon_sym_RPAREN);
      END_STATE();
    case 93:
      ACCEPT_TOKEN(anon_sym_COLON);
      END_STATE();
    case 94:
      ACCEPT_TOKEN(anon_sym_LBRACK);
      END_STATE();
    case 95:
      ACCEPT_TOKEN(anon_sym_RBRACK);
      END_STATE();
    case 96:
      ACCEPT_TOKEN(anon_sym_DOT);
      END_STATE();
    case 97:
      ACCEPT_TOKEN(anon_sym_DOT);
      if (lookahead == '.') ADVANCE(22);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(203);
      END_STATE();
    case 98:
      ACCEPT_TOKEN(anon_sym_DOT);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(203);
      END_STATE();
    case 99:
      ACCEPT_TOKEN(anon_sym_EQ_GT);
      END_STATE();
    case 100:
      ACCEPT_TOKEN(anon_sym_QMARK_DOT);
      END_STATE();
    case 101:
      ACCEPT_TOKEN(anon_sym_PLUS_EQ);
      END_STATE();
    case 102:
      ACCEPT_TOKEN(anon_sym_DASH_EQ);
      END_STATE();
    case 103:
      ACCEPT_TOKEN(anon_sym_STAR_EQ);
      END_STATE();
    case 104:
      ACCEPT_TOKEN(anon_sym_SLASH_EQ);
      END_STATE();
    case 105:
      ACCEPT_TOKEN(anon_sym_PERCENT_EQ);
      END_STATE();
    case 106:
      ACCEPT_TOKEN(anon_sym_CARET_EQ);
      END_STATE();
    case 107:
      ACCEPT_TOKEN(anon_sym_AMP_EQ);
      END_STATE();
    case 108:
      ACCEPT_TOKEN(anon_sym_PIPE_EQ);
      END_STATE();
    case 109:
      ACCEPT_TOKEN(anon_sym_GT_GT_EQ);
      END_STATE();
    case 110:
      ACCEPT_TOKEN(anon_sym_GT_GT_GT_EQ);
      END_STATE();
    case 111:
      ACCEPT_TOKEN(anon_sym_LT_LT_EQ);
      END_STATE();
    case 112:
      ACCEPT_TOKEN(anon_sym_STAR_STAR_EQ);
      END_STATE();
    case 113:
      ACCEPT_TOKEN(anon_sym_AMP_AMP_EQ);
      END_STATE();
    case 114:
      ACCEPT_TOKEN(anon_sym_PIPE_PIPE_EQ);
      END_STATE();
    case 115:
      ACCEPT_TOKEN(anon_sym_QMARK_QMARK_EQ);
      END_STATE();
    case 116:
      ACCEPT_TOKEN(anon_sym_DOT_DOT_DOT);
      END_STATE();
    case 117:
      ACCEPT_TOKEN(anon_sym_AMP_AMP);
      END_STATE();
    case 118:
      ACCEPT_TOKEN(anon_sym_AMP_AMP);
      if (lookahead == '=') ADVANCE(113);
      END_STATE();
    case 119:
      ACCEPT_TOKEN(anon_sym_PIPE_PIPE);
      END_STATE();
    case 120:
      ACCEPT_TOKEN(anon_sym_PIPE_PIPE);
      if (lookahead == '=') ADVANCE(114);
      END_STATE();
    case 121:
      ACCEPT_TOKEN(anon_sym_GT_GT);
      if (lookahead == '=') ADVANCE(109);
      if (lookahead == '>') ADVANCE(124);
      END_STATE();
    case 122:
      ACCEPT_TOKEN(anon_sym_GT_GT);
      if (lookahead == '>') ADVANCE(123);
      END_STATE();
    case 123:
      ACCEPT_TOKEN(anon_sym_GT_GT_GT);
      END_STATE();
    case 124:
      ACCEPT_TOKEN(anon_sym_GT_GT_GT);
      if (lookahead == '=') ADVANCE(110);
      END_STATE();
    case 125:
      ACCEPT_TOKEN(anon_sym_LT_LT);
      END_STATE();
    case 126:
      ACCEPT_TOKEN(anon_sym_LT_LT);
      if (lookahead == '=') ADVANCE(111);
      END_STATE();
    case 127:
      ACCEPT_TOKEN(anon_sym_AMP);
      END_STATE();
    case 128:
      ACCEPT_TOKEN(anon_sym_AMP);
      if (lookahead == '&') ADVANCE(118);
      if (lookahead == '=') ADVANCE(107);
      END_STATE();
    case 129:
      ACCEPT_TOKEN(anon_sym_AMP);
      if (lookahead == '&') ADVANCE(117);
      END_STATE();
    case 130:
      ACCEPT_TOKEN(anon_sym_CARET);
      END_STATE();
    case 131:
      ACCEPT_TOKEN(anon_sym_CARET);
      if (lookahead == '=') ADVANCE(106);
      END_STATE();
    case 132:
      ACCEPT_TOKEN(anon_sym_PIPE);
      END_STATE();
    case 133:
      ACCEPT_TOKEN(anon_sym_PIPE);
      if (lookahead == '=') ADVANCE(108);
      if (lookahead == '|') ADVANCE(120);
      END_STATE();
    case 134:
      ACCEPT_TOKEN(anon_sym_PIPE);
      if (lookahead == '=') ADVANCE(108);
      if (lookahead == '|') ADVANCE(120);
      if (lookahead == '}') ADVANCE(218);
      END_STATE();
    case 135:
      ACCEPT_TOKEN(anon_sym_PIPE);
      if (lookahead == '|') ADVANCE(119);
      END_STATE();
    case 136:
      ACCEPT_TOKEN(anon_sym_PIPE);
      if (lookahead == '|') ADVANCE(119);
      if (lookahead == '}') ADVANCE(218);
      END_STATE();
    case 137:
      ACCEPT_TOKEN(anon_sym_PIPE);
      if (lookahead == '}') ADVANCE(218);
      END_STATE();
    case 138:
      ACCEPT_TOKEN(anon_sym_PLUS);
      END_STATE();
    case 139:
      ACCEPT_TOKEN(anon_sym_PLUS);
      if (lookahead == '+') ADVANCE(167);
      END_STATE();
    case 140:
      ACCEPT_TOKEN(anon_sym_PLUS);
      if (lookahead == '+') ADVANCE(167);
      if (lookahead == '=') ADVANCE(101);
      END_STATE();
    case 141:
      ACCEPT_TOKEN(anon_sym_PLUS);
      if (lookahead == '+') ADVANCE(167);
      if (lookahead == '=') ADVANCE(101);
      if (lookahead == '?') ADVANCE(25);
      END_STATE();
    case 142:
      ACCEPT_TOKEN(anon_sym_DASH);
      END_STATE();
    case 143:
      ACCEPT_TOKEN(anon_sym_DASH);
      if (lookahead == '-') ADVANCE(168);
      END_STATE();
    case 144:
      ACCEPT_TOKEN(anon_sym_DASH);
      if (lookahead == '-') ADVANCE(168);
      if (lookahead == '=') ADVANCE(102);
      END_STATE();
    case 145:
      ACCEPT_TOKEN(anon_sym_DASH);
      if (lookahead == '-') ADVANCE(168);
      if (lookahead == '=') ADVANCE(102);
      if (lookahead == '?') ADVANCE(26);
      END_STATE();
    case 146:
      ACCEPT_TOKEN(anon_sym_SLASH);
      if (lookahead == '*') ADVANCE(19);
      if (lookahead == '/') ADVANCE(189);
      END_STATE();
    case 147:
      ACCEPT_TOKEN(anon_sym_SLASH);
      if (lookahead == '*') ADVANCE(19);
      if (lookahead == '/') ADVANCE(189);
      if (lookahead == '=') ADVANCE(104);
      END_STATE();
    case 148:
      ACCEPT_TOKEN(anon_sym_PERCENT);
      END_STATE();
    case 149:
      ACCEPT_TOKEN(anon_sym_PERCENT);
      if (lookahead == '=') ADVANCE(105);
      END_STATE();
    case 150:
      ACCEPT_TOKEN(anon_sym_STAR_STAR);
      END_STATE();
    case 151:
      ACCEPT_TOKEN(anon_sym_STAR_STAR);
      if (lookahead == '=') ADVANCE(112);
      END_STATE();
    case 152:
      ACCEPT_TOKEN(anon_sym_LT);
      END_STATE();
    case 153:
      ACCEPT_TOKEN(anon_sym_LT);
      if (lookahead == '<') ADVANCE(126);
      if (lookahead == '=') ADVANCE(155);
      END_STATE();
    case 154:
      ACCEPT_TOKEN(anon_sym_LT);
      if (lookahead == '<') ADVANCE(125);
      if (lookahead == '=') ADVANCE(155);
      END_STATE();
    case 155:
      ACCEPT_TOKEN(anon_sym_LT_EQ);
      END_STATE();
    case 156:
      ACCEPT_TOKEN(anon_sym_EQ_EQ);
      if (lookahead == '=') ADVANCE(157);
      END_STATE();
    case 157:
      ACCEPT_TOKEN(anon_sym_EQ_EQ_EQ);
      END_STATE();
    case 158:
      ACCEPT_TOKEN(anon_sym_BANG_EQ);
      if (lookahead == '=') ADVANCE(159);
      END_STATE();
    case 159:
      ACCEPT_TOKEN(anon_sym_BANG_EQ_EQ);
      END_STATE();
    case 160:
      ACCEPT_TOKEN(anon_sym_GT_EQ);
      END_STATE();
    case 161:
      ACCEPT_TOKEN(anon_sym_GT);
      END_STATE();
    case 162:
      ACCEPT_TOKEN(anon_sym_GT);
      if (lookahead == '=') ADVANCE(160);
      if (lookahead == '>') ADVANCE(121);
      END_STATE();
    case 163:
      ACCEPT_TOKEN(anon_sym_GT);
      if (lookahead == '=') ADVANCE(160);
      if (lookahead == '>') ADVANCE(122);
      END_STATE();
    case 164:
      ACCEPT_TOKEN(anon_sym_QMARK_QMARK);
      END_STATE();
    case 165:
      ACCEPT_TOKEN(anon_sym_QMARK_QMARK);
      if (lookahead == '=') ADVANCE(115);
      END_STATE();
    case 166:
      ACCEPT_TOKEN(anon_sym_TILDE);
      END_STATE();
    case 167:
      ACCEPT_TOKEN(anon_sym_PLUS_PLUS);
      END_STATE();
    case 168:
      ACCEPT_TOKEN(anon_sym_DASH_DASH);
      END_STATE();
    case 169:
      ACCEPT_TOKEN(anon_sym_DQUOTE);
      END_STATE();
    case 170:
      ACCEPT_TOKEN(anon_sym_SQUOTE);
      END_STATE();
    case 171:
      ACCEPT_TOKEN(sym_unescaped_double_string_fragment);
      if (lookahead == '*') ADVANCE(173);
      if (lookahead == '/') ADVANCE(175);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '\r' &&
          lookahead != '"' &&
          lookahead != '\\') ADVANCE(176);
      END_STATE();
    case 172:
      ACCEPT_TOKEN(sym_unescaped_double_string_fragment);
      if (lookahead == '*') ADVANCE(172);
      if (lookahead == '/') ADVANCE(176);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '\r' &&
          lookahead != '"' &&
          lookahead != '\\') ADVANCE(173);
      END_STATE();
    case 173:
      ACCEPT_TOKEN(sym_unescaped_double_string_fragment);
      if (lookahead == '*') ADVANCE(172);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '\r' &&
          lookahead != '"' &&
          lookahead != '\\') ADVANCE(173);
      END_STATE();
    case 174:
      ACCEPT_TOKEN(sym_unescaped_double_string_fragment);
      if (lookahead == '/') ADVANCE(171);
      if ((set_contains(extras_character_set_1, 10, lookahead)) &&
          lookahead != '\n' &&
          lookahead != '\r') ADVANCE(174);
      if (lookahead != 0 &&
          (lookahead < '\t' || '\r' < lookahead) &&
          lookahead != '"' &&
          lookahead != '\\') ADVANCE(176);
      END_STATE();
    case 175:
      ACCEPT_TOKEN(sym_unescaped_double_string_fragment);
      if (lookahead == 0x2028 ||
          lookahead == 0x2029) ADVANCE(176);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '\r' &&
          lookahead != '"' &&
          lookahead != '\\') ADVANCE(175);
      END_STATE();
    case 176:
      ACCEPT_TOKEN(sym_unescaped_double_string_fragment);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '\r' &&
          lookahead != '"' &&
          lookahead != '\\') ADVANCE(176);
      END_STATE();
    case 177:
      ACCEPT_TOKEN(sym_unescaped_single_string_fragment);
      if (lookahead == '*') ADVANCE(179);
      if (lookahead == '/') ADVANCE(181);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '\r' &&
          lookahead != '\'' &&
          lookahead != '\\') ADVANCE(182);
      END_STATE();
    case 178:
      ACCEPT_TOKEN(sym_unescaped_single_string_fragment);
      if (lookahead == '*') ADVANCE(178);
      if (lookahead == '/') ADVANCE(182);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '\r' &&
          lookahead != '\'' &&
          lookahead != '\\') ADVANCE(179);
      END_STATE();
    case 179:
      ACCEPT_TOKEN(sym_unescaped_single_string_fragment);
      if (lookahead == '*') ADVANCE(178);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '\r' &&
          lookahead != '\'' &&
          lookahead != '\\') ADVANCE(179);
      END_STATE();
    case 180:
      ACCEPT_TOKEN(sym_unescaped_single_string_fragment);
      if (lookahead == '/') ADVANCE(177);
      if ((set_contains(extras_character_set_1, 10, lookahead)) &&
          lookahead != '\n' &&
          lookahead != '\r') ADVANCE(180);
      if (lookahead != 0 &&
          (lookahead < '\t' || '\r' < lookahead) &&
          lookahead != '\'' &&
          lookahead != '\\') ADVANCE(182);
      END_STATE();
    case 181:
      ACCEPT_TOKEN(sym_unescaped_single_string_fragment);
      if (lookahead == 0x2028 ||
          lookahead == 0x2029) ADVANCE(182);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '\r' &&
          lookahead != '\'' &&
          lookahead != '\\') ADVANCE(181);
      END_STATE();
    case 182:
      ACCEPT_TOKEN(sym_unescaped_single_string_fragment);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '\r' &&
          lookahead != '\'' &&
          lookahead != '\\') ADVANCE(182);
      END_STATE();
    case 183:
      ACCEPT_TOKEN(sym_escape_sequence);
      END_STATE();
    case 184:
      ACCEPT_TOKEN(sym_escape_sequence);
      if (lookahead == '\\') ADVANCE(35);
      if (set_contains(sym_identifier_character_set_2, 15, lookahead)) ADVANCE(207);
      END_STATE();
    case 185:
      ACCEPT_TOKEN(sym_escape_sequence);
      if (lookahead == '\n' ||
          lookahead == 0x2028 ||
          lookahead == 0x2029) ADVANCE(183);
      END_STATE();
    case 186:
      ACCEPT_TOKEN(sym_escape_sequence);
      if (('0' <= lookahead && lookahead <= '7')) ADVANCE(183);
      END_STATE();
    case 187:
      ACCEPT_TOKEN(sym_escape_sequence);
      if (('0' <= lookahead && lookahead <= '7')) ADVANCE(186);
      END_STATE();
    case 188:
      ACCEPT_TOKEN(sym_comment);
      END_STATE();
    case 189:
      ACCEPT_TOKEN(sym_comment);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '\r' &&
          lookahead != 0x2028 &&
          lookahead != 0x2029) ADVANCE(189);
      END_STATE();
    case 190:
      ACCEPT_TOKEN(anon_sym_BQUOTE);
      END_STATE();
    case 191:
      ACCEPT_TOKEN(anon_sym_DOLLAR_LBRACE);
      END_STATE();
    case 192:
      ACCEPT_TOKEN(anon_sym_SLASH2);
      END_STATE();
    case 193:
      ACCEPT_TOKEN(sym_regex_pattern);
      if (lookahead == '\n') SKIP(24);
      if (lookahead == '/') ADVANCE(17);
      if (lookahead == '[') ADVANCE(32);
      if (lookahead == '\\') ADVANCE(72);
      if (set_contains(extras_character_set_1, 10, lookahead)) ADVANCE(193);
      if (lookahead != 0) ADVANCE(194);
      END_STATE();
    case 194:
      ACCEPT_TOKEN(sym_regex_pattern);
      if (lookahead == '[') ADVANCE(32);
      if (lookahead == '\\') ADVANCE(72);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '/') ADVANCE(194);
      END_STATE();
    case 195:
      ACCEPT_TOKEN(sym_regex_flags);
      if (lookahead == '\\') ADVANCE(35);
      if (('a' <= lookahead && lookahead <= 'z')) ADVANCE(195);
      if (set_contains(sym_identifier_character_set_2, 15, lookahead)) ADVANCE(207);
      END_STATE();
    case 196:
      ACCEPT_TOKEN(sym_number);
      END_STATE();
    case 197:
      ACCEPT_TOKEN(sym_number);
      ADVANCE_MAP(
        '.', 205,
        '0', 199,
        '_', 52,
        'n', 196,
        'B', 48,
        'b', 48,
        'E', 47,
        'e', 47,
        'O', 49,
        'o', 49,
        'X', 57,
        'x', 57,
      );
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(198);
      END_STATE();
    case 198:
      ACCEPT_TOKEN(sym_number);
      if (lookahead == '.') ADVANCE(205);
      if (lookahead == '_') ADVANCE(50);
      if (lookahead == 'n') ADVANCE(196);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(47);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(198);
      END_STATE();
    case 199:
      ACCEPT_TOKEN(sym_number);
      if (lookahead == '_') ADVANCE(52);
      if (lookahead == 'n') ADVANCE(196);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(199);
      END_STATE();
    case 200:
      ACCEPT_TOKEN(sym_number);
      if (lookahead == '_') ADVANCE(48);
      if (lookahead == 'n') ADVANCE(196);
      if (lookahead == '0' ||
          lookahead == '1') ADVANCE(200);
      END_STATE();
    case 201:
      ACCEPT_TOKEN(sym_number);
      if (lookahead == '_') ADVANCE(49);
      if (lookahead == 'n') ADVANCE(196);
      if (('0' <= lookahead && lookahead <= '7')) ADVANCE(201);
      END_STATE();
    case 202:
      ACCEPT_TOKEN(sym_number);
      if (lookahead == '_') ADVANCE(57);
      if (lookahead == 'n') ADVANCE(196);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(202);
      END_STATE();
    case 203:
      ACCEPT_TOKEN(sym_number);
      if (lookahead == '_') ADVANCE(51);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(47);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(203);
      END_STATE();
    case 204:
      ACCEPT_TOKEN(sym_number);
      if (lookahead == '_') ADVANCE(53);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(204);
      END_STATE();
    case 205:
      ACCEPT_TOKEN(sym_number);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(47);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(203);
      END_STATE();
    case 206:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '\\') ADVANCE(35);
      if (lookahead == '{') ADVANCE(191);
      if (set_contains(sym_identifier_character_set_2, 15, lookahead)) ADVANCE(207);
      END_STATE();
    case 207:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '\\') ADVANCE(35);
      if (set_contains(sym_identifier_character_set_2, 15, lookahead)) ADVANCE(207);
      END_STATE();
    case 208:
      ACCEPT_TOKEN(sym_private_property_identifier);
      if (lookahead == '\\') ADVANCE(34);
      if (set_contains(sym_identifier_character_set_2, 15, lookahead)) ADVANCE(208);
      END_STATE();
    case 209:
      ACCEPT_TOKEN(anon_sym_AT);
      END_STATE();
    case 210:
      ACCEPT_TOKEN(anon_sym_QMARK);
      END_STATE();
    case 211:
      ACCEPT_TOKEN(anon_sym_QMARK);
      if (lookahead == '.') ADVANCE(100);
      END_STATE();
    case 212:
      ACCEPT_TOKEN(anon_sym_QMARK);
      if (lookahead == '.') ADVANCE(100);
      if (lookahead == '?') ADVANCE(165);
      END_STATE();
    case 213:
      ACCEPT_TOKEN(anon_sym_QMARK);
      if (lookahead == '.') ADVANCE(100);
      if (lookahead == '?') ADVANCE(164);
      END_STATE();
    case 214:
      ACCEPT_TOKEN(anon_sym_DASH_QMARK_COLON);
      END_STATE();
    case 215:
      ACCEPT_TOKEN(anon_sym_PLUS_QMARK_COLON);
      END_STATE();
    case 216:
      ACCEPT_TOKEN(anon_sym_QMARK_COLON);
      END_STATE();
    case 217:
      ACCEPT_TOKEN(anon_sym_LBRACE_PIPE);
      END_STATE();
    case 218:
      ACCEPT_TOKEN(anon_sym_PIPE_RBRACE);
      END_STATE();
    default:
      return false;
  }
}

static bool ts_lex_keywords(TSLexer *lexer, TSStateId state) {
  START_LEXER();
  eof = lexer->eof(lexer);
  switch (state) {
    case 0:
      ADVANCE_MAP(
        'a', 1,
        'b', 2,
        'c', 3,
        'd', 4,
        'e', 5,
        'f', 6,
        'g', 7,
        'i', 8,
        'k', 9,
        'l', 10,
        'm', 11,
        'n', 12,
        'o', 13,
        'p', 14,
        'r', 15,
        's', 16,
        't', 17,
        'u', 18,
        'v', 19,
        'w', 20,
        'y', 21,
      );
      if (set_contains(extras_character_set_1, 10, lookahead)) SKIP(0);
      END_STATE();
    case 1:
      if (lookahead == 'b') ADVANCE(22);
      if (lookahead == 'c') ADVANCE(23);
      if (lookahead == 'n') ADVANCE(24);
      if (lookahead == 's') ADVANCE(25);
      if (lookahead == 'w') ADVANCE(26);
      END_STATE();
    case 2:
      if (lookahead == 'o') ADVANCE(27);
      if (lookahead == 'r') ADVANCE(28);
      END_STATE();
    case 3:
      if (lookahead == 'a') ADVANCE(29);
      if (lookahead == 'l') ADVANCE(30);
      if (lookahead == 'o') ADVANCE(31);
      END_STATE();
    case 4:
      if (lookahead == 'e') ADVANCE(32);
      if (lookahead == 'o') ADVANCE(33);
      END_STATE();
    case 5:
      if (lookahead == 'l') ADVANCE(34);
      if (lookahead == 'n') ADVANCE(35);
      if (lookahead == 'x') ADVANCE(36);
      END_STATE();
    case 6:
      if (lookahead == 'a') ADVANCE(37);
      if (lookahead == 'i') ADVANCE(38);
      if (lookahead == 'o') ADVANCE(39);
      if (lookahead == 'r') ADVANCE(40);
      if (lookahead == 'u') ADVANCE(41);
      END_STATE();
    case 7:
      if (lookahead == 'e') ADVANCE(42);
      if (lookahead == 'l') ADVANCE(43);
      END_STATE();
    case 8:
      if (lookahead == 'f') ADVANCE(44);
      if (lookahead == 'm') ADVANCE(45);
      if (lookahead == 'n') ADVANCE(46);
      if (lookahead == 's') ADVANCE(47);
      END_STATE();
    case 9:
      if (lookahead == 'e') ADVANCE(48);
      END_STATE();
    case 10:
      if (lookahead == 'e') ADVANCE(49);
      END_STATE();
    case 11:
      if (lookahead == 'e') ADVANCE(50);
      if (lookahead == 'o') ADVANCE(51);
      END_STATE();
    case 12:
      if (lookahead == 'a') ADVANCE(52);
      if (lookahead == 'e') ADVANCE(53);
      if (lookahead == 'u') ADVANCE(54);
      END_STATE();
    case 13:
      if (lookahead == 'b') ADVANCE(55);
      if (lookahead == 'f') ADVANCE(56);
      if (lookahead == 'v') ADVANCE(57);
      END_STATE();
    case 14:
      if (lookahead == 'r') ADVANCE(58);
      if (lookahead == 'u') ADVANCE(59);
      END_STATE();
    case 15:
      if (lookahead == 'e') ADVANCE(60);
      END_STATE();
    case 16:
      if (lookahead == 'a') ADVANCE(61);
      if (lookahead == 'e') ADVANCE(62);
      if (lookahead == 't') ADVANCE(63);
      if (lookahead == 'u') ADVANCE(64);
      if (lookahead == 'w') ADVANCE(65);
      if (lookahead == 'y') ADVANCE(66);
      END_STATE();
    case 17:
      if (lookahead == 'a') ADVANCE(67);
      if (lookahead == 'h') ADVANCE(68);
      if (lookahead == 'r') ADVANCE(69);
      if (lookahead == 'y') ADVANCE(70);
      END_STATE();
    case 18:
      if (lookahead == 'n') ADVANCE(71);
      if (lookahead == 's') ADVANCE(72);
      END_STATE();
    case 19:
      if (lookahead == 'a') ADVANCE(73);
      if (lookahead == 'o') ADVANCE(74);
      END_STATE();
    case 20:
      if (lookahead == 'h') ADVANCE(75);
      if (lookahead == 'i') ADVANCE(76);
      END_STATE();
    case 21:
      if (lookahead == 'i') ADVANCE(77);
      END_STATE();
    case 22:
      if (lookahead == 's') ADVANCE(78);
      END_STATE();
    case 23:
      if (lookahead == 'c') ADVANCE(79);
      END_STATE();
    case 24:
      if (lookahead == 'y') ADVANCE(80);
      END_STATE();
    case 25:
      ACCEPT_TOKEN(anon_sym_as);
      if (lookahead == 's') ADVANCE(81);
      if (lookahead == 'y') ADVANCE(82);
      END_STATE();
    case 26:
      if (lookahead == 'a') ADVANCE(83);
      END_STATE();
    case 27:
      if (lookahead == 'o') ADVANCE(84);
      END_STATE();
    case 28:
      if (lookahead == 'e') ADVANCE(85);
      END_STATE();
    case 29:
      if (lookahead == 's') ADVANCE(86);
      if (lookahead == 't') ADVANCE(87);
      END_STATE();
    case 30:
      if (lookahead == 'a') ADVANCE(88);
      END_STATE();
    case 31:
      if (lookahead == 'n') ADVANCE(89);
      END_STATE();
    case 32:
      if (lookahead == 'b') ADVANCE(90);
      if (lookahead == 'c') ADVANCE(91);
      if (lookahead == 'f') ADVANCE(92);
      if (lookahead == 'l') ADVANCE(93);
      END_STATE();
    case 33:
      ACCEPT_TOKEN(anon_sym_do);
      END_STATE();
    case 34:
      if (lookahead == 's') ADVANCE(94);
      END_STATE();
    case 35:
      if (lookahead == 'u') ADVANCE(95);
      END_STATE();
    case 36:
      if (lookahead == 'p') ADVANCE(96);
      if (lookahead == 't') ADVANCE(97);
      END_STATE();
    case 37:
      if (lookahead == 'l') ADVANCE(98);
      END_STATE();
    case 38:
      if (lookahead == 'n') ADVANCE(99);
      END_STATE();
    case 39:
      if (lookahead == 'r') ADVANCE(100);
      END_STATE();
    case 40:
      if (lookahead == 'o') ADVANCE(101);
      END_STATE();
    case 41:
      if (lookahead == 'n') ADVANCE(102);
      END_STATE();
    case 42:
      if (lookahead == 't') ADVANCE(103);
      END_STATE();
    case 43:
      if (lookahead == 'o') ADVANCE(104);
      END_STATE();
    case 44:
      ACCEPT_TOKEN(anon_sym_if);
      END_STATE();
    case 45:
      if (lookahead == 'p') ADVANCE(105);
      END_STATE();
    case 46:
      ACCEPT_TOKEN(anon_sym_in);
      if (lookahead == 'f') ADVANCE(106);
      if (lookahead == 's') ADVANCE(107);
      if (lookahead == 't') ADVANCE(108);
      END_STATE();
    case 47:
      ACCEPT_TOKEN(anon_sym_is);
      END_STATE();
    case 48:
      if (lookahead == 'y') ADVANCE(109);
      END_STATE();
    case 49:
      if (lookahead == 't') ADVANCE(110);
      END_STATE();
    case 50:
      if (lookahead == 't') ADVANCE(111);
      END_STATE();
    case 51:
      if (lookahead == 'd') ADVANCE(112);
      END_STATE();
    case 52:
      if (lookahead == 'm') ADVANCE(113);
      END_STATE();
    case 53:
      if (lookahead == 'v') ADVANCE(114);
      if (lookahead == 'w') ADVANCE(115);
      END_STATE();
    case 54:
      if (lookahead == 'l') ADVANCE(116);
      if (lookahead == 'm') ADVANCE(117);
      END_STATE();
    case 55:
      if (lookahead == 'j') ADVANCE(118);
      END_STATE();
    case 56:
      ACCEPT_TOKEN(anon_sym_of);
      END_STATE();
    case 57:
      if (lookahead == 'e') ADVANCE(119);
      END_STATE();
    case 58:
      if (lookahead == 'i') ADVANCE(120);
      if (lookahead == 'o') ADVANCE(121);
      END_STATE();
    case 59:
      if (lookahead == 'b') ADVANCE(122);
      END_STATE();
    case 60:
      if (lookahead == 'a') ADVANCE(123);
      if (lookahead == 'q') ADVANCE(124);
      if (lookahead == 't') ADVANCE(125);
      END_STATE();
    case 61:
      if (lookahead == 't') ADVANCE(126);
      END_STATE();
    case 62:
      if (lookahead == 't') ADVANCE(127);
      END_STATE();
    case 63:
      if (lookahead == 'a') ADVANCE(128);
      if (lookahead == 'r') ADVANCE(129);
      END_STATE();
    case 64:
      if (lookahead == 'p') ADVANCE(130);
      END_STATE();
    case 65:
      if (lookahead == 'i') ADVANCE(131);
      END_STATE();
    case 66:
      if (lookahead == 'm') ADVANCE(132);
      END_STATE();
    case 67:
      if (lookahead == 'r') ADVANCE(133);
      END_STATE();
    case 68:
      if (lookahead == 'i') ADVANCE(134);
      if (lookahead == 'r') ADVANCE(135);
      END_STATE();
    case 69:
      if (lookahead == 'u') ADVANCE(136);
      if (lookahead == 'y') ADVANCE(137);
      END_STATE();
    case 70:
      if (lookahead == 'p') ADVANCE(138);
      END_STATE();
    case 71:
      if (lookahead == 'd') ADVANCE(139);
      if (lookahead == 'i') ADVANCE(140);
      if (lookahead == 'k') ADVANCE(141);
      END_STATE();
    case 72:
      if (lookahead == 'i') ADVANCE(142);
      END_STATE();
    case 73:
      if (lookahead == 'r') ADVANCE(143);
      END_STATE();
    case 74:
      if (lookahead == 'i') ADVANCE(144);
      END_STATE();
    case 75:
      if (lookahead == 'i') ADVANCE(145);
      END_STATE();
    case 76:
      if (lookahead == 't') ADVANCE(146);
      END_STATE();
    case 77:
      if (lookahead == 'e') ADVANCE(147);
      END_STATE();
    case 78:
      if (lookahead == 't') ADVANCE(148);
      END_STATE();
    case 79:
      if (lookahead == 'e') ADVANCE(149);
      END_STATE();
    case 80:
      ACCEPT_TOKEN(anon_sym_any);
      END_STATE();
    case 81:
      if (lookahead == 'e') ADVANCE(150);
      END_STATE();
    case 82:
      if (lookahead == 'n') ADVANCE(151);
      END_STATE();
    case 83:
      if (lookahead == 'i') ADVANCE(152);
      END_STATE();
    case 84:
      if (lookahead == 'l') ADVANCE(153);
      END_STATE();
    case 85:
      if (lookahead == 'a') ADVANCE(154);
      END_STATE();
    case 86:
      if (lookahead == 'e') ADVANCE(155);
      END_STATE();
    case 87:
      if (lookahead == 'c') ADVANCE(156);
      END_STATE();
    case 88:
      if (lookahead == 's') ADVANCE(157);
      END_STATE();
    case 89:
      if (lookahead == 's') ADVANCE(158);
      if (lookahead == 't') ADVANCE(159);
      END_STATE();
    case 90:
      if (lookahead == 'u') ADVANCE(160);
      END_STATE();
    case 91:
      if (lookahead == 'l') ADVANCE(161);
      END_STATE();
    case 92:
      if (lookahead == 'a') ADVANCE(162);
      END_STATE();
    case 93:
      if (lookahead == 'e') ADVANCE(163);
      END_STATE();
    case 94:
      if (lookahead == 'e') ADVANCE(164);
      END_STATE();
    case 95:
      if (lookahead == 'm') ADVANCE(165);
      END_STATE();
    case 96:
      if (lookahead == 'o') ADVANCE(166);
      END_STATE();
    case 97:
      if (lookahead == 'e') ADVANCE(167);
      END_STATE();
    case 98:
      if (lookahead == 's') ADVANCE(168);
      END_STATE();
    case 99:
      if (lookahead == 'a') ADVANCE(169);
      END_STATE();
    case 100:
      ACCEPT_TOKEN(anon_sym_for);
      END_STATE();
    case 101:
      if (lookahead == 'm') ADVANCE(170);
      END_STATE();
    case 102:
      if (lookahead == 'c') ADVANCE(171);
      END_STATE();
    case 103:
      ACCEPT_TOKEN(anon_sym_get);
      END_STATE();
    case 104:
      if (lookahead == 'b') ADVANCE(172);
      END_STATE();
    case 105:
      if (lookahead == 'l') ADVANCE(173);
      if (lookahead == 'o') ADVANCE(174);
      END_STATE();
    case 106:
      if (lookahead == 'e') ADVANCE(175);
      END_STATE();
    case 107:
      if (lookahead == 't') ADVANCE(176);
      END_STATE();
    case 108:
      if (lookahead == 'e') ADVANCE(177);
      END_STATE();
    case 109:
      if (lookahead == 'o') ADVANCE(178);
      END_STATE();
    case 110:
      ACCEPT_TOKEN(anon_sym_let);
      END_STATE();
    case 111:
      if (lookahead == 'a') ADVANCE(179);
      END_STATE();
    case 112:
      if (lookahead == 'u') ADVANCE(180);
      END_STATE();
    case 113:
      if (lookahead == 'e') ADVANCE(181);
      END_STATE();
    case 114:
      if (lookahead == 'e') ADVANCE(182);
      END_STATE();
    case 115:
      ACCEPT_TOKEN(anon_sym_new);
      END_STATE();
    case 116:
      if (lookahead == 'l') ADVANCE(183);
      END_STATE();
    case 117:
      if (lookahead == 'b') ADVANCE(184);
      END_STATE();
    case 118:
      if (lookahead == 'e') ADVANCE(185);
      END_STATE();
    case 119:
      if (lookahead == 'r') ADVANCE(186);
      END_STATE();
    case 120:
      if (lookahead == 'v') ADVANCE(187);
      END_STATE();
    case 121:
      if (lookahead == 't') ADVANCE(188);
      END_STATE();
    case 122:
      if (lookahead == 'l') ADVANCE(189);
      END_STATE();
    case 123:
      if (lookahead == 'd') ADVANCE(190);
      END_STATE();
    case 124:
      if (lookahead == 'u') ADVANCE(191);
      END_STATE();
    case 125:
      if (lookahead == 'u') ADVANCE(192);
      END_STATE();
    case 126:
      if (lookahead == 'i') ADVANCE(193);
      END_STATE();
    case 127:
      ACCEPT_TOKEN(anon_sym_set);
      END_STATE();
    case 128:
      if (lookahead == 't') ADVANCE(194);
      END_STATE();
    case 129:
      if (lookahead == 'i') ADVANCE(195);
      END_STATE();
    case 130:
      if (lookahead == 'e') ADVANCE(196);
      END_STATE();
    case 131:
      if (lookahead == 't') ADVANCE(197);
      END_STATE();
    case 132:
      if (lookahead == 'b') ADVANCE(198);
      END_STATE();
    case 133:
      if (lookahead == 'g') ADVANCE(199);
      END_STATE();
    case 134:
      if (lookahead == 's') ADVANCE(200);
      END_STATE();
    case 135:
      if (lookahead == 'o') ADVANCE(201);
      END_STATE();
    case 136:
      if (lookahead == 'e') ADVANCE(202);
      END_STATE();
    case 137:
      ACCEPT_TOKEN(anon_sym_try);
      END_STATE();
    case 138:
      if (lookahead == 'e') ADVANCE(203);
      END_STATE();
    case 139:
      if (lookahead == 'e') ADVANCE(204);
      END_STATE();
    case 140:
      if (lookahead == 'q') ADVANCE(205);
      END_STATE();
    case 141:
      if (lookahead == 'n') ADVANCE(206);
      END_STATE();
    case 142:
      if (lookahead == 'n') ADVANCE(207);
      END_STATE();
    case 143:
      ACCEPT_TOKEN(anon_sym_var);
      END_STATE();
    case 144:
      if (lookahead == 'd') ADVANCE(208);
      END_STATE();
    case 145:
      if (lookahead == 'l') ADVANCE(209);
      END_STATE();
    case 146:
      if (lookahead == 'h') ADVANCE(210);
      END_STATE();
    case 147:
      if (lookahead == 'l') ADVANCE(211);
      END_STATE();
    case 148:
      if (lookahead == 'r') ADVANCE(212);
      END_STATE();
    case 149:
      if (lookahead == 's') ADVANCE(213);
      END_STATE();
    case 150:
      if (lookahead == 'r') ADVANCE(214);
      END_STATE();
    case 151:
      if (lookahead == 'c') ADVANCE(215);
      END_STATE();
    case 152:
      if (lookahead == 't') ADVANCE(216);
      END_STATE();
    case 153:
      if (lookahead == 'e') ADVANCE(217);
      END_STATE();
    case 154:
      if (lookahead == 'k') ADVANCE(218);
      END_STATE();
    case 155:
      ACCEPT_TOKEN(anon_sym_case);
      END_STATE();
    case 156:
      if (lookahead == 'h') ADVANCE(219);
      END_STATE();
    case 157:
      if (lookahead == 's') ADVANCE(220);
      END_STATE();
    case 158:
      if (lookahead == 't') ADVANCE(221);
      END_STATE();
    case 159:
      if (lookahead == 'i') ADVANCE(222);
      END_STATE();
    case 160:
      if (lookahead == 'g') ADVANCE(223);
      END_STATE();
    case 161:
      if (lookahead == 'a') ADVANCE(224);
      END_STATE();
    case 162:
      if (lookahead == 'u') ADVANCE(225);
      END_STATE();
    case 163:
      if (lookahead == 't') ADVANCE(226);
      END_STATE();
    case 164:
      ACCEPT_TOKEN(anon_sym_else);
      END_STATE();
    case 165:
      ACCEPT_TOKEN(anon_sym_enum);
      END_STATE();
    case 166:
      if (lookahead == 'r') ADVANCE(227);
      END_STATE();
    case 167:
      if (lookahead == 'n') ADVANCE(228);
      END_STATE();
    case 168:
      if (lookahead == 'e') ADVANCE(229);
      END_STATE();
    case 169:
      if (lookahead == 'l') ADVANCE(230);
      END_STATE();
    case 170:
      ACCEPT_TOKEN(anon_sym_from);
      END_STATE();
    case 171:
      if (lookahead == 't') ADVANCE(231);
      END_STATE();
    case 172:
      if (lookahead == 'a') ADVANCE(232);
      END_STATE();
    case 173:
      if (lookahead == 'e') ADVANCE(233);
      END_STATE();
    case 174:
      if (lookahead == 'r') ADVANCE(234);
      END_STATE();
    case 175:
      if (lookahead == 'r') ADVANCE(235);
      END_STATE();
    case 176:
      if (lookahead == 'a') ADVANCE(236);
      END_STATE();
    case 177:
      if (lookahead == 'r') ADVANCE(237);
      END_STATE();
    case 178:
      if (lookahead == 'f') ADVANCE(238);
      END_STATE();
    case 179:
      ACCEPT_TOKEN(anon_sym_meta);
      END_STATE();
    case 180:
      if (lookahead == 'l') ADVANCE(239);
      END_STATE();
    case 181:
      if (lookahead == 's') ADVANCE(240);
      END_STATE();
    case 182:
      if (lookahead == 'r') ADVANCE(241);
      END_STATE();
    case 183:
      ACCEPT_TOKEN(sym_null);
      END_STATE();
    case 184:
      if (lookahead == 'e') ADVANCE(242);
      END_STATE();
    case 185:
      if (lookahead == 'c') ADVANCE(243);
      END_STATE();
    case 186:
      if (lookahead == 'r') ADVANCE(244);
      END_STATE();
    case 187:
      if (lookahead == 'a') ADVANCE(245);
      END_STATE();
    case 188:
      if (lookahead == 'e') ADVANCE(246);
      END_STATE();
    case 189:
      if (lookahead == 'i') ADVANCE(247);
      END_STATE();
    case 190:
      if (lookahead == 'o') ADVANCE(248);
      END_STATE();
    case 191:
      if (lookahead == 'i') ADVANCE(249);
      END_STATE();
    case 192:
      if (lookahead == 'r') ADVANCE(250);
      END_STATE();
    case 193:
      if (lookahead == 's') ADVANCE(251);
      END_STATE();
    case 194:
      if (lookahead == 'i') ADVANCE(252);
      END_STATE();
    case 195:
      if (lookahead == 'n') ADVANCE(253);
      END_STATE();
    case 196:
      if (lookahead == 'r') ADVANCE(254);
      END_STATE();
    case 197:
      if (lookahead == 'c') ADVANCE(255);
      END_STATE();
    case 198:
      if (lookahead == 'o') ADVANCE(256);
      END_STATE();
    case 199:
      if (lookahead == 'e') ADVANCE(257);
      END_STATE();
    case 200:
      ACCEPT_TOKEN(sym_this);
      END_STATE();
    case 201:
      if (lookahead == 'w') ADVANCE(258);
      END_STATE();
    case 202:
      ACCEPT_TOKEN(sym_true);
      END_STATE();
    case 203:
      ACCEPT_TOKEN(anon_sym_type);
      if (lookahead == 'o') ADVANCE(259);
      END_STATE();
    case 204:
      if (lookahead == 'f') ADVANCE(260);
      END_STATE();
    case 205:
      if (lookahead == 'u') ADVANCE(261);
      END_STATE();
    case 206:
      if (lookahead == 'o') ADVANCE(262);
      END_STATE();
    case 207:
      if (lookahead == 'g') ADVANCE(263);
      END_STATE();
    case 208:
      ACCEPT_TOKEN(anon_sym_void);
      END_STATE();
    case 209:
      if (lookahead == 'e') ADVANCE(264);
      END_STATE();
    case 210:
      ACCEPT_TOKEN(anon_sym_with);
      END_STATE();
    case 211:
      if (lookahead == 'd') ADVANCE(265);
      END_STATE();
    case 212:
      if (lookahead == 'a') ADVANCE(266);
      END_STATE();
    case 213:
      if (lookahead == 's') ADVANCE(267);
      END_STATE();
    case 214:
      if (lookahead == 't') ADVANCE(268);
      END_STATE();
    case 215:
      ACCEPT_TOKEN(anon_sym_async);
      END_STATE();
    case 216:
      ACCEPT_TOKEN(anon_sym_await);
      END_STATE();
    case 217:
      if (lookahead == 'a') ADVANCE(269);
      END_STATE();
    case 218:
      ACCEPT_TOKEN(anon_sym_break);
      END_STATE();
    case 219:
      ACCEPT_TOKEN(anon_sym_catch);
      END_STATE();
    case 220:
      ACCEPT_TOKEN(anon_sym_class);
      END_STATE();
    case 221:
      ACCEPT_TOKEN(anon_sym_const);
      END_STATE();
    case 222:
      if (lookahead == 'n') ADVANCE(270);
      END_STATE();
    case 223:
      if (lookahead == 'g') ADVANCE(271);
      END_STATE();
    case 224:
      if (lookahead == 'r') ADVANCE(272);
      END_STATE();
    case 225:
      if (lookahead == 'l') ADVANCE(273);
      END_STATE();
    case 226:
      if (lookahead == 'e') ADVANCE(274);
      END_STATE();
    case 227:
      if (lookahead == 't') ADVANCE(275);
      END_STATE();
    case 228:
      if (lookahead == 'd') ADVANCE(276);
      END_STATE();
    case 229:
      ACCEPT_TOKEN(sym_false);
      END_STATE();
    case 230:
      if (lookahead == 'l') ADVANCE(277);
      END_STATE();
    case 231:
      if (lookahead == 'i') ADVANCE(278);
      END_STATE();
    case 232:
      if (lookahead == 'l') ADVANCE(279);
      END_STATE();
    case 233:
      if (lookahead == 'm') ADVANCE(280);
      END_STATE();
    case 234:
      if (lookahead == 't') ADVANCE(281);
      END_STATE();
    case 235:
      ACCEPT_TOKEN(anon_sym_infer);
      END_STATE();
    case 236:
      if (lookahead == 'n') ADVANCE(282);
      END_STATE();
    case 237:
      if (lookahead == 'f') ADVANCE(283);
      END_STATE();
    case 238:
      ACCEPT_TOKEN(anon_sym_keyof);
      END_STATE();
    case 239:
      if (lookahead == 'e') ADVANCE(284);
      END_STATE();
    case 240:
      if (lookahead == 'p') ADVANCE(285);
      END_STATE();
    case 241:
      ACCEPT_TOKEN(anon_sym_never);
      END_STATE();
    case 242:
      if (lookahead == 'r') ADVANCE(286);
      END_STATE();
    case 243:
      if (lookahead == 't') ADVANCE(287);
      END_STATE();
    case 244:
      if (lookahead == 'i') ADVANCE(288);
      END_STATE();
    case 245:
      if (lookahead == 't') ADVANCE(289);
      END_STATE();
    case 246:
      if (lookahead == 'c') ADVANCE(290);
      END_STATE();
    case 247:
      if (lookahead == 'c') ADVANCE(291);
      END_STATE();
    case 248:
      if (lookahead == 'n') ADVANCE(292);
      END_STATE();
    case 249:
      if (lookahead == 'r') ADVANCE(293);
      END_STATE();
    case 250:
      if (lookahead == 'n') ADVANCE(294);
      END_STATE();
    case 251:
      if (lookahead == 'f') ADVANCE(295);
      END_STATE();
    case 252:
      if (lookahead == 'c') ADVANCE(296);
      END_STATE();
    case 253:
      if (lookahead == 'g') ADVANCE(297);
      END_STATE();
    case 254:
      ACCEPT_TOKEN(sym_super);
      END_STATE();
    case 255:
      if (lookahead == 'h') ADVANCE(298);
      END_STATE();
    case 256:
      if (lookahead == 'l') ADVANCE(299);
      END_STATE();
    case 257:
      if (lookahead == 't') ADVANCE(300);
      END_STATE();
    case 258:
      ACCEPT_TOKEN(anon_sym_throw);
      END_STATE();
    case 259:
      if (lookahead == 'f') ADVANCE(301);
      END_STATE();
    case 260:
      if (lookahead == 'i') ADVANCE(302);
      END_STATE();
    case 261:
      if (lookahead == 'e') ADVANCE(303);
      END_STATE();
    case 262:
      if (lookahead == 'w') ADVANCE(304);
      END_STATE();
    case 263:
      ACCEPT_TOKEN(anon_sym_using);
      END_STATE();
    case 264:
      ACCEPT_TOKEN(anon_sym_while);
      END_STATE();
    case 265:
      ACCEPT_TOKEN(anon_sym_yield);
      END_STATE();
    case 266:
      if (lookahead == 'c') ADVANCE(305);
      END_STATE();
    case 267:
      if (lookahead == 'o') ADVANCE(306);
      END_STATE();
    case 268:
      ACCEPT_TOKEN(anon_sym_assert);
      if (lookahead == 's') ADVANCE(307);
      END_STATE();
    case 269:
      if (lookahead == 'n') ADVANCE(308);
      END_STATE();
    case 270:
      if (lookahead == 'u') ADVANCE(309);
      END_STATE();
    case 271:
      if (lookahead == 'e') ADVANCE(310);
      END_STATE();
    case 272:
      if (lookahead == 'e') ADVANCE(311);
      END_STATE();
    case 273:
      if (lookahead == 't') ADVANCE(312);
      END_STATE();
    case 274:
      ACCEPT_TOKEN(anon_sym_delete);
      END_STATE();
    case 275:
      ACCEPT_TOKEN(anon_sym_export);
      END_STATE();
    case 276:
      if (lookahead == 's') ADVANCE(313);
      END_STATE();
    case 277:
      if (lookahead == 'y') ADVANCE(314);
      END_STATE();
    case 278:
      if (lookahead == 'o') ADVANCE(315);
      END_STATE();
    case 279:
      ACCEPT_TOKEN(anon_sym_global);
      END_STATE();
    case 280:
      if (lookahead == 'e') ADVANCE(316);
      END_STATE();
    case 281:
      ACCEPT_TOKEN(anon_sym_import);
      END_STATE();
    case 282:
      if (lookahead == 'c') ADVANCE(317);
      END_STATE();
    case 283:
      if (lookahead == 'a') ADVANCE(318);
      END_STATE();
    case 284:
      ACCEPT_TOKEN(anon_sym_module);
      END_STATE();
    case 285:
      if (lookahead == 'a') ADVANCE(319);
      END_STATE();
    case 286:
      ACCEPT_TOKEN(anon_sym_number);
      END_STATE();
    case 287:
      ACCEPT_TOKEN(anon_sym_object);
      END_STATE();
    case 288:
      if (lookahead == 'd') ADVANCE(320);
      END_STATE();
    case 289:
      if (lookahead == 'e') ADVANCE(321);
      END_STATE();
    case 290:
      if (lookahead == 't') ADVANCE(322);
      END_STATE();
    case 291:
      ACCEPT_TOKEN(anon_sym_public);
      END_STATE();
    case 292:
      if (lookahead == 'l') ADVANCE(323);
      END_STATE();
    case 293:
      if (lookahead == 'e') ADVANCE(324);
      END_STATE();
    case 294:
      ACCEPT_TOKEN(anon_sym_return);
      END_STATE();
    case 295:
      if (lookahead == 'i') ADVANCE(325);
      END_STATE();
    case 296:
      ACCEPT_TOKEN(anon_sym_static);
      END_STATE();
    case 297:
      ACCEPT_TOKEN(anon_sym_string);
      END_STATE();
    case 298:
      ACCEPT_TOKEN(anon_sym_switch);
      END_STATE();
    case 299:
      ACCEPT_TOKEN(anon_sym_symbol);
      END_STATE();
    case 300:
      ACCEPT_TOKEN(anon_sym_target);
      END_STATE();
    case 301:
      ACCEPT_TOKEN(anon_sym_typeof);
      END_STATE();
    case 302:
      if (lookahead == 'n') ADVANCE(326);
      END_STATE();
    case 303:
      ACCEPT_TOKEN(anon_sym_unique);
      END_STATE();
    case 304:
      if (lookahead == 'n') ADVANCE(327);
      END_STATE();
    case 305:
      if (lookahead == 't') ADVANCE(328);
      END_STATE();
    case 306:
      if (lookahead == 'r') ADVANCE(329);
      END_STATE();
    case 307:
      ACCEPT_TOKEN(anon_sym_asserts);
      END_STATE();
    case 308:
      ACCEPT_TOKEN(anon_sym_boolean);
      END_STATE();
    case 309:
      if (lookahead == 'e') ADVANCE(330);
      END_STATE();
    case 310:
      if (lookahead == 'r') ADVANCE(331);
      END_STATE();
    case 311:
      ACCEPT_TOKEN(anon_sym_declare);
      END_STATE();
    case 312:
      ACCEPT_TOKEN(anon_sym_default);
      END_STATE();
    case 313:
      ACCEPT_TOKEN(anon_sym_extends);
      END_STATE();
    case 314:
      ACCEPT_TOKEN(anon_sym_finally);
      END_STATE();
    case 315:
      if (lookahead == 'n') ADVANCE(332);
      END_STATE();
    case 316:
      if (lookahead == 'n') ADVANCE(333);
      END_STATE();
    case 317:
      if (lookahead == 'e') ADVANCE(334);
      END_STATE();
    case 318:
      if (lookahead == 'c') ADVANCE(335);
      END_STATE();
    case 319:
      if (lookahead == 'c') ADVANCE(336);
      END_STATE();
    case 320:
      if (lookahead == 'e') ADVANCE(337);
      END_STATE();
    case 321:
      ACCEPT_TOKEN(anon_sym_private);
      END_STATE();
    case 322:
      if (lookahead == 'e') ADVANCE(338);
      END_STATE();
    case 323:
      if (lookahead == 'y') ADVANCE(339);
      END_STATE();
    case 324:
      ACCEPT_TOKEN(anon_sym_require);
      END_STATE();
    case 325:
      if (lookahead == 'e') ADVANCE(340);
      END_STATE();
    case 326:
      if (lookahead == 'e') ADVANCE(341);
      END_STATE();
    case 327:
      ACCEPT_TOKEN(anon_sym_unknown);
      END_STATE();
    case 328:
      ACCEPT_TOKEN(anon_sym_abstract);
      END_STATE();
    case 329:
      ACCEPT_TOKEN(anon_sym_accessor);
      END_STATE();
    case 330:
      ACCEPT_TOKEN(anon_sym_continue);
      END_STATE();
    case 331:
      ACCEPT_TOKEN(anon_sym_debugger);
      END_STATE();
    case 332:
      ACCEPT_TOKEN(anon_sym_function);
      END_STATE();
    case 333:
      if (lookahead == 't') ADVANCE(342);
      END_STATE();
    case 334:
      if (lookahead == 'o') ADVANCE(343);
      END_STATE();
    case 335:
      if (lookahead == 'e') ADVANCE(344);
      END_STATE();
    case 336:
      if (lookahead == 'e') ADVANCE(345);
      END_STATE();
    case 337:
      ACCEPT_TOKEN(anon_sym_override);
      END_STATE();
    case 338:
      if (lookahead == 'd') ADVANCE(346);
      END_STATE();
    case 339:
      ACCEPT_TOKEN(anon_sym_readonly);
      END_STATE();
    case 340:
      if (lookahead == 's') ADVANCE(347);
      END_STATE();
    case 341:
      if (lookahead == 'd') ADVANCE(348);
      END_STATE();
    case 342:
      if (lookahead == 's') ADVANCE(349);
      END_STATE();
    case 343:
      if (lookahead == 'f') ADVANCE(350);
      END_STATE();
    case 344:
      ACCEPT_TOKEN(anon_sym_interface);
      END_STATE();
    case 345:
      ACCEPT_TOKEN(anon_sym_namespace);
      END_STATE();
    case 346:
      ACCEPT_TOKEN(anon_sym_protected);
      END_STATE();
    case 347:
      ACCEPT_TOKEN(anon_sym_satisfies);
      END_STATE();
    case 348:
      ACCEPT_TOKEN(sym_undefined);
      END_STATE();
    case 349:
      ACCEPT_TOKEN(anon_sym_implements);
      END_STATE();
    case 350:
      ACCEPT_TOKEN(anon_sym_instanceof);
      END_STATE();
    default:
      return false;
  }
}

static const TSLexMode ts_lex_modes[STATE_COUNT] = {
  [0] = {.lex_state = 0, .external_lex_state = 1},
  [1] = {.lex_state = 75, .external_lex_state = 2},
  [2] = {.lex_state = 2, .external_lex_state = 3},
  [3] = {.lex_state = 2, .external_lex_state = 3},
  [4] = {.lex_state = 75, .external_lex_state = 2},
  [5] = {.lex_state = 75, .external_lex_state = 2},
  [6] = {.lex_state = 75, .external_lex_state = 2},
  [7] = {.lex_state = 75, .external_lex_state = 2},
  [8] = {.lex_state = 75, .external_lex_state = 2},
  [9] = {.lex_state = 75, .external_lex_state = 2},
  [10] = {.lex_state = 75, .external_lex_state = 2},
  [11] = {.lex_state = 75, .external_lex_state = 2},
  [12] = {.lex_state = 75, .external_lex_state = 2},
  [13] = {.lex_state = 75, .external_lex_state = 2},
  [14] = {.lex_state = 75, .external_lex_state = 2},
  [15] = {.lex_state = 75, .external_lex_state = 2},
  [16] = {.lex_state = 75, .external_lex_state = 2},
  [17] = {.lex_state = 75, .external_lex_state = 2},
  [18] = {.lex_state = 75, .external_lex_state = 2},
  [19] = {.lex_state = 75, .external_lex_state = 2},
  [20] = {.lex_state = 75, .external_lex_state = 2},
  [21] = {.lex_state = 75, .external_lex_state = 2},
  [22] = {.lex_state = 75, .external_lex_state = 2},
  [23] = {.lex_state = 75, .external_lex_state = 2},
  [24] = {.lex_state = 75, .external_lex_state = 2},
  [25] = {.lex_state = 75, .external_lex_state = 2},
  [26] = {.lex_state = 75, .external_lex_state = 2},
  [27] = {.lex_state = 75, .external_lex_state = 2},
  [28] = {.lex_state = 75, .external_lex_state = 2},
  [29] = {.lex_state = 75, .external_lex_state = 2},
  [30] = {.lex_state = 75, .external_lex_state = 2},
  [31] = {.lex_state = 8, .external_lex_state = 2},
  [32] = {.lex_state = 75, .external_lex_state = 2},
  [33] = {.lex_state = 75, .external_lex_state = 2},
  [34] = {.lex_state = 75, .external_lex_state = 2},
  [35] = {.lex_state = 75, .external_lex_state = 2},
  [36] = {.lex_state = 75, .external_lex_state = 2},
  [37] = {.lex_state = 75, .external_lex_state = 2},
  [38] = {.lex_state = 8, .external_lex_state = 2},
  [39] = {.lex_state = 75, .external_lex_state = 2},
  [40] = {.lex_state = 8, .external_lex_state = 2},
  [41] = {.lex_state = 75, .external_lex_state = 2},
  [42] = {.lex_state = 75, .external_lex_state = 2},
  [43] = {.lex_state = 75, .external_lex_state = 2},
  [44] = {.lex_state = 75, .external_lex_state = 2},
  [45] = {.lex_state = 75, .external_lex_state = 2},
  [46] = {.lex_state = 75, .external_lex_state = 2},
  [47] = {.lex_state = 75, .external_lex_state = 2},
  [48] = {.lex_state = 75, .external_lex_state = 2},
  [49] = {.lex_state = 75, .external_lex_state = 2},
  [50] = {.lex_state = 75, .external_lex_state = 2},
  [51] = {.lex_state = 75, .external_lex_state = 2},
  [52] = {.lex_state = 75, .external_lex_state = 2},
  [53] = {.lex_state = 8, .external_lex_state = 2},
  [54] = {.lex_state = 75, .external_lex_state = 2},
  [55] = {.lex_state = 75, .external_lex_state = 2},
  [56] = {.lex_state = 8, .external_lex_state = 2},
  [57] = {.lex_state = 75, .external_lex_state = 2},
  [58] = {.lex_state = 75, .external_lex_state = 2},
  [59] = {.lex_state = 75, .external_lex_state = 2},
  [60] = {.lex_state = 75, .external_lex_state = 2},
  [61] = {.lex_state = 75, .external_lex_state = 2},
  [62] = {.lex_state = 75, .external_lex_state = 2},
  [63] = {.lex_state = 8, .external_lex_state = 2},
  [64] = {.lex_state = 75, .external_lex_state = 2},
  [65] = {.lex_state = 75, .external_lex_state = 2},
  [66] = {.lex_state = 8, .external_lex_state = 2},
  [67] = {.lex_state = 8, .external_lex_state = 2},
  [68] = {.lex_state = 8, .external_lex_state = 2},
  [69] = {.lex_state = 8, .external_lex_state = 2},
  [70] = {.lex_state = 75, .external_lex_state = 2},
  [71] = {.lex_state = 75, .external_lex_state = 2},
  [72] = {.lex_state = 3, .external_lex_state = 4},
  [73] = {.lex_state = 3, .external_lex_state = 4},
  [74] = {.lex_state = 3, .external_lex_state = 4},
  [75] = {.lex_state = 3, .external_lex_state = 3},
  [76] = {.lex_state = 8, .external_lex_state = 2},
  [77] = {.lex_state = 8, .external_lex_state = 2},
  [78] = {.lex_state = 3, .external_lex_state = 3},
  [79] = {.lex_state = 3, .external_lex_state = 3},
  [80] = {.lex_state = 3, .external_lex_state = 3},
  [81] = {.lex_state = 8, .external_lex_state = 2},
  [82] = {.lex_state = 3, .external_lex_state = 3},
  [83] = {.lex_state = 3, .external_lex_state = 3},
  [84] = {.lex_state = 3, .external_lex_state = 3},
  [85] = {.lex_state = 3, .external_lex_state = 3},
  [86] = {.lex_state = 8, .external_lex_state = 2},
  [87] = {.lex_state = 3, .external_lex_state = 3},
  [88] = {.lex_state = 3, .external_lex_state = 3},
  [89] = {.lex_state = 8, .external_lex_state = 2},
  [90] = {.lex_state = 8, .external_lex_state = 2},
  [91] = {.lex_state = 8, .external_lex_state = 2},
  [92] = {.lex_state = 8, .external_lex_state = 2},
  [93] = {.lex_state = 3, .external_lex_state = 3},
  [94] = {.lex_state = 3, .external_lex_state = 3},
  [95] = {.lex_state = 3, .external_lex_state = 3},
  [96] = {.lex_state = 3, .external_lex_state = 3},
  [97] = {.lex_state = 3, .external_lex_state = 4},
  [98] = {.lex_state = 3, .external_lex_state = 3},
  [99] = {.lex_state = 3, .external_lex_state = 4},
  [100] = {.lex_state = 3, .external_lex_state = 4},
  [101] = {.lex_state = 3, .external_lex_state = 3},
  [102] = {.lex_state = 3, .external_lex_state = 4},
  [103] = {.lex_state = 3, .external_lex_state = 4},
  [104] = {.lex_state = 3, .external_lex_state = 4},
  [105] = {.lex_state = 3, .external_lex_state = 4},
  [106] = {.lex_state = 3, .external_lex_state = 4},
  [107] = {.lex_state = 3, .external_lex_state = 3},
  [108] = {.lex_state = 3, .external_lex_state = 3},
  [109] = {.lex_state = 3, .external_lex_state = 3},
  [110] = {.lex_state = 3, .external_lex_state = 3},
  [111] = {.lex_state = 3, .external_lex_state = 3},
  [112] = {.lex_state = 3, .external_lex_state = 3},
  [113] = {.lex_state = 3, .external_lex_state = 3},
  [114] = {.lex_state = 3, .external_lex_state = 3},
  [115] = {.lex_state = 3, .external_lex_state = 3},
  [116] = {.lex_state = 3, .external_lex_state = 4},
  [117] = {.lex_state = 3, .external_lex_state = 3},
  [118] = {.lex_state = 3, .external_lex_state = 4},
  [119] = {.lex_state = 3, .external_lex_state = 3},
  [120] = {.lex_state = 3, .external_lex_state = 4},
  [121] = {.lex_state = 3, .external_lex_state = 3},
  [122] = {.lex_state = 3, .external_lex_state = 3},
  [123] = {.lex_state = 3, .external_lex_state = 3},
  [124] = {.lex_state = 3, .external_lex_state = 3},
  [125] = {.lex_state = 3, .external_lex_state = 3},
  [126] = {.lex_state = 3, .external_lex_state = 3},
  [127] = {.lex_state = 3, .external_lex_state = 3},
  [128] = {.lex_state = 3, .external_lex_state = 3},
  [129] = {.lex_state = 3, .external_lex_state = 3},
  [130] = {.lex_state = 3, .external_lex_state = 3},
  [131] = {.lex_state = 3, .external_lex_state = 3},
  [132] = {.lex_state = 3, .external_lex_state = 3},
  [133] = {.lex_state = 3, .external_lex_state = 3},
  [134] = {.lex_state = 3, .external_lex_state = 3},
  [135] = {.lex_state = 3, .external_lex_state = 3},
  [136] = {.lex_state = 3, .external_lex_state = 3},
  [137] = {.lex_state = 3, .external_lex_state = 3},
  [138] = {.lex_state = 3, .external_lex_state = 3},
  [139] = {.lex_state = 3, .external_lex_state = 3},
  [140] = {.lex_state = 3, .external_lex_state = 3},
  [141] = {.lex_state = 3, .external_lex_state = 3},
  [142] = {.lex_state = 3, .external_lex_state = 3},
  [143] = {.lex_state = 8, .external_lex_state = 2},
  [144] = {.lex_state = 3, .external_lex_state = 3},
  [145] = {.lex_state = 3, .external_lex_state = 3},
  [146] = {.lex_state = 3, .external_lex_state = 3},
  [147] = {.lex_state = 3, .external_lex_state = 3},
  [148] = {.lex_state = 3, .external_lex_state = 3},
  [149] = {.lex_state = 3, .external_lex_state = 3},
  [150] = {.lex_state = 8, .external_lex_state = 2},
  [151] = {.lex_state = 8, .external_lex_state = 2},
  [152] = {.lex_state = 8, .external_lex_state = 2},
  [153] = {.lex_state = 8, .external_lex_state = 2},
  [154] = {.lex_state = 8, .external_lex_state = 2},
  [155] = {.lex_state = 8, .external_lex_state = 2},
  [156] = {.lex_state = 8, .external_lex_state = 2},
  [157] = {.lex_state = 8, .external_lex_state = 2},
  [158] = {.lex_state = 8, .external_lex_state = 2},
  [159] = {.lex_state = 8, .external_lex_state = 2},
  [160] = {.lex_state = 8, .external_lex_state = 2},
  [161] = {.lex_state = 8, .external_lex_state = 2},
  [162] = {.lex_state = 8, .external_lex_state = 2},
  [163] = {.lex_state = 74, .external_lex_state = 3},
  [164] = {.lex_state = 74, .external_lex_state = 4},
  [165] = {.lex_state = 74, .external_lex_state = 4},
  [166] = {.lex_state = 74, .external_lex_state = 3},
  [167] = {.lex_state = 74, .external_lex_state = 3},
  [168] = {.lex_state = 74, .external_lex_state = 4},
  [169] = {.lex_state = 74, .external_lex_state = 3},
  [170] = {.lex_state = 74, .external_lex_state = 3},
  [171] = {.lex_state = 74, .external_lex_state = 3},
  [172] = {.lex_state = 74, .external_lex_state = 3},
  [173] = {.lex_state = 2, .external_lex_state = 3},
  [174] = {.lex_state = 2, .external_lex_state = 4},
  [175] = {.lex_state = 2, .external_lex_state = 4},
  [176] = {.lex_state = 2, .external_lex_state = 3},
  [177] = {.lex_state = 2, .external_lex_state = 3},
  [178] = {.lex_state = 2, .external_lex_state = 3},
  [179] = {.lex_state = 75, .external_lex_state = 2},
  [180] = {.lex_state = 75, .external_lex_state = 2},
  [181] = {.lex_state = 75, .external_lex_state = 2},
  [182] = {.lex_state = 2, .external_lex_state = 3},
  [183] = {.lex_state = 2, .external_lex_state = 4},
  [184] = {.lex_state = 75, .external_lex_state = 2},
  [185] = {.lex_state = 2, .external_lex_state = 3},
  [186] = {.lex_state = 75, .external_lex_state = 2},
  [187] = {.lex_state = 2, .external_lex_state = 3},
  [188] = {.lex_state = 75, .external_lex_state = 2},
  [189] = {.lex_state = 2, .external_lex_state = 3},
  [190] = {.lex_state = 2, .external_lex_state = 3},
  [191] = {.lex_state = 2, .external_lex_state = 3},
  [192] = {.lex_state = 2, .external_lex_state = 3},
  [193] = {.lex_state = 2, .external_lex_state = 3},
  [194] = {.lex_state = 75, .external_lex_state = 2},
  [195] = {.lex_state = 75, .external_lex_state = 2},
  [196] = {.lex_state = 75, .external_lex_state = 2},
  [197] = {.lex_state = 75, .external_lex_state = 2},
  [198] = {.lex_state = 75, .external_lex_state = 2},
  [199] = {.lex_state = 75, .external_lex_state = 2},
  [200] = {.lex_state = 74, .external_lex_state = 4},
  [201] = {.lex_state = 74, .external_lex_state = 4},
  [202] = {.lex_state = 75, .external_lex_state = 2},
  [203] = {.lex_state = 74, .external_lex_state = 4},
  [204] = {.lex_state = 75, .external_lex_state = 2},
  [205] = {.lex_state = 75, .external_lex_state = 2},
  [206] = {.lex_state = 74, .external_lex_state = 4},
  [207] = {.lex_state = 75, .external_lex_state = 2},
  [208] = {.lex_state = 75, .external_lex_state = 2},
  [209] = {.lex_state = 74, .external_lex_state = 4},
  [210] = {.lex_state = 74, .external_lex_state = 4},
  [211] = {.lex_state = 74, .external_lex_state = 4},
  [212] = {.lex_state = 74, .external_lex_state = 4},
  [213] = {.lex_state = 74, .external_lex_state = 4},
  [214] = {.lex_state = 74, .external_lex_state = 4},
  [215] = {.lex_state = 75, .external_lex_state = 2},
  [216] = {.lex_state = 75, .external_lex_state = 2},
  [217] = {.lex_state = 74, .external_lex_state = 4},
  [218] = {.lex_state = 75, .external_lex_state = 2},
  [219] = {.lex_state = 74, .external_lex_state = 4},
  [220] = {.lex_state = 74, .external_lex_state = 4},
  [221] = {.lex_state = 75, .external_lex_state = 2},
  [222] = {.lex_state = 74, .external_lex_state = 4},
  [223] = {.lex_state = 74, .external_lex_state = 4},
  [224] = {.lex_state = 74, .external_lex_state = 4},
  [225] = {.lex_state = 74, .external_lex_state = 4},
  [226] = {.lex_state = 74, .external_lex_state = 4},
  [227] = {.lex_state = 74, .external_lex_state = 4},
  [228] = {.lex_state = 74, .external_lex_state = 4},
  [229] = {.lex_state = 75, .external_lex_state = 2},
  [230] = {.lex_state = 74, .external_lex_state = 4},
  [231] = {.lex_state = 74, .external_lex_state = 4},
  [232] = {.lex_state = 74, .external_lex_state = 4},
  [233] = {.lex_state = 74, .external_lex_state = 4},
  [234] = {.lex_state = 75, .external_lex_state = 2},
  [235] = {.lex_state = 74, .external_lex_state = 4},
  [236] = {.lex_state = 74, .external_lex_state = 4},
  [237] = {.lex_state = 75, .external_lex_state = 2},
  [238] = {.lex_state = 74, .external_lex_state = 4},
  [239] = {.lex_state = 74, .external_lex_state = 4},
  [240] = {.lex_state = 74, .external_lex_state = 4},
  [241] = {.lex_state = 75, .external_lex_state = 2},
  [242] = {.lex_state = 75, .external_lex_state = 5},
  [243] = {.lex_state = 75, .external_lex_state = 2},
  [244] = {.lex_state = 75, .external_lex_state = 2},
  [245] = {.lex_state = 75, .external_lex_state = 2},
  [246] = {.lex_state = 75, .external_lex_state = 2},
  [247] = {.lex_state = 75, .external_lex_state = 2},
  [248] = {.lex_state = 75, .external_lex_state = 2},
  [249] = {.lex_state = 75, .external_lex_state = 2},
  [250] = {.lex_state = 75, .external_lex_state = 2},
  [251] = {.lex_state = 75, .external_lex_state = 2},
  [252] = {.lex_state = 75, .external_lex_state = 2},
  [253] = {.lex_state = 75, .external_lex_state = 2},
  [254] = {.lex_state = 75, .external_lex_state = 2},
  [255] = {.lex_state = 75, .external_lex_state = 2},
  [256] = {.lex_state = 3, .external_lex_state = 3},
  [257] = {.lex_state = 3, .external_lex_state = 3},
  [258] = {.lex_state = 3, .external_lex_state = 3},
  [259] = {.lex_state = 3, .external_lex_state = 3},
  [260] = {.lex_state = 75, .external_lex_state = 2},
  [261] = {.lex_state = 75, .external_lex_state = 2},
  [262] = {.lex_state = 75, .external_lex_state = 2},
  [263] = {.lex_state = 75, .external_lex_state = 2},
  [264] = {.lex_state = 75, .external_lex_state = 2},
  [265] = {.lex_state = 75, .external_lex_state = 2},
  [266] = {.lex_state = 75, .external_lex_state = 2},
  [267] = {.lex_state = 75, .external_lex_state = 2},
  [268] = {.lex_state = 75, .external_lex_state = 2},
  [269] = {.lex_state = 75, .external_lex_state = 2},
  [270] = {.lex_state = 75, .external_lex_state = 2},
  [271] = {.lex_state = 75, .external_lex_state = 2},
  [272] = {.lex_state = 75, .external_lex_state = 2},
  [273] = {.lex_state = 75, .external_lex_state = 2},
  [274] = {.lex_state = 75, .external_lex_state = 2},
  [275] = {.lex_state = 75, .external_lex_state = 2},
  [276] = {.lex_state = 75, .external_lex_state = 2},
  [277] = {.lex_state = 75, .external_lex_state = 2},
  [278] = {.lex_state = 75, .external_lex_state = 2},
  [279] = {.lex_state = 75, .external_lex_state = 2},
  [280] = {.lex_state = 75, .external_lex_state = 2},
  [281] = {.lex_state = 75, .external_lex_state = 2},
  [282] = {.lex_state = 75, .external_lex_state = 2},
  [283] = {.lex_state = 75, .external_lex_state = 2},
  [284] = {.lex_state = 75, .external_lex_state = 2},
  [285] = {.lex_state = 75, .external_lex_state = 2},
  [286] = {.lex_state = 75, .external_lex_state = 2},
  [287] = {.lex_state = 75, .external_lex_state = 2},
  [288] = {.lex_state = 75, .external_lex_state = 2},
  [289] = {.lex_state = 75, .external_lex_state = 2},
  [290] = {.lex_state = 75, .external_lex_state = 2},
  [291] = {.lex_state = 75, .external_lex_state = 2},
  [292] = {.lex_state = 75, .external_lex_state = 2},
  [293] = {.lex_state = 75, .external_lex_state = 2},
  [294] = {.lex_state = 75, .external_lex_state = 2},
  [295] = {.lex_state = 75, .external_lex_state = 2},
  [296] = {.lex_state = 75, .external_lex_state = 2},
  [297] = {.lex_state = 75, .external_lex_state = 5},
  [298] = {.lex_state = 75, .external_lex_state = 2},
  [299] = {.lex_state = 75, .external_lex_state = 2},
  [300] = {.lex_state = 75, .external_lex_state = 2},
  [301] = {.lex_state = 75, .external_lex_state = 2},
  [302] = {.lex_state = 75, .external_lex_state = 2},
  [303] = {.lex_state = 75, .external_lex_state = 2},
  [304] = {.lex_state = 75, .external_lex_state = 2},
  [305] = {.lex_state = 75, .external_lex_state = 2},
  [306] = {.lex_state = 75, .external_lex_state = 2},
  [307] = {.lex_state = 75, .external_lex_state = 2},
  [308] = {.lex_state = 75, .external_lex_state = 2},
  [309] = {.lex_state = 75, .external_lex_state = 2},
  [310] = {.lex_state = 75, .external_lex_state = 2},
  [311] = {.lex_state = 75, .external_lex_state = 2},
  [312] = {.lex_state = 75, .external_lex_state = 2},
  [313] = {.lex_state = 75, .external_lex_state = 2},
  [314] = {.lex_state = 75, .external_lex_state = 2},
  [315] = {.lex_state = 75, .external_lex_state = 2},
  [316] = {.lex_state = 75, .external_lex_state = 2},
  [317] = {.lex_state = 75, .external_lex_state = 2},
  [318] = {.lex_state = 75, .external_lex_state = 2},
  [319] = {.lex_state = 75, .external_lex_state = 2},
  [320] = {.lex_state = 75, .external_lex_state = 2},
  [321] = {.lex_state = 75, .external_lex_state = 2},
  [322] = {.lex_state = 75, .external_lex_state = 2},
  [323] = {.lex_state = 75, .external_lex_state = 2},
  [324] = {.lex_state = 75, .external_lex_state = 2},
  [325] = {.lex_state = 75, .external_lex_state = 2},
  [326] = {.lex_state = 75, .external_lex_state = 2},
  [327] = {.lex_state = 75, .external_lex_state = 2},
  [328] = {.lex_state = 75, .external_lex_state = 2},
  [329] = {.lex_state = 75, .external_lex_state = 2},
  [330] = {.lex_state = 75, .external_lex_state = 2},
  [331] = {.lex_state = 75, .external_lex_state = 2},
  [332] = {.lex_state = 75, .external_lex_state = 2},
  [333] = {.lex_state = 75, .external_lex_state = 2},
  [334] = {.lex_state = 75, .external_lex_state = 2},
  [335] = {.lex_state = 75, .external_lex_state = 2},
  [336] = {.lex_state = 75, .external_lex_state = 2},
  [337] = {.lex_state = 75, .external_lex_state = 2},
  [338] = {.lex_state = 75, .external_lex_state = 2},
  [339] = {.lex_state = 75, .external_lex_state = 2},
  [340] = {.lex_state = 75, .external_lex_state = 2},
  [341] = {.lex_state = 75, .external_lex_state = 2},
  [342] = {.lex_state = 75, .external_lex_state = 2},
  [343] = {.lex_state = 75, .external_lex_state = 2},
  [344] = {.lex_state = 75, .external_lex_state = 2},
  [345] = {.lex_state = 75, .external_lex_state = 2},
  [346] = {.lex_state = 75, .external_lex_state = 2},
  [347] = {.lex_state = 75, .external_lex_state = 2},
  [348] = {.lex_state = 75, .external_lex_state = 2},
  [349] = {.lex_state = 75, .external_lex_state = 2},
  [350] = {.lex_state = 75, .external_lex_state = 2},
  [351] = {.lex_state = 75, .external_lex_state = 2},
  [352] = {.lex_state = 75, .external_lex_state = 2},
  [353] = {.lex_state = 75, .external_lex_state = 2},
  [354] = {.lex_state = 75, .external_lex_state = 2},
  [355] = {.lex_state = 75, .external_lex_state = 2},
  [356] = {.lex_state = 75, .external_lex_state = 2},
  [357] = {.lex_state = 75, .external_lex_state = 2},
  [358] = {.lex_state = 75, .external_lex_state = 2},
  [359] = {.lex_state = 75, .external_lex_state = 2},
  [360] = {.lex_state = 75, .external_lex_state = 2},
  [361] = {.lex_state = 75, .external_lex_state = 2},
  [362] = {.lex_state = 75, .external_lex_state = 2},
  [363] = {.lex_state = 75, .external_lex_state = 2},
  [364] = {.lex_state = 75, .external_lex_state = 2},
  [365] = {.lex_state = 75, .external_lex_state = 2},
  [366] = {.lex_state = 75, .external_lex_state = 2},
  [367] = {.lex_state = 75, .external_lex_state = 2},
  [368] = {.lex_state = 75, .external_lex_state = 2},
  [369] = {.lex_state = 75, .external_lex_state = 2},
  [370] = {.lex_state = 75, .external_lex_state = 2},
  [371] = {.lex_state = 75, .external_lex_state = 2},
  [372] = {.lex_state = 75, .external_lex_state = 2},
  [373] = {.lex_state = 75, .external_lex_state = 2},
  [374] = {.lex_state = 75, .external_lex_state = 2},
  [375] = {.lex_state = 75, .external_lex_state = 2},
  [376] = {.lex_state = 75, .external_lex_state = 2},
  [377] = {.lex_state = 75, .external_lex_state = 2},
  [378] = {.lex_state = 75, .external_lex_state = 2},
  [379] = {.lex_state = 75, .external_lex_state = 2},
  [380] = {.lex_state = 75, .external_lex_state = 2},
  [381] = {.lex_state = 75, .external_lex_state = 2},
  [382] = {.lex_state = 75, .external_lex_state = 2},
  [383] = {.lex_state = 75, .external_lex_state = 2},
  [384] = {.lex_state = 75, .external_lex_state = 2},
  [385] = {.lex_state = 75, .external_lex_state = 2},
  [386] = {.lex_state = 75, .external_lex_state = 2},
  [387] = {.lex_state = 75, .external_lex_state = 2},
  [388] = {.lex_state = 75, .external_lex_state = 2},
  [389] = {.lex_state = 75, .external_lex_state = 2},
  [390] = {.lex_state = 75, .external_lex_state = 2},
  [391] = {.lex_state = 75, .external_lex_state = 2},
  [392] = {.lex_state = 75, .external_lex_state = 2},
  [393] = {.lex_state = 75, .external_lex_state = 2},
  [394] = {.lex_state = 75, .external_lex_state = 2},
  [395] = {.lex_state = 75, .external_lex_state = 2},
  [396] = {.lex_state = 75, .external_lex_state = 2},
  [397] = {.lex_state = 75, .external_lex_state = 2},
  [398] = {.lex_state = 75, .external_lex_state = 2},
  [399] = {.lex_state = 75, .external_lex_state = 2},
  [400] = {.lex_state = 75, .external_lex_state = 2},
  [401] = {.lex_state = 75, .external_lex_state = 2},
  [402] = {.lex_state = 75, .external_lex_state = 2},
  [403] = {.lex_state = 75, .external_lex_state = 2},
  [404] = {.lex_state = 75, .external_lex_state = 2},
  [405] = {.lex_state = 75, .external_lex_state = 2},
  [406] = {.lex_state = 75, .external_lex_state = 2},
  [407] = {.lex_state = 75, .external_lex_state = 2},
  [408] = {.lex_state = 75, .external_lex_state = 2},
  [409] = {.lex_state = 75, .external_lex_state = 2},
  [410] = {.lex_state = 75, .external_lex_state = 2},
  [411] = {.lex_state = 75, .external_lex_state = 2},
  [412] = {.lex_state = 75, .external_lex_state = 2},
  [413] = {.lex_state = 75, .external_lex_state = 2},
  [414] = {.lex_state = 75, .external_lex_state = 2},
  [415] = {.lex_state = 75, .external_lex_state = 2},
  [416] = {.lex_state = 75, .external_lex_state = 2},
  [417] = {.lex_state = 75, .external_lex_state = 2},
  [418] = {.lex_state = 75, .external_lex_state = 2},
  [419] = {.lex_state = 75, .external_lex_state = 2},
  [420] = {.lex_state = 75, .external_lex_state = 2},
  [421] = {.lex_state = 75, .external_lex_state = 2},
  [422] = {.lex_state = 75, .external_lex_state = 2},
  [423] = {.lex_state = 75, .external_lex_state = 2},
  [424] = {.lex_state = 75, .external_lex_state = 2},
  [425] = {.lex_state = 75, .external_lex_state = 2},
  [426] = {.lex_state = 75, .external_lex_state = 2},
  [427] = {.lex_state = 3, .external_lex_state = 4},
  [428] = {.lex_state = 75, .external_lex_state = 2},
  [429] = {.lex_state = 75, .external_lex_state = 2},
  [430] = {.lex_state = 75, .external_lex_state = 2},
  [431] = {.lex_state = 75, .external_lex_state = 2},
  [432] = {.lex_state = 75, .external_lex_state = 2},
  [433] = {.lex_state = 75, .external_lex_state = 2},
  [434] = {.lex_state = 75, .external_lex_state = 2},
  [435] = {.lex_state = 75, .external_lex_state = 2},
  [436] = {.lex_state = 75, .external_lex_state = 2},
  [437] = {.lex_state = 75, .external_lex_state = 2},
  [438] = {.lex_state = 75, .external_lex_state = 2},
  [439] = {.lex_state = 75, .external_lex_state = 2},
  [440] = {.lex_state = 3, .external_lex_state = 4},
  [441] = {.lex_state = 75, .external_lex_state = 2},
  [442] = {.lex_state = 75, .external_lex_state = 2},
  [443] = {.lex_state = 75, .external_lex_state = 2},
  [444] = {.lex_state = 75, .external_lex_state = 2},
  [445] = {.lex_state = 75, .external_lex_state = 2},
  [446] = {.lex_state = 75, .external_lex_state = 2},
  [447] = {.lex_state = 75, .external_lex_state = 2},
  [448] = {.lex_state = 75, .external_lex_state = 2},
  [449] = {.lex_state = 75, .external_lex_state = 2},
  [450] = {.lex_state = 75, .external_lex_state = 2},
  [451] = {.lex_state = 75, .external_lex_state = 2},
  [452] = {.lex_state = 75, .external_lex_state = 2},
  [453] = {.lex_state = 75, .external_lex_state = 2},
  [454] = {.lex_state = 75, .external_lex_state = 2},
  [455] = {.lex_state = 75, .external_lex_state = 2},
  [456] = {.lex_state = 75, .external_lex_state = 2},
  [457] = {.lex_state = 75, .external_lex_state = 2},
  [458] = {.lex_state = 75, .external_lex_state = 2},
  [459] = {.lex_state = 75, .external_lex_state = 2},
  [460] = {.lex_state = 75, .external_lex_state = 2},
  [461] = {.lex_state = 75, .external_lex_state = 2},
  [462] = {.lex_state = 75, .external_lex_state = 2},
  [463] = {.lex_state = 75, .external_lex_state = 2},
  [464] = {.lex_state = 75, .external_lex_state = 2},
  [465] = {.lex_state = 75, .external_lex_state = 2},
  [466] = {.lex_state = 75, .external_lex_state = 2},
  [467] = {.lex_state = 75, .external_lex_state = 2},
  [468] = {.lex_state = 75, .external_lex_state = 2},
  [469] = {.lex_state = 75, .external_lex_state = 2},
  [470] = {.lex_state = 75, .external_lex_state = 2},
  [471] = {.lex_state = 75, .external_lex_state = 2},
  [472] = {.lex_state = 75, .external_lex_state = 2},
  [473] = {.lex_state = 75, .external_lex_state = 2},
  [474] = {.lex_state = 75, .external_lex_state = 2},
  [475] = {.lex_state = 75, .external_lex_state = 2},
  [476] = {.lex_state = 75, .external_lex_state = 2},
  [477] = {.lex_state = 75, .external_lex_state = 2},
  [478] = {.lex_state = 75, .external_lex_state = 2},
  [479] = {.lex_state = 75, .external_lex_state = 2},
  [480] = {.lex_state = 75, .external_lex_state = 2},
  [481] = {.lex_state = 75, .external_lex_state = 2},
  [482] = {.lex_state = 75, .external_lex_state = 2},
  [483] = {.lex_state = 75, .external_lex_state = 2},
  [484] = {.lex_state = 75, .external_lex_state = 2},
  [485] = {.lex_state = 75, .external_lex_state = 2},
  [486] = {.lex_state = 75, .external_lex_state = 2},
  [487] = {.lex_state = 75, .external_lex_state = 2},
  [488] = {.lex_state = 75, .external_lex_state = 2},
  [489] = {.lex_state = 75, .external_lex_state = 2},
  [490] = {.lex_state = 75, .external_lex_state = 2},
  [491] = {.lex_state = 75, .external_lex_state = 2},
  [492] = {.lex_state = 75, .external_lex_state = 2},
  [493] = {.lex_state = 75, .external_lex_state = 2},
  [494] = {.lex_state = 75, .external_lex_state = 2},
  [495] = {.lex_state = 75, .external_lex_state = 2},
  [496] = {.lex_state = 75, .external_lex_state = 2},
  [497] = {.lex_state = 75, .external_lex_state = 2},
  [498] = {.lex_state = 75, .external_lex_state = 2},
  [499] = {.lex_state = 75, .external_lex_state = 2},
  [500] = {.lex_state = 75, .external_lex_state = 2},
  [501] = {.lex_state = 75, .external_lex_state = 2},
  [502] = {.lex_state = 75, .external_lex_state = 2},
  [503] = {.lex_state = 75, .external_lex_state = 2},
  [504] = {.lex_state = 75, .external_lex_state = 2},
  [505] = {.lex_state = 75, .external_lex_state = 2},
  [506] = {.lex_state = 75, .external_lex_state = 2},
  [507] = {.lex_state = 75, .external_lex_state = 2},
  [508] = {.lex_state = 75, .external_lex_state = 2},
  [509] = {.lex_state = 75, .external_lex_state = 2},
  [510] = {.lex_state = 75, .external_lex_state = 2},
  [511] = {.lex_state = 75, .external_lex_state = 2},
  [512] = {.lex_state = 75, .external_lex_state = 2},
  [513] = {.lex_state = 75, .external_lex_state = 2},
  [514] = {.lex_state = 75, .external_lex_state = 2},
  [515] = {.lex_state = 75, .external_lex_state = 2},
  [516] = {.lex_state = 75, .external_lex_state = 2},
  [517] = {.lex_state = 75, .external_lex_state = 2},
  [518] = {.lex_state = 75, .external_lex_state = 2},
  [519] = {.lex_state = 75, .external_lex_state = 2},
  [520] = {.lex_state = 75, .external_lex_state = 2},
  [521] = {.lex_state = 75, .external_lex_state = 2},
  [522] = {.lex_state = 75, .external_lex_state = 2},
  [523] = {.lex_state = 75, .external_lex_state = 2},
  [524] = {.lex_state = 75, .external_lex_state = 2},
  [525] = {.lex_state = 75, .external_lex_state = 2},
  [526] = {.lex_state = 75, .external_lex_state = 2},
  [527] = {.lex_state = 75, .external_lex_state = 2},
  [528] = {.lex_state = 75, .external_lex_state = 2},
  [529] = {.lex_state = 75, .external_lex_state = 2},
  [530] = {.lex_state = 75, .external_lex_state = 2},
  [531] = {.lex_state = 75, .external_lex_state = 2},
  [532] = {.lex_state = 75, .external_lex_state = 2},
  [533] = {.lex_state = 75, .external_lex_state = 2},
  [534] = {.lex_state = 75, .external_lex_state = 2},
  [535] = {.lex_state = 75, .external_lex_state = 2},
  [536] = {.lex_state = 75, .external_lex_state = 2},
  [537] = {.lex_state = 75, .external_lex_state = 2},
  [538] = {.lex_state = 75, .external_lex_state = 2},
  [539] = {.lex_state = 75, .external_lex_state = 2},
  [540] = {.lex_state = 75, .external_lex_state = 2},
  [541] = {.lex_state = 75, .external_lex_state = 2},
  [542] = {.lex_state = 75, .external_lex_state = 2},
  [543] = {.lex_state = 75, .external_lex_state = 2},
  [544] = {.lex_state = 75, .external_lex_state = 2},
  [545] = {.lex_state = 75, .external_lex_state = 2},
  [546] = {.lex_state = 75, .external_lex_state = 2},
  [547] = {.lex_state = 75, .external_lex_state = 2},
  [548] = {.lex_state = 75, .external_lex_state = 2},
  [549] = {.lex_state = 75, .external_lex_state = 2},
  [550] = {.lex_state = 75, .external_lex_state = 2},
  [551] = {.lex_state = 75, .external_lex_state = 2},
  [552] = {.lex_state = 75, .external_lex_state = 2},
  [553] = {.lex_state = 75, .external_lex_state = 2},
  [554] = {.lex_state = 75, .external_lex_state = 2},
  [555] = {.lex_state = 75, .external_lex_state = 2},
  [556] = {.lex_state = 75, .external_lex_state = 2},
  [557] = {.lex_state = 75, .external_lex_state = 2},
  [558] = {.lex_state = 75, .external_lex_state = 2},
  [559] = {.lex_state = 75, .external_lex_state = 2},
  [560] = {.lex_state = 75, .external_lex_state = 2},
  [561] = {.lex_state = 75, .external_lex_state = 2},
  [562] = {.lex_state = 75, .external_lex_state = 2},
  [563] = {.lex_state = 75, .external_lex_state = 2},
  [564] = {.lex_state = 75, .external_lex_state = 2},
  [565] = {.lex_state = 75, .external_lex_state = 2},
  [566] = {.lex_state = 75, .external_lex_state = 2},
  [567] = {.lex_state = 75, .external_lex_state = 2},
  [568] = {.lex_state = 75, .external_lex_state = 2},
  [569] = {.lex_state = 75, .external_lex_state = 2},
  [570] = {.lex_state = 75, .external_lex_state = 2},
  [571] = {.lex_state = 75, .external_lex_state = 2},
  [572] = {.lex_state = 75, .external_lex_state = 2},
  [573] = {.lex_state = 75, .external_lex_state = 2},
  [574] = {.lex_state = 75, .external_lex_state = 2},
  [575] = {.lex_state = 75, .external_lex_state = 2},
  [576] = {.lex_state = 75, .external_lex_state = 2},
  [577] = {.lex_state = 75, .external_lex_state = 2},
  [578] = {.lex_state = 75, .external_lex_state = 2},
  [579] = {.lex_state = 75, .external_lex_state = 2},
  [580] = {.lex_state = 75, .external_lex_state = 2},
  [581] = {.lex_state = 75, .external_lex_state = 2},
  [582] = {.lex_state = 75, .external_lex_state = 2},
  [583] = {.lex_state = 75, .external_lex_state = 2},
  [584] = {.lex_state = 75, .external_lex_state = 2},
  [585] = {.lex_state = 75, .external_lex_state = 2},
  [586] = {.lex_state = 75, .external_lex_state = 2},
  [587] = {.lex_state = 75, .external_lex_state = 2},
  [588] = {.lex_state = 75, .external_lex_state = 2},
  [589] = {.lex_state = 75, .external_lex_state = 2},
  [590] = {.lex_state = 3, .external_lex_state = 4},
  [591] = {.lex_state = 75, .external_lex_state = 2},
  [592] = {.lex_state = 75, .external_lex_state = 2},
  [593] = {.lex_state = 75, .external_lex_state = 2},
  [594] = {.lex_state = 75, .external_lex_state = 2},
  [595] = {.lex_state = 75, .external_lex_state = 2},
  [596] = {.lex_state = 75, .external_lex_state = 2},
  [597] = {.lex_state = 75, .external_lex_state = 2},
  [598] = {.lex_state = 75, .external_lex_state = 2},
  [599] = {.lex_state = 75, .external_lex_state = 2},
  [600] = {.lex_state = 75, .external_lex_state = 2},
  [601] = {.lex_state = 75, .external_lex_state = 2},
  [602] = {.lex_state = 75, .external_lex_state = 2},
  [603] = {.lex_state = 75, .external_lex_state = 2},
  [604] = {.lex_state = 75, .external_lex_state = 2},
  [605] = {.lex_state = 75, .external_lex_state = 2},
  [606] = {.lex_state = 75, .external_lex_state = 2},
  [607] = {.lex_state = 75, .external_lex_state = 2},
  [608] = {.lex_state = 75, .external_lex_state = 2},
  [609] = {.lex_state = 75, .external_lex_state = 2},
  [610] = {.lex_state = 75, .external_lex_state = 2},
  [611] = {.lex_state = 75, .external_lex_state = 2},
  [612] = {.lex_state = 75, .external_lex_state = 2},
  [613] = {.lex_state = 75, .external_lex_state = 2},
  [614] = {.lex_state = 75, .external_lex_state = 2},
  [615] = {.lex_state = 75, .external_lex_state = 2},
  [616] = {.lex_state = 75, .external_lex_state = 2},
  [617] = {.lex_state = 75, .external_lex_state = 2},
  [618] = {.lex_state = 75, .external_lex_state = 2},
  [619] = {.lex_state = 75, .external_lex_state = 2},
  [620] = {.lex_state = 75, .external_lex_state = 2},
  [621] = {.lex_state = 75, .external_lex_state = 2},
  [622] = {.lex_state = 75, .external_lex_state = 2},
  [623] = {.lex_state = 75, .external_lex_state = 2},
  [624] = {.lex_state = 75, .external_lex_state = 2},
  [625] = {.lex_state = 75, .external_lex_state = 2},
  [626] = {.lex_state = 75, .external_lex_state = 2},
  [627] = {.lex_state = 75, .external_lex_state = 2},
  [628] = {.lex_state = 75, .external_lex_state = 2},
  [629] = {.lex_state = 75, .external_lex_state = 2},
  [630] = {.lex_state = 75, .external_lex_state = 2},
  [631] = {.lex_state = 75, .external_lex_state = 2},
  [632] = {.lex_state = 75, .external_lex_state = 2},
  [633] = {.lex_state = 75, .external_lex_state = 2},
  [634] = {.lex_state = 75, .external_lex_state = 2},
  [635] = {.lex_state = 75, .external_lex_state = 2},
  [636] = {.lex_state = 75, .external_lex_state = 2},
  [637] = {.lex_state = 75, .external_lex_state = 2},
  [638] = {.lex_state = 75, .external_lex_state = 2},
  [639] = {.lex_state = 75, .external_lex_state = 2},
  [640] = {.lex_state = 75, .external_lex_state = 2},
  [641] = {.lex_state = 75, .external_lex_state = 2},
  [642] = {.lex_state = 75, .external_lex_state = 2},
  [643] = {.lex_state = 75, .external_lex_state = 2},
  [644] = {.lex_state = 75, .external_lex_state = 2},
  [645] = {.lex_state = 75, .external_lex_state = 2},
  [646] = {.lex_state = 75, .external_lex_state = 2},
  [647] = {.lex_state = 75, .external_lex_state = 2},
  [648] = {.lex_state = 75, .external_lex_state = 2},
  [649] = {.lex_state = 75, .external_lex_state = 2},
  [650] = {.lex_state = 75, .external_lex_state = 2},
  [651] = {.lex_state = 75, .external_lex_state = 2},
  [652] = {.lex_state = 75, .external_lex_state = 2},
  [653] = {.lex_state = 75, .external_lex_state = 2},
  [654] = {.lex_state = 75, .external_lex_state = 2},
  [655] = {.lex_state = 75, .external_lex_state = 2},
  [656] = {.lex_state = 75, .external_lex_state = 2},
  [657] = {.lex_state = 75, .external_lex_state = 2},
  [658] = {.lex_state = 75, .external_lex_state = 2},
  [659] = {.lex_state = 75, .external_lex_state = 2},
  [660] = {.lex_state = 75, .external_lex_state = 2},
  [661] = {.lex_state = 75, .external_lex_state = 2},
  [662] = {.lex_state = 75, .external_lex_state = 2},
  [663] = {.lex_state = 75, .external_lex_state = 2},
  [664] = {.lex_state = 75, .external_lex_state = 2},
  [665] = {.lex_state = 75, .external_lex_state = 2},
  [666] = {.lex_state = 75, .external_lex_state = 2},
  [667] = {.lex_state = 75, .external_lex_state = 2},
  [668] = {.lex_state = 75, .external_lex_state = 2},
  [669] = {.lex_state = 75, .external_lex_state = 2},
  [670] = {.lex_state = 75, .external_lex_state = 2},
  [671] = {.lex_state = 75, .external_lex_state = 2},
  [672] = {.lex_state = 75, .external_lex_state = 2},
  [673] = {.lex_state = 75, .external_lex_state = 2},
  [674] = {.lex_state = 75, .external_lex_state = 2},
  [675] = {.lex_state = 75, .external_lex_state = 2},
  [676] = {.lex_state = 75, .external_lex_state = 2},
  [677] = {.lex_state = 75, .external_lex_state = 2},
  [678] = {.lex_state = 75, .external_lex_state = 2},
  [679] = {.lex_state = 75, .external_lex_state = 2},
  [680] = {.lex_state = 75, .external_lex_state = 2},
  [681] = {.lex_state = 75, .external_lex_state = 2},
  [682] = {.lex_state = 75, .external_lex_state = 2},
  [683] = {.lex_state = 75, .external_lex_state = 2},
  [684] = {.lex_state = 75, .external_lex_state = 2},
  [685] = {.lex_state = 75, .external_lex_state = 2},
  [686] = {.lex_state = 75, .external_lex_state = 2},
  [687] = {.lex_state = 75, .external_lex_state = 2},
  [688] = {.lex_state = 75, .external_lex_state = 2},
  [689] = {.lex_state = 75, .external_lex_state = 2},
  [690] = {.lex_state = 2, .external_lex_state = 4},
  [691] = {.lex_state = 2, .external_lex_state = 4},
  [692] = {.lex_state = 2, .external_lex_state = 4},
  [693] = {.lex_state = 2, .external_lex_state = 4},
  [694] = {.lex_state = 2, .external_lex_state = 4},
  [695] = {.lex_state = 2, .external_lex_state = 4},
  [696] = {.lex_state = 3, .external_lex_state = 4},
  [697] = {.lex_state = 3, .external_lex_state = 4},
  [698] = {.lex_state = 2, .external_lex_state = 4},
  [699] = {.lex_state = 2, .external_lex_state = 4},
  [700] = {.lex_state = 2, .external_lex_state = 4},
  [701] = {.lex_state = 2, .external_lex_state = 4},
  [702] = {.lex_state = 2, .external_lex_state = 4},
  [703] = {.lex_state = 2, .external_lex_state = 4},
  [704] = {.lex_state = 2, .external_lex_state = 4},
  [705] = {.lex_state = 2, .external_lex_state = 4},
  [706] = {.lex_state = 2, .external_lex_state = 4},
  [707] = {.lex_state = 2, .external_lex_state = 4},
  [708] = {.lex_state = 75, .external_lex_state = 2},
  [709] = {.lex_state = 75, .external_lex_state = 2},
  [710] = {.lex_state = 2, .external_lex_state = 4},
  [711] = {.lex_state = 75, .external_lex_state = 2},
  [712] = {.lex_state = 75, .external_lex_state = 2},
  [713] = {.lex_state = 75, .external_lex_state = 2},
  [714] = {.lex_state = 75, .external_lex_state = 2},
  [715] = {.lex_state = 75, .external_lex_state = 2},
  [716] = {.lex_state = 2, .external_lex_state = 4},
  [717] = {.lex_state = 2, .external_lex_state = 4},
  [718] = {.lex_state = 2, .external_lex_state = 4},
  [719] = {.lex_state = 2, .external_lex_state = 4},
  [720] = {.lex_state = 2, .external_lex_state = 4},
  [721] = {.lex_state = 2, .external_lex_state = 4},
  [722] = {.lex_state = 2, .external_lex_state = 4},
  [723] = {.lex_state = 2, .external_lex_state = 4},
  [724] = {.lex_state = 2, .external_lex_state = 3},
  [725] = {.lex_state = 2, .external_lex_state = 3},
  [726] = {.lex_state = 2, .external_lex_state = 3},
  [727] = {.lex_state = 2, .external_lex_state = 3},
  [728] = {.lex_state = 2, .external_lex_state = 4},
  [729] = {.lex_state = 2, .external_lex_state = 4},
  [730] = {.lex_state = 2, .external_lex_state = 4},
  [731] = {.lex_state = 2, .external_lex_state = 3},
  [732] = {.lex_state = 2, .external_lex_state = 4},
  [733] = {.lex_state = 2, .external_lex_state = 3},
  [734] = {.lex_state = 2, .external_lex_state = 4},
  [735] = {.lex_state = 2, .external_lex_state = 4},
  [736] = {.lex_state = 2, .external_lex_state = 3},
  [737] = {.lex_state = 3, .external_lex_state = 3},
  [738] = {.lex_state = 2, .external_lex_state = 3},
  [739] = {.lex_state = 2, .external_lex_state = 3},
  [740] = {.lex_state = 3, .external_lex_state = 3},
  [741] = {.lex_state = 2, .external_lex_state = 3},
  [742] = {.lex_state = 2, .external_lex_state = 3},
  [743] = {.lex_state = 2, .external_lex_state = 4},
  [744] = {.lex_state = 2, .external_lex_state = 3},
  [745] = {.lex_state = 75, .external_lex_state = 2},
  [746] = {.lex_state = 2, .external_lex_state = 3},
  [747] = {.lex_state = 75, .external_lex_state = 5},
  [748] = {.lex_state = 2, .external_lex_state = 4},
  [749] = {.lex_state = 2, .external_lex_state = 4},
  [750] = {.lex_state = 2, .external_lex_state = 4},
  [751] = {.lex_state = 2, .external_lex_state = 3},
  [752] = {.lex_state = 2, .external_lex_state = 4},
  [753] = {.lex_state = 75, .external_lex_state = 5},
  [754] = {.lex_state = 75, .external_lex_state = 5},
  [755] = {.lex_state = 75, .external_lex_state = 2},
  [756] = {.lex_state = 75, .external_lex_state = 5},
  [757] = {.lex_state = 75, .external_lex_state = 5},
  [758] = {.lex_state = 75, .external_lex_state = 5},
  [759] = {.lex_state = 75, .external_lex_state = 5},
  [760] = {.lex_state = 75, .external_lex_state = 5},
  [761] = {.lex_state = 2, .external_lex_state = 3},
  [762] = {.lex_state = 2, .external_lex_state = 3},
  [763] = {.lex_state = 2, .external_lex_state = 3},
  [764] = {.lex_state = 2, .external_lex_state = 3},
  [765] = {.lex_state = 2, .external_lex_state = 3},
  [766] = {.lex_state = 2, .external_lex_state = 3},
  [767] = {.lex_state = 2, .external_lex_state = 3},
  [768] = {.lex_state = 2, .external_lex_state = 3},
  [769] = {.lex_state = 75, .external_lex_state = 2},
  [770] = {.lex_state = 75, .external_lex_state = 2},
  [771] = {.lex_state = 2, .external_lex_state = 3},
  [772] = {.lex_state = 2, .external_lex_state = 3},
  [773] = {.lex_state = 2, .external_lex_state = 3},
  [774] = {.lex_state = 2, .external_lex_state = 3},
  [775] = {.lex_state = 2, .external_lex_state = 3},
  [776] = {.lex_state = 2, .external_lex_state = 3},
  [777] = {.lex_state = 2, .external_lex_state = 3},
  [778] = {.lex_state = 2, .external_lex_state = 3},
  [779] = {.lex_state = 2, .external_lex_state = 3},
  [780] = {.lex_state = 75, .external_lex_state = 2},
  [781] = {.lex_state = 2, .external_lex_state = 3},
  [782] = {.lex_state = 2, .external_lex_state = 3},
  [783] = {.lex_state = 75, .external_lex_state = 2},
  [784] = {.lex_state = 9, .external_lex_state = 2},
  [785] = {.lex_state = 75, .external_lex_state = 5},
  [786] = {.lex_state = 75, .external_lex_state = 5},
  [787] = {.lex_state = 75, .external_lex_state = 5},
  [788] = {.lex_state = 75, .external_lex_state = 5},
  [789] = {.lex_state = 75, .external_lex_state = 2},
  [790] = {.lex_state = 75, .external_lex_state = 2},
  [791] = {.lex_state = 75, .external_lex_state = 5},
  [792] = {.lex_state = 75, .external_lex_state = 5},
  [793] = {.lex_state = 9, .external_lex_state = 2},
  [794] = {.lex_state = 75, .external_lex_state = 5},
  [795] = {.lex_state = 9, .external_lex_state = 2},
  [796] = {.lex_state = 75, .external_lex_state = 5},
  [797] = {.lex_state = 75, .external_lex_state = 5},
  [798] = {.lex_state = 75, .external_lex_state = 2},
  [799] = {.lex_state = 75, .external_lex_state = 5},
  [800] = {.lex_state = 9, .external_lex_state = 2},
  [801] = {.lex_state = 75, .external_lex_state = 5},
  [802] = {.lex_state = 75, .external_lex_state = 2},
  [803] = {.lex_state = 75, .external_lex_state = 5},
  [804] = {.lex_state = 75, .external_lex_state = 5},
  [805] = {.lex_state = 9, .external_lex_state = 2},
  [806] = {.lex_state = 75, .external_lex_state = 5},
  [807] = {.lex_state = 75, .external_lex_state = 2},
  [808] = {.lex_state = 75, .external_lex_state = 2},
  [809] = {.lex_state = 75, .external_lex_state = 2},
  [810] = {.lex_state = 75, .external_lex_state = 2},
  [811] = {.lex_state = 75, .external_lex_state = 5},
  [812] = {.lex_state = 75, .external_lex_state = 2},
  [813] = {.lex_state = 75, .external_lex_state = 2},
  [814] = {.lex_state = 75, .external_lex_state = 2},
  [815] = {.lex_state = 75, .external_lex_state = 2},
  [816] = {.lex_state = 75, .external_lex_state = 2},
  [817] = {.lex_state = 75, .external_lex_state = 2},
  [818] = {.lex_state = 75, .external_lex_state = 2},
  [819] = {.lex_state = 75, .external_lex_state = 2},
  [820] = {.lex_state = 9, .external_lex_state = 2},
  [821] = {.lex_state = 9, .external_lex_state = 2},
  [822] = {.lex_state = 75, .external_lex_state = 2},
  [823] = {.lex_state = 75, .external_lex_state = 2},
  [824] = {.lex_state = 75, .external_lex_state = 2},
  [825] = {.lex_state = 75, .external_lex_state = 2},
  [826] = {.lex_state = 75, .external_lex_state = 2},
  [827] = {.lex_state = 75, .external_lex_state = 2},
  [828] = {.lex_state = 75, .external_lex_state = 2},
  [829] = {.lex_state = 75, .external_lex_state = 2},
  [830] = {.lex_state = 75, .external_lex_state = 2},
  [831] = {.lex_state = 75, .external_lex_state = 2},
  [832] = {.lex_state = 75, .external_lex_state = 2},
  [833] = {.lex_state = 75, .external_lex_state = 2},
  [834] = {.lex_state = 75, .external_lex_state = 2},
  [835] = {.lex_state = 75, .external_lex_state = 2},
  [836] = {.lex_state = 75, .external_lex_state = 2},
  [837] = {.lex_state = 75, .external_lex_state = 2},
  [838] = {.lex_state = 75, .external_lex_state = 2},
  [839] = {.lex_state = 75, .external_lex_state = 2},
  [840] = {.lex_state = 75, .external_lex_state = 2},
  [841] = {.lex_state = 75, .external_lex_state = 2},
  [842] = {.lex_state = 75, .external_lex_state = 2},
  [843] = {.lex_state = 75, .external_lex_state = 2},
  [844] = {.lex_state = 75, .external_lex_state = 2},
  [845] = {.lex_state = 75, .external_lex_state = 2},
  [846] = {.lex_state = 75, .external_lex_state = 2},
  [847] = {.lex_state = 75, .external_lex_state = 2},
  [848] = {.lex_state = 9, .external_lex_state = 2},
  [849] = {.lex_state = 75, .external_lex_state = 2},
  [850] = {.lex_state = 75, .external_lex_state = 2},
  [851] = {.lex_state = 75, .external_lex_state = 2},
  [852] = {.lex_state = 75, .external_lex_state = 2},
  [853] = {.lex_state = 75, .external_lex_state = 2},
  [854] = {.lex_state = 75, .external_lex_state = 2},
  [855] = {.lex_state = 75, .external_lex_state = 2},
  [856] = {.lex_state = 75, .external_lex_state = 2},
  [857] = {.lex_state = 75, .external_lex_state = 2},
  [858] = {.lex_state = 75, .external_lex_state = 2},
  [859] = {.lex_state = 75, .external_lex_state = 2},
  [860] = {.lex_state = 75, .external_lex_state = 2},
  [861] = {.lex_state = 75, .external_lex_state = 2},
  [862] = {.lex_state = 75, .external_lex_state = 2},
  [863] = {.lex_state = 75, .external_lex_state = 2},
  [864] = {.lex_state = 75, .external_lex_state = 2},
  [865] = {.lex_state = 75, .external_lex_state = 2},
  [866] = {.lex_state = 75, .external_lex_state = 2},
  [867] = {.lex_state = 75, .external_lex_state = 2},
  [868] = {.lex_state = 9, .external_lex_state = 2},
  [869] = {.lex_state = 75, .external_lex_state = 2},
  [870] = {.lex_state = 75, .external_lex_state = 2},
  [871] = {.lex_state = 75, .external_lex_state = 2},
  [872] = {.lex_state = 75, .external_lex_state = 2},
  [873] = {.lex_state = 75, .external_lex_state = 2},
  [874] = {.lex_state = 75, .external_lex_state = 2},
  [875] = {.lex_state = 75, .external_lex_state = 2},
  [876] = {.lex_state = 9, .external_lex_state = 2},
  [877] = {.lex_state = 75, .external_lex_state = 2},
  [878] = {.lex_state = 75, .external_lex_state = 2},
  [879] = {.lex_state = 75, .external_lex_state = 2},
  [880] = {.lex_state = 75, .external_lex_state = 2},
  [881] = {.lex_state = 75, .external_lex_state = 2},
  [882] = {.lex_state = 75, .external_lex_state = 2},
  [883] = {.lex_state = 75, .external_lex_state = 2},
  [884] = {.lex_state = 75, .external_lex_state = 2},
  [885] = {.lex_state = 75, .external_lex_state = 2},
  [886] = {.lex_state = 75, .external_lex_state = 2},
  [887] = {.lex_state = 75, .external_lex_state = 2},
  [888] = {.lex_state = 75, .external_lex_state = 2},
  [889] = {.lex_state = 9, .external_lex_state = 2},
  [890] = {.lex_state = 75, .external_lex_state = 2},
  [891] = {.lex_state = 75, .external_lex_state = 2},
  [892] = {.lex_state = 75, .external_lex_state = 2},
  [893] = {.lex_state = 75, .external_lex_state = 2},
  [894] = {.lex_state = 75, .external_lex_state = 2},
  [895] = {.lex_state = 75, .external_lex_state = 2},
  [896] = {.lex_state = 75, .external_lex_state = 2},
  [897] = {.lex_state = 75, .external_lex_state = 2},
  [898] = {.lex_state = 75, .external_lex_state = 2},
  [899] = {.lex_state = 75, .external_lex_state = 2},
  [900] = {.lex_state = 9, .external_lex_state = 2},
  [901] = {.lex_state = 75, .external_lex_state = 2},
  [902] = {.lex_state = 75, .external_lex_state = 2},
  [903] = {.lex_state = 75, .external_lex_state = 2},
  [904] = {.lex_state = 75, .external_lex_state = 2},
  [905] = {.lex_state = 75, .external_lex_state = 2},
  [906] = {.lex_state = 9, .external_lex_state = 2},
  [907] = {.lex_state = 75, .external_lex_state = 2},
  [908] = {.lex_state = 75, .external_lex_state = 2},
  [909] = {.lex_state = 75, .external_lex_state = 2},
  [910] = {.lex_state = 75, .external_lex_state = 2},
  [911] = {.lex_state = 75, .external_lex_state = 2},
  [912] = {.lex_state = 75, .external_lex_state = 2},
  [913] = {.lex_state = 75, .external_lex_state = 2},
  [914] = {.lex_state = 75, .external_lex_state = 2},
  [915] = {.lex_state = 75, .external_lex_state = 2},
  [916] = {.lex_state = 75, .external_lex_state = 2},
  [917] = {.lex_state = 75, .external_lex_state = 2},
  [918] = {.lex_state = 75, .external_lex_state = 2},
  [919] = {.lex_state = 75, .external_lex_state = 2},
  [920] = {.lex_state = 75, .external_lex_state = 2},
  [921] = {.lex_state = 75, .external_lex_state = 2},
  [922] = {.lex_state = 75, .external_lex_state = 2},
  [923] = {.lex_state = 75, .external_lex_state = 2},
  [924] = {.lex_state = 75, .external_lex_state = 2},
  [925] = {.lex_state = 75, .external_lex_state = 2},
  [926] = {.lex_state = 75, .external_lex_state = 2},
  [927] = {.lex_state = 75, .external_lex_state = 2},
  [928] = {.lex_state = 75, .external_lex_state = 2},
  [929] = {.lex_state = 75, .external_lex_state = 2},
  [930] = {.lex_state = 75, .external_lex_state = 2},
  [931] = {.lex_state = 75, .external_lex_state = 2},
  [932] = {.lex_state = 75, .external_lex_state = 2},
  [933] = {.lex_state = 9, .external_lex_state = 2},
  [934] = {.lex_state = 75, .external_lex_state = 2},
  [935] = {.lex_state = 9, .external_lex_state = 2},
  [936] = {.lex_state = 75, .external_lex_state = 2},
  [937] = {.lex_state = 75, .external_lex_state = 2},
  [938] = {.lex_state = 75, .external_lex_state = 2},
  [939] = {.lex_state = 75, .external_lex_state = 2},
  [940] = {.lex_state = 75, .external_lex_state = 2},
  [941] = {.lex_state = 75, .external_lex_state = 2},
  [942] = {.lex_state = 75, .external_lex_state = 2},
  [943] = {.lex_state = 75, .external_lex_state = 2},
  [944] = {.lex_state = 75, .external_lex_state = 2},
  [945] = {.lex_state = 9, .external_lex_state = 2},
  [946] = {.lex_state = 9, .external_lex_state = 2},
  [947] = {.lex_state = 75, .external_lex_state = 2},
  [948] = {.lex_state = 9, .external_lex_state = 2},
  [949] = {.lex_state = 9, .external_lex_state = 2},
  [950] = {.lex_state = 75, .external_lex_state = 2},
  [951] = {.lex_state = 9, .external_lex_state = 2},
  [952] = {.lex_state = 75, .external_lex_state = 2},
  [953] = {.lex_state = 9, .external_lex_state = 2},
  [954] = {.lex_state = 75, .external_lex_state = 2},
  [955] = {.lex_state = 75, .external_lex_state = 2},
  [956] = {.lex_state = 75, .external_lex_state = 2},
  [957] = {.lex_state = 9, .external_lex_state = 2},
  [958] = {.lex_state = 75, .external_lex_state = 2},
  [959] = {.lex_state = 9, .external_lex_state = 2},
  [960] = {.lex_state = 75, .external_lex_state = 2},
  [961] = {.lex_state = 9, .external_lex_state = 2},
  [962] = {.lex_state = 9, .external_lex_state = 2},
  [963] = {.lex_state = 9, .external_lex_state = 2},
  [964] = {.lex_state = 9, .external_lex_state = 2},
  [965] = {.lex_state = 75, .external_lex_state = 2},
  [966] = {.lex_state = 75, .external_lex_state = 2},
  [967] = {.lex_state = 9, .external_lex_state = 2},
  [968] = {.lex_state = 9, .external_lex_state = 2},
  [969] = {.lex_state = 75, .external_lex_state = 2},
  [970] = {.lex_state = 75, .external_lex_state = 2},
  [971] = {.lex_state = 9, .external_lex_state = 2},
  [972] = {.lex_state = 75, .external_lex_state = 2},
  [973] = {.lex_state = 9, .external_lex_state = 2},
  [974] = {.lex_state = 9, .external_lex_state = 2},
  [975] = {.lex_state = 75, .external_lex_state = 2},
  [976] = {.lex_state = 9, .external_lex_state = 2},
  [977] = {.lex_state = 9, .external_lex_state = 2},
  [978] = {.lex_state = 9, .external_lex_state = 2},
  [979] = {.lex_state = 9, .external_lex_state = 2},
  [980] = {.lex_state = 9, .external_lex_state = 2},
  [981] = {.lex_state = 9, .external_lex_state = 2},
  [982] = {.lex_state = 9, .external_lex_state = 2},
  [983] = {.lex_state = 9, .external_lex_state = 2},
  [984] = {.lex_state = 9, .external_lex_state = 2},
  [985] = {.lex_state = 9, .external_lex_state = 2},
  [986] = {.lex_state = 9, .external_lex_state = 2},
  [987] = {.lex_state = 9, .external_lex_state = 2},
  [988] = {.lex_state = 7, .external_lex_state = 2},
  [989] = {.lex_state = 9, .external_lex_state = 2},
  [990] = {.lex_state = 9, .external_lex_state = 2},
  [991] = {.lex_state = 7, .external_lex_state = 2},
  [992] = {.lex_state = 7, .external_lex_state = 2},
  [993] = {.lex_state = 9, .external_lex_state = 2},
  [994] = {.lex_state = 9, .external_lex_state = 2},
  [995] = {.lex_state = 9, .external_lex_state = 2},
  [996] = {.lex_state = 9, .external_lex_state = 2},
  [997] = {.lex_state = 9, .external_lex_state = 2},
  [998] = {.lex_state = 9, .external_lex_state = 2},
  [999] = {.lex_state = 9, .external_lex_state = 2},
  [1000] = {.lex_state = 9, .external_lex_state = 2},
  [1001] = {.lex_state = 9, .external_lex_state = 2},
  [1002] = {.lex_state = 9, .external_lex_state = 2},
  [1003] = {.lex_state = 9, .external_lex_state = 2},
  [1004] = {.lex_state = 9, .external_lex_state = 2},
  [1005] = {.lex_state = 9, .external_lex_state = 2},
  [1006] = {.lex_state = 9, .external_lex_state = 2},
  [1007] = {.lex_state = 9, .external_lex_state = 2},
  [1008] = {.lex_state = 9, .external_lex_state = 2},
  [1009] = {.lex_state = 9, .external_lex_state = 2},
  [1010] = {.lex_state = 9, .external_lex_state = 2},
  [1011] = {.lex_state = 9, .external_lex_state = 2},
  [1012] = {.lex_state = 9, .external_lex_state = 2},
  [1013] = {.lex_state = 9, .external_lex_state = 2},
  [1014] = {.lex_state = 9, .external_lex_state = 2},
  [1015] = {.lex_state = 9, .external_lex_state = 2},
  [1016] = {.lex_state = 9, .external_lex_state = 2},
  [1017] = {.lex_state = 9, .external_lex_state = 2},
  [1018] = {.lex_state = 9, .external_lex_state = 2},
  [1019] = {.lex_state = 9, .external_lex_state = 2},
  [1020] = {.lex_state = 9, .external_lex_state = 2},
  [1021] = {.lex_state = 9, .external_lex_state = 2},
  [1022] = {.lex_state = 9, .external_lex_state = 2},
  [1023] = {.lex_state = 9, .external_lex_state = 2},
  [1024] = {.lex_state = 9, .external_lex_state = 2},
  [1025] = {.lex_state = 9, .external_lex_state = 2},
  [1026] = {.lex_state = 9, .external_lex_state = 2},
  [1027] = {.lex_state = 9, .external_lex_state = 2},
  [1028] = {.lex_state = 9, .external_lex_state = 2},
  [1029] = {.lex_state = 9, .external_lex_state = 2},
  [1030] = {.lex_state = 9, .external_lex_state = 2},
  [1031] = {.lex_state = 9, .external_lex_state = 2},
  [1032] = {.lex_state = 9, .external_lex_state = 2},
  [1033] = {.lex_state = 9, .external_lex_state = 2},
  [1034] = {.lex_state = 9, .external_lex_state = 2},
  [1035] = {.lex_state = 9, .external_lex_state = 2},
  [1036] = {.lex_state = 9, .external_lex_state = 2},
  [1037] = {.lex_state = 9, .external_lex_state = 2},
  [1038] = {.lex_state = 9, .external_lex_state = 2},
  [1039] = {.lex_state = 9, .external_lex_state = 2},
  [1040] = {.lex_state = 9, .external_lex_state = 2},
  [1041] = {.lex_state = 9, .external_lex_state = 2},
  [1042] = {.lex_state = 9, .external_lex_state = 2},
  [1043] = {.lex_state = 9, .external_lex_state = 2},
  [1044] = {.lex_state = 9, .external_lex_state = 2},
  [1045] = {.lex_state = 9, .external_lex_state = 2},
  [1046] = {.lex_state = 9, .external_lex_state = 2},
  [1047] = {.lex_state = 9, .external_lex_state = 2},
  [1048] = {.lex_state = 9, .external_lex_state = 2},
  [1049] = {.lex_state = 9, .external_lex_state = 2},
  [1050] = {.lex_state = 9, .external_lex_state = 2},
  [1051] = {.lex_state = 9, .external_lex_state = 2},
  [1052] = {.lex_state = 9, .external_lex_state = 2},
  [1053] = {.lex_state = 9, .external_lex_state = 2},
  [1054] = {.lex_state = 9, .external_lex_state = 2},
  [1055] = {.lex_state = 9, .external_lex_state = 2},
  [1056] = {.lex_state = 9, .external_lex_state = 2},
  [1057] = {.lex_state = 9, .external_lex_state = 2},
  [1058] = {.lex_state = 9, .external_lex_state = 2},
  [1059] = {.lex_state = 9, .external_lex_state = 2},
  [1060] = {.lex_state = 9, .external_lex_state = 2},
  [1061] = {.lex_state = 9, .external_lex_state = 2},
  [1062] = {.lex_state = 9, .external_lex_state = 2},
  [1063] = {.lex_state = 9, .external_lex_state = 2},
  [1064] = {.lex_state = 9, .external_lex_state = 2},
  [1065] = {.lex_state = 9, .external_lex_state = 2},
  [1066] = {.lex_state = 9, .external_lex_state = 2},
  [1067] = {.lex_state = 9, .external_lex_state = 2},
  [1068] = {.lex_state = 9, .external_lex_state = 2},
  [1069] = {.lex_state = 9, .external_lex_state = 2},
  [1070] = {.lex_state = 9, .external_lex_state = 2},
  [1071] = {.lex_state = 9, .external_lex_state = 2},
  [1072] = {.lex_state = 9, .external_lex_state = 2},
  [1073] = {.lex_state = 9, .external_lex_state = 2},
  [1074] = {.lex_state = 9, .external_lex_state = 2},
  [1075] = {.lex_state = 9, .external_lex_state = 2},
  [1076] = {.lex_state = 9, .external_lex_state = 2},
  [1077] = {.lex_state = 9, .external_lex_state = 2},
  [1078] = {.lex_state = 9, .external_lex_state = 2},
  [1079] = {.lex_state = 9, .external_lex_state = 2},
  [1080] = {.lex_state = 9, .external_lex_state = 2},
  [1081] = {.lex_state = 9, .external_lex_state = 2},
  [1082] = {.lex_state = 9, .external_lex_state = 2},
  [1083] = {.lex_state = 9, .external_lex_state = 2},
  [1084] = {.lex_state = 9, .external_lex_state = 2},
  [1085] = {.lex_state = 9, .external_lex_state = 2},
  [1086] = {.lex_state = 9, .external_lex_state = 2},
  [1087] = {.lex_state = 9, .external_lex_state = 2},
  [1088] = {.lex_state = 9, .external_lex_state = 2},
  [1089] = {.lex_state = 9, .external_lex_state = 2},
  [1090] = {.lex_state = 9, .external_lex_state = 2},
  [1091] = {.lex_state = 9, .external_lex_state = 2},
  [1092] = {.lex_state = 9, .external_lex_state = 2},
  [1093] = {.lex_state = 9, .external_lex_state = 2},
  [1094] = {.lex_state = 9, .external_lex_state = 2},
  [1095] = {.lex_state = 9, .external_lex_state = 2},
  [1096] = {.lex_state = 9, .external_lex_state = 2},
  [1097] = {.lex_state = 9, .external_lex_state = 2},
  [1098] = {.lex_state = 9, .external_lex_state = 2},
  [1099] = {.lex_state = 9, .external_lex_state = 2},
  [1100] = {.lex_state = 9, .external_lex_state = 2},
  [1101] = {.lex_state = 9, .external_lex_state = 2},
  [1102] = {.lex_state = 9, .external_lex_state = 2},
  [1103] = {.lex_state = 9, .external_lex_state = 2},
  [1104] = {.lex_state = 9, .external_lex_state = 2},
  [1105] = {.lex_state = 9, .external_lex_state = 2},
  [1106] = {.lex_state = 9, .external_lex_state = 2},
  [1107] = {.lex_state = 9, .external_lex_state = 2},
  [1108] = {.lex_state = 9, .external_lex_state = 2},
  [1109] = {.lex_state = 9, .external_lex_state = 2},
  [1110] = {.lex_state = 9, .external_lex_state = 2},
  [1111] = {.lex_state = 9, .external_lex_state = 2},
  [1112] = {.lex_state = 9, .external_lex_state = 2},
  [1113] = {.lex_state = 9, .external_lex_state = 2},
  [1114] = {.lex_state = 9, .external_lex_state = 2},
  [1115] = {.lex_state = 9, .external_lex_state = 2},
  [1116] = {.lex_state = 9, .external_lex_state = 2},
  [1117] = {.lex_state = 9, .external_lex_state = 2},
  [1118] = {.lex_state = 9, .external_lex_state = 2},
  [1119] = {.lex_state = 9, .external_lex_state = 2},
  [1120] = {.lex_state = 9, .external_lex_state = 2},
  [1121] = {.lex_state = 9, .external_lex_state = 2},
  [1122] = {.lex_state = 9, .external_lex_state = 2},
  [1123] = {.lex_state = 9, .external_lex_state = 2},
  [1124] = {.lex_state = 9, .external_lex_state = 2},
  [1125] = {.lex_state = 9, .external_lex_state = 2},
  [1126] = {.lex_state = 9, .external_lex_state = 2},
  [1127] = {.lex_state = 9, .external_lex_state = 2},
  [1128] = {.lex_state = 9, .external_lex_state = 2},
  [1129] = {.lex_state = 9, .external_lex_state = 2},
  [1130] = {.lex_state = 9, .external_lex_state = 2},
  [1131] = {.lex_state = 9, .external_lex_state = 2},
  [1132] = {.lex_state = 9, .external_lex_state = 2},
  [1133] = {.lex_state = 9, .external_lex_state = 2},
  [1134] = {.lex_state = 9, .external_lex_state = 2},
  [1135] = {.lex_state = 9, .external_lex_state = 2},
  [1136] = {.lex_state = 9, .external_lex_state = 2},
  [1137] = {.lex_state = 9, .external_lex_state = 2},
  [1138] = {.lex_state = 9, .external_lex_state = 2},
  [1139] = {.lex_state = 9, .external_lex_state = 2},
  [1140] = {.lex_state = 9, .external_lex_state = 2},
  [1141] = {.lex_state = 9, .external_lex_state = 2},
  [1142] = {.lex_state = 9, .external_lex_state = 2},
  [1143] = {.lex_state = 9, .external_lex_state = 2},
  [1144] = {.lex_state = 9, .external_lex_state = 2},
  [1145] = {.lex_state = 9, .external_lex_state = 2},
  [1146] = {.lex_state = 9, .external_lex_state = 2},
  [1147] = {.lex_state = 9, .external_lex_state = 2},
  [1148] = {.lex_state = 9, .external_lex_state = 2},
  [1149] = {.lex_state = 9, .external_lex_state = 2},
  [1150] = {.lex_state = 9, .external_lex_state = 2},
  [1151] = {.lex_state = 10, .external_lex_state = 2},
  [1152] = {.lex_state = 10, .external_lex_state = 2},
  [1153] = {.lex_state = 10, .external_lex_state = 2},
  [1154] = {.lex_state = 10, .external_lex_state = 2},
  [1155] = {.lex_state = 10, .external_lex_state = 2},
  [1156] = {.lex_state = 10, .external_lex_state = 2},
  [1157] = {.lex_state = 10, .external_lex_state = 2},
  [1158] = {.lex_state = 10, .external_lex_state = 2},
  [1159] = {.lex_state = 10, .external_lex_state = 2},
  [1160] = {.lex_state = 10, .external_lex_state = 2},
  [1161] = {.lex_state = 10, .external_lex_state = 2},
  [1162] = {.lex_state = 10, .external_lex_state = 2},
  [1163] = {.lex_state = 3, .external_lex_state = 4},
  [1164] = {.lex_state = 2, .external_lex_state = 4},
  [1165] = {.lex_state = 3, .external_lex_state = 4},
  [1166] = {.lex_state = 75, .external_lex_state = 2},
  [1167] = {.lex_state = 2, .external_lex_state = 4},
  [1168] = {.lex_state = 2, .external_lex_state = 4},
  [1169] = {.lex_state = 3, .external_lex_state = 4},
  [1170] = {.lex_state = 75, .external_lex_state = 2},
  [1171] = {.lex_state = 75, .external_lex_state = 2},
  [1172] = {.lex_state = 2, .external_lex_state = 4},
  [1173] = {.lex_state = 2, .external_lex_state = 4},
  [1174] = {.lex_state = 2, .external_lex_state = 4},
  [1175] = {.lex_state = 2, .external_lex_state = 3},
  [1176] = {.lex_state = 2, .external_lex_state = 3},
  [1177] = {.lex_state = 2, .external_lex_state = 3},
  [1178] = {.lex_state = 2, .external_lex_state = 3},
  [1179] = {.lex_state = 10, .external_lex_state = 2},
  [1180] = {.lex_state = 10, .external_lex_state = 2},
  [1181] = {.lex_state = 2, .external_lex_state = 4},
  [1182] = {.lex_state = 3, .external_lex_state = 4},
  [1183] = {.lex_state = 2, .external_lex_state = 4},
  [1184] = {.lex_state = 2, .external_lex_state = 4},
  [1185] = {.lex_state = 2, .external_lex_state = 3},
  [1186] = {.lex_state = 2, .external_lex_state = 3},
  [1187] = {.lex_state = 2, .external_lex_state = 4},
  [1188] = {.lex_state = 2, .external_lex_state = 4},
  [1189] = {.lex_state = 2, .external_lex_state = 4},
  [1190] = {.lex_state = 2, .external_lex_state = 4},
  [1191] = {.lex_state = 2, .external_lex_state = 4},
  [1192] = {.lex_state = 3, .external_lex_state = 4},
  [1193] = {.lex_state = 2, .external_lex_state = 4},
  [1194] = {.lex_state = 2, .external_lex_state = 4},
  [1195] = {.lex_state = 2, .external_lex_state = 3},
  [1196] = {.lex_state = 2, .external_lex_state = 4},
  [1197] = {.lex_state = 3, .external_lex_state = 3},
  [1198] = {.lex_state = 3, .external_lex_state = 3},
  [1199] = {.lex_state = 3, .external_lex_state = 3},
  [1200] = {.lex_state = 3, .external_lex_state = 3},
  [1201] = {.lex_state = 3, .external_lex_state = 3},
  [1202] = {.lex_state = 3, .external_lex_state = 3},
  [1203] = {.lex_state = 2, .external_lex_state = 3},
  [1204] = {.lex_state = 3, .external_lex_state = 3},
  [1205] = {.lex_state = 3, .external_lex_state = 3},
  [1206] = {.lex_state = 3, .external_lex_state = 3},
  [1207] = {.lex_state = 3, .external_lex_state = 3},
  [1208] = {.lex_state = 2, .external_lex_state = 3},
  [1209] = {.lex_state = 3, .external_lex_state = 3},
  [1210] = {.lex_state = 2, .external_lex_state = 3},
  [1211] = {.lex_state = 2, .external_lex_state = 3},
  [1212] = {.lex_state = 3, .external_lex_state = 3},
  [1213] = {.lex_state = 3, .external_lex_state = 3},
  [1214] = {.lex_state = 2, .external_lex_state = 3},
  [1215] = {.lex_state = 2, .external_lex_state = 4},
  [1216] = {.lex_state = 2, .external_lex_state = 4},
  [1217] = {.lex_state = 3, .external_lex_state = 3},
  [1218] = {.lex_state = 2, .external_lex_state = 4},
  [1219] = {.lex_state = 3, .external_lex_state = 3},
  [1220] = {.lex_state = 2, .external_lex_state = 4},
  [1221] = {.lex_state = 3, .external_lex_state = 4},
  [1222] = {.lex_state = 3, .external_lex_state = 4},
  [1223] = {.lex_state = 2, .external_lex_state = 3},
  [1224] = {.lex_state = 2, .external_lex_state = 4},
  [1225] = {.lex_state = 2, .external_lex_state = 3},
  [1226] = {.lex_state = 2, .external_lex_state = 4},
  [1227] = {.lex_state = 2, .external_lex_state = 4},
  [1228] = {.lex_state = 2, .external_lex_state = 4},
  [1229] = {.lex_state = 2, .external_lex_state = 3},
  [1230] = {.lex_state = 2, .external_lex_state = 4},
  [1231] = {.lex_state = 2, .external_lex_state = 4},
  [1232] = {.lex_state = 2, .external_lex_state = 4},
  [1233] = {.lex_state = 2, .external_lex_state = 4},
  [1234] = {.lex_state = 2, .external_lex_state = 3},
  [1235] = {.lex_state = 2, .external_lex_state = 3},
  [1236] = {.lex_state = 2, .external_lex_state = 3},
  [1237] = {.lex_state = 2, .external_lex_state = 3},
  [1238] = {.lex_state = 2, .external_lex_state = 3},
  [1239] = {.lex_state = 2, .external_lex_state = 3},
  [1240] = {.lex_state = 2, .external_lex_state = 3},
  [1241] = {.lex_state = 2, .external_lex_state = 3},
  [1242] = {.lex_state = 2, .external_lex_state = 3},
  [1243] = {.lex_state = 2, .external_lex_state = 3},
  [1244] = {.lex_state = 2, .external_lex_state = 4},
  [1245] = {.lex_state = 2, .external_lex_state = 4},
  [1246] = {.lex_state = 75, .external_lex_state = 2},
  [1247] = {.lex_state = 2, .external_lex_state = 4},
  [1248] = {.lex_state = 2, .external_lex_state = 3},
  [1249] = {.lex_state = 2, .external_lex_state = 4},
  [1250] = {.lex_state = 2, .external_lex_state = 3},
  [1251] = {.lex_state = 2, .external_lex_state = 3},
  [1252] = {.lex_state = 2, .external_lex_state = 3},
  [1253] = {.lex_state = 2, .external_lex_state = 3},
  [1254] = {.lex_state = 3, .external_lex_state = 3},
  [1255] = {.lex_state = 3, .external_lex_state = 3},
  [1256] = {.lex_state = 2, .external_lex_state = 4},
  [1257] = {.lex_state = 2, .external_lex_state = 3},
  [1258] = {.lex_state = 2, .external_lex_state = 3},
  [1259] = {.lex_state = 2, .external_lex_state = 3},
  [1260] = {.lex_state = 2, .external_lex_state = 3},
  [1261] = {.lex_state = 2, .external_lex_state = 3},
  [1262] = {.lex_state = 2, .external_lex_state = 4},
  [1263] = {.lex_state = 2, .external_lex_state = 3},
  [1264] = {.lex_state = 2, .external_lex_state = 3},
  [1265] = {.lex_state = 2, .external_lex_state = 3},
  [1266] = {.lex_state = 2, .external_lex_state = 3},
  [1267] = {.lex_state = 2, .external_lex_state = 3},
  [1268] = {.lex_state = 2, .external_lex_state = 3},
  [1269] = {.lex_state = 75, .external_lex_state = 2},
  [1270] = {.lex_state = 2, .external_lex_state = 4},
  [1271] = {.lex_state = 2, .external_lex_state = 3},
  [1272] = {.lex_state = 75, .external_lex_state = 2},
  [1273] = {.lex_state = 2, .external_lex_state = 3},
  [1274] = {.lex_state = 2, .external_lex_state = 3},
  [1275] = {.lex_state = 2, .external_lex_state = 3},
  [1276] = {.lex_state = 2, .external_lex_state = 3},
  [1277] = {.lex_state = 2, .external_lex_state = 3},
  [1278] = {.lex_state = 2, .external_lex_state = 3},
  [1279] = {.lex_state = 2, .external_lex_state = 3},
  [1280] = {.lex_state = 2, .external_lex_state = 3},
  [1281] = {.lex_state = 2, .external_lex_state = 3},
  [1282] = {.lex_state = 2, .external_lex_state = 4},
  [1283] = {.lex_state = 2, .external_lex_state = 3},
  [1284] = {.lex_state = 2, .external_lex_state = 4},
  [1285] = {.lex_state = 2, .external_lex_state = 4},
  [1286] = {.lex_state = 2, .external_lex_state = 3},
  [1287] = {.lex_state = 75, .external_lex_state = 2},
  [1288] = {.lex_state = 75, .external_lex_state = 2},
  [1289] = {.lex_state = 2, .external_lex_state = 3},
  [1290] = {.lex_state = 2, .external_lex_state = 4},
  [1291] = {.lex_state = 2, .external_lex_state = 4},
  [1292] = {.lex_state = 2, .external_lex_state = 4},
  [1293] = {.lex_state = 2, .external_lex_state = 3},
  [1294] = {.lex_state = 2, .external_lex_state = 4},
  [1295] = {.lex_state = 2, .external_lex_state = 3},
  [1296] = {.lex_state = 2, .external_lex_state = 3},
  [1297] = {.lex_state = 75, .external_lex_state = 2},
  [1298] = {.lex_state = 2, .external_lex_state = 3},
  [1299] = {.lex_state = 2, .external_lex_state = 3},
  [1300] = {.lex_state = 2, .external_lex_state = 4},
  [1301] = {.lex_state = 2, .external_lex_state = 3},
  [1302] = {.lex_state = 3, .external_lex_state = 3},
  [1303] = {.lex_state = 2, .external_lex_state = 4},
  [1304] = {.lex_state = 2, .external_lex_state = 3},
  [1305] = {.lex_state = 2, .external_lex_state = 3},
  [1306] = {.lex_state = 2, .external_lex_state = 3},
  [1307] = {.lex_state = 2, .external_lex_state = 4},
  [1308] = {.lex_state = 2, .external_lex_state = 4},
  [1309] = {.lex_state = 2, .external_lex_state = 3},
  [1310] = {.lex_state = 2, .external_lex_state = 4},
  [1311] = {.lex_state = 2, .external_lex_state = 4},
  [1312] = {.lex_state = 2, .external_lex_state = 4},
  [1313] = {.lex_state = 2, .external_lex_state = 4},
  [1314] = {.lex_state = 2, .external_lex_state = 3},
  [1315] = {.lex_state = 2, .external_lex_state = 4},
  [1316] = {.lex_state = 2, .external_lex_state = 4},
  [1317] = {.lex_state = 75, .external_lex_state = 2},
  [1318] = {.lex_state = 2, .external_lex_state = 3},
  [1319] = {.lex_state = 2, .external_lex_state = 3},
  [1320] = {.lex_state = 2, .external_lex_state = 4},
  [1321] = {.lex_state = 2, .external_lex_state = 4},
  [1322] = {.lex_state = 2, .external_lex_state = 3},
  [1323] = {.lex_state = 2, .external_lex_state = 3},
  [1324] = {.lex_state = 2, .external_lex_state = 4},
  [1325] = {.lex_state = 2, .external_lex_state = 4},
  [1326] = {.lex_state = 2, .external_lex_state = 4},
  [1327] = {.lex_state = 2, .external_lex_state = 3},
  [1328] = {.lex_state = 2, .external_lex_state = 4},
  [1329] = {.lex_state = 2, .external_lex_state = 4},
  [1330] = {.lex_state = 2, .external_lex_state = 4},
  [1331] = {.lex_state = 2, .external_lex_state = 4},
  [1332] = {.lex_state = 75, .external_lex_state = 2},
  [1333] = {.lex_state = 2, .external_lex_state = 3},
  [1334] = {.lex_state = 2, .external_lex_state = 4},
  [1335] = {.lex_state = 2, .external_lex_state = 4},
  [1336] = {.lex_state = 2, .external_lex_state = 3},
  [1337] = {.lex_state = 2, .external_lex_state = 4},
  [1338] = {.lex_state = 2, .external_lex_state = 3},
  [1339] = {.lex_state = 2, .external_lex_state = 3},
  [1340] = {.lex_state = 2, .external_lex_state = 3},
  [1341] = {.lex_state = 2, .external_lex_state = 3},
  [1342] = {.lex_state = 2, .external_lex_state = 4},
  [1343] = {.lex_state = 3, .external_lex_state = 3},
  [1344] = {.lex_state = 75, .external_lex_state = 2},
  [1345] = {.lex_state = 2, .external_lex_state = 3},
  [1346] = {.lex_state = 2, .external_lex_state = 3},
  [1347] = {.lex_state = 2, .external_lex_state = 4},
  [1348] = {.lex_state = 2, .external_lex_state = 4},
  [1349] = {.lex_state = 2, .external_lex_state = 3},
  [1350] = {.lex_state = 2, .external_lex_state = 4},
  [1351] = {.lex_state = 2, .external_lex_state = 4},
  [1352] = {.lex_state = 2, .external_lex_state = 3},
  [1353] = {.lex_state = 3, .external_lex_state = 3},
  [1354] = {.lex_state = 2, .external_lex_state = 3},
  [1355] = {.lex_state = 3, .external_lex_state = 3},
  [1356] = {.lex_state = 2, .external_lex_state = 3},
  [1357] = {.lex_state = 2, .external_lex_state = 3},
  [1358] = {.lex_state = 2, .external_lex_state = 3},
  [1359] = {.lex_state = 2, .external_lex_state = 4},
  [1360] = {.lex_state = 2, .external_lex_state = 3},
  [1361] = {.lex_state = 2, .external_lex_state = 3},
  [1362] = {.lex_state = 2, .external_lex_state = 4},
  [1363] = {.lex_state = 2, .external_lex_state = 3},
  [1364] = {.lex_state = 2, .external_lex_state = 4},
  [1365] = {.lex_state = 2, .external_lex_state = 3},
  [1366] = {.lex_state = 2, .external_lex_state = 3},
  [1367] = {.lex_state = 2, .external_lex_state = 4},
  [1368] = {.lex_state = 2, .external_lex_state = 3},
  [1369] = {.lex_state = 2, .external_lex_state = 3},
  [1370] = {.lex_state = 2, .external_lex_state = 3},
  [1371] = {.lex_state = 2, .external_lex_state = 3},
  [1372] = {.lex_state = 2, .external_lex_state = 3},
  [1373] = {.lex_state = 2, .external_lex_state = 3},
  [1374] = {.lex_state = 3, .external_lex_state = 3},
  [1375] = {.lex_state = 3, .external_lex_state = 3},
  [1376] = {.lex_state = 2, .external_lex_state = 3},
  [1377] = {.lex_state = 2, .external_lex_state = 3},
  [1378] = {.lex_state = 2, .external_lex_state = 3},
  [1379] = {.lex_state = 2, .external_lex_state = 3},
  [1380] = {.lex_state = 9, .external_lex_state = 2},
  [1381] = {.lex_state = 2, .external_lex_state = 3},
  [1382] = {.lex_state = 9, .external_lex_state = 2},
  [1383] = {.lex_state = 2, .external_lex_state = 4},
  [1384] = {.lex_state = 2, .external_lex_state = 4},
  [1385] = {.lex_state = 2, .external_lex_state = 4},
  [1386] = {.lex_state = 9, .external_lex_state = 2},
  [1387] = {.lex_state = 3, .external_lex_state = 3},
  [1388] = {.lex_state = 2, .external_lex_state = 3},
  [1389] = {.lex_state = 9, .external_lex_state = 2},
  [1390] = {.lex_state = 2, .external_lex_state = 3},
  [1391] = {.lex_state = 2, .external_lex_state = 3},
  [1392] = {.lex_state = 2, .external_lex_state = 3},
  [1393] = {.lex_state = 2, .external_lex_state = 3},
  [1394] = {.lex_state = 9, .external_lex_state = 2},
  [1395] = {.lex_state = 9, .external_lex_state = 2},
  [1396] = {.lex_state = 2, .external_lex_state = 3},
  [1397] = {.lex_state = 2, .external_lex_state = 3},
  [1398] = {.lex_state = 2, .external_lex_state = 3},
  [1399] = {.lex_state = 2, .external_lex_state = 3},
  [1400] = {.lex_state = 2, .external_lex_state = 4},
  [1401] = {.lex_state = 2, .external_lex_state = 3},
  [1402] = {.lex_state = 2, .external_lex_state = 3},
  [1403] = {.lex_state = 2, .external_lex_state = 3},
  [1404] = {.lex_state = 2, .external_lex_state = 3},
  [1405] = {.lex_state = 2, .external_lex_state = 3},
  [1406] = {.lex_state = 2, .external_lex_state = 3},
  [1407] = {.lex_state = 2, .external_lex_state = 3},
  [1408] = {.lex_state = 2, .external_lex_state = 3},
  [1409] = {.lex_state = 2, .external_lex_state = 3},
  [1410] = {.lex_state = 2, .external_lex_state = 4},
  [1411] = {.lex_state = 2, .external_lex_state = 3},
  [1412] = {.lex_state = 2, .external_lex_state = 3},
  [1413] = {.lex_state = 2, .external_lex_state = 3},
  [1414] = {.lex_state = 2, .external_lex_state = 3},
  [1415] = {.lex_state = 2, .external_lex_state = 3},
  [1416] = {.lex_state = 2, .external_lex_state = 3},
  [1417] = {.lex_state = 2, .external_lex_state = 3},
  [1418] = {.lex_state = 2, .external_lex_state = 3},
  [1419] = {.lex_state = 9, .external_lex_state = 2},
  [1420] = {.lex_state = 2, .external_lex_state = 3},
  [1421] = {.lex_state = 2, .external_lex_state = 3},
  [1422] = {.lex_state = 2, .external_lex_state = 3},
  [1423] = {.lex_state = 9, .external_lex_state = 2},
  [1424] = {.lex_state = 9, .external_lex_state = 2},
  [1425] = {.lex_state = 2, .external_lex_state = 3},
  [1426] = {.lex_state = 9, .external_lex_state = 2},
  [1427] = {.lex_state = 2, .external_lex_state = 3},
  [1428] = {.lex_state = 2, .external_lex_state = 3},
  [1429] = {.lex_state = 2, .external_lex_state = 3},
  [1430] = {.lex_state = 2, .external_lex_state = 3},
  [1431] = {.lex_state = 2, .external_lex_state = 3},
  [1432] = {.lex_state = 9, .external_lex_state = 2},
  [1433] = {.lex_state = 9, .external_lex_state = 2},
  [1434] = {.lex_state = 2, .external_lex_state = 3},
  [1435] = {.lex_state = 2, .external_lex_state = 3},
  [1436] = {.lex_state = 9, .external_lex_state = 2},
  [1437] = {.lex_state = 9, .external_lex_state = 2},
  [1438] = {.lex_state = 2, .external_lex_state = 3},
  [1439] = {.lex_state = 9, .external_lex_state = 2},
  [1440] = {.lex_state = 2, .external_lex_state = 3},
  [1441] = {.lex_state = 9, .external_lex_state = 2},
  [1442] = {.lex_state = 9, .external_lex_state = 2},
  [1443] = {.lex_state = 9, .external_lex_state = 2},
  [1444] = {.lex_state = 2, .external_lex_state = 3},
  [1445] = {.lex_state = 2, .external_lex_state = 3},
  [1446] = {.lex_state = 2, .external_lex_state = 3},
  [1447] = {.lex_state = 2, .external_lex_state = 3},
  [1448] = {.lex_state = 2, .external_lex_state = 3},
  [1449] = {.lex_state = 2, .external_lex_state = 3},
  [1450] = {.lex_state = 9, .external_lex_state = 2},
  [1451] = {.lex_state = 2, .external_lex_state = 3},
  [1452] = {.lex_state = 2, .external_lex_state = 3},
  [1453] = {.lex_state = 2, .external_lex_state = 3},
  [1454] = {.lex_state = 9, .external_lex_state = 2},
  [1455] = {.lex_state = 9, .external_lex_state = 2},
  [1456] = {.lex_state = 2, .external_lex_state = 3},
  [1457] = {.lex_state = 2, .external_lex_state = 3},
  [1458] = {.lex_state = 2, .external_lex_state = 3},
  [1459] = {.lex_state = 2, .external_lex_state = 3},
  [1460] = {.lex_state = 9, .external_lex_state = 2},
  [1461] = {.lex_state = 2, .external_lex_state = 3},
  [1462] = {.lex_state = 9, .external_lex_state = 2},
  [1463] = {.lex_state = 9, .external_lex_state = 2},
  [1464] = {.lex_state = 2, .external_lex_state = 3},
  [1465] = {.lex_state = 2, .external_lex_state = 3},
  [1466] = {.lex_state = 2, .external_lex_state = 3},
  [1467] = {.lex_state = 2, .external_lex_state = 3},
  [1468] = {.lex_state = 2, .external_lex_state = 3},
  [1469] = {.lex_state = 2, .external_lex_state = 3},
  [1470] = {.lex_state = 2, .external_lex_state = 3},
  [1471] = {.lex_state = 2, .external_lex_state = 3},
  [1472] = {.lex_state = 2, .external_lex_state = 3},
  [1473] = {.lex_state = 2, .external_lex_state = 3},
  [1474] = {.lex_state = 9, .external_lex_state = 2},
  [1475] = {.lex_state = 9, .external_lex_state = 2},
  [1476] = {.lex_state = 9, .external_lex_state = 2},
  [1477] = {.lex_state = 9, .external_lex_state = 2},
  [1478] = {.lex_state = 9, .external_lex_state = 2},
  [1479] = {.lex_state = 9, .external_lex_state = 2},
  [1480] = {.lex_state = 9, .external_lex_state = 2},
  [1481] = {.lex_state = 75, .external_lex_state = 5},
  [1482] = {.lex_state = 9, .external_lex_state = 2},
  [1483] = {.lex_state = 9, .external_lex_state = 2},
  [1484] = {.lex_state = 9, .external_lex_state = 2},
  [1485] = {.lex_state = 9, .external_lex_state = 2},
  [1486] = {.lex_state = 75, .external_lex_state = 5},
  [1487] = {.lex_state = 75, .external_lex_state = 5},
  [1488] = {.lex_state = 75, .external_lex_state = 5},
  [1489] = {.lex_state = 9, .external_lex_state = 2},
  [1490] = {.lex_state = 9, .external_lex_state = 2},
  [1491] = {.lex_state = 9, .external_lex_state = 2},
  [1492] = {.lex_state = 9, .external_lex_state = 2},
  [1493] = {.lex_state = 75, .external_lex_state = 5},
  [1494] = {.lex_state = 9, .external_lex_state = 2},
  [1495] = {.lex_state = 9, .external_lex_state = 2},
  [1496] = {.lex_state = 9, .external_lex_state = 2},
  [1497] = {.lex_state = 75, .external_lex_state = 2},
  [1498] = {.lex_state = 75, .external_lex_state = 2},
  [1499] = {.lex_state = 75, .external_lex_state = 2},
  [1500] = {.lex_state = 75, .external_lex_state = 2},
  [1501] = {.lex_state = 74, .external_lex_state = 3},
  [1502] = {.lex_state = 75, .external_lex_state = 2},
  [1503] = {.lex_state = 75, .external_lex_state = 2},
  [1504] = {.lex_state = 74, .external_lex_state = 3},
  [1505] = {.lex_state = 74, .external_lex_state = 3},
  [1506] = {.lex_state = 74, .external_lex_state = 3},
  [1507] = {.lex_state = 75, .external_lex_state = 5},
  [1508] = {.lex_state = 74, .external_lex_state = 4},
  [1509] = {.lex_state = 74, .external_lex_state = 3},
  [1510] = {.lex_state = 75, .external_lex_state = 5},
  [1511] = {.lex_state = 74, .external_lex_state = 4},
  [1512] = {.lex_state = 74, .external_lex_state = 3},
  [1513] = {.lex_state = 74, .external_lex_state = 3},
  [1514] = {.lex_state = 74, .external_lex_state = 3},
  [1515] = {.lex_state = 74, .external_lex_state = 3},
  [1516] = {.lex_state = 74, .external_lex_state = 3},
  [1517] = {.lex_state = 74, .external_lex_state = 3},
  [1518] = {.lex_state = 74, .external_lex_state = 3},
  [1519] = {.lex_state = 74, .external_lex_state = 3},
  [1520] = {.lex_state = 75, .external_lex_state = 2},
  [1521] = {.lex_state = 74, .external_lex_state = 4},
  [1522] = {.lex_state = 74, .external_lex_state = 3},
  [1523] = {.lex_state = 74, .external_lex_state = 3},
  [1524] = {.lex_state = 74, .external_lex_state = 3},
  [1525] = {.lex_state = 74, .external_lex_state = 3},
  [1526] = {.lex_state = 74, .external_lex_state = 3},
  [1527] = {.lex_state = 74, .external_lex_state = 3},
  [1528] = {.lex_state = 74, .external_lex_state = 3},
  [1529] = {.lex_state = 74, .external_lex_state = 3},
  [1530] = {.lex_state = 74, .external_lex_state = 3},
  [1531] = {.lex_state = 74, .external_lex_state = 3},
  [1532] = {.lex_state = 74, .external_lex_state = 3},
  [1533] = {.lex_state = 74, .external_lex_state = 3},
  [1534] = {.lex_state = 74, .external_lex_state = 4},
  [1535] = {.lex_state = 74, .external_lex_state = 3},
  [1536] = {.lex_state = 74, .external_lex_state = 3},
  [1537] = {.lex_state = 74, .external_lex_state = 3},
  [1538] = {.lex_state = 74, .external_lex_state = 3},
  [1539] = {.lex_state = 74, .external_lex_state = 3},
  [1540] = {.lex_state = 74, .external_lex_state = 3},
  [1541] = {.lex_state = 74, .external_lex_state = 3},
  [1542] = {.lex_state = 74, .external_lex_state = 3},
  [1543] = {.lex_state = 74, .external_lex_state = 3},
  [1544] = {.lex_state = 74, .external_lex_state = 3},
  [1545] = {.lex_state = 74, .external_lex_state = 3},
  [1546] = {.lex_state = 74, .external_lex_state = 3},
  [1547] = {.lex_state = 74, .external_lex_state = 3},
  [1548] = {.lex_state = 74, .external_lex_state = 3},
  [1549] = {.lex_state = 74, .external_lex_state = 3},
  [1550] = {.lex_state = 74, .external_lex_state = 3},
  [1551] = {.lex_state = 74, .external_lex_state = 3},
  [1552] = {.lex_state = 74, .external_lex_state = 3},
  [1553] = {.lex_state = 74, .external_lex_state = 3},
  [1554] = {.lex_state = 74, .external_lex_state = 3},
  [1555] = {.lex_state = 74, .external_lex_state = 3},
  [1556] = {.lex_state = 74, .external_lex_state = 3},
  [1557] = {.lex_state = 74, .external_lex_state = 3},
  [1558] = {.lex_state = 74, .external_lex_state = 3},
  [1559] = {.lex_state = 74, .external_lex_state = 3},
  [1560] = {.lex_state = 74, .external_lex_state = 3},
  [1561] = {.lex_state = 74, .external_lex_state = 3},
  [1562] = {.lex_state = 74, .external_lex_state = 3},
  [1563] = {.lex_state = 74, .external_lex_state = 3},
  [1564] = {.lex_state = 74, .external_lex_state = 3},
  [1565] = {.lex_state = 74, .external_lex_state = 3},
  [1566] = {.lex_state = 74, .external_lex_state = 3},
  [1567] = {.lex_state = 74, .external_lex_state = 3},
  [1568] = {.lex_state = 74, .external_lex_state = 3},
  [1569] = {.lex_state = 74, .external_lex_state = 3},
  [1570] = {.lex_state = 74, .external_lex_state = 3},
  [1571] = {.lex_state = 74, .external_lex_state = 3},
  [1572] = {.lex_state = 74, .external_lex_state = 3},
  [1573] = {.lex_state = 74, .external_lex_state = 3},
  [1574] = {.lex_state = 74, .external_lex_state = 3},
  [1575] = {.lex_state = 74, .external_lex_state = 3},
  [1576] = {.lex_state = 74, .external_lex_state = 3},
  [1577] = {.lex_state = 74, .external_lex_state = 3},
  [1578] = {.lex_state = 74, .external_lex_state = 3},
  [1579] = {.lex_state = 74, .external_lex_state = 4},
  [1580] = {.lex_state = 74, .external_lex_state = 3},
  [1581] = {.lex_state = 74, .external_lex_state = 3},
  [1582] = {.lex_state = 74, .external_lex_state = 3},
  [1583] = {.lex_state = 74, .external_lex_state = 3},
  [1584] = {.lex_state = 74, .external_lex_state = 3},
  [1585] = {.lex_state = 74, .external_lex_state = 3},
  [1586] = {.lex_state = 74, .external_lex_state = 3},
  [1587] = {.lex_state = 74, .external_lex_state = 3},
  [1588] = {.lex_state = 74, .external_lex_state = 3},
  [1589] = {.lex_state = 74, .external_lex_state = 3},
  [1590] = {.lex_state = 74, .external_lex_state = 3},
  [1591] = {.lex_state = 74, .external_lex_state = 3},
  [1592] = {.lex_state = 74, .external_lex_state = 3},
  [1593] = {.lex_state = 74, .external_lex_state = 3},
  [1594] = {.lex_state = 74, .external_lex_state = 3},
  [1595] = {.lex_state = 74, .external_lex_state = 3},
  [1596] = {.lex_state = 74, .external_lex_state = 3},
  [1597] = {.lex_state = 74, .external_lex_state = 3},
  [1598] = {.lex_state = 74, .external_lex_state = 3},
  [1599] = {.lex_state = 74, .external_lex_state = 3},
  [1600] = {.lex_state = 74, .external_lex_state = 3},
  [1601] = {.lex_state = 74, .external_lex_state = 3},
  [1602] = {.lex_state = 74, .external_lex_state = 3},
  [1603] = {.lex_state = 74, .external_lex_state = 3},
  [1604] = {.lex_state = 74, .external_lex_state = 3},
  [1605] = {.lex_state = 74, .external_lex_state = 3},
  [1606] = {.lex_state = 74, .external_lex_state = 4},
  [1607] = {.lex_state = 74, .external_lex_state = 3},
  [1608] = {.lex_state = 74, .external_lex_state = 4},
  [1609] = {.lex_state = 74, .external_lex_state = 3},
  [1610] = {.lex_state = 74, .external_lex_state = 3},
  [1611] = {.lex_state = 74, .external_lex_state = 3},
  [1612] = {.lex_state = 74, .external_lex_state = 4},
  [1613] = {.lex_state = 74, .external_lex_state = 3},
  [1614] = {.lex_state = 74, .external_lex_state = 3},
  [1615] = {.lex_state = 74, .external_lex_state = 3},
  [1616] = {.lex_state = 74, .external_lex_state = 3},
  [1617] = {.lex_state = 74, .external_lex_state = 3},
  [1618] = {.lex_state = 74, .external_lex_state = 3},
  [1619] = {.lex_state = 74, .external_lex_state = 3},
  [1620] = {.lex_state = 74, .external_lex_state = 3},
  [1621] = {.lex_state = 74, .external_lex_state = 3},
  [1622] = {.lex_state = 74, .external_lex_state = 3},
  [1623] = {.lex_state = 74, .external_lex_state = 3},
  [1624] = {.lex_state = 74, .external_lex_state = 3},
  [1625] = {.lex_state = 74, .external_lex_state = 3},
  [1626] = {.lex_state = 74, .external_lex_state = 3},
  [1627] = {.lex_state = 74, .external_lex_state = 3},
  [1628] = {.lex_state = 74, .external_lex_state = 3},
  [1629] = {.lex_state = 74, .external_lex_state = 3},
  [1630] = {.lex_state = 74, .external_lex_state = 3},
  [1631] = {.lex_state = 74, .external_lex_state = 3},
  [1632] = {.lex_state = 74, .external_lex_state = 3},
  [1633] = {.lex_state = 74, .external_lex_state = 3},
  [1634] = {.lex_state = 74, .external_lex_state = 3},
  [1635] = {.lex_state = 74, .external_lex_state = 3},
  [1636] = {.lex_state = 74, .external_lex_state = 3},
  [1637] = {.lex_state = 74, .external_lex_state = 3},
  [1638] = {.lex_state = 74, .external_lex_state = 3},
  [1639] = {.lex_state = 74, .external_lex_state = 3},
  [1640] = {.lex_state = 74, .external_lex_state = 3},
  [1641] = {.lex_state = 74, .external_lex_state = 3},
  [1642] = {.lex_state = 74, .external_lex_state = 3},
  [1643] = {.lex_state = 74, .external_lex_state = 3},
  [1644] = {.lex_state = 74, .external_lex_state = 3},
  [1645] = {.lex_state = 74, .external_lex_state = 3},
  [1646] = {.lex_state = 74, .external_lex_state = 3},
  [1647] = {.lex_state = 74, .external_lex_state = 3},
  [1648] = {.lex_state = 74, .external_lex_state = 3},
  [1649] = {.lex_state = 74, .external_lex_state = 3},
  [1650] = {.lex_state = 74, .external_lex_state = 3},
  [1651] = {.lex_state = 74, .external_lex_state = 3},
  [1652] = {.lex_state = 74, .external_lex_state = 3},
  [1653] = {.lex_state = 74, .external_lex_state = 3},
  [1654] = {.lex_state = 74, .external_lex_state = 3},
  [1655] = {.lex_state = 74, .external_lex_state = 3},
  [1656] = {.lex_state = 74, .external_lex_state = 3},
  [1657] = {.lex_state = 74, .external_lex_state = 3},
  [1658] = {.lex_state = 74, .external_lex_state = 3},
  [1659] = {.lex_state = 74, .external_lex_state = 3},
  [1660] = {.lex_state = 74, .external_lex_state = 3},
  [1661] = {.lex_state = 74, .external_lex_state = 3},
  [1662] = {.lex_state = 74, .external_lex_state = 3},
  [1663] = {.lex_state = 74, .external_lex_state = 3},
  [1664] = {.lex_state = 74, .external_lex_state = 3},
  [1665] = {.lex_state = 74, .external_lex_state = 3},
  [1666] = {.lex_state = 74, .external_lex_state = 3},
  [1667] = {.lex_state = 74, .external_lex_state = 3},
  [1668] = {.lex_state = 74, .external_lex_state = 3},
  [1669] = {.lex_state = 74, .external_lex_state = 3},
  [1670] = {.lex_state = 74, .external_lex_state = 3},
  [1671] = {.lex_state = 74, .external_lex_state = 3},
  [1672] = {.lex_state = 74, .external_lex_state = 3},
  [1673] = {.lex_state = 74, .external_lex_state = 3},
  [1674] = {.lex_state = 74, .external_lex_state = 3},
  [1675] = {.lex_state = 74, .external_lex_state = 3},
  [1676] = {.lex_state = 74, .external_lex_state = 3},
  [1677] = {.lex_state = 74, .external_lex_state = 3},
  [1678] = {.lex_state = 74, .external_lex_state = 3},
  [1679] = {.lex_state = 74, .external_lex_state = 3},
  [1680] = {.lex_state = 74, .external_lex_state = 3},
  [1681] = {.lex_state = 74, .external_lex_state = 3},
  [1682] = {.lex_state = 74, .external_lex_state = 3},
  [1683] = {.lex_state = 74, .external_lex_state = 3},
  [1684] = {.lex_state = 74, .external_lex_state = 3},
  [1685] = {.lex_state = 74, .external_lex_state = 3},
  [1686] = {.lex_state = 74, .external_lex_state = 3},
  [1687] = {.lex_state = 74, .external_lex_state = 3},
  [1688] = {.lex_state = 74, .external_lex_state = 3},
  [1689] = {.lex_state = 74, .external_lex_state = 3},
  [1690] = {.lex_state = 74, .external_lex_state = 3},
  [1691] = {.lex_state = 74, .external_lex_state = 3},
  [1692] = {.lex_state = 74, .external_lex_state = 3},
  [1693] = {.lex_state = 74, .external_lex_state = 3},
  [1694] = {.lex_state = 74, .external_lex_state = 3},
  [1695] = {.lex_state = 74, .external_lex_state = 3},
  [1696] = {.lex_state = 74, .external_lex_state = 4},
  [1697] = {.lex_state = 74, .external_lex_state = 3},
  [1698] = {.lex_state = 74, .external_lex_state = 3},
  [1699] = {.lex_state = 74, .external_lex_state = 3},
  [1700] = {.lex_state = 74, .external_lex_state = 3},
  [1701] = {.lex_state = 74, .external_lex_state = 3},
  [1702] = {.lex_state = 74, .external_lex_state = 3},
  [1703] = {.lex_state = 74, .external_lex_state = 3},
  [1704] = {.lex_state = 74, .external_lex_state = 3},
  [1705] = {.lex_state = 74, .external_lex_state = 3},
  [1706] = {.lex_state = 74, .external_lex_state = 3},
  [1707] = {.lex_state = 74, .external_lex_state = 3},
  [1708] = {.lex_state = 74, .external_lex_state = 4},
  [1709] = {.lex_state = 74, .external_lex_state = 4},
  [1710] = {.lex_state = 74, .external_lex_state = 3},
  [1711] = {.lex_state = 74, .external_lex_state = 3},
  [1712] = {.lex_state = 74, .external_lex_state = 3},
  [1713] = {.lex_state = 74, .external_lex_state = 3},
  [1714] = {.lex_state = 74, .external_lex_state = 3},
  [1715] = {.lex_state = 74, .external_lex_state = 3},
  [1716] = {.lex_state = 74, .external_lex_state = 3},
  [1717] = {.lex_state = 75, .external_lex_state = 5},
  [1718] = {.lex_state = 75, .external_lex_state = 5},
  [1719] = {.lex_state = 75, .external_lex_state = 5},
  [1720] = {.lex_state = 75, .external_lex_state = 5},
  [1721] = {.lex_state = 75, .external_lex_state = 5},
  [1722] = {.lex_state = 74, .external_lex_state = 3},
  [1723] = {.lex_state = 74, .external_lex_state = 3},
  [1724] = {.lex_state = 74, .external_lex_state = 4},
  [1725] = {.lex_state = 75, .external_lex_state = 5},
  [1726] = {.lex_state = 74, .external_lex_state = 3},
  [1727] = {.lex_state = 74, .external_lex_state = 4},
  [1728] = {.lex_state = 75, .external_lex_state = 5},
  [1729] = {.lex_state = 74, .external_lex_state = 4},
  [1730] = {.lex_state = 74, .external_lex_state = 4},
  [1731] = {.lex_state = 75, .external_lex_state = 5},
  [1732] = {.lex_state = 74, .external_lex_state = 4},
  [1733] = {.lex_state = 74, .external_lex_state = 4},
  [1734] = {.lex_state = 75, .external_lex_state = 5},
  [1735] = {.lex_state = 74, .external_lex_state = 4},
  [1736] = {.lex_state = 75, .external_lex_state = 5},
  [1737] = {.lex_state = 74, .external_lex_state = 4},
  [1738] = {.lex_state = 75, .external_lex_state = 5},
  [1739] = {.lex_state = 74, .external_lex_state = 3},
  [1740] = {.lex_state = 74, .external_lex_state = 3},
  [1741] = {.lex_state = 74, .external_lex_state = 3},
  [1742] = {.lex_state = 75, .external_lex_state = 5},
  [1743] = {.lex_state = 74, .external_lex_state = 3},
  [1744] = {.lex_state = 74, .external_lex_state = 3},
  [1745] = {.lex_state = 74, .external_lex_state = 3},
  [1746] = {.lex_state = 74, .external_lex_state = 3},
  [1747] = {.lex_state = 74, .external_lex_state = 3},
  [1748] = {.lex_state = 74, .external_lex_state = 3},
  [1749] = {.lex_state = 74, .external_lex_state = 3},
  [1750] = {.lex_state = 74, .external_lex_state = 4},
  [1751] = {.lex_state = 74, .external_lex_state = 3},
  [1752] = {.lex_state = 74, .external_lex_state = 3},
  [1753] = {.lex_state = 74, .external_lex_state = 3},
  [1754] = {.lex_state = 74, .external_lex_state = 3},
  [1755] = {.lex_state = 74, .external_lex_state = 3},
  [1756] = {.lex_state = 74, .external_lex_state = 3},
  [1757] = {.lex_state = 74, .external_lex_state = 3},
  [1758] = {.lex_state = 74, .external_lex_state = 3},
  [1759] = {.lex_state = 74, .external_lex_state = 3},
  [1760] = {.lex_state = 74, .external_lex_state = 3},
  [1761] = {.lex_state = 74, .external_lex_state = 3},
  [1762] = {.lex_state = 74, .external_lex_state = 3},
  [1763] = {.lex_state = 74, .external_lex_state = 3},
  [1764] = {.lex_state = 74, .external_lex_state = 3},
  [1765] = {.lex_state = 74, .external_lex_state = 3},
  [1766] = {.lex_state = 74, .external_lex_state = 4},
  [1767] = {.lex_state = 75, .external_lex_state = 5},
  [1768] = {.lex_state = 74, .external_lex_state = 3},
  [1769] = {.lex_state = 75, .external_lex_state = 5},
  [1770] = {.lex_state = 75, .external_lex_state = 5},
  [1771] = {.lex_state = 74, .external_lex_state = 4},
  [1772] = {.lex_state = 75, .external_lex_state = 5},
  [1773] = {.lex_state = 75, .external_lex_state = 5},
  [1774] = {.lex_state = 74, .external_lex_state = 4},
  [1775] = {.lex_state = 75, .external_lex_state = 5},
  [1776] = {.lex_state = 74, .external_lex_state = 3},
  [1777] = {.lex_state = 74, .external_lex_state = 3},
  [1778] = {.lex_state = 74, .external_lex_state = 3},
  [1779] = {.lex_state = 74, .external_lex_state = 3},
  [1780] = {.lex_state = 74, .external_lex_state = 4},
  [1781] = {.lex_state = 74, .external_lex_state = 4},
  [1782] = {.lex_state = 74, .external_lex_state = 4},
  [1783] = {.lex_state = 75, .external_lex_state = 5},
  [1784] = {.lex_state = 75, .external_lex_state = 5},
  [1785] = {.lex_state = 74, .external_lex_state = 4},
  [1786] = {.lex_state = 74, .external_lex_state = 4},
  [1787] = {.lex_state = 74, .external_lex_state = 3},
  [1788] = {.lex_state = 74, .external_lex_state = 4},
  [1789] = {.lex_state = 74, .external_lex_state = 4},
  [1790] = {.lex_state = 74, .external_lex_state = 4},
  [1791] = {.lex_state = 74, .external_lex_state = 4},
  [1792] = {.lex_state = 75, .external_lex_state = 5},
  [1793] = {.lex_state = 74, .external_lex_state = 3},
  [1794] = {.lex_state = 74, .external_lex_state = 3},
  [1795] = {.lex_state = 74, .external_lex_state = 4},
  [1796] = {.lex_state = 74, .external_lex_state = 4},
  [1797] = {.lex_state = 74, .external_lex_state = 3},
  [1798] = {.lex_state = 74, .external_lex_state = 4},
  [1799] = {.lex_state = 74, .external_lex_state = 3},
  [1800] = {.lex_state = 74, .external_lex_state = 4},
  [1801] = {.lex_state = 74, .external_lex_state = 4},
  [1802] = {.lex_state = 74, .external_lex_state = 4},
  [1803] = {.lex_state = 74, .external_lex_state = 4},
  [1804] = {.lex_state = 74, .external_lex_state = 4},
  [1805] = {.lex_state = 74, .external_lex_state = 4},
  [1806] = {.lex_state = 74, .external_lex_state = 4},
  [1807] = {.lex_state = 74, .external_lex_state = 4},
  [1808] = {.lex_state = 74, .external_lex_state = 4},
  [1809] = {.lex_state = 74, .external_lex_state = 4},
  [1810] = {.lex_state = 74, .external_lex_state = 4},
  [1811] = {.lex_state = 74, .external_lex_state = 4},
  [1812] = {.lex_state = 74, .external_lex_state = 4},
  [1813] = {.lex_state = 74, .external_lex_state = 3},
  [1814] = {.lex_state = 74, .external_lex_state = 4},
  [1815] = {.lex_state = 74, .external_lex_state = 4},
  [1816] = {.lex_state = 74, .external_lex_state = 3},
  [1817] = {.lex_state = 74, .external_lex_state = 4},
  [1818] = {.lex_state = 74, .external_lex_state = 4},
  [1819] = {.lex_state = 74, .external_lex_state = 4},
  [1820] = {.lex_state = 74, .external_lex_state = 4},
  [1821] = {.lex_state = 74, .external_lex_state = 4},
  [1822] = {.lex_state = 74, .external_lex_state = 4},
  [1823] = {.lex_state = 74, .external_lex_state = 4},
  [1824] = {.lex_state = 75, .external_lex_state = 5},
  [1825] = {.lex_state = 74, .external_lex_state = 3},
  [1826] = {.lex_state = 74, .external_lex_state = 4},
  [1827] = {.lex_state = 4, .external_lex_state = 3},
  [1828] = {.lex_state = 74, .external_lex_state = 4},
  [1829] = {.lex_state = 75, .external_lex_state = 5},
  [1830] = {.lex_state = 74, .external_lex_state = 4},
  [1831] = {.lex_state = 74, .external_lex_state = 4},
  [1832] = {.lex_state = 74, .external_lex_state = 3},
  [1833] = {.lex_state = 75, .external_lex_state = 5},
  [1834] = {.lex_state = 74, .external_lex_state = 4},
  [1835] = {.lex_state = 74, .external_lex_state = 4},
  [1836] = {.lex_state = 74, .external_lex_state = 4},
  [1837] = {.lex_state = 74, .external_lex_state = 4},
  [1838] = {.lex_state = 74, .external_lex_state = 4},
  [1839] = {.lex_state = 74, .external_lex_state = 4},
  [1840] = {.lex_state = 74, .external_lex_state = 4},
  [1841] = {.lex_state = 74, .external_lex_state = 4},
  [1842] = {.lex_state = 74, .external_lex_state = 4},
  [1843] = {.lex_state = 74, .external_lex_state = 4},
  [1844] = {.lex_state = 74, .external_lex_state = 4},
  [1845] = {.lex_state = 74, .external_lex_state = 4},
  [1846] = {.lex_state = 74, .external_lex_state = 4},
  [1847] = {.lex_state = 74, .external_lex_state = 4},
  [1848] = {.lex_state = 74, .external_lex_state = 4},
  [1849] = {.lex_state = 74, .external_lex_state = 4},
  [1850] = {.lex_state = 74, .external_lex_state = 4},
  [1851] = {.lex_state = 74, .external_lex_state = 4},
  [1852] = {.lex_state = 74, .external_lex_state = 4},
  [1853] = {.lex_state = 74, .external_lex_state = 4},
  [1854] = {.lex_state = 74, .external_lex_state = 4},
  [1855] = {.lex_state = 74, .external_lex_state = 4},
  [1856] = {.lex_state = 74, .external_lex_state = 4},
  [1857] = {.lex_state = 74, .external_lex_state = 4},
  [1858] = {.lex_state = 74, .external_lex_state = 4},
  [1859] = {.lex_state = 74, .external_lex_state = 4},
  [1860] = {.lex_state = 74, .external_lex_state = 4},
  [1861] = {.lex_state = 74, .external_lex_state = 4},
  [1862] = {.lex_state = 74, .external_lex_state = 4},
  [1863] = {.lex_state = 74, .external_lex_state = 4},
  [1864] = {.lex_state = 74, .external_lex_state = 3},
  [1865] = {.lex_state = 74, .external_lex_state = 4},
  [1866] = {.lex_state = 74, .external_lex_state = 4},
  [1867] = {.lex_state = 74, .external_lex_state = 3},
  [1868] = {.lex_state = 74, .external_lex_state = 4},
  [1869] = {.lex_state = 75, .external_lex_state = 5},
  [1870] = {.lex_state = 75, .external_lex_state = 5},
  [1871] = {.lex_state = 74, .external_lex_state = 4},
  [1872] = {.lex_state = 74, .external_lex_state = 4},
  [1873] = {.lex_state = 74, .external_lex_state = 4},
  [1874] = {.lex_state = 74, .external_lex_state = 4},
  [1875] = {.lex_state = 74, .external_lex_state = 4},
  [1876] = {.lex_state = 74, .external_lex_state = 4},
  [1877] = {.lex_state = 75, .external_lex_state = 2},
  [1878] = {.lex_state = 74, .external_lex_state = 4},
  [1879] = {.lex_state = 74, .external_lex_state = 4},
  [1880] = {.lex_state = 74, .external_lex_state = 4},
  [1881] = {.lex_state = 74, .external_lex_state = 4},
  [1882] = {.lex_state = 74, .external_lex_state = 4},
  [1883] = {.lex_state = 74, .external_lex_state = 4},
  [1884] = {.lex_state = 74, .external_lex_state = 4},
  [1885] = {.lex_state = 74, .external_lex_state = 4},
  [1886] = {.lex_state = 74, .external_lex_state = 3},
  [1887] = {.lex_state = 74, .external_lex_state = 3},
  [1888] = {.lex_state = 74, .external_lex_state = 3},
  [1889] = {.lex_state = 75, .external_lex_state = 2},
  [1890] = {.lex_state = 74, .external_lex_state = 3},
  [1891] = {.lex_state = 74, .external_lex_state = 3},
  [1892] = {.lex_state = 75, .external_lex_state = 5},
  [1893] = {.lex_state = 74, .external_lex_state = 4},
  [1894] = {.lex_state = 74, .external_lex_state = 4},
  [1895] = {.lex_state = 74, .external_lex_state = 3},
  [1896] = {.lex_state = 74, .external_lex_state = 3},
  [1897] = {.lex_state = 74, .external_lex_state = 3},
  [1898] = {.lex_state = 74, .external_lex_state = 3},
  [1899] = {.lex_state = 74, .external_lex_state = 3},
  [1900] = {.lex_state = 74, .external_lex_state = 3},
  [1901] = {.lex_state = 74, .external_lex_state = 3},
  [1902] = {.lex_state = 74, .external_lex_state = 4},
  [1903] = {.lex_state = 74, .external_lex_state = 3},
  [1904] = {.lex_state = 74, .external_lex_state = 3},
  [1905] = {.lex_state = 74, .external_lex_state = 4},
  [1906] = {.lex_state = 74, .external_lex_state = 3},
  [1907] = {.lex_state = 74, .external_lex_state = 3},
  [1908] = {.lex_state = 74, .external_lex_state = 3},
  [1909] = {.lex_state = 74, .external_lex_state = 4},
  [1910] = {.lex_state = 74, .external_lex_state = 4},
  [1911] = {.lex_state = 74, .external_lex_state = 4},
  [1912] = {.lex_state = 74, .external_lex_state = 4},
  [1913] = {.lex_state = 74, .external_lex_state = 3},
  [1914] = {.lex_state = 74, .external_lex_state = 3},
  [1915] = {.lex_state = 74, .external_lex_state = 4},
  [1916] = {.lex_state = 74, .external_lex_state = 4},
  [1917] = {.lex_state = 75, .external_lex_state = 2},
  [1918] = {.lex_state = 74, .external_lex_state = 4},
  [1919] = {.lex_state = 74, .external_lex_state = 3},
  [1920] = {.lex_state = 74, .external_lex_state = 4},
  [1921] = {.lex_state = 74, .external_lex_state = 4},
  [1922] = {.lex_state = 74, .external_lex_state = 3},
  [1923] = {.lex_state = 74, .external_lex_state = 3},
  [1924] = {.lex_state = 74, .external_lex_state = 3},
  [1925] = {.lex_state = 74, .external_lex_state = 4},
  [1926] = {.lex_state = 74, .external_lex_state = 4},
  [1927] = {.lex_state = 74, .external_lex_state = 3},
  [1928] = {.lex_state = 74, .external_lex_state = 4},
  [1929] = {.lex_state = 75, .external_lex_state = 5},
  [1930] = {.lex_state = 74, .external_lex_state = 3},
  [1931] = {.lex_state = 74, .external_lex_state = 4},
  [1932] = {.lex_state = 74, .external_lex_state = 3},
  [1933] = {.lex_state = 75, .external_lex_state = 5},
  [1934] = {.lex_state = 74, .external_lex_state = 3},
  [1935] = {.lex_state = 74, .external_lex_state = 4},
  [1936] = {.lex_state = 74, .external_lex_state = 3},
  [1937] = {.lex_state = 74, .external_lex_state = 4},
  [1938] = {.lex_state = 74, .external_lex_state = 4},
  [1939] = {.lex_state = 74, .external_lex_state = 4},
  [1940] = {.lex_state = 74, .external_lex_state = 4},
  [1941] = {.lex_state = 74, .external_lex_state = 4},
  [1942] = {.lex_state = 74, .external_lex_state = 4},
  [1943] = {.lex_state = 74, .external_lex_state = 4},
  [1944] = {.lex_state = 74, .external_lex_state = 4},
  [1945] = {.lex_state = 74, .external_lex_state = 4},
  [1946] = {.lex_state = 74, .external_lex_state = 3},
  [1947] = {.lex_state = 75, .external_lex_state = 2},
  [1948] = {.lex_state = 74, .external_lex_state = 4},
  [1949] = {.lex_state = 74, .external_lex_state = 3},
  [1950] = {.lex_state = 74, .external_lex_state = 3},
  [1951] = {.lex_state = 74, .external_lex_state = 4},
  [1952] = {.lex_state = 74, .external_lex_state = 4},
  [1953] = {.lex_state = 75, .external_lex_state = 2},
  [1954] = {.lex_state = 74, .external_lex_state = 3},
  [1955] = {.lex_state = 74, .external_lex_state = 3},
  [1956] = {.lex_state = 74, .external_lex_state = 4},
  [1957] = {.lex_state = 74, .external_lex_state = 4},
  [1958] = {.lex_state = 74, .external_lex_state = 4},
  [1959] = {.lex_state = 74, .external_lex_state = 3},
  [1960] = {.lex_state = 74, .external_lex_state = 3},
  [1961] = {.lex_state = 74, .external_lex_state = 4},
  [1962] = {.lex_state = 75, .external_lex_state = 2},
  [1963] = {.lex_state = 74, .external_lex_state = 4},
  [1964] = {.lex_state = 74, .external_lex_state = 4},
  [1965] = {.lex_state = 74, .external_lex_state = 4},
  [1966] = {.lex_state = 74, .external_lex_state = 4},
  [1967] = {.lex_state = 74, .external_lex_state = 4},
  [1968] = {.lex_state = 75, .external_lex_state = 5},
  [1969] = {.lex_state = 75, .external_lex_state = 5},
  [1970] = {.lex_state = 74, .external_lex_state = 4},
  [1971] = {.lex_state = 75, .external_lex_state = 5},
  [1972] = {.lex_state = 75, .external_lex_state = 5},
  [1973] = {.lex_state = 74, .external_lex_state = 4},
  [1974] = {.lex_state = 74, .external_lex_state = 4},
  [1975] = {.lex_state = 74, .external_lex_state = 4},
  [1976] = {.lex_state = 74, .external_lex_state = 3},
  [1977] = {.lex_state = 74, .external_lex_state = 4},
  [1978] = {.lex_state = 74, .external_lex_state = 4},
  [1979] = {.lex_state = 74, .external_lex_state = 4},
  [1980] = {.lex_state = 74, .external_lex_state = 4},
  [1981] = {.lex_state = 74, .external_lex_state = 4},
  [1982] = {.lex_state = 74, .external_lex_state = 4},
  [1983] = {.lex_state = 74, .external_lex_state = 4},
  [1984] = {.lex_state = 74, .external_lex_state = 4},
  [1985] = {.lex_state = 74, .external_lex_state = 4},
  [1986] = {.lex_state = 74, .external_lex_state = 4},
  [1987] = {.lex_state = 74, .external_lex_state = 4},
  [1988] = {.lex_state = 74, .external_lex_state = 4},
  [1989] = {.lex_state = 74, .external_lex_state = 4},
  [1990] = {.lex_state = 74, .external_lex_state = 4},
  [1991] = {.lex_state = 74, .external_lex_state = 4},
  [1992] = {.lex_state = 74, .external_lex_state = 4},
  [1993] = {.lex_state = 74, .external_lex_state = 4},
  [1994] = {.lex_state = 74, .external_lex_state = 4},
  [1995] = {.lex_state = 74, .external_lex_state = 4},
  [1996] = {.lex_state = 74, .external_lex_state = 4},
  [1997] = {.lex_state = 74, .external_lex_state = 4},
  [1998] = {.lex_state = 74, .external_lex_state = 4},
  [1999] = {.lex_state = 74, .external_lex_state = 4},
  [2000] = {.lex_state = 74, .external_lex_state = 4},
  [2001] = {.lex_state = 74, .external_lex_state = 4},
  [2002] = {.lex_state = 74, .external_lex_state = 3},
  [2003] = {.lex_state = 74, .external_lex_state = 3},
  [2004] = {.lex_state = 74, .external_lex_state = 4},
  [2005] = {.lex_state = 74, .external_lex_state = 4},
  [2006] = {.lex_state = 74, .external_lex_state = 4},
  [2007] = {.lex_state = 74, .external_lex_state = 4},
  [2008] = {.lex_state = 74, .external_lex_state = 4},
  [2009] = {.lex_state = 74, .external_lex_state = 4},
  [2010] = {.lex_state = 74, .external_lex_state = 4},
  [2011] = {.lex_state = 74, .external_lex_state = 4},
  [2012] = {.lex_state = 74, .external_lex_state = 4},
  [2013] = {.lex_state = 74, .external_lex_state = 4},
  [2014] = {.lex_state = 75, .external_lex_state = 5},
  [2015] = {.lex_state = 74, .external_lex_state = 4},
  [2016] = {.lex_state = 74, .external_lex_state = 4},
  [2017] = {.lex_state = 74, .external_lex_state = 4},
  [2018] = {.lex_state = 74, .external_lex_state = 4},
  [2019] = {.lex_state = 74, .external_lex_state = 4},
  [2020] = {.lex_state = 74, .external_lex_state = 3},
  [2021] = {.lex_state = 74, .external_lex_state = 4},
  [2022] = {.lex_state = 74, .external_lex_state = 4},
  [2023] = {.lex_state = 74, .external_lex_state = 4},
  [2024] = {.lex_state = 74, .external_lex_state = 4},
  [2025] = {.lex_state = 74, .external_lex_state = 3},
  [2026] = {.lex_state = 74, .external_lex_state = 4},
  [2027] = {.lex_state = 74, .external_lex_state = 3},
  [2028] = {.lex_state = 75, .external_lex_state = 2},
  [2029] = {.lex_state = 74, .external_lex_state = 4},
  [2030] = {.lex_state = 74, .external_lex_state = 4},
  [2031] = {.lex_state = 74, .external_lex_state = 4},
  [2032] = {.lex_state = 74, .external_lex_state = 4},
  [2033] = {.lex_state = 74, .external_lex_state = 4},
  [2034] = {.lex_state = 74, .external_lex_state = 3},
  [2035] = {.lex_state = 74, .external_lex_state = 3},
  [2036] = {.lex_state = 74, .external_lex_state = 4},
  [2037] = {.lex_state = 74, .external_lex_state = 4},
  [2038] = {.lex_state = 74, .external_lex_state = 4},
  [2039] = {.lex_state = 74, .external_lex_state = 4},
  [2040] = {.lex_state = 74, .external_lex_state = 4},
  [2041] = {.lex_state = 74, .external_lex_state = 3},
  [2042] = {.lex_state = 74, .external_lex_state = 4},
  [2043] = {.lex_state = 74, .external_lex_state = 4},
  [2044] = {.lex_state = 74, .external_lex_state = 4},
  [2045] = {.lex_state = 74, .external_lex_state = 4},
  [2046] = {.lex_state = 74, .external_lex_state = 4},
  [2047] = {.lex_state = 74, .external_lex_state = 4},
  [2048] = {.lex_state = 74, .external_lex_state = 4},
  [2049] = {.lex_state = 74, .external_lex_state = 4},
  [2050] = {.lex_state = 74, .external_lex_state = 4},
  [2051] = {.lex_state = 74, .external_lex_state = 4},
  [2052] = {.lex_state = 74, .external_lex_state = 4},
  [2053] = {.lex_state = 74, .external_lex_state = 4},
  [2054] = {.lex_state = 74, .external_lex_state = 4},
  [2055] = {.lex_state = 74, .external_lex_state = 4},
  [2056] = {.lex_state = 74, .external_lex_state = 4},
  [2057] = {.lex_state = 74, .external_lex_state = 4},
  [2058] = {.lex_state = 74, .external_lex_state = 4},
  [2059] = {.lex_state = 74, .external_lex_state = 4},
  [2060] = {.lex_state = 74, .external_lex_state = 4},
  [2061] = {.lex_state = 74, .external_lex_state = 4},
  [2062] = {.lex_state = 74, .external_lex_state = 4},
  [2063] = {.lex_state = 74, .external_lex_state = 4},
  [2064] = {.lex_state = 74, .external_lex_state = 4},
  [2065] = {.lex_state = 75, .external_lex_state = 5},
  [2066] = {.lex_state = 75, .external_lex_state = 5},
  [2067] = {.lex_state = 74, .external_lex_state = 4},
  [2068] = {.lex_state = 75, .external_lex_state = 5},
  [2069] = {.lex_state = 74, .external_lex_state = 4},
  [2070] = {.lex_state = 75, .external_lex_state = 5},
  [2071] = {.lex_state = 75, .external_lex_state = 5},
  [2072] = {.lex_state = 74, .external_lex_state = 4},
  [2073] = {.lex_state = 74, .external_lex_state = 4},
  [2074] = {.lex_state = 74, .external_lex_state = 4},
  [2075] = {.lex_state = 75, .external_lex_state = 2},
  [2076] = {.lex_state = 74, .external_lex_state = 4},
  [2077] = {.lex_state = 74, .external_lex_state = 4},
  [2078] = {.lex_state = 74, .external_lex_state = 4},
  [2079] = {.lex_state = 74, .external_lex_state = 4},
  [2080] = {.lex_state = 74, .external_lex_state = 3},
  [2081] = {.lex_state = 74, .external_lex_state = 3},
  [2082] = {.lex_state = 74, .external_lex_state = 3},
  [2083] = {.lex_state = 74, .external_lex_state = 3},
  [2084] = {.lex_state = 74, .external_lex_state = 3},
  [2085] = {.lex_state = 74, .external_lex_state = 3},
  [2086] = {.lex_state = 74, .external_lex_state = 3},
  [2087] = {.lex_state = 74, .external_lex_state = 3},
  [2088] = {.lex_state = 74, .external_lex_state = 3},
  [2089] = {.lex_state = 74, .external_lex_state = 3},
  [2090] = {.lex_state = 74, .external_lex_state = 3},
  [2091] = {.lex_state = 74, .external_lex_state = 3},
  [2092] = {.lex_state = 74, .external_lex_state = 3},
  [2093] = {.lex_state = 74, .external_lex_state = 3},
  [2094] = {.lex_state = 74, .external_lex_state = 3},
  [2095] = {.lex_state = 74, .external_lex_state = 3},
  [2096] = {.lex_state = 74, .external_lex_state = 3},
  [2097] = {.lex_state = 74, .external_lex_state = 3},
  [2098] = {.lex_state = 74, .external_lex_state = 3},
  [2099] = {.lex_state = 74, .external_lex_state = 3},
  [2100] = {.lex_state = 74, .external_lex_state = 3},
  [2101] = {.lex_state = 74, .external_lex_state = 3},
  [2102] = {.lex_state = 74, .external_lex_state = 3},
  [2103] = {.lex_state = 74, .external_lex_state = 3},
  [2104] = {.lex_state = 74, .external_lex_state = 3},
  [2105] = {.lex_state = 74, .external_lex_state = 3},
  [2106] = {.lex_state = 74, .external_lex_state = 3},
  [2107] = {.lex_state = 74, .external_lex_state = 3},
  [2108] = {.lex_state = 74, .external_lex_state = 3},
  [2109] = {.lex_state = 74, .external_lex_state = 3},
  [2110] = {.lex_state = 74, .external_lex_state = 4},
  [2111] = {.lex_state = 75, .external_lex_state = 5},
  [2112] = {.lex_state = 74, .external_lex_state = 3},
  [2113] = {.lex_state = 74, .external_lex_state = 3},
  [2114] = {.lex_state = 75, .external_lex_state = 5},
  [2115] = {.lex_state = 74, .external_lex_state = 4},
  [2116] = {.lex_state = 74, .external_lex_state = 4},
  [2117] = {.lex_state = 75, .external_lex_state = 5},
  [2118] = {.lex_state = 75, .external_lex_state = 5},
  [2119] = {.lex_state = 75, .external_lex_state = 5},
  [2120] = {.lex_state = 75, .external_lex_state = 5},
  [2121] = {.lex_state = 74, .external_lex_state = 3},
  [2122] = {.lex_state = 75, .external_lex_state = 5},
  [2123] = {.lex_state = 75, .external_lex_state = 5},
  [2124] = {.lex_state = 74, .external_lex_state = 3},
  [2125] = {.lex_state = 74, .external_lex_state = 3},
  [2126] = {.lex_state = 74, .external_lex_state = 3},
  [2127] = {.lex_state = 74, .external_lex_state = 3},
  [2128] = {.lex_state = 74, .external_lex_state = 3},
  [2129] = {.lex_state = 74, .external_lex_state = 3},
  [2130] = {.lex_state = 74, .external_lex_state = 4},
  [2131] = {.lex_state = 74, .external_lex_state = 4},
  [2132] = {.lex_state = 74, .external_lex_state = 4},
  [2133] = {.lex_state = 74, .external_lex_state = 4},
  [2134] = {.lex_state = 74, .external_lex_state = 4},
  [2135] = {.lex_state = 74, .external_lex_state = 3},
  [2136] = {.lex_state = 74, .external_lex_state = 4},
  [2137] = {.lex_state = 75, .external_lex_state = 5},
  [2138] = {.lex_state = 75, .external_lex_state = 5},
  [2139] = {.lex_state = 74, .external_lex_state = 4},
  [2140] = {.lex_state = 74, .external_lex_state = 4},
  [2141] = {.lex_state = 74, .external_lex_state = 4},
  [2142] = {.lex_state = 74, .external_lex_state = 3},
  [2143] = {.lex_state = 74, .external_lex_state = 4},
  [2144] = {.lex_state = 74, .external_lex_state = 3},
  [2145] = {.lex_state = 74, .external_lex_state = 4},
  [2146] = {.lex_state = 74, .external_lex_state = 4},
  [2147] = {.lex_state = 74, .external_lex_state = 4},
  [2148] = {.lex_state = 74, .external_lex_state = 4},
  [2149] = {.lex_state = 74, .external_lex_state = 4},
  [2150] = {.lex_state = 74, .external_lex_state = 4},
  [2151] = {.lex_state = 74, .external_lex_state = 4},
  [2152] = {.lex_state = 74, .external_lex_state = 4},
  [2153] = {.lex_state = 74, .external_lex_state = 4},
  [2154] = {.lex_state = 74, .external_lex_state = 4},
  [2155] = {.lex_state = 74, .external_lex_state = 4},
  [2156] = {.lex_state = 74, .external_lex_state = 4},
  [2157] = {.lex_state = 75, .external_lex_state = 5},
  [2158] = {.lex_state = 74, .external_lex_state = 4},
  [2159] = {.lex_state = 74, .external_lex_state = 4},
  [2160] = {.lex_state = 74, .external_lex_state = 4},
  [2161] = {.lex_state = 74, .external_lex_state = 4},
  [2162] = {.lex_state = 74, .external_lex_state = 4},
  [2163] = {.lex_state = 74, .external_lex_state = 4},
  [2164] = {.lex_state = 74, .external_lex_state = 4},
  [2165] = {.lex_state = 74, .external_lex_state = 4},
  [2166] = {.lex_state = 74, .external_lex_state = 3},
  [2167] = {.lex_state = 74, .external_lex_state = 4},
  [2168] = {.lex_state = 74, .external_lex_state = 4},
  [2169] = {.lex_state = 75, .external_lex_state = 2},
  [2170] = {.lex_state = 74, .external_lex_state = 4},
  [2171] = {.lex_state = 75, .external_lex_state = 5},
  [2172] = {.lex_state = 75, .external_lex_state = 2},
  [2173] = {.lex_state = 74, .external_lex_state = 4},
  [2174] = {.lex_state = 74, .external_lex_state = 3},
  [2175] = {.lex_state = 74, .external_lex_state = 3},
  [2176] = {.lex_state = 74, .external_lex_state = 3},
  [2177] = {.lex_state = 75, .external_lex_state = 5},
  [2178] = {.lex_state = 75, .external_lex_state = 5},
  [2179] = {.lex_state = 75, .external_lex_state = 5},
  [2180] = {.lex_state = 74, .external_lex_state = 4},
  [2181] = {.lex_state = 74, .external_lex_state = 4},
  [2182] = {.lex_state = 74, .external_lex_state = 4},
  [2183] = {.lex_state = 74, .external_lex_state = 3},
  [2184] = {.lex_state = 74, .external_lex_state = 4},
  [2185] = {.lex_state = 74, .external_lex_state = 4},
  [2186] = {.lex_state = 74, .external_lex_state = 4},
  [2187] = {.lex_state = 74, .external_lex_state = 4},
  [2188] = {.lex_state = 74, .external_lex_state = 3},
  [2189] = {.lex_state = 74, .external_lex_state = 4},
  [2190] = {.lex_state = 74, .external_lex_state = 4},
  [2191] = {.lex_state = 74, .external_lex_state = 4},
  [2192] = {.lex_state = 74, .external_lex_state = 4},
  [2193] = {.lex_state = 74, .external_lex_state = 4},
  [2194] = {.lex_state = 74, .external_lex_state = 4},
  [2195] = {.lex_state = 74, .external_lex_state = 4},
  [2196] = {.lex_state = 75, .external_lex_state = 5},
  [2197] = {.lex_state = 74, .external_lex_state = 4},
  [2198] = {.lex_state = 74, .external_lex_state = 4},
  [2199] = {.lex_state = 74, .external_lex_state = 4},
  [2200] = {.lex_state = 74, .external_lex_state = 4},
  [2201] = {.lex_state = 74, .external_lex_state = 4},
  [2202] = {.lex_state = 74, .external_lex_state = 4},
  [2203] = {.lex_state = 75, .external_lex_state = 5},
  [2204] = {.lex_state = 74, .external_lex_state = 4},
  [2205] = {.lex_state = 75, .external_lex_state = 5},
  [2206] = {.lex_state = 74, .external_lex_state = 4},
  [2207] = {.lex_state = 74, .external_lex_state = 4},
  [2208] = {.lex_state = 74, .external_lex_state = 3},
  [2209] = {.lex_state = 4, .external_lex_state = 4},
  [2210] = {.lex_state = 74, .external_lex_state = 4},
  [2211] = {.lex_state = 74, .external_lex_state = 4},
  [2212] = {.lex_state = 74, .external_lex_state = 3},
  [2213] = {.lex_state = 74, .external_lex_state = 3},
  [2214] = {.lex_state = 75, .external_lex_state = 2},
  [2215] = {.lex_state = 75, .external_lex_state = 5},
  [2216] = {.lex_state = 75, .external_lex_state = 5},
  [2217] = {.lex_state = 75, .external_lex_state = 2},
  [2218] = {.lex_state = 75, .external_lex_state = 2},
  [2219] = {.lex_state = 74, .external_lex_state = 3},
  [2220] = {.lex_state = 74, .external_lex_state = 4},
  [2221] = {.lex_state = 4, .external_lex_state = 4},
  [2222] = {.lex_state = 74, .external_lex_state = 4},
  [2223] = {.lex_state = 75, .external_lex_state = 2},
  [2224] = {.lex_state = 74, .external_lex_state = 4},
  [2225] = {.lex_state = 74, .external_lex_state = 3},
  [2226] = {.lex_state = 74, .external_lex_state = 3},
  [2227] = {.lex_state = 74, .external_lex_state = 3},
  [2228] = {.lex_state = 74, .external_lex_state = 4},
  [2229] = {.lex_state = 74, .external_lex_state = 3},
  [2230] = {.lex_state = 74, .external_lex_state = 4},
  [2231] = {.lex_state = 74, .external_lex_state = 3},
  [2232] = {.lex_state = 74, .external_lex_state = 3},
  [2233] = {.lex_state = 74, .external_lex_state = 3},
  [2234] = {.lex_state = 74, .external_lex_state = 4},
  [2235] = {.lex_state = 75, .external_lex_state = 5},
  [2236] = {.lex_state = 74, .external_lex_state = 3},
  [2237] = {.lex_state = 74, .external_lex_state = 3},
  [2238] = {.lex_state = 74, .external_lex_state = 3},
  [2239] = {.lex_state = 74, .external_lex_state = 4},
  [2240] = {.lex_state = 74, .external_lex_state = 4},
  [2241] = {.lex_state = 74, .external_lex_state = 4},
  [2242] = {.lex_state = 74, .external_lex_state = 4},
  [2243] = {.lex_state = 74, .external_lex_state = 3},
  [2244] = {.lex_state = 75, .external_lex_state = 5},
  [2245] = {.lex_state = 74, .external_lex_state = 4},
  [2246] = {.lex_state = 74, .external_lex_state = 4},
  [2247] = {.lex_state = 74, .external_lex_state = 4},
  [2248] = {.lex_state = 75, .external_lex_state = 5},
  [2249] = {.lex_state = 74, .external_lex_state = 4},
  [2250] = {.lex_state = 74, .external_lex_state = 3},
  [2251] = {.lex_state = 74, .external_lex_state = 4},
  [2252] = {.lex_state = 75, .external_lex_state = 5},
  [2253] = {.lex_state = 75, .external_lex_state = 5},
  [2254] = {.lex_state = 74, .external_lex_state = 4},
  [2255] = {.lex_state = 74, .external_lex_state = 4},
  [2256] = {.lex_state = 74, .external_lex_state = 4},
  [2257] = {.lex_state = 75, .external_lex_state = 5},
  [2258] = {.lex_state = 74, .external_lex_state = 4},
  [2259] = {.lex_state = 74, .external_lex_state = 4},
  [2260] = {.lex_state = 74, .external_lex_state = 4},
  [2261] = {.lex_state = 74, .external_lex_state = 3},
  [2262] = {.lex_state = 74, .external_lex_state = 4},
  [2263] = {.lex_state = 75, .external_lex_state = 5},
  [2264] = {.lex_state = 74, .external_lex_state = 3},
  [2265] = {.lex_state = 74, .external_lex_state = 4},
  [2266] = {.lex_state = 74, .external_lex_state = 4},
  [2267] = {.lex_state = 74, .external_lex_state = 4},
  [2268] = {.lex_state = 75, .external_lex_state = 5},
  [2269] = {.lex_state = 74, .external_lex_state = 3},
  [2270] = {.lex_state = 75, .external_lex_state = 5},
  [2271] = {.lex_state = 74, .external_lex_state = 3},
  [2272] = {.lex_state = 74, .external_lex_state = 3},
  [2273] = {.lex_state = 74, .external_lex_state = 3},
  [2274] = {.lex_state = 75, .external_lex_state = 5},
  [2275] = {.lex_state = 74, .external_lex_state = 3},
  [2276] = {.lex_state = 75, .external_lex_state = 5},
  [2277] = {.lex_state = 74, .external_lex_state = 4},
  [2278] = {.lex_state = 74, .external_lex_state = 3},
  [2279] = {.lex_state = 74, .external_lex_state = 4},
  [2280] = {.lex_state = 74, .external_lex_state = 4},
  [2281] = {.lex_state = 74, .external_lex_state = 4},
  [2282] = {.lex_state = 74, .external_lex_state = 4},
  [2283] = {.lex_state = 74, .external_lex_state = 4},
  [2284] = {.lex_state = 74, .external_lex_state = 4},
  [2285] = {.lex_state = 74, .external_lex_state = 3},
  [2286] = {.lex_state = 74, .external_lex_state = 4},
  [2287] = {.lex_state = 74, .external_lex_state = 3},
  [2288] = {.lex_state = 74, .external_lex_state = 3},
  [2289] = {.lex_state = 74, .external_lex_state = 3},
  [2290] = {.lex_state = 74, .external_lex_state = 3},
  [2291] = {.lex_state = 74, .external_lex_state = 3},
  [2292] = {.lex_state = 74, .external_lex_state = 3},
  [2293] = {.lex_state = 74, .external_lex_state = 3},
  [2294] = {.lex_state = 74, .external_lex_state = 3},
  [2295] = {.lex_state = 74, .external_lex_state = 3},
  [2296] = {.lex_state = 74, .external_lex_state = 3},
  [2297] = {.lex_state = 75, .external_lex_state = 5},
  [2298] = {.lex_state = 75, .external_lex_state = 5},
  [2299] = {.lex_state = 74, .external_lex_state = 3},
  [2300] = {.lex_state = 75, .external_lex_state = 5},
  [2301] = {.lex_state = 74, .external_lex_state = 3},
  [2302] = {.lex_state = 74, .external_lex_state = 4},
  [2303] = {.lex_state = 75, .external_lex_state = 5},
  [2304] = {.lex_state = 74, .external_lex_state = 4},
  [2305] = {.lex_state = 74, .external_lex_state = 3},
  [2306] = {.lex_state = 75, .external_lex_state = 5},
  [2307] = {.lex_state = 75, .external_lex_state = 5},
  [2308] = {.lex_state = 74, .external_lex_state = 3},
  [2309] = {.lex_state = 74, .external_lex_state = 4},
  [2310] = {.lex_state = 74, .external_lex_state = 4},
  [2311] = {.lex_state = 74, .external_lex_state = 3},
  [2312] = {.lex_state = 74, .external_lex_state = 3},
  [2313] = {.lex_state = 75, .external_lex_state = 5},
  [2314] = {.lex_state = 74, .external_lex_state = 3},
  [2315] = {.lex_state = 75, .external_lex_state = 2},
  [2316] = {.lex_state = 74, .external_lex_state = 3},
  [2317] = {.lex_state = 74, .external_lex_state = 4},
  [2318] = {.lex_state = 74, .external_lex_state = 4},
  [2319] = {.lex_state = 74, .external_lex_state = 4},
  [2320] = {.lex_state = 74, .external_lex_state = 4},
  [2321] = {.lex_state = 75, .external_lex_state = 2},
  [2322] = {.lex_state = 75, .external_lex_state = 2},
  [2323] = {.lex_state = 74, .external_lex_state = 4},
  [2324] = {.lex_state = 74, .external_lex_state = 4},
  [2325] = {.lex_state = 74, .external_lex_state = 4},
  [2326] = {.lex_state = 74, .external_lex_state = 4},
  [2327] = {.lex_state = 74, .external_lex_state = 4},
  [2328] = {.lex_state = 74, .external_lex_state = 3},
  [2329] = {.lex_state = 74, .external_lex_state = 3},
  [2330] = {.lex_state = 74, .external_lex_state = 3},
  [2331] = {.lex_state = 74, .external_lex_state = 3},
  [2332] = {.lex_state = 75, .external_lex_state = 2},
  [2333] = {.lex_state = 74, .external_lex_state = 4},
  [2334] = {.lex_state = 75, .external_lex_state = 2},
  [2335] = {.lex_state = 75, .external_lex_state = 5},
  [2336] = {.lex_state = 74, .external_lex_state = 3},
  [2337] = {.lex_state = 74, .external_lex_state = 3},
  [2338] = {.lex_state = 74, .external_lex_state = 3},
  [2339] = {.lex_state = 74, .external_lex_state = 3},
  [2340] = {.lex_state = 75, .external_lex_state = 5},
  [2341] = {.lex_state = 74, .external_lex_state = 3},
  [2342] = {.lex_state = 74, .external_lex_state = 4},
  [2343] = {.lex_state = 75, .external_lex_state = 2},
  [2344] = {.lex_state = 75, .external_lex_state = 2},
  [2345] = {.lex_state = 74, .external_lex_state = 4},
  [2346] = {.lex_state = 75, .external_lex_state = 2},
  [2347] = {.lex_state = 75, .external_lex_state = 5},
  [2348] = {.lex_state = 75, .external_lex_state = 5},
  [2349] = {.lex_state = 74, .external_lex_state = 3},
  [2350] = {.lex_state = 74, .external_lex_state = 3},
  [2351] = {.lex_state = 74, .external_lex_state = 3},
  [2352] = {.lex_state = 75, .external_lex_state = 5},
  [2353] = {.lex_state = 74, .external_lex_state = 4},
  [2354] = {.lex_state = 75, .external_lex_state = 5},
  [2355] = {.lex_state = 75, .external_lex_state = 5},
  [2356] = {.lex_state = 74, .external_lex_state = 4},
  [2357] = {.lex_state = 75, .external_lex_state = 5},
  [2358] = {.lex_state = 74, .external_lex_state = 4},
  [2359] = {.lex_state = 74, .external_lex_state = 3},
  [2360] = {.lex_state = 74, .external_lex_state = 3},
  [2361] = {.lex_state = 74, .external_lex_state = 3},
  [2362] = {.lex_state = 74, .external_lex_state = 3},
  [2363] = {.lex_state = 74, .external_lex_state = 3},
  [2364] = {.lex_state = 74, .external_lex_state = 3},
  [2365] = {.lex_state = 74, .external_lex_state = 3},
  [2366] = {.lex_state = 74, .external_lex_state = 3},
  [2367] = {.lex_state = 74, .external_lex_state = 3},
  [2368] = {.lex_state = 74, .external_lex_state = 3},
  [2369] = {.lex_state = 74, .external_lex_state = 3},
  [2370] = {.lex_state = 74, .external_lex_state = 3},
  [2371] = {.lex_state = 74, .external_lex_state = 3},
  [2372] = {.lex_state = 74, .external_lex_state = 4},
  [2373] = {.lex_state = 74, .external_lex_state = 3},
  [2374] = {.lex_state = 75, .external_lex_state = 2},
  [2375] = {.lex_state = 75, .external_lex_state = 5},
  [2376] = {.lex_state = 74, .external_lex_state = 3},
  [2377] = {.lex_state = 74, .external_lex_state = 4},
  [2378] = {.lex_state = 75, .external_lex_state = 2},
  [2379] = {.lex_state = 75, .external_lex_state = 5},
  [2380] = {.lex_state = 75, .external_lex_state = 5},
  [2381] = {.lex_state = 74, .external_lex_state = 4},
  [2382] = {.lex_state = 74, .external_lex_state = 3},
  [2383] = {.lex_state = 75, .external_lex_state = 5},
  [2384] = {.lex_state = 75, .external_lex_state = 2},
  [2385] = {.lex_state = 4, .external_lex_state = 3},
  [2386] = {.lex_state = 74, .external_lex_state = 3},
  [2387] = {.lex_state = 74, .external_lex_state = 3},
  [2388] = {.lex_state = 74, .external_lex_state = 3},
  [2389] = {.lex_state = 74, .external_lex_state = 3},
  [2390] = {.lex_state = 74, .external_lex_state = 3},
  [2391] = {.lex_state = 74, .external_lex_state = 3},
  [2392] = {.lex_state = 74, .external_lex_state = 3},
  [2393] = {.lex_state = 74, .external_lex_state = 3},
  [2394] = {.lex_state = 74, .external_lex_state = 3},
  [2395] = {.lex_state = 74, .external_lex_state = 3},
  [2396] = {.lex_state = 74, .external_lex_state = 3},
  [2397] = {.lex_state = 75, .external_lex_state = 2},
  [2398] = {.lex_state = 75, .external_lex_state = 5},
  [2399] = {.lex_state = 74, .external_lex_state = 3},
  [2400] = {.lex_state = 74, .external_lex_state = 3},
  [2401] = {.lex_state = 75, .external_lex_state = 5},
  [2402] = {.lex_state = 74, .external_lex_state = 3},
  [2403] = {.lex_state = 74, .external_lex_state = 3},
  [2404] = {.lex_state = 74, .external_lex_state = 3},
  [2405] = {.lex_state = 74, .external_lex_state = 3},
  [2406] = {.lex_state = 74, .external_lex_state = 3},
  [2407] = {.lex_state = 74, .external_lex_state = 3},
  [2408] = {.lex_state = 74, .external_lex_state = 3},
  [2409] = {.lex_state = 74, .external_lex_state = 3},
  [2410] = {.lex_state = 74, .external_lex_state = 3},
  [2411] = {.lex_state = 74, .external_lex_state = 4},
  [2412] = {.lex_state = 74, .external_lex_state = 3},
  [2413] = {.lex_state = 74, .external_lex_state = 3},
  [2414] = {.lex_state = 74, .external_lex_state = 3},
  [2415] = {.lex_state = 74, .external_lex_state = 3},
  [2416] = {.lex_state = 74, .external_lex_state = 3},
  [2417] = {.lex_state = 74, .external_lex_state = 3},
  [2418] = {.lex_state = 74, .external_lex_state = 3},
  [2419] = {.lex_state = 74, .external_lex_state = 3},
  [2420] = {.lex_state = 74, .external_lex_state = 3},
  [2421] = {.lex_state = 74, .external_lex_state = 3},
  [2422] = {.lex_state = 74, .external_lex_state = 3},
  [2423] = {.lex_state = 74, .external_lex_state = 3},
  [2424] = {.lex_state = 74, .external_lex_state = 3},
  [2425] = {.lex_state = 74, .external_lex_state = 3},
  [2426] = {.lex_state = 74, .external_lex_state = 3},
  [2427] = {.lex_state = 74, .external_lex_state = 3},
  [2428] = {.lex_state = 75, .external_lex_state = 5},
  [2429] = {.lex_state = 75, .external_lex_state = 2},
  [2430] = {.lex_state = 74, .external_lex_state = 3},
  [2431] = {.lex_state = 75, .external_lex_state = 5},
  [2432] = {.lex_state = 74, .external_lex_state = 3},
  [2433] = {.lex_state = 74, .external_lex_state = 3},
  [2434] = {.lex_state = 75, .external_lex_state = 5},
  [2435] = {.lex_state = 74, .external_lex_state = 4},
  [2436] = {.lex_state = 74, .external_lex_state = 3},
  [2437] = {.lex_state = 75, .external_lex_state = 5},
  [2438] = {.lex_state = 75, .external_lex_state = 2},
  [2439] = {.lex_state = 74, .external_lex_state = 3},
  [2440] = {.lex_state = 75, .external_lex_state = 5},
  [2441] = {.lex_state = 74, .external_lex_state = 4},
  [2442] = {.lex_state = 74, .external_lex_state = 3},
  [2443] = {.lex_state = 75, .external_lex_state = 5},
  [2444] = {.lex_state = 75, .external_lex_state = 5},
  [2445] = {.lex_state = 75, .external_lex_state = 2},
  [2446] = {.lex_state = 74, .external_lex_state = 3},
  [2447] = {.lex_state = 74, .external_lex_state = 3},
  [2448] = {.lex_state = 74, .external_lex_state = 3},
  [2449] = {.lex_state = 74, .external_lex_state = 3},
  [2450] = {.lex_state = 74, .external_lex_state = 3},
  [2451] = {.lex_state = 75, .external_lex_state = 5},
  [2452] = {.lex_state = 75, .external_lex_state = 5},
  [2453] = {.lex_state = 74, .external_lex_state = 4},
  [2454] = {.lex_state = 74, .external_lex_state = 4},
  [2455] = {.lex_state = 75, .external_lex_state = 5},
  [2456] = {.lex_state = 74, .external_lex_state = 3},
  [2457] = {.lex_state = 75, .external_lex_state = 2},
  [2458] = {.lex_state = 74, .external_lex_state = 3},
  [2459] = {.lex_state = 75, .external_lex_state = 5},
  [2460] = {.lex_state = 74, .external_lex_state = 3},
  [2461] = {.lex_state = 75, .external_lex_state = 5},
  [2462] = {.lex_state = 74, .external_lex_state = 3},
  [2463] = {.lex_state = 75, .external_lex_state = 5},
  [2464] = {.lex_state = 74, .external_lex_state = 3},
  [2465] = {.lex_state = 74, .external_lex_state = 3},
  [2466] = {.lex_state = 75, .external_lex_state = 5},
  [2467] = {.lex_state = 74, .external_lex_state = 3},
  [2468] = {.lex_state = 74, .external_lex_state = 3},
  [2469] = {.lex_state = 74, .external_lex_state = 3},
  [2470] = {.lex_state = 74, .external_lex_state = 3},
  [2471] = {.lex_state = 74, .external_lex_state = 3},
  [2472] = {.lex_state = 74, .external_lex_state = 3},
  [2473] = {.lex_state = 75, .external_lex_state = 2},
  [2474] = {.lex_state = 74, .external_lex_state = 3},
  [2475] = {.lex_state = 75, .external_lex_state = 5},
  [2476] = {.lex_state = 74, .external_lex_state = 4},
  [2477] = {.lex_state = 74, .external_lex_state = 4},
  [2478] = {.lex_state = 75, .external_lex_state = 2},
  [2479] = {.lex_state = 74, .external_lex_state = 3},
  [2480] = {.lex_state = 74, .external_lex_state = 4},
  [2481] = {.lex_state = 74, .external_lex_state = 3},
  [2482] = {.lex_state = 74, .external_lex_state = 3},
  [2483] = {.lex_state = 74, .external_lex_state = 3},
  [2484] = {.lex_state = 74, .external_lex_state = 3},
  [2485] = {.lex_state = 74, .external_lex_state = 3},
  [2486] = {.lex_state = 74, .external_lex_state = 3},
  [2487] = {.lex_state = 74, .external_lex_state = 3},
  [2488] = {.lex_state = 74, .external_lex_state = 3},
  [2489] = {.lex_state = 74, .external_lex_state = 3},
  [2490] = {.lex_state = 74, .external_lex_state = 3},
  [2491] = {.lex_state = 74, .external_lex_state = 3},
  [2492] = {.lex_state = 74, .external_lex_state = 3},
  [2493] = {.lex_state = 74, .external_lex_state = 3},
  [2494] = {.lex_state = 74, .external_lex_state = 3},
  [2495] = {.lex_state = 74, .external_lex_state = 3},
  [2496] = {.lex_state = 74, .external_lex_state = 3},
  [2497] = {.lex_state = 74, .external_lex_state = 3},
  [2498] = {.lex_state = 74, .external_lex_state = 3},
  [2499] = {.lex_state = 74, .external_lex_state = 3},
  [2500] = {.lex_state = 74, .external_lex_state = 3},
  [2501] = {.lex_state = 74, .external_lex_state = 3},
  [2502] = {.lex_state = 74, .external_lex_state = 3},
  [2503] = {.lex_state = 74, .external_lex_state = 3},
  [2504] = {.lex_state = 74, .external_lex_state = 3},
  [2505] = {.lex_state = 74, .external_lex_state = 3},
  [2506] = {.lex_state = 74, .external_lex_state = 3},
  [2507] = {.lex_state = 74, .external_lex_state = 3},
  [2508] = {.lex_state = 74, .external_lex_state = 3},
  [2509] = {.lex_state = 74, .external_lex_state = 3},
  [2510] = {.lex_state = 75, .external_lex_state = 5},
  [2511] = {.lex_state = 74, .external_lex_state = 3},
  [2512] = {.lex_state = 74, .external_lex_state = 3},
  [2513] = {.lex_state = 74, .external_lex_state = 4},
  [2514] = {.lex_state = 74, .external_lex_state = 3},
  [2515] = {.lex_state = 74, .external_lex_state = 3},
  [2516] = {.lex_state = 74, .external_lex_state = 3},
  [2517] = {.lex_state = 74, .external_lex_state = 3},
  [2518] = {.lex_state = 74, .external_lex_state = 3},
  [2519] = {.lex_state = 74, .external_lex_state = 3},
  [2520] = {.lex_state = 75, .external_lex_state = 5},
  [2521] = {.lex_state = 74, .external_lex_state = 3},
  [2522] = {.lex_state = 74, .external_lex_state = 3},
  [2523] = {.lex_state = 74, .external_lex_state = 3},
  [2524] = {.lex_state = 75, .external_lex_state = 5},
  [2525] = {.lex_state = 75, .external_lex_state = 2},
  [2526] = {.lex_state = 75, .external_lex_state = 5},
  [2527] = {.lex_state = 74, .external_lex_state = 3},
  [2528] = {.lex_state = 74, .external_lex_state = 3},
  [2529] = {.lex_state = 74, .external_lex_state = 3},
  [2530] = {.lex_state = 74, .external_lex_state = 3},
  [2531] = {.lex_state = 74, .external_lex_state = 3},
  [2532] = {.lex_state = 74, .external_lex_state = 3},
  [2533] = {.lex_state = 74, .external_lex_state = 3},
  [2534] = {.lex_state = 74, .external_lex_state = 3},
  [2535] = {.lex_state = 74, .external_lex_state = 3},
  [2536] = {.lex_state = 74, .external_lex_state = 3},
  [2537] = {.lex_state = 74, .external_lex_state = 3},
  [2538] = {.lex_state = 74, .external_lex_state = 3},
  [2539] = {.lex_state = 74, .external_lex_state = 3},
  [2540] = {.lex_state = 74, .external_lex_state = 3},
  [2541] = {.lex_state = 74, .external_lex_state = 3},
  [2542] = {.lex_state = 74, .external_lex_state = 3},
  [2543] = {.lex_state = 74, .external_lex_state = 3},
  [2544] = {.lex_state = 74, .external_lex_state = 3},
  [2545] = {.lex_state = 74, .external_lex_state = 3},
  [2546] = {.lex_state = 74, .external_lex_state = 3},
  [2547] = {.lex_state = 74, .external_lex_state = 3},
  [2548] = {.lex_state = 74, .external_lex_state = 3},
  [2549] = {.lex_state = 74, .external_lex_state = 3},
  [2550] = {.lex_state = 74, .external_lex_state = 3},
  [2551] = {.lex_state = 74, .external_lex_state = 3},
  [2552] = {.lex_state = 74, .external_lex_state = 3},
  [2553] = {.lex_state = 74, .external_lex_state = 3},
  [2554] = {.lex_state = 75, .external_lex_state = 5},
  [2555] = {.lex_state = 75, .external_lex_state = 5},
  [2556] = {.lex_state = 75, .external_lex_state = 2},
  [2557] = {.lex_state = 74, .external_lex_state = 3},
  [2558] = {.lex_state = 74, .external_lex_state = 3},
  [2559] = {.lex_state = 74, .external_lex_state = 3},
  [2560] = {.lex_state = 74, .external_lex_state = 3},
  [2561] = {.lex_state = 75, .external_lex_state = 2},
  [2562] = {.lex_state = 74, .external_lex_state = 3},
  [2563] = {.lex_state = 75, .external_lex_state = 2},
  [2564] = {.lex_state = 74, .external_lex_state = 3},
  [2565] = {.lex_state = 74, .external_lex_state = 3},
  [2566] = {.lex_state = 74, .external_lex_state = 3},
  [2567] = {.lex_state = 74, .external_lex_state = 3},
  [2568] = {.lex_state = 74, .external_lex_state = 3},
  [2569] = {.lex_state = 75, .external_lex_state = 2},
  [2570] = {.lex_state = 75, .external_lex_state = 2},
  [2571] = {.lex_state = 74, .external_lex_state = 3},
  [2572] = {.lex_state = 74, .external_lex_state = 3},
  [2573] = {.lex_state = 74, .external_lex_state = 3},
  [2574] = {.lex_state = 74, .external_lex_state = 3},
  [2575] = {.lex_state = 74, .external_lex_state = 3},
  [2576] = {.lex_state = 74, .external_lex_state = 3},
  [2577] = {.lex_state = 74, .external_lex_state = 3},
  [2578] = {.lex_state = 74, .external_lex_state = 3},
  [2579] = {.lex_state = 74, .external_lex_state = 3},
  [2580] = {.lex_state = 74, .external_lex_state = 3},
  [2581] = {.lex_state = 75, .external_lex_state = 2},
  [2582] = {.lex_state = 75, .external_lex_state = 2},
  [2583] = {.lex_state = 75, .external_lex_state = 5},
  [2584] = {.lex_state = 75, .external_lex_state = 5},
  [2585] = {.lex_state = 75, .external_lex_state = 5},
  [2586] = {.lex_state = 75, .external_lex_state = 5},
  [2587] = {.lex_state = 74, .external_lex_state = 3},
  [2588] = {.lex_state = 74, .external_lex_state = 3},
  [2589] = {.lex_state = 74, .external_lex_state = 3},
  [2590] = {.lex_state = 74, .external_lex_state = 3},
  [2591] = {.lex_state = 74, .external_lex_state = 3},
  [2592] = {.lex_state = 74, .external_lex_state = 3},
  [2593] = {.lex_state = 75, .external_lex_state = 5},
  [2594] = {.lex_state = 75, .external_lex_state = 5},
  [2595] = {.lex_state = 74, .external_lex_state = 3},
  [2596] = {.lex_state = 74, .external_lex_state = 3},
  [2597] = {.lex_state = 74, .external_lex_state = 3},
  [2598] = {.lex_state = 74, .external_lex_state = 3},
  [2599] = {.lex_state = 74, .external_lex_state = 4},
  [2600] = {.lex_state = 75, .external_lex_state = 5},
  [2601] = {.lex_state = 74, .external_lex_state = 3},
  [2602] = {.lex_state = 75, .external_lex_state = 5},
  [2603] = {.lex_state = 74, .external_lex_state = 3},
  [2604] = {.lex_state = 74, .external_lex_state = 3},
  [2605] = {.lex_state = 74, .external_lex_state = 3},
  [2606] = {.lex_state = 74, .external_lex_state = 3},
  [2607] = {.lex_state = 75, .external_lex_state = 5},
  [2608] = {.lex_state = 74, .external_lex_state = 3},
  [2609] = {.lex_state = 75, .external_lex_state = 2},
  [2610] = {.lex_state = 75, .external_lex_state = 2},
  [2611] = {.lex_state = 74, .external_lex_state = 3},
  [2612] = {.lex_state = 75, .external_lex_state = 5},
  [2613] = {.lex_state = 75, .external_lex_state = 2},
  [2614] = {.lex_state = 75, .external_lex_state = 2},
  [2615] = {.lex_state = 75, .external_lex_state = 2},
  [2616] = {.lex_state = 75, .external_lex_state = 2},
  [2617] = {.lex_state = 75, .external_lex_state = 2},
  [2618] = {.lex_state = 75, .external_lex_state = 2},
  [2619] = {.lex_state = 75, .external_lex_state = 5},
  [2620] = {.lex_state = 75, .external_lex_state = 2},
  [2621] = {.lex_state = 75, .external_lex_state = 2},
  [2622] = {.lex_state = 74, .external_lex_state = 3},
  [2623] = {.lex_state = 75, .external_lex_state = 2},
  [2624] = {.lex_state = 75, .external_lex_state = 5},
  [2625] = {.lex_state = 75, .external_lex_state = 5},
  [2626] = {.lex_state = 75, .external_lex_state = 2},
  [2627] = {.lex_state = 75, .external_lex_state = 2},
  [2628] = {.lex_state = 75, .external_lex_state = 2},
  [2629] = {.lex_state = 75, .external_lex_state = 2},
  [2630] = {.lex_state = 75, .external_lex_state = 2},
  [2631] = {.lex_state = 75, .external_lex_state = 5},
  [2632] = {.lex_state = 75, .external_lex_state = 5},
  [2633] = {.lex_state = 75, .external_lex_state = 5},
  [2634] = {.lex_state = 75, .external_lex_state = 5},
  [2635] = {.lex_state = 75, .external_lex_state = 5},
  [2636] = {.lex_state = 75, .external_lex_state = 5},
  [2637] = {.lex_state = 75, .external_lex_state = 5},
  [2638] = {.lex_state = 4, .external_lex_state = 3},
  [2639] = {.lex_state = 75, .external_lex_state = 5},
  [2640] = {.lex_state = 75, .external_lex_state = 5},
  [2641] = {.lex_state = 75, .external_lex_state = 5},
  [2642] = {.lex_state = 74, .external_lex_state = 3},
  [2643] = {.lex_state = 74, .external_lex_state = 3},
  [2644] = {.lex_state = 74, .external_lex_state = 3},
  [2645] = {.lex_state = 75, .external_lex_state = 5},
  [2646] = {.lex_state = 74, .external_lex_state = 3},
  [2647] = {.lex_state = 75, .external_lex_state = 5},
  [2648] = {.lex_state = 9, .external_lex_state = 5},
  [2649] = {.lex_state = 9, .external_lex_state = 5},
  [2650] = {.lex_state = 9, .external_lex_state = 5},
  [2651] = {.lex_state = 9, .external_lex_state = 5},
  [2652] = {.lex_state = 74, .external_lex_state = 3},
  [2653] = {.lex_state = 9, .external_lex_state = 5},
  [2654] = {.lex_state = 9, .external_lex_state = 5},
  [2655] = {.lex_state = 9, .external_lex_state = 5},
  [2656] = {.lex_state = 9, .external_lex_state = 5},
  [2657] = {.lex_state = 9, .external_lex_state = 5},
  [2658] = {.lex_state = 9, .external_lex_state = 5},
  [2659] = {.lex_state = 9, .external_lex_state = 5},
  [2660] = {.lex_state = 9, .external_lex_state = 5},
  [2661] = {.lex_state = 9, .external_lex_state = 5},
  [2662] = {.lex_state = 9, .external_lex_state = 5},
  [2663] = {.lex_state = 9, .external_lex_state = 5},
  [2664] = {.lex_state = 9, .external_lex_state = 5},
  [2665] = {.lex_state = 9, .external_lex_state = 5},
  [2666] = {.lex_state = 9, .external_lex_state = 5},
  [2667] = {.lex_state = 74, .external_lex_state = 3},
  [2668] = {.lex_state = 9, .external_lex_state = 5},
  [2669] = {.lex_state = 9, .external_lex_state = 5},
  [2670] = {.lex_state = 9, .external_lex_state = 5},
  [2671] = {.lex_state = 9, .external_lex_state = 5},
  [2672] = {.lex_state = 9, .external_lex_state = 5},
  [2673] = {.lex_state = 9, .external_lex_state = 5},
  [2674] = {.lex_state = 9, .external_lex_state = 5},
  [2675] = {.lex_state = 74, .external_lex_state = 3},
  [2676] = {.lex_state = 74, .external_lex_state = 3},
  [2677] = {.lex_state = 74, .external_lex_state = 3},
  [2678] = {.lex_state = 9, .external_lex_state = 5},
  [2679] = {.lex_state = 9, .external_lex_state = 5},
  [2680] = {.lex_state = 9, .external_lex_state = 5},
  [2681] = {.lex_state = 9, .external_lex_state = 5},
  [2682] = {.lex_state = 74, .external_lex_state = 3},
  [2683] = {.lex_state = 75, .external_lex_state = 2},
  [2684] = {.lex_state = 9, .external_lex_state = 5},
  [2685] = {.lex_state = 9, .external_lex_state = 5},
  [2686] = {.lex_state = 74, .external_lex_state = 3},
  [2687] = {.lex_state = 9, .external_lex_state = 5},
  [2688] = {.lex_state = 9, .external_lex_state = 5},
  [2689] = {.lex_state = 74, .external_lex_state = 3},
  [2690] = {.lex_state = 9, .external_lex_state = 5},
  [2691] = {.lex_state = 9, .external_lex_state = 5},
  [2692] = {.lex_state = 9, .external_lex_state = 5},
  [2693] = {.lex_state = 9, .external_lex_state = 5},
  [2694] = {.lex_state = 74, .external_lex_state = 3},
  [2695] = {.lex_state = 9, .external_lex_state = 5},
  [2696] = {.lex_state = 9, .external_lex_state = 5},
  [2697] = {.lex_state = 9, .external_lex_state = 5},
  [2698] = {.lex_state = 9, .external_lex_state = 5},
  [2699] = {.lex_state = 9, .external_lex_state = 5},
  [2700] = {.lex_state = 9, .external_lex_state = 5},
  [2701] = {.lex_state = 9, .external_lex_state = 5},
  [2702] = {.lex_state = 9, .external_lex_state = 5},
  [2703] = {.lex_state = 9, .external_lex_state = 5},
  [2704] = {.lex_state = 9, .external_lex_state = 5},
  [2705] = {.lex_state = 9, .external_lex_state = 5},
  [2706] = {.lex_state = 74, .external_lex_state = 3},
  [2707] = {.lex_state = 9, .external_lex_state = 5},
  [2708] = {.lex_state = 9, .external_lex_state = 5},
  [2709] = {.lex_state = 74, .external_lex_state = 3},
  [2710] = {.lex_state = 9, .external_lex_state = 5},
  [2711] = {.lex_state = 75, .external_lex_state = 2},
  [2712] = {.lex_state = 9, .external_lex_state = 5},
  [2713] = {.lex_state = 75, .external_lex_state = 2},
  [2714] = {.lex_state = 75, .external_lex_state = 2},
  [2715] = {.lex_state = 9, .external_lex_state = 2},
  [2716] = {.lex_state = 9, .external_lex_state = 2},
  [2717] = {.lex_state = 9, .external_lex_state = 2},
  [2718] = {.lex_state = 9, .external_lex_state = 2},
  [2719] = {.lex_state = 74, .external_lex_state = 3},
  [2720] = {.lex_state = 9, .external_lex_state = 2},
  [2721] = {.lex_state = 9, .external_lex_state = 2},
  [2722] = {.lex_state = 75, .external_lex_state = 2},
  [2723] = {.lex_state = 9, .external_lex_state = 2},
  [2724] = {.lex_state = 75, .external_lex_state = 2},
  [2725] = {.lex_state = 75, .external_lex_state = 2},
  [2726] = {.lex_state = 75, .external_lex_state = 2},
  [2727] = {.lex_state = 75, .external_lex_state = 2},
  [2728] = {.lex_state = 75, .external_lex_state = 2},
  [2729] = {.lex_state = 75, .external_lex_state = 2},
  [2730] = {.lex_state = 75, .external_lex_state = 2},
  [2731] = {.lex_state = 75, .external_lex_state = 2},
  [2732] = {.lex_state = 75, .external_lex_state = 2},
  [2733] = {.lex_state = 75, .external_lex_state = 2},
  [2734] = {.lex_state = 75, .external_lex_state = 2},
  [2735] = {.lex_state = 75, .external_lex_state = 2},
  [2736] = {.lex_state = 75, .external_lex_state = 2},
  [2737] = {.lex_state = 75, .external_lex_state = 2},
  [2738] = {.lex_state = 75, .external_lex_state = 2},
  [2739] = {.lex_state = 75, .external_lex_state = 2},
  [2740] = {.lex_state = 75, .external_lex_state = 2},
  [2741] = {.lex_state = 75, .external_lex_state = 2},
  [2742] = {.lex_state = 75, .external_lex_state = 2},
  [2743] = {.lex_state = 75, .external_lex_state = 2},
  [2744] = {.lex_state = 75, .external_lex_state = 2},
  [2745] = {.lex_state = 75, .external_lex_state = 2},
  [2746] = {.lex_state = 75, .external_lex_state = 2},
  [2747] = {.lex_state = 75, .external_lex_state = 2},
  [2748] = {.lex_state = 75, .external_lex_state = 2},
  [2749] = {.lex_state = 75, .external_lex_state = 2},
  [2750] = {.lex_state = 75, .external_lex_state = 2},
  [2751] = {.lex_state = 75, .external_lex_state = 2},
  [2752] = {.lex_state = 75, .external_lex_state = 2},
  [2753] = {.lex_state = 75, .external_lex_state = 2},
  [2754] = {.lex_state = 75, .external_lex_state = 2},
  [2755] = {.lex_state = 75, .external_lex_state = 2},
  [2756] = {.lex_state = 75, .external_lex_state = 2},
  [2757] = {.lex_state = 75, .external_lex_state = 2},
  [2758] = {.lex_state = 75, .external_lex_state = 2},
  [2759] = {.lex_state = 75, .external_lex_state = 2},
  [2760] = {.lex_state = 75, .external_lex_state = 2},
  [2761] = {.lex_state = 75, .external_lex_state = 2},
  [2762] = {.lex_state = 75, .external_lex_state = 2},
  [2763] = {.lex_state = 75, .external_lex_state = 2},
  [2764] = {.lex_state = 75, .external_lex_state = 2},
  [2765] = {.lex_state = 75, .external_lex_state = 2},
  [2766] = {.lex_state = 75, .external_lex_state = 2},
  [2767] = {.lex_state = 75, .external_lex_state = 2},
  [2768] = {.lex_state = 75, .external_lex_state = 2},
  [2769] = {.lex_state = 75, .external_lex_state = 2},
  [2770] = {.lex_state = 75, .external_lex_state = 2},
  [2771] = {.lex_state = 75, .external_lex_state = 2},
  [2772] = {.lex_state = 75, .external_lex_state = 2},
  [2773] = {.lex_state = 75, .external_lex_state = 2},
  [2774] = {.lex_state = 75, .external_lex_state = 2},
  [2775] = {.lex_state = 75, .external_lex_state = 2},
  [2776] = {.lex_state = 75, .external_lex_state = 2},
  [2777] = {.lex_state = 75, .external_lex_state = 2},
  [2778] = {.lex_state = 75, .external_lex_state = 2},
  [2779] = {.lex_state = 75, .external_lex_state = 2},
  [2780] = {.lex_state = 75, .external_lex_state = 2},
  [2781] = {.lex_state = 75, .external_lex_state = 2},
  [2782] = {.lex_state = 75, .external_lex_state = 2},
  [2783] = {.lex_state = 75, .external_lex_state = 2},
  [2784] = {.lex_state = 75, .external_lex_state = 2},
  [2785] = {.lex_state = 75, .external_lex_state = 2},
  [2786] = {.lex_state = 75, .external_lex_state = 2},
  [2787] = {.lex_state = 75, .external_lex_state = 2},
  [2788] = {.lex_state = 75, .external_lex_state = 2},
  [2789] = {.lex_state = 75, .external_lex_state = 2},
  [2790] = {.lex_state = 75, .external_lex_state = 2},
  [2791] = {.lex_state = 75, .external_lex_state = 2},
  [2792] = {.lex_state = 75, .external_lex_state = 2},
  [2793] = {.lex_state = 75, .external_lex_state = 2},
  [2794] = {.lex_state = 75, .external_lex_state = 2},
  [2795] = {.lex_state = 75, .external_lex_state = 2},
  [2796] = {.lex_state = 75, .external_lex_state = 2},
  [2797] = {.lex_state = 75, .external_lex_state = 2},
  [2798] = {.lex_state = 75, .external_lex_state = 2},
  [2799] = {.lex_state = 75, .external_lex_state = 2},
  [2800] = {.lex_state = 75, .external_lex_state = 2},
  [2801] = {.lex_state = 75, .external_lex_state = 2},
  [2802] = {.lex_state = 75, .external_lex_state = 2},
  [2803] = {.lex_state = 75, .external_lex_state = 2},
  [2804] = {.lex_state = 75, .external_lex_state = 2},
  [2805] = {.lex_state = 75, .external_lex_state = 2},
  [2806] = {.lex_state = 75, .external_lex_state = 2},
  [2807] = {.lex_state = 75, .external_lex_state = 2},
  [2808] = {.lex_state = 75, .external_lex_state = 2},
  [2809] = {.lex_state = 75, .external_lex_state = 2},
  [2810] = {.lex_state = 75, .external_lex_state = 2},
  [2811] = {.lex_state = 75, .external_lex_state = 2},
  [2812] = {.lex_state = 75, .external_lex_state = 2},
  [2813] = {.lex_state = 75, .external_lex_state = 2},
  [2814] = {.lex_state = 75, .external_lex_state = 2},
  [2815] = {.lex_state = 75, .external_lex_state = 2},
  [2816] = {.lex_state = 75, .external_lex_state = 2},
  [2817] = {.lex_state = 75, .external_lex_state = 2},
  [2818] = {.lex_state = 75, .external_lex_state = 2},
  [2819] = {.lex_state = 75, .external_lex_state = 2},
  [2820] = {.lex_state = 75, .external_lex_state = 2},
  [2821] = {.lex_state = 75, .external_lex_state = 2},
  [2822] = {.lex_state = 75, .external_lex_state = 2},
  [2823] = {.lex_state = 75, .external_lex_state = 2},
  [2824] = {.lex_state = 75, .external_lex_state = 2},
  [2825] = {.lex_state = 75, .external_lex_state = 2},
  [2826] = {.lex_state = 75, .external_lex_state = 2},
  [2827] = {.lex_state = 75, .external_lex_state = 2},
  [2828] = {.lex_state = 75, .external_lex_state = 2},
  [2829] = {.lex_state = 75, .external_lex_state = 2},
  [2830] = {.lex_state = 75, .external_lex_state = 2},
  [2831] = {.lex_state = 75, .external_lex_state = 2},
  [2832] = {.lex_state = 75, .external_lex_state = 2},
  [2833] = {.lex_state = 75, .external_lex_state = 2},
  [2834] = {.lex_state = 75, .external_lex_state = 2},
  [2835] = {.lex_state = 75, .external_lex_state = 2},
  [2836] = {.lex_state = 75, .external_lex_state = 2},
  [2837] = {.lex_state = 75, .external_lex_state = 2},
  [2838] = {.lex_state = 75, .external_lex_state = 2},
  [2839] = {.lex_state = 75, .external_lex_state = 2},
  [2840] = {.lex_state = 75, .external_lex_state = 2},
  [2841] = {.lex_state = 75, .external_lex_state = 2},
  [2842] = {.lex_state = 75, .external_lex_state = 2},
  [2843] = {.lex_state = 75, .external_lex_state = 2},
  [2844] = {.lex_state = 75, .external_lex_state = 2},
  [2845] = {.lex_state = 75, .external_lex_state = 2},
  [2846] = {.lex_state = 75, .external_lex_state = 2},
  [2847] = {.lex_state = 75, .external_lex_state = 2},
  [2848] = {.lex_state = 75, .external_lex_state = 2},
  [2849] = {.lex_state = 75, .external_lex_state = 2},
  [2850] = {.lex_state = 75, .external_lex_state = 2},
  [2851] = {.lex_state = 75, .external_lex_state = 2},
  [2852] = {.lex_state = 75, .external_lex_state = 2},
  [2853] = {.lex_state = 75, .external_lex_state = 2},
  [2854] = {.lex_state = 75, .external_lex_state = 2},
  [2855] = {.lex_state = 75, .external_lex_state = 2},
  [2856] = {.lex_state = 75, .external_lex_state = 2},
  [2857] = {.lex_state = 75, .external_lex_state = 2},
  [2858] = {.lex_state = 75, .external_lex_state = 2},
  [2859] = {.lex_state = 75, .external_lex_state = 2},
  [2860] = {.lex_state = 75, .external_lex_state = 2},
  [2861] = {.lex_state = 75, .external_lex_state = 2},
  [2862] = {.lex_state = 75, .external_lex_state = 2},
  [2863] = {.lex_state = 75, .external_lex_state = 2},
  [2864] = {.lex_state = 75, .external_lex_state = 2},
  [2865] = {.lex_state = 75, .external_lex_state = 2},
  [2866] = {.lex_state = 75, .external_lex_state = 2},
  [2867] = {.lex_state = 75, .external_lex_state = 2},
  [2868] = {.lex_state = 75, .external_lex_state = 2},
  [2869] = {.lex_state = 75, .external_lex_state = 2},
  [2870] = {.lex_state = 75, .external_lex_state = 2},
  [2871] = {.lex_state = 75, .external_lex_state = 2},
  [2872] = {.lex_state = 75, .external_lex_state = 2},
  [2873] = {.lex_state = 75, .external_lex_state = 2},
  [2874] = {.lex_state = 75, .external_lex_state = 2},
  [2875] = {.lex_state = 75, .external_lex_state = 2},
  [2876] = {.lex_state = 7, .external_lex_state = 2},
  [2877] = {.lex_state = 7, .external_lex_state = 2},
  [2878] = {.lex_state = 7, .external_lex_state = 2},
  [2879] = {.lex_state = 7, .external_lex_state = 2},
  [2880] = {.lex_state = 7, .external_lex_state = 2},
  [2881] = {.lex_state = 7, .external_lex_state = 2},
  [2882] = {.lex_state = 7, .external_lex_state = 2},
  [2883] = {.lex_state = 7, .external_lex_state = 2},
  [2884] = {.lex_state = 7, .external_lex_state = 2},
  [2885] = {.lex_state = 7, .external_lex_state = 2},
  [2886] = {.lex_state = 7, .external_lex_state = 2},
  [2887] = {.lex_state = 7, .external_lex_state = 2},
  [2888] = {.lex_state = 7, .external_lex_state = 2},
  [2889] = {.lex_state = 7, .external_lex_state = 2},
  [2890] = {.lex_state = 7, .external_lex_state = 2},
  [2891] = {.lex_state = 7, .external_lex_state = 2},
  [2892] = {.lex_state = 7, .external_lex_state = 2},
  [2893] = {.lex_state = 7, .external_lex_state = 2},
  [2894] = {.lex_state = 7, .external_lex_state = 2},
  [2895] = {.lex_state = 7, .external_lex_state = 2},
  [2896] = {.lex_state = 7, .external_lex_state = 2},
  [2897] = {.lex_state = 7, .external_lex_state = 2},
  [2898] = {.lex_state = 7, .external_lex_state = 2},
  [2899] = {.lex_state = 7, .external_lex_state = 2},
  [2900] = {.lex_state = 7, .external_lex_state = 2},
  [2901] = {.lex_state = 7, .external_lex_state = 2},
  [2902] = {.lex_state = 7, .external_lex_state = 2},
  [2903] = {.lex_state = 7, .external_lex_state = 2},
  [2904] = {.lex_state = 7, .external_lex_state = 2},
  [2905] = {.lex_state = 7, .external_lex_state = 2},
  [2906] = {.lex_state = 7, .external_lex_state = 2},
  [2907] = {.lex_state = 7, .external_lex_state = 2},
  [2908] = {.lex_state = 7, .external_lex_state = 2},
  [2909] = {.lex_state = 7, .external_lex_state = 2},
  [2910] = {.lex_state = 7, .external_lex_state = 2},
  [2911] = {.lex_state = 7, .external_lex_state = 2},
  [2912] = {.lex_state = 7, .external_lex_state = 2},
  [2913] = {.lex_state = 75, .external_lex_state = 5},
  [2914] = {.lex_state = 75, .external_lex_state = 5},
  [2915] = {.lex_state = 75, .external_lex_state = 2},
  [2916] = {.lex_state = 7, .external_lex_state = 2},
  [2917] = {.lex_state = 7, .external_lex_state = 2},
  [2918] = {.lex_state = 7, .external_lex_state = 2},
  [2919] = {.lex_state = 75, .external_lex_state = 2},
  [2920] = {.lex_state = 7, .external_lex_state = 2},
  [2921] = {.lex_state = 7, .external_lex_state = 2},
  [2922] = {.lex_state = 7, .external_lex_state = 2},
  [2923] = {.lex_state = 75, .external_lex_state = 2},
  [2924] = {.lex_state = 75, .external_lex_state = 2},
  [2925] = {.lex_state = 7, .external_lex_state = 5},
  [2926] = {.lex_state = 75, .external_lex_state = 2},
  [2927] = {.lex_state = 75, .external_lex_state = 2},
  [2928] = {.lex_state = 75, .external_lex_state = 2},
  [2929] = {.lex_state = 75, .external_lex_state = 2},
  [2930] = {.lex_state = 75, .external_lex_state = 2},
  [2931] = {.lex_state = 7, .external_lex_state = 5},
  [2932] = {.lex_state = 75, .external_lex_state = 2},
  [2933] = {.lex_state = 7, .external_lex_state = 5},
  [2934] = {.lex_state = 75, .external_lex_state = 2},
  [2935] = {.lex_state = 75, .external_lex_state = 2},
  [2936] = {.lex_state = 75, .external_lex_state = 2},
  [2937] = {.lex_state = 75, .external_lex_state = 2},
  [2938] = {.lex_state = 75, .external_lex_state = 2},
  [2939] = {.lex_state = 75, .external_lex_state = 2},
  [2940] = {.lex_state = 75, .external_lex_state = 2},
  [2941] = {.lex_state = 7, .external_lex_state = 5},
  [2942] = {.lex_state = 75, .external_lex_state = 2},
  [2943] = {.lex_state = 7, .external_lex_state = 5},
  [2944] = {.lex_state = 75, .external_lex_state = 2},
  [2945] = {.lex_state = 75, .external_lex_state = 2},
  [2946] = {.lex_state = 7, .external_lex_state = 5},
  [2947] = {.lex_state = 75, .external_lex_state = 2},
  [2948] = {.lex_state = 75, .external_lex_state = 2},
  [2949] = {.lex_state = 75, .external_lex_state = 2},
  [2950] = {.lex_state = 7, .external_lex_state = 5},
  [2951] = {.lex_state = 7, .external_lex_state = 6},
  [2952] = {.lex_state = 7, .external_lex_state = 5},
  [2953] = {.lex_state = 7, .external_lex_state = 5},
  [2954] = {.lex_state = 7, .external_lex_state = 5},
  [2955] = {.lex_state = 75, .external_lex_state = 2},
  [2956] = {.lex_state = 7, .external_lex_state = 5},
  [2957] = {.lex_state = 75, .external_lex_state = 2},
  [2958] = {.lex_state = 7, .external_lex_state = 5},
  [2959] = {.lex_state = 7, .external_lex_state = 5},
  [2960] = {.lex_state = 7, .external_lex_state = 5},
  [2961] = {.lex_state = 7, .external_lex_state = 5},
  [2962] = {.lex_state = 75, .external_lex_state = 2},
  [2963] = {.lex_state = 7, .external_lex_state = 5},
  [2964] = {.lex_state = 75, .external_lex_state = 2},
  [2965] = {.lex_state = 7, .external_lex_state = 5},
  [2966] = {.lex_state = 7, .external_lex_state = 5},
  [2967] = {.lex_state = 7, .external_lex_state = 5},
  [2968] = {.lex_state = 75, .external_lex_state = 2},
  [2969] = {.lex_state = 7, .external_lex_state = 5},
  [2970] = {.lex_state = 75, .external_lex_state = 2},
  [2971] = {.lex_state = 75, .external_lex_state = 2},
  [2972] = {.lex_state = 75, .external_lex_state = 2},
  [2973] = {.lex_state = 75, .external_lex_state = 2},
  [2974] = {.lex_state = 75, .external_lex_state = 2},
  [2975] = {.lex_state = 75, .external_lex_state = 2},
  [2976] = {.lex_state = 75, .external_lex_state = 2},
  [2977] = {.lex_state = 75, .external_lex_state = 2},
  [2978] = {.lex_state = 75, .external_lex_state = 2},
  [2979] = {.lex_state = 2, .external_lex_state = 2},
  [2980] = {.lex_state = 2, .external_lex_state = 2},
  [2981] = {.lex_state = 75, .external_lex_state = 2},
  [2982] = {.lex_state = 75, .external_lex_state = 2},
  [2983] = {.lex_state = 7, .external_lex_state = 5},
  [2984] = {.lex_state = 75, .external_lex_state = 2},
  [2985] = {.lex_state = 75, .external_lex_state = 2},
  [2986] = {.lex_state = 2, .external_lex_state = 2},
  [2987] = {.lex_state = 7, .external_lex_state = 5},
  [2988] = {.lex_state = 75, .external_lex_state = 2},
  [2989] = {.lex_state = 7, .external_lex_state = 5},
  [2990] = {.lex_state = 7, .external_lex_state = 5},
  [2991] = {.lex_state = 75, .external_lex_state = 2},
  [2992] = {.lex_state = 75, .external_lex_state = 2},
  [2993] = {.lex_state = 7, .external_lex_state = 5},
  [2994] = {.lex_state = 75, .external_lex_state = 2},
  [2995] = {.lex_state = 7, .external_lex_state = 5},
  [2996] = {.lex_state = 75, .external_lex_state = 2},
  [2997] = {.lex_state = 7, .external_lex_state = 5},
  [2998] = {.lex_state = 75, .external_lex_state = 2},
  [2999] = {.lex_state = 75, .external_lex_state = 2},
  [3000] = {.lex_state = 75, .external_lex_state = 2},
  [3001] = {.lex_state = 75, .external_lex_state = 2},
  [3002] = {.lex_state = 75, .external_lex_state = 2},
  [3003] = {.lex_state = 2, .external_lex_state = 2},
  [3004] = {.lex_state = 2, .external_lex_state = 2},
  [3005] = {.lex_state = 7, .external_lex_state = 5},
  [3006] = {.lex_state = 75, .external_lex_state = 2},
  [3007] = {.lex_state = 75, .external_lex_state = 2},
  [3008] = {.lex_state = 75, .external_lex_state = 2},
  [3009] = {.lex_state = 2, .external_lex_state = 2},
  [3010] = {.lex_state = 75, .external_lex_state = 2},
  [3011] = {.lex_state = 75, .external_lex_state = 2},
  [3012] = {.lex_state = 7, .external_lex_state = 5},
  [3013] = {.lex_state = 2, .external_lex_state = 2},
  [3014] = {.lex_state = 7, .external_lex_state = 5},
  [3015] = {.lex_state = 75, .external_lex_state = 2},
  [3016] = {.lex_state = 75, .external_lex_state = 5},
  [3017] = {.lex_state = 7, .external_lex_state = 5},
  [3018] = {.lex_state = 75, .external_lex_state = 2},
  [3019] = {.lex_state = 75, .external_lex_state = 2},
  [3020] = {.lex_state = 2, .external_lex_state = 2},
  [3021] = {.lex_state = 75, .external_lex_state = 2},
  [3022] = {.lex_state = 7, .external_lex_state = 5},
  [3023] = {.lex_state = 75, .external_lex_state = 2},
  [3024] = {.lex_state = 75, .external_lex_state = 2},
  [3025] = {.lex_state = 2, .external_lex_state = 2},
  [3026] = {.lex_state = 7, .external_lex_state = 6},
  [3027] = {.lex_state = 7, .external_lex_state = 5},
  [3028] = {.lex_state = 7, .external_lex_state = 5},
  [3029] = {.lex_state = 2, .external_lex_state = 2},
  [3030] = {.lex_state = 75, .external_lex_state = 2},
  [3031] = {.lex_state = 7, .external_lex_state = 5},
  [3032] = {.lex_state = 75, .external_lex_state = 2},
  [3033] = {.lex_state = 7, .external_lex_state = 5},
  [3034] = {.lex_state = 75, .external_lex_state = 2},
  [3035] = {.lex_state = 75, .external_lex_state = 2},
  [3036] = {.lex_state = 75, .external_lex_state = 2},
  [3037] = {.lex_state = 7, .external_lex_state = 6},
  [3038] = {.lex_state = 7, .external_lex_state = 5},
  [3039] = {.lex_state = 75, .external_lex_state = 2},
  [3040] = {.lex_state = 75, .external_lex_state = 2},
  [3041] = {.lex_state = 75, .external_lex_state = 2},
  [3042] = {.lex_state = 75, .external_lex_state = 2},
  [3043] = {.lex_state = 75, .external_lex_state = 5},
  [3044] = {.lex_state = 75, .external_lex_state = 5},
  [3045] = {.lex_state = 75, .external_lex_state = 5},
  [3046] = {.lex_state = 75, .external_lex_state = 2},
  [3047] = {.lex_state = 75, .external_lex_state = 2},
  [3048] = {.lex_state = 75, .external_lex_state = 5},
  [3049] = {.lex_state = 75, .external_lex_state = 2},
  [3050] = {.lex_state = 75, .external_lex_state = 5},
  [3051] = {.lex_state = 75, .external_lex_state = 5},
  [3052] = {.lex_state = 75, .external_lex_state = 5},
  [3053] = {.lex_state = 75, .external_lex_state = 2},
  [3054] = {.lex_state = 75, .external_lex_state = 2},
  [3055] = {.lex_state = 75, .external_lex_state = 2},
  [3056] = {.lex_state = 75, .external_lex_state = 2},
  [3057] = {.lex_state = 75, .external_lex_state = 5},
  [3058] = {.lex_state = 75, .external_lex_state = 5},
  [3059] = {.lex_state = 75, .external_lex_state = 2},
  [3060] = {.lex_state = 75, .external_lex_state = 5},
  [3061] = {.lex_state = 75, .external_lex_state = 2},
  [3062] = {.lex_state = 75, .external_lex_state = 5},
  [3063] = {.lex_state = 75, .external_lex_state = 5},
  [3064] = {.lex_state = 75, .external_lex_state = 5},
  [3065] = {.lex_state = 75, .external_lex_state = 5},
  [3066] = {.lex_state = 75, .external_lex_state = 5},
  [3067] = {.lex_state = 75, .external_lex_state = 5},
  [3068] = {.lex_state = 75, .external_lex_state = 5},
  [3069] = {.lex_state = 75, .external_lex_state = 5},
  [3070] = {.lex_state = 75, .external_lex_state = 5},
  [3071] = {.lex_state = 75, .external_lex_state = 5},
  [3072] = {.lex_state = 75, .external_lex_state = 5},
  [3073] = {.lex_state = 75, .external_lex_state = 5},
  [3074] = {.lex_state = 75, .external_lex_state = 5},
  [3075] = {.lex_state = 75, .external_lex_state = 2},
  [3076] = {.lex_state = 75, .external_lex_state = 5},
  [3077] = {.lex_state = 75, .external_lex_state = 5},
  [3078] = {.lex_state = 75, .external_lex_state = 2},
  [3079] = {.lex_state = 75, .external_lex_state = 5},
  [3080] = {.lex_state = 75, .external_lex_state = 5},
  [3081] = {.lex_state = 75, .external_lex_state = 5},
  [3082] = {.lex_state = 75, .external_lex_state = 5},
  [3083] = {.lex_state = 75, .external_lex_state = 5},
  [3084] = {.lex_state = 7, .external_lex_state = 6},
  [3085] = {.lex_state = 75, .external_lex_state = 5},
  [3086] = {.lex_state = 7, .external_lex_state = 5},
  [3087] = {.lex_state = 75, .external_lex_state = 2},
  [3088] = {.lex_state = 7, .external_lex_state = 5},
  [3089] = {.lex_state = 7, .external_lex_state = 5},
  [3090] = {.lex_state = 7, .external_lex_state = 5},
  [3091] = {.lex_state = 75, .external_lex_state = 5},
  [3092] = {.lex_state = 75, .external_lex_state = 5},
  [3093] = {.lex_state = 75, .external_lex_state = 5},
  [3094] = {.lex_state = 7, .external_lex_state = 5},
  [3095] = {.lex_state = 75, .external_lex_state = 2},
  [3096] = {.lex_state = 75, .external_lex_state = 2},
  [3097] = {.lex_state = 75, .external_lex_state = 5},
  [3098] = {.lex_state = 75, .external_lex_state = 5},
  [3099] = {.lex_state = 7, .external_lex_state = 5},
  [3100] = {.lex_state = 75, .external_lex_state = 5},
  [3101] = {.lex_state = 75, .external_lex_state = 5},
  [3102] = {.lex_state = 75, .external_lex_state = 5},
  [3103] = {.lex_state = 75, .external_lex_state = 5},
  [3104] = {.lex_state = 75, .external_lex_state = 5},
  [3105] = {.lex_state = 75, .external_lex_state = 5},
  [3106] = {.lex_state = 75, .external_lex_state = 2},
  [3107] = {.lex_state = 7, .external_lex_state = 6},
  [3108] = {.lex_state = 7, .external_lex_state = 6},
  [3109] = {.lex_state = 7, .external_lex_state = 6},
  [3110] = {.lex_state = 7, .external_lex_state = 6},
  [3111] = {.lex_state = 75, .external_lex_state = 5},
  [3112] = {.lex_state = 7, .external_lex_state = 6},
  [3113] = {.lex_state = 7, .external_lex_state = 6},
  [3114] = {.lex_state = 7, .external_lex_state = 6},
  [3115] = {.lex_state = 7, .external_lex_state = 6},
  [3116] = {.lex_state = 7, .external_lex_state = 6},
  [3117] = {.lex_state = 7, .external_lex_state = 6},
  [3118] = {.lex_state = 7, .external_lex_state = 6},
  [3119] = {.lex_state = 7, .external_lex_state = 6},
  [3120] = {.lex_state = 7, .external_lex_state = 6},
  [3121] = {.lex_state = 7, .external_lex_state = 6},
  [3122] = {.lex_state = 7, .external_lex_state = 6},
  [3123] = {.lex_state = 7, .external_lex_state = 6},
  [3124] = {.lex_state = 7, .external_lex_state = 5},
  [3125] = {.lex_state = 7, .external_lex_state = 6},
  [3126] = {.lex_state = 7, .external_lex_state = 6},
  [3127] = {.lex_state = 7, .external_lex_state = 6},
  [3128] = {.lex_state = 7, .external_lex_state = 6},
  [3129] = {.lex_state = 75, .external_lex_state = 6},
  [3130] = {.lex_state = 7, .external_lex_state = 6},
  [3131] = {.lex_state = 7, .external_lex_state = 6},
  [3132] = {.lex_state = 7, .external_lex_state = 6},
  [3133] = {.lex_state = 7, .external_lex_state = 6},
  [3134] = {.lex_state = 7, .external_lex_state = 6},
  [3135] = {.lex_state = 75, .external_lex_state = 5},
  [3136] = {.lex_state = 7, .external_lex_state = 6},
  [3137] = {.lex_state = 7, .external_lex_state = 6},
  [3138] = {.lex_state = 7, .external_lex_state = 6},
  [3139] = {.lex_state = 7, .external_lex_state = 6},
  [3140] = {.lex_state = 7, .external_lex_state = 6},
  [3141] = {.lex_state = 7, .external_lex_state = 6},
  [3142] = {.lex_state = 7, .external_lex_state = 6},
  [3143] = {.lex_state = 75, .external_lex_state = 5},
  [3144] = {.lex_state = 75, .external_lex_state = 5},
  [3145] = {.lex_state = 75, .external_lex_state = 2},
  [3146] = {.lex_state = 75, .external_lex_state = 2},
  [3147] = {.lex_state = 75, .external_lex_state = 5},
  [3148] = {.lex_state = 75, .external_lex_state = 2},
  [3149] = {.lex_state = 75, .external_lex_state = 2},
  [3150] = {.lex_state = 75, .external_lex_state = 2},
  [3151] = {.lex_state = 75, .external_lex_state = 5},
  [3152] = {.lex_state = 75, .external_lex_state = 5},
  [3153] = {.lex_state = 75, .external_lex_state = 2},
  [3154] = {.lex_state = 75, .external_lex_state = 2},
  [3155] = {.lex_state = 7, .external_lex_state = 5},
  [3156] = {.lex_state = 7, .external_lex_state = 6},
  [3157] = {.lex_state = 75, .external_lex_state = 5},
  [3158] = {.lex_state = 75, .external_lex_state = 6},
  [3159] = {.lex_state = 75, .external_lex_state = 5},
  [3160] = {.lex_state = 75, .external_lex_state = 5},
  [3161] = {.lex_state = 75, .external_lex_state = 5},
  [3162] = {.lex_state = 75, .external_lex_state = 5},
  [3163] = {.lex_state = 75, .external_lex_state = 5},
  [3164] = {.lex_state = 75, .external_lex_state = 5},
  [3165] = {.lex_state = 75, .external_lex_state = 5},
  [3166] = {.lex_state = 75, .external_lex_state = 5},
  [3167] = {.lex_state = 75, .external_lex_state = 5},
  [3168] = {.lex_state = 75, .external_lex_state = 5},
  [3169] = {.lex_state = 75, .external_lex_state = 5},
  [3170] = {.lex_state = 75, .external_lex_state = 5},
  [3171] = {.lex_state = 75, .external_lex_state = 5},
  [3172] = {.lex_state = 75, .external_lex_state = 5},
  [3173] = {.lex_state = 75, .external_lex_state = 5},
  [3174] = {.lex_state = 75, .external_lex_state = 2},
  [3175] = {.lex_state = 75, .external_lex_state = 5},
  [3176] = {.lex_state = 75, .external_lex_state = 5},
  [3177] = {.lex_state = 75, .external_lex_state = 2},
  [3178] = {.lex_state = 75, .external_lex_state = 5},
  [3179] = {.lex_state = 75, .external_lex_state = 5},
  [3180] = {.lex_state = 75, .external_lex_state = 5},
  [3181] = {.lex_state = 75, .external_lex_state = 6},
  [3182] = {.lex_state = 75, .external_lex_state = 5},
  [3183] = {.lex_state = 75, .external_lex_state = 5},
  [3184] = {.lex_state = 75, .external_lex_state = 5},
  [3185] = {.lex_state = 75, .external_lex_state = 5},
  [3186] = {.lex_state = 75, .external_lex_state = 5},
  [3187] = {.lex_state = 75, .external_lex_state = 5},
  [3188] = {.lex_state = 75, .external_lex_state = 5},
  [3189] = {.lex_state = 75, .external_lex_state = 2},
  [3190] = {.lex_state = 75, .external_lex_state = 5},
  [3191] = {.lex_state = 75, .external_lex_state = 5},
  [3192] = {.lex_state = 75, .external_lex_state = 5},
  [3193] = {.lex_state = 75, .external_lex_state = 5},
  [3194] = {.lex_state = 75, .external_lex_state = 5},
  [3195] = {.lex_state = 75, .external_lex_state = 5},
  [3196] = {.lex_state = 7, .external_lex_state = 2},
  [3197] = {.lex_state = 7, .external_lex_state = 2},
  [3198] = {.lex_state = 7, .external_lex_state = 2},
  [3199] = {.lex_state = 75, .external_lex_state = 5},
  [3200] = {.lex_state = 75, .external_lex_state = 5},
  [3201] = {.lex_state = 75, .external_lex_state = 5},
  [3202] = {.lex_state = 75, .external_lex_state = 5},
  [3203] = {.lex_state = 75, .external_lex_state = 5},
  [3204] = {.lex_state = 75, .external_lex_state = 5},
  [3205] = {.lex_state = 75, .external_lex_state = 5},
  [3206] = {.lex_state = 75, .external_lex_state = 5},
  [3207] = {.lex_state = 75, .external_lex_state = 5},
  [3208] = {.lex_state = 75, .external_lex_state = 5},
  [3209] = {.lex_state = 75, .external_lex_state = 5},
  [3210] = {.lex_state = 75, .external_lex_state = 5},
  [3211] = {.lex_state = 75, .external_lex_state = 5},
  [3212] = {.lex_state = 75, .external_lex_state = 5},
  [3213] = {.lex_state = 75, .external_lex_state = 5},
  [3214] = {.lex_state = 75, .external_lex_state = 5},
  [3215] = {.lex_state = 75, .external_lex_state = 5},
  [3216] = {.lex_state = 75, .external_lex_state = 5},
  [3217] = {.lex_state = 75, .external_lex_state = 5},
  [3218] = {.lex_state = 75, .external_lex_state = 5},
  [3219] = {.lex_state = 75, .external_lex_state = 5},
  [3220] = {.lex_state = 7, .external_lex_state = 6},
  [3221] = {.lex_state = 7, .external_lex_state = 6},
  [3222] = {.lex_state = 75, .external_lex_state = 5},
  [3223] = {.lex_state = 7, .external_lex_state = 6},
  [3224] = {.lex_state = 7, .external_lex_state = 6},
  [3225] = {.lex_state = 7, .external_lex_state = 6},
  [3226] = {.lex_state = 7, .external_lex_state = 6},
  [3227] = {.lex_state = 75, .external_lex_state = 5},
  [3228] = {.lex_state = 75, .external_lex_state = 6},
  [3229] = {.lex_state = 75, .external_lex_state = 5},
  [3230] = {.lex_state = 75, .external_lex_state = 6},
  [3231] = {.lex_state = 75, .external_lex_state = 6},
  [3232] = {.lex_state = 75, .external_lex_state = 5},
  [3233] = {.lex_state = 75, .external_lex_state = 6},
  [3234] = {.lex_state = 75, .external_lex_state = 6},
  [3235] = {.lex_state = 75, .external_lex_state = 6},
  [3236] = {.lex_state = 75, .external_lex_state = 6},
  [3237] = {.lex_state = 75, .external_lex_state = 6},
  [3238] = {.lex_state = 7, .external_lex_state = 6},
  [3239] = {.lex_state = 75, .external_lex_state = 5},
  [3240] = {.lex_state = 75, .external_lex_state = 5},
  [3241] = {.lex_state = 75, .external_lex_state = 5},
  [3242] = {.lex_state = 75, .external_lex_state = 5},
  [3243] = {.lex_state = 75, .external_lex_state = 5},
  [3244] = {.lex_state = 75, .external_lex_state = 5},
  [3245] = {.lex_state = 75, .external_lex_state = 5},
  [3246] = {.lex_state = 75, .external_lex_state = 5},
  [3247] = {.lex_state = 7, .external_lex_state = 6},
  [3248] = {.lex_state = 75, .external_lex_state = 5},
  [3249] = {.lex_state = 75, .external_lex_state = 5},
  [3250] = {.lex_state = 75, .external_lex_state = 5},
  [3251] = {.lex_state = 75, .external_lex_state = 5},
  [3252] = {.lex_state = 75, .external_lex_state = 5},
  [3253] = {.lex_state = 75, .external_lex_state = 5},
  [3254] = {.lex_state = 75, .external_lex_state = 5},
  [3255] = {.lex_state = 75, .external_lex_state = 5},
  [3256] = {.lex_state = 75, .external_lex_state = 2},
  [3257] = {.lex_state = 75, .external_lex_state = 5},
  [3258] = {.lex_state = 75, .external_lex_state = 5},
  [3259] = {.lex_state = 75, .external_lex_state = 5},
  [3260] = {.lex_state = 75, .external_lex_state = 5},
  [3261] = {.lex_state = 75, .external_lex_state = 5},
  [3262] = {.lex_state = 75, .external_lex_state = 2},
  [3263] = {.lex_state = 75, .external_lex_state = 5},
  [3264] = {.lex_state = 75, .external_lex_state = 5},
  [3265] = {.lex_state = 75, .external_lex_state = 5},
  [3266] = {.lex_state = 75, .external_lex_state = 5},
  [3267] = {.lex_state = 75, .external_lex_state = 5},
  [3268] = {.lex_state = 75, .external_lex_state = 5},
  [3269] = {.lex_state = 75, .external_lex_state = 5},
  [3270] = {.lex_state = 75, .external_lex_state = 5},
  [3271] = {.lex_state = 75, .external_lex_state = 5},
  [3272] = {.lex_state = 75, .external_lex_state = 5},
  [3273] = {.lex_state = 75, .external_lex_state = 5},
  [3274] = {.lex_state = 75, .external_lex_state = 5},
  [3275] = {.lex_state = 75, .external_lex_state = 5},
  [3276] = {.lex_state = 75, .external_lex_state = 5},
  [3277] = {.lex_state = 75, .external_lex_state = 5},
  [3278] = {.lex_state = 75, .external_lex_state = 6},
  [3279] = {.lex_state = 75, .external_lex_state = 5},
  [3280] = {.lex_state = 75, .external_lex_state = 5},
  [3281] = {.lex_state = 75, .external_lex_state = 5},
  [3282] = {.lex_state = 75, .external_lex_state = 5},
  [3283] = {.lex_state = 75, .external_lex_state = 5},
  [3284] = {.lex_state = 75, .external_lex_state = 5},
  [3285] = {.lex_state = 75, .external_lex_state = 5},
  [3286] = {.lex_state = 75, .external_lex_state = 5},
  [3287] = {.lex_state = 75, .external_lex_state = 6},
  [3288] = {.lex_state = 75, .external_lex_state = 6},
  [3289] = {.lex_state = 75, .external_lex_state = 6},
  [3290] = {.lex_state = 75, .external_lex_state = 2},
  [3291] = {.lex_state = 75, .external_lex_state = 2},
  [3292] = {.lex_state = 75, .external_lex_state = 2},
  [3293] = {.lex_state = 75, .external_lex_state = 2},
  [3294] = {.lex_state = 75, .external_lex_state = 2},
  [3295] = {.lex_state = 75, .external_lex_state = 2},
  [3296] = {.lex_state = 75, .external_lex_state = 2},
  [3297] = {.lex_state = 75, .external_lex_state = 2},
  [3298] = {.lex_state = 75, .external_lex_state = 2},
  [3299] = {.lex_state = 75, .external_lex_state = 5},
  [3300] = {.lex_state = 75, .external_lex_state = 2},
  [3301] = {.lex_state = 75, .external_lex_state = 6},
  [3302] = {.lex_state = 75, .external_lex_state = 5},
  [3303] = {.lex_state = 75, .external_lex_state = 2},
  [3304] = {.lex_state = 75, .external_lex_state = 5},
  [3305] = {.lex_state = 75, .external_lex_state = 6},
  [3306] = {.lex_state = 75, .external_lex_state = 2},
  [3307] = {.lex_state = 75, .external_lex_state = 2},
  [3308] = {.lex_state = 75, .external_lex_state = 2},
  [3309] = {.lex_state = 75, .external_lex_state = 6},
  [3310] = {.lex_state = 75, .external_lex_state = 2},
  [3311] = {.lex_state = 75, .external_lex_state = 6},
  [3312] = {.lex_state = 75, .external_lex_state = 2},
  [3313] = {.lex_state = 75, .external_lex_state = 5},
  [3314] = {.lex_state = 75, .external_lex_state = 5},
  [3315] = {.lex_state = 75, .external_lex_state = 5},
  [3316] = {.lex_state = 75, .external_lex_state = 2},
  [3317] = {.lex_state = 75, .external_lex_state = 6},
  [3318] = {.lex_state = 75, .external_lex_state = 2},
  [3319] = {.lex_state = 75, .external_lex_state = 6},
  [3320] = {.lex_state = 75, .external_lex_state = 5},
  [3321] = {.lex_state = 75, .external_lex_state = 5},
  [3322] = {.lex_state = 75, .external_lex_state = 6},
  [3323] = {.lex_state = 75, .external_lex_state = 5},
  [3324] = {.lex_state = 75, .external_lex_state = 5},
  [3325] = {.lex_state = 75, .external_lex_state = 6},
  [3326] = {.lex_state = 75, .external_lex_state = 5},
  [3327] = {.lex_state = 75, .external_lex_state = 6},
  [3328] = {.lex_state = 75, .external_lex_state = 6},
  [3329] = {.lex_state = 75, .external_lex_state = 6},
  [3330] = {.lex_state = 75, .external_lex_state = 6},
  [3331] = {.lex_state = 75, .external_lex_state = 6},
  [3332] = {.lex_state = 75, .external_lex_state = 6},
  [3333] = {.lex_state = 75, .external_lex_state = 5},
  [3334] = {.lex_state = 75, .external_lex_state = 5},
  [3335] = {.lex_state = 75, .external_lex_state = 6},
  [3336] = {.lex_state = 75, .external_lex_state = 6},
  [3337] = {.lex_state = 75, .external_lex_state = 6},
  [3338] = {.lex_state = 75, .external_lex_state = 6},
  [3339] = {.lex_state = 75, .external_lex_state = 6},
  [3340] = {.lex_state = 75, .external_lex_state = 2},
  [3341] = {.lex_state = 75, .external_lex_state = 2},
  [3342] = {.lex_state = 75, .external_lex_state = 5},
  [3343] = {.lex_state = 75, .external_lex_state = 5},
  [3344] = {.lex_state = 75, .external_lex_state = 6},
  [3345] = {.lex_state = 75, .external_lex_state = 6},
  [3346] = {.lex_state = 75, .external_lex_state = 6},
  [3347] = {.lex_state = 75, .external_lex_state = 6},
  [3348] = {.lex_state = 75, .external_lex_state = 5},
  [3349] = {.lex_state = 75, .external_lex_state = 2},
  [3350] = {.lex_state = 75, .external_lex_state = 5},
  [3351] = {.lex_state = 75, .external_lex_state = 6},
  [3352] = {.lex_state = 75, .external_lex_state = 6},
  [3353] = {.lex_state = 75, .external_lex_state = 2},
  [3354] = {.lex_state = 75, .external_lex_state = 6},
  [3355] = {.lex_state = 75, .external_lex_state = 6},
  [3356] = {.lex_state = 75, .external_lex_state = 6},
  [3357] = {.lex_state = 75, .external_lex_state = 6},
  [3358] = {.lex_state = 75, .external_lex_state = 5},
  [3359] = {.lex_state = 75, .external_lex_state = 6},
  [3360] = {.lex_state = 75, .external_lex_state = 5},
  [3361] = {.lex_state = 75, .external_lex_state = 6},
  [3362] = {.lex_state = 75, .external_lex_state = 2},
  [3363] = {.lex_state = 75, .external_lex_state = 6},
  [3364] = {.lex_state = 75, .external_lex_state = 2},
  [3365] = {.lex_state = 75, .external_lex_state = 2},
  [3366] = {.lex_state = 75, .external_lex_state = 2},
  [3367] = {.lex_state = 75, .external_lex_state = 5},
  [3368] = {.lex_state = 75, .external_lex_state = 5},
  [3369] = {.lex_state = 75, .external_lex_state = 5},
  [3370] = {.lex_state = 75, .external_lex_state = 2},
  [3371] = {.lex_state = 75, .external_lex_state = 2},
  [3372] = {.lex_state = 8, .external_lex_state = 2},
  [3373] = {.lex_state = 75, .external_lex_state = 6},
  [3374] = {.lex_state = 75, .external_lex_state = 2},
  [3375] = {.lex_state = 75, .external_lex_state = 6},
  [3376] = {.lex_state = 75, .external_lex_state = 5},
  [3377] = {.lex_state = 75, .external_lex_state = 2},
  [3378] = {.lex_state = 75, .external_lex_state = 6},
  [3379] = {.lex_state = 75, .external_lex_state = 5},
  [3380] = {.lex_state = 75, .external_lex_state = 2},
  [3381] = {.lex_state = 75, .external_lex_state = 2},
  [3382] = {.lex_state = 8, .external_lex_state = 2},
  [3383] = {.lex_state = 75, .external_lex_state = 6},
  [3384] = {.lex_state = 75, .external_lex_state = 6},
  [3385] = {.lex_state = 75, .external_lex_state = 5},
  [3386] = {.lex_state = 75, .external_lex_state = 6},
  [3387] = {.lex_state = 75, .external_lex_state = 5},
  [3388] = {.lex_state = 75, .external_lex_state = 2},
  [3389] = {.lex_state = 75, .external_lex_state = 2},
  [3390] = {.lex_state = 75, .external_lex_state = 6},
  [3391] = {.lex_state = 75, .external_lex_state = 5},
  [3392] = {.lex_state = 75, .external_lex_state = 5},
  [3393] = {.lex_state = 75, .external_lex_state = 5},
  [3394] = {.lex_state = 75, .external_lex_state = 5},
  [3395] = {.lex_state = 75, .external_lex_state = 2},
  [3396] = {.lex_state = 75, .external_lex_state = 2},
  [3397] = {.lex_state = 75, .external_lex_state = 5},
  [3398] = {.lex_state = 75, .external_lex_state = 6},
  [3399] = {.lex_state = 75, .external_lex_state = 5},
  [3400] = {.lex_state = 75, .external_lex_state = 5},
  [3401] = {.lex_state = 75, .external_lex_state = 6},
  [3402] = {.lex_state = 75, .external_lex_state = 5},
  [3403] = {.lex_state = 75, .external_lex_state = 5},
  [3404] = {.lex_state = 75, .external_lex_state = 2},
  [3405] = {.lex_state = 75, .external_lex_state = 5},
  [3406] = {.lex_state = 75, .external_lex_state = 6},
  [3407] = {.lex_state = 75, .external_lex_state = 2},
  [3408] = {.lex_state = 75, .external_lex_state = 5},
  [3409] = {.lex_state = 75, .external_lex_state = 2},
  [3410] = {.lex_state = 75, .external_lex_state = 2},
  [3411] = {.lex_state = 75, .external_lex_state = 2},
  [3412] = {.lex_state = 75, .external_lex_state = 2},
  [3413] = {.lex_state = 75, .external_lex_state = 2},
  [3414] = {.lex_state = 75, .external_lex_state = 5},
  [3415] = {.lex_state = 75, .external_lex_state = 5},
  [3416] = {.lex_state = 75, .external_lex_state = 2},
  [3417] = {.lex_state = 75, .external_lex_state = 2},
  [3418] = {.lex_state = 75, .external_lex_state = 5},
  [3419] = {.lex_state = 75, .external_lex_state = 5},
  [3420] = {.lex_state = 75, .external_lex_state = 6},
  [3421] = {.lex_state = 75, .external_lex_state = 2},
  [3422] = {.lex_state = 75, .external_lex_state = 5},
  [3423] = {.lex_state = 75, .external_lex_state = 5},
  [3424] = {.lex_state = 75, .external_lex_state = 2},
  [3425] = {.lex_state = 75, .external_lex_state = 5},
  [3426] = {.lex_state = 75, .external_lex_state = 5},
  [3427] = {.lex_state = 75, .external_lex_state = 2},
  [3428] = {.lex_state = 75, .external_lex_state = 5},
  [3429] = {.lex_state = 75, .external_lex_state = 5},
  [3430] = {.lex_state = 75, .external_lex_state = 6},
  [3431] = {.lex_state = 75, .external_lex_state = 6},
  [3432] = {.lex_state = 75, .external_lex_state = 6},
  [3433] = {.lex_state = 75, .external_lex_state = 6},
  [3434] = {.lex_state = 75, .external_lex_state = 2},
  [3435] = {.lex_state = 75, .external_lex_state = 2},
  [3436] = {.lex_state = 75, .external_lex_state = 6},
  [3437] = {.lex_state = 75, .external_lex_state = 6},
  [3438] = {.lex_state = 75, .external_lex_state = 2},
  [3439] = {.lex_state = 75, .external_lex_state = 6},
  [3440] = {.lex_state = 75, .external_lex_state = 2},
  [3441] = {.lex_state = 75, .external_lex_state = 2},
  [3442] = {.lex_state = 75, .external_lex_state = 5},
  [3443] = {.lex_state = 8, .external_lex_state = 2},
  [3444] = {.lex_state = 75, .external_lex_state = 6},
  [3445] = {.lex_state = 75, .external_lex_state = 6},
  [3446] = {.lex_state = 75, .external_lex_state = 5},
  [3447] = {.lex_state = 75, .external_lex_state = 6},
  [3448] = {.lex_state = 75, .external_lex_state = 6},
  [3449] = {.lex_state = 75, .external_lex_state = 5},
  [3450] = {.lex_state = 75, .external_lex_state = 6},
  [3451] = {.lex_state = 75, .external_lex_state = 5},
  [3452] = {.lex_state = 75, .external_lex_state = 5},
  [3453] = {.lex_state = 75, .external_lex_state = 6},
  [3454] = {.lex_state = 75, .external_lex_state = 6},
  [3455] = {.lex_state = 75, .external_lex_state = 6},
  [3456] = {.lex_state = 75, .external_lex_state = 6},
  [3457] = {.lex_state = 75, .external_lex_state = 6},
  [3458] = {.lex_state = 75, .external_lex_state = 5},
  [3459] = {.lex_state = 75, .external_lex_state = 5},
  [3460] = {.lex_state = 75, .external_lex_state = 5},
  [3461] = {.lex_state = 75, .external_lex_state = 5},
  [3462] = {.lex_state = 75, .external_lex_state = 5},
  [3463] = {.lex_state = 75, .external_lex_state = 6},
  [3464] = {.lex_state = 75, .external_lex_state = 5},
  [3465] = {.lex_state = 13, .external_lex_state = 2},
  [3466] = {.lex_state = 75, .external_lex_state = 5},
  [3467] = {.lex_state = 75, .external_lex_state = 5},
  [3468] = {.lex_state = 13, .external_lex_state = 2},
  [3469] = {.lex_state = 75, .external_lex_state = 2},
  [3470] = {.lex_state = 13, .external_lex_state = 2},
  [3471] = {.lex_state = 75, .external_lex_state = 2},
  [3472] = {.lex_state = 75, .external_lex_state = 2},
  [3473] = {.lex_state = 13, .external_lex_state = 7},
  [3474] = {.lex_state = 75, .external_lex_state = 2},
  [3475] = {.lex_state = 13, .external_lex_state = 7},
  [3476] = {.lex_state = 13, .external_lex_state = 7},
  [3477] = {.lex_state = 13, .external_lex_state = 7},
  [3478] = {.lex_state = 13, .external_lex_state = 7},
  [3479] = {.lex_state = 13, .external_lex_state = 7},
  [3480] = {.lex_state = 75, .external_lex_state = 2},
  [3481] = {.lex_state = 75, .external_lex_state = 2},
  [3482] = {.lex_state = 75, .external_lex_state = 2},
  [3483] = {.lex_state = 75, .external_lex_state = 2},
  [3484] = {.lex_state = 13, .external_lex_state = 7},
  [3485] = {.lex_state = 13, .external_lex_state = 2},
  [3486] = {.lex_state = 75, .external_lex_state = 2},
  [3487] = {.lex_state = 75, .external_lex_state = 2},
  [3488] = {.lex_state = 13, .external_lex_state = 2},
  [3489] = {.lex_state = 7, .external_lex_state = 2},
  [3490] = {.lex_state = 7, .external_lex_state = 2},
  [3491] = {.lex_state = 75, .external_lex_state = 5},
  [3492] = {.lex_state = 75, .external_lex_state = 2},
  [3493] = {.lex_state = 75, .external_lex_state = 2},
  [3494] = {.lex_state = 75, .external_lex_state = 2},
  [3495] = {.lex_state = 13, .external_lex_state = 2},
  [3496] = {.lex_state = 75, .external_lex_state = 2},
  [3497] = {.lex_state = 13, .external_lex_state = 2},
  [3498] = {.lex_state = 13, .external_lex_state = 2},
  [3499] = {.lex_state = 75, .external_lex_state = 5},
  [3500] = {.lex_state = 75, .external_lex_state = 5},
  [3501] = {.lex_state = 13, .external_lex_state = 7},
  [3502] = {.lex_state = 75, .external_lex_state = 6},
  [3503] = {.lex_state = 75, .external_lex_state = 2},
  [3504] = {.lex_state = 75, .external_lex_state = 2},
  [3505] = {.lex_state = 13, .external_lex_state = 2},
  [3506] = {.lex_state = 7, .external_lex_state = 2},
  [3507] = {.lex_state = 75, .external_lex_state = 2},
  [3508] = {.lex_state = 7, .external_lex_state = 2},
  [3509] = {.lex_state = 75, .external_lex_state = 5},
  [3510] = {.lex_state = 75, .external_lex_state = 5},
  [3511] = {.lex_state = 75, .external_lex_state = 5},
  [3512] = {.lex_state = 75, .external_lex_state = 5},
  [3513] = {.lex_state = 75, .external_lex_state = 2},
  [3514] = {.lex_state = 75, .external_lex_state = 5},
  [3515] = {.lex_state = 75, .external_lex_state = 5},
  [3516] = {.lex_state = 75, .external_lex_state = 5},
  [3517] = {.lex_state = 75, .external_lex_state = 5},
  [3518] = {.lex_state = 75, .external_lex_state = 5},
  [3519] = {.lex_state = 75, .external_lex_state = 5},
  [3520] = {.lex_state = 75, .external_lex_state = 5},
  [3521] = {.lex_state = 75, .external_lex_state = 5},
  [3522] = {.lex_state = 75, .external_lex_state = 5},
  [3523] = {.lex_state = 75, .external_lex_state = 5},
  [3524] = {.lex_state = 75, .external_lex_state = 5},
  [3525] = {.lex_state = 75, .external_lex_state = 2},
  [3526] = {.lex_state = 75, .external_lex_state = 2},
  [3527] = {.lex_state = 75, .external_lex_state = 5},
  [3528] = {.lex_state = 75, .external_lex_state = 5},
  [3529] = {.lex_state = 75, .external_lex_state = 5},
  [3530] = {.lex_state = 75, .external_lex_state = 5},
  [3531] = {.lex_state = 75, .external_lex_state = 5},
  [3532] = {.lex_state = 75, .external_lex_state = 2},
  [3533] = {.lex_state = 75, .external_lex_state = 5},
  [3534] = {.lex_state = 75, .external_lex_state = 5},
  [3535] = {.lex_state = 75, .external_lex_state = 2},
  [3536] = {.lex_state = 75, .external_lex_state = 5},
  [3537] = {.lex_state = 75, .external_lex_state = 5},
  [3538] = {.lex_state = 75, .external_lex_state = 5},
  [3539] = {.lex_state = 75, .external_lex_state = 5},
  [3540] = {.lex_state = 7, .external_lex_state = 2},
  [3541] = {.lex_state = 75, .external_lex_state = 5},
  [3542] = {.lex_state = 75, .external_lex_state = 2},
  [3543] = {.lex_state = 7, .external_lex_state = 2},
  [3544] = {.lex_state = 75, .external_lex_state = 5},
  [3545] = {.lex_state = 75, .external_lex_state = 2},
  [3546] = {.lex_state = 7, .external_lex_state = 2},
  [3547] = {.lex_state = 75, .external_lex_state = 5},
  [3548] = {.lex_state = 75, .external_lex_state = 5},
  [3549] = {.lex_state = 75, .external_lex_state = 2},
  [3550] = {.lex_state = 75, .external_lex_state = 5},
  [3551] = {.lex_state = 75, .external_lex_state = 5},
  [3552] = {.lex_state = 75, .external_lex_state = 5},
  [3553] = {.lex_state = 75, .external_lex_state = 5},
  [3554] = {.lex_state = 75, .external_lex_state = 5},
  [3555] = {.lex_state = 75, .external_lex_state = 2},
  [3556] = {.lex_state = 75, .external_lex_state = 5},
  [3557] = {.lex_state = 75, .external_lex_state = 5},
  [3558] = {.lex_state = 75, .external_lex_state = 2},
  [3559] = {.lex_state = 75, .external_lex_state = 5},
  [3560] = {.lex_state = 75, .external_lex_state = 5},
  [3561] = {.lex_state = 75, .external_lex_state = 5},
  [3562] = {.lex_state = 75, .external_lex_state = 5},
  [3563] = {.lex_state = 7, .external_lex_state = 2},
  [3564] = {.lex_state = 75, .external_lex_state = 5},
  [3565] = {.lex_state = 75, .external_lex_state = 5},
  [3566] = {.lex_state = 75, .external_lex_state = 5},
  [3567] = {.lex_state = 75, .external_lex_state = 5},
  [3568] = {.lex_state = 75, .external_lex_state = 2},
  [3569] = {.lex_state = 75, .external_lex_state = 5},
  [3570] = {.lex_state = 7, .external_lex_state = 2},
  [3571] = {.lex_state = 75, .external_lex_state = 5},
  [3572] = {.lex_state = 7, .external_lex_state = 2},
  [3573] = {.lex_state = 75, .external_lex_state = 5},
  [3574] = {.lex_state = 7, .external_lex_state = 2},
  [3575] = {.lex_state = 7, .external_lex_state = 2},
  [3576] = {.lex_state = 75, .external_lex_state = 5},
  [3577] = {.lex_state = 75, .external_lex_state = 2},
  [3578] = {.lex_state = 75, .external_lex_state = 2},
  [3579] = {.lex_state = 75, .external_lex_state = 2},
  [3580] = {.lex_state = 75, .external_lex_state = 5},
  [3581] = {.lex_state = 75, .external_lex_state = 2},
  [3582] = {.lex_state = 75, .external_lex_state = 5},
  [3583] = {.lex_state = 75, .external_lex_state = 5},
  [3584] = {.lex_state = 75, .external_lex_state = 5},
  [3585] = {.lex_state = 75, .external_lex_state = 5},
  [3586] = {.lex_state = 75, .external_lex_state = 5},
  [3587] = {.lex_state = 75, .external_lex_state = 5},
  [3588] = {.lex_state = 75, .external_lex_state = 5},
  [3589] = {.lex_state = 75, .external_lex_state = 5},
  [3590] = {.lex_state = 75, .external_lex_state = 2},
  [3591] = {.lex_state = 75, .external_lex_state = 5},
  [3592] = {.lex_state = 75, .external_lex_state = 5},
  [3593] = {.lex_state = 7, .external_lex_state = 2},
  [3594] = {.lex_state = 75, .external_lex_state = 2},
  [3595] = {.lex_state = 75, .external_lex_state = 2},
  [3596] = {.lex_state = 75, .external_lex_state = 2},
  [3597] = {.lex_state = 75, .external_lex_state = 5},
  [3598] = {.lex_state = 75, .external_lex_state = 5},
  [3599] = {.lex_state = 7, .external_lex_state = 2},
  [3600] = {.lex_state = 75, .external_lex_state = 2},
  [3601] = {.lex_state = 75, .external_lex_state = 5},
  [3602] = {.lex_state = 75, .external_lex_state = 5},
  [3603] = {.lex_state = 75, .external_lex_state = 5},
  [3604] = {.lex_state = 75, .external_lex_state = 5},
  [3605] = {.lex_state = 75, .external_lex_state = 2},
  [3606] = {.lex_state = 75, .external_lex_state = 5},
  [3607] = {.lex_state = 75, .external_lex_state = 5},
  [3608] = {.lex_state = 75, .external_lex_state = 5},
  [3609] = {.lex_state = 7, .external_lex_state = 2},
  [3610] = {.lex_state = 75, .external_lex_state = 2},
  [3611] = {.lex_state = 75, .external_lex_state = 5},
  [3612] = {.lex_state = 75, .external_lex_state = 5},
  [3613] = {.lex_state = 75, .external_lex_state = 5},
  [3614] = {.lex_state = 75, .external_lex_state = 5},
  [3615] = {.lex_state = 75, .external_lex_state = 5},
  [3616] = {.lex_state = 75, .external_lex_state = 2},
  [3617] = {.lex_state = 75, .external_lex_state = 5},
  [3618] = {.lex_state = 75, .external_lex_state = 2},
  [3619] = {.lex_state = 75, .external_lex_state = 2},
  [3620] = {.lex_state = 8, .external_lex_state = 2},
  [3621] = {.lex_state = 75, .external_lex_state = 2},
  [3622] = {.lex_state = 75, .external_lex_state = 5},
  [3623] = {.lex_state = 75, .external_lex_state = 5},
  [3624] = {.lex_state = 75, .external_lex_state = 2},
  [3625] = {.lex_state = 75, .external_lex_state = 5},
  [3626] = {.lex_state = 75, .external_lex_state = 5},
  [3627] = {.lex_state = 75, .external_lex_state = 5},
  [3628] = {.lex_state = 75, .external_lex_state = 5},
  [3629] = {.lex_state = 75, .external_lex_state = 5},
  [3630] = {.lex_state = 75, .external_lex_state = 5},
  [3631] = {.lex_state = 75, .external_lex_state = 5},
  [3632] = {.lex_state = 75, .external_lex_state = 5},
  [3633] = {.lex_state = 75, .external_lex_state = 5},
  [3634] = {.lex_state = 75, .external_lex_state = 2},
  [3635] = {.lex_state = 75, .external_lex_state = 5},
  [3636] = {.lex_state = 7, .external_lex_state = 2},
  [3637] = {.lex_state = 75, .external_lex_state = 5},
  [3638] = {.lex_state = 75, .external_lex_state = 2},
  [3639] = {.lex_state = 7, .external_lex_state = 2},
  [3640] = {.lex_state = 75, .external_lex_state = 5},
  [3641] = {.lex_state = 75, .external_lex_state = 5},
  [3642] = {.lex_state = 75, .external_lex_state = 2},
  [3643] = {.lex_state = 75, .external_lex_state = 2},
  [3644] = {.lex_state = 75, .external_lex_state = 5},
  [3645] = {.lex_state = 75, .external_lex_state = 2},
  [3646] = {.lex_state = 75, .external_lex_state = 5},
  [3647] = {.lex_state = 75, .external_lex_state = 2},
  [3648] = {.lex_state = 75, .external_lex_state = 2},
  [3649] = {.lex_state = 75, .external_lex_state = 5},
  [3650] = {.lex_state = 75, .external_lex_state = 2},
  [3651] = {.lex_state = 75, .external_lex_state = 5},
  [3652] = {.lex_state = 8, .external_lex_state = 2},
  [3653] = {.lex_state = 75, .external_lex_state = 5},
  [3654] = {.lex_state = 75, .external_lex_state = 2},
  [3655] = {.lex_state = 75, .external_lex_state = 5},
  [3656] = {.lex_state = 75, .external_lex_state = 5},
  [3657] = {.lex_state = 75, .external_lex_state = 5},
  [3658] = {.lex_state = 75, .external_lex_state = 5},
  [3659] = {.lex_state = 75, .external_lex_state = 5},
  [3660] = {.lex_state = 75, .external_lex_state = 2},
  [3661] = {.lex_state = 75, .external_lex_state = 2},
  [3662] = {.lex_state = 75, .external_lex_state = 2},
  [3663] = {.lex_state = 7, .external_lex_state = 2},
  [3664] = {.lex_state = 75, .external_lex_state = 5},
  [3665] = {.lex_state = 75, .external_lex_state = 5},
  [3666] = {.lex_state = 75, .external_lex_state = 2},
  [3667] = {.lex_state = 75, .external_lex_state = 5},
  [3668] = {.lex_state = 75, .external_lex_state = 5},
  [3669] = {.lex_state = 75, .external_lex_state = 5},
  [3670] = {.lex_state = 75, .external_lex_state = 2},
  [3671] = {.lex_state = 75, .external_lex_state = 5},
  [3672] = {.lex_state = 75, .external_lex_state = 5},
  [3673] = {.lex_state = 75, .external_lex_state = 5},
  [3674] = {.lex_state = 75, .external_lex_state = 5},
  [3675] = {.lex_state = 75, .external_lex_state = 2},
  [3676] = {.lex_state = 75, .external_lex_state = 2},
  [3677] = {.lex_state = 8, .external_lex_state = 2},
  [3678] = {.lex_state = 75, .external_lex_state = 5},
  [3679] = {.lex_state = 75, .external_lex_state = 5},
  [3680] = {.lex_state = 75, .external_lex_state = 2},
  [3681] = {.lex_state = 75, .external_lex_state = 5},
  [3682] = {.lex_state = 75, .external_lex_state = 5},
  [3683] = {.lex_state = 75, .external_lex_state = 5},
  [3684] = {.lex_state = 75, .external_lex_state = 2},
  [3685] = {.lex_state = 75, .external_lex_state = 2},
  [3686] = {.lex_state = 75, .external_lex_state = 5},
  [3687] = {.lex_state = 75, .external_lex_state = 5},
  [3688] = {.lex_state = 75, .external_lex_state = 2},
  [3689] = {.lex_state = 75, .external_lex_state = 2},
  [3690] = {.lex_state = 75, .external_lex_state = 5},
  [3691] = {.lex_state = 75, .external_lex_state = 5},
  [3692] = {.lex_state = 75, .external_lex_state = 2},
  [3693] = {.lex_state = 75, .external_lex_state = 2},
  [3694] = {.lex_state = 75, .external_lex_state = 2},
  [3695] = {.lex_state = 7, .external_lex_state = 2},
  [3696] = {.lex_state = 75, .external_lex_state = 2},
  [3697] = {.lex_state = 75, .external_lex_state = 2},
  [3698] = {.lex_state = 75, .external_lex_state = 5},
  [3699] = {.lex_state = 75, .external_lex_state = 2},
  [3700] = {.lex_state = 75, .external_lex_state = 5},
  [3701] = {.lex_state = 75, .external_lex_state = 5},
  [3702] = {.lex_state = 75, .external_lex_state = 5},
  [3703] = {.lex_state = 75, .external_lex_state = 5},
  [3704] = {.lex_state = 75, .external_lex_state = 5},
  [3705] = {.lex_state = 75, .external_lex_state = 5},
  [3706] = {.lex_state = 75, .external_lex_state = 5},
  [3707] = {.lex_state = 75, .external_lex_state = 5},
  [3708] = {.lex_state = 75, .external_lex_state = 5},
  [3709] = {.lex_state = 75, .external_lex_state = 2},
  [3710] = {.lex_state = 75, .external_lex_state = 5},
  [3711] = {.lex_state = 75, .external_lex_state = 2},
  [3712] = {.lex_state = 75, .external_lex_state = 5},
  [3713] = {.lex_state = 75, .external_lex_state = 2},
  [3714] = {.lex_state = 75, .external_lex_state = 5},
  [3715] = {.lex_state = 75, .external_lex_state = 2},
  [3716] = {.lex_state = 75, .external_lex_state = 2},
  [3717] = {.lex_state = 75, .external_lex_state = 2},
  [3718] = {.lex_state = 75, .external_lex_state = 5},
  [3719] = {.lex_state = 75, .external_lex_state = 2},
  [3720] = {.lex_state = 75, .external_lex_state = 2},
  [3721] = {.lex_state = 75, .external_lex_state = 5},
  [3722] = {.lex_state = 75, .external_lex_state = 2},
  [3723] = {.lex_state = 75, .external_lex_state = 2},
  [3724] = {.lex_state = 75, .external_lex_state = 5},
  [3725] = {.lex_state = 75, .external_lex_state = 5},
  [3726] = {.lex_state = 75, .external_lex_state = 5},
  [3727] = {.lex_state = 75, .external_lex_state = 5},
  [3728] = {.lex_state = 75, .external_lex_state = 5},
  [3729] = {.lex_state = 75, .external_lex_state = 5},
  [3730] = {.lex_state = 75, .external_lex_state = 2},
  [3731] = {.lex_state = 75, .external_lex_state = 2},
  [3732] = {.lex_state = 75, .external_lex_state = 2},
  [3733] = {.lex_state = 75, .external_lex_state = 2},
  [3734] = {.lex_state = 75, .external_lex_state = 5},
  [3735] = {.lex_state = 75, .external_lex_state = 5},
  [3736] = {.lex_state = 75, .external_lex_state = 5},
  [3737] = {.lex_state = 75, .external_lex_state = 5},
  [3738] = {.lex_state = 75, .external_lex_state = 5},
  [3739] = {.lex_state = 7, .external_lex_state = 2},
  [3740] = {.lex_state = 75, .external_lex_state = 5},
  [3741] = {.lex_state = 75, .external_lex_state = 5},
  [3742] = {.lex_state = 75, .external_lex_state = 2},
  [3743] = {.lex_state = 75, .external_lex_state = 5},
  [3744] = {.lex_state = 75, .external_lex_state = 2},
  [3745] = {.lex_state = 75, .external_lex_state = 5},
  [3746] = {.lex_state = 75, .external_lex_state = 5},
  [3747] = {.lex_state = 75, .external_lex_state = 5},
  [3748] = {.lex_state = 75, .external_lex_state = 5},
  [3749] = {.lex_state = 75, .external_lex_state = 5},
  [3750] = {.lex_state = 75, .external_lex_state = 5},
  [3751] = {.lex_state = 75, .external_lex_state = 6},
  [3752] = {.lex_state = 75, .external_lex_state = 2},
  [3753] = {.lex_state = 75, .external_lex_state = 2},
  [3754] = {.lex_state = 75, .external_lex_state = 6},
  [3755] = {.lex_state = 75, .external_lex_state = 2},
  [3756] = {.lex_state = 75, .external_lex_state = 6},
  [3757] = {.lex_state = 75, .external_lex_state = 6},
  [3758] = {.lex_state = 75, .external_lex_state = 2},
  [3759] = {.lex_state = 75, .external_lex_state = 6},
  [3760] = {.lex_state = 75, .external_lex_state = 2},
  [3761] = {.lex_state = 75, .external_lex_state = 2},
  [3762] = {.lex_state = 75, .external_lex_state = 6},
  [3763] = {.lex_state = 75, .external_lex_state = 2},
  [3764] = {.lex_state = 13, .external_lex_state = 7},
  [3765] = {.lex_state = 75, .external_lex_state = 2},
  [3766] = {.lex_state = 75, .external_lex_state = 2},
  [3767] = {.lex_state = 75, .external_lex_state = 2},
  [3768] = {.lex_state = 75, .external_lex_state = 2},
  [3769] = {.lex_state = 75, .external_lex_state = 2},
  [3770] = {.lex_state = 75, .external_lex_state = 6},
  [3771] = {.lex_state = 75, .external_lex_state = 2},
  [3772] = {.lex_state = 75, .external_lex_state = 2},
  [3773] = {.lex_state = 75, .external_lex_state = 2},
  [3774] = {.lex_state = 75, .external_lex_state = 2},
  [3775] = {.lex_state = 75, .external_lex_state = 2},
  [3776] = {.lex_state = 75, .external_lex_state = 2},
  [3777] = {.lex_state = 75, .external_lex_state = 5},
  [3778] = {.lex_state = 75, .external_lex_state = 2},
  [3779] = {.lex_state = 75, .external_lex_state = 2},
  [3780] = {.lex_state = 75, .external_lex_state = 2},
  [3781] = {.lex_state = 75, .external_lex_state = 2},
  [3782] = {.lex_state = 75, .external_lex_state = 2},
  [3783] = {.lex_state = 75, .external_lex_state = 6},
  [3784] = {.lex_state = 75, .external_lex_state = 2},
  [3785] = {.lex_state = 13, .external_lex_state = 7},
  [3786] = {.lex_state = 75, .external_lex_state = 5},
  [3787] = {.lex_state = 75, .external_lex_state = 2},
  [3788] = {.lex_state = 75, .external_lex_state = 2},
  [3789] = {.lex_state = 75, .external_lex_state = 6},
  [3790] = {.lex_state = 75, .external_lex_state = 5},
  [3791] = {.lex_state = 75, .external_lex_state = 2},
  [3792] = {.lex_state = 75, .external_lex_state = 2},
  [3793] = {.lex_state = 75, .external_lex_state = 5},
  [3794] = {.lex_state = 75, .external_lex_state = 5},
  [3795] = {.lex_state = 75, .external_lex_state = 2},
  [3796] = {.lex_state = 75, .external_lex_state = 6},
  [3797] = {.lex_state = 75, .external_lex_state = 5},
  [3798] = {.lex_state = 75, .external_lex_state = 2},
  [3799] = {.lex_state = 75, .external_lex_state = 6},
  [3800] = {.lex_state = 75, .external_lex_state = 6},
  [3801] = {.lex_state = 75, .external_lex_state = 5},
  [3802] = {.lex_state = 75, .external_lex_state = 2},
  [3803] = {.lex_state = 75, .external_lex_state = 5},
  [3804] = {.lex_state = 75, .external_lex_state = 2},
  [3805] = {.lex_state = 75, .external_lex_state = 6},
  [3806] = {.lex_state = 75, .external_lex_state = 2},
  [3807] = {.lex_state = 75, .external_lex_state = 2},
  [3808] = {.lex_state = 75, .external_lex_state = 5},
  [3809] = {.lex_state = 75, .external_lex_state = 5},
  [3810] = {.lex_state = 75, .external_lex_state = 5},
  [3811] = {.lex_state = 75, .external_lex_state = 5},
  [3812] = {.lex_state = 75, .external_lex_state = 2},
  [3813] = {.lex_state = 75, .external_lex_state = 6},
  [3814] = {.lex_state = 75, .external_lex_state = 5},
  [3815] = {.lex_state = 75, .external_lex_state = 5},
  [3816] = {.lex_state = 75, .external_lex_state = 2},
  [3817] = {.lex_state = 75, .external_lex_state = 2},
  [3818] = {.lex_state = 8, .external_lex_state = 2},
  [3819] = {.lex_state = 75, .external_lex_state = 6},
  [3820] = {.lex_state = 75, .external_lex_state = 6},
  [3821] = {.lex_state = 75, .external_lex_state = 2},
  [3822] = {.lex_state = 75, .external_lex_state = 2},
  [3823] = {.lex_state = 75, .external_lex_state = 2},
  [3824] = {.lex_state = 75, .external_lex_state = 2},
  [3825] = {.lex_state = 75, .external_lex_state = 5},
  [3826] = {.lex_state = 75, .external_lex_state = 2},
  [3827] = {.lex_state = 75, .external_lex_state = 2},
  [3828] = {.lex_state = 75, .external_lex_state = 2},
  [3829] = {.lex_state = 75, .external_lex_state = 2},
  [3830] = {.lex_state = 75, .external_lex_state = 2},
  [3831] = {.lex_state = 75, .external_lex_state = 2},
  [3832] = {.lex_state = 13, .external_lex_state = 7},
  [3833] = {.lex_state = 75, .external_lex_state = 2},
  [3834] = {.lex_state = 75, .external_lex_state = 5},
  [3835] = {.lex_state = 75, .external_lex_state = 2},
  [3836] = {.lex_state = 75, .external_lex_state = 2},
  [3837] = {.lex_state = 75, .external_lex_state = 2},
  [3838] = {.lex_state = 75, .external_lex_state = 2},
  [3839] = {.lex_state = 75, .external_lex_state = 6},
  [3840] = {.lex_state = 75, .external_lex_state = 2},
  [3841] = {.lex_state = 75, .external_lex_state = 2},
  [3842] = {.lex_state = 75, .external_lex_state = 2},
  [3843] = {.lex_state = 75, .external_lex_state = 2},
  [3844] = {.lex_state = 75, .external_lex_state = 5},
  [3845] = {.lex_state = 75, .external_lex_state = 2},
  [3846] = {.lex_state = 75, .external_lex_state = 2},
  [3847] = {.lex_state = 75, .external_lex_state = 6},
  [3848] = {.lex_state = 75, .external_lex_state = 6},
  [3849] = {.lex_state = 75, .external_lex_state = 2},
  [3850] = {.lex_state = 75, .external_lex_state = 2},
  [3851] = {.lex_state = 75, .external_lex_state = 2},
  [3852] = {.lex_state = 13, .external_lex_state = 7},
  [3853] = {.lex_state = 75, .external_lex_state = 2},
  [3854] = {.lex_state = 75, .external_lex_state = 2},
  [3855] = {.lex_state = 75, .external_lex_state = 6},
  [3856] = {.lex_state = 75, .external_lex_state = 2},
  [3857] = {.lex_state = 75, .external_lex_state = 2},
  [3858] = {.lex_state = 75, .external_lex_state = 2},
  [3859] = {.lex_state = 75, .external_lex_state = 2},
  [3860] = {.lex_state = 75, .external_lex_state = 2},
  [3861] = {.lex_state = 13, .external_lex_state = 7},
  [3862] = {.lex_state = 75, .external_lex_state = 5},
  [3863] = {.lex_state = 75, .external_lex_state = 2},
  [3864] = {.lex_state = 75, .external_lex_state = 5},
  [3865] = {.lex_state = 75, .external_lex_state = 2},
  [3866] = {.lex_state = 75, .external_lex_state = 2},
  [3867] = {.lex_state = 75, .external_lex_state = 2},
  [3868] = {.lex_state = 75, .external_lex_state = 5},
  [3869] = {.lex_state = 8, .external_lex_state = 2},
  [3870] = {.lex_state = 75, .external_lex_state = 6},
  [3871] = {.lex_state = 75, .external_lex_state = 2},
  [3872] = {.lex_state = 75, .external_lex_state = 2},
  [3873] = {.lex_state = 75, .external_lex_state = 2},
  [3874] = {.lex_state = 75, .external_lex_state = 2},
  [3875] = {.lex_state = 75, .external_lex_state = 5},
  [3876] = {.lex_state = 75, .external_lex_state = 2},
  [3877] = {.lex_state = 75, .external_lex_state = 2},
  [3878] = {.lex_state = 75, .external_lex_state = 2},
  [3879] = {.lex_state = 75, .external_lex_state = 5},
  [3880] = {.lex_state = 75, .external_lex_state = 2},
  [3881] = {.lex_state = 75, .external_lex_state = 6},
  [3882] = {.lex_state = 75, .external_lex_state = 2},
  [3883] = {.lex_state = 75, .external_lex_state = 2},
  [3884] = {.lex_state = 75, .external_lex_state = 5},
  [3885] = {.lex_state = 75, .external_lex_state = 6},
  [3886] = {.lex_state = 75, .external_lex_state = 5},
  [3887] = {.lex_state = 75, .external_lex_state = 5},
  [3888] = {.lex_state = 75, .external_lex_state = 2},
  [3889] = {.lex_state = 75, .external_lex_state = 5},
  [3890] = {.lex_state = 75, .external_lex_state = 2},
  [3891] = {.lex_state = 75, .external_lex_state = 5},
  [3892] = {.lex_state = 75, .external_lex_state = 2},
  [3893] = {.lex_state = 75, .external_lex_state = 6},
  [3894] = {.lex_state = 75, .external_lex_state = 2},
  [3895] = {.lex_state = 75, .external_lex_state = 6},
  [3896] = {.lex_state = 75, .external_lex_state = 5},
  [3897] = {.lex_state = 75, .external_lex_state = 2},
  [3898] = {.lex_state = 75, .external_lex_state = 2},
  [3899] = {.lex_state = 75, .external_lex_state = 2},
  [3900] = {.lex_state = 75, .external_lex_state = 6},
  [3901] = {.lex_state = 13, .external_lex_state = 8},
  [3902] = {.lex_state = 75, .external_lex_state = 5},
  [3903] = {.lex_state = 75, .external_lex_state = 2},
  [3904] = {.lex_state = 75, .external_lex_state = 5},
  [3905] = {.lex_state = 75, .external_lex_state = 5},
  [3906] = {.lex_state = 75, .external_lex_state = 2},
  [3907] = {.lex_state = 75, .external_lex_state = 5},
  [3908] = {.lex_state = 75, .external_lex_state = 5},
  [3909] = {.lex_state = 75, .external_lex_state = 5},
  [3910] = {.lex_state = 75, .external_lex_state = 5},
  [3911] = {.lex_state = 75, .external_lex_state = 5},
  [3912] = {.lex_state = 75, .external_lex_state = 5},
  [3913] = {.lex_state = 75, .external_lex_state = 5},
  [3914] = {.lex_state = 75, .external_lex_state = 2},
  [3915] = {.lex_state = 75, .external_lex_state = 5},
  [3916] = {.lex_state = 75, .external_lex_state = 5},
  [3917] = {.lex_state = 75, .external_lex_state = 5},
  [3918] = {.lex_state = 75, .external_lex_state = 6},
  [3919] = {.lex_state = 75, .external_lex_state = 6},
  [3920] = {.lex_state = 75, .external_lex_state = 5},
  [3921] = {.lex_state = 75, .external_lex_state = 6},
  [3922] = {.lex_state = 75, .external_lex_state = 2},
  [3923] = {.lex_state = 13, .external_lex_state = 8},
  [3924] = {.lex_state = 75, .external_lex_state = 2},
  [3925] = {.lex_state = 75, .external_lex_state = 5},
  [3926] = {.lex_state = 75, .external_lex_state = 5},
  [3927] = {.lex_state = 75, .external_lex_state = 5},
  [3928] = {.lex_state = 75, .external_lex_state = 5},
  [3929] = {.lex_state = 75, .external_lex_state = 5},
  [3930] = {.lex_state = 75, .external_lex_state = 2},
  [3931] = {.lex_state = 75, .external_lex_state = 5},
  [3932] = {.lex_state = 75, .external_lex_state = 5},
  [3933] = {.lex_state = 75, .external_lex_state = 5},
  [3934] = {.lex_state = 75, .external_lex_state = 5},
  [3935] = {.lex_state = 75, .external_lex_state = 5},
  [3936] = {.lex_state = 75, .external_lex_state = 5},
  [3937] = {.lex_state = 75, .external_lex_state = 5},
  [3938] = {.lex_state = 75, .external_lex_state = 5},
  [3939] = {.lex_state = 75, .external_lex_state = 2},
  [3940] = {.lex_state = 75, .external_lex_state = 5},
  [3941] = {.lex_state = 75, .external_lex_state = 2},
  [3942] = {.lex_state = 75, .external_lex_state = 5},
  [3943] = {.lex_state = 75, .external_lex_state = 5},
  [3944] = {.lex_state = 75, .external_lex_state = 6},
  [3945] = {.lex_state = 75, .external_lex_state = 5},
  [3946] = {.lex_state = 75, .external_lex_state = 5},
  [3947] = {.lex_state = 75, .external_lex_state = 5},
  [3948] = {.lex_state = 75, .external_lex_state = 2},
  [3949] = {.lex_state = 75, .external_lex_state = 5},
  [3950] = {.lex_state = 75, .external_lex_state = 5},
  [3951] = {.lex_state = 2, .external_lex_state = 2},
  [3952] = {.lex_state = 75, .external_lex_state = 5},
  [3953] = {.lex_state = 75, .external_lex_state = 5},
  [3954] = {.lex_state = 75, .external_lex_state = 5},
  [3955] = {.lex_state = 75, .external_lex_state = 5},
  [3956] = {.lex_state = 75, .external_lex_state = 5},
  [3957] = {.lex_state = 75, .external_lex_state = 5},
  [3958] = {.lex_state = 75, .external_lex_state = 5},
  [3959] = {.lex_state = 75, .external_lex_state = 5},
  [3960] = {.lex_state = 75, .external_lex_state = 5},
  [3961] = {.lex_state = 75, .external_lex_state = 6},
  [3962] = {.lex_state = 75, .external_lex_state = 5},
  [3963] = {.lex_state = 75, .external_lex_state = 5},
  [3964] = {.lex_state = 75, .external_lex_state = 6},
  [3965] = {.lex_state = 75, .external_lex_state = 5},
  [3966] = {.lex_state = 75, .external_lex_state = 5},
  [3967] = {.lex_state = 75, .external_lex_state = 5},
  [3968] = {.lex_state = 75, .external_lex_state = 5},
  [3969] = {.lex_state = 75, .external_lex_state = 5},
  [3970] = {.lex_state = 75, .external_lex_state = 5},
  [3971] = {.lex_state = 75, .external_lex_state = 2},
  [3972] = {.lex_state = 75, .external_lex_state = 2},
  [3973] = {.lex_state = 75, .external_lex_state = 5},
  [3974] = {.lex_state = 75, .external_lex_state = 5},
  [3975] = {.lex_state = 75, .external_lex_state = 5},
  [3976] = {.lex_state = 75, .external_lex_state = 2},
  [3977] = {.lex_state = 75, .external_lex_state = 5},
  [3978] = {.lex_state = 75, .external_lex_state = 5},
  [3979] = {.lex_state = 75, .external_lex_state = 5},
  [3980] = {.lex_state = 75, .external_lex_state = 6},
  [3981] = {.lex_state = 75, .external_lex_state = 5},
  [3982] = {.lex_state = 75, .external_lex_state = 5},
  [3983] = {.lex_state = 75, .external_lex_state = 5},
  [3984] = {.lex_state = 75, .external_lex_state = 5},
  [3985] = {.lex_state = 75, .external_lex_state = 5},
  [3986] = {.lex_state = 75, .external_lex_state = 2},
  [3987] = {.lex_state = 75, .external_lex_state = 2},
  [3988] = {.lex_state = 75, .external_lex_state = 5},
  [3989] = {.lex_state = 75, .external_lex_state = 2},
  [3990] = {.lex_state = 75, .external_lex_state = 5},
  [3991] = {.lex_state = 75, .external_lex_state = 5},
  [3992] = {.lex_state = 75, .external_lex_state = 5},
  [3993] = {.lex_state = 75, .external_lex_state = 5},
  [3994] = {.lex_state = 75, .external_lex_state = 5},
  [3995] = {.lex_state = 75, .external_lex_state = 5},
  [3996] = {.lex_state = 75, .external_lex_state = 5},
  [3997] = {.lex_state = 75, .external_lex_state = 5},
  [3998] = {.lex_state = 75, .external_lex_state = 5},
  [3999] = {.lex_state = 75, .external_lex_state = 5},
  [4000] = {.lex_state = 75, .external_lex_state = 5},
  [4001] = {.lex_state = 75, .external_lex_state = 2},
  [4002] = {.lex_state = 75, .external_lex_state = 5},
  [4003] = {.lex_state = 75, .external_lex_state = 5},
  [4004] = {.lex_state = 75, .external_lex_state = 5},
  [4005] = {.lex_state = 75, .external_lex_state = 5},
  [4006] = {.lex_state = 75, .external_lex_state = 5},
  [4007] = {.lex_state = 75, .external_lex_state = 5},
  [4008] = {.lex_state = 75, .external_lex_state = 5},
  [4009] = {.lex_state = 75, .external_lex_state = 2},
  [4010] = {.lex_state = 75, .external_lex_state = 2},
  [4011] = {.lex_state = 75, .external_lex_state = 5},
  [4012] = {.lex_state = 75, .external_lex_state = 2},
  [4013] = {.lex_state = 75, .external_lex_state = 2},
  [4014] = {.lex_state = 75, .external_lex_state = 5},
  [4015] = {.lex_state = 75, .external_lex_state = 5},
  [4016] = {.lex_state = 75, .external_lex_state = 5},
  [4017] = {.lex_state = 75, .external_lex_state = 5},
  [4018] = {.lex_state = 75, .external_lex_state = 5},
  [4019] = {.lex_state = 75, .external_lex_state = 5},
  [4020] = {.lex_state = 75, .external_lex_state = 5},
  [4021] = {.lex_state = 75, .external_lex_state = 5},
  [4022] = {.lex_state = 75, .external_lex_state = 5},
  [4023] = {.lex_state = 75, .external_lex_state = 5},
  [4024] = {.lex_state = 75, .external_lex_state = 2},
  [4025] = {.lex_state = 75, .external_lex_state = 5},
  [4026] = {.lex_state = 75, .external_lex_state = 5},
  [4027] = {.lex_state = 75, .external_lex_state = 5},
  [4028] = {.lex_state = 75, .external_lex_state = 5},
  [4029] = {.lex_state = 75, .external_lex_state = 5},
  [4030] = {.lex_state = 75, .external_lex_state = 5},
  [4031] = {.lex_state = 75, .external_lex_state = 2},
  [4032] = {.lex_state = 75, .external_lex_state = 5},
  [4033] = {.lex_state = 75, .external_lex_state = 5},
  [4034] = {.lex_state = 75, .external_lex_state = 5},
  [4035] = {.lex_state = 75, .external_lex_state = 5},
  [4036] = {.lex_state = 75, .external_lex_state = 5},
  [4037] = {.lex_state = 75, .external_lex_state = 5},
  [4038] = {.lex_state = 75, .external_lex_state = 2},
  [4039] = {.lex_state = 75, .external_lex_state = 6},
  [4040] = {.lex_state = 75, .external_lex_state = 5},
  [4041] = {.lex_state = 75, .external_lex_state = 5},
  [4042] = {.lex_state = 75, .external_lex_state = 2},
  [4043] = {.lex_state = 75, .external_lex_state = 5},
  [4044] = {.lex_state = 75, .external_lex_state = 5},
  [4045] = {.lex_state = 75, .external_lex_state = 5},
  [4046] = {.lex_state = 13, .external_lex_state = 8},
  [4047] = {.lex_state = 75, .external_lex_state = 5},
  [4048] = {.lex_state = 75, .external_lex_state = 5},
  [4049] = {.lex_state = 75, .external_lex_state = 5},
  [4050] = {.lex_state = 75, .external_lex_state = 5},
  [4051] = {.lex_state = 75, .external_lex_state = 5},
  [4052] = {.lex_state = 75, .external_lex_state = 5},
  [4053] = {.lex_state = 75, .external_lex_state = 6},
  [4054] = {.lex_state = 75, .external_lex_state = 5},
  [4055] = {.lex_state = 75, .external_lex_state = 5},
  [4056] = {.lex_state = 75, .external_lex_state = 5},
  [4057] = {.lex_state = 13, .external_lex_state = 8},
  [4058] = {.lex_state = 75, .external_lex_state = 5},
  [4059] = {.lex_state = 75, .external_lex_state = 5},
  [4060] = {.lex_state = 75, .external_lex_state = 5},
  [4061] = {.lex_state = 75, .external_lex_state = 5},
  [4062] = {.lex_state = 75, .external_lex_state = 6},
  [4063] = {.lex_state = 75, .external_lex_state = 5},
  [4064] = {.lex_state = 75, .external_lex_state = 5},
  [4065] = {.lex_state = 75, .external_lex_state = 5},
  [4066] = {.lex_state = 75, .external_lex_state = 5},
  [4067] = {.lex_state = 75, .external_lex_state = 5},
  [4068] = {.lex_state = 75, .external_lex_state = 5},
  [4069] = {.lex_state = 75, .external_lex_state = 5},
  [4070] = {.lex_state = 75, .external_lex_state = 5},
  [4071] = {.lex_state = 75, .external_lex_state = 5},
  [4072] = {.lex_state = 75, .external_lex_state = 5},
  [4073] = {.lex_state = 75, .external_lex_state = 5},
  [4074] = {.lex_state = 75, .external_lex_state = 5},
  [4075] = {.lex_state = 75, .external_lex_state = 5},
  [4076] = {.lex_state = 75, .external_lex_state = 5},
  [4077] = {.lex_state = 75, .external_lex_state = 5},
  [4078] = {.lex_state = 75, .external_lex_state = 5},
  [4079] = {.lex_state = 75, .external_lex_state = 5},
  [4080] = {.lex_state = 75, .external_lex_state = 5},
  [4081] = {.lex_state = 75, .external_lex_state = 5},
  [4082] = {.lex_state = 75, .external_lex_state = 5},
  [4083] = {.lex_state = 75, .external_lex_state = 5},
  [4084] = {.lex_state = 75, .external_lex_state = 5},
  [4085] = {.lex_state = 13, .external_lex_state = 8},
  [4086] = {.lex_state = 75, .external_lex_state = 5},
  [4087] = {.lex_state = 75, .external_lex_state = 2},
  [4088] = {.lex_state = 75, .external_lex_state = 5},
  [4089] = {.lex_state = 75, .external_lex_state = 5},
  [4090] = {.lex_state = 75, .external_lex_state = 5},
  [4091] = {.lex_state = 75, .external_lex_state = 5},
  [4092] = {.lex_state = 13, .external_lex_state = 8},
  [4093] = {.lex_state = 75, .external_lex_state = 5},
  [4094] = {.lex_state = 75, .external_lex_state = 2},
  [4095] = {.lex_state = 75, .external_lex_state = 5},
  [4096] = {.lex_state = 75, .external_lex_state = 5},
  [4097] = {.lex_state = 75, .external_lex_state = 5},
  [4098] = {.lex_state = 75, .external_lex_state = 5},
  [4099] = {.lex_state = 75, .external_lex_state = 5},
  [4100] = {.lex_state = 75, .external_lex_state = 5},
  [4101] = {.lex_state = 75, .external_lex_state = 5},
  [4102] = {.lex_state = 75, .external_lex_state = 5},
  [4103] = {.lex_state = 75, .external_lex_state = 5},
  [4104] = {.lex_state = 75, .external_lex_state = 5},
  [4105] = {.lex_state = 75, .external_lex_state = 5},
  [4106] = {.lex_state = 75, .external_lex_state = 5},
  [4107] = {.lex_state = 13, .external_lex_state = 8},
  [4108] = {.lex_state = 13, .external_lex_state = 8},
  [4109] = {.lex_state = 75, .external_lex_state = 5},
  [4110] = {.lex_state = 75, .external_lex_state = 5},
  [4111] = {.lex_state = 75, .external_lex_state = 5},
  [4112] = {.lex_state = 13, .external_lex_state = 8},
  [4113] = {.lex_state = 75, .external_lex_state = 5},
  [4114] = {.lex_state = 75, .external_lex_state = 5},
  [4115] = {.lex_state = 75, .external_lex_state = 2},
  [4116] = {.lex_state = 75, .external_lex_state = 2},
  [4117] = {.lex_state = 75, .external_lex_state = 5},
  [4118] = {.lex_state = 75, .external_lex_state = 5},
  [4119] = {.lex_state = 75, .external_lex_state = 5},
  [4120] = {.lex_state = 75, .external_lex_state = 5},
  [4121] = {.lex_state = 75, .external_lex_state = 5},
  [4122] = {.lex_state = 75, .external_lex_state = 5},
  [4123] = {.lex_state = 75, .external_lex_state = 5},
  [4124] = {.lex_state = 75, .external_lex_state = 5},
  [4125] = {.lex_state = 75, .external_lex_state = 2},
  [4126] = {.lex_state = 75, .external_lex_state = 5},
  [4127] = {.lex_state = 75, .external_lex_state = 5},
  [4128] = {.lex_state = 75, .external_lex_state = 5},
  [4129] = {.lex_state = 75, .external_lex_state = 2},
  [4130] = {.lex_state = 75, .external_lex_state = 5},
  [4131] = {.lex_state = 75, .external_lex_state = 5},
  [4132] = {.lex_state = 75, .external_lex_state = 2},
  [4133] = {.lex_state = 75, .external_lex_state = 2},
  [4134] = {.lex_state = 75, .external_lex_state = 5},
  [4135] = {.lex_state = 75, .external_lex_state = 5},
  [4136] = {.lex_state = 13, .external_lex_state = 8},
  [4137] = {.lex_state = 75, .external_lex_state = 2},
  [4138] = {.lex_state = 75, .external_lex_state = 5},
  [4139] = {.lex_state = 75, .external_lex_state = 5},
  [4140] = {.lex_state = 75, .external_lex_state = 5},
  [4141] = {.lex_state = 75, .external_lex_state = 5},
  [4142] = {.lex_state = 75, .external_lex_state = 5},
  [4143] = {.lex_state = 8, .external_lex_state = 2},
  [4144] = {.lex_state = 75, .external_lex_state = 5},
  [4145] = {.lex_state = 7, .external_lex_state = 2},
  [4146] = {.lex_state = 75, .external_lex_state = 5},
  [4147] = {.lex_state = 75, .external_lex_state = 2},
  [4148] = {.lex_state = 75, .external_lex_state = 2},
  [4149] = {.lex_state = 75, .external_lex_state = 5},
  [4150] = {.lex_state = 75, .external_lex_state = 2},
  [4151] = {.lex_state = 75, .external_lex_state = 2},
  [4152] = {.lex_state = 75, .external_lex_state = 5},
  [4153] = {.lex_state = 75, .external_lex_state = 2},
  [4154] = {.lex_state = 75, .external_lex_state = 2},
  [4155] = {.lex_state = 75, .external_lex_state = 5},
  [4156] = {.lex_state = 75, .external_lex_state = 5},
  [4157] = {.lex_state = 75, .external_lex_state = 2},
  [4158] = {.lex_state = 75, .external_lex_state = 5},
  [4159] = {.lex_state = 75, .external_lex_state = 5},
  [4160] = {.lex_state = 75, .external_lex_state = 2},
  [4161] = {.lex_state = 75, .external_lex_state = 2},
  [4162] = {.lex_state = 75, .external_lex_state = 5},
  [4163] = {.lex_state = 75, .external_lex_state = 2},
  [4164] = {.lex_state = 75, .external_lex_state = 2},
  [4165] = {.lex_state = 75, .external_lex_state = 5},
  [4166] = {.lex_state = 75, .external_lex_state = 5},
  [4167] = {.lex_state = 75, .external_lex_state = 5},
  [4168] = {.lex_state = 75, .external_lex_state = 5},
  [4169] = {.lex_state = 75, .external_lex_state = 5},
  [4170] = {.lex_state = 75, .external_lex_state = 5},
  [4171] = {.lex_state = 75, .external_lex_state = 2},
  [4172] = {.lex_state = 75, .external_lex_state = 2},
  [4173] = {.lex_state = 75, .external_lex_state = 2},
  [4174] = {.lex_state = 75, .external_lex_state = 2},
  [4175] = {.lex_state = 75, .external_lex_state = 2},
  [4176] = {.lex_state = 75, .external_lex_state = 2},
  [4177] = {.lex_state = 75, .external_lex_state = 5},
  [4178] = {.lex_state = 75, .external_lex_state = 2},
  [4179] = {.lex_state = 75, .external_lex_state = 5},
  [4180] = {.lex_state = 75, .external_lex_state = 2},
  [4181] = {.lex_state = 75, .external_lex_state = 5},
  [4182] = {.lex_state = 75, .external_lex_state = 5},
  [4183] = {.lex_state = 75, .external_lex_state = 5},
  [4184] = {.lex_state = 75, .external_lex_state = 2},
  [4185] = {.lex_state = 75, .external_lex_state = 2},
  [4186] = {.lex_state = 75, .external_lex_state = 5},
  [4187] = {.lex_state = 75, .external_lex_state = 5},
  [4188] = {.lex_state = 75, .external_lex_state = 5},
  [4189] = {.lex_state = 75, .external_lex_state = 2},
  [4190] = {.lex_state = 75, .external_lex_state = 2},
  [4191] = {.lex_state = 75, .external_lex_state = 6},
  [4192] = {.lex_state = 75, .external_lex_state = 5},
  [4193] = {.lex_state = 75, .external_lex_state = 2},
  [4194] = {.lex_state = 75, .external_lex_state = 5},
  [4195] = {.lex_state = 75, .external_lex_state = 5},
  [4196] = {.lex_state = 75, .external_lex_state = 2},
  [4197] = {.lex_state = 75, .external_lex_state = 2},
  [4198] = {.lex_state = 75, .external_lex_state = 5},
  [4199] = {.lex_state = 75, .external_lex_state = 5},
  [4200] = {.lex_state = 75, .external_lex_state = 2},
  [4201] = {.lex_state = 75, .external_lex_state = 2},
  [4202] = {.lex_state = 75, .external_lex_state = 5},
  [4203] = {.lex_state = 75, .external_lex_state = 2},
  [4204] = {.lex_state = 75, .external_lex_state = 5},
  [4205] = {.lex_state = 75, .external_lex_state = 5},
  [4206] = {.lex_state = 75, .external_lex_state = 5},
  [4207] = {.lex_state = 75, .external_lex_state = 2},
  [4208] = {.lex_state = 2, .external_lex_state = 2},
  [4209] = {.lex_state = 75, .external_lex_state = 5},
  [4210] = {.lex_state = 75, .external_lex_state = 2},
  [4211] = {.lex_state = 75, .external_lex_state = 5},
  [4212] = {.lex_state = 75, .external_lex_state = 5},
  [4213] = {.lex_state = 75, .external_lex_state = 5},
  [4214] = {.lex_state = 75, .external_lex_state = 5},
  [4215] = {.lex_state = 75, .external_lex_state = 5},
  [4216] = {.lex_state = 75, .external_lex_state = 5},
  [4217] = {.lex_state = 75, .external_lex_state = 2},
  [4218] = {.lex_state = 13, .external_lex_state = 8},
  [4219] = {.lex_state = 75, .external_lex_state = 5},
  [4220] = {.lex_state = 75, .external_lex_state = 2},
  [4221] = {.lex_state = 75, .external_lex_state = 5},
  [4222] = {.lex_state = 75, .external_lex_state = 2},
  [4223] = {.lex_state = 75, .external_lex_state = 2},
  [4224] = {.lex_state = 75, .external_lex_state = 2},
  [4225] = {.lex_state = 75, .external_lex_state = 2},
  [4226] = {.lex_state = 75, .external_lex_state = 2},
  [4227] = {.lex_state = 75, .external_lex_state = 2},
  [4228] = {.lex_state = 75, .external_lex_state = 2},
  [4229] = {.lex_state = 75, .external_lex_state = 2},
  [4230] = {.lex_state = 75, .external_lex_state = 5},
  [4231] = {.lex_state = 75, .external_lex_state = 5},
  [4232] = {.lex_state = 75, .external_lex_state = 5},
  [4233] = {.lex_state = 75, .external_lex_state = 5},
  [4234] = {.lex_state = 75, .external_lex_state = 5},
  [4235] = {.lex_state = 75, .external_lex_state = 5},
  [4236] = {.lex_state = 75, .external_lex_state = 5},
  [4237] = {.lex_state = 75, .external_lex_state = 5},
  [4238] = {.lex_state = 75, .external_lex_state = 5},
  [4239] = {.lex_state = 75, .external_lex_state = 5},
  [4240] = {.lex_state = 75, .external_lex_state = 5},
  [4241] = {.lex_state = 75, .external_lex_state = 5},
  [4242] = {.lex_state = 75, .external_lex_state = 5},
  [4243] = {.lex_state = 75, .external_lex_state = 5},
  [4244] = {.lex_state = 75, .external_lex_state = 5},
  [4245] = {.lex_state = 75, .external_lex_state = 5},
  [4246] = {.lex_state = 75, .external_lex_state = 5},
  [4247] = {.lex_state = 75, .external_lex_state = 2},
  [4248] = {.lex_state = 75, .external_lex_state = 2},
  [4249] = {.lex_state = 75, .external_lex_state = 2},
  [4250] = {.lex_state = 75, .external_lex_state = 6},
  [4251] = {.lex_state = 75, .external_lex_state = 5},
  [4252] = {.lex_state = 75, .external_lex_state = 5},
  [4253] = {.lex_state = 75, .external_lex_state = 2},
  [4254] = {.lex_state = 75, .external_lex_state = 5},
  [4255] = {.lex_state = 75, .external_lex_state = 5},
  [4256] = {.lex_state = 75, .external_lex_state = 2},
  [4257] = {.lex_state = 75, .external_lex_state = 5},
  [4258] = {.lex_state = 75, .external_lex_state = 2},
  [4259] = {.lex_state = 75, .external_lex_state = 5},
  [4260] = {.lex_state = 75, .external_lex_state = 2},
  [4261] = {.lex_state = 75, .external_lex_state = 5},
  [4262] = {.lex_state = 75, .external_lex_state = 5},
  [4263] = {.lex_state = 75, .external_lex_state = 5},
  [4264] = {.lex_state = 75, .external_lex_state = 5},
  [4265] = {.lex_state = 75, .external_lex_state = 5},
  [4266] = {.lex_state = 75, .external_lex_state = 5},
  [4267] = {.lex_state = 75, .external_lex_state = 5},
  [4268] = {.lex_state = 75, .external_lex_state = 5},
  [4269] = {.lex_state = 75, .external_lex_state = 5},
  [4270] = {.lex_state = 75, .external_lex_state = 5},
  [4271] = {.lex_state = 75, .external_lex_state = 5},
  [4272] = {.lex_state = 75, .external_lex_state = 5},
  [4273] = {.lex_state = 75, .external_lex_state = 2},
  [4274] = {.lex_state = 75, .external_lex_state = 5},
  [4275] = {.lex_state = 75, .external_lex_state = 5},
  [4276] = {.lex_state = 75, .external_lex_state = 2},
  [4277] = {.lex_state = 75, .external_lex_state = 2},
  [4278] = {.lex_state = 75, .external_lex_state = 5},
  [4279] = {.lex_state = 75, .external_lex_state = 2},
  [4280] = {.lex_state = 75, .external_lex_state = 5},
  [4281] = {.lex_state = 75, .external_lex_state = 5},
  [4282] = {.lex_state = 75, .external_lex_state = 5},
  [4283] = {.lex_state = 75, .external_lex_state = 5},
  [4284] = {.lex_state = 75, .external_lex_state = 5},
  [4285] = {.lex_state = 75, .external_lex_state = 2},
  [4286] = {.lex_state = 75, .external_lex_state = 5},
  [4287] = {.lex_state = 75, .external_lex_state = 5},
  [4288] = {.lex_state = 75, .external_lex_state = 2},
  [4289] = {.lex_state = 75, .external_lex_state = 5},
  [4290] = {.lex_state = 75, .external_lex_state = 2},
  [4291] = {.lex_state = 75, .external_lex_state = 2},
  [4292] = {.lex_state = 75, .external_lex_state = 2},
  [4293] = {.lex_state = 75, .external_lex_state = 2},
  [4294] = {.lex_state = 75, .external_lex_state = 5},
  [4295] = {.lex_state = 75, .external_lex_state = 5},
  [4296] = {.lex_state = 75, .external_lex_state = 5},
  [4297] = {.lex_state = 75, .external_lex_state = 5},
  [4298] = {.lex_state = 75, .external_lex_state = 2},
  [4299] = {.lex_state = 75, .external_lex_state = 5},
  [4300] = {.lex_state = 75, .external_lex_state = 5},
  [4301] = {.lex_state = 75, .external_lex_state = 2},
  [4302] = {.lex_state = 75, .external_lex_state = 5},
  [4303] = {.lex_state = 75, .external_lex_state = 2},
  [4304] = {.lex_state = 75, .external_lex_state = 2},
  [4305] = {.lex_state = 75, .external_lex_state = 2},
  [4306] = {.lex_state = 75, .external_lex_state = 2},
  [4307] = {.lex_state = 75, .external_lex_state = 5},
  [4308] = {.lex_state = 75, .external_lex_state = 2},
  [4309] = {.lex_state = 75, .external_lex_state = 2},
  [4310] = {.lex_state = 75, .external_lex_state = 5},
  [4311] = {.lex_state = 75, .external_lex_state = 5},
  [4312] = {.lex_state = 75, .external_lex_state = 2},
  [4313] = {.lex_state = 75, .external_lex_state = 5},
  [4314] = {.lex_state = 75, .external_lex_state = 5},
  [4315] = {.lex_state = 75, .external_lex_state = 5},
  [4316] = {.lex_state = 75, .external_lex_state = 5},
  [4317] = {.lex_state = 75, .external_lex_state = 2},
  [4318] = {.lex_state = 75, .external_lex_state = 5},
  [4319] = {.lex_state = 75, .external_lex_state = 2},
  [4320] = {.lex_state = 75, .external_lex_state = 2},
  [4321] = {.lex_state = 75, .external_lex_state = 2},
  [4322] = {.lex_state = 75, .external_lex_state = 2},
  [4323] = {.lex_state = 75, .external_lex_state = 2},
  [4324] = {.lex_state = 75, .external_lex_state = 6},
  [4325] = {.lex_state = 75, .external_lex_state = 5},
  [4326] = {.lex_state = 75, .external_lex_state = 2},
  [4327] = {.lex_state = 75, .external_lex_state = 5},
  [4328] = {.lex_state = 75, .external_lex_state = 5},
  [4329] = {.lex_state = 75, .external_lex_state = 2},
  [4330] = {.lex_state = 75, .external_lex_state = 5},
  [4331] = {.lex_state = 75, .external_lex_state = 5},
  [4332] = {.lex_state = 75, .external_lex_state = 5},
  [4333] = {.lex_state = 75, .external_lex_state = 5},
  [4334] = {.lex_state = 75, .external_lex_state = 5},
  [4335] = {.lex_state = 75, .external_lex_state = 2},
  [4336] = {.lex_state = 75, .external_lex_state = 5},
  [4337] = {.lex_state = 75, .external_lex_state = 5},
  [4338] = {.lex_state = 75, .external_lex_state = 5},
  [4339] = {.lex_state = 75, .external_lex_state = 2},
  [4340] = {.lex_state = 75, .external_lex_state = 2},
  [4341] = {.lex_state = 75, .external_lex_state = 2},
  [4342] = {.lex_state = 75, .external_lex_state = 5},
  [4343] = {.lex_state = 75, .external_lex_state = 5},
  [4344] = {.lex_state = 75, .external_lex_state = 5},
  [4345] = {.lex_state = 75, .external_lex_state = 5},
  [4346] = {.lex_state = 75, .external_lex_state = 5},
  [4347] = {.lex_state = 75, .external_lex_state = 5},
  [4348] = {.lex_state = 75, .external_lex_state = 2},
  [4349] = {.lex_state = 75, .external_lex_state = 5},
  [4350] = {.lex_state = 8, .external_lex_state = 2},
  [4351] = {.lex_state = 8, .external_lex_state = 2},
  [4352] = {.lex_state = 75, .external_lex_state = 5},
  [4353] = {.lex_state = 75, .external_lex_state = 5},
  [4354] = {.lex_state = 75, .external_lex_state = 2},
  [4355] = {.lex_state = 75, .external_lex_state = 6},
  [4356] = {.lex_state = 75, .external_lex_state = 5},
  [4357] = {.lex_state = 75, .external_lex_state = 5},
  [4358] = {.lex_state = 75, .external_lex_state = 5},
  [4359] = {.lex_state = 75, .external_lex_state = 2},
  [4360] = {.lex_state = 75, .external_lex_state = 5},
  [4361] = {.lex_state = 75, .external_lex_state = 5},
  [4362] = {.lex_state = 75, .external_lex_state = 5},
  [4363] = {.lex_state = 75, .external_lex_state = 5},
  [4364] = {.lex_state = 75, .external_lex_state = 5},
  [4365] = {.lex_state = 75, .external_lex_state = 5},
  [4366] = {.lex_state = 75, .external_lex_state = 5},
  [4367] = {.lex_state = 75, .external_lex_state = 5},
  [4368] = {.lex_state = 75, .external_lex_state = 5},
  [4369] = {.lex_state = 75, .external_lex_state = 5},
  [4370] = {.lex_state = 75, .external_lex_state = 5},
  [4371] = {.lex_state = 75, .external_lex_state = 5},
  [4372] = {.lex_state = 75, .external_lex_state = 5},
  [4373] = {.lex_state = 7, .external_lex_state = 2},
  [4374] = {.lex_state = 75, .external_lex_state = 5},
  [4375] = {.lex_state = 75, .external_lex_state = 5},
  [4376] = {.lex_state = 75, .external_lex_state = 5},
  [4377] = {.lex_state = 75, .external_lex_state = 5},
  [4378] = {.lex_state = 75, .external_lex_state = 5},
  [4379] = {.lex_state = 75, .external_lex_state = 5},
  [4380] = {.lex_state = 16, .external_lex_state = 9},
  [4381] = {.lex_state = 16, .external_lex_state = 9},
  [4382] = {.lex_state = 75, .external_lex_state = 2},
  [4383] = {.lex_state = 75, .external_lex_state = 2},
  [4384] = {.lex_state = 75, .external_lex_state = 2},
  [4385] = {.lex_state = 75, .external_lex_state = 5},
  [4386] = {.lex_state = 75, .external_lex_state = 2},
  [4387] = {.lex_state = 75, .external_lex_state = 2},
  [4388] = {.lex_state = 75, .external_lex_state = 2},
  [4389] = {.lex_state = 7, .external_lex_state = 2},
  [4390] = {.lex_state = 12, .external_lex_state = 9},
  [4391] = {.lex_state = 75, .external_lex_state = 2},
  [4392] = {.lex_state = 16, .external_lex_state = 9},
  [4393] = {.lex_state = 12, .external_lex_state = 9},
  [4394] = {.lex_state = 12, .external_lex_state = 9},
  [4395] = {.lex_state = 16, .external_lex_state = 9},
  [4396] = {.lex_state = 16, .external_lex_state = 9},
  [4397] = {.lex_state = 75, .external_lex_state = 2},
  [4398] = {.lex_state = 75, .external_lex_state = 2},
  [4399] = {.lex_state = 2, .external_lex_state = 2},
  [4400] = {.lex_state = 2, .external_lex_state = 2},
  [4401] = {.lex_state = 2, .external_lex_state = 2},
  [4402] = {.lex_state = 12, .external_lex_state = 9},
  [4403] = {.lex_state = 75, .external_lex_state = 2},
  [4404] = {.lex_state = 12, .external_lex_state = 9},
  [4405] = {.lex_state = 75, .external_lex_state = 2},
  [4406] = {.lex_state = 75, .external_lex_state = 2},
  [4407] = {.lex_state = 75, .external_lex_state = 2},
  [4408] = {.lex_state = 75, .external_lex_state = 2},
  [4409] = {.lex_state = 75, .external_lex_state = 2},
  [4410] = {.lex_state = 75, .external_lex_state = 2},
  [4411] = {.lex_state = 16, .external_lex_state = 9},
  [4412] = {.lex_state = 12, .external_lex_state = 9},
  [4413] = {.lex_state = 75, .external_lex_state = 2},
  [4414] = {.lex_state = 75, .external_lex_state = 2},
  [4415] = {.lex_state = 75, .external_lex_state = 2},
  [4416] = {.lex_state = 75, .external_lex_state = 5},
  [4417] = {.lex_state = 75, .external_lex_state = 5},
  [4418] = {.lex_state = 75, .external_lex_state = 2},
  [4419] = {.lex_state = 75, .external_lex_state = 2},
  [4420] = {.lex_state = 75, .external_lex_state = 2},
  [4421] = {.lex_state = 7, .external_lex_state = 2},
  [4422] = {.lex_state = 75, .external_lex_state = 2},
  [4423] = {.lex_state = 75, .external_lex_state = 2},
  [4424] = {.lex_state = 75, .external_lex_state = 2},
  [4425] = {.lex_state = 75, .external_lex_state = 2},
  [4426] = {.lex_state = 75, .external_lex_state = 5},
  [4427] = {.lex_state = 75, .external_lex_state = 5},
  [4428] = {.lex_state = 75, .external_lex_state = 2},
  [4429] = {.lex_state = 75, .external_lex_state = 2},
  [4430] = {.lex_state = 75, .external_lex_state = 2},
  [4431] = {.lex_state = 75, .external_lex_state = 2},
  [4432] = {.lex_state = 75, .external_lex_state = 2},
  [4433] = {.lex_state = 75, .external_lex_state = 2},
  [4434] = {.lex_state = 75, .external_lex_state = 2},
  [4435] = {.lex_state = 75, .external_lex_state = 2},
  [4436] = {.lex_state = 75, .external_lex_state = 2},
  [4437] = {.lex_state = 75, .external_lex_state = 2},
  [4438] = {.lex_state = 75, .external_lex_state = 2},
  [4439] = {.lex_state = 75, .external_lex_state = 2},
  [4440] = {.lex_state = 75, .external_lex_state = 6},
  [4441] = {.lex_state = 75, .external_lex_state = 2},
  [4442] = {.lex_state = 75, .external_lex_state = 2},
  [4443] = {.lex_state = 16, .external_lex_state = 9},
  [4444] = {.lex_state = 75, .external_lex_state = 2},
  [4445] = {.lex_state = 13, .external_lex_state = 7},
  [4446] = {.lex_state = 75, .external_lex_state = 2},
  [4447] = {.lex_state = 2, .external_lex_state = 2},
  [4448] = {.lex_state = 75, .external_lex_state = 2},
  [4449] = {.lex_state = 75, .external_lex_state = 2},
  [4450] = {.lex_state = 75, .external_lex_state = 5},
  [4451] = {.lex_state = 75, .external_lex_state = 5},
  [4452] = {.lex_state = 16, .external_lex_state = 9},
  [4453] = {.lex_state = 12, .external_lex_state = 9},
  [4454] = {.lex_state = 75, .external_lex_state = 2},
  [4455] = {.lex_state = 75, .external_lex_state = 5},
  [4456] = {.lex_state = 16, .external_lex_state = 9},
  [4457] = {.lex_state = 75, .external_lex_state = 5},
  [4458] = {.lex_state = 75, .external_lex_state = 5},
  [4459] = {.lex_state = 75, .external_lex_state = 5},
  [4460] = {.lex_state = 75, .external_lex_state = 5},
  [4461] = {.lex_state = 75, .external_lex_state = 2},
  [4462] = {.lex_state = 75, .external_lex_state = 2},
  [4463] = {.lex_state = 75, .external_lex_state = 2},
  [4464] = {.lex_state = 75, .external_lex_state = 5},
  [4465] = {.lex_state = 12, .external_lex_state = 9},
  [4466] = {.lex_state = 16, .external_lex_state = 9},
  [4467] = {.lex_state = 75, .external_lex_state = 5},
  [4468] = {.lex_state = 75, .external_lex_state = 2},
  [4469] = {.lex_state = 75, .external_lex_state = 5},
  [4470] = {.lex_state = 75, .external_lex_state = 2},
  [4471] = {.lex_state = 12, .external_lex_state = 9},
  [4472] = {.lex_state = 75, .external_lex_state = 2},
  [4473] = {.lex_state = 75, .external_lex_state = 2},
  [4474] = {.lex_state = 75, .external_lex_state = 2},
  [4475] = {.lex_state = 75, .external_lex_state = 2},
  [4476] = {.lex_state = 12, .external_lex_state = 9},
  [4477] = {.lex_state = 75, .external_lex_state = 2},
  [4478] = {.lex_state = 16, .external_lex_state = 9},
  [4479] = {.lex_state = 75, .external_lex_state = 2},
  [4480] = {.lex_state = 75, .external_lex_state = 2},
  [4481] = {.lex_state = 75, .external_lex_state = 2},
  [4482] = {.lex_state = 16, .external_lex_state = 9},
  [4483] = {.lex_state = 75, .external_lex_state = 2},
  [4484] = {.lex_state = 75, .external_lex_state = 2},
  [4485] = {.lex_state = 2, .external_lex_state = 2},
  [4486] = {.lex_state = 75, .external_lex_state = 2},
  [4487] = {.lex_state = 13, .external_lex_state = 7},
  [4488] = {.lex_state = 75, .external_lex_state = 2},
  [4489] = {.lex_state = 75, .external_lex_state = 2},
  [4490] = {.lex_state = 75, .external_lex_state = 2},
  [4491] = {.lex_state = 75, .external_lex_state = 2},
  [4492] = {.lex_state = 75, .external_lex_state = 2},
  [4493] = {.lex_state = 12, .external_lex_state = 9},
  [4494] = {.lex_state = 12, .external_lex_state = 9},
  [4495] = {.lex_state = 16, .external_lex_state = 9},
  [4496] = {.lex_state = 16, .external_lex_state = 9},
  [4497] = {.lex_state = 75, .external_lex_state = 2},
  [4498] = {.lex_state = 75, .external_lex_state = 2},
  [4499] = {.lex_state = 75, .external_lex_state = 2},
  [4500] = {.lex_state = 75, .external_lex_state = 2},
  [4501] = {.lex_state = 75, .external_lex_state = 2},
  [4502] = {.lex_state = 75, .external_lex_state = 2},
  [4503] = {.lex_state = 75, .external_lex_state = 2},
  [4504] = {.lex_state = 75, .external_lex_state = 2},
  [4505] = {.lex_state = 75, .external_lex_state = 2},
  [4506] = {.lex_state = 75, .external_lex_state = 5},
  [4507] = {.lex_state = 75, .external_lex_state = 2},
  [4508] = {.lex_state = 75, .external_lex_state = 2},
  [4509] = {.lex_state = 12, .external_lex_state = 9},
  [4510] = {.lex_state = 75, .external_lex_state = 2},
  [4511] = {.lex_state = 16, .external_lex_state = 9},
  [4512] = {.lex_state = 12, .external_lex_state = 9},
  [4513] = {.lex_state = 12, .external_lex_state = 9},
  [4514] = {.lex_state = 75, .external_lex_state = 2},
  [4515] = {.lex_state = 75, .external_lex_state = 5},
  [4516] = {.lex_state = 75, .external_lex_state = 5},
  [4517] = {.lex_state = 75, .external_lex_state = 5},
  [4518] = {.lex_state = 75, .external_lex_state = 5},
  [4519] = {.lex_state = 75, .external_lex_state = 5},
  [4520] = {.lex_state = 75, .external_lex_state = 5},
  [4521] = {.lex_state = 75, .external_lex_state = 5},
  [4522] = {.lex_state = 75, .external_lex_state = 5},
  [4523] = {.lex_state = 75, .external_lex_state = 2},
  [4524] = {.lex_state = 75, .external_lex_state = 2},
  [4525] = {.lex_state = 75, .external_lex_state = 5},
  [4526] = {.lex_state = 75, .external_lex_state = 5},
  [4527] = {.lex_state = 75, .external_lex_state = 5},
  [4528] = {.lex_state = 75, .external_lex_state = 5},
  [4529] = {.lex_state = 75, .external_lex_state = 5},
  [4530] = {.lex_state = 75, .external_lex_state = 5},
  [4531] = {.lex_state = 75, .external_lex_state = 2},
  [4532] = {.lex_state = 75, .external_lex_state = 5},
  [4533] = {.lex_state = 75, .external_lex_state = 2},
  [4534] = {.lex_state = 75, .external_lex_state = 5},
  [4535] = {.lex_state = 75, .external_lex_state = 5},
  [4536] = {.lex_state = 75, .external_lex_state = 5},
  [4537] = {.lex_state = 75, .external_lex_state = 2},
  [4538] = {.lex_state = 75, .external_lex_state = 5},
  [4539] = {.lex_state = 75, .external_lex_state = 5},
  [4540] = {.lex_state = 75, .external_lex_state = 2},
  [4541] = {.lex_state = 75, .external_lex_state = 2},
  [4542] = {.lex_state = 75, .external_lex_state = 2},
  [4543] = {.lex_state = 75, .external_lex_state = 2},
  [4544] = {.lex_state = 75, .external_lex_state = 2},
  [4545] = {.lex_state = 75, .external_lex_state = 2},
  [4546] = {.lex_state = 75, .external_lex_state = 5},
  [4547] = {.lex_state = 75, .external_lex_state = 5},
  [4548] = {.lex_state = 75, .external_lex_state = 5},
  [4549] = {.lex_state = 75, .external_lex_state = 5},
  [4550] = {.lex_state = 75, .external_lex_state = 5},
  [4551] = {.lex_state = 75, .external_lex_state = 5},
  [4552] = {.lex_state = 75, .external_lex_state = 2},
  [4553] = {.lex_state = 75, .external_lex_state = 2},
  [4554] = {.lex_state = 75, .external_lex_state = 2},
  [4555] = {.lex_state = 75, .external_lex_state = 2},
  [4556] = {.lex_state = 75, .external_lex_state = 5},
  [4557] = {.lex_state = 75, .external_lex_state = 5},
  [4558] = {.lex_state = 75, .external_lex_state = 5},
  [4559] = {.lex_state = 75, .external_lex_state = 5},
  [4560] = {.lex_state = 75, .external_lex_state = 5},
  [4561] = {.lex_state = 75, .external_lex_state = 5},
  [4562] = {.lex_state = 75, .external_lex_state = 5},
  [4563] = {.lex_state = 75, .external_lex_state = 5},
  [4564] = {.lex_state = 75, .external_lex_state = 5},
  [4565] = {.lex_state = 75, .external_lex_state = 5},
  [4566] = {.lex_state = 75, .external_lex_state = 5},
  [4567] = {.lex_state = 75, .external_lex_state = 5},
  [4568] = {.lex_state = 75, .external_lex_state = 2},
  [4569] = {.lex_state = 75, .external_lex_state = 5},
  [4570] = {.lex_state = 75, .external_lex_state = 5},
  [4571] = {.lex_state = 75, .external_lex_state = 5},
  [4572] = {.lex_state = 75, .external_lex_state = 5},
  [4573] = {.lex_state = 75, .external_lex_state = 5},
  [4574] = {.lex_state = 75, .external_lex_state = 5},
  [4575] = {.lex_state = 75, .external_lex_state = 5},
  [4576] = {.lex_state = 75, .external_lex_state = 2},
  [4577] = {.lex_state = 75, .external_lex_state = 5},
  [4578] = {.lex_state = 75, .external_lex_state = 2},
  [4579] = {.lex_state = 75, .external_lex_state = 5},
  [4580] = {.lex_state = 75, .external_lex_state = 5},
  [4581] = {.lex_state = 75, .external_lex_state = 5},
  [4582] = {.lex_state = 75, .external_lex_state = 5},
  [4583] = {.lex_state = 75, .external_lex_state = 5},
  [4584] = {.lex_state = 75, .external_lex_state = 5},
  [4585] = {.lex_state = 75, .external_lex_state = 5},
  [4586] = {.lex_state = 75, .external_lex_state = 2},
  [4587] = {.lex_state = 75, .external_lex_state = 2},
  [4588] = {.lex_state = 75, .external_lex_state = 2},
  [4589] = {.lex_state = 75, .external_lex_state = 5},
  [4590] = {.lex_state = 75, .external_lex_state = 2},
  [4591] = {.lex_state = 75, .external_lex_state = 2},
  [4592] = {.lex_state = 75, .external_lex_state = 5},
  [4593] = {.lex_state = 75, .external_lex_state = 5},
  [4594] = {.lex_state = 75, .external_lex_state = 2},
  [4595] = {.lex_state = 75, .external_lex_state = 2},
  [4596] = {.lex_state = 75, .external_lex_state = 2},
  [4597] = {.lex_state = 75, .external_lex_state = 2},
  [4598] = {.lex_state = 75, .external_lex_state = 5},
  [4599] = {.lex_state = 75, .external_lex_state = 2},
  [4600] = {.lex_state = 75, .external_lex_state = 5},
  [4601] = {.lex_state = 75, .external_lex_state = 5},
  [4602] = {.lex_state = 75, .external_lex_state = 2},
  [4603] = {.lex_state = 75, .external_lex_state = 5},
  [4604] = {.lex_state = 75, .external_lex_state = 5},
  [4605] = {.lex_state = 75, .external_lex_state = 5},
  [4606] = {.lex_state = 75, .external_lex_state = 5},
  [4607] = {.lex_state = 75, .external_lex_state = 5},
  [4608] = {.lex_state = 75, .external_lex_state = 5},
  [4609] = {.lex_state = 75, .external_lex_state = 5},
  [4610] = {.lex_state = 75, .external_lex_state = 5},
  [4611] = {.lex_state = 75, .external_lex_state = 5},
  [4612] = {.lex_state = 75, .external_lex_state = 5},
  [4613] = {.lex_state = 75, .external_lex_state = 5},
  [4614] = {.lex_state = 75, .external_lex_state = 5},
  [4615] = {.lex_state = 75, .external_lex_state = 5},
  [4616] = {.lex_state = 75, .external_lex_state = 5},
  [4617] = {.lex_state = 75, .external_lex_state = 5},
  [4618] = {.lex_state = 75, .external_lex_state = 5},
  [4619] = {.lex_state = 75, .external_lex_state = 5},
  [4620] = {.lex_state = 75, .external_lex_state = 2},
  [4621] = {.lex_state = 75, .external_lex_state = 2},
  [4622] = {.lex_state = 75, .external_lex_state = 2},
  [4623] = {.lex_state = 75, .external_lex_state = 5},
  [4624] = {.lex_state = 75, .external_lex_state = 5},
  [4625] = {.lex_state = 75, .external_lex_state = 5},
  [4626] = {.lex_state = 75, .external_lex_state = 5},
  [4627] = {.lex_state = 75, .external_lex_state = 5},
  [4628] = {.lex_state = 75, .external_lex_state = 5},
  [4629] = {.lex_state = 75, .external_lex_state = 2},
  [4630] = {.lex_state = 75, .external_lex_state = 5},
  [4631] = {.lex_state = 75, .external_lex_state = 5},
  [4632] = {.lex_state = 75, .external_lex_state = 5},
  [4633] = {.lex_state = 75, .external_lex_state = 5},
  [4634] = {.lex_state = 75, .external_lex_state = 5},
  [4635] = {.lex_state = 75, .external_lex_state = 5},
  [4636] = {.lex_state = 75, .external_lex_state = 2},
  [4637] = {.lex_state = 75, .external_lex_state = 5},
  [4638] = {.lex_state = 75, .external_lex_state = 2},
  [4639] = {.lex_state = 75, .external_lex_state = 2},
  [4640] = {.lex_state = 75, .external_lex_state = 5},
  [4641] = {.lex_state = 75, .external_lex_state = 5},
  [4642] = {.lex_state = 75, .external_lex_state = 5},
  [4643] = {.lex_state = 2, .external_lex_state = 2},
  [4644] = {.lex_state = 75, .external_lex_state = 2},
  [4645] = {.lex_state = 75, .external_lex_state = 5},
  [4646] = {.lex_state = 75, .external_lex_state = 2},
  [4647] = {.lex_state = 75, .external_lex_state = 2},
  [4648] = {.lex_state = 75, .external_lex_state = 5},
  [4649] = {.lex_state = 75, .external_lex_state = 2},
  [4650] = {.lex_state = 75, .external_lex_state = 2},
  [4651] = {.lex_state = 2, .external_lex_state = 2},
  [4652] = {.lex_state = 75, .external_lex_state = 5},
  [4653] = {.lex_state = 75, .external_lex_state = 2},
  [4654] = {.lex_state = 75, .external_lex_state = 2},
  [4655] = {.lex_state = 75, .external_lex_state = 5},
  [4656] = {.lex_state = 75, .external_lex_state = 2},
  [4657] = {.lex_state = 75, .external_lex_state = 5},
  [4658] = {.lex_state = 75, .external_lex_state = 5},
  [4659] = {.lex_state = 75, .external_lex_state = 5},
  [4660] = {.lex_state = 75, .external_lex_state = 5},
  [4661] = {.lex_state = 75, .external_lex_state = 2},
  [4662] = {.lex_state = 75, .external_lex_state = 5},
  [4663] = {.lex_state = 75, .external_lex_state = 2},
  [4664] = {.lex_state = 75, .external_lex_state = 5},
  [4665] = {.lex_state = 75, .external_lex_state = 5},
  [4666] = {.lex_state = 75, .external_lex_state = 5},
  [4667] = {.lex_state = 75, .external_lex_state = 5},
  [4668] = {.lex_state = 75, .external_lex_state = 2},
  [4669] = {.lex_state = 75, .external_lex_state = 5},
  [4670] = {.lex_state = 75, .external_lex_state = 5},
  [4671] = {.lex_state = 75, .external_lex_state = 2},
  [4672] = {.lex_state = 75, .external_lex_state = 2},
  [4673] = {.lex_state = 75, .external_lex_state = 5},
  [4674] = {.lex_state = 75, .external_lex_state = 5},
  [4675] = {.lex_state = 75, .external_lex_state = 5},
  [4676] = {.lex_state = 75, .external_lex_state = 5},
  [4677] = {.lex_state = 75, .external_lex_state = 5},
  [4678] = {.lex_state = 75, .external_lex_state = 2},
  [4679] = {.lex_state = 75, .external_lex_state = 5},
  [4680] = {.lex_state = 75, .external_lex_state = 5},
  [4681] = {.lex_state = 75, .external_lex_state = 2},
  [4682] = {.lex_state = 75, .external_lex_state = 5},
  [4683] = {.lex_state = 2, .external_lex_state = 2},
  [4684] = {.lex_state = 75, .external_lex_state = 2},
  [4685] = {.lex_state = 75, .external_lex_state = 2},
  [4686] = {.lex_state = 75, .external_lex_state = 2},
  [4687] = {.lex_state = 75, .external_lex_state = 2},
  [4688] = {.lex_state = 2, .external_lex_state = 2},
  [4689] = {.lex_state = 75, .external_lex_state = 5},
  [4690] = {.lex_state = 75, .external_lex_state = 5},
  [4691] = {.lex_state = 75, .external_lex_state = 5},
  [4692] = {.lex_state = 75, .external_lex_state = 2},
  [4693] = {.lex_state = 75, .external_lex_state = 2},
  [4694] = {.lex_state = 75, .external_lex_state = 5},
  [4695] = {.lex_state = 75, .external_lex_state = 2},
  [4696] = {.lex_state = 75, .external_lex_state = 5},
  [4697] = {.lex_state = 75, .external_lex_state = 2},
  [4698] = {.lex_state = 75, .external_lex_state = 2},
  [4699] = {.lex_state = 75, .external_lex_state = 5},
  [4700] = {.lex_state = 75, .external_lex_state = 2},
  [4701] = {.lex_state = 75, .external_lex_state = 5},
  [4702] = {.lex_state = 75, .external_lex_state = 5},
  [4703] = {.lex_state = 75, .external_lex_state = 5},
  [4704] = {.lex_state = 75, .external_lex_state = 5},
  [4705] = {.lex_state = 75, .external_lex_state = 5},
  [4706] = {.lex_state = 75, .external_lex_state = 5},
  [4707] = {.lex_state = 75, .external_lex_state = 5},
  [4708] = {.lex_state = 75, .external_lex_state = 2},
  [4709] = {.lex_state = 75, .external_lex_state = 5},
  [4710] = {.lex_state = 75, .external_lex_state = 5},
  [4711] = {.lex_state = 75, .external_lex_state = 5},
  [4712] = {.lex_state = 75, .external_lex_state = 2},
  [4713] = {.lex_state = 75, .external_lex_state = 2},
  [4714] = {.lex_state = 75, .external_lex_state = 2},
  [4715] = {.lex_state = 75, .external_lex_state = 5},
  [4716] = {.lex_state = 75, .external_lex_state = 2},
  [4717] = {.lex_state = 75, .external_lex_state = 5},
  [4718] = {.lex_state = 75, .external_lex_state = 5},
  [4719] = {.lex_state = 75, .external_lex_state = 5},
  [4720] = {.lex_state = 75, .external_lex_state = 5},
  [4721] = {.lex_state = 75, .external_lex_state = 2},
  [4722] = {.lex_state = 75, .external_lex_state = 5},
  [4723] = {.lex_state = 75, .external_lex_state = 5},
  [4724] = {.lex_state = 75, .external_lex_state = 5},
  [4725] = {.lex_state = 75, .external_lex_state = 5},
  [4726] = {.lex_state = 75, .external_lex_state = 5},
  [4727] = {.lex_state = 75, .external_lex_state = 5},
  [4728] = {.lex_state = 75, .external_lex_state = 5},
  [4729] = {.lex_state = 75, .external_lex_state = 5},
  [4730] = {.lex_state = 75, .external_lex_state = 2},
  [4731] = {.lex_state = 75, .external_lex_state = 5},
  [4732] = {.lex_state = 75, .external_lex_state = 5},
  [4733] = {.lex_state = 75, .external_lex_state = 2},
  [4734] = {.lex_state = 75, .external_lex_state = 2},
  [4735] = {.lex_state = 75, .external_lex_state = 2},
  [4736] = {.lex_state = 75, .external_lex_state = 2},
  [4737] = {.lex_state = 75, .external_lex_state = 5},
  [4738] = {.lex_state = 75, .external_lex_state = 5},
  [4739] = {.lex_state = 75, .external_lex_state = 5},
  [4740] = {.lex_state = 75, .external_lex_state = 2},
  [4741] = {.lex_state = 75, .external_lex_state = 5},
  [4742] = {.lex_state = 75, .external_lex_state = 5},
  [4743] = {.lex_state = 75, .external_lex_state = 5},
  [4744] = {.lex_state = 75, .external_lex_state = 2},
  [4745] = {.lex_state = 75, .external_lex_state = 2},
  [4746] = {.lex_state = 75, .external_lex_state = 2},
  [4747] = {.lex_state = 75, .external_lex_state = 5},
  [4748] = {.lex_state = 75, .external_lex_state = 5},
  [4749] = {.lex_state = 75, .external_lex_state = 5},
  [4750] = {.lex_state = 75, .external_lex_state = 5},
  [4751] = {.lex_state = 75, .external_lex_state = 5},
  [4752] = {.lex_state = 75, .external_lex_state = 5},
  [4753] = {.lex_state = 75, .external_lex_state = 5},
  [4754] = {.lex_state = 75, .external_lex_state = 5},
  [4755] = {.lex_state = 75, .external_lex_state = 5},
  [4756] = {.lex_state = 75, .external_lex_state = 5},
  [4757] = {.lex_state = 75, .external_lex_state = 5},
  [4758] = {.lex_state = 75, .external_lex_state = 5},
  [4759] = {.lex_state = 75, .external_lex_state = 5},
  [4760] = {.lex_state = 75, .external_lex_state = 5},
  [4761] = {.lex_state = 75, .external_lex_state = 5},
  [4762] = {.lex_state = 75, .external_lex_state = 5},
  [4763] = {.lex_state = 75, .external_lex_state = 5},
  [4764] = {.lex_state = 75, .external_lex_state = 5},
  [4765] = {.lex_state = 75, .external_lex_state = 5},
  [4766] = {.lex_state = 75, .external_lex_state = 5},
  [4767] = {.lex_state = 75, .external_lex_state = 5},
  [4768] = {.lex_state = 75, .external_lex_state = 5},
  [4769] = {.lex_state = 75, .external_lex_state = 5},
  [4770] = {.lex_state = 75, .external_lex_state = 5},
  [4771] = {.lex_state = 75, .external_lex_state = 5},
  [4772] = {.lex_state = 75, .external_lex_state = 5},
  [4773] = {.lex_state = 75, .external_lex_state = 5},
  [4774] = {.lex_state = 75, .external_lex_state = 5},
  [4775] = {.lex_state = 75, .external_lex_state = 5},
  [4776] = {.lex_state = 75, .external_lex_state = 5},
  [4777] = {.lex_state = 75, .external_lex_state = 5},
  [4778] = {.lex_state = 75, .external_lex_state = 5},
  [4779] = {.lex_state = 75, .external_lex_state = 5},
  [4780] = {.lex_state = 2, .external_lex_state = 2},
  [4781] = {.lex_state = 75, .external_lex_state = 5},
  [4782] = {.lex_state = 75, .external_lex_state = 5},
  [4783] = {.lex_state = 75, .external_lex_state = 2},
  [4784] = {.lex_state = 75, .external_lex_state = 2},
  [4785] = {.lex_state = 75, .external_lex_state = 2},
  [4786] = {.lex_state = 75, .external_lex_state = 5},
  [4787] = {.lex_state = 75, .external_lex_state = 2},
  [4788] = {.lex_state = 75, .external_lex_state = 5},
  [4789] = {.lex_state = 75, .external_lex_state = 2},
  [4790] = {.lex_state = 75, .external_lex_state = 2},
  [4791] = {.lex_state = 75, .external_lex_state = 5},
  [4792] = {.lex_state = 75, .external_lex_state = 2},
  [4793] = {.lex_state = 75, .external_lex_state = 5},
  [4794] = {.lex_state = 75, .external_lex_state = 5},
  [4795] = {.lex_state = 75, .external_lex_state = 5},
  [4796] = {.lex_state = 75, .external_lex_state = 5},
  [4797] = {.lex_state = 75, .external_lex_state = 2},
  [4798] = {.lex_state = 75, .external_lex_state = 5},
  [4799] = {.lex_state = 75, .external_lex_state = 5},
  [4800] = {.lex_state = 75, .external_lex_state = 5},
  [4801] = {.lex_state = 75, .external_lex_state = 5},
  [4802] = {.lex_state = 75, .external_lex_state = 2},
  [4803] = {.lex_state = 75, .external_lex_state = 5},
  [4804] = {.lex_state = 75, .external_lex_state = 5},
  [4805] = {.lex_state = 75, .external_lex_state = 5},
  [4806] = {.lex_state = 75, .external_lex_state = 2},
  [4807] = {.lex_state = 75, .external_lex_state = 5},
  [4808] = {.lex_state = 75, .external_lex_state = 2},
  [4809] = {.lex_state = 75, .external_lex_state = 5},
  [4810] = {.lex_state = 75, .external_lex_state = 2},
  [4811] = {.lex_state = 75, .external_lex_state = 5},
  [4812] = {.lex_state = 75, .external_lex_state = 2},
  [4813] = {.lex_state = 75, .external_lex_state = 5},
  [4814] = {.lex_state = 75, .external_lex_state = 2},
  [4815] = {.lex_state = 75, .external_lex_state = 2},
  [4816] = {.lex_state = 75, .external_lex_state = 5},
  [4817] = {.lex_state = 75, .external_lex_state = 5},
  [4818] = {.lex_state = 75, .external_lex_state = 5},
  [4819] = {.lex_state = 75, .external_lex_state = 5},
  [4820] = {.lex_state = 75, .external_lex_state = 5},
  [4821] = {.lex_state = 75, .external_lex_state = 5},
  [4822] = {.lex_state = 75, .external_lex_state = 5},
  [4823] = {.lex_state = 75, .external_lex_state = 5},
  [4824] = {.lex_state = 75, .external_lex_state = 5},
  [4825] = {.lex_state = 75, .external_lex_state = 5},
  [4826] = {.lex_state = 75, .external_lex_state = 5},
  [4827] = {.lex_state = 75, .external_lex_state = 5},
  [4828] = {.lex_state = 75, .external_lex_state = 5},
  [4829] = {.lex_state = 75, .external_lex_state = 2},
  [4830] = {.lex_state = 75, .external_lex_state = 5},
  [4831] = {.lex_state = 75, .external_lex_state = 5},
  [4832] = {.lex_state = 75, .external_lex_state = 5},
  [4833] = {.lex_state = 75, .external_lex_state = 5},
  [4834] = {.lex_state = 75, .external_lex_state = 5},
  [4835] = {.lex_state = 75, .external_lex_state = 5},
  [4836] = {.lex_state = 75, .external_lex_state = 5},
  [4837] = {.lex_state = 75, .external_lex_state = 5},
  [4838] = {.lex_state = 75, .external_lex_state = 5},
  [4839] = {.lex_state = 75, .external_lex_state = 5},
  [4840] = {.lex_state = 75, .external_lex_state = 5},
  [4841] = {.lex_state = 75, .external_lex_state = 5},
  [4842] = {.lex_state = 75, .external_lex_state = 5},
  [4843] = {.lex_state = 75, .external_lex_state = 5},
  [4844] = {.lex_state = 75, .external_lex_state = 5},
  [4845] = {.lex_state = 75, .external_lex_state = 5},
  [4846] = {.lex_state = 75, .external_lex_state = 5},
  [4847] = {.lex_state = 75, .external_lex_state = 5},
  [4848] = {.lex_state = 75, .external_lex_state = 5},
  [4849] = {.lex_state = 75, .external_lex_state = 5},
  [4850] = {.lex_state = 75, .external_lex_state = 5},
  [4851] = {.lex_state = 75, .external_lex_state = 5},
  [4852] = {.lex_state = 75, .external_lex_state = 5},
  [4853] = {.lex_state = 75, .external_lex_state = 5},
  [4854] = {.lex_state = 75, .external_lex_state = 5},
  [4855] = {.lex_state = 75, .external_lex_state = 5},
  [4856] = {.lex_state = 75, .external_lex_state = 5},
  [4857] = {.lex_state = 75, .external_lex_state = 5},
  [4858] = {.lex_state = 75, .external_lex_state = 5},
  [4859] = {.lex_state = 75, .external_lex_state = 5},
  [4860] = {.lex_state = 75, .external_lex_state = 5},
  [4861] = {.lex_state = 75, .external_lex_state = 5},
  [4862] = {.lex_state = 75, .external_lex_state = 5},
  [4863] = {.lex_state = 75, .external_lex_state = 5},
  [4864] = {.lex_state = 75, .external_lex_state = 5},
  [4865] = {.lex_state = 75, .external_lex_state = 5},
  [4866] = {.lex_state = 75, .external_lex_state = 5},
  [4867] = {.lex_state = 75, .external_lex_state = 5},
  [4868] = {.lex_state = 75, .external_lex_state = 5},
  [4869] = {.lex_state = 75, .external_lex_state = 2},
  [4870] = {.lex_state = 75, .external_lex_state = 5},
  [4871] = {.lex_state = 75, .external_lex_state = 5},
  [4872] = {.lex_state = 75, .external_lex_state = 5},
  [4873] = {.lex_state = 75, .external_lex_state = 5},
  [4874] = {.lex_state = 75, .external_lex_state = 5},
  [4875] = {.lex_state = 75, .external_lex_state = 5},
  [4876] = {.lex_state = 75, .external_lex_state = 5},
  [4877] = {.lex_state = 75, .external_lex_state = 5},
  [4878] = {.lex_state = 75, .external_lex_state = 2},
  [4879] = {.lex_state = 75, .external_lex_state = 2},
  [4880] = {.lex_state = 75, .external_lex_state = 5},
  [4881] = {.lex_state = 75, .external_lex_state = 2},
  [4882] = {.lex_state = 75, .external_lex_state = 5},
  [4883] = {.lex_state = 75, .external_lex_state = 5},
  [4884] = {.lex_state = 75, .external_lex_state = 5},
  [4885] = {.lex_state = 75, .external_lex_state = 5},
  [4886] = {.lex_state = 75, .external_lex_state = 5},
  [4887] = {.lex_state = 75, .external_lex_state = 2},
  [4888] = {.lex_state = 75, .external_lex_state = 5},
  [4889] = {.lex_state = 75, .external_lex_state = 5},
  [4890] = {.lex_state = 75, .external_lex_state = 2},
  [4891] = {.lex_state = 2, .external_lex_state = 2},
  [4892] = {.lex_state = 75, .external_lex_state = 5},
  [4893] = {.lex_state = 75, .external_lex_state = 5},
  [4894] = {.lex_state = 75, .external_lex_state = 2},
  [4895] = {.lex_state = 75, .external_lex_state = 5},
  [4896] = {.lex_state = 75, .external_lex_state = 2},
  [4897] = {.lex_state = 75, .external_lex_state = 2},
  [4898] = {.lex_state = 75, .external_lex_state = 5},
  [4899] = {.lex_state = 75, .external_lex_state = 2},
  [4900] = {.lex_state = 75, .external_lex_state = 5},
  [4901] = {.lex_state = 75, .external_lex_state = 5},
  [4902] = {.lex_state = 75, .external_lex_state = 5},
  [4903] = {.lex_state = 75, .external_lex_state = 5},
  [4904] = {.lex_state = 75, .external_lex_state = 5},
  [4905] = {.lex_state = 75, .external_lex_state = 2},
  [4906] = {.lex_state = 75, .external_lex_state = 5},
  [4907] = {.lex_state = 75, .external_lex_state = 5},
  [4908] = {.lex_state = 75, .external_lex_state = 2},
  [4909] = {.lex_state = 75, .external_lex_state = 5},
  [4910] = {.lex_state = 75, .external_lex_state = 2},
  [4911] = {.lex_state = 75, .external_lex_state = 5},
  [4912] = {.lex_state = 75, .external_lex_state = 5},
  [4913] = {.lex_state = 75, .external_lex_state = 5},
  [4914] = {.lex_state = 75, .external_lex_state = 5},
  [4915] = {.lex_state = 75, .external_lex_state = 5},
  [4916] = {.lex_state = 75, .external_lex_state = 5},
  [4917] = {.lex_state = 75, .external_lex_state = 5},
  [4918] = {.lex_state = 75, .external_lex_state = 5},
  [4919] = {.lex_state = 75, .external_lex_state = 5},
  [4920] = {.lex_state = 75, .external_lex_state = 5},
  [4921] = {.lex_state = 75, .external_lex_state = 5},
  [4922] = {.lex_state = 75, .external_lex_state = 5},
  [4923] = {.lex_state = 75, .external_lex_state = 5},
  [4924] = {.lex_state = 75, .external_lex_state = 5},
  [4925] = {.lex_state = 75, .external_lex_state = 2},
  [4926] = {.lex_state = 75, .external_lex_state = 5},
  [4927] = {.lex_state = 75, .external_lex_state = 2},
  [4928] = {.lex_state = 75, .external_lex_state = 5},
  [4929] = {.lex_state = 75, .external_lex_state = 5},
  [4930] = {.lex_state = 75, .external_lex_state = 2},
  [4931] = {.lex_state = 75, .external_lex_state = 5},
  [4932] = {.lex_state = 75, .external_lex_state = 5},
  [4933] = {.lex_state = 75, .external_lex_state = 5},
  [4934] = {.lex_state = 75, .external_lex_state = 5},
  [4935] = {.lex_state = 75, .external_lex_state = 2},
  [4936] = {.lex_state = 75, .external_lex_state = 5},
  [4937] = {.lex_state = 75, .external_lex_state = 5},
  [4938] = {.lex_state = 75, .external_lex_state = 5},
  [4939] = {.lex_state = 75, .external_lex_state = 2},
  [4940] = {.lex_state = 75, .external_lex_state = 5},
  [4941] = {.lex_state = 75, .external_lex_state = 5},
  [4942] = {.lex_state = 75, .external_lex_state = 5},
  [4943] = {.lex_state = 75, .external_lex_state = 5},
  [4944] = {.lex_state = 75, .external_lex_state = 5},
  [4945] = {.lex_state = 75, .external_lex_state = 5},
  [4946] = {.lex_state = 75, .external_lex_state = 2},
  [4947] = {.lex_state = 75, .external_lex_state = 5},
  [4948] = {.lex_state = 75, .external_lex_state = 5},
  [4949] = {.lex_state = 75, .external_lex_state = 2},
  [4950] = {.lex_state = 75, .external_lex_state = 2},
  [4951] = {.lex_state = 75, .external_lex_state = 5},
  [4952] = {.lex_state = 13, .external_lex_state = 8},
  [4953] = {.lex_state = 75, .external_lex_state = 5},
  [4954] = {.lex_state = 75, .external_lex_state = 5},
  [4955] = {.lex_state = 75, .external_lex_state = 2},
  [4956] = {.lex_state = 75, .external_lex_state = 2},
  [4957] = {.lex_state = 75, .external_lex_state = 5},
  [4958] = {.lex_state = 75, .external_lex_state = 2},
  [4959] = {.lex_state = 75, .external_lex_state = 2},
  [4960] = {.lex_state = 75, .external_lex_state = 2},
  [4961] = {.lex_state = 75, .external_lex_state = 2},
  [4962] = {.lex_state = 75, .external_lex_state = 2},
  [4963] = {.lex_state = 75, .external_lex_state = 5},
  [4964] = {.lex_state = 75, .external_lex_state = 2},
  [4965] = {.lex_state = 75, .external_lex_state = 2},
  [4966] = {.lex_state = 75, .external_lex_state = 2},
  [4967] = {.lex_state = 75, .external_lex_state = 2},
  [4968] = {.lex_state = 75, .external_lex_state = 5},
  [4969] = {.lex_state = 75, .external_lex_state = 2},
  [4970] = {.lex_state = 75, .external_lex_state = 5},
  [4971] = {.lex_state = 75, .external_lex_state = 2},
  [4972] = {.lex_state = 75, .external_lex_state = 2},
  [4973] = {.lex_state = 75, .external_lex_state = 2},
  [4974] = {.lex_state = 75, .external_lex_state = 2},
  [4975] = {.lex_state = 75, .external_lex_state = 2},
  [4976] = {.lex_state = 75, .external_lex_state = 5},
  [4977] = {.lex_state = 75, .external_lex_state = 2},
  [4978] = {.lex_state = 75, .external_lex_state = 5},
  [4979] = {.lex_state = 75, .external_lex_state = 5},
  [4980] = {.lex_state = 75, .external_lex_state = 2},
  [4981] = {.lex_state = 75, .external_lex_state = 2},
  [4982] = {.lex_state = 75, .external_lex_state = 2},
  [4983] = {.lex_state = 75, .external_lex_state = 5},
  [4984] = {.lex_state = 75, .external_lex_state = 5},
  [4985] = {.lex_state = 75, .external_lex_state = 5},
  [4986] = {.lex_state = 75, .external_lex_state = 5},
  [4987] = {.lex_state = 75, .external_lex_state = 2},
  [4988] = {.lex_state = 75, .external_lex_state = 5},
  [4989] = {.lex_state = 75, .external_lex_state = 2},
  [4990] = {.lex_state = 75, .external_lex_state = 2},
  [4991] = {.lex_state = 75, .external_lex_state = 5},
  [4992] = {.lex_state = 75, .external_lex_state = 2},
  [4993] = {.lex_state = 75, .external_lex_state = 2},
  [4994] = {.lex_state = 75, .external_lex_state = 2},
  [4995] = {.lex_state = 75, .external_lex_state = 5},
  [4996] = {.lex_state = 75, .external_lex_state = 2},
  [4997] = {.lex_state = 75, .external_lex_state = 2},
  [4998] = {.lex_state = 75, .external_lex_state = 2},
  [4999] = {.lex_state = 75, .external_lex_state = 2},
  [5000] = {.lex_state = 75, .external_lex_state = 2},
  [5001] = {.lex_state = 75, .external_lex_state = 2},
  [5002] = {.lex_state = 75, .external_lex_state = 5},
  [5003] = {.lex_state = 75, .external_lex_state = 2},
  [5004] = {.lex_state = 75, .external_lex_state = 2},
  [5005] = {.lex_state = 75, .external_lex_state = 2},
  [5006] = {.lex_state = 75, .external_lex_state = 2},
  [5007] = {.lex_state = 75, .external_lex_state = 5},
  [5008] = {.lex_state = 75, .external_lex_state = 2},
  [5009] = {.lex_state = 75, .external_lex_state = 5},
  [5010] = {.lex_state = 75, .external_lex_state = 5},
  [5011] = {.lex_state = 75, .external_lex_state = 2},
  [5012] = {.lex_state = 75, .external_lex_state = 5},
  [5013] = {.lex_state = 75, .external_lex_state = 2},
  [5014] = {.lex_state = 75, .external_lex_state = 2},
  [5015] = {.lex_state = 75, .external_lex_state = 5},
  [5016] = {.lex_state = 75, .external_lex_state = 2},
  [5017] = {.lex_state = 75, .external_lex_state = 5},
  [5018] = {.lex_state = 75, .external_lex_state = 2},
  [5019] = {.lex_state = 75, .external_lex_state = 2},
  [5020] = {.lex_state = 75, .external_lex_state = 2},
  [5021] = {.lex_state = 75, .external_lex_state = 5},
  [5022] = {.lex_state = 75, .external_lex_state = 2},
  [5023] = {.lex_state = 75, .external_lex_state = 2},
  [5024] = {.lex_state = 75, .external_lex_state = 5},
  [5025] = {.lex_state = 75, .external_lex_state = 5},
  [5026] = {.lex_state = 75, .external_lex_state = 2},
  [5027] = {.lex_state = 75, .external_lex_state = 2},
  [5028] = {.lex_state = 75, .external_lex_state = 5},
  [5029] = {.lex_state = 75, .external_lex_state = 2},
  [5030] = {.lex_state = 75, .external_lex_state = 2},
  [5031] = {.lex_state = 75, .external_lex_state = 5},
  [5032] = {.lex_state = 75, .external_lex_state = 2},
  [5033] = {.lex_state = 75, .external_lex_state = 2},
  [5034] = {.lex_state = 75, .external_lex_state = 5},
  [5035] = {.lex_state = 75, .external_lex_state = 5},
  [5036] = {.lex_state = 75, .external_lex_state = 5},
  [5037] = {.lex_state = 75, .external_lex_state = 5},
  [5038] = {.lex_state = 75, .external_lex_state = 2},
  [5039] = {.lex_state = 75, .external_lex_state = 5},
  [5040] = {.lex_state = 75, .external_lex_state = 5},
  [5041] = {.lex_state = 75, .external_lex_state = 5},
  [5042] = {.lex_state = 75, .external_lex_state = 5},
  [5043] = {.lex_state = 75, .external_lex_state = 5},
  [5044] = {.lex_state = 75, .external_lex_state = 5},
  [5045] = {.lex_state = 75, .external_lex_state = 5},
  [5046] = {.lex_state = 75, .external_lex_state = 5},
  [5047] = {.lex_state = 75, .external_lex_state = 5},
  [5048] = {.lex_state = 75, .external_lex_state = 5},
  [5049] = {.lex_state = 75, .external_lex_state = 5},
  [5050] = {.lex_state = 75, .external_lex_state = 5},
  [5051] = {.lex_state = 75, .external_lex_state = 5},
  [5052] = {.lex_state = 75, .external_lex_state = 2},
  [5053] = {.lex_state = 75, .external_lex_state = 5},
  [5054] = {.lex_state = 75, .external_lex_state = 5},
  [5055] = {.lex_state = 75, .external_lex_state = 5},
  [5056] = {.lex_state = 75, .external_lex_state = 5},
  [5057] = {.lex_state = 75, .external_lex_state = 5},
  [5058] = {.lex_state = 75, .external_lex_state = 5},
  [5059] = {.lex_state = 75, .external_lex_state = 5},
  [5060] = {.lex_state = 75, .external_lex_state = 5},
  [5061] = {.lex_state = 75, .external_lex_state = 5},
  [5062] = {.lex_state = 75, .external_lex_state = 2},
  [5063] = {.lex_state = 75, .external_lex_state = 5},
  [5064] = {.lex_state = 75, .external_lex_state = 5},
  [5065] = {.lex_state = 75, .external_lex_state = 5},
  [5066] = {.lex_state = 75, .external_lex_state = 5},
  [5067] = {.lex_state = 75, .external_lex_state = 5},
  [5068] = {.lex_state = 75, .external_lex_state = 5},
  [5069] = {.lex_state = 75, .external_lex_state = 5},
  [5070] = {.lex_state = 75, .external_lex_state = 5},
  [5071] = {.lex_state = 75, .external_lex_state = 5},
  [5072] = {.lex_state = 75, .external_lex_state = 5},
  [5073] = {.lex_state = 75, .external_lex_state = 5},
  [5074] = {.lex_state = 75, .external_lex_state = 5},
  [5075] = {.lex_state = 2, .external_lex_state = 2},
  [5076] = {.lex_state = 2, .external_lex_state = 2},
  [5077] = {.lex_state = 75, .external_lex_state = 5},
  [5078] = {.lex_state = 75, .external_lex_state = 5},
  [5079] = {.lex_state = 75, .external_lex_state = 5},
  [5080] = {.lex_state = 75, .external_lex_state = 2},
  [5081] = {.lex_state = 75, .external_lex_state = 5},
  [5082] = {.lex_state = 75, .external_lex_state = 5},
  [5083] = {.lex_state = 75, .external_lex_state = 5},
  [5084] = {.lex_state = 75, .external_lex_state = 5},
  [5085] = {.lex_state = 75, .external_lex_state = 5},
  [5086] = {.lex_state = 75, .external_lex_state = 5},
  [5087] = {.lex_state = 75, .external_lex_state = 5},
  [5088] = {.lex_state = 75, .external_lex_state = 5},
  [5089] = {.lex_state = 75, .external_lex_state = 5},
  [5090] = {.lex_state = 75, .external_lex_state = 5},
  [5091] = {.lex_state = 75, .external_lex_state = 5},
  [5092] = {.lex_state = 75, .external_lex_state = 5},
  [5093] = {.lex_state = 75, .external_lex_state = 5},
  [5094] = {.lex_state = 75, .external_lex_state = 5},
  [5095] = {.lex_state = 75, .external_lex_state = 5},
  [5096] = {.lex_state = 75, .external_lex_state = 2},
  [5097] = {.lex_state = 75, .external_lex_state = 5},
  [5098] = {.lex_state = 75, .external_lex_state = 5},
  [5099] = {.lex_state = 75, .external_lex_state = 5},
  [5100] = {.lex_state = 75, .external_lex_state = 5},
  [5101] = {.lex_state = 75, .external_lex_state = 5},
  [5102] = {.lex_state = 75, .external_lex_state = 5},
  [5103] = {.lex_state = 75, .external_lex_state = 5},
  [5104] = {.lex_state = 75, .external_lex_state = 5},
  [5105] = {.lex_state = 75, .external_lex_state = 5},
  [5106] = {.lex_state = 2, .external_lex_state = 2},
  [5107] = {.lex_state = 75, .external_lex_state = 5},
  [5108] = {.lex_state = 2, .external_lex_state = 2},
  [5109] = {.lex_state = 75, .external_lex_state = 5},
  [5110] = {.lex_state = 75, .external_lex_state = 5},
  [5111] = {.lex_state = 75, .external_lex_state = 5},
  [5112] = {.lex_state = 75, .external_lex_state = 5},
  [5113] = {.lex_state = 75, .external_lex_state = 5},
  [5114] = {.lex_state = 75, .external_lex_state = 5},
  [5115] = {.lex_state = 75, .external_lex_state = 2},
  [5116] = {.lex_state = 75, .external_lex_state = 2},
  [5117] = {.lex_state = 75, .external_lex_state = 5},
  [5118] = {.lex_state = 75, .external_lex_state = 5},
  [5119] = {.lex_state = 75, .external_lex_state = 5},
  [5120] = {.lex_state = 75, .external_lex_state = 5},
  [5121] = {.lex_state = 75, .external_lex_state = 2},
  [5122] = {.lex_state = 75, .external_lex_state = 5},
  [5123] = {.lex_state = 75, .external_lex_state = 5},
  [5124] = {.lex_state = 75, .external_lex_state = 5},
  [5125] = {.lex_state = 75, .external_lex_state = 2},
  [5126] = {.lex_state = 75, .external_lex_state = 2},
  [5127] = {.lex_state = 75, .external_lex_state = 2},
  [5128] = {.lex_state = 75, .external_lex_state = 2},
  [5129] = {.lex_state = 75, .external_lex_state = 5},
  [5130] = {.lex_state = 75, .external_lex_state = 2},
  [5131] = {.lex_state = 75, .external_lex_state = 2},
  [5132] = {.lex_state = 75, .external_lex_state = 2},
  [5133] = {.lex_state = 75, .external_lex_state = 2},
  [5134] = {.lex_state = 75, .external_lex_state = 2},
  [5135] = {.lex_state = 75, .external_lex_state = 2},
  [5136] = {.lex_state = 75, .external_lex_state = 2},
  [5137] = {.lex_state = 75, .external_lex_state = 2},
  [5138] = {.lex_state = 75, .external_lex_state = 2},
  [5139] = {.lex_state = 75, .external_lex_state = 2},
  [5140] = {.lex_state = 75, .external_lex_state = 2},
  [5141] = {.lex_state = 75, .external_lex_state = 2},
  [5142] = {.lex_state = 75, .external_lex_state = 2},
  [5143] = {.lex_state = 75, .external_lex_state = 2},
  [5144] = {.lex_state = 75, .external_lex_state = 2},
  [5145] = {.lex_state = 75, .external_lex_state = 2},
  [5146] = {.lex_state = 75, .external_lex_state = 2},
  [5147] = {.lex_state = 75, .external_lex_state = 2},
  [5148] = {.lex_state = 75, .external_lex_state = 2},
  [5149] = {.lex_state = 75, .external_lex_state = 2},
  [5150] = {.lex_state = 75, .external_lex_state = 2},
  [5151] = {.lex_state = 75, .external_lex_state = 2},
  [5152] = {.lex_state = 75, .external_lex_state = 2},
  [5153] = {.lex_state = 75, .external_lex_state = 2},
  [5154] = {.lex_state = 75, .external_lex_state = 2},
  [5155] = {.lex_state = 75, .external_lex_state = 2},
  [5156] = {.lex_state = 75, .external_lex_state = 2},
  [5157] = {.lex_state = 75, .external_lex_state = 2},
  [5158] = {.lex_state = 75, .external_lex_state = 2},
  [5159] = {.lex_state = 75, .external_lex_state = 2},
  [5160] = {.lex_state = 75, .external_lex_state = 2},
  [5161] = {.lex_state = 75, .external_lex_state = 5},
  [5162] = {.lex_state = 75, .external_lex_state = 2},
  [5163] = {.lex_state = 75, .external_lex_state = 2},
  [5164] = {.lex_state = 75, .external_lex_state = 2},
  [5165] = {.lex_state = 75, .external_lex_state = 2},
  [5166] = {.lex_state = 75, .external_lex_state = 2},
  [5167] = {.lex_state = 75, .external_lex_state = 2},
  [5168] = {.lex_state = 75, .external_lex_state = 2},
  [5169] = {.lex_state = 75, .external_lex_state = 2},
  [5170] = {.lex_state = 75, .external_lex_state = 2},
  [5171] = {.lex_state = 75, .external_lex_state = 2},
  [5172] = {.lex_state = 75, .external_lex_state = 5},
  [5173] = {.lex_state = 75, .external_lex_state = 2},
  [5174] = {.lex_state = 75, .external_lex_state = 2},
  [5175] = {.lex_state = 75, .external_lex_state = 2},
  [5176] = {.lex_state = 75, .external_lex_state = 2},
  [5177] = {.lex_state = 75, .external_lex_state = 2},
  [5178] = {.lex_state = 75, .external_lex_state = 2},
  [5179] = {.lex_state = 75, .external_lex_state = 2},
  [5180] = {.lex_state = 75, .external_lex_state = 2},
  [5181] = {.lex_state = 75, .external_lex_state = 2},
  [5182] = {.lex_state = 75, .external_lex_state = 2},
  [5183] = {.lex_state = 75, .external_lex_state = 2},
  [5184] = {.lex_state = 75, .external_lex_state = 2},
  [5185] = {.lex_state = 75, .external_lex_state = 2},
  [5186] = {.lex_state = 75, .external_lex_state = 2},
  [5187] = {.lex_state = 75, .external_lex_state = 2},
  [5188] = {.lex_state = 75, .external_lex_state = 2},
  [5189] = {.lex_state = 75, .external_lex_state = 2},
  [5190] = {.lex_state = 75, .external_lex_state = 2},
  [5191] = {.lex_state = 75, .external_lex_state = 2},
  [5192] = {.lex_state = 75, .external_lex_state = 2},
  [5193] = {.lex_state = 75, .external_lex_state = 2},
  [5194] = {.lex_state = 75, .external_lex_state = 5},
  [5195] = {.lex_state = 75, .external_lex_state = 5},
  [5196] = {.lex_state = 75, .external_lex_state = 2},
  [5197] = {.lex_state = 75, .external_lex_state = 5},
  [5198] = {.lex_state = 75, .external_lex_state = 2},
  [5199] = {.lex_state = 75, .external_lex_state = 2},
  [5200] = {.lex_state = 75, .external_lex_state = 2},
  [5201] = {.lex_state = 75, .external_lex_state = 2},
  [5202] = {.lex_state = 75, .external_lex_state = 2},
  [5203] = {.lex_state = 75, .external_lex_state = 5},
  [5204] = {.lex_state = 75, .external_lex_state = 2},
  [5205] = {.lex_state = 75, .external_lex_state = 2},
  [5206] = {.lex_state = 75, .external_lex_state = 2},
  [5207] = {.lex_state = 75, .external_lex_state = 5},
  [5208] = {.lex_state = 75, .external_lex_state = 2},
  [5209] = {.lex_state = 75, .external_lex_state = 2},
  [5210] = {.lex_state = 75, .external_lex_state = 2},
  [5211] = {.lex_state = 75, .external_lex_state = 2},
  [5212] = {.lex_state = 75, .external_lex_state = 2},
  [5213] = {.lex_state = 75, .external_lex_state = 2},
  [5214] = {.lex_state = 75, .external_lex_state = 2},
  [5215] = {.lex_state = 75, .external_lex_state = 2},
  [5216] = {.lex_state = 75, .external_lex_state = 2},
  [5217] = {.lex_state = 75, .external_lex_state = 2},
  [5218] = {.lex_state = 75, .external_lex_state = 2},
  [5219] = {.lex_state = 75, .external_lex_state = 2},
  [5220] = {.lex_state = 75, .external_lex_state = 2},
  [5221] = {.lex_state = 75, .external_lex_state = 2},
  [5222] = {.lex_state = 75, .external_lex_state = 2},
  [5223] = {.lex_state = 75, .external_lex_state = 2},
  [5224] = {.lex_state = 75, .external_lex_state = 2},
  [5225] = {.lex_state = 75, .external_lex_state = 2},
  [5226] = {.lex_state = 75, .external_lex_state = 2},
  [5227] = {.lex_state = 75, .external_lex_state = 2},
  [5228] = {.lex_state = 75, .external_lex_state = 2},
  [5229] = {.lex_state = 75, .external_lex_state = 2},
  [5230] = {.lex_state = 75, .external_lex_state = 2},
  [5231] = {.lex_state = 75, .external_lex_state = 2},
  [5232] = {.lex_state = 75, .external_lex_state = 2},
  [5233] = {.lex_state = 75, .external_lex_state = 2},
  [5234] = {.lex_state = 75, .external_lex_state = 2},
  [5235] = {.lex_state = 75, .external_lex_state = 2},
  [5236] = {.lex_state = 75, .external_lex_state = 2},
  [5237] = {.lex_state = 75, .external_lex_state = 2},
  [5238] = {.lex_state = 75, .external_lex_state = 2},
  [5239] = {.lex_state = 75, .external_lex_state = 2},
  [5240] = {.lex_state = 75, .external_lex_state = 2},
  [5241] = {.lex_state = 75, .external_lex_state = 2},
  [5242] = {.lex_state = 75, .external_lex_state = 2},
  [5243] = {.lex_state = 75, .external_lex_state = 2},
  [5244] = {.lex_state = 75, .external_lex_state = 2},
  [5245] = {.lex_state = 75, .external_lex_state = 5},
  [5246] = {.lex_state = 75, .external_lex_state = 2},
  [5247] = {.lex_state = 75, .external_lex_state = 2},
  [5248] = {.lex_state = 75, .external_lex_state = 2},
  [5249] = {.lex_state = 75, .external_lex_state = 2},
  [5250] = {.lex_state = 75, .external_lex_state = 2},
  [5251] = {.lex_state = 75, .external_lex_state = 2},
  [5252] = {.lex_state = 75, .external_lex_state = 2},
  [5253] = {.lex_state = 75, .external_lex_state = 2},
  [5254] = {.lex_state = 75, .external_lex_state = 2},
  [5255] = {.lex_state = 75, .external_lex_state = 2},
  [5256] = {.lex_state = 75, .external_lex_state = 2},
  [5257] = {.lex_state = 75, .external_lex_state = 2},
  [5258] = {.lex_state = 75, .external_lex_state = 2},
  [5259] = {.lex_state = 75, .external_lex_state = 2},
  [5260] = {.lex_state = 75, .external_lex_state = 2},
  [5261] = {.lex_state = 75, .external_lex_state = 2},
  [5262] = {.lex_state = 75, .external_lex_state = 2},
  [5263] = {.lex_state = 75, .external_lex_state = 2},
  [5264] = {.lex_state = 75, .external_lex_state = 2},
  [5265] = {.lex_state = 75, .external_lex_state = 2},
  [5266] = {.lex_state = 75, .external_lex_state = 2},
  [5267] = {.lex_state = 75, .external_lex_state = 2},
  [5268] = {.lex_state = 75, .external_lex_state = 2},
  [5269] = {.lex_state = 75, .external_lex_state = 2},
  [5270] = {.lex_state = 75, .external_lex_state = 2},
  [5271] = {.lex_state = 75, .external_lex_state = 2},
  [5272] = {.lex_state = 75, .external_lex_state = 2},
  [5273] = {.lex_state = 75, .external_lex_state = 2},
  [5274] = {.lex_state = 75, .external_lex_state = 2},
  [5275] = {.lex_state = 75, .external_lex_state = 2},
  [5276] = {.lex_state = 75, .external_lex_state = 2},
  [5277] = {.lex_state = 75, .external_lex_state = 2},
  [5278] = {.lex_state = 75, .external_lex_state = 2},
  [5279] = {.lex_state = 75, .external_lex_state = 2},
  [5280] = {.lex_state = 75, .external_lex_state = 2},
  [5281] = {.lex_state = 75, .external_lex_state = 2},
  [5282] = {.lex_state = 75, .external_lex_state = 2},
  [5283] = {.lex_state = 75, .external_lex_state = 2},
  [5284] = {.lex_state = 75, .external_lex_state = 5},
  [5285] = {.lex_state = 75, .external_lex_state = 2},
  [5286] = {.lex_state = 75, .external_lex_state = 2},
  [5287] = {.lex_state = 75, .external_lex_state = 2},
  [5288] = {.lex_state = 75, .external_lex_state = 2},
  [5289] = {.lex_state = 75, .external_lex_state = 2},
  [5290] = {.lex_state = 75, .external_lex_state = 2},
  [5291] = {.lex_state = 75, .external_lex_state = 2},
  [5292] = {.lex_state = 75, .external_lex_state = 2},
  [5293] = {.lex_state = 75, .external_lex_state = 2},
  [5294] = {.lex_state = 75, .external_lex_state = 2},
  [5295] = {.lex_state = 75, .external_lex_state = 2},
  [5296] = {.lex_state = 75, .external_lex_state = 2},
  [5297] = {.lex_state = 75, .external_lex_state = 2},
  [5298] = {.lex_state = 75, .external_lex_state = 2},
  [5299] = {.lex_state = 75, .external_lex_state = 2},
  [5300] = {.lex_state = 75, .external_lex_state = 2},
  [5301] = {.lex_state = 75, .external_lex_state = 2},
  [5302] = {.lex_state = 75, .external_lex_state = 2},
  [5303] = {.lex_state = 75, .external_lex_state = 2},
  [5304] = {.lex_state = 75, .external_lex_state = 2},
  [5305] = {.lex_state = 75, .external_lex_state = 5},
  [5306] = {.lex_state = 75, .external_lex_state = 2},
  [5307] = {.lex_state = 75, .external_lex_state = 2},
  [5308] = {.lex_state = 75, .external_lex_state = 2},
  [5309] = {.lex_state = 75, .external_lex_state = 5},
  [5310] = {.lex_state = 75, .external_lex_state = 2},
  [5311] = {.lex_state = 75, .external_lex_state = 2},
  [5312] = {.lex_state = 75, .external_lex_state = 2},
  [5313] = {.lex_state = 75, .external_lex_state = 2},
  [5314] = {.lex_state = 75, .external_lex_state = 2},
  [5315] = {.lex_state = 75, .external_lex_state = 2},
  [5316] = {.lex_state = 75, .external_lex_state = 2},
  [5317] = {.lex_state = 75, .external_lex_state = 2},
  [5318] = {.lex_state = 75, .external_lex_state = 2},
  [5319] = {.lex_state = 75, .external_lex_state = 2},
  [5320] = {.lex_state = 75, .external_lex_state = 2},
  [5321] = {.lex_state = 75, .external_lex_state = 2},
  [5322] = {.lex_state = 75, .external_lex_state = 2},
  [5323] = {.lex_state = 75, .external_lex_state = 2},
  [5324] = {.lex_state = 75, .external_lex_state = 2},
  [5325] = {.lex_state = 75, .external_lex_state = 2},
  [5326] = {.lex_state = 75, .external_lex_state = 2},
  [5327] = {.lex_state = 75, .external_lex_state = 2},
  [5328] = {.lex_state = 75, .external_lex_state = 2},
  [5329] = {.lex_state = 75, .external_lex_state = 2},
  [5330] = {.lex_state = 75, .external_lex_state = 2},
  [5331] = {.lex_state = 75, .external_lex_state = 5},
  [5332] = {.lex_state = 75, .external_lex_state = 2},
  [5333] = {.lex_state = 75, .external_lex_state = 5},
  [5334] = {.lex_state = 75, .external_lex_state = 5},
  [5335] = {.lex_state = 75, .external_lex_state = 2},
  [5336] = {.lex_state = 75, .external_lex_state = 2},
  [5337] = {.lex_state = 75, .external_lex_state = 2},
  [5338] = {.lex_state = 75, .external_lex_state = 2},
  [5339] = {.lex_state = 75, .external_lex_state = 2},
  [5340] = {.lex_state = 75, .external_lex_state = 2},
  [5341] = {.lex_state = 75, .external_lex_state = 2},
  [5342] = {.lex_state = 75, .external_lex_state = 2},
  [5343] = {.lex_state = 75, .external_lex_state = 2},
  [5344] = {.lex_state = 75, .external_lex_state = 2},
  [5345] = {.lex_state = 75, .external_lex_state = 2},
  [5346] = {.lex_state = 75, .external_lex_state = 2},
  [5347] = {.lex_state = 75, .external_lex_state = 2},
  [5348] = {.lex_state = 75, .external_lex_state = 2},
  [5349] = {.lex_state = 75, .external_lex_state = 2},
  [5350] = {.lex_state = 75, .external_lex_state = 2},
  [5351] = {.lex_state = 75, .external_lex_state = 2},
  [5352] = {.lex_state = 75, .external_lex_state = 2},
  [5353] = {.lex_state = 75, .external_lex_state = 2},
  [5354] = {.lex_state = 75, .external_lex_state = 2},
  [5355] = {.lex_state = 75, .external_lex_state = 2},
  [5356] = {.lex_state = 75, .external_lex_state = 5},
  [5357] = {.lex_state = 75, .external_lex_state = 2},
  [5358] = {.lex_state = 75, .external_lex_state = 2},
  [5359] = {.lex_state = 75, .external_lex_state = 5},
  [5360] = {.lex_state = 75, .external_lex_state = 2},
  [5361] = {.lex_state = 75, .external_lex_state = 2},
  [5362] = {.lex_state = 75, .external_lex_state = 2},
  [5363] = {.lex_state = 75, .external_lex_state = 2},
  [5364] = {.lex_state = 75, .external_lex_state = 2},
  [5365] = {.lex_state = 75, .external_lex_state = 2},
  [5366] = {.lex_state = 75, .external_lex_state = 2},
  [5367] = {.lex_state = 75, .external_lex_state = 2},
  [5368] = {.lex_state = 75, .external_lex_state = 2},
  [5369] = {.lex_state = 75, .external_lex_state = 2},
  [5370] = {.lex_state = 75, .external_lex_state = 2},
  [5371] = {.lex_state = 75, .external_lex_state = 5},
  [5372] = {.lex_state = 75, .external_lex_state = 2},
  [5373] = {.lex_state = 75, .external_lex_state = 2},
  [5374] = {.lex_state = 75, .external_lex_state = 2},
  [5375] = {.lex_state = 75, .external_lex_state = 2},
  [5376] = {.lex_state = 75, .external_lex_state = 2},
  [5377] = {.lex_state = 75, .external_lex_state = 2},
  [5378] = {.lex_state = 75, .external_lex_state = 2},
  [5379] = {.lex_state = 75, .external_lex_state = 2},
  [5380] = {.lex_state = 75, .external_lex_state = 2},
  [5381] = {.lex_state = 75, .external_lex_state = 2},
  [5382] = {.lex_state = 75, .external_lex_state = 2},
  [5383] = {.lex_state = 75, .external_lex_state = 5},
  [5384] = {.lex_state = 75, .external_lex_state = 2},
  [5385] = {.lex_state = 75, .external_lex_state = 2},
  [5386] = {.lex_state = 75, .external_lex_state = 2},
  [5387] = {.lex_state = 75, .external_lex_state = 2},
  [5388] = {.lex_state = 75, .external_lex_state = 2},
  [5389] = {.lex_state = 75, .external_lex_state = 2},
  [5390] = {.lex_state = 75, .external_lex_state = 2},
  [5391] = {.lex_state = 75, .external_lex_state = 2},
  [5392] = {.lex_state = 75, .external_lex_state = 2},
  [5393] = {.lex_state = 75, .external_lex_state = 2},
  [5394] = {.lex_state = 75, .external_lex_state = 2},
  [5395] = {.lex_state = 75, .external_lex_state = 2},
  [5396] = {.lex_state = 75, .external_lex_state = 2},
  [5397] = {.lex_state = 75, .external_lex_state = 2},
  [5398] = {.lex_state = 75, .external_lex_state = 5},
  [5399] = {.lex_state = 75, .external_lex_state = 2},
  [5400] = {.lex_state = 75, .external_lex_state = 5},
  [5401] = {.lex_state = 75, .external_lex_state = 2},
  [5402] = {.lex_state = 75, .external_lex_state = 2},
  [5403] = {.lex_state = 75, .external_lex_state = 2},
  [5404] = {.lex_state = 75, .external_lex_state = 2},
  [5405] = {.lex_state = 75, .external_lex_state = 2},
  [5406] = {.lex_state = 75, .external_lex_state = 2},
  [5407] = {.lex_state = 75, .external_lex_state = 2},
  [5408] = {.lex_state = 75, .external_lex_state = 2},
  [5409] = {.lex_state = 75, .external_lex_state = 2},
  [5410] = {.lex_state = 75, .external_lex_state = 2},
  [5411] = {.lex_state = 75, .external_lex_state = 2},
  [5412] = {.lex_state = 75, .external_lex_state = 2},
  [5413] = {.lex_state = 75, .external_lex_state = 5},
  [5414] = {.lex_state = 75, .external_lex_state = 2},
  [5415] = {.lex_state = 75, .external_lex_state = 2},
  [5416] = {.lex_state = 75, .external_lex_state = 2},
  [5417] = {.lex_state = 75, .external_lex_state = 2},
  [5418] = {.lex_state = 75, .external_lex_state = 2},
  [5419] = {.lex_state = 75, .external_lex_state = 2},
  [5420] = {.lex_state = 75, .external_lex_state = 2},
  [5421] = {.lex_state = 75, .external_lex_state = 2},
  [5422] = {.lex_state = 75, .external_lex_state = 2},
  [5423] = {.lex_state = 75, .external_lex_state = 5},
  [5424] = {.lex_state = 75, .external_lex_state = 2},
  [5425] = {.lex_state = 75, .external_lex_state = 2},
  [5426] = {.lex_state = 75, .external_lex_state = 2},
  [5427] = {.lex_state = 75, .external_lex_state = 2},
  [5428] = {.lex_state = 75, .external_lex_state = 5},
  [5429] = {.lex_state = 75, .external_lex_state = 2},
  [5430] = {.lex_state = 75, .external_lex_state = 2},
  [5431] = {.lex_state = 75, .external_lex_state = 2},
  [5432] = {.lex_state = 75, .external_lex_state = 2},
  [5433] = {.lex_state = 75, .external_lex_state = 2},
  [5434] = {.lex_state = 75, .external_lex_state = 2},
  [5435] = {.lex_state = 75, .external_lex_state = 2},
  [5436] = {.lex_state = 75, .external_lex_state = 2},
  [5437] = {.lex_state = 75, .external_lex_state = 5},
  [5438] = {.lex_state = 75, .external_lex_state = 2},
  [5439] = {.lex_state = 75, .external_lex_state = 2},
  [5440] = {.lex_state = 75, .external_lex_state = 2},
  [5441] = {.lex_state = 75, .external_lex_state = 2},
  [5442] = {.lex_state = 75, .external_lex_state = 2},
  [5443] = {.lex_state = 75, .external_lex_state = 2},
  [5444] = {.lex_state = 75, .external_lex_state = 2},
  [5445] = {.lex_state = 75, .external_lex_state = 2},
  [5446] = {.lex_state = 75, .external_lex_state = 2},
  [5447] = {.lex_state = 75, .external_lex_state = 2},
  [5448] = {.lex_state = 75, .external_lex_state = 2},
  [5449] = {.lex_state = 75, .external_lex_state = 2},
  [5450] = {.lex_state = 75, .external_lex_state = 2},
  [5451] = {.lex_state = 75, .external_lex_state = 2},
  [5452] = {.lex_state = 75, .external_lex_state = 2},
  [5453] = {.lex_state = 75, .external_lex_state = 2},
  [5454] = {.lex_state = 75, .external_lex_state = 2},
  [5455] = {.lex_state = 75, .external_lex_state = 2},
  [5456] = {.lex_state = 75, .external_lex_state = 2},
  [5457] = {.lex_state = 75, .external_lex_state = 5},
  [5458] = {.lex_state = 75, .external_lex_state = 2},
  [5459] = {.lex_state = 75, .external_lex_state = 2},
  [5460] = {.lex_state = 75, .external_lex_state = 5},
  [5461] = {.lex_state = 75, .external_lex_state = 5},
  [5462] = {.lex_state = 75, .external_lex_state = 2},
  [5463] = {.lex_state = 75, .external_lex_state = 2},
  [5464] = {.lex_state = 75, .external_lex_state = 2},
  [5465] = {.lex_state = 75, .external_lex_state = 2},
  [5466] = {.lex_state = 75, .external_lex_state = 2},
  [5467] = {.lex_state = 75, .external_lex_state = 2},
  [5468] = {.lex_state = 75, .external_lex_state = 2},
  [5469] = {.lex_state = 75, .external_lex_state = 2},
  [5470] = {.lex_state = 75, .external_lex_state = 2},
  [5471] = {.lex_state = 75, .external_lex_state = 2},
  [5472] = {.lex_state = 75, .external_lex_state = 2},
  [5473] = {.lex_state = 75, .external_lex_state = 2},
  [5474] = {.lex_state = 75, .external_lex_state = 2},
  [5475] = {.lex_state = 75, .external_lex_state = 2},
  [5476] = {.lex_state = 75, .external_lex_state = 2},
  [5477] = {.lex_state = 75, .external_lex_state = 2},
  [5478] = {.lex_state = 75, .external_lex_state = 2},
  [5479] = {.lex_state = 75, .external_lex_state = 2},
  [5480] = {.lex_state = 75, .external_lex_state = 2},
  [5481] = {.lex_state = 75, .external_lex_state = 2},
  [5482] = {.lex_state = 1, .external_lex_state = 10},
  [5483] = {.lex_state = 75, .external_lex_state = 2},
  [5484] = {.lex_state = 75, .external_lex_state = 2},
  [5485] = {.lex_state = 75, .external_lex_state = 2},
  [5486] = {.lex_state = 75, .external_lex_state = 2},
  [5487] = {.lex_state = 75, .external_lex_state = 2},
  [5488] = {.lex_state = 75, .external_lex_state = 2},
  [5489] = {.lex_state = 75, .external_lex_state = 2},
  [5490] = {.lex_state = 75, .external_lex_state = 2},
  [5491] = {.lex_state = 75, .external_lex_state = 2},
  [5492] = {.lex_state = 75, .external_lex_state = 2},
  [5493] = {.lex_state = 75, .external_lex_state = 2},
  [5494] = {.lex_state = 1, .external_lex_state = 10},
  [5495] = {.lex_state = 75, .external_lex_state = 2},
  [5496] = {.lex_state = 75, .external_lex_state = 2},
  [5497] = {.lex_state = 75, .external_lex_state = 2},
  [5498] = {.lex_state = 75, .external_lex_state = 2},
  [5499] = {.lex_state = 75, .external_lex_state = 2},
  [5500] = {.lex_state = 75, .external_lex_state = 2},
  [5501] = {.lex_state = 75, .external_lex_state = 2},
  [5502] = {.lex_state = 75, .external_lex_state = 2},
  [5503] = {.lex_state = 75, .external_lex_state = 2},
  [5504] = {.lex_state = 75, .external_lex_state = 2},
  [5505] = {.lex_state = 75, .external_lex_state = 2},
  [5506] = {.lex_state = 75, .external_lex_state = 2},
  [5507] = {.lex_state = 75, .external_lex_state = 2},
  [5508] = {.lex_state = 75, .external_lex_state = 2},
  [5509] = {.lex_state = 75, .external_lex_state = 2},
  [5510] = {.lex_state = 75, .external_lex_state = 2},
  [5511] = {.lex_state = 75, .external_lex_state = 2},
  [5512] = {.lex_state = 75, .external_lex_state = 2},
  [5513] = {.lex_state = 75, .external_lex_state = 2},
  [5514] = {.lex_state = 75, .external_lex_state = 2},
  [5515] = {.lex_state = 75, .external_lex_state = 2},
  [5516] = {.lex_state = 75, .external_lex_state = 2},
  [5517] = {.lex_state = 75, .external_lex_state = 2},
  [5518] = {.lex_state = 75, .external_lex_state = 2},
  [5519] = {.lex_state = 75, .external_lex_state = 2},
  [5520] = {.lex_state = 75, .external_lex_state = 2},
  [5521] = {.lex_state = 75, .external_lex_state = 2},
  [5522] = {.lex_state = 75, .external_lex_state = 2},
  [5523] = {.lex_state = 75, .external_lex_state = 2},
  [5524] = {.lex_state = 75, .external_lex_state = 2},
  [5525] = {.lex_state = 75, .external_lex_state = 2},
  [5526] = {.lex_state = 75, .external_lex_state = 2},
  [5527] = {.lex_state = 75, .external_lex_state = 2},
  [5528] = {.lex_state = 75, .external_lex_state = 2},
  [5529] = {.lex_state = 75, .external_lex_state = 2},
  [5530] = {.lex_state = 75, .external_lex_state = 2},
  [5531] = {.lex_state = 75, .external_lex_state = 2},
  [5532] = {.lex_state = 75, .external_lex_state = 2},
  [5533] = {.lex_state = 75, .external_lex_state = 2},
  [5534] = {.lex_state = 75, .external_lex_state = 2},
  [5535] = {.lex_state = 75, .external_lex_state = 2},
  [5536] = {.lex_state = 75, .external_lex_state = 2},
  [5537] = {.lex_state = 75, .external_lex_state = 2},
  [5538] = {.lex_state = 75, .external_lex_state = 2},
  [5539] = {.lex_state = 75, .external_lex_state = 2},
  [5540] = {.lex_state = 75, .external_lex_state = 2},
  [5541] = {.lex_state = 75, .external_lex_state = 2},
  [5542] = {.lex_state = 75, .external_lex_state = 2},
  [5543] = {.lex_state = 75, .external_lex_state = 2},
  [5544] = {.lex_state = 75, .external_lex_state = 2},
  [5545] = {.lex_state = 75, .external_lex_state = 2},
  [5546] = {.lex_state = 75, .external_lex_state = 2},
  [5547] = {.lex_state = 75, .external_lex_state = 2},
  [5548] = {.lex_state = 75, .external_lex_state = 2},
  [5549] = {.lex_state = 75, .external_lex_state = 2},
  [5550] = {.lex_state = 75, .external_lex_state = 2},
  [5551] = {.lex_state = 75, .external_lex_state = 2},
  [5552] = {.lex_state = 75, .external_lex_state = 2},
  [5553] = {.lex_state = 23, .external_lex_state = 2},
  [5554] = {.lex_state = 75, .external_lex_state = 2},
  [5555] = {.lex_state = 75, .external_lex_state = 2},
  [5556] = {.lex_state = 75, .external_lex_state = 2},
  [5557] = {.lex_state = 75, .external_lex_state = 2},
  [5558] = {.lex_state = 75, .external_lex_state = 2},
  [5559] = {.lex_state = 75, .external_lex_state = 2},
  [5560] = {.lex_state = 75, .external_lex_state = 2},
  [5561] = {.lex_state = 75, .external_lex_state = 2},
  [5562] = {.lex_state = 75, .external_lex_state = 2},
  [5563] = {.lex_state = 75, .external_lex_state = 2},
  [5564] = {.lex_state = 75, .external_lex_state = 2},
  [5565] = {.lex_state = 75, .external_lex_state = 2},
  [5566] = {.lex_state = 75, .external_lex_state = 2},
  [5567] = {.lex_state = 75, .external_lex_state = 2},
  [5568] = {.lex_state = 75, .external_lex_state = 2},
  [5569] = {.lex_state = 75, .external_lex_state = 2},
  [5570] = {.lex_state = 75, .external_lex_state = 2},
  [5571] = {.lex_state = 75, .external_lex_state = 2},
  [5572] = {.lex_state = 75, .external_lex_state = 2},
  [5573] = {.lex_state = 75, .external_lex_state = 2},
  [5574] = {.lex_state = 75, .external_lex_state = 2},
  [5575] = {.lex_state = 75, .external_lex_state = 2},
  [5576] = {.lex_state = 75, .external_lex_state = 2},
  [5577] = {.lex_state = 75, .external_lex_state = 2},
  [5578] = {.lex_state = 75, .external_lex_state = 2},
  [5579] = {.lex_state = 75, .external_lex_state = 2},
  [5580] = {.lex_state = 75, .external_lex_state = 2},
  [5581] = {.lex_state = 75, .external_lex_state = 2},
  [5582] = {.lex_state = 75, .external_lex_state = 2},
  [5583] = {.lex_state = 75, .external_lex_state = 2},
  [5584] = {.lex_state = 75, .external_lex_state = 2},
  [5585] = {.lex_state = 75, .external_lex_state = 2},
  [5586] = {.lex_state = 75, .external_lex_state = 2},
  [5587] = {.lex_state = 75, .external_lex_state = 2},
  [5588] = {.lex_state = 75, .external_lex_state = 2},
  [5589] = {.lex_state = 75, .external_lex_state = 2},
  [5590] = {.lex_state = 75, .external_lex_state = 2},
  [5591] = {.lex_state = 75, .external_lex_state = 2},
  [5592] = {.lex_state = 75, .external_lex_state = 2},
  [5593] = {.lex_state = 75, .external_lex_state = 2},
  [5594] = {.lex_state = 75, .external_lex_state = 2},
  [5595] = {.lex_state = 75, .external_lex_state = 2},
  [5596] = {.lex_state = 75, .external_lex_state = 2},
  [5597] = {.lex_state = 75, .external_lex_state = 2},
  [5598] = {.lex_state = 75, .external_lex_state = 2},
  [5599] = {.lex_state = 75, .external_lex_state = 2},
  [5600] = {.lex_state = 75, .external_lex_state = 2},
  [5601] = {.lex_state = 75, .external_lex_state = 2},
  [5602] = {.lex_state = 75, .external_lex_state = 2},
  [5603] = {.lex_state = 75, .external_lex_state = 2},
  [5604] = {.lex_state = 75, .external_lex_state = 2},
  [5605] = {.lex_state = 75, .external_lex_state = 2},
  [5606] = {.lex_state = 75, .external_lex_state = 2},
  [5607] = {.lex_state = 75, .external_lex_state = 2},
  [5608] = {.lex_state = 75, .external_lex_state = 2},
  [5609] = {.lex_state = 75, .external_lex_state = 2},
  [5610] = {.lex_state = 75, .external_lex_state = 2},
  [5611] = {.lex_state = 75, .external_lex_state = 2},
  [5612] = {.lex_state = 75, .external_lex_state = 2},
  [5613] = {.lex_state = 75, .external_lex_state = 2},
  [5614] = {.lex_state = 75, .external_lex_state = 2},
  [5615] = {.lex_state = 75, .external_lex_state = 2},
  [5616] = {.lex_state = 75, .external_lex_state = 2},
  [5617] = {.lex_state = 75, .external_lex_state = 2},
  [5618] = {.lex_state = 75, .external_lex_state = 2},
  [5619] = {.lex_state = 75, .external_lex_state = 2},
  [5620] = {.lex_state = 75, .external_lex_state = 2},
  [5621] = {.lex_state = 75, .external_lex_state = 2},
  [5622] = {.lex_state = 75, .external_lex_state = 2},
  [5623] = {.lex_state = 75, .external_lex_state = 2},
  [5624] = {.lex_state = 75, .external_lex_state = 2},
  [5625] = {.lex_state = 75, .external_lex_state = 2},
  [5626] = {.lex_state = 75, .external_lex_state = 2},
  [5627] = {.lex_state = 1, .external_lex_state = 10},
  [5628] = {.lex_state = 75, .external_lex_state = 2},
  [5629] = {.lex_state = 75, .external_lex_state = 2},
  [5630] = {.lex_state = 75, .external_lex_state = 2},
  [5631] = {.lex_state = 75, .external_lex_state = 2},
  [5632] = {.lex_state = 75, .external_lex_state = 2},
  [5633] = {.lex_state = 75, .external_lex_state = 2},
  [5634] = {.lex_state = 75, .external_lex_state = 2},
  [5635] = {.lex_state = 75, .external_lex_state = 2},
  [5636] = {.lex_state = 75, .external_lex_state = 2},
  [5637] = {.lex_state = 75, .external_lex_state = 2},
  [5638] = {.lex_state = 75, .external_lex_state = 2},
  [5639] = {.lex_state = 75, .external_lex_state = 2},
  [5640] = {.lex_state = 75, .external_lex_state = 2},
  [5641] = {.lex_state = 75, .external_lex_state = 2},
  [5642] = {.lex_state = 75, .external_lex_state = 2},
  [5643] = {.lex_state = 75, .external_lex_state = 2},
  [5644] = {.lex_state = 75, .external_lex_state = 2},
  [5645] = {.lex_state = 75, .external_lex_state = 2},
  [5646] = {.lex_state = 75, .external_lex_state = 2},
  [5647] = {.lex_state = 75, .external_lex_state = 2},
  [5648] = {.lex_state = 75, .external_lex_state = 2},
  [5649] = {.lex_state = 23, .external_lex_state = 2},
  [5650] = {.lex_state = 75, .external_lex_state = 2},
  [5651] = {.lex_state = 75, .external_lex_state = 2},
  [5652] = {.lex_state = 75, .external_lex_state = 2},
  [5653] = {.lex_state = 75, .external_lex_state = 2},
  [5654] = {.lex_state = 75, .external_lex_state = 2},
  [5655] = {.lex_state = 1, .external_lex_state = 10},
  [5656] = {.lex_state = 75, .external_lex_state = 2},
  [5657] = {.lex_state = 75, .external_lex_state = 2},
  [5658] = {.lex_state = 75, .external_lex_state = 2},
  [5659] = {.lex_state = 75, .external_lex_state = 2},
  [5660] = {.lex_state = 75, .external_lex_state = 2},
  [5661] = {.lex_state = 75, .external_lex_state = 2},
  [5662] = {.lex_state = 23, .external_lex_state = 2},
  [5663] = {.lex_state = 75, .external_lex_state = 2},
  [5664] = {.lex_state = 75, .external_lex_state = 2},
  [5665] = {.lex_state = 75, .external_lex_state = 2},
  [5666] = {.lex_state = 75, .external_lex_state = 2},
  [5667] = {.lex_state = 75, .external_lex_state = 2},
  [5668] = {.lex_state = 1, .external_lex_state = 10},
  [5669] = {.lex_state = 75, .external_lex_state = 2},
  [5670] = {.lex_state = 75, .external_lex_state = 2},
  [5671] = {.lex_state = 75, .external_lex_state = 2},
  [5672] = {.lex_state = 75, .external_lex_state = 2},
  [5673] = {.lex_state = 75, .external_lex_state = 2},
  [5674] = {.lex_state = 75, .external_lex_state = 2},
  [5675] = {.lex_state = 75, .external_lex_state = 2},
  [5676] = {.lex_state = 75, .external_lex_state = 2},
  [5677] = {.lex_state = 75, .external_lex_state = 2},
  [5678] = {.lex_state = 75, .external_lex_state = 2},
  [5679] = {.lex_state = 75, .external_lex_state = 2},
  [5680] = {.lex_state = 75, .external_lex_state = 2},
  [5681] = {.lex_state = 75, .external_lex_state = 2},
  [5682] = {.lex_state = 75, .external_lex_state = 2},
  [5683] = {.lex_state = 23, .external_lex_state = 2},
  [5684] = {.lex_state = 75, .external_lex_state = 2},
  [5685] = {.lex_state = 75, .external_lex_state = 2},
  [5686] = {.lex_state = 75, .external_lex_state = 2},
  [5687] = {.lex_state = 75, .external_lex_state = 2},
  [5688] = {.lex_state = 75, .external_lex_state = 2},
  [5689] = {.lex_state = 75, .external_lex_state = 2},
  [5690] = {.lex_state = 75, .external_lex_state = 2},
  [5691] = {.lex_state = 75, .external_lex_state = 2},
  [5692] = {.lex_state = 75, .external_lex_state = 2},
  [5693] = {.lex_state = 75, .external_lex_state = 2},
  [5694] = {.lex_state = 75, .external_lex_state = 2},
  [5695] = {.lex_state = 75, .external_lex_state = 2},
  [5696] = {.lex_state = 75, .external_lex_state = 2},
  [5697] = {.lex_state = 75, .external_lex_state = 2},
  [5698] = {.lex_state = 75, .external_lex_state = 2},
  [5699] = {.lex_state = 75, .external_lex_state = 2},
  [5700] = {.lex_state = 75, .external_lex_state = 2},
  [5701] = {.lex_state = 75, .external_lex_state = 2},
  [5702] = {.lex_state = 75, .external_lex_state = 2},
  [5703] = {.lex_state = 75, .external_lex_state = 2},
  [5704] = {.lex_state = 75, .external_lex_state = 2},
  [5705] = {.lex_state = 75, .external_lex_state = 2},
  [5706] = {.lex_state = 75, .external_lex_state = 2},
  [5707] = {.lex_state = 75, .external_lex_state = 2},
  [5708] = {.lex_state = 75, .external_lex_state = 2},
  [5709] = {.lex_state = 75, .external_lex_state = 2},
  [5710] = {.lex_state = 75, .external_lex_state = 2},
  [5711] = {.lex_state = 75, .external_lex_state = 2},
  [5712] = {.lex_state = 75, .external_lex_state = 2},
  [5713] = {.lex_state = 75, .external_lex_state = 2},
  [5714] = {.lex_state = 75, .external_lex_state = 2},
  [5715] = {.lex_state = 75, .external_lex_state = 2},
  [5716] = {.lex_state = 75, .external_lex_state = 2},
  [5717] = {.lex_state = 75, .external_lex_state = 2},
  [5718] = {.lex_state = 75, .external_lex_state = 2},
  [5719] = {.lex_state = 75, .external_lex_state = 2},
  [5720] = {.lex_state = 75, .external_lex_state = 2},
  [5721] = {.lex_state = 75, .external_lex_state = 2},
  [5722] = {.lex_state = 75, .external_lex_state = 2},
  [5723] = {.lex_state = 75, .external_lex_state = 2},
  [5724] = {.lex_state = 75, .external_lex_state = 2},
  [5725] = {.lex_state = 75, .external_lex_state = 2},
  [5726] = {.lex_state = 75, .external_lex_state = 2},
  [5727] = {.lex_state = 75, .external_lex_state = 2},
  [5728] = {.lex_state = 75, .external_lex_state = 2},
  [5729] = {.lex_state = 75, .external_lex_state = 2},
  [5730] = {.lex_state = 75, .external_lex_state = 2},
  [5731] = {.lex_state = 75, .external_lex_state = 2},
  [5732] = {.lex_state = 75, .external_lex_state = 2},
  [5733] = {.lex_state = 75, .external_lex_state = 2},
  [5734] = {.lex_state = 75, .external_lex_state = 2},
  [5735] = {.lex_state = 75, .external_lex_state = 2},
  [5736] = {.lex_state = 75, .external_lex_state = 2},
  [5737] = {.lex_state = 75, .external_lex_state = 2},
  [5738] = {.lex_state = 75, .external_lex_state = 2},
  [5739] = {.lex_state = 75, .external_lex_state = 2},
  [5740] = {.lex_state = 75, .external_lex_state = 2},
  [5741] = {.lex_state = 75, .external_lex_state = 2},
  [5742] = {.lex_state = 75, .external_lex_state = 2},
  [5743] = {.lex_state = 75, .external_lex_state = 2},
  [5744] = {.lex_state = 75, .external_lex_state = 2},
  [5745] = {.lex_state = 75, .external_lex_state = 2},
  [5746] = {.lex_state = 75, .external_lex_state = 2},
  [5747] = {.lex_state = 75, .external_lex_state = 2},
  [5748] = {.lex_state = 75, .external_lex_state = 2},
  [5749] = {.lex_state = 75, .external_lex_state = 2},
  [5750] = {.lex_state = 75, .external_lex_state = 2},
  [5751] = {.lex_state = 75, .external_lex_state = 2},
  [5752] = {.lex_state = 75, .external_lex_state = 2},
  [5753] = {.lex_state = 75, .external_lex_state = 2},
  [5754] = {.lex_state = 75, .external_lex_state = 2},
  [5755] = {.lex_state = 75, .external_lex_state = 2},
  [5756] = {.lex_state = 75, .external_lex_state = 2},
  [5757] = {.lex_state = 75, .external_lex_state = 2},
  [5758] = {.lex_state = 75, .external_lex_state = 2},
  [5759] = {.lex_state = 75, .external_lex_state = 2},
  [5760] = {.lex_state = 75, .external_lex_state = 2},
  [5761] = {.lex_state = 75, .external_lex_state = 2},
  [5762] = {.lex_state = 75, .external_lex_state = 2},
  [5763] = {.lex_state = 75, .external_lex_state = 2},
  [5764] = {.lex_state = 75, .external_lex_state = 2},
  [5765] = {.lex_state = 75, .external_lex_state = 2},
  [5766] = {.lex_state = 75, .external_lex_state = 2},
  [5767] = {.lex_state = 75, .external_lex_state = 2},
  [5768] = {.lex_state = 75, .external_lex_state = 2},
  [5769] = {.lex_state = 75, .external_lex_state = 2},
  [5770] = {.lex_state = 75, .external_lex_state = 2},
  [5771] = {.lex_state = 75, .external_lex_state = 2},
  [5772] = {.lex_state = 75, .external_lex_state = 2},
  [5773] = {.lex_state = 75, .external_lex_state = 2},
  [5774] = {.lex_state = 75, .external_lex_state = 2},
  [5775] = {.lex_state = 75, .external_lex_state = 2},
  [5776] = {.lex_state = 75, .external_lex_state = 2},
  [5777] = {.lex_state = 75, .external_lex_state = 2},
  [5778] = {.lex_state = 75, .external_lex_state = 2},
  [5779] = {.lex_state = 75, .external_lex_state = 2},
  [5780] = {.lex_state = 75, .external_lex_state = 2},
  [5781] = {.lex_state = 75, .external_lex_state = 2},
  [5782] = {.lex_state = 75, .external_lex_state = 2},
  [5783] = {.lex_state = 75, .external_lex_state = 2},
  [5784] = {.lex_state = 75, .external_lex_state = 2},
  [5785] = {.lex_state = 75, .external_lex_state = 2},
  [5786] = {.lex_state = 75, .external_lex_state = 2},
  [5787] = {.lex_state = 75, .external_lex_state = 2},
  [5788] = {.lex_state = 75, .external_lex_state = 2},
  [5789] = {.lex_state = 75, .external_lex_state = 2},
  [5790] = {.lex_state = 75, .external_lex_state = 2},
  [5791] = {.lex_state = 75, .external_lex_state = 2},
  [5792] = {.lex_state = 75, .external_lex_state = 2},
  [5793] = {.lex_state = 75, .external_lex_state = 2},
  [5794] = {.lex_state = 75, .external_lex_state = 2},
  [5795] = {.lex_state = 75, .external_lex_state = 2},
  [5796] = {.lex_state = 75, .external_lex_state = 2},
  [5797] = {.lex_state = 75, .external_lex_state = 2},
  [5798] = {.lex_state = 75, .external_lex_state = 2},
  [5799] = {.lex_state = 75, .external_lex_state = 2},
  [5800] = {.lex_state = 75, .external_lex_state = 2},
  [5801] = {.lex_state = 23, .external_lex_state = 2},
  [5802] = {.lex_state = 75, .external_lex_state = 2},
  [5803] = {.lex_state = 75, .external_lex_state = 2},
  [5804] = {.lex_state = 75, .external_lex_state = 2},
  [5805] = {.lex_state = 75, .external_lex_state = 2},
  [5806] = {.lex_state = 75, .external_lex_state = 2},
  [5807] = {.lex_state = 75, .external_lex_state = 2},
  [5808] = {.lex_state = 75, .external_lex_state = 2},
  [5809] = {.lex_state = 75, .external_lex_state = 2},
  [5810] = {.lex_state = 75, .external_lex_state = 2},
  [5811] = {.lex_state = 75, .external_lex_state = 2},
  [5812] = {.lex_state = 75, .external_lex_state = 2},
  [5813] = {.lex_state = 75, .external_lex_state = 2},
  [5814] = {.lex_state = 75, .external_lex_state = 2},
  [5815] = {.lex_state = 75, .external_lex_state = 2},
  [5816] = {.lex_state = 75, .external_lex_state = 2},
  [5817] = {.lex_state = 75, .external_lex_state = 2},
  [5818] = {.lex_state = 75, .external_lex_state = 2},
  [5819] = {.lex_state = 75, .external_lex_state = 2},
  [5820] = {.lex_state = 75, .external_lex_state = 2},
  [5821] = {.lex_state = 75, .external_lex_state = 2},
  [5822] = {.lex_state = 75, .external_lex_state = 2},
  [5823] = {.lex_state = 75, .external_lex_state = 2},
  [5824] = {.lex_state = 75, .external_lex_state = 2},
  [5825] = {.lex_state = 75, .external_lex_state = 2},
  [5826] = {.lex_state = 75, .external_lex_state = 2},
  [5827] = {.lex_state = 75, .external_lex_state = 2},
  [5828] = {.lex_state = 75, .external_lex_state = 2},
  [5829] = {.lex_state = 75, .external_lex_state = 2},
  [5830] = {.lex_state = 75, .external_lex_state = 2},
  [5831] = {.lex_state = 75, .external_lex_state = 2},
  [5832] = {.lex_state = 75, .external_lex_state = 2},
  [5833] = {.lex_state = 75, .external_lex_state = 2},
  [5834] = {.lex_state = 75, .external_lex_state = 2},
  [5835] = {.lex_state = 75, .external_lex_state = 2},
  [5836] = {.lex_state = 75, .external_lex_state = 2},
  [5837] = {.lex_state = 75, .external_lex_state = 2},
  [5838] = {.lex_state = 75, .external_lex_state = 2},
  [5839] = {.lex_state = 75, .external_lex_state = 2},
  [5840] = {.lex_state = 75, .external_lex_state = 2},
  [5841] = {.lex_state = 75, .external_lex_state = 2},
  [5842] = {.lex_state = 75, .external_lex_state = 2},
  [5843] = {.lex_state = 75, .external_lex_state = 2},
  [5844] = {.lex_state = 75, .external_lex_state = 2},
  [5845] = {.lex_state = 75, .external_lex_state = 2},
  [5846] = {.lex_state = 75, .external_lex_state = 2},
  [5847] = {.lex_state = 75, .external_lex_state = 2},
  [5848] = {.lex_state = 75, .external_lex_state = 2},
  [5849] = {.lex_state = 75, .external_lex_state = 2},
  [5850] = {.lex_state = 75, .external_lex_state = 2},
  [5851] = {.lex_state = 75, .external_lex_state = 2},
  [5852] = {.lex_state = 75, .external_lex_state = 2},
  [5853] = {.lex_state = 75, .external_lex_state = 2},
  [5854] = {.lex_state = 75, .external_lex_state = 2},
  [5855] = {.lex_state = 75, .external_lex_state = 2},
  [5856] = {.lex_state = 75, .external_lex_state = 2},
  [5857] = {.lex_state = 75, .external_lex_state = 2},
  [5858] = {.lex_state = 75, .external_lex_state = 2},
  [5859] = {.lex_state = 75, .external_lex_state = 2},
  [5860] = {.lex_state = 75, .external_lex_state = 2},
  [5861] = {.lex_state = 75, .external_lex_state = 2},
  [5862] = {.lex_state = 75, .external_lex_state = 2},
  [5863] = {.lex_state = 75, .external_lex_state = 2},
  [5864] = {.lex_state = 75, .external_lex_state = 2},
  [5865] = {.lex_state = 75, .external_lex_state = 2},
  [5866] = {.lex_state = 75, .external_lex_state = 2},
  [5867] = {.lex_state = 75, .external_lex_state = 2},
  [5868] = {.lex_state = 75, .external_lex_state = 2},
  [5869] = {.lex_state = 75, .external_lex_state = 2},
};

static const uint16_t ts_parse_table[LARGE_STATE_COUNT][SYMBOL_COUNT] = {
  [0] = {
    [ts_builtin_sym_end] = ACTIONS(1),
    [sym_identifier] = ACTIONS(1),
    [sym_hash_bang_line] = ACTIONS(1),
    [anon_sym_export] = ACTIONS(1),
    [anon_sym_STAR] = ACTIONS(1),
    [anon_sym_default] = ACTIONS(1),
    [anon_sym_type] = ACTIONS(1),
    [anon_sym_EQ] = ACTIONS(1),
    [anon_sym_as] = ACTIONS(1),
    [anon_sym_namespace] = ACTIONS(1),
    [anon_sym_LBRACE] = ACTIONS(1),
    [anon_sym_COMMA] = ACTIONS(1),
    [anon_sym_RBRACE] = ACTIONS(1),
    [anon_sym_typeof] = ACTIONS(1),
    [anon_sym_import] = ACTIONS(1),
    [anon_sym_from] = ACTIONS(1),
    [anon_sym_with] = ACTIONS(1),
    [anon_sym_assert] = ACTIONS(1),
    [anon_sym_var] = ACTIONS(1),
    [anon_sym_let] = ACTIONS(1),
    [anon_sym_const] = ACTIONS(1),
    [anon_sym_BANG] = ACTIONS(1),
    [anon_sym_else] = ACTIONS(1),
    [anon_sym_if] = ACTIONS(1),
    [anon_sym_switch] = ACTIONS(1),
    [anon_sym_for] = ACTIONS(1),
    [anon_sym_LPAREN] = ACTIONS(1),
    [anon_sym_SEMI] = ACTIONS(1),
    [anon_sym_RPAREN] = ACTIONS(1),
    [anon_sym_await] = ACTIONS(1),
    [anon_sym_in] = ACTIONS(1),
    [anon_sym_of] = ACTIONS(1),
    [anon_sym_while] = ACTIONS(1),
    [anon_sym_do] = ACTIONS(1),
    [anon_sym_try] = ACTIONS(1),
    [anon_sym_break] = ACTIONS(1),
    [anon_sym_continue] = ACTIONS(1),
    [anon_sym_debugger] = ACTIONS(1),
    [anon_sym_return] = ACTIONS(1),
    [anon_sym_throw] = ACTIONS(1),
    [anon_sym_COLON] = ACTIONS(1),
    [anon_sym_case] = ACTIONS(1),
    [anon_sym_catch] = ACTIONS(1),
    [anon_sym_finally] = ACTIONS(1),
    [anon_sym_yield] = ACTIONS(1),
    [anon_sym_LBRACK] = ACTIONS(1),
    [anon_sym_RBRACK] = ACTIONS(1),
    [anon_sym_DOT] = ACTIONS(1),
    [anon_sym_class] = ACTIONS(1),
    [anon_sym_async] = ACTIONS(1),
    [anon_sym_function] = ACTIONS(1),
    [anon_sym_EQ_GT] = ACTIONS(1),
    [anon_sym_QMARK_DOT] = ACTIONS(1),
    [anon_sym_new] = ACTIONS(1),
    [anon_sym_using] = ACTIONS(1),
    [anon_sym_PLUS_EQ] = ACTIONS(1),
    [anon_sym_DASH_EQ] = ACTIONS(1),
    [anon_sym_STAR_EQ] = ACTIONS(1),
    [anon_sym_SLASH_EQ] = ACTIONS(1),
    [anon_sym_PERCENT_EQ] = ACTIONS(1),
    [anon_sym_CARET_EQ] = ACTIONS(1),
    [anon_sym_AMP_EQ] = ACTIONS(1),
    [anon_sym_PIPE_EQ] = ACTIONS(1),
    [anon_sym_GT_GT_EQ] = ACTIONS(1),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(1),
    [anon_sym_LT_LT_EQ] = ACTIONS(1),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(1),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(1),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(1),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(1),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1),
    [anon_sym_AMP_AMP] = ACTIONS(1),
    [anon_sym_PIPE_PIPE] = ACTIONS(1),
    [anon_sym_GT_GT] = ACTIONS(1),
    [anon_sym_GT_GT_GT] = ACTIONS(1),
    [anon_sym_LT_LT] = ACTIONS(1),
    [anon_sym_AMP] = ACTIONS(1),
    [anon_sym_CARET] = ACTIONS(1),
    [anon_sym_PIPE] = ACTIONS(1),
    [anon_sym_PLUS] = ACTIONS(1),
    [anon_sym_DASH] = ACTIONS(1),
    [anon_sym_SLASH] = ACTIONS(1),
    [anon_sym_PERCENT] = ACTIONS(1),
    [anon_sym_STAR_STAR] = ACTIONS(1),
    [anon_sym_LT] = ACTIONS(1),
    [anon_sym_LT_EQ] = ACTIONS(1),
    [anon_sym_EQ_EQ] = ACTIONS(1),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(1),
    [anon_sym_BANG_EQ] = ACTIONS(1),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(1),
    [anon_sym_GT_EQ] = ACTIONS(1),
    [anon_sym_GT] = ACTIONS(1),
    [anon_sym_QMARK_QMARK] = ACTIONS(1),
    [anon_sym_instanceof] = ACTIONS(1),
    [anon_sym_TILDE] = ACTIONS(1),
    [anon_sym_void] = ACTIONS(1),
    [anon_sym_delete] = ACTIONS(1),
    [anon_sym_PLUS_PLUS] = ACTIONS(1),
    [anon_sym_DASH_DASH] = ACTIONS(1),
    [anon_sym_DQUOTE] = ACTIONS(1),
    [anon_sym_SQUOTE] = ACTIONS(1),
    [sym_escape_sequence] = ACTIONS(1),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BQUOTE] = ACTIONS(1),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(1),
    [anon_sym_SLASH2] = ACTIONS(1),
    [sym_number] = ACTIONS(1),
    [sym_private_property_identifier] = ACTIONS(1),
    [anon_sym_target] = ACTIONS(1),
    [anon_sym_meta] = ACTIONS(1),
    [sym_this] = ACTIONS(1),
    [sym_super] = ACTIONS(1),
    [sym_true] = ACTIONS(1),
    [sym_false] = ACTIONS(1),
    [sym_null] = ACTIONS(1),
    [sym_undefined] = ACTIONS(1),
    [anon_sym_AT] = ACTIONS(1),
    [anon_sym_static] = ACTIONS(1),
    [anon_sym_readonly] = ACTIONS(1),
    [anon_sym_get] = ACTIONS(1),
    [anon_sym_set] = ACTIONS(1),
    [anon_sym_QMARK] = ACTIONS(1),
    [anon_sym_declare] = ACTIONS(1),
    [anon_sym_public] = ACTIONS(1),
    [anon_sym_private] = ACTIONS(1),
    [anon_sym_protected] = ACTIONS(1),
    [anon_sym_override] = ACTIONS(1),
    [anon_sym_module] = ACTIONS(1),
    [anon_sym_any] = ACTIONS(1),
    [anon_sym_number] = ACTIONS(1),
    [anon_sym_boolean] = ACTIONS(1),
    [anon_sym_string] = ACTIONS(1),
    [anon_sym_symbol] = ACTIONS(1),
    [anon_sym_object] = ACTIONS(1),
    [anon_sym_abstract] = ACTIONS(1),
    [anon_sym_accessor] = ACTIONS(1),
    [anon_sym_satisfies] = ACTIONS(1),
    [anon_sym_require] = ACTIONS(1),
    [anon_sym_extends] = ACTIONS(1),
    [anon_sym_implements] = ACTIONS(1),
    [anon_sym_global] = ACTIONS(1),
    [anon_sym_interface] = ACTIONS(1),
    [anon_sym_enum] = ACTIONS(1),
    [anon_sym_DASH_QMARK_COLON] = ACTIONS(1),
    [anon_sym_PLUS_QMARK_COLON] = ACTIONS(1),
    [anon_sym_asserts] = ACTIONS(1),
    [anon_sym_infer] = ACTIONS(1),
    [anon_sym_is] = ACTIONS(1),
    [anon_sym_keyof] = ACTIONS(1),
    [anon_sym_unique] = ACTIONS(1),
    [anon_sym_unknown] = ACTIONS(1),
    [anon_sym_never] = ACTIONS(1),
    [anon_sym_LBRACE_PIPE] = ACTIONS(1),
    [anon_sym_PIPE_RBRACE] = ACTIONS(1),
    [sym__automatic_semicolon] = ACTIONS(1),
    [sym__template_chars] = ACTIONS(1),
    [sym__ternary_qmark] = ACTIONS(1),
    [sym_html_comment] = ACTIONS(5),
    [sym_jsx_text] = ACTIONS(1),
    [sym__function_signature_automatic_semicolon] = ACTIONS(1),
    [sym___error_recovery] = ACTIONS(1),
  },
  [1] = {
    [sym_program] = STATE(5657),
    [sym_export_statement] = STATE(892),
    [sym_declaration] = STATE(892),
    [sym_import] = STATE(3636),
    [sym_import_statement] = STATE(892),
    [sym_statement] = STATE(16),
    [sym_expression_statement] = STATE(892),
    [sym_variable_declaration] = STATE(831),
    [sym_lexical_declaration] = STATE(831),
    [sym_statement_block] = STATE(892),
    [sym_if_statement] = STATE(892),
    [sym_switch_statement] = STATE(892),
    [sym_for_statement] = STATE(892),
    [sym_for_in_statement] = STATE(892),
    [sym_while_statement] = STATE(892),
    [sym_do_statement] = STATE(892),
    [sym_try_statement] = STATE(892),
    [sym_with_statement] = STATE(892),
    [sym_break_statement] = STATE(892),
    [sym_continue_statement] = STATE(892),
    [sym_debugger_statement] = STATE(892),
    [sym_return_statement] = STATE(892),
    [sym_throw_statement] = STATE(892),
    [sym_empty_statement] = STATE(892),
    [sym_labeled_statement] = STATE(892),
    [sym_parenthesized_expression] = STATE(1362),
    [sym_expression] = STATE(1902),
    [sym_primary_expression] = STATE(1810),
    [sym_yield_expression] = STATE(2358),
    [sym_object] = STATE(2222),
    [sym_object_pattern] = STATE(5492),
    [sym_array] = STATE(2222),
    [sym_array_pattern] = STATE(5492),
    [sym_class] = STATE(2222),
    [sym_class_declaration] = STATE(831),
    [sym_function_expression] = STATE(2222),
    [sym_function_declaration] = STATE(831),
    [sym_generator_function] = STATE(2222),
    [sym_generator_function_declaration] = STATE(831),
    [sym_arrow_function] = STATE(2222),
    [sym__call_signature] = STATE(5821),
    [sym_call_expression] = STATE(2222),
    [sym_new_expression] = STATE(1948),
    [sym_await_expression] = STATE(2358),
    [sym_member_expression] = STATE(1362),
    [sym_subscript_expression] = STATE(1362),
    [sym_assignment_expression] = STATE(2358),
    [sym__augmented_assignment_lhs] = STATE(3025),
    [sym_augmented_assignment_expression] = STATE(2358),
    [sym__destructuring_pattern] = STATE(5492),
    [sym_ternary_expression] = STATE(2358),
    [sym_binary_expression] = STATE(2358),
    [sym_unary_expression] = STATE(2358),
    [sym_update_expression] = STATE(2358),
    [sym_sequence_expression] = STATE(5305),
    [sym_string] = STATE(2222),
    [sym_template_string] = STATE(2222),
    [sym_regex] = STATE(2222),
    [sym_meta_property] = STATE(2222),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1362),
    [sym_function_signature] = STATE(831),
    [sym_type_assertion] = STATE(2358),
    [sym_as_expression] = STATE(2358),
    [sym_satisfies_expression] = STATE(2358),
    [sym_instantiation_expression] = STATE(2358),
    [sym_ambient_declaration] = STATE(831),
    [sym_abstract_class_declaration] = STATE(831),
    [sym_module] = STATE(831),
    [sym_internal_module] = STATE(214),
    [sym_import_alias] = STATE(831),
    [sym_interface_declaration] = STATE(831),
    [sym_enum_declaration] = STATE(831),
    [sym_type_alias_declaration] = STATE(831),
    [sym_type_arguments] = STATE(428),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_program_repeat1] = STATE(16),
    [aux_sym_export_statement_repeat1] = STATE(3774),
    [ts_builtin_sym_end] = ACTIONS(7),
    [sym_identifier] = ACTIONS(9),
    [sym_hash_bang_line] = ACTIONS(11),
    [anon_sym_export] = ACTIONS(13),
    [anon_sym_type] = ACTIONS(15),
    [anon_sym_namespace] = ACTIONS(17),
    [anon_sym_LBRACE] = ACTIONS(19),
    [anon_sym_typeof] = ACTIONS(21),
    [anon_sym_import] = ACTIONS(23),
    [anon_sym_with] = ACTIONS(25),
    [anon_sym_var] = ACTIONS(27),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_const] = ACTIONS(31),
    [anon_sym_BANG] = ACTIONS(33),
    [anon_sym_if] = ACTIONS(35),
    [anon_sym_switch] = ACTIONS(37),
    [anon_sym_for] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_SEMI] = ACTIONS(43),
    [anon_sym_await] = ACTIONS(45),
    [anon_sym_while] = ACTIONS(47),
    [anon_sym_do] = ACTIONS(49),
    [anon_sym_try] = ACTIONS(51),
    [anon_sym_break] = ACTIONS(53),
    [anon_sym_continue] = ACTIONS(55),
    [anon_sym_debugger] = ACTIONS(57),
    [anon_sym_return] = ACTIONS(59),
    [anon_sym_throw] = ACTIONS(61),
    [anon_sym_yield] = ACTIONS(63),
    [anon_sym_LBRACK] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(67),
    [anon_sym_async] = ACTIONS(69),
    [anon_sym_function] = ACTIONS(71),
    [anon_sym_new] = ACTIONS(73),
    [anon_sym_using] = ACTIONS(75),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_SLASH] = ACTIONS(77),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(33),
    [anon_sym_void] = ACTIONS(21),
    [anon_sym_delete] = ACTIONS(21),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_DQUOTE] = ACTIONS(83),
    [anon_sym_SQUOTE] = ACTIONS(85),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(87),
    [sym_number] = ACTIONS(89),
    [sym_private_property_identifier] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(93),
    [sym_true] = ACTIONS(93),
    [sym_false] = ACTIONS(93),
    [sym_null] = ACTIONS(93),
    [sym_undefined] = ACTIONS(95),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(99),
    [anon_sym_readonly] = ACTIONS(99),
    [anon_sym_get] = ACTIONS(99),
    [anon_sym_set] = ACTIONS(99),
    [anon_sym_declare] = ACTIONS(101),
    [anon_sym_public] = ACTIONS(99),
    [anon_sym_private] = ACTIONS(99),
    [anon_sym_protected] = ACTIONS(99),
    [anon_sym_override] = ACTIONS(99),
    [anon_sym_module] = ACTIONS(103),
    [anon_sym_any] = ACTIONS(99),
    [anon_sym_number] = ACTIONS(99),
    [anon_sym_boolean] = ACTIONS(99),
    [anon_sym_string] = ACTIONS(99),
    [anon_sym_symbol] = ACTIONS(99),
    [anon_sym_object] = ACTIONS(99),
    [anon_sym_abstract] = ACTIONS(105),
    [anon_sym_interface] = ACTIONS(107),
    [anon_sym_enum] = ACTIONS(109),
    [sym_html_comment] = ACTIONS(5),
  },
  [2] = {
    [sym_import] = STATE(3593),
    [sym_parenthesized_expression] = STATE(1213),
    [sym_expression] = STATE(2644),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(3722),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(3722),
    [sym_nested_identifier] = STATE(5474),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5800),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1295),
    [sym_subscript_expression] = STATE(1295),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3013),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(3722),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(2213),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(4087),
    [sym_pattern] = STATE(4312),
    [sym_rest_pattern] = STATE(3684),
    [sym_non_null_expression] = STATE(1295),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_nested_type_identifier] = STATE(2939),
    [sym__type_query_member_expression_in_type_annotation] = STATE(2937),
    [sym__type_query_call_expression_in_type_annotation] = STATE(2938),
    [sym_type] = STATE(3153),
    [sym_constructor_type] = STATE(3007),
    [sym_primary_type] = STATE(2981),
    [sym_template_literal_type] = STATE(3039),
    [sym_infer_type] = STATE(3007),
    [sym_conditional_type] = STATE(3039),
    [sym_generic_type] = STATE(3039),
    [sym_type_query] = STATE(3039),
    [sym_index_type_query] = STATE(3039),
    [sym_lookup_type] = STATE(3039),
    [sym_literal_type] = STATE(3039),
    [sym__number] = STATE(3041),
    [sym_existential_type] = STATE(3039),
    [sym_flow_maybe_type] = STATE(3039),
    [sym_parenthesized_type] = STATE(3039),
    [sym_predefined_type] = STATE(3039),
    [sym_type_arguments] = STATE(539),
    [sym_object_type] = STATE(3039),
    [sym_type_parameters] = STATE(5158),
    [sym_array_type] = STATE(3039),
    [sym_tuple_type] = STATE(3039),
    [sym_readonly_type] = STATE(3007),
    [sym_union_type] = STATE(3039),
    [sym_intersection_type] = STATE(3039),
    [sym_function_type] = STATE(3007),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(111),
    [anon_sym_export] = ACTIONS(113),
    [anon_sym_STAR] = ACTIONS(115),
    [anon_sym_type] = ACTIONS(113),
    [anon_sym_EQ] = ACTIONS(117),
    [anon_sym_as] = ACTIONS(120),
    [anon_sym_namespace] = ACTIONS(122),
    [anon_sym_LBRACE] = ACTIONS(124),
    [anon_sym_COMMA] = ACTIONS(126),
    [anon_sym_typeof] = ACTIONS(129),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(113),
    [anon_sym_const] = ACTIONS(133),
    [anon_sym_BANG] = ACTIONS(135),
    [anon_sym_LPAREN] = ACTIONS(138),
    [anon_sym_RPAREN] = ACTIONS(126),
    [anon_sym_await] = ACTIONS(140),
    [anon_sym_in] = ACTIONS(120),
    [anon_sym_COLON] = ACTIONS(126),
    [anon_sym_yield] = ACTIONS(142),
    [anon_sym_LBRACK] = ACTIONS(144),
    [anon_sym_DOT] = ACTIONS(120),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(148),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_EQ_GT] = ACTIONS(152),
    [anon_sym_QMARK_DOT] = ACTIONS(154),
    [anon_sym_new] = ACTIONS(156),
    [anon_sym_using] = ACTIONS(158),
    [anon_sym_PLUS_EQ] = ACTIONS(160),
    [anon_sym_DASH_EQ] = ACTIONS(160),
    [anon_sym_STAR_EQ] = ACTIONS(160),
    [anon_sym_SLASH_EQ] = ACTIONS(160),
    [anon_sym_PERCENT_EQ] = ACTIONS(160),
    [anon_sym_CARET_EQ] = ACTIONS(160),
    [anon_sym_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_LT_LT_EQ] = ACTIONS(160),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(160),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(160),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(162),
    [anon_sym_AMP_AMP] = ACTIONS(120),
    [anon_sym_PIPE_PIPE] = ACTIONS(120),
    [anon_sym_GT_GT] = ACTIONS(120),
    [anon_sym_GT_GT_GT] = ACTIONS(120),
    [anon_sym_LT_LT] = ACTIONS(120),
    [anon_sym_AMP] = ACTIONS(164),
    [anon_sym_CARET] = ACTIONS(120),
    [anon_sym_PIPE] = ACTIONS(166),
    [anon_sym_PLUS] = ACTIONS(168),
    [anon_sym_DASH] = ACTIONS(168),
    [anon_sym_SLASH] = ACTIONS(170),
    [anon_sym_PERCENT] = ACTIONS(120),
    [anon_sym_STAR_STAR] = ACTIONS(120),
    [anon_sym_LT] = ACTIONS(173),
    [anon_sym_LT_EQ] = ACTIONS(154),
    [anon_sym_EQ_EQ] = ACTIONS(120),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(154),
    [anon_sym_BANG_EQ] = ACTIONS(120),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(154),
    [anon_sym_GT_EQ] = ACTIONS(154),
    [anon_sym_GT] = ACTIONS(120),
    [anon_sym_QMARK_QMARK] = ACTIONS(120),
    [anon_sym_instanceof] = ACTIONS(120),
    [anon_sym_TILDE] = ACTIONS(175),
    [anon_sym_void] = ACTIONS(177),
    [anon_sym_delete] = ACTIONS(179),
    [anon_sym_PLUS_PLUS] = ACTIONS(181),
    [anon_sym_DASH_DASH] = ACTIONS(181),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(188),
    [sym_number] = ACTIONS(190),
    [sym_private_property_identifier] = ACTIONS(192),
    [sym_this] = ACTIONS(194),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(198),
    [sym_false] = ACTIONS(198),
    [sym_null] = ACTIONS(198),
    [sym_undefined] = ACTIONS(200),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(113),
    [anon_sym_readonly] = ACTIONS(202),
    [anon_sym_get] = ACTIONS(113),
    [anon_sym_set] = ACTIONS(113),
    [anon_sym_QMARK] = ACTIONS(204),
    [anon_sym_declare] = ACTIONS(113),
    [anon_sym_public] = ACTIONS(113),
    [anon_sym_private] = ACTIONS(113),
    [anon_sym_protected] = ACTIONS(113),
    [anon_sym_override] = ACTIONS(113),
    [anon_sym_module] = ACTIONS(113),
    [anon_sym_any] = ACTIONS(206),
    [anon_sym_number] = ACTIONS(206),
    [anon_sym_boolean] = ACTIONS(206),
    [anon_sym_string] = ACTIONS(206),
    [anon_sym_symbol] = ACTIONS(206),
    [anon_sym_object] = ACTIONS(206),
    [anon_sym_abstract] = ACTIONS(208),
    [anon_sym_satisfies] = ACTIONS(120),
    [anon_sym_infer] = ACTIONS(210),
    [anon_sym_keyof] = ACTIONS(212),
    [anon_sym_unique] = ACTIONS(214),
    [anon_sym_unknown] = ACTIONS(216),
    [anon_sym_never] = ACTIONS(216),
    [anon_sym_LBRACE_PIPE] = ACTIONS(218),
    [sym__ternary_qmark] = ACTIONS(154),
    [sym_html_comment] = ACTIONS(5),
  },
  [3] = {
    [sym_import] = STATE(3593),
    [sym_parenthesized_expression] = STATE(1213),
    [sym_expression] = STATE(2644),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(3722),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(3722),
    [sym_nested_identifier] = STATE(5474),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5800),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1295),
    [sym_subscript_expression] = STATE(1295),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3013),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(3722),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(2213),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(4087),
    [sym_pattern] = STATE(4312),
    [sym_rest_pattern] = STATE(3684),
    [sym_non_null_expression] = STATE(1295),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_nested_type_identifier] = STATE(2939),
    [sym__type_query_member_expression_in_type_annotation] = STATE(2937),
    [sym__type_query_call_expression_in_type_annotation] = STATE(2938),
    [sym_type] = STATE(3153),
    [sym_constructor_type] = STATE(3007),
    [sym_primary_type] = STATE(2981),
    [sym_template_literal_type] = STATE(3039),
    [sym_infer_type] = STATE(3007),
    [sym_conditional_type] = STATE(3039),
    [sym_generic_type] = STATE(3039),
    [sym_type_query] = STATE(3039),
    [sym_index_type_query] = STATE(3039),
    [sym_lookup_type] = STATE(3039),
    [sym_literal_type] = STATE(3039),
    [sym__number] = STATE(3041),
    [sym_existential_type] = STATE(3039),
    [sym_flow_maybe_type] = STATE(3039),
    [sym_parenthesized_type] = STATE(3039),
    [sym_predefined_type] = STATE(3039),
    [sym_type_arguments] = STATE(539),
    [sym_object_type] = STATE(3039),
    [sym_type_parameters] = STATE(5158),
    [sym_array_type] = STATE(3039),
    [sym_tuple_type] = STATE(3039),
    [sym_readonly_type] = STATE(3007),
    [sym_union_type] = STATE(3039),
    [sym_intersection_type] = STATE(3039),
    [sym_function_type] = STATE(3007),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(111),
    [anon_sym_export] = ACTIONS(113),
    [anon_sym_STAR] = ACTIONS(115),
    [anon_sym_type] = ACTIONS(113),
    [anon_sym_EQ] = ACTIONS(220),
    [anon_sym_as] = ACTIONS(120),
    [anon_sym_namespace] = ACTIONS(122),
    [anon_sym_LBRACE] = ACTIONS(124),
    [anon_sym_COMMA] = ACTIONS(223),
    [anon_sym_typeof] = ACTIONS(129),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(113),
    [anon_sym_const] = ACTIONS(133),
    [anon_sym_BANG] = ACTIONS(135),
    [anon_sym_LPAREN] = ACTIONS(138),
    [anon_sym_RPAREN] = ACTIONS(223),
    [anon_sym_await] = ACTIONS(140),
    [anon_sym_in] = ACTIONS(120),
    [anon_sym_COLON] = ACTIONS(223),
    [anon_sym_yield] = ACTIONS(142),
    [anon_sym_LBRACK] = ACTIONS(144),
    [anon_sym_DOT] = ACTIONS(120),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(148),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_EQ_GT] = ACTIONS(225),
    [anon_sym_QMARK_DOT] = ACTIONS(154),
    [anon_sym_new] = ACTIONS(156),
    [anon_sym_using] = ACTIONS(158),
    [anon_sym_PLUS_EQ] = ACTIONS(160),
    [anon_sym_DASH_EQ] = ACTIONS(160),
    [anon_sym_STAR_EQ] = ACTIONS(160),
    [anon_sym_SLASH_EQ] = ACTIONS(160),
    [anon_sym_PERCENT_EQ] = ACTIONS(160),
    [anon_sym_CARET_EQ] = ACTIONS(160),
    [anon_sym_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_LT_LT_EQ] = ACTIONS(160),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(160),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(160),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(162),
    [anon_sym_AMP_AMP] = ACTIONS(120),
    [anon_sym_PIPE_PIPE] = ACTIONS(120),
    [anon_sym_GT_GT] = ACTIONS(120),
    [anon_sym_GT_GT_GT] = ACTIONS(120),
    [anon_sym_LT_LT] = ACTIONS(120),
    [anon_sym_AMP] = ACTIONS(164),
    [anon_sym_CARET] = ACTIONS(120),
    [anon_sym_PIPE] = ACTIONS(166),
    [anon_sym_PLUS] = ACTIONS(168),
    [anon_sym_DASH] = ACTIONS(168),
    [anon_sym_SLASH] = ACTIONS(170),
    [anon_sym_PERCENT] = ACTIONS(120),
    [anon_sym_STAR_STAR] = ACTIONS(120),
    [anon_sym_LT] = ACTIONS(173),
    [anon_sym_LT_EQ] = ACTIONS(154),
    [anon_sym_EQ_EQ] = ACTIONS(120),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(154),
    [anon_sym_BANG_EQ] = ACTIONS(120),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(154),
    [anon_sym_GT_EQ] = ACTIONS(154),
    [anon_sym_GT] = ACTIONS(120),
    [anon_sym_QMARK_QMARK] = ACTIONS(120),
    [anon_sym_instanceof] = ACTIONS(120),
    [anon_sym_TILDE] = ACTIONS(175),
    [anon_sym_void] = ACTIONS(177),
    [anon_sym_delete] = ACTIONS(179),
    [anon_sym_PLUS_PLUS] = ACTIONS(181),
    [anon_sym_DASH_DASH] = ACTIONS(181),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(188),
    [sym_number] = ACTIONS(190),
    [sym_private_property_identifier] = ACTIONS(192),
    [sym_this] = ACTIONS(194),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(198),
    [sym_false] = ACTIONS(198),
    [sym_null] = ACTIONS(198),
    [sym_undefined] = ACTIONS(200),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(113),
    [anon_sym_readonly] = ACTIONS(202),
    [anon_sym_get] = ACTIONS(113),
    [anon_sym_set] = ACTIONS(113),
    [anon_sym_QMARK] = ACTIONS(204),
    [anon_sym_declare] = ACTIONS(113),
    [anon_sym_public] = ACTIONS(113),
    [anon_sym_private] = ACTIONS(113),
    [anon_sym_protected] = ACTIONS(113),
    [anon_sym_override] = ACTIONS(113),
    [anon_sym_module] = ACTIONS(113),
    [anon_sym_any] = ACTIONS(206),
    [anon_sym_number] = ACTIONS(206),
    [anon_sym_boolean] = ACTIONS(206),
    [anon_sym_string] = ACTIONS(206),
    [anon_sym_symbol] = ACTIONS(206),
    [anon_sym_object] = ACTIONS(206),
    [anon_sym_abstract] = ACTIONS(208),
    [anon_sym_satisfies] = ACTIONS(120),
    [anon_sym_infer] = ACTIONS(210),
    [anon_sym_keyof] = ACTIONS(212),
    [anon_sym_unique] = ACTIONS(214),
    [anon_sym_unknown] = ACTIONS(216),
    [anon_sym_never] = ACTIONS(216),
    [anon_sym_LBRACE_PIPE] = ACTIONS(218),
    [sym__ternary_qmark] = ACTIONS(154),
    [sym_html_comment] = ACTIONS(5),
  },
  [4] = {
    [sym_export_statement] = STATE(892),
    [sym_declaration] = STATE(892),
    [sym_import] = STATE(3636),
    [sym_import_statement] = STATE(892),
    [sym_statement] = STATE(14),
    [sym_expression_statement] = STATE(892),
    [sym_variable_declaration] = STATE(831),
    [sym_lexical_declaration] = STATE(831),
    [sym_statement_block] = STATE(892),
    [sym_if_statement] = STATE(892),
    [sym_switch_statement] = STATE(892),
    [sym_for_statement] = STATE(892),
    [sym_for_in_statement] = STATE(892),
    [sym_while_statement] = STATE(892),
    [sym_do_statement] = STATE(892),
    [sym_try_statement] = STATE(892),
    [sym_with_statement] = STATE(892),
    [sym_break_statement] = STATE(892),
    [sym_continue_statement] = STATE(892),
    [sym_debugger_statement] = STATE(892),
    [sym_return_statement] = STATE(892),
    [sym_throw_statement] = STATE(892),
    [sym_empty_statement] = STATE(892),
    [sym_labeled_statement] = STATE(892),
    [sym_parenthesized_expression] = STATE(1362),
    [sym_expression] = STATE(1902),
    [sym_primary_expression] = STATE(1810),
    [sym_yield_expression] = STATE(2358),
    [sym_object] = STATE(2222),
    [sym_object_pattern] = STATE(5637),
    [sym_object_assignment_pattern] = STATE(4555),
    [sym_array] = STATE(2222),
    [sym_array_pattern] = STATE(5637),
    [sym_class] = STATE(2222),
    [sym_class_declaration] = STATE(831),
    [sym_function_expression] = STATE(2222),
    [sym_function_declaration] = STATE(831),
    [sym_generator_function] = STATE(2222),
    [sym_generator_function_declaration] = STATE(831),
    [sym_arrow_function] = STATE(2222),
    [sym__call_signature] = STATE(5821),
    [sym_call_expression] = STATE(2222),
    [sym_new_expression] = STATE(1948),
    [sym_await_expression] = STATE(2358),
    [sym_member_expression] = STATE(1362),
    [sym_subscript_expression] = STATE(1362),
    [sym_assignment_expression] = STATE(2358),
    [sym__augmented_assignment_lhs] = STATE(3025),
    [sym_augmented_assignment_expression] = STATE(2358),
    [sym__destructuring_pattern] = STATE(5637),
    [sym_spread_element] = STATE(4576),
    [sym_ternary_expression] = STATE(2358),
    [sym_binary_expression] = STATE(2358),
    [sym_unary_expression] = STATE(2358),
    [sym_update_expression] = STATE(2358),
    [sym_sequence_expression] = STATE(5305),
    [sym_string] = STATE(2202),
    [sym_template_string] = STATE(2222),
    [sym_regex] = STATE(2222),
    [sym_meta_property] = STATE(2222),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_rest_pattern] = STATE(4555),
    [sym_method_definition] = STATE(4576),
    [sym_pair] = STATE(4576),
    [sym_pair_pattern] = STATE(4555),
    [sym__property_name] = STATE(3648),
    [sym_computed_property_name] = STATE(3648),
    [sym_non_null_expression] = STATE(1362),
    [sym_function_signature] = STATE(831),
    [sym_type_assertion] = STATE(2358),
    [sym_as_expression] = STATE(2358),
    [sym_satisfies_expression] = STATE(2358),
    [sym_instantiation_expression] = STATE(2358),
    [sym_ambient_declaration] = STATE(831),
    [sym_abstract_class_declaration] = STATE(831),
    [sym_module] = STATE(831),
    [sym_internal_module] = STATE(214),
    [sym_import_alias] = STATE(831),
    [sym_interface_declaration] = STATE(831),
    [sym_enum_declaration] = STATE(831),
    [sym_type_alias_declaration] = STATE(831),
    [sym_accessibility_modifier] = STATE(2786),
    [sym_override_modifier] = STATE(2808),
    [sym_type_arguments] = STATE(428),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_program_repeat1] = STATE(14),
    [aux_sym_export_statement_repeat1] = STATE(3774),
    [aux_sym_object_repeat1] = STATE(4744),
    [aux_sym_object_pattern_repeat1] = STATE(4745),
    [sym_identifier] = ACTIONS(227),
    [anon_sym_export] = ACTIONS(229),
    [anon_sym_STAR] = ACTIONS(231),
    [anon_sym_type] = ACTIONS(233),
    [anon_sym_namespace] = ACTIONS(235),
    [anon_sym_LBRACE] = ACTIONS(19),
    [anon_sym_COMMA] = ACTIONS(237),
    [anon_sym_RBRACE] = ACTIONS(239),
    [anon_sym_typeof] = ACTIONS(21),
    [anon_sym_import] = ACTIONS(23),
    [anon_sym_with] = ACTIONS(25),
    [anon_sym_var] = ACTIONS(27),
    [anon_sym_let] = ACTIONS(241),
    [anon_sym_const] = ACTIONS(31),
    [anon_sym_BANG] = ACTIONS(33),
    [anon_sym_if] = ACTIONS(35),
    [anon_sym_switch] = ACTIONS(37),
    [anon_sym_for] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_SEMI] = ACTIONS(43),
    [anon_sym_await] = ACTIONS(45),
    [anon_sym_while] = ACTIONS(47),
    [anon_sym_do] = ACTIONS(49),
    [anon_sym_try] = ACTIONS(51),
    [anon_sym_break] = ACTIONS(53),
    [anon_sym_continue] = ACTIONS(55),
    [anon_sym_debugger] = ACTIONS(57),
    [anon_sym_return] = ACTIONS(59),
    [anon_sym_throw] = ACTIONS(61),
    [anon_sym_yield] = ACTIONS(63),
    [anon_sym_LBRACK] = ACTIONS(243),
    [anon_sym_class] = ACTIONS(67),
    [anon_sym_async] = ACTIONS(245),
    [anon_sym_function] = ACTIONS(71),
    [anon_sym_new] = ACTIONS(247),
    [anon_sym_using] = ACTIONS(75),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(249),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_SLASH] = ACTIONS(77),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(33),
    [anon_sym_void] = ACTIONS(21),
    [anon_sym_delete] = ACTIONS(21),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_DQUOTE] = ACTIONS(83),
    [anon_sym_SQUOTE] = ACTIONS(85),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(87),
    [sym_number] = ACTIONS(251),
    [sym_private_property_identifier] = ACTIONS(253),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(93),
    [sym_true] = ACTIONS(93),
    [sym_false] = ACTIONS(93),
    [sym_null] = ACTIONS(93),
    [sym_undefined] = ACTIONS(95),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(255),
    [anon_sym_readonly] = ACTIONS(257),
    [anon_sym_get] = ACTIONS(259),
    [anon_sym_set] = ACTIONS(259),
    [anon_sym_declare] = ACTIONS(261),
    [anon_sym_public] = ACTIONS(263),
    [anon_sym_private] = ACTIONS(263),
    [anon_sym_protected] = ACTIONS(263),
    [anon_sym_override] = ACTIONS(265),
    [anon_sym_module] = ACTIONS(267),
    [anon_sym_any] = ACTIONS(269),
    [anon_sym_number] = ACTIONS(269),
    [anon_sym_boolean] = ACTIONS(269),
    [anon_sym_string] = ACTIONS(269),
    [anon_sym_symbol] = ACTIONS(269),
    [anon_sym_object] = ACTIONS(269),
    [anon_sym_abstract] = ACTIONS(105),
    [anon_sym_interface] = ACTIONS(107),
    [anon_sym_enum] = ACTIONS(109),
    [sym_html_comment] = ACTIONS(5),
  },
  [5] = {
    [sym_export_statement] = STATE(892),
    [sym_declaration] = STATE(892),
    [sym_import] = STATE(3636),
    [sym_import_statement] = STATE(892),
    [sym_statement] = STATE(18),
    [sym_expression_statement] = STATE(892),
    [sym_variable_declaration] = STATE(831),
    [sym_lexical_declaration] = STATE(831),
    [sym_statement_block] = STATE(892),
    [sym_if_statement] = STATE(892),
    [sym_switch_statement] = STATE(892),
    [sym_for_statement] = STATE(892),
    [sym_for_in_statement] = STATE(892),
    [sym_while_statement] = STATE(892),
    [sym_do_statement] = STATE(892),
    [sym_try_statement] = STATE(892),
    [sym_with_statement] = STATE(892),
    [sym_break_statement] = STATE(892),
    [sym_continue_statement] = STATE(892),
    [sym_debugger_statement] = STATE(892),
    [sym_return_statement] = STATE(892),
    [sym_throw_statement] = STATE(892),
    [sym_empty_statement] = STATE(892),
    [sym_labeled_statement] = STATE(892),
    [sym_parenthesized_expression] = STATE(1362),
    [sym_expression] = STATE(1902),
    [sym_primary_expression] = STATE(1810),
    [sym_yield_expression] = STATE(2358),
    [sym_object] = STATE(2222),
    [sym_object_pattern] = STATE(5637),
    [sym_object_assignment_pattern] = STATE(4555),
    [sym_array] = STATE(2222),
    [sym_array_pattern] = STATE(5637),
    [sym_class] = STATE(2222),
    [sym_class_declaration] = STATE(831),
    [sym_function_expression] = STATE(2222),
    [sym_function_declaration] = STATE(831),
    [sym_generator_function] = STATE(2222),
    [sym_generator_function_declaration] = STATE(831),
    [sym_arrow_function] = STATE(2222),
    [sym__call_signature] = STATE(5821),
    [sym_call_expression] = STATE(2222),
    [sym_new_expression] = STATE(1948),
    [sym_await_expression] = STATE(2358),
    [sym_member_expression] = STATE(1362),
    [sym_subscript_expression] = STATE(1362),
    [sym_assignment_expression] = STATE(2358),
    [sym__augmented_assignment_lhs] = STATE(3025),
    [sym_augmented_assignment_expression] = STATE(2358),
    [sym__destructuring_pattern] = STATE(5637),
    [sym_spread_element] = STATE(4576),
    [sym_ternary_expression] = STATE(2358),
    [sym_binary_expression] = STATE(2358),
    [sym_unary_expression] = STATE(2358),
    [sym_update_expression] = STATE(2358),
    [sym_sequence_expression] = STATE(5305),
    [sym_string] = STATE(2202),
    [sym_template_string] = STATE(2222),
    [sym_regex] = STATE(2222),
    [sym_meta_property] = STATE(2222),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_rest_pattern] = STATE(4555),
    [sym_method_definition] = STATE(4576),
    [sym_pair] = STATE(4576),
    [sym_pair_pattern] = STATE(4555),
    [sym__property_name] = STATE(3648),
    [sym_computed_property_name] = STATE(3648),
    [sym_non_null_expression] = STATE(1362),
    [sym_function_signature] = STATE(831),
    [sym_type_assertion] = STATE(2358),
    [sym_as_expression] = STATE(2358),
    [sym_satisfies_expression] = STATE(2358),
    [sym_instantiation_expression] = STATE(2358),
    [sym_ambient_declaration] = STATE(831),
    [sym_abstract_class_declaration] = STATE(831),
    [sym_module] = STATE(831),
    [sym_internal_module] = STATE(214),
    [sym_import_alias] = STATE(831),
    [sym_interface_declaration] = STATE(831),
    [sym_enum_declaration] = STATE(831),
    [sym_type_alias_declaration] = STATE(831),
    [sym_accessibility_modifier] = STATE(2786),
    [sym_override_modifier] = STATE(2808),
    [sym_type_arguments] = STATE(428),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_program_repeat1] = STATE(18),
    [aux_sym_export_statement_repeat1] = STATE(3774),
    [aux_sym_object_repeat1] = STATE(4744),
    [aux_sym_object_pattern_repeat1] = STATE(4745),
    [sym_identifier] = ACTIONS(227),
    [anon_sym_export] = ACTIONS(229),
    [anon_sym_STAR] = ACTIONS(231),
    [anon_sym_type] = ACTIONS(233),
    [anon_sym_namespace] = ACTIONS(235),
    [anon_sym_LBRACE] = ACTIONS(19),
    [anon_sym_COMMA] = ACTIONS(237),
    [anon_sym_RBRACE] = ACTIONS(271),
    [anon_sym_typeof] = ACTIONS(21),
    [anon_sym_import] = ACTIONS(23),
    [anon_sym_with] = ACTIONS(25),
    [anon_sym_var] = ACTIONS(27),
    [anon_sym_let] = ACTIONS(241),
    [anon_sym_const] = ACTIONS(31),
    [anon_sym_BANG] = ACTIONS(33),
    [anon_sym_if] = ACTIONS(35),
    [anon_sym_switch] = ACTIONS(37),
    [anon_sym_for] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_SEMI] = ACTIONS(43),
    [anon_sym_await] = ACTIONS(45),
    [anon_sym_while] = ACTIONS(47),
    [anon_sym_do] = ACTIONS(49),
    [anon_sym_try] = ACTIONS(51),
    [anon_sym_break] = ACTIONS(53),
    [anon_sym_continue] = ACTIONS(55),
    [anon_sym_debugger] = ACTIONS(57),
    [anon_sym_return] = ACTIONS(59),
    [anon_sym_throw] = ACTIONS(61),
    [anon_sym_yield] = ACTIONS(63),
    [anon_sym_LBRACK] = ACTIONS(243),
    [anon_sym_class] = ACTIONS(67),
    [anon_sym_async] = ACTIONS(245),
    [anon_sym_function] = ACTIONS(71),
    [anon_sym_new] = ACTIONS(247),
    [anon_sym_using] = ACTIONS(75),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(249),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_SLASH] = ACTIONS(77),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(33),
    [anon_sym_void] = ACTIONS(21),
    [anon_sym_delete] = ACTIONS(21),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_DQUOTE] = ACTIONS(83),
    [anon_sym_SQUOTE] = ACTIONS(85),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(87),
    [sym_number] = ACTIONS(251),
    [sym_private_property_identifier] = ACTIONS(253),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(93),
    [sym_true] = ACTIONS(93),
    [sym_false] = ACTIONS(93),
    [sym_null] = ACTIONS(93),
    [sym_undefined] = ACTIONS(95),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(255),
    [anon_sym_readonly] = ACTIONS(257),
    [anon_sym_get] = ACTIONS(259),
    [anon_sym_set] = ACTIONS(259),
    [anon_sym_declare] = ACTIONS(261),
    [anon_sym_public] = ACTIONS(263),
    [anon_sym_private] = ACTIONS(263),
    [anon_sym_protected] = ACTIONS(263),
    [anon_sym_override] = ACTIONS(265),
    [anon_sym_module] = ACTIONS(267),
    [anon_sym_any] = ACTIONS(269),
    [anon_sym_number] = ACTIONS(269),
    [anon_sym_boolean] = ACTIONS(269),
    [anon_sym_string] = ACTIONS(269),
    [anon_sym_symbol] = ACTIONS(269),
    [anon_sym_object] = ACTIONS(269),
    [anon_sym_abstract] = ACTIONS(105),
    [anon_sym_interface] = ACTIONS(107),
    [anon_sym_enum] = ACTIONS(109),
    [sym_html_comment] = ACTIONS(5),
  },
  [6] = {
    [sym_export_statement] = STATE(892),
    [sym_declaration] = STATE(892),
    [sym_import] = STATE(3636),
    [sym_import_statement] = STATE(892),
    [sym_statement] = STATE(22),
    [sym_expression_statement] = STATE(892),
    [sym_variable_declaration] = STATE(831),
    [sym_lexical_declaration] = STATE(831),
    [sym_statement_block] = STATE(892),
    [sym_if_statement] = STATE(892),
    [sym_switch_statement] = STATE(892),
    [sym_for_statement] = STATE(892),
    [sym_for_in_statement] = STATE(892),
    [sym_while_statement] = STATE(892),
    [sym_do_statement] = STATE(892),
    [sym_try_statement] = STATE(892),
    [sym_with_statement] = STATE(892),
    [sym_break_statement] = STATE(892),
    [sym_continue_statement] = STATE(892),
    [sym_debugger_statement] = STATE(892),
    [sym_return_statement] = STATE(892),
    [sym_throw_statement] = STATE(892),
    [sym_empty_statement] = STATE(892),
    [sym_labeled_statement] = STATE(892),
    [sym_parenthesized_expression] = STATE(1362),
    [sym_expression] = STATE(1902),
    [sym_primary_expression] = STATE(1810),
    [sym_yield_expression] = STATE(2358),
    [sym_object] = STATE(2222),
    [sym_object_pattern] = STATE(5637),
    [sym_object_assignment_pattern] = STATE(4555),
    [sym_array] = STATE(2222),
    [sym_array_pattern] = STATE(5637),
    [sym_class] = STATE(2222),
    [sym_class_declaration] = STATE(831),
    [sym_function_expression] = STATE(2222),
    [sym_function_declaration] = STATE(831),
    [sym_generator_function] = STATE(2222),
    [sym_generator_function_declaration] = STATE(831),
    [sym_arrow_function] = STATE(2222),
    [sym__call_signature] = STATE(5821),
    [sym_call_expression] = STATE(2222),
    [sym_new_expression] = STATE(1948),
    [sym_await_expression] = STATE(2358),
    [sym_member_expression] = STATE(1362),
    [sym_subscript_expression] = STATE(1362),
    [sym_assignment_expression] = STATE(2358),
    [sym__augmented_assignment_lhs] = STATE(3025),
    [sym_augmented_assignment_expression] = STATE(2358),
    [sym__destructuring_pattern] = STATE(5637),
    [sym_spread_element] = STATE(4721),
    [sym_ternary_expression] = STATE(2358),
    [sym_binary_expression] = STATE(2358),
    [sym_unary_expression] = STATE(2358),
    [sym_update_expression] = STATE(2358),
    [sym_sequence_expression] = STATE(5305),
    [sym_string] = STATE(2202),
    [sym_template_string] = STATE(2222),
    [sym_regex] = STATE(2222),
    [sym_meta_property] = STATE(2222),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_rest_pattern] = STATE(4555),
    [sym_method_definition] = STATE(4721),
    [sym_pair] = STATE(4721),
    [sym_pair_pattern] = STATE(4555),
    [sym__property_name] = STATE(3648),
    [sym_computed_property_name] = STATE(3648),
    [sym_non_null_expression] = STATE(1362),
    [sym_function_signature] = STATE(831),
    [sym_type_assertion] = STATE(2358),
    [sym_as_expression] = STATE(2358),
    [sym_satisfies_expression] = STATE(2358),
    [sym_instantiation_expression] = STATE(2358),
    [sym_ambient_declaration] = STATE(831),
    [sym_abstract_class_declaration] = STATE(831),
    [sym_module] = STATE(831),
    [sym_internal_module] = STATE(214),
    [sym_import_alias] = STATE(831),
    [sym_interface_declaration] = STATE(831),
    [sym_enum_declaration] = STATE(831),
    [sym_type_alias_declaration] = STATE(831),
    [sym_accessibility_modifier] = STATE(2786),
    [sym_override_modifier] = STATE(2808),
    [sym_type_arguments] = STATE(428),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_program_repeat1] = STATE(22),
    [aux_sym_export_statement_repeat1] = STATE(3774),
    [aux_sym_object_repeat1] = STATE(4734),
    [aux_sym_object_pattern_repeat1] = STATE(4745),
    [sym_identifier] = ACTIONS(273),
    [anon_sym_export] = ACTIONS(275),
    [anon_sym_STAR] = ACTIONS(231),
    [anon_sym_type] = ACTIONS(277),
    [anon_sym_namespace] = ACTIONS(279),
    [anon_sym_LBRACE] = ACTIONS(19),
    [anon_sym_COMMA] = ACTIONS(237),
    [anon_sym_RBRACE] = ACTIONS(281),
    [anon_sym_typeof] = ACTIONS(21),
    [anon_sym_import] = ACTIONS(23),
    [anon_sym_with] = ACTIONS(25),
    [anon_sym_var] = ACTIONS(27),
    [anon_sym_let] = ACTIONS(283),
    [anon_sym_const] = ACTIONS(31),
    [anon_sym_BANG] = ACTIONS(33),
    [anon_sym_if] = ACTIONS(35),
    [anon_sym_switch] = ACTIONS(37),
    [anon_sym_for] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_SEMI] = ACTIONS(43),
    [anon_sym_await] = ACTIONS(45),
    [anon_sym_while] = ACTIONS(47),
    [anon_sym_do] = ACTIONS(49),
    [anon_sym_try] = ACTIONS(51),
    [anon_sym_break] = ACTIONS(53),
    [anon_sym_continue] = ACTIONS(55),
    [anon_sym_debugger] = ACTIONS(57),
    [anon_sym_return] = ACTIONS(59),
    [anon_sym_throw] = ACTIONS(61),
    [anon_sym_yield] = ACTIONS(63),
    [anon_sym_LBRACK] = ACTIONS(243),
    [anon_sym_class] = ACTIONS(67),
    [anon_sym_async] = ACTIONS(285),
    [anon_sym_function] = ACTIONS(71),
    [anon_sym_new] = ACTIONS(287),
    [anon_sym_using] = ACTIONS(75),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(249),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_SLASH] = ACTIONS(77),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(33),
    [anon_sym_void] = ACTIONS(21),
    [anon_sym_delete] = ACTIONS(21),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_DQUOTE] = ACTIONS(83),
    [anon_sym_SQUOTE] = ACTIONS(85),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(87),
    [sym_number] = ACTIONS(251),
    [sym_private_property_identifier] = ACTIONS(253),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(93),
    [sym_true] = ACTIONS(93),
    [sym_false] = ACTIONS(93),
    [sym_null] = ACTIONS(93),
    [sym_undefined] = ACTIONS(95),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(289),
    [anon_sym_readonly] = ACTIONS(291),
    [anon_sym_get] = ACTIONS(293),
    [anon_sym_set] = ACTIONS(293),
    [anon_sym_declare] = ACTIONS(295),
    [anon_sym_public] = ACTIONS(297),
    [anon_sym_private] = ACTIONS(297),
    [anon_sym_protected] = ACTIONS(297),
    [anon_sym_override] = ACTIONS(299),
    [anon_sym_module] = ACTIONS(301),
    [anon_sym_any] = ACTIONS(303),
    [anon_sym_number] = ACTIONS(303),
    [anon_sym_boolean] = ACTIONS(303),
    [anon_sym_string] = ACTIONS(303),
    [anon_sym_symbol] = ACTIONS(303),
    [anon_sym_object] = ACTIONS(303),
    [anon_sym_abstract] = ACTIONS(105),
    [anon_sym_interface] = ACTIONS(107),
    [anon_sym_enum] = ACTIONS(109),
    [sym_html_comment] = ACTIONS(5),
  },
  [7] = {
    [sym_export_statement] = STATE(892),
    [sym_declaration] = STATE(892),
    [sym_import] = STATE(3636),
    [sym_import_statement] = STATE(892),
    [sym_statement] = STATE(14),
    [sym_expression_statement] = STATE(892),
    [sym_variable_declaration] = STATE(831),
    [sym_lexical_declaration] = STATE(831),
    [sym_statement_block] = STATE(892),
    [sym_if_statement] = STATE(892),
    [sym_switch_statement] = STATE(892),
    [sym_for_statement] = STATE(892),
    [sym_for_in_statement] = STATE(892),
    [sym_while_statement] = STATE(892),
    [sym_do_statement] = STATE(892),
    [sym_try_statement] = STATE(892),
    [sym_with_statement] = STATE(892),
    [sym_break_statement] = STATE(892),
    [sym_continue_statement] = STATE(892),
    [sym_debugger_statement] = STATE(892),
    [sym_return_statement] = STATE(892),
    [sym_throw_statement] = STATE(892),
    [sym_empty_statement] = STATE(892),
    [sym_labeled_statement] = STATE(892),
    [sym_parenthesized_expression] = STATE(1362),
    [sym_expression] = STATE(1902),
    [sym_primary_expression] = STATE(1810),
    [sym_yield_expression] = STATE(2358),
    [sym_object] = STATE(2222),
    [sym_object_pattern] = STATE(5637),
    [sym_object_assignment_pattern] = STATE(4555),
    [sym_array] = STATE(2222),
    [sym_array_pattern] = STATE(5637),
    [sym_class] = STATE(2222),
    [sym_class_declaration] = STATE(831),
    [sym_function_expression] = STATE(2222),
    [sym_function_declaration] = STATE(831),
    [sym_generator_function] = STATE(2222),
    [sym_generator_function_declaration] = STATE(831),
    [sym_arrow_function] = STATE(2222),
    [sym__call_signature] = STATE(5821),
    [sym_call_expression] = STATE(2222),
    [sym_new_expression] = STATE(1948),
    [sym_await_expression] = STATE(2358),
    [sym_member_expression] = STATE(1362),
    [sym_subscript_expression] = STATE(1362),
    [sym_assignment_expression] = STATE(2358),
    [sym__augmented_assignment_lhs] = STATE(3025),
    [sym_augmented_assignment_expression] = STATE(2358),
    [sym__destructuring_pattern] = STATE(5637),
    [sym_spread_element] = STATE(4576),
    [sym_ternary_expression] = STATE(2358),
    [sym_binary_expression] = STATE(2358),
    [sym_unary_expression] = STATE(2358),
    [sym_update_expression] = STATE(2358),
    [sym_sequence_expression] = STATE(5305),
    [sym_string] = STATE(2202),
    [sym_template_string] = STATE(2222),
    [sym_regex] = STATE(2222),
    [sym_meta_property] = STATE(2222),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_rest_pattern] = STATE(4555),
    [sym_method_definition] = STATE(4576),
    [sym_pair] = STATE(4576),
    [sym_pair_pattern] = STATE(4555),
    [sym__property_name] = STATE(3648),
    [sym_computed_property_name] = STATE(3648),
    [sym_non_null_expression] = STATE(1362),
    [sym_function_signature] = STATE(831),
    [sym_type_assertion] = STATE(2358),
    [sym_as_expression] = STATE(2358),
    [sym_satisfies_expression] = STATE(2358),
    [sym_instantiation_expression] = STATE(2358),
    [sym_ambient_declaration] = STATE(831),
    [sym_abstract_class_declaration] = STATE(831),
    [sym_module] = STATE(831),
    [sym_internal_module] = STATE(214),
    [sym_import_alias] = STATE(831),
    [sym_interface_declaration] = STATE(831),
    [sym_enum_declaration] = STATE(831),
    [sym_type_alias_declaration] = STATE(831),
    [sym_accessibility_modifier] = STATE(2786),
    [sym_override_modifier] = STATE(2808),
    [sym_type_arguments] = STATE(428),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_program_repeat1] = STATE(14),
    [aux_sym_export_statement_repeat1] = STATE(3774),
    [aux_sym_object_repeat1] = STATE(4744),
    [aux_sym_object_pattern_repeat1] = STATE(4745),
    [sym_identifier] = ACTIONS(227),
    [anon_sym_export] = ACTIONS(229),
    [anon_sym_STAR] = ACTIONS(231),
    [anon_sym_type] = ACTIONS(233),
    [anon_sym_namespace] = ACTIONS(235),
    [anon_sym_LBRACE] = ACTIONS(19),
    [anon_sym_COMMA] = ACTIONS(237),
    [anon_sym_RBRACE] = ACTIONS(305),
    [anon_sym_typeof] = ACTIONS(21),
    [anon_sym_import] = ACTIONS(23),
    [anon_sym_with] = ACTIONS(25),
    [anon_sym_var] = ACTIONS(27),
    [anon_sym_let] = ACTIONS(241),
    [anon_sym_const] = ACTIONS(31),
    [anon_sym_BANG] = ACTIONS(33),
    [anon_sym_if] = ACTIONS(35),
    [anon_sym_switch] = ACTIONS(37),
    [anon_sym_for] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_SEMI] = ACTIONS(43),
    [anon_sym_await] = ACTIONS(45),
    [anon_sym_while] = ACTIONS(47),
    [anon_sym_do] = ACTIONS(49),
    [anon_sym_try] = ACTIONS(51),
    [anon_sym_break] = ACTIONS(53),
    [anon_sym_continue] = ACTIONS(55),
    [anon_sym_debugger] = ACTIONS(57),
    [anon_sym_return] = ACTIONS(59),
    [anon_sym_throw] = ACTIONS(61),
    [anon_sym_yield] = ACTIONS(63),
    [anon_sym_LBRACK] = ACTIONS(243),
    [anon_sym_class] = ACTIONS(67),
    [anon_sym_async] = ACTIONS(245),
    [anon_sym_function] = ACTIONS(71),
    [anon_sym_new] = ACTIONS(247),
    [anon_sym_using] = ACTIONS(75),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(249),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_SLASH] = ACTIONS(77),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(33),
    [anon_sym_void] = ACTIONS(21),
    [anon_sym_delete] = ACTIONS(21),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_DQUOTE] = ACTIONS(83),
    [anon_sym_SQUOTE] = ACTIONS(85),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(87),
    [sym_number] = ACTIONS(251),
    [sym_private_property_identifier] = ACTIONS(253),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(93),
    [sym_true] = ACTIONS(93),
    [sym_false] = ACTIONS(93),
    [sym_null] = ACTIONS(93),
    [sym_undefined] = ACTIONS(95),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(255),
    [anon_sym_readonly] = ACTIONS(257),
    [anon_sym_get] = ACTIONS(259),
    [anon_sym_set] = ACTIONS(259),
    [anon_sym_declare] = ACTIONS(261),
    [anon_sym_public] = ACTIONS(263),
    [anon_sym_private] = ACTIONS(263),
    [anon_sym_protected] = ACTIONS(263),
    [anon_sym_override] = ACTIONS(265),
    [anon_sym_module] = ACTIONS(267),
    [anon_sym_any] = ACTIONS(269),
    [anon_sym_number] = ACTIONS(269),
    [anon_sym_boolean] = ACTIONS(269),
    [anon_sym_string] = ACTIONS(269),
    [anon_sym_symbol] = ACTIONS(269),
    [anon_sym_object] = ACTIONS(269),
    [anon_sym_abstract] = ACTIONS(105),
    [anon_sym_interface] = ACTIONS(107),
    [anon_sym_enum] = ACTIONS(109),
    [sym_html_comment] = ACTIONS(5),
  },
  [8] = {
    [sym_export_statement] = STATE(892),
    [sym_declaration] = STATE(892),
    [sym_import] = STATE(3636),
    [sym_import_statement] = STATE(892),
    [sym_statement] = STATE(22),
    [sym_expression_statement] = STATE(892),
    [sym_variable_declaration] = STATE(831),
    [sym_lexical_declaration] = STATE(831),
    [sym_statement_block] = STATE(892),
    [sym_if_statement] = STATE(892),
    [sym_switch_statement] = STATE(892),
    [sym_for_statement] = STATE(892),
    [sym_for_in_statement] = STATE(892),
    [sym_while_statement] = STATE(892),
    [sym_do_statement] = STATE(892),
    [sym_try_statement] = STATE(892),
    [sym_with_statement] = STATE(892),
    [sym_break_statement] = STATE(892),
    [sym_continue_statement] = STATE(892),
    [sym_debugger_statement] = STATE(892),
    [sym_return_statement] = STATE(892),
    [sym_throw_statement] = STATE(892),
    [sym_empty_statement] = STATE(892),
    [sym_labeled_statement] = STATE(892),
    [sym_parenthesized_expression] = STATE(1362),
    [sym_expression] = STATE(1902),
    [sym_primary_expression] = STATE(1810),
    [sym_yield_expression] = STATE(2358),
    [sym_object] = STATE(2222),
    [sym_object_pattern] = STATE(5637),
    [sym_object_assignment_pattern] = STATE(4555),
    [sym_array] = STATE(2222),
    [sym_array_pattern] = STATE(5637),
    [sym_class] = STATE(2222),
    [sym_class_declaration] = STATE(831),
    [sym_function_expression] = STATE(2222),
    [sym_function_declaration] = STATE(831),
    [sym_generator_function] = STATE(2222),
    [sym_generator_function_declaration] = STATE(831),
    [sym_arrow_function] = STATE(2222),
    [sym__call_signature] = STATE(5821),
    [sym_call_expression] = STATE(2222),
    [sym_new_expression] = STATE(1948),
    [sym_await_expression] = STATE(2358),
    [sym_member_expression] = STATE(1362),
    [sym_subscript_expression] = STATE(1362),
    [sym_assignment_expression] = STATE(2358),
    [sym__augmented_assignment_lhs] = STATE(3025),
    [sym_augmented_assignment_expression] = STATE(2358),
    [sym__destructuring_pattern] = STATE(5637),
    [sym_spread_element] = STATE(4721),
    [sym_ternary_expression] = STATE(2358),
    [sym_binary_expression] = STATE(2358),
    [sym_unary_expression] = STATE(2358),
    [sym_update_expression] = STATE(2358),
    [sym_sequence_expression] = STATE(5305),
    [sym_string] = STATE(2202),
    [sym_template_string] = STATE(2222),
    [sym_regex] = STATE(2222),
    [sym_meta_property] = STATE(2222),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_rest_pattern] = STATE(4555),
    [sym_method_definition] = STATE(4721),
    [sym_pair] = STATE(4721),
    [sym_pair_pattern] = STATE(4555),
    [sym__property_name] = STATE(3648),
    [sym_computed_property_name] = STATE(3648),
    [sym_non_null_expression] = STATE(1362),
    [sym_function_signature] = STATE(831),
    [sym_type_assertion] = STATE(2358),
    [sym_as_expression] = STATE(2358),
    [sym_satisfies_expression] = STATE(2358),
    [sym_instantiation_expression] = STATE(2358),
    [sym_ambient_declaration] = STATE(831),
    [sym_abstract_class_declaration] = STATE(831),
    [sym_module] = STATE(831),
    [sym_internal_module] = STATE(214),
    [sym_import_alias] = STATE(831),
    [sym_interface_declaration] = STATE(831),
    [sym_enum_declaration] = STATE(831),
    [sym_type_alias_declaration] = STATE(831),
    [sym_accessibility_modifier] = STATE(2786),
    [sym_override_modifier] = STATE(2808),
    [sym_type_arguments] = STATE(428),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_program_repeat1] = STATE(22),
    [aux_sym_export_statement_repeat1] = STATE(3774),
    [aux_sym_object_repeat1] = STATE(4734),
    [aux_sym_object_pattern_repeat1] = STATE(4745),
    [sym_identifier] = ACTIONS(307),
    [anon_sym_export] = ACTIONS(309),
    [anon_sym_STAR] = ACTIONS(231),
    [anon_sym_type] = ACTIONS(311),
    [anon_sym_namespace] = ACTIONS(313),
    [anon_sym_LBRACE] = ACTIONS(19),
    [anon_sym_COMMA] = ACTIONS(237),
    [anon_sym_RBRACE] = ACTIONS(281),
    [anon_sym_typeof] = ACTIONS(21),
    [anon_sym_import] = ACTIONS(23),
    [anon_sym_with] = ACTIONS(25),
    [anon_sym_var] = ACTIONS(27),
    [anon_sym_let] = ACTIONS(315),
    [anon_sym_const] = ACTIONS(31),
    [anon_sym_BANG] = ACTIONS(33),
    [anon_sym_if] = ACTIONS(35),
    [anon_sym_switch] = ACTIONS(37),
    [anon_sym_for] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_SEMI] = ACTIONS(43),
    [anon_sym_await] = ACTIONS(45),
    [anon_sym_while] = ACTIONS(47),
    [anon_sym_do] = ACTIONS(49),
    [anon_sym_try] = ACTIONS(51),
    [anon_sym_break] = ACTIONS(53),
    [anon_sym_continue] = ACTIONS(55),
    [anon_sym_debugger] = ACTIONS(57),
    [anon_sym_return] = ACTIONS(59),
    [anon_sym_throw] = ACTIONS(61),
    [anon_sym_yield] = ACTIONS(63),
    [anon_sym_LBRACK] = ACTIONS(243),
    [anon_sym_class] = ACTIONS(67),
    [anon_sym_async] = ACTIONS(317),
    [anon_sym_function] = ACTIONS(71),
    [anon_sym_new] = ACTIONS(319),
    [anon_sym_using] = ACTIONS(75),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(249),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_SLASH] = ACTIONS(77),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(33),
    [anon_sym_void] = ACTIONS(21),
    [anon_sym_delete] = ACTIONS(21),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_DQUOTE] = ACTIONS(83),
    [anon_sym_SQUOTE] = ACTIONS(85),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(87),
    [sym_number] = ACTIONS(251),
    [sym_private_property_identifier] = ACTIONS(253),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(93),
    [sym_true] = ACTIONS(93),
    [sym_false] = ACTIONS(93),
    [sym_null] = ACTIONS(93),
    [sym_undefined] = ACTIONS(95),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(321),
    [anon_sym_readonly] = ACTIONS(323),
    [anon_sym_get] = ACTIONS(325),
    [anon_sym_set] = ACTIONS(325),
    [anon_sym_declare] = ACTIONS(327),
    [anon_sym_public] = ACTIONS(329),
    [anon_sym_private] = ACTIONS(329),
    [anon_sym_protected] = ACTIONS(329),
    [anon_sym_override] = ACTIONS(331),
    [anon_sym_module] = ACTIONS(333),
    [anon_sym_any] = ACTIONS(335),
    [anon_sym_number] = ACTIONS(335),
    [anon_sym_boolean] = ACTIONS(335),
    [anon_sym_string] = ACTIONS(335),
    [anon_sym_symbol] = ACTIONS(335),
    [anon_sym_object] = ACTIONS(335),
    [anon_sym_abstract] = ACTIONS(105),
    [anon_sym_interface] = ACTIONS(107),
    [anon_sym_enum] = ACTIONS(109),
    [sym_html_comment] = ACTIONS(5),
  },
  [9] = {
    [sym_export_statement] = STATE(892),
    [sym_declaration] = STATE(892),
    [sym_import] = STATE(3636),
    [sym_import_statement] = STATE(892),
    [sym_statement] = STATE(9),
    [sym_expression_statement] = STATE(892),
    [sym_variable_declaration] = STATE(831),
    [sym_lexical_declaration] = STATE(831),
    [sym_statement_block] = STATE(892),
    [sym_if_statement] = STATE(892),
    [sym_switch_statement] = STATE(892),
    [sym_for_statement] = STATE(892),
    [sym_for_in_statement] = STATE(892),
    [sym_while_statement] = STATE(892),
    [sym_do_statement] = STATE(892),
    [sym_try_statement] = STATE(892),
    [sym_with_statement] = STATE(892),
    [sym_break_statement] = STATE(892),
    [sym_continue_statement] = STATE(892),
    [sym_debugger_statement] = STATE(892),
    [sym_return_statement] = STATE(892),
    [sym_throw_statement] = STATE(892),
    [sym_empty_statement] = STATE(892),
    [sym_labeled_statement] = STATE(892),
    [sym_parenthesized_expression] = STATE(1362),
    [sym_expression] = STATE(1902),
    [sym_primary_expression] = STATE(1810),
    [sym_yield_expression] = STATE(2358),
    [sym_object] = STATE(2222),
    [sym_object_pattern] = STATE(5492),
    [sym_array] = STATE(2222),
    [sym_array_pattern] = STATE(5492),
    [sym_class] = STATE(2222),
    [sym_class_declaration] = STATE(831),
    [sym_function_expression] = STATE(2222),
    [sym_function_declaration] = STATE(831),
    [sym_generator_function] = STATE(2222),
    [sym_generator_function_declaration] = STATE(831),
    [sym_arrow_function] = STATE(2222),
    [sym__call_signature] = STATE(5821),
    [sym_call_expression] = STATE(2222),
    [sym_new_expression] = STATE(1948),
    [sym_await_expression] = STATE(2358),
    [sym_member_expression] = STATE(1362),
    [sym_subscript_expression] = STATE(1362),
    [sym_assignment_expression] = STATE(2358),
    [sym__augmented_assignment_lhs] = STATE(3025),
    [sym_augmented_assignment_expression] = STATE(2358),
    [sym__destructuring_pattern] = STATE(5492),
    [sym_ternary_expression] = STATE(2358),
    [sym_binary_expression] = STATE(2358),
    [sym_unary_expression] = STATE(2358),
    [sym_update_expression] = STATE(2358),
    [sym_sequence_expression] = STATE(5305),
    [sym_string] = STATE(2222),
    [sym_template_string] = STATE(2222),
    [sym_regex] = STATE(2222),
    [sym_meta_property] = STATE(2222),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1362),
    [sym_function_signature] = STATE(831),
    [sym_type_assertion] = STATE(2358),
    [sym_as_expression] = STATE(2358),
    [sym_satisfies_expression] = STATE(2358),
    [sym_instantiation_expression] = STATE(2358),
    [sym_ambient_declaration] = STATE(831),
    [sym_abstract_class_declaration] = STATE(831),
    [sym_module] = STATE(831),
    [sym_internal_module] = STATE(214),
    [sym_import_alias] = STATE(831),
    [sym_interface_declaration] = STATE(831),
    [sym_enum_declaration] = STATE(831),
    [sym_type_alias_declaration] = STATE(831),
    [sym_type_arguments] = STATE(428),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_program_repeat1] = STATE(9),
    [aux_sym_export_statement_repeat1] = STATE(3774),
    [ts_builtin_sym_end] = ACTIONS(337),
    [sym_identifier] = ACTIONS(339),
    [anon_sym_export] = ACTIONS(342),
    [anon_sym_default] = ACTIONS(345),
    [anon_sym_type] = ACTIONS(347),
    [anon_sym_namespace] = ACTIONS(350),
    [anon_sym_LBRACE] = ACTIONS(353),
    [anon_sym_RBRACE] = ACTIONS(337),
    [anon_sym_typeof] = ACTIONS(356),
    [anon_sym_import] = ACTIONS(359),
    [anon_sym_with] = ACTIONS(362),
    [anon_sym_var] = ACTIONS(365),
    [anon_sym_let] = ACTIONS(368),
    [anon_sym_const] = ACTIONS(371),
    [anon_sym_BANG] = ACTIONS(374),
    [anon_sym_if] = ACTIONS(377),
    [anon_sym_switch] = ACTIONS(380),
    [anon_sym_for] = ACTIONS(383),
    [anon_sym_LPAREN] = ACTIONS(386),
    [anon_sym_SEMI] = ACTIONS(389),
    [anon_sym_await] = ACTIONS(392),
    [anon_sym_while] = ACTIONS(395),
    [anon_sym_do] = ACTIONS(398),
    [anon_sym_try] = ACTIONS(401),
    [anon_sym_break] = ACTIONS(404),
    [anon_sym_continue] = ACTIONS(407),
    [anon_sym_debugger] = ACTIONS(410),
    [anon_sym_return] = ACTIONS(413),
    [anon_sym_throw] = ACTIONS(416),
    [anon_sym_case] = ACTIONS(345),
    [anon_sym_yield] = ACTIONS(419),
    [anon_sym_LBRACK] = ACTIONS(422),
    [anon_sym_class] = ACTIONS(425),
    [anon_sym_async] = ACTIONS(428),
    [anon_sym_function] = ACTIONS(431),
    [anon_sym_new] = ACTIONS(434),
    [anon_sym_using] = ACTIONS(437),
    [anon_sym_PLUS] = ACTIONS(356),
    [anon_sym_DASH] = ACTIONS(356),
    [anon_sym_SLASH] = ACTIONS(440),
    [anon_sym_LT] = ACTIONS(443),
    [anon_sym_TILDE] = ACTIONS(374),
    [anon_sym_void] = ACTIONS(356),
    [anon_sym_delete] = ACTIONS(356),
    [anon_sym_PLUS_PLUS] = ACTIONS(446),
    [anon_sym_DASH_DASH] = ACTIONS(446),
    [anon_sym_DQUOTE] = ACTIONS(449),
    [anon_sym_SQUOTE] = ACTIONS(452),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(455),
    [sym_number] = ACTIONS(458),
    [sym_private_property_identifier] = ACTIONS(461),
    [sym_this] = ACTIONS(464),
    [sym_super] = ACTIONS(464),
    [sym_true] = ACTIONS(464),
    [sym_false] = ACTIONS(464),
    [sym_null] = ACTIONS(464),
    [sym_undefined] = ACTIONS(467),
    [anon_sym_AT] = ACTIONS(470),
    [anon_sym_static] = ACTIONS(473),
    [anon_sym_readonly] = ACTIONS(473),
    [anon_sym_get] = ACTIONS(473),
    [anon_sym_set] = ACTIONS(473),
    [anon_sym_declare] = ACTIONS(476),
    [anon_sym_public] = ACTIONS(473),
    [anon_sym_private] = ACTIONS(473),
    [anon_sym_protected] = ACTIONS(473),
    [anon_sym_override] = ACTIONS(473),
    [anon_sym_module] = ACTIONS(479),
    [anon_sym_any] = ACTIONS(473),
    [anon_sym_number] = ACTIONS(473),
    [anon_sym_boolean] = ACTIONS(473),
    [anon_sym_string] = ACTIONS(473),
    [anon_sym_symbol] = ACTIONS(473),
    [anon_sym_object] = ACTIONS(473),
    [anon_sym_abstract] = ACTIONS(482),
    [anon_sym_interface] = ACTIONS(485),
    [anon_sym_enum] = ACTIONS(488),
    [sym_html_comment] = ACTIONS(5),
  },
  [10] = {
    [sym_export_statement] = STATE(892),
    [sym_declaration] = STATE(892),
    [sym_import] = STATE(3636),
    [sym_import_statement] = STATE(892),
    [sym_statement] = STATE(9),
    [sym_expression_statement] = STATE(892),
    [sym_variable_declaration] = STATE(831),
    [sym_lexical_declaration] = STATE(831),
    [sym_statement_block] = STATE(892),
    [sym_if_statement] = STATE(892),
    [sym_switch_statement] = STATE(892),
    [sym_for_statement] = STATE(892),
    [sym_for_in_statement] = STATE(892),
    [sym_while_statement] = STATE(892),
    [sym_do_statement] = STATE(892),
    [sym_try_statement] = STATE(892),
    [sym_with_statement] = STATE(892),
    [sym_break_statement] = STATE(892),
    [sym_continue_statement] = STATE(892),
    [sym_debugger_statement] = STATE(892),
    [sym_return_statement] = STATE(892),
    [sym_throw_statement] = STATE(892),
    [sym_empty_statement] = STATE(892),
    [sym_labeled_statement] = STATE(892),
    [sym_parenthesized_expression] = STATE(1362),
    [sym_expression] = STATE(1902),
    [sym_primary_expression] = STATE(1810),
    [sym_yield_expression] = STATE(2358),
    [sym_object] = STATE(2222),
    [sym_object_pattern] = STATE(5492),
    [sym_array] = STATE(2222),
    [sym_array_pattern] = STATE(5492),
    [sym_class] = STATE(2222),
    [sym_class_declaration] = STATE(831),
    [sym_function_expression] = STATE(2222),
    [sym_function_declaration] = STATE(831),
    [sym_generator_function] = STATE(2222),
    [sym_generator_function_declaration] = STATE(831),
    [sym_arrow_function] = STATE(2222),
    [sym__call_signature] = STATE(5821),
    [sym_call_expression] = STATE(2222),
    [sym_new_expression] = STATE(1948),
    [sym_await_expression] = STATE(2358),
    [sym_member_expression] = STATE(1362),
    [sym_subscript_expression] = STATE(1362),
    [sym_assignment_expression] = STATE(2358),
    [sym__augmented_assignment_lhs] = STATE(3025),
    [sym_augmented_assignment_expression] = STATE(2358),
    [sym__destructuring_pattern] = STATE(5492),
    [sym_ternary_expression] = STATE(2358),
    [sym_binary_expression] = STATE(2358),
    [sym_unary_expression] = STATE(2358),
    [sym_update_expression] = STATE(2358),
    [sym_sequence_expression] = STATE(5305),
    [sym_string] = STATE(2222),
    [sym_template_string] = STATE(2222),
    [sym_regex] = STATE(2222),
    [sym_meta_property] = STATE(2222),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1362),
    [sym_function_signature] = STATE(831),
    [sym_type_assertion] = STATE(2358),
    [sym_as_expression] = STATE(2358),
    [sym_satisfies_expression] = STATE(2358),
    [sym_instantiation_expression] = STATE(2358),
    [sym_ambient_declaration] = STATE(831),
    [sym_abstract_class_declaration] = STATE(831),
    [sym_module] = STATE(831),
    [sym_internal_module] = STATE(214),
    [sym_import_alias] = STATE(831),
    [sym_interface_declaration] = STATE(831),
    [sym_enum_declaration] = STATE(831),
    [sym_type_alias_declaration] = STATE(831),
    [sym_type_arguments] = STATE(428),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_program_repeat1] = STATE(9),
    [aux_sym_export_statement_repeat1] = STATE(3774),
    [sym_identifier] = ACTIONS(9),
    [anon_sym_export] = ACTIONS(13),
    [anon_sym_default] = ACTIONS(491),
    [anon_sym_type] = ACTIONS(15),
    [anon_sym_namespace] = ACTIONS(17),
    [anon_sym_LBRACE] = ACTIONS(19),
    [anon_sym_RBRACE] = ACTIONS(493),
    [anon_sym_typeof] = ACTIONS(21),
    [anon_sym_import] = ACTIONS(23),
    [anon_sym_with] = ACTIONS(25),
    [anon_sym_var] = ACTIONS(27),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_const] = ACTIONS(31),
    [anon_sym_BANG] = ACTIONS(33),
    [anon_sym_if] = ACTIONS(35),
    [anon_sym_switch] = ACTIONS(37),
    [anon_sym_for] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_SEMI] = ACTIONS(43),
    [anon_sym_await] = ACTIONS(45),
    [anon_sym_while] = ACTIONS(47),
    [anon_sym_do] = ACTIONS(49),
    [anon_sym_try] = ACTIONS(51),
    [anon_sym_break] = ACTIONS(53),
    [anon_sym_continue] = ACTIONS(55),
    [anon_sym_debugger] = ACTIONS(57),
    [anon_sym_return] = ACTIONS(59),
    [anon_sym_throw] = ACTIONS(61),
    [anon_sym_case] = ACTIONS(491),
    [anon_sym_yield] = ACTIONS(63),
    [anon_sym_LBRACK] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(67),
    [anon_sym_async] = ACTIONS(69),
    [anon_sym_function] = ACTIONS(71),
    [anon_sym_new] = ACTIONS(73),
    [anon_sym_using] = ACTIONS(75),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_SLASH] = ACTIONS(77),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(33),
    [anon_sym_void] = ACTIONS(21),
    [anon_sym_delete] = ACTIONS(21),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_DQUOTE] = ACTIONS(83),
    [anon_sym_SQUOTE] = ACTIONS(85),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(87),
    [sym_number] = ACTIONS(89),
    [sym_private_property_identifier] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(93),
    [sym_true] = ACTIONS(93),
    [sym_false] = ACTIONS(93),
    [sym_null] = ACTIONS(93),
    [sym_undefined] = ACTIONS(95),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(99),
    [anon_sym_readonly] = ACTIONS(99),
    [anon_sym_get] = ACTIONS(99),
    [anon_sym_set] = ACTIONS(99),
    [anon_sym_declare] = ACTIONS(101),
    [anon_sym_public] = ACTIONS(99),
    [anon_sym_private] = ACTIONS(99),
    [anon_sym_protected] = ACTIONS(99),
    [anon_sym_override] = ACTIONS(99),
    [anon_sym_module] = ACTIONS(103),
    [anon_sym_any] = ACTIONS(99),
    [anon_sym_number] = ACTIONS(99),
    [anon_sym_boolean] = ACTIONS(99),
    [anon_sym_string] = ACTIONS(99),
    [anon_sym_symbol] = ACTIONS(99),
    [anon_sym_object] = ACTIONS(99),
    [anon_sym_abstract] = ACTIONS(105),
    [anon_sym_interface] = ACTIONS(107),
    [anon_sym_enum] = ACTIONS(109),
    [sym_html_comment] = ACTIONS(5),
  },
  [11] = {
    [sym_export_statement] = STATE(892),
    [sym_declaration] = STATE(892),
    [sym_import] = STATE(3636),
    [sym_import_statement] = STATE(892),
    [sym_statement] = STATE(10),
    [sym_expression_statement] = STATE(892),
    [sym_variable_declaration] = STATE(831),
    [sym_lexical_declaration] = STATE(831),
    [sym_statement_block] = STATE(892),
    [sym_if_statement] = STATE(892),
    [sym_switch_statement] = STATE(892),
    [sym_for_statement] = STATE(892),
    [sym_for_in_statement] = STATE(892),
    [sym_while_statement] = STATE(892),
    [sym_do_statement] = STATE(892),
    [sym_try_statement] = STATE(892),
    [sym_with_statement] = STATE(892),
    [sym_break_statement] = STATE(892),
    [sym_continue_statement] = STATE(892),
    [sym_debugger_statement] = STATE(892),
    [sym_return_statement] = STATE(892),
    [sym_throw_statement] = STATE(892),
    [sym_empty_statement] = STATE(892),
    [sym_labeled_statement] = STATE(892),
    [sym_parenthesized_expression] = STATE(1362),
    [sym_expression] = STATE(1902),
    [sym_primary_expression] = STATE(1810),
    [sym_yield_expression] = STATE(2358),
    [sym_object] = STATE(2222),
    [sym_object_pattern] = STATE(5492),
    [sym_array] = STATE(2222),
    [sym_array_pattern] = STATE(5492),
    [sym_class] = STATE(2222),
    [sym_class_declaration] = STATE(831),
    [sym_function_expression] = STATE(2222),
    [sym_function_declaration] = STATE(831),
    [sym_generator_function] = STATE(2222),
    [sym_generator_function_declaration] = STATE(831),
    [sym_arrow_function] = STATE(2222),
    [sym__call_signature] = STATE(5821),
    [sym_call_expression] = STATE(2222),
    [sym_new_expression] = STATE(1948),
    [sym_await_expression] = STATE(2358),
    [sym_member_expression] = STATE(1362),
    [sym_subscript_expression] = STATE(1362),
    [sym_assignment_expression] = STATE(2358),
    [sym__augmented_assignment_lhs] = STATE(3025),
    [sym_augmented_assignment_expression] = STATE(2358),
    [sym__destructuring_pattern] = STATE(5492),
    [sym_ternary_expression] = STATE(2358),
    [sym_binary_expression] = STATE(2358),
    [sym_unary_expression] = STATE(2358),
    [sym_update_expression] = STATE(2358),
    [sym_sequence_expression] = STATE(5305),
    [sym_string] = STATE(2222),
    [sym_template_string] = STATE(2222),
    [sym_regex] = STATE(2222),
    [sym_meta_property] = STATE(2222),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1362),
    [sym_function_signature] = STATE(831),
    [sym_type_assertion] = STATE(2358),
    [sym_as_expression] = STATE(2358),
    [sym_satisfies_expression] = STATE(2358),
    [sym_instantiation_expression] = STATE(2358),
    [sym_ambient_declaration] = STATE(831),
    [sym_abstract_class_declaration] = STATE(831),
    [sym_module] = STATE(831),
    [sym_internal_module] = STATE(214),
    [sym_import_alias] = STATE(831),
    [sym_interface_declaration] = STATE(831),
    [sym_enum_declaration] = STATE(831),
    [sym_type_alias_declaration] = STATE(831),
    [sym_type_arguments] = STATE(428),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_program_repeat1] = STATE(10),
    [aux_sym_export_statement_repeat1] = STATE(3774),
    [sym_identifier] = ACTIONS(9),
    [anon_sym_export] = ACTIONS(13),
    [anon_sym_default] = ACTIONS(495),
    [anon_sym_type] = ACTIONS(15),
    [anon_sym_namespace] = ACTIONS(17),
    [anon_sym_LBRACE] = ACTIONS(19),
    [anon_sym_RBRACE] = ACTIONS(497),
    [anon_sym_typeof] = ACTIONS(21),
    [anon_sym_import] = ACTIONS(23),
    [anon_sym_with] = ACTIONS(25),
    [anon_sym_var] = ACTIONS(27),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_const] = ACTIONS(31),
    [anon_sym_BANG] = ACTIONS(33),
    [anon_sym_if] = ACTIONS(35),
    [anon_sym_switch] = ACTIONS(37),
    [anon_sym_for] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_SEMI] = ACTIONS(43),
    [anon_sym_await] = ACTIONS(45),
    [anon_sym_while] = ACTIONS(47),
    [anon_sym_do] = ACTIONS(49),
    [anon_sym_try] = ACTIONS(51),
    [anon_sym_break] = ACTIONS(53),
    [anon_sym_continue] = ACTIONS(55),
    [anon_sym_debugger] = ACTIONS(57),
    [anon_sym_return] = ACTIONS(59),
    [anon_sym_throw] = ACTIONS(61),
    [anon_sym_case] = ACTIONS(495),
    [anon_sym_yield] = ACTIONS(63),
    [anon_sym_LBRACK] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(67),
    [anon_sym_async] = ACTIONS(69),
    [anon_sym_function] = ACTIONS(71),
    [anon_sym_new] = ACTIONS(73),
    [anon_sym_using] = ACTIONS(75),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_SLASH] = ACTIONS(77),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(33),
    [anon_sym_void] = ACTIONS(21),
    [anon_sym_delete] = ACTIONS(21),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_DQUOTE] = ACTIONS(83),
    [anon_sym_SQUOTE] = ACTIONS(85),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(87),
    [sym_number] = ACTIONS(89),
    [sym_private_property_identifier] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(93),
    [sym_true] = ACTIONS(93),
    [sym_false] = ACTIONS(93),
    [sym_null] = ACTIONS(93),
    [sym_undefined] = ACTIONS(95),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(99),
    [anon_sym_readonly] = ACTIONS(99),
    [anon_sym_get] = ACTIONS(99),
    [anon_sym_set] = ACTIONS(99),
    [anon_sym_declare] = ACTIONS(101),
    [anon_sym_public] = ACTIONS(99),
    [anon_sym_private] = ACTIONS(99),
    [anon_sym_protected] = ACTIONS(99),
    [anon_sym_override] = ACTIONS(99),
    [anon_sym_module] = ACTIONS(103),
    [anon_sym_any] = ACTIONS(99),
    [anon_sym_number] = ACTIONS(99),
    [anon_sym_boolean] = ACTIONS(99),
    [anon_sym_string] = ACTIONS(99),
    [anon_sym_symbol] = ACTIONS(99),
    [anon_sym_object] = ACTIONS(99),
    [anon_sym_abstract] = ACTIONS(105),
    [anon_sym_interface] = ACTIONS(107),
    [anon_sym_enum] = ACTIONS(109),
    [sym_html_comment] = ACTIONS(5),
  },
  [12] = {
    [sym_export_statement] = STATE(892),
    [sym_declaration] = STATE(892),
    [sym_import] = STATE(3636),
    [sym_import_statement] = STATE(892),
    [sym_statement] = STATE(13),
    [sym_expression_statement] = STATE(892),
    [sym_variable_declaration] = STATE(831),
    [sym_lexical_declaration] = STATE(831),
    [sym_statement_block] = STATE(892),
    [sym_if_statement] = STATE(892),
    [sym_switch_statement] = STATE(892),
    [sym_for_statement] = STATE(892),
    [sym_for_in_statement] = STATE(892),
    [sym_while_statement] = STATE(892),
    [sym_do_statement] = STATE(892),
    [sym_try_statement] = STATE(892),
    [sym_with_statement] = STATE(892),
    [sym_break_statement] = STATE(892),
    [sym_continue_statement] = STATE(892),
    [sym_debugger_statement] = STATE(892),
    [sym_return_statement] = STATE(892),
    [sym_throw_statement] = STATE(892),
    [sym_empty_statement] = STATE(892),
    [sym_labeled_statement] = STATE(892),
    [sym_parenthesized_expression] = STATE(1362),
    [sym_expression] = STATE(1902),
    [sym_primary_expression] = STATE(1810),
    [sym_yield_expression] = STATE(2358),
    [sym_object] = STATE(2222),
    [sym_object_pattern] = STATE(5492),
    [sym_array] = STATE(2222),
    [sym_array_pattern] = STATE(5492),
    [sym_class] = STATE(2222),
    [sym_class_declaration] = STATE(831),
    [sym_function_expression] = STATE(2222),
    [sym_function_declaration] = STATE(831),
    [sym_generator_function] = STATE(2222),
    [sym_generator_function_declaration] = STATE(831),
    [sym_arrow_function] = STATE(2222),
    [sym__call_signature] = STATE(5821),
    [sym_call_expression] = STATE(2222),
    [sym_new_expression] = STATE(1948),
    [sym_await_expression] = STATE(2358),
    [sym_member_expression] = STATE(1362),
    [sym_subscript_expression] = STATE(1362),
    [sym_assignment_expression] = STATE(2358),
    [sym__augmented_assignment_lhs] = STATE(3025),
    [sym_augmented_assignment_expression] = STATE(2358),
    [sym__destructuring_pattern] = STATE(5492),
    [sym_ternary_expression] = STATE(2358),
    [sym_binary_expression] = STATE(2358),
    [sym_unary_expression] = STATE(2358),
    [sym_update_expression] = STATE(2358),
    [sym_sequence_expression] = STATE(5305),
    [sym_string] = STATE(2222),
    [sym_template_string] = STATE(2222),
    [sym_regex] = STATE(2222),
    [sym_meta_property] = STATE(2222),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1362),
    [sym_function_signature] = STATE(831),
    [sym_type_assertion] = STATE(2358),
    [sym_as_expression] = STATE(2358),
    [sym_satisfies_expression] = STATE(2358),
    [sym_instantiation_expression] = STATE(2358),
    [sym_ambient_declaration] = STATE(831),
    [sym_abstract_class_declaration] = STATE(831),
    [sym_module] = STATE(831),
    [sym_internal_module] = STATE(214),
    [sym_import_alias] = STATE(831),
    [sym_interface_declaration] = STATE(831),
    [sym_enum_declaration] = STATE(831),
    [sym_type_alias_declaration] = STATE(831),
    [sym_type_arguments] = STATE(428),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_program_repeat1] = STATE(13),
    [aux_sym_export_statement_repeat1] = STATE(3774),
    [sym_identifier] = ACTIONS(9),
    [anon_sym_export] = ACTIONS(13),
    [anon_sym_default] = ACTIONS(499),
    [anon_sym_type] = ACTIONS(15),
    [anon_sym_namespace] = ACTIONS(17),
    [anon_sym_LBRACE] = ACTIONS(19),
    [anon_sym_RBRACE] = ACTIONS(501),
    [anon_sym_typeof] = ACTIONS(21),
    [anon_sym_import] = ACTIONS(23),
    [anon_sym_with] = ACTIONS(25),
    [anon_sym_var] = ACTIONS(27),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_const] = ACTIONS(31),
    [anon_sym_BANG] = ACTIONS(33),
    [anon_sym_if] = ACTIONS(35),
    [anon_sym_switch] = ACTIONS(37),
    [anon_sym_for] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_SEMI] = ACTIONS(43),
    [anon_sym_await] = ACTIONS(45),
    [anon_sym_while] = ACTIONS(47),
    [anon_sym_do] = ACTIONS(49),
    [anon_sym_try] = ACTIONS(51),
    [anon_sym_break] = ACTIONS(53),
    [anon_sym_continue] = ACTIONS(55),
    [anon_sym_debugger] = ACTIONS(57),
    [anon_sym_return] = ACTIONS(59),
    [anon_sym_throw] = ACTIONS(61),
    [anon_sym_case] = ACTIONS(499),
    [anon_sym_yield] = ACTIONS(63),
    [anon_sym_LBRACK] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(67),
    [anon_sym_async] = ACTIONS(69),
    [anon_sym_function] = ACTIONS(71),
    [anon_sym_new] = ACTIONS(73),
    [anon_sym_using] = ACTIONS(75),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_SLASH] = ACTIONS(77),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(33),
    [anon_sym_void] = ACTIONS(21),
    [anon_sym_delete] = ACTIONS(21),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_DQUOTE] = ACTIONS(83),
    [anon_sym_SQUOTE] = ACTIONS(85),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(87),
    [sym_number] = ACTIONS(89),
    [sym_private_property_identifier] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(93),
    [sym_true] = ACTIONS(93),
    [sym_false] = ACTIONS(93),
    [sym_null] = ACTIONS(93),
    [sym_undefined] = ACTIONS(95),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(99),
    [anon_sym_readonly] = ACTIONS(99),
    [anon_sym_get] = ACTIONS(99),
    [anon_sym_set] = ACTIONS(99),
    [anon_sym_declare] = ACTIONS(101),
    [anon_sym_public] = ACTIONS(99),
    [anon_sym_private] = ACTIONS(99),
    [anon_sym_protected] = ACTIONS(99),
    [anon_sym_override] = ACTIONS(99),
    [anon_sym_module] = ACTIONS(103),
    [anon_sym_any] = ACTIONS(99),
    [anon_sym_number] = ACTIONS(99),
    [anon_sym_boolean] = ACTIONS(99),
    [anon_sym_string] = ACTIONS(99),
    [anon_sym_symbol] = ACTIONS(99),
    [anon_sym_object] = ACTIONS(99),
    [anon_sym_abstract] = ACTIONS(105),
    [anon_sym_interface] = ACTIONS(107),
    [anon_sym_enum] = ACTIONS(109),
    [sym_html_comment] = ACTIONS(5),
  },
  [13] = {
    [sym_export_statement] = STATE(892),
    [sym_declaration] = STATE(892),
    [sym_import] = STATE(3636),
    [sym_import_statement] = STATE(892),
    [sym_statement] = STATE(9),
    [sym_expression_statement] = STATE(892),
    [sym_variable_declaration] = STATE(831),
    [sym_lexical_declaration] = STATE(831),
    [sym_statement_block] = STATE(892),
    [sym_if_statement] = STATE(892),
    [sym_switch_statement] = STATE(892),
    [sym_for_statement] = STATE(892),
    [sym_for_in_statement] = STATE(892),
    [sym_while_statement] = STATE(892),
    [sym_do_statement] = STATE(892),
    [sym_try_statement] = STATE(892),
    [sym_with_statement] = STATE(892),
    [sym_break_statement] = STATE(892),
    [sym_continue_statement] = STATE(892),
    [sym_debugger_statement] = STATE(892),
    [sym_return_statement] = STATE(892),
    [sym_throw_statement] = STATE(892),
    [sym_empty_statement] = STATE(892),
    [sym_labeled_statement] = STATE(892),
    [sym_parenthesized_expression] = STATE(1362),
    [sym_expression] = STATE(1902),
    [sym_primary_expression] = STATE(1810),
    [sym_yield_expression] = STATE(2358),
    [sym_object] = STATE(2222),
    [sym_object_pattern] = STATE(5492),
    [sym_array] = STATE(2222),
    [sym_array_pattern] = STATE(5492),
    [sym_class] = STATE(2222),
    [sym_class_declaration] = STATE(831),
    [sym_function_expression] = STATE(2222),
    [sym_function_declaration] = STATE(831),
    [sym_generator_function] = STATE(2222),
    [sym_generator_function_declaration] = STATE(831),
    [sym_arrow_function] = STATE(2222),
    [sym__call_signature] = STATE(5821),
    [sym_call_expression] = STATE(2222),
    [sym_new_expression] = STATE(1948),
    [sym_await_expression] = STATE(2358),
    [sym_member_expression] = STATE(1362),
    [sym_subscript_expression] = STATE(1362),
    [sym_assignment_expression] = STATE(2358),
    [sym__augmented_assignment_lhs] = STATE(3025),
    [sym_augmented_assignment_expression] = STATE(2358),
    [sym__destructuring_pattern] = STATE(5492),
    [sym_ternary_expression] = STATE(2358),
    [sym_binary_expression] = STATE(2358),
    [sym_unary_expression] = STATE(2358),
    [sym_update_expression] = STATE(2358),
    [sym_sequence_expression] = STATE(5305),
    [sym_string] = STATE(2222),
    [sym_template_string] = STATE(2222),
    [sym_regex] = STATE(2222),
    [sym_meta_property] = STATE(2222),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1362),
    [sym_function_signature] = STATE(831),
    [sym_type_assertion] = STATE(2358),
    [sym_as_expression] = STATE(2358),
    [sym_satisfies_expression] = STATE(2358),
    [sym_instantiation_expression] = STATE(2358),
    [sym_ambient_declaration] = STATE(831),
    [sym_abstract_class_declaration] = STATE(831),
    [sym_module] = STATE(831),
    [sym_internal_module] = STATE(214),
    [sym_import_alias] = STATE(831),
    [sym_interface_declaration] = STATE(831),
    [sym_enum_declaration] = STATE(831),
    [sym_type_alias_declaration] = STATE(831),
    [sym_type_arguments] = STATE(428),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_program_repeat1] = STATE(9),
    [aux_sym_export_statement_repeat1] = STATE(3774),
    [sym_identifier] = ACTIONS(9),
    [anon_sym_export] = ACTIONS(13),
    [anon_sym_default] = ACTIONS(503),
    [anon_sym_type] = ACTIONS(15),
    [anon_sym_namespace] = ACTIONS(17),
    [anon_sym_LBRACE] = ACTIONS(19),
    [anon_sym_RBRACE] = ACTIONS(505),
    [anon_sym_typeof] = ACTIONS(21),
    [anon_sym_import] = ACTIONS(23),
    [anon_sym_with] = ACTIONS(25),
    [anon_sym_var] = ACTIONS(27),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_const] = ACTIONS(31),
    [anon_sym_BANG] = ACTIONS(33),
    [anon_sym_if] = ACTIONS(35),
    [anon_sym_switch] = ACTIONS(37),
    [anon_sym_for] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_SEMI] = ACTIONS(43),
    [anon_sym_await] = ACTIONS(45),
    [anon_sym_while] = ACTIONS(47),
    [anon_sym_do] = ACTIONS(49),
    [anon_sym_try] = ACTIONS(51),
    [anon_sym_break] = ACTIONS(53),
    [anon_sym_continue] = ACTIONS(55),
    [anon_sym_debugger] = ACTIONS(57),
    [anon_sym_return] = ACTIONS(59),
    [anon_sym_throw] = ACTIONS(61),
    [anon_sym_case] = ACTIONS(503),
    [anon_sym_yield] = ACTIONS(63),
    [anon_sym_LBRACK] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(67),
    [anon_sym_async] = ACTIONS(69),
    [anon_sym_function] = ACTIONS(71),
    [anon_sym_new] = ACTIONS(73),
    [anon_sym_using] = ACTIONS(75),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_SLASH] = ACTIONS(77),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(33),
    [anon_sym_void] = ACTIONS(21),
    [anon_sym_delete] = ACTIONS(21),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_DQUOTE] = ACTIONS(83),
    [anon_sym_SQUOTE] = ACTIONS(85),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(87),
    [sym_number] = ACTIONS(89),
    [sym_private_property_identifier] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(93),
    [sym_true] = ACTIONS(93),
    [sym_false] = ACTIONS(93),
    [sym_null] = ACTIONS(93),
    [sym_undefined] = ACTIONS(95),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(99),
    [anon_sym_readonly] = ACTIONS(99),
    [anon_sym_get] = ACTIONS(99),
    [anon_sym_set] = ACTIONS(99),
    [anon_sym_declare] = ACTIONS(101),
    [anon_sym_public] = ACTIONS(99),
    [anon_sym_private] = ACTIONS(99),
    [anon_sym_protected] = ACTIONS(99),
    [anon_sym_override] = ACTIONS(99),
    [anon_sym_module] = ACTIONS(103),
    [anon_sym_any] = ACTIONS(99),
    [anon_sym_number] = ACTIONS(99),
    [anon_sym_boolean] = ACTIONS(99),
    [anon_sym_string] = ACTIONS(99),
    [anon_sym_symbol] = ACTIONS(99),
    [anon_sym_object] = ACTIONS(99),
    [anon_sym_abstract] = ACTIONS(105),
    [anon_sym_interface] = ACTIONS(107),
    [anon_sym_enum] = ACTIONS(109),
    [sym_html_comment] = ACTIONS(5),
  },
  [14] = {
    [sym_export_statement] = STATE(892),
    [sym_declaration] = STATE(892),
    [sym_import] = STATE(3636),
    [sym_import_statement] = STATE(892),
    [sym_statement] = STATE(9),
    [sym_expression_statement] = STATE(892),
    [sym_variable_declaration] = STATE(831),
    [sym_lexical_declaration] = STATE(831),
    [sym_statement_block] = STATE(892),
    [sym_if_statement] = STATE(892),
    [sym_switch_statement] = STATE(892),
    [sym_for_statement] = STATE(892),
    [sym_for_in_statement] = STATE(892),
    [sym_while_statement] = STATE(892),
    [sym_do_statement] = STATE(892),
    [sym_try_statement] = STATE(892),
    [sym_with_statement] = STATE(892),
    [sym_break_statement] = STATE(892),
    [sym_continue_statement] = STATE(892),
    [sym_debugger_statement] = STATE(892),
    [sym_return_statement] = STATE(892),
    [sym_throw_statement] = STATE(892),
    [sym_empty_statement] = STATE(892),
    [sym_labeled_statement] = STATE(892),
    [sym_parenthesized_expression] = STATE(1362),
    [sym_expression] = STATE(1902),
    [sym_primary_expression] = STATE(1810),
    [sym_yield_expression] = STATE(2358),
    [sym_object] = STATE(2222),
    [sym_object_pattern] = STATE(5492),
    [sym_array] = STATE(2222),
    [sym_array_pattern] = STATE(5492),
    [sym_class] = STATE(2222),
    [sym_class_declaration] = STATE(831),
    [sym_function_expression] = STATE(2222),
    [sym_function_declaration] = STATE(831),
    [sym_generator_function] = STATE(2222),
    [sym_generator_function_declaration] = STATE(831),
    [sym_arrow_function] = STATE(2222),
    [sym__call_signature] = STATE(5821),
    [sym_call_expression] = STATE(2222),
    [sym_new_expression] = STATE(1948),
    [sym_await_expression] = STATE(2358),
    [sym_member_expression] = STATE(1362),
    [sym_subscript_expression] = STATE(1362),
    [sym_assignment_expression] = STATE(2358),
    [sym__augmented_assignment_lhs] = STATE(3025),
    [sym_augmented_assignment_expression] = STATE(2358),
    [sym__destructuring_pattern] = STATE(5492),
    [sym_ternary_expression] = STATE(2358),
    [sym_binary_expression] = STATE(2358),
    [sym_unary_expression] = STATE(2358),
    [sym_update_expression] = STATE(2358),
    [sym_sequence_expression] = STATE(5305),
    [sym_string] = STATE(2222),
    [sym_template_string] = STATE(2222),
    [sym_regex] = STATE(2222),
    [sym_meta_property] = STATE(2222),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1362),
    [sym_function_signature] = STATE(831),
    [sym_type_assertion] = STATE(2358),
    [sym_as_expression] = STATE(2358),
    [sym_satisfies_expression] = STATE(2358),
    [sym_instantiation_expression] = STATE(2358),
    [sym_ambient_declaration] = STATE(831),
    [sym_abstract_class_declaration] = STATE(831),
    [sym_module] = STATE(831),
    [sym_internal_module] = STATE(214),
    [sym_import_alias] = STATE(831),
    [sym_interface_declaration] = STATE(831),
    [sym_enum_declaration] = STATE(831),
    [sym_type_alias_declaration] = STATE(831),
    [sym_type_arguments] = STATE(428),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_program_repeat1] = STATE(9),
    [aux_sym_export_statement_repeat1] = STATE(3774),
    [sym_identifier] = ACTIONS(9),
    [anon_sym_export] = ACTIONS(13),
    [anon_sym_type] = ACTIONS(15),
    [anon_sym_namespace] = ACTIONS(17),
    [anon_sym_LBRACE] = ACTIONS(19),
    [anon_sym_RBRACE] = ACTIONS(507),
    [anon_sym_typeof] = ACTIONS(21),
    [anon_sym_import] = ACTIONS(23),
    [anon_sym_with] = ACTIONS(25),
    [anon_sym_var] = ACTIONS(27),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_const] = ACTIONS(31),
    [anon_sym_BANG] = ACTIONS(33),
    [anon_sym_if] = ACTIONS(35),
    [anon_sym_switch] = ACTIONS(37),
    [anon_sym_for] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_SEMI] = ACTIONS(43),
    [anon_sym_await] = ACTIONS(45),
    [anon_sym_while] = ACTIONS(47),
    [anon_sym_do] = ACTIONS(49),
    [anon_sym_try] = ACTIONS(51),
    [anon_sym_break] = ACTIONS(53),
    [anon_sym_continue] = ACTIONS(55),
    [anon_sym_debugger] = ACTIONS(57),
    [anon_sym_return] = ACTIONS(59),
    [anon_sym_throw] = ACTIONS(61),
    [anon_sym_yield] = ACTIONS(63),
    [anon_sym_LBRACK] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(67),
    [anon_sym_async] = ACTIONS(69),
    [anon_sym_function] = ACTIONS(71),
    [anon_sym_new] = ACTIONS(73),
    [anon_sym_using] = ACTIONS(75),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_SLASH] = ACTIONS(77),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(33),
    [anon_sym_void] = ACTIONS(21),
    [anon_sym_delete] = ACTIONS(21),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_DQUOTE] = ACTIONS(83),
    [anon_sym_SQUOTE] = ACTIONS(85),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(87),
    [sym_number] = ACTIONS(89),
    [sym_private_property_identifier] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(93),
    [sym_true] = ACTIONS(93),
    [sym_false] = ACTIONS(93),
    [sym_null] = ACTIONS(93),
    [sym_undefined] = ACTIONS(95),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(99),
    [anon_sym_readonly] = ACTIONS(99),
    [anon_sym_get] = ACTIONS(99),
    [anon_sym_set] = ACTIONS(99),
    [anon_sym_declare] = ACTIONS(101),
    [anon_sym_public] = ACTIONS(99),
    [anon_sym_private] = ACTIONS(99),
    [anon_sym_protected] = ACTIONS(99),
    [anon_sym_override] = ACTIONS(99),
    [anon_sym_module] = ACTIONS(103),
    [anon_sym_any] = ACTIONS(99),
    [anon_sym_number] = ACTIONS(99),
    [anon_sym_boolean] = ACTIONS(99),
    [anon_sym_string] = ACTIONS(99),
    [anon_sym_symbol] = ACTIONS(99),
    [anon_sym_object] = ACTIONS(99),
    [anon_sym_abstract] = ACTIONS(105),
    [anon_sym_interface] = ACTIONS(107),
    [anon_sym_enum] = ACTIONS(109),
    [sym_html_comment] = ACTIONS(5),
  },
  [15] = {
    [sym_export_statement] = STATE(892),
    [sym_declaration] = STATE(892),
    [sym_import] = STATE(3636),
    [sym_import_statement] = STATE(892),
    [sym_statement] = STATE(9),
    [sym_expression_statement] = STATE(892),
    [sym_variable_declaration] = STATE(831),
    [sym_lexical_declaration] = STATE(831),
    [sym_statement_block] = STATE(892),
    [sym_if_statement] = STATE(892),
    [sym_switch_statement] = STATE(892),
    [sym_for_statement] = STATE(892),
    [sym_for_in_statement] = STATE(892),
    [sym_while_statement] = STATE(892),
    [sym_do_statement] = STATE(892),
    [sym_try_statement] = STATE(892),
    [sym_with_statement] = STATE(892),
    [sym_break_statement] = STATE(892),
    [sym_continue_statement] = STATE(892),
    [sym_debugger_statement] = STATE(892),
    [sym_return_statement] = STATE(892),
    [sym_throw_statement] = STATE(892),
    [sym_empty_statement] = STATE(892),
    [sym_labeled_statement] = STATE(892),
    [sym_parenthesized_expression] = STATE(1362),
    [sym_expression] = STATE(1902),
    [sym_primary_expression] = STATE(1810),
    [sym_yield_expression] = STATE(2358),
    [sym_object] = STATE(2222),
    [sym_object_pattern] = STATE(5492),
    [sym_array] = STATE(2222),
    [sym_array_pattern] = STATE(5492),
    [sym_class] = STATE(2222),
    [sym_class_declaration] = STATE(831),
    [sym_function_expression] = STATE(2222),
    [sym_function_declaration] = STATE(831),
    [sym_generator_function] = STATE(2222),
    [sym_generator_function_declaration] = STATE(831),
    [sym_arrow_function] = STATE(2222),
    [sym__call_signature] = STATE(5821),
    [sym_call_expression] = STATE(2222),
    [sym_new_expression] = STATE(1948),
    [sym_await_expression] = STATE(2358),
    [sym_member_expression] = STATE(1362),
    [sym_subscript_expression] = STATE(1362),
    [sym_assignment_expression] = STATE(2358),
    [sym__augmented_assignment_lhs] = STATE(3025),
    [sym_augmented_assignment_expression] = STATE(2358),
    [sym__destructuring_pattern] = STATE(5492),
    [sym_ternary_expression] = STATE(2358),
    [sym_binary_expression] = STATE(2358),
    [sym_unary_expression] = STATE(2358),
    [sym_update_expression] = STATE(2358),
    [sym_sequence_expression] = STATE(5305),
    [sym_string] = STATE(2222),
    [sym_template_string] = STATE(2222),
    [sym_regex] = STATE(2222),
    [sym_meta_property] = STATE(2222),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1362),
    [sym_function_signature] = STATE(831),
    [sym_type_assertion] = STATE(2358),
    [sym_as_expression] = STATE(2358),
    [sym_satisfies_expression] = STATE(2358),
    [sym_instantiation_expression] = STATE(2358),
    [sym_ambient_declaration] = STATE(831),
    [sym_abstract_class_declaration] = STATE(831),
    [sym_module] = STATE(831),
    [sym_internal_module] = STATE(214),
    [sym_import_alias] = STATE(831),
    [sym_interface_declaration] = STATE(831),
    [sym_enum_declaration] = STATE(831),
    [sym_type_alias_declaration] = STATE(831),
    [sym_type_arguments] = STATE(428),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_program_repeat1] = STATE(9),
    [aux_sym_export_statement_repeat1] = STATE(3774),
    [sym_identifier] = ACTIONS(9),
    [anon_sym_export] = ACTIONS(13),
    [anon_sym_type] = ACTIONS(15),
    [anon_sym_namespace] = ACTIONS(17),
    [anon_sym_LBRACE] = ACTIONS(19),
    [anon_sym_RBRACE] = ACTIONS(509),
    [anon_sym_typeof] = ACTIONS(21),
    [anon_sym_import] = ACTIONS(23),
    [anon_sym_with] = ACTIONS(25),
    [anon_sym_var] = ACTIONS(27),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_const] = ACTIONS(31),
    [anon_sym_BANG] = ACTIONS(33),
    [anon_sym_if] = ACTIONS(35),
    [anon_sym_switch] = ACTIONS(37),
    [anon_sym_for] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_SEMI] = ACTIONS(43),
    [anon_sym_await] = ACTIONS(45),
    [anon_sym_while] = ACTIONS(47),
    [anon_sym_do] = ACTIONS(49),
    [anon_sym_try] = ACTIONS(51),
    [anon_sym_break] = ACTIONS(53),
    [anon_sym_continue] = ACTIONS(55),
    [anon_sym_debugger] = ACTIONS(57),
    [anon_sym_return] = ACTIONS(59),
    [anon_sym_throw] = ACTIONS(61),
    [anon_sym_yield] = ACTIONS(63),
    [anon_sym_LBRACK] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(67),
    [anon_sym_async] = ACTIONS(69),
    [anon_sym_function] = ACTIONS(71),
    [anon_sym_new] = ACTIONS(73),
    [anon_sym_using] = ACTIONS(75),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_SLASH] = ACTIONS(77),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(33),
    [anon_sym_void] = ACTIONS(21),
    [anon_sym_delete] = ACTIONS(21),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_DQUOTE] = ACTIONS(83),
    [anon_sym_SQUOTE] = ACTIONS(85),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(87),
    [sym_number] = ACTIONS(89),
    [sym_private_property_identifier] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(93),
    [sym_true] = ACTIONS(93),
    [sym_false] = ACTIONS(93),
    [sym_null] = ACTIONS(93),
    [sym_undefined] = ACTIONS(95),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(99),
    [anon_sym_readonly] = ACTIONS(99),
    [anon_sym_get] = ACTIONS(99),
    [anon_sym_set] = ACTIONS(99),
    [anon_sym_declare] = ACTIONS(101),
    [anon_sym_public] = ACTIONS(99),
    [anon_sym_private] = ACTIONS(99),
    [anon_sym_protected] = ACTIONS(99),
    [anon_sym_override] = ACTIONS(99),
    [anon_sym_module] = ACTIONS(103),
    [anon_sym_any] = ACTIONS(99),
    [anon_sym_number] = ACTIONS(99),
    [anon_sym_boolean] = ACTIONS(99),
    [anon_sym_string] = ACTIONS(99),
    [anon_sym_symbol] = ACTIONS(99),
    [anon_sym_object] = ACTIONS(99),
    [anon_sym_abstract] = ACTIONS(105),
    [anon_sym_interface] = ACTIONS(107),
    [anon_sym_enum] = ACTIONS(109),
    [sym_html_comment] = ACTIONS(5),
  },
  [16] = {
    [sym_export_statement] = STATE(892),
    [sym_declaration] = STATE(892),
    [sym_import] = STATE(3636),
    [sym_import_statement] = STATE(892),
    [sym_statement] = STATE(9),
    [sym_expression_statement] = STATE(892),
    [sym_variable_declaration] = STATE(831),
    [sym_lexical_declaration] = STATE(831),
    [sym_statement_block] = STATE(892),
    [sym_if_statement] = STATE(892),
    [sym_switch_statement] = STATE(892),
    [sym_for_statement] = STATE(892),
    [sym_for_in_statement] = STATE(892),
    [sym_while_statement] = STATE(892),
    [sym_do_statement] = STATE(892),
    [sym_try_statement] = STATE(892),
    [sym_with_statement] = STATE(892),
    [sym_break_statement] = STATE(892),
    [sym_continue_statement] = STATE(892),
    [sym_debugger_statement] = STATE(892),
    [sym_return_statement] = STATE(892),
    [sym_throw_statement] = STATE(892),
    [sym_empty_statement] = STATE(892),
    [sym_labeled_statement] = STATE(892),
    [sym_parenthesized_expression] = STATE(1362),
    [sym_expression] = STATE(1902),
    [sym_primary_expression] = STATE(1810),
    [sym_yield_expression] = STATE(2358),
    [sym_object] = STATE(2222),
    [sym_object_pattern] = STATE(5492),
    [sym_array] = STATE(2222),
    [sym_array_pattern] = STATE(5492),
    [sym_class] = STATE(2222),
    [sym_class_declaration] = STATE(831),
    [sym_function_expression] = STATE(2222),
    [sym_function_declaration] = STATE(831),
    [sym_generator_function] = STATE(2222),
    [sym_generator_function_declaration] = STATE(831),
    [sym_arrow_function] = STATE(2222),
    [sym__call_signature] = STATE(5821),
    [sym_call_expression] = STATE(2222),
    [sym_new_expression] = STATE(1948),
    [sym_await_expression] = STATE(2358),
    [sym_member_expression] = STATE(1362),
    [sym_subscript_expression] = STATE(1362),
    [sym_assignment_expression] = STATE(2358),
    [sym__augmented_assignment_lhs] = STATE(3025),
    [sym_augmented_assignment_expression] = STATE(2358),
    [sym__destructuring_pattern] = STATE(5492),
    [sym_ternary_expression] = STATE(2358),
    [sym_binary_expression] = STATE(2358),
    [sym_unary_expression] = STATE(2358),
    [sym_update_expression] = STATE(2358),
    [sym_sequence_expression] = STATE(5305),
    [sym_string] = STATE(2222),
    [sym_template_string] = STATE(2222),
    [sym_regex] = STATE(2222),
    [sym_meta_property] = STATE(2222),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1362),
    [sym_function_signature] = STATE(831),
    [sym_type_assertion] = STATE(2358),
    [sym_as_expression] = STATE(2358),
    [sym_satisfies_expression] = STATE(2358),
    [sym_instantiation_expression] = STATE(2358),
    [sym_ambient_declaration] = STATE(831),
    [sym_abstract_class_declaration] = STATE(831),
    [sym_module] = STATE(831),
    [sym_internal_module] = STATE(214),
    [sym_import_alias] = STATE(831),
    [sym_interface_declaration] = STATE(831),
    [sym_enum_declaration] = STATE(831),
    [sym_type_alias_declaration] = STATE(831),
    [sym_type_arguments] = STATE(428),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_program_repeat1] = STATE(9),
    [aux_sym_export_statement_repeat1] = STATE(3774),
    [ts_builtin_sym_end] = ACTIONS(511),
    [sym_identifier] = ACTIONS(9),
    [anon_sym_export] = ACTIONS(13),
    [anon_sym_type] = ACTIONS(15),
    [anon_sym_namespace] = ACTIONS(17),
    [anon_sym_LBRACE] = ACTIONS(19),
    [anon_sym_typeof] = ACTIONS(21),
    [anon_sym_import] = ACTIONS(23),
    [anon_sym_with] = ACTIONS(25),
    [anon_sym_var] = ACTIONS(27),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_const] = ACTIONS(31),
    [anon_sym_BANG] = ACTIONS(33),
    [anon_sym_if] = ACTIONS(35),
    [anon_sym_switch] = ACTIONS(37),
    [anon_sym_for] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_SEMI] = ACTIONS(43),
    [anon_sym_await] = ACTIONS(45),
    [anon_sym_while] = ACTIONS(47),
    [anon_sym_do] = ACTIONS(49),
    [anon_sym_try] = ACTIONS(51),
    [anon_sym_break] = ACTIONS(53),
    [anon_sym_continue] = ACTIONS(55),
    [anon_sym_debugger] = ACTIONS(57),
    [anon_sym_return] = ACTIONS(59),
    [anon_sym_throw] = ACTIONS(61),
    [anon_sym_yield] = ACTIONS(63),
    [anon_sym_LBRACK] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(67),
    [anon_sym_async] = ACTIONS(69),
    [anon_sym_function] = ACTIONS(71),
    [anon_sym_new] = ACTIONS(73),
    [anon_sym_using] = ACTIONS(75),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_SLASH] = ACTIONS(77),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(33),
    [anon_sym_void] = ACTIONS(21),
    [anon_sym_delete] = ACTIONS(21),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_DQUOTE] = ACTIONS(83),
    [anon_sym_SQUOTE] = ACTIONS(85),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(87),
    [sym_number] = ACTIONS(89),
    [sym_private_property_identifier] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(93),
    [sym_true] = ACTIONS(93),
    [sym_false] = ACTIONS(93),
    [sym_null] = ACTIONS(93),
    [sym_undefined] = ACTIONS(95),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(99),
    [anon_sym_readonly] = ACTIONS(99),
    [anon_sym_get] = ACTIONS(99),
    [anon_sym_set] = ACTIONS(99),
    [anon_sym_declare] = ACTIONS(101),
    [anon_sym_public] = ACTIONS(99),
    [anon_sym_private] = ACTIONS(99),
    [anon_sym_protected] = ACTIONS(99),
    [anon_sym_override] = ACTIONS(99),
    [anon_sym_module] = ACTIONS(103),
    [anon_sym_any] = ACTIONS(99),
    [anon_sym_number] = ACTIONS(99),
    [anon_sym_boolean] = ACTIONS(99),
    [anon_sym_string] = ACTIONS(99),
    [anon_sym_symbol] = ACTIONS(99),
    [anon_sym_object] = ACTIONS(99),
    [anon_sym_abstract] = ACTIONS(105),
    [anon_sym_interface] = ACTIONS(107),
    [anon_sym_enum] = ACTIONS(109),
    [sym_html_comment] = ACTIONS(5),
  },
  [17] = {
    [sym_export_statement] = STATE(892),
    [sym_declaration] = STATE(892),
    [sym_import] = STATE(3636),
    [sym_import_statement] = STATE(892),
    [sym_statement] = STATE(9),
    [sym_expression_statement] = STATE(892),
    [sym_variable_declaration] = STATE(831),
    [sym_lexical_declaration] = STATE(831),
    [sym_statement_block] = STATE(892),
    [sym_if_statement] = STATE(892),
    [sym_switch_statement] = STATE(892),
    [sym_for_statement] = STATE(892),
    [sym_for_in_statement] = STATE(892),
    [sym_while_statement] = STATE(892),
    [sym_do_statement] = STATE(892),
    [sym_try_statement] = STATE(892),
    [sym_with_statement] = STATE(892),
    [sym_break_statement] = STATE(892),
    [sym_continue_statement] = STATE(892),
    [sym_debugger_statement] = STATE(892),
    [sym_return_statement] = STATE(892),
    [sym_throw_statement] = STATE(892),
    [sym_empty_statement] = STATE(892),
    [sym_labeled_statement] = STATE(892),
    [sym_parenthesized_expression] = STATE(1362),
    [sym_expression] = STATE(1902),
    [sym_primary_expression] = STATE(1810),
    [sym_yield_expression] = STATE(2358),
    [sym_object] = STATE(2222),
    [sym_object_pattern] = STATE(5492),
    [sym_array] = STATE(2222),
    [sym_array_pattern] = STATE(5492),
    [sym_class] = STATE(2222),
    [sym_class_declaration] = STATE(831),
    [sym_function_expression] = STATE(2222),
    [sym_function_declaration] = STATE(831),
    [sym_generator_function] = STATE(2222),
    [sym_generator_function_declaration] = STATE(831),
    [sym_arrow_function] = STATE(2222),
    [sym__call_signature] = STATE(5821),
    [sym_call_expression] = STATE(2222),
    [sym_new_expression] = STATE(1948),
    [sym_await_expression] = STATE(2358),
    [sym_member_expression] = STATE(1362),
    [sym_subscript_expression] = STATE(1362),
    [sym_assignment_expression] = STATE(2358),
    [sym__augmented_assignment_lhs] = STATE(3025),
    [sym_augmented_assignment_expression] = STATE(2358),
    [sym__destructuring_pattern] = STATE(5492),
    [sym_ternary_expression] = STATE(2358),
    [sym_binary_expression] = STATE(2358),
    [sym_unary_expression] = STATE(2358),
    [sym_update_expression] = STATE(2358),
    [sym_sequence_expression] = STATE(5305),
    [sym_string] = STATE(2222),
    [sym_template_string] = STATE(2222),
    [sym_regex] = STATE(2222),
    [sym_meta_property] = STATE(2222),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1362),
    [sym_function_signature] = STATE(831),
    [sym_type_assertion] = STATE(2358),
    [sym_as_expression] = STATE(2358),
    [sym_satisfies_expression] = STATE(2358),
    [sym_instantiation_expression] = STATE(2358),
    [sym_ambient_declaration] = STATE(831),
    [sym_abstract_class_declaration] = STATE(831),
    [sym_module] = STATE(831),
    [sym_internal_module] = STATE(214),
    [sym_import_alias] = STATE(831),
    [sym_interface_declaration] = STATE(831),
    [sym_enum_declaration] = STATE(831),
    [sym_type_alias_declaration] = STATE(831),
    [sym_type_arguments] = STATE(428),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_program_repeat1] = STATE(9),
    [aux_sym_export_statement_repeat1] = STATE(3774),
    [ts_builtin_sym_end] = ACTIONS(513),
    [sym_identifier] = ACTIONS(9),
    [anon_sym_export] = ACTIONS(13),
    [anon_sym_type] = ACTIONS(15),
    [anon_sym_namespace] = ACTIONS(17),
    [anon_sym_LBRACE] = ACTIONS(19),
    [anon_sym_typeof] = ACTIONS(21),
    [anon_sym_import] = ACTIONS(23),
    [anon_sym_with] = ACTIONS(25),
    [anon_sym_var] = ACTIONS(27),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_const] = ACTIONS(31),
    [anon_sym_BANG] = ACTIONS(33),
    [anon_sym_if] = ACTIONS(35),
    [anon_sym_switch] = ACTIONS(37),
    [anon_sym_for] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_SEMI] = ACTIONS(43),
    [anon_sym_await] = ACTIONS(45),
    [anon_sym_while] = ACTIONS(47),
    [anon_sym_do] = ACTIONS(49),
    [anon_sym_try] = ACTIONS(51),
    [anon_sym_break] = ACTIONS(53),
    [anon_sym_continue] = ACTIONS(55),
    [anon_sym_debugger] = ACTIONS(57),
    [anon_sym_return] = ACTIONS(59),
    [anon_sym_throw] = ACTIONS(61),
    [anon_sym_yield] = ACTIONS(63),
    [anon_sym_LBRACK] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(67),
    [anon_sym_async] = ACTIONS(69),
    [anon_sym_function] = ACTIONS(71),
    [anon_sym_new] = ACTIONS(73),
    [anon_sym_using] = ACTIONS(75),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_SLASH] = ACTIONS(77),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(33),
    [anon_sym_void] = ACTIONS(21),
    [anon_sym_delete] = ACTIONS(21),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_DQUOTE] = ACTIONS(83),
    [anon_sym_SQUOTE] = ACTIONS(85),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(87),
    [sym_number] = ACTIONS(89),
    [sym_private_property_identifier] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(93),
    [sym_true] = ACTIONS(93),
    [sym_false] = ACTIONS(93),
    [sym_null] = ACTIONS(93),
    [sym_undefined] = ACTIONS(95),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(99),
    [anon_sym_readonly] = ACTIONS(99),
    [anon_sym_get] = ACTIONS(99),
    [anon_sym_set] = ACTIONS(99),
    [anon_sym_declare] = ACTIONS(101),
    [anon_sym_public] = ACTIONS(99),
    [anon_sym_private] = ACTIONS(99),
    [anon_sym_protected] = ACTIONS(99),
    [anon_sym_override] = ACTIONS(99),
    [anon_sym_module] = ACTIONS(103),
    [anon_sym_any] = ACTIONS(99),
    [anon_sym_number] = ACTIONS(99),
    [anon_sym_boolean] = ACTIONS(99),
    [anon_sym_string] = ACTIONS(99),
    [anon_sym_symbol] = ACTIONS(99),
    [anon_sym_object] = ACTIONS(99),
    [anon_sym_abstract] = ACTIONS(105),
    [anon_sym_interface] = ACTIONS(107),
    [anon_sym_enum] = ACTIONS(109),
    [sym_html_comment] = ACTIONS(5),
  },
  [18] = {
    [sym_export_statement] = STATE(892),
    [sym_declaration] = STATE(892),
    [sym_import] = STATE(3636),
    [sym_import_statement] = STATE(892),
    [sym_statement] = STATE(9),
    [sym_expression_statement] = STATE(892),
    [sym_variable_declaration] = STATE(831),
    [sym_lexical_declaration] = STATE(831),
    [sym_statement_block] = STATE(892),
    [sym_if_statement] = STATE(892),
    [sym_switch_statement] = STATE(892),
    [sym_for_statement] = STATE(892),
    [sym_for_in_statement] = STATE(892),
    [sym_while_statement] = STATE(892),
    [sym_do_statement] = STATE(892),
    [sym_try_statement] = STATE(892),
    [sym_with_statement] = STATE(892),
    [sym_break_statement] = STATE(892),
    [sym_continue_statement] = STATE(892),
    [sym_debugger_statement] = STATE(892),
    [sym_return_statement] = STATE(892),
    [sym_throw_statement] = STATE(892),
    [sym_empty_statement] = STATE(892),
    [sym_labeled_statement] = STATE(892),
    [sym_parenthesized_expression] = STATE(1362),
    [sym_expression] = STATE(1902),
    [sym_primary_expression] = STATE(1810),
    [sym_yield_expression] = STATE(2358),
    [sym_object] = STATE(2222),
    [sym_object_pattern] = STATE(5492),
    [sym_array] = STATE(2222),
    [sym_array_pattern] = STATE(5492),
    [sym_class] = STATE(2222),
    [sym_class_declaration] = STATE(831),
    [sym_function_expression] = STATE(2222),
    [sym_function_declaration] = STATE(831),
    [sym_generator_function] = STATE(2222),
    [sym_generator_function_declaration] = STATE(831),
    [sym_arrow_function] = STATE(2222),
    [sym__call_signature] = STATE(5821),
    [sym_call_expression] = STATE(2222),
    [sym_new_expression] = STATE(1948),
    [sym_await_expression] = STATE(2358),
    [sym_member_expression] = STATE(1362),
    [sym_subscript_expression] = STATE(1362),
    [sym_assignment_expression] = STATE(2358),
    [sym__augmented_assignment_lhs] = STATE(3025),
    [sym_augmented_assignment_expression] = STATE(2358),
    [sym__destructuring_pattern] = STATE(5492),
    [sym_ternary_expression] = STATE(2358),
    [sym_binary_expression] = STATE(2358),
    [sym_unary_expression] = STATE(2358),
    [sym_update_expression] = STATE(2358),
    [sym_sequence_expression] = STATE(5305),
    [sym_string] = STATE(2222),
    [sym_template_string] = STATE(2222),
    [sym_regex] = STATE(2222),
    [sym_meta_property] = STATE(2222),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1362),
    [sym_function_signature] = STATE(831),
    [sym_type_assertion] = STATE(2358),
    [sym_as_expression] = STATE(2358),
    [sym_satisfies_expression] = STATE(2358),
    [sym_instantiation_expression] = STATE(2358),
    [sym_ambient_declaration] = STATE(831),
    [sym_abstract_class_declaration] = STATE(831),
    [sym_module] = STATE(831),
    [sym_internal_module] = STATE(214),
    [sym_import_alias] = STATE(831),
    [sym_interface_declaration] = STATE(831),
    [sym_enum_declaration] = STATE(831),
    [sym_type_alias_declaration] = STATE(831),
    [sym_type_arguments] = STATE(428),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_program_repeat1] = STATE(9),
    [aux_sym_export_statement_repeat1] = STATE(3774),
    [sym_identifier] = ACTIONS(9),
    [anon_sym_export] = ACTIONS(13),
    [anon_sym_type] = ACTIONS(15),
    [anon_sym_namespace] = ACTIONS(17),
    [anon_sym_LBRACE] = ACTIONS(19),
    [anon_sym_RBRACE] = ACTIONS(515),
    [anon_sym_typeof] = ACTIONS(21),
    [anon_sym_import] = ACTIONS(23),
    [anon_sym_with] = ACTIONS(25),
    [anon_sym_var] = ACTIONS(27),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_const] = ACTIONS(31),
    [anon_sym_BANG] = ACTIONS(33),
    [anon_sym_if] = ACTIONS(35),
    [anon_sym_switch] = ACTIONS(37),
    [anon_sym_for] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_SEMI] = ACTIONS(43),
    [anon_sym_await] = ACTIONS(45),
    [anon_sym_while] = ACTIONS(47),
    [anon_sym_do] = ACTIONS(49),
    [anon_sym_try] = ACTIONS(51),
    [anon_sym_break] = ACTIONS(53),
    [anon_sym_continue] = ACTIONS(55),
    [anon_sym_debugger] = ACTIONS(57),
    [anon_sym_return] = ACTIONS(59),
    [anon_sym_throw] = ACTIONS(61),
    [anon_sym_yield] = ACTIONS(63),
    [anon_sym_LBRACK] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(67),
    [anon_sym_async] = ACTIONS(69),
    [anon_sym_function] = ACTIONS(71),
    [anon_sym_new] = ACTIONS(73),
    [anon_sym_using] = ACTIONS(75),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_SLASH] = ACTIONS(77),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(33),
    [anon_sym_void] = ACTIONS(21),
    [anon_sym_delete] = ACTIONS(21),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_DQUOTE] = ACTIONS(83),
    [anon_sym_SQUOTE] = ACTIONS(85),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(87),
    [sym_number] = ACTIONS(89),
    [sym_private_property_identifier] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(93),
    [sym_true] = ACTIONS(93),
    [sym_false] = ACTIONS(93),
    [sym_null] = ACTIONS(93),
    [sym_undefined] = ACTIONS(95),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(99),
    [anon_sym_readonly] = ACTIONS(99),
    [anon_sym_get] = ACTIONS(99),
    [anon_sym_set] = ACTIONS(99),
    [anon_sym_declare] = ACTIONS(101),
    [anon_sym_public] = ACTIONS(99),
    [anon_sym_private] = ACTIONS(99),
    [anon_sym_protected] = ACTIONS(99),
    [anon_sym_override] = ACTIONS(99),
    [anon_sym_module] = ACTIONS(103),
    [anon_sym_any] = ACTIONS(99),
    [anon_sym_number] = ACTIONS(99),
    [anon_sym_boolean] = ACTIONS(99),
    [anon_sym_string] = ACTIONS(99),
    [anon_sym_symbol] = ACTIONS(99),
    [anon_sym_object] = ACTIONS(99),
    [anon_sym_abstract] = ACTIONS(105),
    [anon_sym_interface] = ACTIONS(107),
    [anon_sym_enum] = ACTIONS(109),
    [sym_html_comment] = ACTIONS(5),
  },
  [19] = {
    [sym_export_statement] = STATE(892),
    [sym_declaration] = STATE(892),
    [sym_import] = STATE(3636),
    [sym_import_statement] = STATE(892),
    [sym_statement] = STATE(20),
    [sym_expression_statement] = STATE(892),
    [sym_variable_declaration] = STATE(831),
    [sym_lexical_declaration] = STATE(831),
    [sym_statement_block] = STATE(892),
    [sym_if_statement] = STATE(892),
    [sym_switch_statement] = STATE(892),
    [sym_for_statement] = STATE(892),
    [sym_for_in_statement] = STATE(892),
    [sym_while_statement] = STATE(892),
    [sym_do_statement] = STATE(892),
    [sym_try_statement] = STATE(892),
    [sym_with_statement] = STATE(892),
    [sym_break_statement] = STATE(892),
    [sym_continue_statement] = STATE(892),
    [sym_debugger_statement] = STATE(892),
    [sym_return_statement] = STATE(892),
    [sym_throw_statement] = STATE(892),
    [sym_empty_statement] = STATE(892),
    [sym_labeled_statement] = STATE(892),
    [sym_parenthesized_expression] = STATE(1362),
    [sym_expression] = STATE(1902),
    [sym_primary_expression] = STATE(1810),
    [sym_yield_expression] = STATE(2358),
    [sym_object] = STATE(2222),
    [sym_object_pattern] = STATE(5492),
    [sym_array] = STATE(2222),
    [sym_array_pattern] = STATE(5492),
    [sym_class] = STATE(2222),
    [sym_class_declaration] = STATE(831),
    [sym_function_expression] = STATE(2222),
    [sym_function_declaration] = STATE(831),
    [sym_generator_function] = STATE(2222),
    [sym_generator_function_declaration] = STATE(831),
    [sym_arrow_function] = STATE(2222),
    [sym__call_signature] = STATE(5821),
    [sym_call_expression] = STATE(2222),
    [sym_new_expression] = STATE(1948),
    [sym_await_expression] = STATE(2358),
    [sym_member_expression] = STATE(1362),
    [sym_subscript_expression] = STATE(1362),
    [sym_assignment_expression] = STATE(2358),
    [sym__augmented_assignment_lhs] = STATE(3025),
    [sym_augmented_assignment_expression] = STATE(2358),
    [sym__destructuring_pattern] = STATE(5492),
    [sym_ternary_expression] = STATE(2358),
    [sym_binary_expression] = STATE(2358),
    [sym_unary_expression] = STATE(2358),
    [sym_update_expression] = STATE(2358),
    [sym_sequence_expression] = STATE(5305),
    [sym_string] = STATE(2222),
    [sym_template_string] = STATE(2222),
    [sym_regex] = STATE(2222),
    [sym_meta_property] = STATE(2222),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1362),
    [sym_function_signature] = STATE(831),
    [sym_type_assertion] = STATE(2358),
    [sym_as_expression] = STATE(2358),
    [sym_satisfies_expression] = STATE(2358),
    [sym_instantiation_expression] = STATE(2358),
    [sym_ambient_declaration] = STATE(831),
    [sym_abstract_class_declaration] = STATE(831),
    [sym_module] = STATE(831),
    [sym_internal_module] = STATE(214),
    [sym_import_alias] = STATE(831),
    [sym_interface_declaration] = STATE(831),
    [sym_enum_declaration] = STATE(831),
    [sym_type_alias_declaration] = STATE(831),
    [sym_type_arguments] = STATE(428),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_program_repeat1] = STATE(20),
    [aux_sym_export_statement_repeat1] = STATE(3774),
    [sym_identifier] = ACTIONS(9),
    [anon_sym_export] = ACTIONS(13),
    [anon_sym_type] = ACTIONS(15),
    [anon_sym_namespace] = ACTIONS(17),
    [anon_sym_LBRACE] = ACTIONS(19),
    [anon_sym_RBRACE] = ACTIONS(517),
    [anon_sym_typeof] = ACTIONS(21),
    [anon_sym_import] = ACTIONS(23),
    [anon_sym_with] = ACTIONS(25),
    [anon_sym_var] = ACTIONS(27),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_const] = ACTIONS(31),
    [anon_sym_BANG] = ACTIONS(33),
    [anon_sym_if] = ACTIONS(35),
    [anon_sym_switch] = ACTIONS(37),
    [anon_sym_for] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_SEMI] = ACTIONS(43),
    [anon_sym_await] = ACTIONS(45),
    [anon_sym_while] = ACTIONS(47),
    [anon_sym_do] = ACTIONS(49),
    [anon_sym_try] = ACTIONS(51),
    [anon_sym_break] = ACTIONS(53),
    [anon_sym_continue] = ACTIONS(55),
    [anon_sym_debugger] = ACTIONS(57),
    [anon_sym_return] = ACTIONS(59),
    [anon_sym_throw] = ACTIONS(61),
    [anon_sym_yield] = ACTIONS(63),
    [anon_sym_LBRACK] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(67),
    [anon_sym_async] = ACTIONS(69),
    [anon_sym_function] = ACTIONS(71),
    [anon_sym_new] = ACTIONS(73),
    [anon_sym_using] = ACTIONS(75),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_SLASH] = ACTIONS(77),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(33),
    [anon_sym_void] = ACTIONS(21),
    [anon_sym_delete] = ACTIONS(21),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_DQUOTE] = ACTIONS(83),
    [anon_sym_SQUOTE] = ACTIONS(85),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(87),
    [sym_number] = ACTIONS(89),
    [sym_private_property_identifier] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(93),
    [sym_true] = ACTIONS(93),
    [sym_false] = ACTIONS(93),
    [sym_null] = ACTIONS(93),
    [sym_undefined] = ACTIONS(95),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(99),
    [anon_sym_readonly] = ACTIONS(99),
    [anon_sym_get] = ACTIONS(99),
    [anon_sym_set] = ACTIONS(99),
    [anon_sym_declare] = ACTIONS(101),
    [anon_sym_public] = ACTIONS(99),
    [anon_sym_private] = ACTIONS(99),
    [anon_sym_protected] = ACTIONS(99),
    [anon_sym_override] = ACTIONS(99),
    [anon_sym_module] = ACTIONS(103),
    [anon_sym_any] = ACTIONS(99),
    [anon_sym_number] = ACTIONS(99),
    [anon_sym_boolean] = ACTIONS(99),
    [anon_sym_string] = ACTIONS(99),
    [anon_sym_symbol] = ACTIONS(99),
    [anon_sym_object] = ACTIONS(99),
    [anon_sym_abstract] = ACTIONS(105),
    [anon_sym_interface] = ACTIONS(107),
    [anon_sym_enum] = ACTIONS(109),
    [sym_html_comment] = ACTIONS(5),
  },
  [20] = {
    [sym_export_statement] = STATE(892),
    [sym_declaration] = STATE(892),
    [sym_import] = STATE(3636),
    [sym_import_statement] = STATE(892),
    [sym_statement] = STATE(9),
    [sym_expression_statement] = STATE(892),
    [sym_variable_declaration] = STATE(831),
    [sym_lexical_declaration] = STATE(831),
    [sym_statement_block] = STATE(892),
    [sym_if_statement] = STATE(892),
    [sym_switch_statement] = STATE(892),
    [sym_for_statement] = STATE(892),
    [sym_for_in_statement] = STATE(892),
    [sym_while_statement] = STATE(892),
    [sym_do_statement] = STATE(892),
    [sym_try_statement] = STATE(892),
    [sym_with_statement] = STATE(892),
    [sym_break_statement] = STATE(892),
    [sym_continue_statement] = STATE(892),
    [sym_debugger_statement] = STATE(892),
    [sym_return_statement] = STATE(892),
    [sym_throw_statement] = STATE(892),
    [sym_empty_statement] = STATE(892),
    [sym_labeled_statement] = STATE(892),
    [sym_parenthesized_expression] = STATE(1362),
    [sym_expression] = STATE(1902),
    [sym_primary_expression] = STATE(1810),
    [sym_yield_expression] = STATE(2358),
    [sym_object] = STATE(2222),
    [sym_object_pattern] = STATE(5492),
    [sym_array] = STATE(2222),
    [sym_array_pattern] = STATE(5492),
    [sym_class] = STATE(2222),
    [sym_class_declaration] = STATE(831),
    [sym_function_expression] = STATE(2222),
    [sym_function_declaration] = STATE(831),
    [sym_generator_function] = STATE(2222),
    [sym_generator_function_declaration] = STATE(831),
    [sym_arrow_function] = STATE(2222),
    [sym__call_signature] = STATE(5821),
    [sym_call_expression] = STATE(2222),
    [sym_new_expression] = STATE(1948),
    [sym_await_expression] = STATE(2358),
    [sym_member_expression] = STATE(1362),
    [sym_subscript_expression] = STATE(1362),
    [sym_assignment_expression] = STATE(2358),
    [sym__augmented_assignment_lhs] = STATE(3025),
    [sym_augmented_assignment_expression] = STATE(2358),
    [sym__destructuring_pattern] = STATE(5492),
    [sym_ternary_expression] = STATE(2358),
    [sym_binary_expression] = STATE(2358),
    [sym_unary_expression] = STATE(2358),
    [sym_update_expression] = STATE(2358),
    [sym_sequence_expression] = STATE(5305),
    [sym_string] = STATE(2222),
    [sym_template_string] = STATE(2222),
    [sym_regex] = STATE(2222),
    [sym_meta_property] = STATE(2222),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1362),
    [sym_function_signature] = STATE(831),
    [sym_type_assertion] = STATE(2358),
    [sym_as_expression] = STATE(2358),
    [sym_satisfies_expression] = STATE(2358),
    [sym_instantiation_expression] = STATE(2358),
    [sym_ambient_declaration] = STATE(831),
    [sym_abstract_class_declaration] = STATE(831),
    [sym_module] = STATE(831),
    [sym_internal_module] = STATE(214),
    [sym_import_alias] = STATE(831),
    [sym_interface_declaration] = STATE(831),
    [sym_enum_declaration] = STATE(831),
    [sym_type_alias_declaration] = STATE(831),
    [sym_type_arguments] = STATE(428),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_program_repeat1] = STATE(9),
    [aux_sym_export_statement_repeat1] = STATE(3774),
    [sym_identifier] = ACTIONS(9),
    [anon_sym_export] = ACTIONS(13),
    [anon_sym_type] = ACTIONS(15),
    [anon_sym_namespace] = ACTIONS(17),
    [anon_sym_LBRACE] = ACTIONS(19),
    [anon_sym_RBRACE] = ACTIONS(519),
    [anon_sym_typeof] = ACTIONS(21),
    [anon_sym_import] = ACTIONS(23),
    [anon_sym_with] = ACTIONS(25),
    [anon_sym_var] = ACTIONS(27),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_const] = ACTIONS(31),
    [anon_sym_BANG] = ACTIONS(33),
    [anon_sym_if] = ACTIONS(35),
    [anon_sym_switch] = ACTIONS(37),
    [anon_sym_for] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_SEMI] = ACTIONS(43),
    [anon_sym_await] = ACTIONS(45),
    [anon_sym_while] = ACTIONS(47),
    [anon_sym_do] = ACTIONS(49),
    [anon_sym_try] = ACTIONS(51),
    [anon_sym_break] = ACTIONS(53),
    [anon_sym_continue] = ACTIONS(55),
    [anon_sym_debugger] = ACTIONS(57),
    [anon_sym_return] = ACTIONS(59),
    [anon_sym_throw] = ACTIONS(61),
    [anon_sym_yield] = ACTIONS(63),
    [anon_sym_LBRACK] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(67),
    [anon_sym_async] = ACTIONS(69),
    [anon_sym_function] = ACTIONS(71),
    [anon_sym_new] = ACTIONS(73),
    [anon_sym_using] = ACTIONS(75),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_SLASH] = ACTIONS(77),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(33),
    [anon_sym_void] = ACTIONS(21),
    [anon_sym_delete] = ACTIONS(21),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_DQUOTE] = ACTIONS(83),
    [anon_sym_SQUOTE] = ACTIONS(85),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(87),
    [sym_number] = ACTIONS(89),
    [sym_private_property_identifier] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(93),
    [sym_true] = ACTIONS(93),
    [sym_false] = ACTIONS(93),
    [sym_null] = ACTIONS(93),
    [sym_undefined] = ACTIONS(95),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(99),
    [anon_sym_readonly] = ACTIONS(99),
    [anon_sym_get] = ACTIONS(99),
    [anon_sym_set] = ACTIONS(99),
    [anon_sym_declare] = ACTIONS(101),
    [anon_sym_public] = ACTIONS(99),
    [anon_sym_private] = ACTIONS(99),
    [anon_sym_protected] = ACTIONS(99),
    [anon_sym_override] = ACTIONS(99),
    [anon_sym_module] = ACTIONS(103),
    [anon_sym_any] = ACTIONS(99),
    [anon_sym_number] = ACTIONS(99),
    [anon_sym_boolean] = ACTIONS(99),
    [anon_sym_string] = ACTIONS(99),
    [anon_sym_symbol] = ACTIONS(99),
    [anon_sym_object] = ACTIONS(99),
    [anon_sym_abstract] = ACTIONS(105),
    [anon_sym_interface] = ACTIONS(107),
    [anon_sym_enum] = ACTIONS(109),
    [sym_html_comment] = ACTIONS(5),
  },
  [21] = {
    [sym_export_statement] = STATE(892),
    [sym_declaration] = STATE(892),
    [sym_import] = STATE(3636),
    [sym_import_statement] = STATE(892),
    [sym_statement] = STATE(18),
    [sym_expression_statement] = STATE(892),
    [sym_variable_declaration] = STATE(831),
    [sym_lexical_declaration] = STATE(831),
    [sym_statement_block] = STATE(892),
    [sym_if_statement] = STATE(892),
    [sym_switch_statement] = STATE(892),
    [sym_for_statement] = STATE(892),
    [sym_for_in_statement] = STATE(892),
    [sym_while_statement] = STATE(892),
    [sym_do_statement] = STATE(892),
    [sym_try_statement] = STATE(892),
    [sym_with_statement] = STATE(892),
    [sym_break_statement] = STATE(892),
    [sym_continue_statement] = STATE(892),
    [sym_debugger_statement] = STATE(892),
    [sym_return_statement] = STATE(892),
    [sym_throw_statement] = STATE(892),
    [sym_empty_statement] = STATE(892),
    [sym_labeled_statement] = STATE(892),
    [sym_parenthesized_expression] = STATE(1362),
    [sym_expression] = STATE(1902),
    [sym_primary_expression] = STATE(1810),
    [sym_yield_expression] = STATE(2358),
    [sym_object] = STATE(2222),
    [sym_object_pattern] = STATE(5492),
    [sym_array] = STATE(2222),
    [sym_array_pattern] = STATE(5492),
    [sym_class] = STATE(2222),
    [sym_class_declaration] = STATE(831),
    [sym_function_expression] = STATE(2222),
    [sym_function_declaration] = STATE(831),
    [sym_generator_function] = STATE(2222),
    [sym_generator_function_declaration] = STATE(831),
    [sym_arrow_function] = STATE(2222),
    [sym__call_signature] = STATE(5821),
    [sym_call_expression] = STATE(2222),
    [sym_new_expression] = STATE(1948),
    [sym_await_expression] = STATE(2358),
    [sym_member_expression] = STATE(1362),
    [sym_subscript_expression] = STATE(1362),
    [sym_assignment_expression] = STATE(2358),
    [sym__augmented_assignment_lhs] = STATE(3025),
    [sym_augmented_assignment_expression] = STATE(2358),
    [sym__destructuring_pattern] = STATE(5492),
    [sym_ternary_expression] = STATE(2358),
    [sym_binary_expression] = STATE(2358),
    [sym_unary_expression] = STATE(2358),
    [sym_update_expression] = STATE(2358),
    [sym_sequence_expression] = STATE(5305),
    [sym_string] = STATE(2222),
    [sym_template_string] = STATE(2222),
    [sym_regex] = STATE(2222),
    [sym_meta_property] = STATE(2222),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1362),
    [sym_function_signature] = STATE(831),
    [sym_type_assertion] = STATE(2358),
    [sym_as_expression] = STATE(2358),
    [sym_satisfies_expression] = STATE(2358),
    [sym_instantiation_expression] = STATE(2358),
    [sym_ambient_declaration] = STATE(831),
    [sym_abstract_class_declaration] = STATE(831),
    [sym_module] = STATE(831),
    [sym_internal_module] = STATE(214),
    [sym_import_alias] = STATE(831),
    [sym_interface_declaration] = STATE(831),
    [sym_enum_declaration] = STATE(831),
    [sym_type_alias_declaration] = STATE(831),
    [sym_type_arguments] = STATE(428),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_program_repeat1] = STATE(18),
    [aux_sym_export_statement_repeat1] = STATE(3774),
    [sym_identifier] = ACTIONS(9),
    [anon_sym_export] = ACTIONS(13),
    [anon_sym_type] = ACTIONS(15),
    [anon_sym_namespace] = ACTIONS(17),
    [anon_sym_LBRACE] = ACTIONS(19),
    [anon_sym_RBRACE] = ACTIONS(521),
    [anon_sym_typeof] = ACTIONS(21),
    [anon_sym_import] = ACTIONS(23),
    [anon_sym_with] = ACTIONS(25),
    [anon_sym_var] = ACTIONS(27),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_const] = ACTIONS(31),
    [anon_sym_BANG] = ACTIONS(33),
    [anon_sym_if] = ACTIONS(35),
    [anon_sym_switch] = ACTIONS(37),
    [anon_sym_for] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_SEMI] = ACTIONS(43),
    [anon_sym_await] = ACTIONS(45),
    [anon_sym_while] = ACTIONS(47),
    [anon_sym_do] = ACTIONS(49),
    [anon_sym_try] = ACTIONS(51),
    [anon_sym_break] = ACTIONS(53),
    [anon_sym_continue] = ACTIONS(55),
    [anon_sym_debugger] = ACTIONS(57),
    [anon_sym_return] = ACTIONS(59),
    [anon_sym_throw] = ACTIONS(61),
    [anon_sym_yield] = ACTIONS(63),
    [anon_sym_LBRACK] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(67),
    [anon_sym_async] = ACTIONS(69),
    [anon_sym_function] = ACTIONS(71),
    [anon_sym_new] = ACTIONS(73),
    [anon_sym_using] = ACTIONS(75),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_SLASH] = ACTIONS(77),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(33),
    [anon_sym_void] = ACTIONS(21),
    [anon_sym_delete] = ACTIONS(21),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_DQUOTE] = ACTIONS(83),
    [anon_sym_SQUOTE] = ACTIONS(85),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(87),
    [sym_number] = ACTIONS(89),
    [sym_private_property_identifier] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(93),
    [sym_true] = ACTIONS(93),
    [sym_false] = ACTIONS(93),
    [sym_null] = ACTIONS(93),
    [sym_undefined] = ACTIONS(95),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(99),
    [anon_sym_readonly] = ACTIONS(99),
    [anon_sym_get] = ACTIONS(99),
    [anon_sym_set] = ACTIONS(99),
    [anon_sym_declare] = ACTIONS(101),
    [anon_sym_public] = ACTIONS(99),
    [anon_sym_private] = ACTIONS(99),
    [anon_sym_protected] = ACTIONS(99),
    [anon_sym_override] = ACTIONS(99),
    [anon_sym_module] = ACTIONS(103),
    [anon_sym_any] = ACTIONS(99),
    [anon_sym_number] = ACTIONS(99),
    [anon_sym_boolean] = ACTIONS(99),
    [anon_sym_string] = ACTIONS(99),
    [anon_sym_symbol] = ACTIONS(99),
    [anon_sym_object] = ACTIONS(99),
    [anon_sym_abstract] = ACTIONS(105),
    [anon_sym_interface] = ACTIONS(107),
    [anon_sym_enum] = ACTIONS(109),
    [sym_html_comment] = ACTIONS(5),
  },
  [22] = {
    [sym_export_statement] = STATE(892),
    [sym_declaration] = STATE(892),
    [sym_import] = STATE(3636),
    [sym_import_statement] = STATE(892),
    [sym_statement] = STATE(9),
    [sym_expression_statement] = STATE(892),
    [sym_variable_declaration] = STATE(831),
    [sym_lexical_declaration] = STATE(831),
    [sym_statement_block] = STATE(892),
    [sym_if_statement] = STATE(892),
    [sym_switch_statement] = STATE(892),
    [sym_for_statement] = STATE(892),
    [sym_for_in_statement] = STATE(892),
    [sym_while_statement] = STATE(892),
    [sym_do_statement] = STATE(892),
    [sym_try_statement] = STATE(892),
    [sym_with_statement] = STATE(892),
    [sym_break_statement] = STATE(892),
    [sym_continue_statement] = STATE(892),
    [sym_debugger_statement] = STATE(892),
    [sym_return_statement] = STATE(892),
    [sym_throw_statement] = STATE(892),
    [sym_empty_statement] = STATE(892),
    [sym_labeled_statement] = STATE(892),
    [sym_parenthesized_expression] = STATE(1362),
    [sym_expression] = STATE(1902),
    [sym_primary_expression] = STATE(1810),
    [sym_yield_expression] = STATE(2358),
    [sym_object] = STATE(2222),
    [sym_object_pattern] = STATE(5492),
    [sym_array] = STATE(2222),
    [sym_array_pattern] = STATE(5492),
    [sym_class] = STATE(2222),
    [sym_class_declaration] = STATE(831),
    [sym_function_expression] = STATE(2222),
    [sym_function_declaration] = STATE(831),
    [sym_generator_function] = STATE(2222),
    [sym_generator_function_declaration] = STATE(831),
    [sym_arrow_function] = STATE(2222),
    [sym__call_signature] = STATE(5821),
    [sym_call_expression] = STATE(2222),
    [sym_new_expression] = STATE(1948),
    [sym_await_expression] = STATE(2358),
    [sym_member_expression] = STATE(1362),
    [sym_subscript_expression] = STATE(1362),
    [sym_assignment_expression] = STATE(2358),
    [sym__augmented_assignment_lhs] = STATE(3025),
    [sym_augmented_assignment_expression] = STATE(2358),
    [sym__destructuring_pattern] = STATE(5492),
    [sym_ternary_expression] = STATE(2358),
    [sym_binary_expression] = STATE(2358),
    [sym_unary_expression] = STATE(2358),
    [sym_update_expression] = STATE(2358),
    [sym_sequence_expression] = STATE(5305),
    [sym_string] = STATE(2222),
    [sym_template_string] = STATE(2222),
    [sym_regex] = STATE(2222),
    [sym_meta_property] = STATE(2222),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1362),
    [sym_function_signature] = STATE(831),
    [sym_type_assertion] = STATE(2358),
    [sym_as_expression] = STATE(2358),
    [sym_satisfies_expression] = STATE(2358),
    [sym_instantiation_expression] = STATE(2358),
    [sym_ambient_declaration] = STATE(831),
    [sym_abstract_class_declaration] = STATE(831),
    [sym_module] = STATE(831),
    [sym_internal_module] = STATE(214),
    [sym_import_alias] = STATE(831),
    [sym_interface_declaration] = STATE(831),
    [sym_enum_declaration] = STATE(831),
    [sym_type_alias_declaration] = STATE(831),
    [sym_type_arguments] = STATE(428),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_program_repeat1] = STATE(9),
    [aux_sym_export_statement_repeat1] = STATE(3774),
    [sym_identifier] = ACTIONS(9),
    [anon_sym_export] = ACTIONS(13),
    [anon_sym_type] = ACTIONS(15),
    [anon_sym_namespace] = ACTIONS(17),
    [anon_sym_LBRACE] = ACTIONS(19),
    [anon_sym_RBRACE] = ACTIONS(523),
    [anon_sym_typeof] = ACTIONS(21),
    [anon_sym_import] = ACTIONS(23),
    [anon_sym_with] = ACTIONS(25),
    [anon_sym_var] = ACTIONS(27),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_const] = ACTIONS(31),
    [anon_sym_BANG] = ACTIONS(33),
    [anon_sym_if] = ACTIONS(35),
    [anon_sym_switch] = ACTIONS(37),
    [anon_sym_for] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_SEMI] = ACTIONS(43),
    [anon_sym_await] = ACTIONS(45),
    [anon_sym_while] = ACTIONS(47),
    [anon_sym_do] = ACTIONS(49),
    [anon_sym_try] = ACTIONS(51),
    [anon_sym_break] = ACTIONS(53),
    [anon_sym_continue] = ACTIONS(55),
    [anon_sym_debugger] = ACTIONS(57),
    [anon_sym_return] = ACTIONS(59),
    [anon_sym_throw] = ACTIONS(61),
    [anon_sym_yield] = ACTIONS(63),
    [anon_sym_LBRACK] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(67),
    [anon_sym_async] = ACTIONS(69),
    [anon_sym_function] = ACTIONS(71),
    [anon_sym_new] = ACTIONS(73),
    [anon_sym_using] = ACTIONS(75),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_SLASH] = ACTIONS(77),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(33),
    [anon_sym_void] = ACTIONS(21),
    [anon_sym_delete] = ACTIONS(21),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_DQUOTE] = ACTIONS(83),
    [anon_sym_SQUOTE] = ACTIONS(85),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(87),
    [sym_number] = ACTIONS(89),
    [sym_private_property_identifier] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(93),
    [sym_true] = ACTIONS(93),
    [sym_false] = ACTIONS(93),
    [sym_null] = ACTIONS(93),
    [sym_undefined] = ACTIONS(95),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(99),
    [anon_sym_readonly] = ACTIONS(99),
    [anon_sym_get] = ACTIONS(99),
    [anon_sym_set] = ACTIONS(99),
    [anon_sym_declare] = ACTIONS(101),
    [anon_sym_public] = ACTIONS(99),
    [anon_sym_private] = ACTIONS(99),
    [anon_sym_protected] = ACTIONS(99),
    [anon_sym_override] = ACTIONS(99),
    [anon_sym_module] = ACTIONS(103),
    [anon_sym_any] = ACTIONS(99),
    [anon_sym_number] = ACTIONS(99),
    [anon_sym_boolean] = ACTIONS(99),
    [anon_sym_string] = ACTIONS(99),
    [anon_sym_symbol] = ACTIONS(99),
    [anon_sym_object] = ACTIONS(99),
    [anon_sym_abstract] = ACTIONS(105),
    [anon_sym_interface] = ACTIONS(107),
    [anon_sym_enum] = ACTIONS(109),
    [sym_html_comment] = ACTIONS(5),
  },
  [23] = {
    [sym_export_statement] = STATE(892),
    [sym_declaration] = STATE(892),
    [sym_import] = STATE(3636),
    [sym_import_statement] = STATE(892),
    [sym_statement] = STATE(22),
    [sym_expression_statement] = STATE(892),
    [sym_variable_declaration] = STATE(831),
    [sym_lexical_declaration] = STATE(831),
    [sym_statement_block] = STATE(892),
    [sym_if_statement] = STATE(892),
    [sym_switch_statement] = STATE(892),
    [sym_for_statement] = STATE(892),
    [sym_for_in_statement] = STATE(892),
    [sym_while_statement] = STATE(892),
    [sym_do_statement] = STATE(892),
    [sym_try_statement] = STATE(892),
    [sym_with_statement] = STATE(892),
    [sym_break_statement] = STATE(892),
    [sym_continue_statement] = STATE(892),
    [sym_debugger_statement] = STATE(892),
    [sym_return_statement] = STATE(892),
    [sym_throw_statement] = STATE(892),
    [sym_empty_statement] = STATE(892),
    [sym_labeled_statement] = STATE(892),
    [sym_parenthesized_expression] = STATE(1362),
    [sym_expression] = STATE(1902),
    [sym_primary_expression] = STATE(1810),
    [sym_yield_expression] = STATE(2358),
    [sym_object] = STATE(2222),
    [sym_object_pattern] = STATE(5492),
    [sym_array] = STATE(2222),
    [sym_array_pattern] = STATE(5492),
    [sym_class] = STATE(2222),
    [sym_class_declaration] = STATE(831),
    [sym_function_expression] = STATE(2222),
    [sym_function_declaration] = STATE(831),
    [sym_generator_function] = STATE(2222),
    [sym_generator_function_declaration] = STATE(831),
    [sym_arrow_function] = STATE(2222),
    [sym__call_signature] = STATE(5821),
    [sym_call_expression] = STATE(2222),
    [sym_new_expression] = STATE(1948),
    [sym_await_expression] = STATE(2358),
    [sym_member_expression] = STATE(1362),
    [sym_subscript_expression] = STATE(1362),
    [sym_assignment_expression] = STATE(2358),
    [sym__augmented_assignment_lhs] = STATE(3025),
    [sym_augmented_assignment_expression] = STATE(2358),
    [sym__destructuring_pattern] = STATE(5492),
    [sym_ternary_expression] = STATE(2358),
    [sym_binary_expression] = STATE(2358),
    [sym_unary_expression] = STATE(2358),
    [sym_update_expression] = STATE(2358),
    [sym_sequence_expression] = STATE(5305),
    [sym_string] = STATE(2222),
    [sym_template_string] = STATE(2222),
    [sym_regex] = STATE(2222),
    [sym_meta_property] = STATE(2222),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1362),
    [sym_function_signature] = STATE(831),
    [sym_type_assertion] = STATE(2358),
    [sym_as_expression] = STATE(2358),
    [sym_satisfies_expression] = STATE(2358),
    [sym_instantiation_expression] = STATE(2358),
    [sym_ambient_declaration] = STATE(831),
    [sym_abstract_class_declaration] = STATE(831),
    [sym_module] = STATE(831),
    [sym_internal_module] = STATE(214),
    [sym_import_alias] = STATE(831),
    [sym_interface_declaration] = STATE(831),
    [sym_enum_declaration] = STATE(831),
    [sym_type_alias_declaration] = STATE(831),
    [sym_type_arguments] = STATE(428),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_program_repeat1] = STATE(22),
    [aux_sym_export_statement_repeat1] = STATE(3774),
    [sym_identifier] = ACTIONS(9),
    [anon_sym_export] = ACTIONS(13),
    [anon_sym_type] = ACTIONS(15),
    [anon_sym_namespace] = ACTIONS(17),
    [anon_sym_LBRACE] = ACTIONS(19),
    [anon_sym_RBRACE] = ACTIONS(525),
    [anon_sym_typeof] = ACTIONS(21),
    [anon_sym_import] = ACTIONS(23),
    [anon_sym_with] = ACTIONS(25),
    [anon_sym_var] = ACTIONS(27),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_const] = ACTIONS(31),
    [anon_sym_BANG] = ACTIONS(33),
    [anon_sym_if] = ACTIONS(35),
    [anon_sym_switch] = ACTIONS(37),
    [anon_sym_for] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_SEMI] = ACTIONS(43),
    [anon_sym_await] = ACTIONS(45),
    [anon_sym_while] = ACTIONS(47),
    [anon_sym_do] = ACTIONS(49),
    [anon_sym_try] = ACTIONS(51),
    [anon_sym_break] = ACTIONS(53),
    [anon_sym_continue] = ACTIONS(55),
    [anon_sym_debugger] = ACTIONS(57),
    [anon_sym_return] = ACTIONS(59),
    [anon_sym_throw] = ACTIONS(61),
    [anon_sym_yield] = ACTIONS(63),
    [anon_sym_LBRACK] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(67),
    [anon_sym_async] = ACTIONS(69),
    [anon_sym_function] = ACTIONS(71),
    [anon_sym_new] = ACTIONS(73),
    [anon_sym_using] = ACTIONS(75),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_SLASH] = ACTIONS(77),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(33),
    [anon_sym_void] = ACTIONS(21),
    [anon_sym_delete] = ACTIONS(21),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_DQUOTE] = ACTIONS(83),
    [anon_sym_SQUOTE] = ACTIONS(85),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(87),
    [sym_number] = ACTIONS(89),
    [sym_private_property_identifier] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(93),
    [sym_true] = ACTIONS(93),
    [sym_false] = ACTIONS(93),
    [sym_null] = ACTIONS(93),
    [sym_undefined] = ACTIONS(95),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(99),
    [anon_sym_readonly] = ACTIONS(99),
    [anon_sym_get] = ACTIONS(99),
    [anon_sym_set] = ACTIONS(99),
    [anon_sym_declare] = ACTIONS(101),
    [anon_sym_public] = ACTIONS(99),
    [anon_sym_private] = ACTIONS(99),
    [anon_sym_protected] = ACTIONS(99),
    [anon_sym_override] = ACTIONS(99),
    [anon_sym_module] = ACTIONS(103),
    [anon_sym_any] = ACTIONS(99),
    [anon_sym_number] = ACTIONS(99),
    [anon_sym_boolean] = ACTIONS(99),
    [anon_sym_string] = ACTIONS(99),
    [anon_sym_symbol] = ACTIONS(99),
    [anon_sym_object] = ACTIONS(99),
    [anon_sym_abstract] = ACTIONS(105),
    [anon_sym_interface] = ACTIONS(107),
    [anon_sym_enum] = ACTIONS(109),
    [sym_html_comment] = ACTIONS(5),
  },
  [24] = {
    [sym_export_statement] = STATE(892),
    [sym_declaration] = STATE(892),
    [sym_import] = STATE(3636),
    [sym_import_statement] = STATE(892),
    [sym_statement] = STATE(9),
    [sym_expression_statement] = STATE(892),
    [sym_variable_declaration] = STATE(831),
    [sym_lexical_declaration] = STATE(831),
    [sym_statement_block] = STATE(892),
    [sym_if_statement] = STATE(892),
    [sym_switch_statement] = STATE(892),
    [sym_for_statement] = STATE(892),
    [sym_for_in_statement] = STATE(892),
    [sym_while_statement] = STATE(892),
    [sym_do_statement] = STATE(892),
    [sym_try_statement] = STATE(892),
    [sym_with_statement] = STATE(892),
    [sym_break_statement] = STATE(892),
    [sym_continue_statement] = STATE(892),
    [sym_debugger_statement] = STATE(892),
    [sym_return_statement] = STATE(892),
    [sym_throw_statement] = STATE(892),
    [sym_empty_statement] = STATE(892),
    [sym_labeled_statement] = STATE(892),
    [sym_parenthesized_expression] = STATE(1362),
    [sym_expression] = STATE(1902),
    [sym_primary_expression] = STATE(1810),
    [sym_yield_expression] = STATE(2358),
    [sym_object] = STATE(2222),
    [sym_object_pattern] = STATE(5492),
    [sym_array] = STATE(2222),
    [sym_array_pattern] = STATE(5492),
    [sym_class] = STATE(2222),
    [sym_class_declaration] = STATE(831),
    [sym_function_expression] = STATE(2222),
    [sym_function_declaration] = STATE(831),
    [sym_generator_function] = STATE(2222),
    [sym_generator_function_declaration] = STATE(831),
    [sym_arrow_function] = STATE(2222),
    [sym__call_signature] = STATE(5821),
    [sym_call_expression] = STATE(2222),
    [sym_new_expression] = STATE(1948),
    [sym_await_expression] = STATE(2358),
    [sym_member_expression] = STATE(1362),
    [sym_subscript_expression] = STATE(1362),
    [sym_assignment_expression] = STATE(2358),
    [sym__augmented_assignment_lhs] = STATE(3025),
    [sym_augmented_assignment_expression] = STATE(2358),
    [sym__destructuring_pattern] = STATE(5492),
    [sym_ternary_expression] = STATE(2358),
    [sym_binary_expression] = STATE(2358),
    [sym_unary_expression] = STATE(2358),
    [sym_update_expression] = STATE(2358),
    [sym_sequence_expression] = STATE(5305),
    [sym_string] = STATE(2222),
    [sym_template_string] = STATE(2222),
    [sym_regex] = STATE(2222),
    [sym_meta_property] = STATE(2222),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1362),
    [sym_function_signature] = STATE(831),
    [sym_type_assertion] = STATE(2358),
    [sym_as_expression] = STATE(2358),
    [sym_satisfies_expression] = STATE(2358),
    [sym_instantiation_expression] = STATE(2358),
    [sym_ambient_declaration] = STATE(831),
    [sym_abstract_class_declaration] = STATE(831),
    [sym_module] = STATE(831),
    [sym_internal_module] = STATE(214),
    [sym_import_alias] = STATE(831),
    [sym_interface_declaration] = STATE(831),
    [sym_enum_declaration] = STATE(831),
    [sym_type_alias_declaration] = STATE(831),
    [sym_type_arguments] = STATE(428),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_program_repeat1] = STATE(9),
    [aux_sym_export_statement_repeat1] = STATE(3774),
    [sym_identifier] = ACTIONS(9),
    [anon_sym_export] = ACTIONS(13),
    [anon_sym_type] = ACTIONS(15),
    [anon_sym_namespace] = ACTIONS(17),
    [anon_sym_LBRACE] = ACTIONS(19),
    [anon_sym_RBRACE] = ACTIONS(527),
    [anon_sym_typeof] = ACTIONS(21),
    [anon_sym_import] = ACTIONS(23),
    [anon_sym_with] = ACTIONS(25),
    [anon_sym_var] = ACTIONS(27),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_const] = ACTIONS(31),
    [anon_sym_BANG] = ACTIONS(33),
    [anon_sym_if] = ACTIONS(35),
    [anon_sym_switch] = ACTIONS(37),
    [anon_sym_for] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_SEMI] = ACTIONS(43),
    [anon_sym_await] = ACTIONS(45),
    [anon_sym_while] = ACTIONS(47),
    [anon_sym_do] = ACTIONS(49),
    [anon_sym_try] = ACTIONS(51),
    [anon_sym_break] = ACTIONS(53),
    [anon_sym_continue] = ACTIONS(55),
    [anon_sym_debugger] = ACTIONS(57),
    [anon_sym_return] = ACTIONS(59),
    [anon_sym_throw] = ACTIONS(61),
    [anon_sym_yield] = ACTIONS(63),
    [anon_sym_LBRACK] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(67),
    [anon_sym_async] = ACTIONS(69),
    [anon_sym_function] = ACTIONS(71),
    [anon_sym_new] = ACTIONS(73),
    [anon_sym_using] = ACTIONS(75),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_SLASH] = ACTIONS(77),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(33),
    [anon_sym_void] = ACTIONS(21),
    [anon_sym_delete] = ACTIONS(21),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_DQUOTE] = ACTIONS(83),
    [anon_sym_SQUOTE] = ACTIONS(85),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(87),
    [sym_number] = ACTIONS(89),
    [sym_private_property_identifier] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(93),
    [sym_true] = ACTIONS(93),
    [sym_false] = ACTIONS(93),
    [sym_null] = ACTIONS(93),
    [sym_undefined] = ACTIONS(95),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(99),
    [anon_sym_readonly] = ACTIONS(99),
    [anon_sym_get] = ACTIONS(99),
    [anon_sym_set] = ACTIONS(99),
    [anon_sym_declare] = ACTIONS(101),
    [anon_sym_public] = ACTIONS(99),
    [anon_sym_private] = ACTIONS(99),
    [anon_sym_protected] = ACTIONS(99),
    [anon_sym_override] = ACTIONS(99),
    [anon_sym_module] = ACTIONS(103),
    [anon_sym_any] = ACTIONS(99),
    [anon_sym_number] = ACTIONS(99),
    [anon_sym_boolean] = ACTIONS(99),
    [anon_sym_string] = ACTIONS(99),
    [anon_sym_symbol] = ACTIONS(99),
    [anon_sym_object] = ACTIONS(99),
    [anon_sym_abstract] = ACTIONS(105),
    [anon_sym_interface] = ACTIONS(107),
    [anon_sym_enum] = ACTIONS(109),
    [sym_html_comment] = ACTIONS(5),
  },
  [25] = {
    [sym_export_statement] = STATE(892),
    [sym_declaration] = STATE(892),
    [sym_import] = STATE(3636),
    [sym_import_statement] = STATE(892),
    [sym_statement] = STATE(24),
    [sym_expression_statement] = STATE(892),
    [sym_variable_declaration] = STATE(831),
    [sym_lexical_declaration] = STATE(831),
    [sym_statement_block] = STATE(892),
    [sym_if_statement] = STATE(892),
    [sym_switch_statement] = STATE(892),
    [sym_for_statement] = STATE(892),
    [sym_for_in_statement] = STATE(892),
    [sym_while_statement] = STATE(892),
    [sym_do_statement] = STATE(892),
    [sym_try_statement] = STATE(892),
    [sym_with_statement] = STATE(892),
    [sym_break_statement] = STATE(892),
    [sym_continue_statement] = STATE(892),
    [sym_debugger_statement] = STATE(892),
    [sym_return_statement] = STATE(892),
    [sym_throw_statement] = STATE(892),
    [sym_empty_statement] = STATE(892),
    [sym_labeled_statement] = STATE(892),
    [sym_parenthesized_expression] = STATE(1362),
    [sym_expression] = STATE(1902),
    [sym_primary_expression] = STATE(1810),
    [sym_yield_expression] = STATE(2358),
    [sym_object] = STATE(2222),
    [sym_object_pattern] = STATE(5492),
    [sym_array] = STATE(2222),
    [sym_array_pattern] = STATE(5492),
    [sym_class] = STATE(2222),
    [sym_class_declaration] = STATE(831),
    [sym_function_expression] = STATE(2222),
    [sym_function_declaration] = STATE(831),
    [sym_generator_function] = STATE(2222),
    [sym_generator_function_declaration] = STATE(831),
    [sym_arrow_function] = STATE(2222),
    [sym__call_signature] = STATE(5821),
    [sym_call_expression] = STATE(2222),
    [sym_new_expression] = STATE(1948),
    [sym_await_expression] = STATE(2358),
    [sym_member_expression] = STATE(1362),
    [sym_subscript_expression] = STATE(1362),
    [sym_assignment_expression] = STATE(2358),
    [sym__augmented_assignment_lhs] = STATE(3025),
    [sym_augmented_assignment_expression] = STATE(2358),
    [sym__destructuring_pattern] = STATE(5492),
    [sym_ternary_expression] = STATE(2358),
    [sym_binary_expression] = STATE(2358),
    [sym_unary_expression] = STATE(2358),
    [sym_update_expression] = STATE(2358),
    [sym_sequence_expression] = STATE(5305),
    [sym_string] = STATE(2222),
    [sym_template_string] = STATE(2222),
    [sym_regex] = STATE(2222),
    [sym_meta_property] = STATE(2222),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1362),
    [sym_function_signature] = STATE(831),
    [sym_type_assertion] = STATE(2358),
    [sym_as_expression] = STATE(2358),
    [sym_satisfies_expression] = STATE(2358),
    [sym_instantiation_expression] = STATE(2358),
    [sym_ambient_declaration] = STATE(831),
    [sym_abstract_class_declaration] = STATE(831),
    [sym_module] = STATE(831),
    [sym_internal_module] = STATE(214),
    [sym_import_alias] = STATE(831),
    [sym_interface_declaration] = STATE(831),
    [sym_enum_declaration] = STATE(831),
    [sym_type_alias_declaration] = STATE(831),
    [sym_type_arguments] = STATE(428),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_program_repeat1] = STATE(24),
    [aux_sym_export_statement_repeat1] = STATE(3774),
    [sym_identifier] = ACTIONS(9),
    [anon_sym_export] = ACTIONS(13),
    [anon_sym_type] = ACTIONS(15),
    [anon_sym_namespace] = ACTIONS(17),
    [anon_sym_LBRACE] = ACTIONS(19),
    [anon_sym_RBRACE] = ACTIONS(529),
    [anon_sym_typeof] = ACTIONS(21),
    [anon_sym_import] = ACTIONS(23),
    [anon_sym_with] = ACTIONS(25),
    [anon_sym_var] = ACTIONS(27),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_const] = ACTIONS(31),
    [anon_sym_BANG] = ACTIONS(33),
    [anon_sym_if] = ACTIONS(35),
    [anon_sym_switch] = ACTIONS(37),
    [anon_sym_for] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_SEMI] = ACTIONS(43),
    [anon_sym_await] = ACTIONS(45),
    [anon_sym_while] = ACTIONS(47),
    [anon_sym_do] = ACTIONS(49),
    [anon_sym_try] = ACTIONS(51),
    [anon_sym_break] = ACTIONS(53),
    [anon_sym_continue] = ACTIONS(55),
    [anon_sym_debugger] = ACTIONS(57),
    [anon_sym_return] = ACTIONS(59),
    [anon_sym_throw] = ACTIONS(61),
    [anon_sym_yield] = ACTIONS(63),
    [anon_sym_LBRACK] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(67),
    [anon_sym_async] = ACTIONS(69),
    [anon_sym_function] = ACTIONS(71),
    [anon_sym_new] = ACTIONS(73),
    [anon_sym_using] = ACTIONS(75),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_SLASH] = ACTIONS(77),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(33),
    [anon_sym_void] = ACTIONS(21),
    [anon_sym_delete] = ACTIONS(21),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_DQUOTE] = ACTIONS(83),
    [anon_sym_SQUOTE] = ACTIONS(85),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(87),
    [sym_number] = ACTIONS(89),
    [sym_private_property_identifier] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(93),
    [sym_true] = ACTIONS(93),
    [sym_false] = ACTIONS(93),
    [sym_null] = ACTIONS(93),
    [sym_undefined] = ACTIONS(95),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(99),
    [anon_sym_readonly] = ACTIONS(99),
    [anon_sym_get] = ACTIONS(99),
    [anon_sym_set] = ACTIONS(99),
    [anon_sym_declare] = ACTIONS(101),
    [anon_sym_public] = ACTIONS(99),
    [anon_sym_private] = ACTIONS(99),
    [anon_sym_protected] = ACTIONS(99),
    [anon_sym_override] = ACTIONS(99),
    [anon_sym_module] = ACTIONS(103),
    [anon_sym_any] = ACTIONS(99),
    [anon_sym_number] = ACTIONS(99),
    [anon_sym_boolean] = ACTIONS(99),
    [anon_sym_string] = ACTIONS(99),
    [anon_sym_symbol] = ACTIONS(99),
    [anon_sym_object] = ACTIONS(99),
    [anon_sym_abstract] = ACTIONS(105),
    [anon_sym_interface] = ACTIONS(107),
    [anon_sym_enum] = ACTIONS(109),
    [sym_html_comment] = ACTIONS(5),
  },
  [26] = {
    [sym_export_statement] = STATE(892),
    [sym_declaration] = STATE(892),
    [sym_import] = STATE(3636),
    [sym_import_statement] = STATE(892),
    [sym_statement] = STATE(14),
    [sym_expression_statement] = STATE(892),
    [sym_variable_declaration] = STATE(831),
    [sym_lexical_declaration] = STATE(831),
    [sym_statement_block] = STATE(892),
    [sym_if_statement] = STATE(892),
    [sym_switch_statement] = STATE(892),
    [sym_for_statement] = STATE(892),
    [sym_for_in_statement] = STATE(892),
    [sym_while_statement] = STATE(892),
    [sym_do_statement] = STATE(892),
    [sym_try_statement] = STATE(892),
    [sym_with_statement] = STATE(892),
    [sym_break_statement] = STATE(892),
    [sym_continue_statement] = STATE(892),
    [sym_debugger_statement] = STATE(892),
    [sym_return_statement] = STATE(892),
    [sym_throw_statement] = STATE(892),
    [sym_empty_statement] = STATE(892),
    [sym_labeled_statement] = STATE(892),
    [sym_parenthesized_expression] = STATE(1362),
    [sym_expression] = STATE(1902),
    [sym_primary_expression] = STATE(1810),
    [sym_yield_expression] = STATE(2358),
    [sym_object] = STATE(2222),
    [sym_object_pattern] = STATE(5492),
    [sym_array] = STATE(2222),
    [sym_array_pattern] = STATE(5492),
    [sym_class] = STATE(2222),
    [sym_class_declaration] = STATE(831),
    [sym_function_expression] = STATE(2222),
    [sym_function_declaration] = STATE(831),
    [sym_generator_function] = STATE(2222),
    [sym_generator_function_declaration] = STATE(831),
    [sym_arrow_function] = STATE(2222),
    [sym__call_signature] = STATE(5821),
    [sym_call_expression] = STATE(2222),
    [sym_new_expression] = STATE(1948),
    [sym_await_expression] = STATE(2358),
    [sym_member_expression] = STATE(1362),
    [sym_subscript_expression] = STATE(1362),
    [sym_assignment_expression] = STATE(2358),
    [sym__augmented_assignment_lhs] = STATE(3025),
    [sym_augmented_assignment_expression] = STATE(2358),
    [sym__destructuring_pattern] = STATE(5492),
    [sym_ternary_expression] = STATE(2358),
    [sym_binary_expression] = STATE(2358),
    [sym_unary_expression] = STATE(2358),
    [sym_update_expression] = STATE(2358),
    [sym_sequence_expression] = STATE(5305),
    [sym_string] = STATE(2222),
    [sym_template_string] = STATE(2222),
    [sym_regex] = STATE(2222),
    [sym_meta_property] = STATE(2222),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1362),
    [sym_function_signature] = STATE(831),
    [sym_type_assertion] = STATE(2358),
    [sym_as_expression] = STATE(2358),
    [sym_satisfies_expression] = STATE(2358),
    [sym_instantiation_expression] = STATE(2358),
    [sym_ambient_declaration] = STATE(831),
    [sym_abstract_class_declaration] = STATE(831),
    [sym_module] = STATE(831),
    [sym_internal_module] = STATE(214),
    [sym_import_alias] = STATE(831),
    [sym_interface_declaration] = STATE(831),
    [sym_enum_declaration] = STATE(831),
    [sym_type_alias_declaration] = STATE(831),
    [sym_type_arguments] = STATE(428),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_program_repeat1] = STATE(14),
    [aux_sym_export_statement_repeat1] = STATE(3774),
    [sym_identifier] = ACTIONS(9),
    [anon_sym_export] = ACTIONS(13),
    [anon_sym_type] = ACTIONS(15),
    [anon_sym_namespace] = ACTIONS(17),
    [anon_sym_LBRACE] = ACTIONS(19),
    [anon_sym_RBRACE] = ACTIONS(531),
    [anon_sym_typeof] = ACTIONS(21),
    [anon_sym_import] = ACTIONS(23),
    [anon_sym_with] = ACTIONS(25),
    [anon_sym_var] = ACTIONS(27),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_const] = ACTIONS(31),
    [anon_sym_BANG] = ACTIONS(33),
    [anon_sym_if] = ACTIONS(35),
    [anon_sym_switch] = ACTIONS(37),
    [anon_sym_for] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_SEMI] = ACTIONS(43),
    [anon_sym_await] = ACTIONS(45),
    [anon_sym_while] = ACTIONS(47),
    [anon_sym_do] = ACTIONS(49),
    [anon_sym_try] = ACTIONS(51),
    [anon_sym_break] = ACTIONS(53),
    [anon_sym_continue] = ACTIONS(55),
    [anon_sym_debugger] = ACTIONS(57),
    [anon_sym_return] = ACTIONS(59),
    [anon_sym_throw] = ACTIONS(61),
    [anon_sym_yield] = ACTIONS(63),
    [anon_sym_LBRACK] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(67),
    [anon_sym_async] = ACTIONS(69),
    [anon_sym_function] = ACTIONS(71),
    [anon_sym_new] = ACTIONS(73),
    [anon_sym_using] = ACTIONS(75),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_SLASH] = ACTIONS(77),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(33),
    [anon_sym_void] = ACTIONS(21),
    [anon_sym_delete] = ACTIONS(21),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_DQUOTE] = ACTIONS(83),
    [anon_sym_SQUOTE] = ACTIONS(85),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(87),
    [sym_number] = ACTIONS(89),
    [sym_private_property_identifier] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(93),
    [sym_true] = ACTIONS(93),
    [sym_false] = ACTIONS(93),
    [sym_null] = ACTIONS(93),
    [sym_undefined] = ACTIONS(95),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(99),
    [anon_sym_readonly] = ACTIONS(99),
    [anon_sym_get] = ACTIONS(99),
    [anon_sym_set] = ACTIONS(99),
    [anon_sym_declare] = ACTIONS(101),
    [anon_sym_public] = ACTIONS(99),
    [anon_sym_private] = ACTIONS(99),
    [anon_sym_protected] = ACTIONS(99),
    [anon_sym_override] = ACTIONS(99),
    [anon_sym_module] = ACTIONS(103),
    [anon_sym_any] = ACTIONS(99),
    [anon_sym_number] = ACTIONS(99),
    [anon_sym_boolean] = ACTIONS(99),
    [anon_sym_string] = ACTIONS(99),
    [anon_sym_symbol] = ACTIONS(99),
    [anon_sym_object] = ACTIONS(99),
    [anon_sym_abstract] = ACTIONS(105),
    [anon_sym_interface] = ACTIONS(107),
    [anon_sym_enum] = ACTIONS(109),
    [sym_html_comment] = ACTIONS(5),
  },
  [27] = {
    [sym_export_statement] = STATE(892),
    [sym_declaration] = STATE(892),
    [sym_import] = STATE(3636),
    [sym_import_statement] = STATE(892),
    [sym_statement] = STATE(9),
    [sym_expression_statement] = STATE(892),
    [sym_variable_declaration] = STATE(831),
    [sym_lexical_declaration] = STATE(831),
    [sym_statement_block] = STATE(892),
    [sym_if_statement] = STATE(892),
    [sym_switch_statement] = STATE(892),
    [sym_for_statement] = STATE(892),
    [sym_for_in_statement] = STATE(892),
    [sym_while_statement] = STATE(892),
    [sym_do_statement] = STATE(892),
    [sym_try_statement] = STATE(892),
    [sym_with_statement] = STATE(892),
    [sym_break_statement] = STATE(892),
    [sym_continue_statement] = STATE(892),
    [sym_debugger_statement] = STATE(892),
    [sym_return_statement] = STATE(892),
    [sym_throw_statement] = STATE(892),
    [sym_empty_statement] = STATE(892),
    [sym_labeled_statement] = STATE(892),
    [sym_parenthesized_expression] = STATE(1362),
    [sym_expression] = STATE(1902),
    [sym_primary_expression] = STATE(1810),
    [sym_yield_expression] = STATE(2358),
    [sym_object] = STATE(2222),
    [sym_object_pattern] = STATE(5492),
    [sym_array] = STATE(2222),
    [sym_array_pattern] = STATE(5492),
    [sym_class] = STATE(2222),
    [sym_class_declaration] = STATE(831),
    [sym_function_expression] = STATE(2222),
    [sym_function_declaration] = STATE(831),
    [sym_generator_function] = STATE(2222),
    [sym_generator_function_declaration] = STATE(831),
    [sym_arrow_function] = STATE(2222),
    [sym__call_signature] = STATE(5821),
    [sym_call_expression] = STATE(2222),
    [sym_new_expression] = STATE(1948),
    [sym_await_expression] = STATE(2358),
    [sym_member_expression] = STATE(1362),
    [sym_subscript_expression] = STATE(1362),
    [sym_assignment_expression] = STATE(2358),
    [sym__augmented_assignment_lhs] = STATE(3025),
    [sym_augmented_assignment_expression] = STATE(2358),
    [sym__destructuring_pattern] = STATE(5492),
    [sym_ternary_expression] = STATE(2358),
    [sym_binary_expression] = STATE(2358),
    [sym_unary_expression] = STATE(2358),
    [sym_update_expression] = STATE(2358),
    [sym_sequence_expression] = STATE(5305),
    [sym_string] = STATE(2222),
    [sym_template_string] = STATE(2222),
    [sym_regex] = STATE(2222),
    [sym_meta_property] = STATE(2222),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1362),
    [sym_function_signature] = STATE(831),
    [sym_type_assertion] = STATE(2358),
    [sym_as_expression] = STATE(2358),
    [sym_satisfies_expression] = STATE(2358),
    [sym_instantiation_expression] = STATE(2358),
    [sym_ambient_declaration] = STATE(831),
    [sym_abstract_class_declaration] = STATE(831),
    [sym_module] = STATE(831),
    [sym_internal_module] = STATE(214),
    [sym_import_alias] = STATE(831),
    [sym_interface_declaration] = STATE(831),
    [sym_enum_declaration] = STATE(831),
    [sym_type_alias_declaration] = STATE(831),
    [sym_type_arguments] = STATE(428),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_program_repeat1] = STATE(9),
    [aux_sym_export_statement_repeat1] = STATE(3774),
    [sym_identifier] = ACTIONS(9),
    [anon_sym_export] = ACTIONS(13),
    [anon_sym_type] = ACTIONS(15),
    [anon_sym_namespace] = ACTIONS(17),
    [anon_sym_LBRACE] = ACTIONS(19),
    [anon_sym_RBRACE] = ACTIONS(533),
    [anon_sym_typeof] = ACTIONS(21),
    [anon_sym_import] = ACTIONS(23),
    [anon_sym_with] = ACTIONS(25),
    [anon_sym_var] = ACTIONS(27),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_const] = ACTIONS(31),
    [anon_sym_BANG] = ACTIONS(33),
    [anon_sym_if] = ACTIONS(35),
    [anon_sym_switch] = ACTIONS(37),
    [anon_sym_for] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_SEMI] = ACTIONS(43),
    [anon_sym_await] = ACTIONS(45),
    [anon_sym_while] = ACTIONS(47),
    [anon_sym_do] = ACTIONS(49),
    [anon_sym_try] = ACTIONS(51),
    [anon_sym_break] = ACTIONS(53),
    [anon_sym_continue] = ACTIONS(55),
    [anon_sym_debugger] = ACTIONS(57),
    [anon_sym_return] = ACTIONS(59),
    [anon_sym_throw] = ACTIONS(61),
    [anon_sym_yield] = ACTIONS(63),
    [anon_sym_LBRACK] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(67),
    [anon_sym_async] = ACTIONS(69),
    [anon_sym_function] = ACTIONS(71),
    [anon_sym_new] = ACTIONS(73),
    [anon_sym_using] = ACTIONS(75),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_SLASH] = ACTIONS(77),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(33),
    [anon_sym_void] = ACTIONS(21),
    [anon_sym_delete] = ACTIONS(21),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_DQUOTE] = ACTIONS(83),
    [anon_sym_SQUOTE] = ACTIONS(85),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(87),
    [sym_number] = ACTIONS(89),
    [sym_private_property_identifier] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(93),
    [sym_true] = ACTIONS(93),
    [sym_false] = ACTIONS(93),
    [sym_null] = ACTIONS(93),
    [sym_undefined] = ACTIONS(95),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(99),
    [anon_sym_readonly] = ACTIONS(99),
    [anon_sym_get] = ACTIONS(99),
    [anon_sym_set] = ACTIONS(99),
    [anon_sym_declare] = ACTIONS(101),
    [anon_sym_public] = ACTIONS(99),
    [anon_sym_private] = ACTIONS(99),
    [anon_sym_protected] = ACTIONS(99),
    [anon_sym_override] = ACTIONS(99),
    [anon_sym_module] = ACTIONS(103),
    [anon_sym_any] = ACTIONS(99),
    [anon_sym_number] = ACTIONS(99),
    [anon_sym_boolean] = ACTIONS(99),
    [anon_sym_string] = ACTIONS(99),
    [anon_sym_symbol] = ACTIONS(99),
    [anon_sym_object] = ACTIONS(99),
    [anon_sym_abstract] = ACTIONS(105),
    [anon_sym_interface] = ACTIONS(107),
    [anon_sym_enum] = ACTIONS(109),
    [sym_html_comment] = ACTIONS(5),
  },
  [28] = {
    [sym_export_statement] = STATE(892),
    [sym_declaration] = STATE(892),
    [sym_import] = STATE(3636),
    [sym_import_statement] = STATE(892),
    [sym_statement] = STATE(15),
    [sym_expression_statement] = STATE(892),
    [sym_variable_declaration] = STATE(831),
    [sym_lexical_declaration] = STATE(831),
    [sym_statement_block] = STATE(892),
    [sym_if_statement] = STATE(892),
    [sym_switch_statement] = STATE(892),
    [sym_for_statement] = STATE(892),
    [sym_for_in_statement] = STATE(892),
    [sym_while_statement] = STATE(892),
    [sym_do_statement] = STATE(892),
    [sym_try_statement] = STATE(892),
    [sym_with_statement] = STATE(892),
    [sym_break_statement] = STATE(892),
    [sym_continue_statement] = STATE(892),
    [sym_debugger_statement] = STATE(892),
    [sym_return_statement] = STATE(892),
    [sym_throw_statement] = STATE(892),
    [sym_empty_statement] = STATE(892),
    [sym_labeled_statement] = STATE(892),
    [sym_parenthesized_expression] = STATE(1362),
    [sym_expression] = STATE(1902),
    [sym_primary_expression] = STATE(1810),
    [sym_yield_expression] = STATE(2358),
    [sym_object] = STATE(2222),
    [sym_object_pattern] = STATE(5492),
    [sym_array] = STATE(2222),
    [sym_array_pattern] = STATE(5492),
    [sym_class] = STATE(2222),
    [sym_class_declaration] = STATE(831),
    [sym_function_expression] = STATE(2222),
    [sym_function_declaration] = STATE(831),
    [sym_generator_function] = STATE(2222),
    [sym_generator_function_declaration] = STATE(831),
    [sym_arrow_function] = STATE(2222),
    [sym__call_signature] = STATE(5821),
    [sym_call_expression] = STATE(2222),
    [sym_new_expression] = STATE(1948),
    [sym_await_expression] = STATE(2358),
    [sym_member_expression] = STATE(1362),
    [sym_subscript_expression] = STATE(1362),
    [sym_assignment_expression] = STATE(2358),
    [sym__augmented_assignment_lhs] = STATE(3025),
    [sym_augmented_assignment_expression] = STATE(2358),
    [sym__destructuring_pattern] = STATE(5492),
    [sym_ternary_expression] = STATE(2358),
    [sym_binary_expression] = STATE(2358),
    [sym_unary_expression] = STATE(2358),
    [sym_update_expression] = STATE(2358),
    [sym_sequence_expression] = STATE(5305),
    [sym_string] = STATE(2222),
    [sym_template_string] = STATE(2222),
    [sym_regex] = STATE(2222),
    [sym_meta_property] = STATE(2222),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1362),
    [sym_function_signature] = STATE(831),
    [sym_type_assertion] = STATE(2358),
    [sym_as_expression] = STATE(2358),
    [sym_satisfies_expression] = STATE(2358),
    [sym_instantiation_expression] = STATE(2358),
    [sym_ambient_declaration] = STATE(831),
    [sym_abstract_class_declaration] = STATE(831),
    [sym_module] = STATE(831),
    [sym_internal_module] = STATE(214),
    [sym_import_alias] = STATE(831),
    [sym_interface_declaration] = STATE(831),
    [sym_enum_declaration] = STATE(831),
    [sym_type_alias_declaration] = STATE(831),
    [sym_type_arguments] = STATE(428),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_program_repeat1] = STATE(15),
    [aux_sym_export_statement_repeat1] = STATE(3774),
    [sym_identifier] = ACTIONS(9),
    [anon_sym_export] = ACTIONS(13),
    [anon_sym_type] = ACTIONS(15),
    [anon_sym_namespace] = ACTIONS(17),
    [anon_sym_LBRACE] = ACTIONS(19),
    [anon_sym_RBRACE] = ACTIONS(535),
    [anon_sym_typeof] = ACTIONS(21),
    [anon_sym_import] = ACTIONS(23),
    [anon_sym_with] = ACTIONS(25),
    [anon_sym_var] = ACTIONS(27),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_const] = ACTIONS(31),
    [anon_sym_BANG] = ACTIONS(33),
    [anon_sym_if] = ACTIONS(35),
    [anon_sym_switch] = ACTIONS(37),
    [anon_sym_for] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_SEMI] = ACTIONS(43),
    [anon_sym_await] = ACTIONS(45),
    [anon_sym_while] = ACTIONS(47),
    [anon_sym_do] = ACTIONS(49),
    [anon_sym_try] = ACTIONS(51),
    [anon_sym_break] = ACTIONS(53),
    [anon_sym_continue] = ACTIONS(55),
    [anon_sym_debugger] = ACTIONS(57),
    [anon_sym_return] = ACTIONS(59),
    [anon_sym_throw] = ACTIONS(61),
    [anon_sym_yield] = ACTIONS(63),
    [anon_sym_LBRACK] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(67),
    [anon_sym_async] = ACTIONS(69),
    [anon_sym_function] = ACTIONS(71),
    [anon_sym_new] = ACTIONS(73),
    [anon_sym_using] = ACTIONS(75),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_SLASH] = ACTIONS(77),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(33),
    [anon_sym_void] = ACTIONS(21),
    [anon_sym_delete] = ACTIONS(21),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_DQUOTE] = ACTIONS(83),
    [anon_sym_SQUOTE] = ACTIONS(85),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(87),
    [sym_number] = ACTIONS(89),
    [sym_private_property_identifier] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(93),
    [sym_true] = ACTIONS(93),
    [sym_false] = ACTIONS(93),
    [sym_null] = ACTIONS(93),
    [sym_undefined] = ACTIONS(95),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(99),
    [anon_sym_readonly] = ACTIONS(99),
    [anon_sym_get] = ACTIONS(99),
    [anon_sym_set] = ACTIONS(99),
    [anon_sym_declare] = ACTIONS(101),
    [anon_sym_public] = ACTIONS(99),
    [anon_sym_private] = ACTIONS(99),
    [anon_sym_protected] = ACTIONS(99),
    [anon_sym_override] = ACTIONS(99),
    [anon_sym_module] = ACTIONS(103),
    [anon_sym_any] = ACTIONS(99),
    [anon_sym_number] = ACTIONS(99),
    [anon_sym_boolean] = ACTIONS(99),
    [anon_sym_string] = ACTIONS(99),
    [anon_sym_symbol] = ACTIONS(99),
    [anon_sym_object] = ACTIONS(99),
    [anon_sym_abstract] = ACTIONS(105),
    [anon_sym_interface] = ACTIONS(107),
    [anon_sym_enum] = ACTIONS(109),
    [sym_html_comment] = ACTIONS(5),
  },
  [29] = {
    [sym_export_statement] = STATE(892),
    [sym_declaration] = STATE(892),
    [sym_import] = STATE(3636),
    [sym_import_statement] = STATE(892),
    [sym_statement] = STATE(27),
    [sym_expression_statement] = STATE(892),
    [sym_variable_declaration] = STATE(831),
    [sym_lexical_declaration] = STATE(831),
    [sym_statement_block] = STATE(892),
    [sym_if_statement] = STATE(892),
    [sym_switch_statement] = STATE(892),
    [sym_for_statement] = STATE(892),
    [sym_for_in_statement] = STATE(892),
    [sym_while_statement] = STATE(892),
    [sym_do_statement] = STATE(892),
    [sym_try_statement] = STATE(892),
    [sym_with_statement] = STATE(892),
    [sym_break_statement] = STATE(892),
    [sym_continue_statement] = STATE(892),
    [sym_debugger_statement] = STATE(892),
    [sym_return_statement] = STATE(892),
    [sym_throw_statement] = STATE(892),
    [sym_empty_statement] = STATE(892),
    [sym_labeled_statement] = STATE(892),
    [sym_parenthesized_expression] = STATE(1362),
    [sym_expression] = STATE(1902),
    [sym_primary_expression] = STATE(1810),
    [sym_yield_expression] = STATE(2358),
    [sym_object] = STATE(2222),
    [sym_object_pattern] = STATE(5492),
    [sym_array] = STATE(2222),
    [sym_array_pattern] = STATE(5492),
    [sym_class] = STATE(2222),
    [sym_class_declaration] = STATE(831),
    [sym_function_expression] = STATE(2222),
    [sym_function_declaration] = STATE(831),
    [sym_generator_function] = STATE(2222),
    [sym_generator_function_declaration] = STATE(831),
    [sym_arrow_function] = STATE(2222),
    [sym__call_signature] = STATE(5821),
    [sym_call_expression] = STATE(2222),
    [sym_new_expression] = STATE(1948),
    [sym_await_expression] = STATE(2358),
    [sym_member_expression] = STATE(1362),
    [sym_subscript_expression] = STATE(1362),
    [sym_assignment_expression] = STATE(2358),
    [sym__augmented_assignment_lhs] = STATE(3025),
    [sym_augmented_assignment_expression] = STATE(2358),
    [sym__destructuring_pattern] = STATE(5492),
    [sym_ternary_expression] = STATE(2358),
    [sym_binary_expression] = STATE(2358),
    [sym_unary_expression] = STATE(2358),
    [sym_update_expression] = STATE(2358),
    [sym_sequence_expression] = STATE(5305),
    [sym_string] = STATE(2222),
    [sym_template_string] = STATE(2222),
    [sym_regex] = STATE(2222),
    [sym_meta_property] = STATE(2222),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1362),
    [sym_function_signature] = STATE(831),
    [sym_type_assertion] = STATE(2358),
    [sym_as_expression] = STATE(2358),
    [sym_satisfies_expression] = STATE(2358),
    [sym_instantiation_expression] = STATE(2358),
    [sym_ambient_declaration] = STATE(831),
    [sym_abstract_class_declaration] = STATE(831),
    [sym_module] = STATE(831),
    [sym_internal_module] = STATE(214),
    [sym_import_alias] = STATE(831),
    [sym_interface_declaration] = STATE(831),
    [sym_enum_declaration] = STATE(831),
    [sym_type_alias_declaration] = STATE(831),
    [sym_type_arguments] = STATE(428),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_program_repeat1] = STATE(27),
    [aux_sym_export_statement_repeat1] = STATE(3774),
    [sym_identifier] = ACTIONS(9),
    [anon_sym_export] = ACTIONS(13),
    [anon_sym_type] = ACTIONS(15),
    [anon_sym_namespace] = ACTIONS(17),
    [anon_sym_LBRACE] = ACTIONS(19),
    [anon_sym_RBRACE] = ACTIONS(537),
    [anon_sym_typeof] = ACTIONS(21),
    [anon_sym_import] = ACTIONS(23),
    [anon_sym_with] = ACTIONS(25),
    [anon_sym_var] = ACTIONS(27),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_const] = ACTIONS(31),
    [anon_sym_BANG] = ACTIONS(33),
    [anon_sym_if] = ACTIONS(35),
    [anon_sym_switch] = ACTIONS(37),
    [anon_sym_for] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_SEMI] = ACTIONS(43),
    [anon_sym_await] = ACTIONS(45),
    [anon_sym_while] = ACTIONS(47),
    [anon_sym_do] = ACTIONS(49),
    [anon_sym_try] = ACTIONS(51),
    [anon_sym_break] = ACTIONS(53),
    [anon_sym_continue] = ACTIONS(55),
    [anon_sym_debugger] = ACTIONS(57),
    [anon_sym_return] = ACTIONS(59),
    [anon_sym_throw] = ACTIONS(61),
    [anon_sym_yield] = ACTIONS(63),
    [anon_sym_LBRACK] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(67),
    [anon_sym_async] = ACTIONS(69),
    [anon_sym_function] = ACTIONS(71),
    [anon_sym_new] = ACTIONS(73),
    [anon_sym_using] = ACTIONS(75),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_SLASH] = ACTIONS(77),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(33),
    [anon_sym_void] = ACTIONS(21),
    [anon_sym_delete] = ACTIONS(21),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_DQUOTE] = ACTIONS(83),
    [anon_sym_SQUOTE] = ACTIONS(85),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(87),
    [sym_number] = ACTIONS(89),
    [sym_private_property_identifier] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(93),
    [sym_true] = ACTIONS(93),
    [sym_false] = ACTIONS(93),
    [sym_null] = ACTIONS(93),
    [sym_undefined] = ACTIONS(95),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(99),
    [anon_sym_readonly] = ACTIONS(99),
    [anon_sym_get] = ACTIONS(99),
    [anon_sym_set] = ACTIONS(99),
    [anon_sym_declare] = ACTIONS(101),
    [anon_sym_public] = ACTIONS(99),
    [anon_sym_private] = ACTIONS(99),
    [anon_sym_protected] = ACTIONS(99),
    [anon_sym_override] = ACTIONS(99),
    [anon_sym_module] = ACTIONS(103),
    [anon_sym_any] = ACTIONS(99),
    [anon_sym_number] = ACTIONS(99),
    [anon_sym_boolean] = ACTIONS(99),
    [anon_sym_string] = ACTIONS(99),
    [anon_sym_symbol] = ACTIONS(99),
    [anon_sym_object] = ACTIONS(99),
    [anon_sym_abstract] = ACTIONS(105),
    [anon_sym_interface] = ACTIONS(107),
    [anon_sym_enum] = ACTIONS(109),
    [sym_html_comment] = ACTIONS(5),
  },
  [30] = {
    [sym_export_statement] = STATE(892),
    [sym_declaration] = STATE(892),
    [sym_import] = STATE(3636),
    [sym_import_statement] = STATE(892),
    [sym_statement] = STATE(17),
    [sym_expression_statement] = STATE(892),
    [sym_variable_declaration] = STATE(831),
    [sym_lexical_declaration] = STATE(831),
    [sym_statement_block] = STATE(892),
    [sym_if_statement] = STATE(892),
    [sym_switch_statement] = STATE(892),
    [sym_for_statement] = STATE(892),
    [sym_for_in_statement] = STATE(892),
    [sym_while_statement] = STATE(892),
    [sym_do_statement] = STATE(892),
    [sym_try_statement] = STATE(892),
    [sym_with_statement] = STATE(892),
    [sym_break_statement] = STATE(892),
    [sym_continue_statement] = STATE(892),
    [sym_debugger_statement] = STATE(892),
    [sym_return_statement] = STATE(892),
    [sym_throw_statement] = STATE(892),
    [sym_empty_statement] = STATE(892),
    [sym_labeled_statement] = STATE(892),
    [sym_parenthesized_expression] = STATE(1362),
    [sym_expression] = STATE(1902),
    [sym_primary_expression] = STATE(1810),
    [sym_yield_expression] = STATE(2358),
    [sym_object] = STATE(2222),
    [sym_object_pattern] = STATE(5492),
    [sym_array] = STATE(2222),
    [sym_array_pattern] = STATE(5492),
    [sym_class] = STATE(2222),
    [sym_class_declaration] = STATE(831),
    [sym_function_expression] = STATE(2222),
    [sym_function_declaration] = STATE(831),
    [sym_generator_function] = STATE(2222),
    [sym_generator_function_declaration] = STATE(831),
    [sym_arrow_function] = STATE(2222),
    [sym__call_signature] = STATE(5821),
    [sym_call_expression] = STATE(2222),
    [sym_new_expression] = STATE(1948),
    [sym_await_expression] = STATE(2358),
    [sym_member_expression] = STATE(1362),
    [sym_subscript_expression] = STATE(1362),
    [sym_assignment_expression] = STATE(2358),
    [sym__augmented_assignment_lhs] = STATE(3025),
    [sym_augmented_assignment_expression] = STATE(2358),
    [sym__destructuring_pattern] = STATE(5492),
    [sym_ternary_expression] = STATE(2358),
    [sym_binary_expression] = STATE(2358),
    [sym_unary_expression] = STATE(2358),
    [sym_update_expression] = STATE(2358),
    [sym_sequence_expression] = STATE(5305),
    [sym_string] = STATE(2222),
    [sym_template_string] = STATE(2222),
    [sym_regex] = STATE(2222),
    [sym_meta_property] = STATE(2222),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1362),
    [sym_function_signature] = STATE(831),
    [sym_type_assertion] = STATE(2358),
    [sym_as_expression] = STATE(2358),
    [sym_satisfies_expression] = STATE(2358),
    [sym_instantiation_expression] = STATE(2358),
    [sym_ambient_declaration] = STATE(831),
    [sym_abstract_class_declaration] = STATE(831),
    [sym_module] = STATE(831),
    [sym_internal_module] = STATE(214),
    [sym_import_alias] = STATE(831),
    [sym_interface_declaration] = STATE(831),
    [sym_enum_declaration] = STATE(831),
    [sym_type_alias_declaration] = STATE(831),
    [sym_type_arguments] = STATE(428),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_program_repeat1] = STATE(17),
    [aux_sym_export_statement_repeat1] = STATE(3774),
    [ts_builtin_sym_end] = ACTIONS(511),
    [sym_identifier] = ACTIONS(9),
    [anon_sym_export] = ACTIONS(13),
    [anon_sym_type] = ACTIONS(15),
    [anon_sym_namespace] = ACTIONS(17),
    [anon_sym_LBRACE] = ACTIONS(19),
    [anon_sym_typeof] = ACTIONS(21),
    [anon_sym_import] = ACTIONS(23),
    [anon_sym_with] = ACTIONS(25),
    [anon_sym_var] = ACTIONS(27),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_const] = ACTIONS(31),
    [anon_sym_BANG] = ACTIONS(33),
    [anon_sym_if] = ACTIONS(35),
    [anon_sym_switch] = ACTIONS(37),
    [anon_sym_for] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_SEMI] = ACTIONS(43),
    [anon_sym_await] = ACTIONS(45),
    [anon_sym_while] = ACTIONS(47),
    [anon_sym_do] = ACTIONS(49),
    [anon_sym_try] = ACTIONS(51),
    [anon_sym_break] = ACTIONS(53),
    [anon_sym_continue] = ACTIONS(55),
    [anon_sym_debugger] = ACTIONS(57),
    [anon_sym_return] = ACTIONS(59),
    [anon_sym_throw] = ACTIONS(61),
    [anon_sym_yield] = ACTIONS(63),
    [anon_sym_LBRACK] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(67),
    [anon_sym_async] = ACTIONS(69),
    [anon_sym_function] = ACTIONS(71),
    [anon_sym_new] = ACTIONS(73),
    [anon_sym_using] = ACTIONS(75),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_SLASH] = ACTIONS(77),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(33),
    [anon_sym_void] = ACTIONS(21),
    [anon_sym_delete] = ACTIONS(21),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_DQUOTE] = ACTIONS(83),
    [anon_sym_SQUOTE] = ACTIONS(85),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(87),
    [sym_number] = ACTIONS(89),
    [sym_private_property_identifier] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(93),
    [sym_true] = ACTIONS(93),
    [sym_false] = ACTIONS(93),
    [sym_null] = ACTIONS(93),
    [sym_undefined] = ACTIONS(95),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(99),
    [anon_sym_readonly] = ACTIONS(99),
    [anon_sym_get] = ACTIONS(99),
    [anon_sym_set] = ACTIONS(99),
    [anon_sym_declare] = ACTIONS(101),
    [anon_sym_public] = ACTIONS(99),
    [anon_sym_private] = ACTIONS(99),
    [anon_sym_protected] = ACTIONS(99),
    [anon_sym_override] = ACTIONS(99),
    [anon_sym_module] = ACTIONS(103),
    [anon_sym_any] = ACTIONS(99),
    [anon_sym_number] = ACTIONS(99),
    [anon_sym_boolean] = ACTIONS(99),
    [anon_sym_string] = ACTIONS(99),
    [anon_sym_symbol] = ACTIONS(99),
    [anon_sym_object] = ACTIONS(99),
    [anon_sym_abstract] = ACTIONS(105),
    [anon_sym_interface] = ACTIONS(107),
    [anon_sym_enum] = ACTIONS(109),
    [sym_html_comment] = ACTIONS(5),
  },
  [31] = {
    [sym_import] = STATE(3663),
    [sym_parenthesized_expression] = STATE(1322),
    [sym_expression] = STATE(2126),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(4425),
    [sym_assignment_pattern] = STATE(4969),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(4425),
    [sym_nested_identifier] = STATE(5474),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5508),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1396),
    [sym_subscript_expression] = STATE(1396),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3003),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(4425),
    [sym_spread_element] = STATE(4946),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(2213),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(4317),
    [sym_pattern] = STATE(4406),
    [sym_rest_pattern] = STATE(4115),
    [sym_non_null_expression] = STATE(1396),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_nested_type_identifier] = STATE(2939),
    [sym__type_query_member_expression_in_type_annotation] = STATE(3303),
    [sym__type_query_call_expression_in_type_annotation] = STATE(2938),
    [sym_type] = STATE(3773),
    [sym_tuple_parameter] = STATE(4568),
    [sym_optional_tuple_parameter] = STATE(4568),
    [sym_optional_type] = STATE(4568),
    [sym_rest_type] = STATE(4568),
    [sym__tuple_type_member] = STATE(4568),
    [sym_constructor_type] = STATE(3007),
    [sym_primary_type] = STATE(2981),
    [sym_template_literal_type] = STATE(3039),
    [sym_infer_type] = STATE(3007),
    [sym_conditional_type] = STATE(3039),
    [sym_generic_type] = STATE(3039),
    [sym_type_query] = STATE(3039),
    [sym_index_type_query] = STATE(3039),
    [sym_lookup_type] = STATE(3039),
    [sym_literal_type] = STATE(3039),
    [sym__number] = STATE(3041),
    [sym_existential_type] = STATE(3039),
    [sym_flow_maybe_type] = STATE(3039),
    [sym_parenthesized_type] = STATE(3039),
    [sym_predefined_type] = STATE(3039),
    [sym_type_arguments] = STATE(484),
    [sym_object_type] = STATE(3039),
    [sym_type_parameters] = STATE(5455),
    [sym_array_type] = STATE(3039),
    [sym_tuple_type] = STATE(3039),
    [sym_readonly_type] = STATE(3007),
    [sym_union_type] = STATE(3039),
    [sym_intersection_type] = STATE(3039),
    [sym_function_type] = STATE(3007),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [aux_sym_array_repeat1] = STATE(4955),
    [aux_sym_array_pattern_repeat1] = STATE(4977),
    [sym_identifier] = ACTIONS(539),
    [anon_sym_export] = ACTIONS(541),
    [anon_sym_STAR] = ACTIONS(543),
    [anon_sym_type] = ACTIONS(541),
    [anon_sym_namespace] = ACTIONS(545),
    [anon_sym_LBRACE] = ACTIONS(547),
    [anon_sym_COMMA] = ACTIONS(549),
    [anon_sym_typeof] = ACTIONS(551),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(541),
    [anon_sym_const] = ACTIONS(133),
    [anon_sym_BANG] = ACTIONS(553),
    [anon_sym_LPAREN] = ACTIONS(138),
    [anon_sym_await] = ACTIONS(555),
    [anon_sym_yield] = ACTIONS(557),
    [anon_sym_LBRACK] = ACTIONS(559),
    [anon_sym_RBRACK] = ACTIONS(561),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(563),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(565),
    [anon_sym_using] = ACTIONS(567),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(569),
    [anon_sym_AMP] = ACTIONS(571),
    [anon_sym_PIPE] = ACTIONS(573),
    [anon_sym_PLUS] = ACTIONS(575),
    [anon_sym_DASH] = ACTIONS(575),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(553),
    [anon_sym_void] = ACTIONS(579),
    [anon_sym_delete] = ACTIONS(581),
    [anon_sym_PLUS_PLUS] = ACTIONS(583),
    [anon_sym_DASH_DASH] = ACTIONS(583),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(188),
    [sym_number] = ACTIONS(190),
    [sym_private_property_identifier] = ACTIONS(585),
    [sym_this] = ACTIONS(587),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(198),
    [sym_false] = ACTIONS(198),
    [sym_null] = ACTIONS(198),
    [sym_undefined] = ACTIONS(589),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(541),
    [anon_sym_readonly] = ACTIONS(591),
    [anon_sym_get] = ACTIONS(541),
    [anon_sym_set] = ACTIONS(541),
    [anon_sym_QMARK] = ACTIONS(593),
    [anon_sym_declare] = ACTIONS(541),
    [anon_sym_public] = ACTIONS(541),
    [anon_sym_private] = ACTIONS(541),
    [anon_sym_protected] = ACTIONS(541),
    [anon_sym_override] = ACTIONS(541),
    [anon_sym_module] = ACTIONS(541),
    [anon_sym_any] = ACTIONS(595),
    [anon_sym_number] = ACTIONS(595),
    [anon_sym_boolean] = ACTIONS(595),
    [anon_sym_string] = ACTIONS(595),
    [anon_sym_symbol] = ACTIONS(595),
    [anon_sym_object] = ACTIONS(595),
    [anon_sym_abstract] = ACTIONS(597),
    [anon_sym_infer] = ACTIONS(599),
    [anon_sym_keyof] = ACTIONS(601),
    [anon_sym_unique] = ACTIONS(214),
    [anon_sym_unknown] = ACTIONS(216),
    [anon_sym_never] = ACTIONS(216),
    [anon_sym_LBRACE_PIPE] = ACTIONS(218),
    [sym_html_comment] = ACTIONS(5),
  },
  [32] = {
    [sym_export_statement] = STATE(892),
    [sym_declaration] = STATE(892),
    [sym_import] = STATE(3636),
    [sym_import_statement] = STATE(892),
    [sym_statement] = STATE(940),
    [sym_expression_statement] = STATE(892),
    [sym_variable_declaration] = STATE(831),
    [sym_lexical_declaration] = STATE(831),
    [sym_statement_block] = STATE(892),
    [sym_if_statement] = STATE(892),
    [sym_switch_statement] = STATE(892),
    [sym_for_statement] = STATE(892),
    [sym_for_in_statement] = STATE(892),
    [sym_while_statement] = STATE(892),
    [sym_do_statement] = STATE(892),
    [sym_try_statement] = STATE(892),
    [sym_with_statement] = STATE(892),
    [sym_break_statement] = STATE(892),
    [sym_continue_statement] = STATE(892),
    [sym_debugger_statement] = STATE(892),
    [sym_return_statement] = STATE(892),
    [sym_throw_statement] = STATE(892),
    [sym_empty_statement] = STATE(892),
    [sym_labeled_statement] = STATE(892),
    [sym_parenthesized_expression] = STATE(1362),
    [sym_expression] = STATE(1902),
    [sym_primary_expression] = STATE(1810),
    [sym_yield_expression] = STATE(2358),
    [sym_object] = STATE(2222),
    [sym_object_pattern] = STATE(5492),
    [sym_array] = STATE(2222),
    [sym_array_pattern] = STATE(5492),
    [sym_class] = STATE(2222),
    [sym_class_declaration] = STATE(831),
    [sym_function_expression] = STATE(2222),
    [sym_function_declaration] = STATE(831),
    [sym_generator_function] = STATE(2222),
    [sym_generator_function_declaration] = STATE(831),
    [sym_arrow_function] = STATE(2222),
    [sym__call_signature] = STATE(5821),
    [sym_call_expression] = STATE(2222),
    [sym_new_expression] = STATE(1948),
    [sym_await_expression] = STATE(2358),
    [sym_member_expression] = STATE(1362),
    [sym_subscript_expression] = STATE(1362),
    [sym_assignment_expression] = STATE(2358),
    [sym__augmented_assignment_lhs] = STATE(3025),
    [sym_augmented_assignment_expression] = STATE(2358),
    [sym__destructuring_pattern] = STATE(5492),
    [sym_ternary_expression] = STATE(2358),
    [sym_binary_expression] = STATE(2358),
    [sym_unary_expression] = STATE(2358),
    [sym_update_expression] = STATE(2358),
    [sym_sequence_expression] = STATE(5305),
    [sym_string] = STATE(2222),
    [sym_template_string] = STATE(2222),
    [sym_regex] = STATE(2222),
    [sym_meta_property] = STATE(2222),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1362),
    [sym_function_signature] = STATE(831),
    [sym_type_assertion] = STATE(2358),
    [sym_as_expression] = STATE(2358),
    [sym_satisfies_expression] = STATE(2358),
    [sym_instantiation_expression] = STATE(2358),
    [sym_ambient_declaration] = STATE(831),
    [sym_abstract_class_declaration] = STATE(831),
    [sym_module] = STATE(831),
    [sym_internal_module] = STATE(2513),
    [sym_import_alias] = STATE(831),
    [sym_interface_declaration] = STATE(831),
    [sym_enum_declaration] = STATE(831),
    [sym_type_alias_declaration] = STATE(831),
    [sym_type_arguments] = STATE(428),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(3830),
    [sym_identifier] = ACTIONS(603),
    [anon_sym_export] = ACTIONS(605),
    [anon_sym_type] = ACTIONS(607),
    [anon_sym_namespace] = ACTIONS(609),
    [anon_sym_LBRACE] = ACTIONS(611),
    [anon_sym_typeof] = ACTIONS(21),
    [anon_sym_import] = ACTIONS(23),
    [anon_sym_with] = ACTIONS(613),
    [anon_sym_var] = ACTIONS(27),
    [anon_sym_let] = ACTIONS(615),
    [anon_sym_const] = ACTIONS(31),
    [anon_sym_BANG] = ACTIONS(33),
    [anon_sym_if] = ACTIONS(617),
    [anon_sym_switch] = ACTIONS(37),
    [anon_sym_for] = ACTIONS(619),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_SEMI] = ACTIONS(43),
    [anon_sym_await] = ACTIONS(45),
    [anon_sym_while] = ACTIONS(621),
    [anon_sym_do] = ACTIONS(49),
    [anon_sym_try] = ACTIONS(51),
    [anon_sym_break] = ACTIONS(53),
    [anon_sym_continue] = ACTIONS(55),
    [anon_sym_debugger] = ACTIONS(57),
    [anon_sym_return] = ACTIONS(59),
    [anon_sym_throw] = ACTIONS(61),
    [anon_sym_yield] = ACTIONS(63),
    [anon_sym_LBRACK] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(623),
    [anon_sym_async] = ACTIONS(625),
    [anon_sym_function] = ACTIONS(627),
    [anon_sym_new] = ACTIONS(629),
    [anon_sym_using] = ACTIONS(75),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_SLASH] = ACTIONS(77),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(33),
    [anon_sym_void] = ACTIONS(21),
    [anon_sym_delete] = ACTIONS(21),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_DQUOTE] = ACTIONS(83),
    [anon_sym_SQUOTE] = ACTIONS(85),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(87),
    [sym_number] = ACTIONS(89),
    [sym_private_property_identifier] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(93),
    [sym_true] = ACTIONS(93),
    [sym_false] = ACTIONS(93),
    [sym_null] = ACTIONS(93),
    [sym_undefined] = ACTIONS(95),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(631),
    [anon_sym_readonly] = ACTIONS(631),
    [anon_sym_get] = ACTIONS(631),
    [anon_sym_set] = ACTIONS(631),
    [anon_sym_declare] = ACTIONS(633),
    [anon_sym_public] = ACTIONS(631),
    [anon_sym_private] = ACTIONS(631),
    [anon_sym_protected] = ACTIONS(631),
    [anon_sym_override] = ACTIONS(631),
    [anon_sym_module] = ACTIONS(635),
    [anon_sym_any] = ACTIONS(631),
    [anon_sym_number] = ACTIONS(631),
    [anon_sym_boolean] = ACTIONS(631),
    [anon_sym_string] = ACTIONS(631),
    [anon_sym_symbol] = ACTIONS(631),
    [anon_sym_object] = ACTIONS(631),
    [anon_sym_abstract] = ACTIONS(105),
    [anon_sym_interface] = ACTIONS(107),
    [anon_sym_enum] = ACTIONS(109),
    [sym_html_comment] = ACTIONS(5),
  },
  [33] = {
    [sym_export_statement] = STATE(892),
    [sym_declaration] = STATE(892),
    [sym_import] = STATE(3636),
    [sym_import_statement] = STATE(892),
    [sym_statement] = STATE(928),
    [sym_expression_statement] = STATE(892),
    [sym_variable_declaration] = STATE(831),
    [sym_lexical_declaration] = STATE(831),
    [sym_statement_block] = STATE(892),
    [sym_if_statement] = STATE(892),
    [sym_switch_statement] = STATE(892),
    [sym_for_statement] = STATE(892),
    [sym_for_in_statement] = STATE(892),
    [sym_while_statement] = STATE(892),
    [sym_do_statement] = STATE(892),
    [sym_try_statement] = STATE(892),
    [sym_with_statement] = STATE(892),
    [sym_break_statement] = STATE(892),
    [sym_continue_statement] = STATE(892),
    [sym_debugger_statement] = STATE(892),
    [sym_return_statement] = STATE(892),
    [sym_throw_statement] = STATE(892),
    [sym_empty_statement] = STATE(892),
    [sym_labeled_statement] = STATE(892),
    [sym_parenthesized_expression] = STATE(1362),
    [sym_expression] = STATE(1902),
    [sym_primary_expression] = STATE(1810),
    [sym_yield_expression] = STATE(2358),
    [sym_object] = STATE(2222),
    [sym_object_pattern] = STATE(5492),
    [sym_array] = STATE(2222),
    [sym_array_pattern] = STATE(5492),
    [sym_class] = STATE(2222),
    [sym_class_declaration] = STATE(831),
    [sym_function_expression] = STATE(2222),
    [sym_function_declaration] = STATE(831),
    [sym_generator_function] = STATE(2222),
    [sym_generator_function_declaration] = STATE(831),
    [sym_arrow_function] = STATE(2222),
    [sym__call_signature] = STATE(5821),
    [sym_call_expression] = STATE(2222),
    [sym_new_expression] = STATE(1948),
    [sym_await_expression] = STATE(2358),
    [sym_member_expression] = STATE(1362),
    [sym_subscript_expression] = STATE(1362),
    [sym_assignment_expression] = STATE(2358),
    [sym__augmented_assignment_lhs] = STATE(3025),
    [sym_augmented_assignment_expression] = STATE(2358),
    [sym__destructuring_pattern] = STATE(5492),
    [sym_ternary_expression] = STATE(2358),
    [sym_binary_expression] = STATE(2358),
    [sym_unary_expression] = STATE(2358),
    [sym_update_expression] = STATE(2358),
    [sym_sequence_expression] = STATE(5305),
    [sym_string] = STATE(2222),
    [sym_template_string] = STATE(2222),
    [sym_regex] = STATE(2222),
    [sym_meta_property] = STATE(2222),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1362),
    [sym_function_signature] = STATE(831),
    [sym_type_assertion] = STATE(2358),
    [sym_as_expression] = STATE(2358),
    [sym_satisfies_expression] = STATE(2358),
    [sym_instantiation_expression] = STATE(2358),
    [sym_ambient_declaration] = STATE(831),
    [sym_abstract_class_declaration] = STATE(831),
    [sym_module] = STATE(831),
    [sym_internal_module] = STATE(214),
    [sym_import_alias] = STATE(831),
    [sym_interface_declaration] = STATE(831),
    [sym_enum_declaration] = STATE(831),
    [sym_type_alias_declaration] = STATE(831),
    [sym_type_arguments] = STATE(428),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(3774),
    [sym_identifier] = ACTIONS(9),
    [anon_sym_export] = ACTIONS(13),
    [anon_sym_type] = ACTIONS(15),
    [anon_sym_namespace] = ACTIONS(17),
    [anon_sym_LBRACE] = ACTIONS(19),
    [anon_sym_typeof] = ACTIONS(21),
    [anon_sym_import] = ACTIONS(23),
    [anon_sym_with] = ACTIONS(25),
    [anon_sym_var] = ACTIONS(27),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_const] = ACTIONS(31),
    [anon_sym_BANG] = ACTIONS(33),
    [anon_sym_if] = ACTIONS(35),
    [anon_sym_switch] = ACTIONS(37),
    [anon_sym_for] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_SEMI] = ACTIONS(43),
    [anon_sym_await] = ACTIONS(45),
    [anon_sym_while] = ACTIONS(47),
    [anon_sym_do] = ACTIONS(49),
    [anon_sym_try] = ACTIONS(51),
    [anon_sym_break] = ACTIONS(53),
    [anon_sym_continue] = ACTIONS(55),
    [anon_sym_debugger] = ACTIONS(57),
    [anon_sym_return] = ACTIONS(59),
    [anon_sym_throw] = ACTIONS(61),
    [anon_sym_yield] = ACTIONS(63),
    [anon_sym_LBRACK] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(67),
    [anon_sym_async] = ACTIONS(69),
    [anon_sym_function] = ACTIONS(71),
    [anon_sym_new] = ACTIONS(73),
    [anon_sym_using] = ACTIONS(75),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_SLASH] = ACTIONS(77),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(33),
    [anon_sym_void] = ACTIONS(21),
    [anon_sym_delete] = ACTIONS(21),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_DQUOTE] = ACTIONS(83),
    [anon_sym_SQUOTE] = ACTIONS(85),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(87),
    [sym_number] = ACTIONS(89),
    [sym_private_property_identifier] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(93),
    [sym_true] = ACTIONS(93),
    [sym_false] = ACTIONS(93),
    [sym_null] = ACTIONS(93),
    [sym_undefined] = ACTIONS(95),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(99),
    [anon_sym_readonly] = ACTIONS(99),
    [anon_sym_get] = ACTIONS(99),
    [anon_sym_set] = ACTIONS(99),
    [anon_sym_declare] = ACTIONS(101),
    [anon_sym_public] = ACTIONS(99),
    [anon_sym_private] = ACTIONS(99),
    [anon_sym_protected] = ACTIONS(99),
    [anon_sym_override] = ACTIONS(99),
    [anon_sym_module] = ACTIONS(103),
    [anon_sym_any] = ACTIONS(99),
    [anon_sym_number] = ACTIONS(99),
    [anon_sym_boolean] = ACTIONS(99),
    [anon_sym_string] = ACTIONS(99),
    [anon_sym_symbol] = ACTIONS(99),
    [anon_sym_object] = ACTIONS(99),
    [anon_sym_abstract] = ACTIONS(105),
    [anon_sym_interface] = ACTIONS(107),
    [anon_sym_enum] = ACTIONS(109),
    [sym_html_comment] = ACTIONS(5),
  },
  [34] = {
    [sym_export_statement] = STATE(892),
    [sym_declaration] = STATE(892),
    [sym_import] = STATE(3636),
    [sym_import_statement] = STATE(892),
    [sym_statement] = STATE(832),
    [sym_expression_statement] = STATE(892),
    [sym_variable_declaration] = STATE(831),
    [sym_lexical_declaration] = STATE(831),
    [sym_statement_block] = STATE(892),
    [sym_if_statement] = STATE(892),
    [sym_switch_statement] = STATE(892),
    [sym_for_statement] = STATE(892),
    [sym_for_in_statement] = STATE(892),
    [sym_while_statement] = STATE(892),
    [sym_do_statement] = STATE(892),
    [sym_try_statement] = STATE(892),
    [sym_with_statement] = STATE(892),
    [sym_break_statement] = STATE(892),
    [sym_continue_statement] = STATE(892),
    [sym_debugger_statement] = STATE(892),
    [sym_return_statement] = STATE(892),
    [sym_throw_statement] = STATE(892),
    [sym_empty_statement] = STATE(892),
    [sym_labeled_statement] = STATE(892),
    [sym_parenthesized_expression] = STATE(1362),
    [sym_expression] = STATE(1902),
    [sym_primary_expression] = STATE(1810),
    [sym_yield_expression] = STATE(2358),
    [sym_object] = STATE(2222),
    [sym_object_pattern] = STATE(5492),
    [sym_array] = STATE(2222),
    [sym_array_pattern] = STATE(5492),
    [sym_class] = STATE(2222),
    [sym_class_declaration] = STATE(831),
    [sym_function_expression] = STATE(2222),
    [sym_function_declaration] = STATE(831),
    [sym_generator_function] = STATE(2222),
    [sym_generator_function_declaration] = STATE(831),
    [sym_arrow_function] = STATE(2222),
    [sym__call_signature] = STATE(5821),
    [sym_call_expression] = STATE(2222),
    [sym_new_expression] = STATE(1948),
    [sym_await_expression] = STATE(2358),
    [sym_member_expression] = STATE(1362),
    [sym_subscript_expression] = STATE(1362),
    [sym_assignment_expression] = STATE(2358),
    [sym__augmented_assignment_lhs] = STATE(3025),
    [sym_augmented_assignment_expression] = STATE(2358),
    [sym__destructuring_pattern] = STATE(5492),
    [sym_ternary_expression] = STATE(2358),
    [sym_binary_expression] = STATE(2358),
    [sym_unary_expression] = STATE(2358),
    [sym_update_expression] = STATE(2358),
    [sym_sequence_expression] = STATE(5305),
    [sym_string] = STATE(2222),
    [sym_template_string] = STATE(2222),
    [sym_regex] = STATE(2222),
    [sym_meta_property] = STATE(2222),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1362),
    [sym_function_signature] = STATE(831),
    [sym_type_assertion] = STATE(2358),
    [sym_as_expression] = STATE(2358),
    [sym_satisfies_expression] = STATE(2358),
    [sym_instantiation_expression] = STATE(2358),
    [sym_ambient_declaration] = STATE(831),
    [sym_abstract_class_declaration] = STATE(831),
    [sym_module] = STATE(831),
    [sym_internal_module] = STATE(2513),
    [sym_import_alias] = STATE(831),
    [sym_interface_declaration] = STATE(831),
    [sym_enum_declaration] = STATE(831),
    [sym_type_alias_declaration] = STATE(831),
    [sym_type_arguments] = STATE(428),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(3830),
    [sym_identifier] = ACTIONS(603),
    [anon_sym_export] = ACTIONS(605),
    [anon_sym_type] = ACTIONS(607),
    [anon_sym_namespace] = ACTIONS(609),
    [anon_sym_LBRACE] = ACTIONS(611),
    [anon_sym_typeof] = ACTIONS(21),
    [anon_sym_import] = ACTIONS(23),
    [anon_sym_with] = ACTIONS(613),
    [anon_sym_var] = ACTIONS(27),
    [anon_sym_let] = ACTIONS(615),
    [anon_sym_const] = ACTIONS(31),
    [anon_sym_BANG] = ACTIONS(33),
    [anon_sym_if] = ACTIONS(617),
    [anon_sym_switch] = ACTIONS(37),
    [anon_sym_for] = ACTIONS(619),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_SEMI] = ACTIONS(43),
    [anon_sym_await] = ACTIONS(45),
    [anon_sym_while] = ACTIONS(621),
    [anon_sym_do] = ACTIONS(49),
    [anon_sym_try] = ACTIONS(51),
    [anon_sym_break] = ACTIONS(53),
    [anon_sym_continue] = ACTIONS(55),
    [anon_sym_debugger] = ACTIONS(57),
    [anon_sym_return] = ACTIONS(59),
    [anon_sym_throw] = ACTIONS(61),
    [anon_sym_yield] = ACTIONS(63),
    [anon_sym_LBRACK] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(623),
    [anon_sym_async] = ACTIONS(625),
    [anon_sym_function] = ACTIONS(627),
    [anon_sym_new] = ACTIONS(629),
    [anon_sym_using] = ACTIONS(75),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_SLASH] = ACTIONS(77),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(33),
    [anon_sym_void] = ACTIONS(21),
    [anon_sym_delete] = ACTIONS(21),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_DQUOTE] = ACTIONS(83),
    [anon_sym_SQUOTE] = ACTIONS(85),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(87),
    [sym_number] = ACTIONS(89),
    [sym_private_property_identifier] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(93),
    [sym_true] = ACTIONS(93),
    [sym_false] = ACTIONS(93),
    [sym_null] = ACTIONS(93),
    [sym_undefined] = ACTIONS(95),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(631),
    [anon_sym_readonly] = ACTIONS(631),
    [anon_sym_get] = ACTIONS(631),
    [anon_sym_set] = ACTIONS(631),
    [anon_sym_declare] = ACTIONS(633),
    [anon_sym_public] = ACTIONS(631),
    [anon_sym_private] = ACTIONS(631),
    [anon_sym_protected] = ACTIONS(631),
    [anon_sym_override] = ACTIONS(631),
    [anon_sym_module] = ACTIONS(635),
    [anon_sym_any] = ACTIONS(631),
    [anon_sym_number] = ACTIONS(631),
    [anon_sym_boolean] = ACTIONS(631),
    [anon_sym_string] = ACTIONS(631),
    [anon_sym_symbol] = ACTIONS(631),
    [anon_sym_object] = ACTIONS(631),
    [anon_sym_abstract] = ACTIONS(105),
    [anon_sym_interface] = ACTIONS(107),
    [anon_sym_enum] = ACTIONS(109),
    [sym_html_comment] = ACTIONS(5),
  },
  [35] = {
    [sym_export_statement] = STATE(892),
    [sym_declaration] = STATE(892),
    [sym_import] = STATE(3636),
    [sym_import_statement] = STATE(892),
    [sym_statement] = STATE(4697),
    [sym_expression_statement] = STATE(892),
    [sym_variable_declaration] = STATE(831),
    [sym_lexical_declaration] = STATE(831),
    [sym_statement_block] = STATE(892),
    [sym_if_statement] = STATE(892),
    [sym_switch_statement] = STATE(892),
    [sym_for_statement] = STATE(892),
    [sym_for_in_statement] = STATE(892),
    [sym_while_statement] = STATE(892),
    [sym_do_statement] = STATE(892),
    [sym_try_statement] = STATE(892),
    [sym_with_statement] = STATE(892),
    [sym_break_statement] = STATE(892),
    [sym_continue_statement] = STATE(892),
    [sym_debugger_statement] = STATE(892),
    [sym_return_statement] = STATE(892),
    [sym_throw_statement] = STATE(892),
    [sym_empty_statement] = STATE(892),
    [sym_labeled_statement] = STATE(892),
    [sym_parenthesized_expression] = STATE(1362),
    [sym_expression] = STATE(1902),
    [sym_primary_expression] = STATE(1810),
    [sym_yield_expression] = STATE(2358),
    [sym_object] = STATE(2222),
    [sym_object_pattern] = STATE(5492),
    [sym_array] = STATE(2222),
    [sym_array_pattern] = STATE(5492),
    [sym_class] = STATE(2222),
    [sym_class_declaration] = STATE(831),
    [sym_function_expression] = STATE(2222),
    [sym_function_declaration] = STATE(831),
    [sym_generator_function] = STATE(2222),
    [sym_generator_function_declaration] = STATE(831),
    [sym_arrow_function] = STATE(2222),
    [sym__call_signature] = STATE(5821),
    [sym_call_expression] = STATE(2222),
    [sym_new_expression] = STATE(1948),
    [sym_await_expression] = STATE(2358),
    [sym_member_expression] = STATE(1362),
    [sym_subscript_expression] = STATE(1362),
    [sym_assignment_expression] = STATE(2358),
    [sym__augmented_assignment_lhs] = STATE(3025),
    [sym_augmented_assignment_expression] = STATE(2358),
    [sym__destructuring_pattern] = STATE(5492),
    [sym_ternary_expression] = STATE(2358),
    [sym_binary_expression] = STATE(2358),
    [sym_unary_expression] = STATE(2358),
    [sym_update_expression] = STATE(2358),
    [sym_sequence_expression] = STATE(5305),
    [sym_string] = STATE(2222),
    [sym_template_string] = STATE(2222),
    [sym_regex] = STATE(2222),
    [sym_meta_property] = STATE(2222),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1362),
    [sym_function_signature] = STATE(831),
    [sym_type_assertion] = STATE(2358),
    [sym_as_expression] = STATE(2358),
    [sym_satisfies_expression] = STATE(2358),
    [sym_instantiation_expression] = STATE(2358),
    [sym_ambient_declaration] = STATE(831),
    [sym_abstract_class_declaration] = STATE(831),
    [sym_module] = STATE(831),
    [sym_internal_module] = STATE(2513),
    [sym_import_alias] = STATE(831),
    [sym_interface_declaration] = STATE(831),
    [sym_enum_declaration] = STATE(831),
    [sym_type_alias_declaration] = STATE(831),
    [sym_type_arguments] = STATE(428),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(3830),
    [sym_identifier] = ACTIONS(603),
    [anon_sym_export] = ACTIONS(605),
    [anon_sym_type] = ACTIONS(607),
    [anon_sym_namespace] = ACTIONS(609),
    [anon_sym_LBRACE] = ACTIONS(611),
    [anon_sym_typeof] = ACTIONS(21),
    [anon_sym_import] = ACTIONS(23),
    [anon_sym_with] = ACTIONS(613),
    [anon_sym_var] = ACTIONS(27),
    [anon_sym_let] = ACTIONS(615),
    [anon_sym_const] = ACTIONS(31),
    [anon_sym_BANG] = ACTIONS(33),
    [anon_sym_if] = ACTIONS(617),
    [anon_sym_switch] = ACTIONS(37),
    [anon_sym_for] = ACTIONS(619),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_SEMI] = ACTIONS(43),
    [anon_sym_await] = ACTIONS(45),
    [anon_sym_while] = ACTIONS(621),
    [anon_sym_do] = ACTIONS(49),
    [anon_sym_try] = ACTIONS(51),
    [anon_sym_break] = ACTIONS(53),
    [anon_sym_continue] = ACTIONS(55),
    [anon_sym_debugger] = ACTIONS(57),
    [anon_sym_return] = ACTIONS(59),
    [anon_sym_throw] = ACTIONS(61),
    [anon_sym_yield] = ACTIONS(63),
    [anon_sym_LBRACK] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(623),
    [anon_sym_async] = ACTIONS(625),
    [anon_sym_function] = ACTIONS(627),
    [anon_sym_new] = ACTIONS(629),
    [anon_sym_using] = ACTIONS(75),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_SLASH] = ACTIONS(77),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(33),
    [anon_sym_void] = ACTIONS(21),
    [anon_sym_delete] = ACTIONS(21),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_DQUOTE] = ACTIONS(83),
    [anon_sym_SQUOTE] = ACTIONS(85),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(87),
    [sym_number] = ACTIONS(89),
    [sym_private_property_identifier] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(93),
    [sym_true] = ACTIONS(93),
    [sym_false] = ACTIONS(93),
    [sym_null] = ACTIONS(93),
    [sym_undefined] = ACTIONS(95),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(631),
    [anon_sym_readonly] = ACTIONS(631),
    [anon_sym_get] = ACTIONS(631),
    [anon_sym_set] = ACTIONS(631),
    [anon_sym_declare] = ACTIONS(633),
    [anon_sym_public] = ACTIONS(631),
    [anon_sym_private] = ACTIONS(631),
    [anon_sym_protected] = ACTIONS(631),
    [anon_sym_override] = ACTIONS(631),
    [anon_sym_module] = ACTIONS(635),
    [anon_sym_any] = ACTIONS(631),
    [anon_sym_number] = ACTIONS(631),
    [anon_sym_boolean] = ACTIONS(631),
    [anon_sym_string] = ACTIONS(631),
    [anon_sym_symbol] = ACTIONS(631),
    [anon_sym_object] = ACTIONS(631),
    [anon_sym_abstract] = ACTIONS(105),
    [anon_sym_interface] = ACTIONS(107),
    [anon_sym_enum] = ACTIONS(109),
    [sym_html_comment] = ACTIONS(5),
  },
  [36] = {
    [sym_export_statement] = STATE(892),
    [sym_declaration] = STATE(892),
    [sym_import] = STATE(3636),
    [sym_import_statement] = STATE(892),
    [sym_statement] = STATE(931),
    [sym_expression_statement] = STATE(892),
    [sym_variable_declaration] = STATE(831),
    [sym_lexical_declaration] = STATE(831),
    [sym_statement_block] = STATE(892),
    [sym_if_statement] = STATE(892),
    [sym_switch_statement] = STATE(892),
    [sym_for_statement] = STATE(892),
    [sym_for_in_statement] = STATE(892),
    [sym_while_statement] = STATE(892),
    [sym_do_statement] = STATE(892),
    [sym_try_statement] = STATE(892),
    [sym_with_statement] = STATE(892),
    [sym_break_statement] = STATE(892),
    [sym_continue_statement] = STATE(892),
    [sym_debugger_statement] = STATE(892),
    [sym_return_statement] = STATE(892),
    [sym_throw_statement] = STATE(892),
    [sym_empty_statement] = STATE(892),
    [sym_labeled_statement] = STATE(892),
    [sym_parenthesized_expression] = STATE(1362),
    [sym_expression] = STATE(1902),
    [sym_primary_expression] = STATE(1810),
    [sym_yield_expression] = STATE(2358),
    [sym_object] = STATE(2222),
    [sym_object_pattern] = STATE(5492),
    [sym_array] = STATE(2222),
    [sym_array_pattern] = STATE(5492),
    [sym_class] = STATE(2222),
    [sym_class_declaration] = STATE(831),
    [sym_function_expression] = STATE(2222),
    [sym_function_declaration] = STATE(831),
    [sym_generator_function] = STATE(2222),
    [sym_generator_function_declaration] = STATE(831),
    [sym_arrow_function] = STATE(2222),
    [sym__call_signature] = STATE(5821),
    [sym_call_expression] = STATE(2222),
    [sym_new_expression] = STATE(1948),
    [sym_await_expression] = STATE(2358),
    [sym_member_expression] = STATE(1362),
    [sym_subscript_expression] = STATE(1362),
    [sym_assignment_expression] = STATE(2358),
    [sym__augmented_assignment_lhs] = STATE(3025),
    [sym_augmented_assignment_expression] = STATE(2358),
    [sym__destructuring_pattern] = STATE(5492),
    [sym_ternary_expression] = STATE(2358),
    [sym_binary_expression] = STATE(2358),
    [sym_unary_expression] = STATE(2358),
    [sym_update_expression] = STATE(2358),
    [sym_sequence_expression] = STATE(5305),
    [sym_string] = STATE(2222),
    [sym_template_string] = STATE(2222),
    [sym_regex] = STATE(2222),
    [sym_meta_property] = STATE(2222),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1362),
    [sym_function_signature] = STATE(831),
    [sym_type_assertion] = STATE(2358),
    [sym_as_expression] = STATE(2358),
    [sym_satisfies_expression] = STATE(2358),
    [sym_instantiation_expression] = STATE(2358),
    [sym_ambient_declaration] = STATE(831),
    [sym_abstract_class_declaration] = STATE(831),
    [sym_module] = STATE(831),
    [sym_internal_module] = STATE(2513),
    [sym_import_alias] = STATE(831),
    [sym_interface_declaration] = STATE(831),
    [sym_enum_declaration] = STATE(831),
    [sym_type_alias_declaration] = STATE(831),
    [sym_type_arguments] = STATE(428),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(3830),
    [sym_identifier] = ACTIONS(603),
    [anon_sym_export] = ACTIONS(605),
    [anon_sym_type] = ACTIONS(607),
    [anon_sym_namespace] = ACTIONS(609),
    [anon_sym_LBRACE] = ACTIONS(611),
    [anon_sym_typeof] = ACTIONS(21),
    [anon_sym_import] = ACTIONS(23),
    [anon_sym_with] = ACTIONS(613),
    [anon_sym_var] = ACTIONS(27),
    [anon_sym_let] = ACTIONS(615),
    [anon_sym_const] = ACTIONS(31),
    [anon_sym_BANG] = ACTIONS(33),
    [anon_sym_if] = ACTIONS(617),
    [anon_sym_switch] = ACTIONS(37),
    [anon_sym_for] = ACTIONS(619),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_SEMI] = ACTIONS(43),
    [anon_sym_await] = ACTIONS(45),
    [anon_sym_while] = ACTIONS(621),
    [anon_sym_do] = ACTIONS(49),
    [anon_sym_try] = ACTIONS(51),
    [anon_sym_break] = ACTIONS(53),
    [anon_sym_continue] = ACTIONS(55),
    [anon_sym_debugger] = ACTIONS(57),
    [anon_sym_return] = ACTIONS(59),
    [anon_sym_throw] = ACTIONS(61),
    [anon_sym_yield] = ACTIONS(63),
    [anon_sym_LBRACK] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(623),
    [anon_sym_async] = ACTIONS(625),
    [anon_sym_function] = ACTIONS(627),
    [anon_sym_new] = ACTIONS(629),
    [anon_sym_using] = ACTIONS(75),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_SLASH] = ACTIONS(77),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(33),
    [anon_sym_void] = ACTIONS(21),
    [anon_sym_delete] = ACTIONS(21),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_DQUOTE] = ACTIONS(83),
    [anon_sym_SQUOTE] = ACTIONS(85),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(87),
    [sym_number] = ACTIONS(89),
    [sym_private_property_identifier] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(93),
    [sym_true] = ACTIONS(93),
    [sym_false] = ACTIONS(93),
    [sym_null] = ACTIONS(93),
    [sym_undefined] = ACTIONS(95),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(631),
    [anon_sym_readonly] = ACTIONS(631),
    [anon_sym_get] = ACTIONS(631),
    [anon_sym_set] = ACTIONS(631),
    [anon_sym_declare] = ACTIONS(633),
    [anon_sym_public] = ACTIONS(631),
    [anon_sym_private] = ACTIONS(631),
    [anon_sym_protected] = ACTIONS(631),
    [anon_sym_override] = ACTIONS(631),
    [anon_sym_module] = ACTIONS(635),
    [anon_sym_any] = ACTIONS(631),
    [anon_sym_number] = ACTIONS(631),
    [anon_sym_boolean] = ACTIONS(631),
    [anon_sym_string] = ACTIONS(631),
    [anon_sym_symbol] = ACTIONS(631),
    [anon_sym_object] = ACTIONS(631),
    [anon_sym_abstract] = ACTIONS(105),
    [anon_sym_interface] = ACTIONS(107),
    [anon_sym_enum] = ACTIONS(109),
    [sym_html_comment] = ACTIONS(5),
  },
  [37] = {
    [sym_export_statement] = STATE(892),
    [sym_declaration] = STATE(892),
    [sym_import] = STATE(3636),
    [sym_import_statement] = STATE(892),
    [sym_statement] = STATE(943),
    [sym_expression_statement] = STATE(892),
    [sym_variable_declaration] = STATE(831),
    [sym_lexical_declaration] = STATE(831),
    [sym_statement_block] = STATE(892),
    [sym_if_statement] = STATE(892),
    [sym_switch_statement] = STATE(892),
    [sym_for_statement] = STATE(892),
    [sym_for_in_statement] = STATE(892),
    [sym_while_statement] = STATE(892),
    [sym_do_statement] = STATE(892),
    [sym_try_statement] = STATE(892),
    [sym_with_statement] = STATE(892),
    [sym_break_statement] = STATE(892),
    [sym_continue_statement] = STATE(892),
    [sym_debugger_statement] = STATE(892),
    [sym_return_statement] = STATE(892),
    [sym_throw_statement] = STATE(892),
    [sym_empty_statement] = STATE(892),
    [sym_labeled_statement] = STATE(892),
    [sym_parenthesized_expression] = STATE(1362),
    [sym_expression] = STATE(1902),
    [sym_primary_expression] = STATE(1810),
    [sym_yield_expression] = STATE(2358),
    [sym_object] = STATE(2222),
    [sym_object_pattern] = STATE(5492),
    [sym_array] = STATE(2222),
    [sym_array_pattern] = STATE(5492),
    [sym_class] = STATE(2222),
    [sym_class_declaration] = STATE(831),
    [sym_function_expression] = STATE(2222),
    [sym_function_declaration] = STATE(831),
    [sym_generator_function] = STATE(2222),
    [sym_generator_function_declaration] = STATE(831),
    [sym_arrow_function] = STATE(2222),
    [sym__call_signature] = STATE(5821),
    [sym_call_expression] = STATE(2222),
    [sym_new_expression] = STATE(1948),
    [sym_await_expression] = STATE(2358),
    [sym_member_expression] = STATE(1362),
    [sym_subscript_expression] = STATE(1362),
    [sym_assignment_expression] = STATE(2358),
    [sym__augmented_assignment_lhs] = STATE(3025),
    [sym_augmented_assignment_expression] = STATE(2358),
    [sym__destructuring_pattern] = STATE(5492),
    [sym_ternary_expression] = STATE(2358),
    [sym_binary_expression] = STATE(2358),
    [sym_unary_expression] = STATE(2358),
    [sym_update_expression] = STATE(2358),
    [sym_sequence_expression] = STATE(5305),
    [sym_string] = STATE(2222),
    [sym_template_string] = STATE(2222),
    [sym_regex] = STATE(2222),
    [sym_meta_property] = STATE(2222),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1362),
    [sym_function_signature] = STATE(831),
    [sym_type_assertion] = STATE(2358),
    [sym_as_expression] = STATE(2358),
    [sym_satisfies_expression] = STATE(2358),
    [sym_instantiation_expression] = STATE(2358),
    [sym_ambient_declaration] = STATE(831),
    [sym_abstract_class_declaration] = STATE(831),
    [sym_module] = STATE(831),
    [sym_internal_module] = STATE(2513),
    [sym_import_alias] = STATE(831),
    [sym_interface_declaration] = STATE(831),
    [sym_enum_declaration] = STATE(831),
    [sym_type_alias_declaration] = STATE(831),
    [sym_type_arguments] = STATE(428),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(3830),
    [sym_identifier] = ACTIONS(603),
    [anon_sym_export] = ACTIONS(605),
    [anon_sym_type] = ACTIONS(607),
    [anon_sym_namespace] = ACTIONS(609),
    [anon_sym_LBRACE] = ACTIONS(611),
    [anon_sym_typeof] = ACTIONS(21),
    [anon_sym_import] = ACTIONS(23),
    [anon_sym_with] = ACTIONS(613),
    [anon_sym_var] = ACTIONS(27),
    [anon_sym_let] = ACTIONS(615),
    [anon_sym_const] = ACTIONS(31),
    [anon_sym_BANG] = ACTIONS(33),
    [anon_sym_if] = ACTIONS(617),
    [anon_sym_switch] = ACTIONS(37),
    [anon_sym_for] = ACTIONS(619),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_SEMI] = ACTIONS(43),
    [anon_sym_await] = ACTIONS(45),
    [anon_sym_while] = ACTIONS(621),
    [anon_sym_do] = ACTIONS(49),
    [anon_sym_try] = ACTIONS(51),
    [anon_sym_break] = ACTIONS(53),
    [anon_sym_continue] = ACTIONS(55),
    [anon_sym_debugger] = ACTIONS(57),
    [anon_sym_return] = ACTIONS(59),
    [anon_sym_throw] = ACTIONS(61),
    [anon_sym_yield] = ACTIONS(63),
    [anon_sym_LBRACK] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(623),
    [anon_sym_async] = ACTIONS(625),
    [anon_sym_function] = ACTIONS(627),
    [anon_sym_new] = ACTIONS(629),
    [anon_sym_using] = ACTIONS(75),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_SLASH] = ACTIONS(77),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(33),
    [anon_sym_void] = ACTIONS(21),
    [anon_sym_delete] = ACTIONS(21),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_DQUOTE] = ACTIONS(83),
    [anon_sym_SQUOTE] = ACTIONS(85),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(87),
    [sym_number] = ACTIONS(89),
    [sym_private_property_identifier] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(93),
    [sym_true] = ACTIONS(93),
    [sym_false] = ACTIONS(93),
    [sym_null] = ACTIONS(93),
    [sym_undefined] = ACTIONS(95),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(631),
    [anon_sym_readonly] = ACTIONS(631),
    [anon_sym_get] = ACTIONS(631),
    [anon_sym_set] = ACTIONS(631),
    [anon_sym_declare] = ACTIONS(633),
    [anon_sym_public] = ACTIONS(631),
    [anon_sym_private] = ACTIONS(631),
    [anon_sym_protected] = ACTIONS(631),
    [anon_sym_override] = ACTIONS(631),
    [anon_sym_module] = ACTIONS(635),
    [anon_sym_any] = ACTIONS(631),
    [anon_sym_number] = ACTIONS(631),
    [anon_sym_boolean] = ACTIONS(631),
    [anon_sym_string] = ACTIONS(631),
    [anon_sym_symbol] = ACTIONS(631),
    [anon_sym_object] = ACTIONS(631),
    [anon_sym_abstract] = ACTIONS(105),
    [anon_sym_interface] = ACTIONS(107),
    [anon_sym_enum] = ACTIONS(109),
    [sym_html_comment] = ACTIONS(5),
  },
  [38] = {
    [sym_import] = STATE(3663),
    [sym_parenthesized_expression] = STATE(1322),
    [sym_expression] = STATE(2126),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(4425),
    [sym_assignment_pattern] = STATE(4969),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(4425),
    [sym_nested_identifier] = STATE(5474),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5508),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1396),
    [sym_subscript_expression] = STATE(1396),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3003),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(4425),
    [sym_spread_element] = STATE(4946),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(2213),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(4317),
    [sym_pattern] = STATE(4406),
    [sym_rest_pattern] = STATE(4115),
    [sym_non_null_expression] = STATE(1396),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_nested_type_identifier] = STATE(2939),
    [sym__type_query_member_expression_in_type_annotation] = STATE(3303),
    [sym__type_query_call_expression_in_type_annotation] = STATE(2938),
    [sym_type] = STATE(3773),
    [sym_tuple_parameter] = STATE(4568),
    [sym_optional_tuple_parameter] = STATE(4568),
    [sym_optional_type] = STATE(4568),
    [sym_rest_type] = STATE(4568),
    [sym__tuple_type_member] = STATE(4568),
    [sym_constructor_type] = STATE(3007),
    [sym_primary_type] = STATE(2981),
    [sym_template_literal_type] = STATE(3039),
    [sym_infer_type] = STATE(3007),
    [sym_conditional_type] = STATE(3039),
    [sym_generic_type] = STATE(3039),
    [sym_type_query] = STATE(3039),
    [sym_index_type_query] = STATE(3039),
    [sym_lookup_type] = STATE(3039),
    [sym_literal_type] = STATE(3039),
    [sym__number] = STATE(3041),
    [sym_existential_type] = STATE(3039),
    [sym_flow_maybe_type] = STATE(3039),
    [sym_parenthesized_type] = STATE(3039),
    [sym_predefined_type] = STATE(3039),
    [sym_type_arguments] = STATE(484),
    [sym_object_type] = STATE(3039),
    [sym_type_parameters] = STATE(5455),
    [sym_array_type] = STATE(3039),
    [sym_tuple_type] = STATE(3039),
    [sym_readonly_type] = STATE(3007),
    [sym_union_type] = STATE(3039),
    [sym_intersection_type] = STATE(3039),
    [sym_function_type] = STATE(3007),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [aux_sym_array_repeat1] = STATE(4955),
    [aux_sym_array_pattern_repeat1] = STATE(4977),
    [sym_identifier] = ACTIONS(539),
    [anon_sym_export] = ACTIONS(541),
    [anon_sym_STAR] = ACTIONS(543),
    [anon_sym_type] = ACTIONS(541),
    [anon_sym_namespace] = ACTIONS(545),
    [anon_sym_LBRACE] = ACTIONS(547),
    [anon_sym_COMMA] = ACTIONS(549),
    [anon_sym_typeof] = ACTIONS(551),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(541),
    [anon_sym_const] = ACTIONS(133),
    [anon_sym_BANG] = ACTIONS(553),
    [anon_sym_LPAREN] = ACTIONS(138),
    [anon_sym_await] = ACTIONS(555),
    [anon_sym_yield] = ACTIONS(557),
    [anon_sym_LBRACK] = ACTIONS(559),
    [anon_sym_RBRACK] = ACTIONS(637),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(563),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(565),
    [anon_sym_using] = ACTIONS(567),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(569),
    [anon_sym_AMP] = ACTIONS(571),
    [anon_sym_PIPE] = ACTIONS(573),
    [anon_sym_PLUS] = ACTIONS(575),
    [anon_sym_DASH] = ACTIONS(575),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(553),
    [anon_sym_void] = ACTIONS(579),
    [anon_sym_delete] = ACTIONS(581),
    [anon_sym_PLUS_PLUS] = ACTIONS(583),
    [anon_sym_DASH_DASH] = ACTIONS(583),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(188),
    [sym_number] = ACTIONS(190),
    [sym_private_property_identifier] = ACTIONS(585),
    [sym_this] = ACTIONS(587),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(198),
    [sym_false] = ACTIONS(198),
    [sym_null] = ACTIONS(198),
    [sym_undefined] = ACTIONS(589),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(541),
    [anon_sym_readonly] = ACTIONS(591),
    [anon_sym_get] = ACTIONS(541),
    [anon_sym_set] = ACTIONS(541),
    [anon_sym_QMARK] = ACTIONS(593),
    [anon_sym_declare] = ACTIONS(541),
    [anon_sym_public] = ACTIONS(541),
    [anon_sym_private] = ACTIONS(541),
    [anon_sym_protected] = ACTIONS(541),
    [anon_sym_override] = ACTIONS(541),
    [anon_sym_module] = ACTIONS(541),
    [anon_sym_any] = ACTIONS(595),
    [anon_sym_number] = ACTIONS(595),
    [anon_sym_boolean] = ACTIONS(595),
    [anon_sym_string] = ACTIONS(595),
    [anon_sym_symbol] = ACTIONS(595),
    [anon_sym_object] = ACTIONS(595),
    [anon_sym_abstract] = ACTIONS(597),
    [anon_sym_infer] = ACTIONS(599),
    [anon_sym_keyof] = ACTIONS(601),
    [anon_sym_unique] = ACTIONS(214),
    [anon_sym_unknown] = ACTIONS(216),
    [anon_sym_never] = ACTIONS(216),
    [anon_sym_LBRACE_PIPE] = ACTIONS(218),
    [sym_html_comment] = ACTIONS(5),
  },
  [39] = {
    [sym_export_statement] = STATE(892),
    [sym_declaration] = STATE(892),
    [sym_import] = STATE(3636),
    [sym_import_statement] = STATE(892),
    [sym_statement] = STATE(884),
    [sym_expression_statement] = STATE(892),
    [sym_variable_declaration] = STATE(831),
    [sym_lexical_declaration] = STATE(831),
    [sym_statement_block] = STATE(892),
    [sym_if_statement] = STATE(892),
    [sym_switch_statement] = STATE(892),
    [sym_for_statement] = STATE(892),
    [sym_for_in_statement] = STATE(892),
    [sym_while_statement] = STATE(892),
    [sym_do_statement] = STATE(892),
    [sym_try_statement] = STATE(892),
    [sym_with_statement] = STATE(892),
    [sym_break_statement] = STATE(892),
    [sym_continue_statement] = STATE(892),
    [sym_debugger_statement] = STATE(892),
    [sym_return_statement] = STATE(892),
    [sym_throw_statement] = STATE(892),
    [sym_empty_statement] = STATE(892),
    [sym_labeled_statement] = STATE(892),
    [sym_parenthesized_expression] = STATE(1362),
    [sym_expression] = STATE(1902),
    [sym_primary_expression] = STATE(1810),
    [sym_yield_expression] = STATE(2358),
    [sym_object] = STATE(2222),
    [sym_object_pattern] = STATE(5492),
    [sym_array] = STATE(2222),
    [sym_array_pattern] = STATE(5492),
    [sym_class] = STATE(2222),
    [sym_class_declaration] = STATE(831),
    [sym_function_expression] = STATE(2222),
    [sym_function_declaration] = STATE(831),
    [sym_generator_function] = STATE(2222),
    [sym_generator_function_declaration] = STATE(831),
    [sym_arrow_function] = STATE(2222),
    [sym__call_signature] = STATE(5821),
    [sym_call_expression] = STATE(2222),
    [sym_new_expression] = STATE(1948),
    [sym_await_expression] = STATE(2358),
    [sym_member_expression] = STATE(1362),
    [sym_subscript_expression] = STATE(1362),
    [sym_assignment_expression] = STATE(2358),
    [sym__augmented_assignment_lhs] = STATE(3025),
    [sym_augmented_assignment_expression] = STATE(2358),
    [sym__destructuring_pattern] = STATE(5492),
    [sym_ternary_expression] = STATE(2358),
    [sym_binary_expression] = STATE(2358),
    [sym_unary_expression] = STATE(2358),
    [sym_update_expression] = STATE(2358),
    [sym_sequence_expression] = STATE(5305),
    [sym_string] = STATE(2222),
    [sym_template_string] = STATE(2222),
    [sym_regex] = STATE(2222),
    [sym_meta_property] = STATE(2222),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1362),
    [sym_function_signature] = STATE(831),
    [sym_type_assertion] = STATE(2358),
    [sym_as_expression] = STATE(2358),
    [sym_satisfies_expression] = STATE(2358),
    [sym_instantiation_expression] = STATE(2358),
    [sym_ambient_declaration] = STATE(831),
    [sym_abstract_class_declaration] = STATE(831),
    [sym_module] = STATE(831),
    [sym_internal_module] = STATE(2513),
    [sym_import_alias] = STATE(831),
    [sym_interface_declaration] = STATE(831),
    [sym_enum_declaration] = STATE(831),
    [sym_type_alias_declaration] = STATE(831),
    [sym_type_arguments] = STATE(428),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(3830),
    [sym_identifier] = ACTIONS(603),
    [anon_sym_export] = ACTIONS(605),
    [anon_sym_type] = ACTIONS(607),
    [anon_sym_namespace] = ACTIONS(609),
    [anon_sym_LBRACE] = ACTIONS(611),
    [anon_sym_typeof] = ACTIONS(21),
    [anon_sym_import] = ACTIONS(23),
    [anon_sym_with] = ACTIONS(613),
    [anon_sym_var] = ACTIONS(27),
    [anon_sym_let] = ACTIONS(615),
    [anon_sym_const] = ACTIONS(31),
    [anon_sym_BANG] = ACTIONS(33),
    [anon_sym_if] = ACTIONS(617),
    [anon_sym_switch] = ACTIONS(37),
    [anon_sym_for] = ACTIONS(619),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_SEMI] = ACTIONS(43),
    [anon_sym_await] = ACTIONS(45),
    [anon_sym_while] = ACTIONS(621),
    [anon_sym_do] = ACTIONS(49),
    [anon_sym_try] = ACTIONS(51),
    [anon_sym_break] = ACTIONS(53),
    [anon_sym_continue] = ACTIONS(55),
    [anon_sym_debugger] = ACTIONS(57),
    [anon_sym_return] = ACTIONS(59),
    [anon_sym_throw] = ACTIONS(61),
    [anon_sym_yield] = ACTIONS(63),
    [anon_sym_LBRACK] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(623),
    [anon_sym_async] = ACTIONS(625),
    [anon_sym_function] = ACTIONS(627),
    [anon_sym_new] = ACTIONS(629),
    [anon_sym_using] = ACTIONS(75),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_SLASH] = ACTIONS(77),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(33),
    [anon_sym_void] = ACTIONS(21),
    [anon_sym_delete] = ACTIONS(21),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_DQUOTE] = ACTIONS(83),
    [anon_sym_SQUOTE] = ACTIONS(85),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(87),
    [sym_number] = ACTIONS(89),
    [sym_private_property_identifier] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(93),
    [sym_true] = ACTIONS(93),
    [sym_false] = ACTIONS(93),
    [sym_null] = ACTIONS(93),
    [sym_undefined] = ACTIONS(95),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(631),
    [anon_sym_readonly] = ACTIONS(631),
    [anon_sym_get] = ACTIONS(631),
    [anon_sym_set] = ACTIONS(631),
    [anon_sym_declare] = ACTIONS(633),
    [anon_sym_public] = ACTIONS(631),
    [anon_sym_private] = ACTIONS(631),
    [anon_sym_protected] = ACTIONS(631),
    [anon_sym_override] = ACTIONS(631),
    [anon_sym_module] = ACTIONS(635),
    [anon_sym_any] = ACTIONS(631),
    [anon_sym_number] = ACTIONS(631),
    [anon_sym_boolean] = ACTIONS(631),
    [anon_sym_string] = ACTIONS(631),
    [anon_sym_symbol] = ACTIONS(631),
    [anon_sym_object] = ACTIONS(631),
    [anon_sym_abstract] = ACTIONS(105),
    [anon_sym_interface] = ACTIONS(107),
    [anon_sym_enum] = ACTIONS(109),
    [sym_html_comment] = ACTIONS(5),
  },
  [40] = {
    [sym_import] = STATE(3663),
    [sym_parenthesized_expression] = STATE(1322),
    [sym_expression] = STATE(2301),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(4425),
    [sym_assignment_pattern] = STATE(4969),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(4425),
    [sym_nested_identifier] = STATE(5474),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5508),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1396),
    [sym_subscript_expression] = STATE(1396),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3003),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(4425),
    [sym_spread_element] = STATE(4971),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(2213),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(4317),
    [sym_pattern] = STATE(4406),
    [sym_rest_pattern] = STATE(4115),
    [sym_non_null_expression] = STATE(1396),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_nested_type_identifier] = STATE(2939),
    [sym__type_query_member_expression_in_type_annotation] = STATE(3303),
    [sym__type_query_call_expression_in_type_annotation] = STATE(2938),
    [sym_type] = STATE(3773),
    [sym_tuple_parameter] = STATE(4568),
    [sym_optional_tuple_parameter] = STATE(4568),
    [sym_optional_type] = STATE(4568),
    [sym_rest_type] = STATE(4568),
    [sym__tuple_type_member] = STATE(4568),
    [sym_constructor_type] = STATE(3007),
    [sym_primary_type] = STATE(2981),
    [sym_template_literal_type] = STATE(3039),
    [sym_infer_type] = STATE(3007),
    [sym_conditional_type] = STATE(3039),
    [sym_generic_type] = STATE(3039),
    [sym_type_query] = STATE(3039),
    [sym_index_type_query] = STATE(3039),
    [sym_lookup_type] = STATE(3039),
    [sym_literal_type] = STATE(3039),
    [sym__number] = STATE(3041),
    [sym_existential_type] = STATE(3039),
    [sym_flow_maybe_type] = STATE(3039),
    [sym_parenthesized_type] = STATE(3039),
    [sym_predefined_type] = STATE(3039),
    [sym_type_arguments] = STATE(484),
    [sym_object_type] = STATE(3039),
    [sym_type_parameters] = STATE(5455),
    [sym_array_type] = STATE(3039),
    [sym_tuple_type] = STATE(3039),
    [sym_readonly_type] = STATE(3007),
    [sym_union_type] = STATE(3039),
    [sym_intersection_type] = STATE(3039),
    [sym_function_type] = STATE(3007),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [aux_sym_array_repeat1] = STATE(4975),
    [aux_sym_array_pattern_repeat1] = STATE(4977),
    [sym_identifier] = ACTIONS(539),
    [anon_sym_export] = ACTIONS(541),
    [anon_sym_STAR] = ACTIONS(543),
    [anon_sym_type] = ACTIONS(541),
    [anon_sym_namespace] = ACTIONS(545),
    [anon_sym_LBRACE] = ACTIONS(547),
    [anon_sym_COMMA] = ACTIONS(549),
    [anon_sym_typeof] = ACTIONS(551),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(541),
    [anon_sym_const] = ACTIONS(133),
    [anon_sym_BANG] = ACTIONS(553),
    [anon_sym_LPAREN] = ACTIONS(138),
    [anon_sym_await] = ACTIONS(555),
    [anon_sym_yield] = ACTIONS(557),
    [anon_sym_LBRACK] = ACTIONS(559),
    [anon_sym_RBRACK] = ACTIONS(639),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(563),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(565),
    [anon_sym_using] = ACTIONS(567),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(569),
    [anon_sym_AMP] = ACTIONS(571),
    [anon_sym_PIPE] = ACTIONS(573),
    [anon_sym_PLUS] = ACTIONS(575),
    [anon_sym_DASH] = ACTIONS(575),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(553),
    [anon_sym_void] = ACTIONS(579),
    [anon_sym_delete] = ACTIONS(581),
    [anon_sym_PLUS_PLUS] = ACTIONS(583),
    [anon_sym_DASH_DASH] = ACTIONS(583),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(188),
    [sym_number] = ACTIONS(190),
    [sym_private_property_identifier] = ACTIONS(585),
    [sym_this] = ACTIONS(587),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(198),
    [sym_false] = ACTIONS(198),
    [sym_null] = ACTIONS(198),
    [sym_undefined] = ACTIONS(589),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(541),
    [anon_sym_readonly] = ACTIONS(591),
    [anon_sym_get] = ACTIONS(541),
    [anon_sym_set] = ACTIONS(541),
    [anon_sym_QMARK] = ACTIONS(593),
    [anon_sym_declare] = ACTIONS(541),
    [anon_sym_public] = ACTIONS(541),
    [anon_sym_private] = ACTIONS(541),
    [anon_sym_protected] = ACTIONS(541),
    [anon_sym_override] = ACTIONS(541),
    [anon_sym_module] = ACTIONS(541),
    [anon_sym_any] = ACTIONS(595),
    [anon_sym_number] = ACTIONS(595),
    [anon_sym_boolean] = ACTIONS(595),
    [anon_sym_string] = ACTIONS(595),
    [anon_sym_symbol] = ACTIONS(595),
    [anon_sym_object] = ACTIONS(595),
    [anon_sym_abstract] = ACTIONS(597),
    [anon_sym_infer] = ACTIONS(599),
    [anon_sym_keyof] = ACTIONS(601),
    [anon_sym_unique] = ACTIONS(214),
    [anon_sym_unknown] = ACTIONS(216),
    [anon_sym_never] = ACTIONS(216),
    [anon_sym_LBRACE_PIPE] = ACTIONS(218),
    [sym_html_comment] = ACTIONS(5),
  },
  [41] = {
    [sym_export_statement] = STATE(892),
    [sym_declaration] = STATE(892),
    [sym_import] = STATE(3636),
    [sym_import_statement] = STATE(892),
    [sym_statement] = STATE(928),
    [sym_expression_statement] = STATE(892),
    [sym_variable_declaration] = STATE(831),
    [sym_lexical_declaration] = STATE(831),
    [sym_statement_block] = STATE(892),
    [sym_if_statement] = STATE(892),
    [sym_switch_statement] = STATE(892),
    [sym_for_statement] = STATE(892),
    [sym_for_in_statement] = STATE(892),
    [sym_while_statement] = STATE(892),
    [sym_do_statement] = STATE(892),
    [sym_try_statement] = STATE(892),
    [sym_with_statement] = STATE(892),
    [sym_break_statement] = STATE(892),
    [sym_continue_statement] = STATE(892),
    [sym_debugger_statement] = STATE(892),
    [sym_return_statement] = STATE(892),
    [sym_throw_statement] = STATE(892),
    [sym_empty_statement] = STATE(892),
    [sym_labeled_statement] = STATE(892),
    [sym_parenthesized_expression] = STATE(1362),
    [sym_expression] = STATE(1902),
    [sym_primary_expression] = STATE(1810),
    [sym_yield_expression] = STATE(2358),
    [sym_object] = STATE(2222),
    [sym_object_pattern] = STATE(5492),
    [sym_array] = STATE(2222),
    [sym_array_pattern] = STATE(5492),
    [sym_class] = STATE(2222),
    [sym_class_declaration] = STATE(831),
    [sym_function_expression] = STATE(2222),
    [sym_function_declaration] = STATE(831),
    [sym_generator_function] = STATE(2222),
    [sym_generator_function_declaration] = STATE(831),
    [sym_arrow_function] = STATE(2222),
    [sym__call_signature] = STATE(5821),
    [sym_call_expression] = STATE(2222),
    [sym_new_expression] = STATE(1948),
    [sym_await_expression] = STATE(2358),
    [sym_member_expression] = STATE(1362),
    [sym_subscript_expression] = STATE(1362),
    [sym_assignment_expression] = STATE(2358),
    [sym__augmented_assignment_lhs] = STATE(3025),
    [sym_augmented_assignment_expression] = STATE(2358),
    [sym__destructuring_pattern] = STATE(5492),
    [sym_ternary_expression] = STATE(2358),
    [sym_binary_expression] = STATE(2358),
    [sym_unary_expression] = STATE(2358),
    [sym_update_expression] = STATE(2358),
    [sym_sequence_expression] = STATE(5305),
    [sym_string] = STATE(2222),
    [sym_template_string] = STATE(2222),
    [sym_regex] = STATE(2222),
    [sym_meta_property] = STATE(2222),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1362),
    [sym_function_signature] = STATE(831),
    [sym_type_assertion] = STATE(2358),
    [sym_as_expression] = STATE(2358),
    [sym_satisfies_expression] = STATE(2358),
    [sym_instantiation_expression] = STATE(2358),
    [sym_ambient_declaration] = STATE(831),
    [sym_abstract_class_declaration] = STATE(831),
    [sym_module] = STATE(831),
    [sym_internal_module] = STATE(2513),
    [sym_import_alias] = STATE(831),
    [sym_interface_declaration] = STATE(831),
    [sym_enum_declaration] = STATE(831),
    [sym_type_alias_declaration] = STATE(831),
    [sym_type_arguments] = STATE(428),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(3830),
    [sym_identifier] = ACTIONS(603),
    [anon_sym_export] = ACTIONS(605),
    [anon_sym_type] = ACTIONS(607),
    [anon_sym_namespace] = ACTIONS(609),
    [anon_sym_LBRACE] = ACTIONS(611),
    [anon_sym_typeof] = ACTIONS(21),
    [anon_sym_import] = ACTIONS(23),
    [anon_sym_with] = ACTIONS(613),
    [anon_sym_var] = ACTIONS(27),
    [anon_sym_let] = ACTIONS(615),
    [anon_sym_const] = ACTIONS(31),
    [anon_sym_BANG] = ACTIONS(33),
    [anon_sym_if] = ACTIONS(617),
    [anon_sym_switch] = ACTIONS(37),
    [anon_sym_for] = ACTIONS(619),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_SEMI] = ACTIONS(43),
    [anon_sym_await] = ACTIONS(45),
    [anon_sym_while] = ACTIONS(621),
    [anon_sym_do] = ACTIONS(49),
    [anon_sym_try] = ACTIONS(51),
    [anon_sym_break] = ACTIONS(53),
    [anon_sym_continue] = ACTIONS(55),
    [anon_sym_debugger] = ACTIONS(57),
    [anon_sym_return] = ACTIONS(59),
    [anon_sym_throw] = ACTIONS(61),
    [anon_sym_yield] = ACTIONS(63),
    [anon_sym_LBRACK] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(623),
    [anon_sym_async] = ACTIONS(625),
    [anon_sym_function] = ACTIONS(627),
    [anon_sym_new] = ACTIONS(629),
    [anon_sym_using] = ACTIONS(75),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_SLASH] = ACTIONS(77),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(33),
    [anon_sym_void] = ACTIONS(21),
    [anon_sym_delete] = ACTIONS(21),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_DQUOTE] = ACTIONS(83),
    [anon_sym_SQUOTE] = ACTIONS(85),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(87),
    [sym_number] = ACTIONS(89),
    [sym_private_property_identifier] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(93),
    [sym_true] = ACTIONS(93),
    [sym_false] = ACTIONS(93),
    [sym_null] = ACTIONS(93),
    [sym_undefined] = ACTIONS(95),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(631),
    [anon_sym_readonly] = ACTIONS(631),
    [anon_sym_get] = ACTIONS(631),
    [anon_sym_set] = ACTIONS(631),
    [anon_sym_declare] = ACTIONS(633),
    [anon_sym_public] = ACTIONS(631),
    [anon_sym_private] = ACTIONS(631),
    [anon_sym_protected] = ACTIONS(631),
    [anon_sym_override] = ACTIONS(631),
    [anon_sym_module] = ACTIONS(635),
    [anon_sym_any] = ACTIONS(631),
    [anon_sym_number] = ACTIONS(631),
    [anon_sym_boolean] = ACTIONS(631),
    [anon_sym_string] = ACTIONS(631),
    [anon_sym_symbol] = ACTIONS(631),
    [anon_sym_object] = ACTIONS(631),
    [anon_sym_abstract] = ACTIONS(105),
    [anon_sym_interface] = ACTIONS(107),
    [anon_sym_enum] = ACTIONS(109),
    [sym_html_comment] = ACTIONS(5),
  },
  [42] = {
    [sym_export_statement] = STATE(892),
    [sym_declaration] = STATE(892),
    [sym_import] = STATE(3636),
    [sym_import_statement] = STATE(892),
    [sym_statement] = STATE(874),
    [sym_expression_statement] = STATE(892),
    [sym_variable_declaration] = STATE(831),
    [sym_lexical_declaration] = STATE(831),
    [sym_statement_block] = STATE(892),
    [sym_if_statement] = STATE(892),
    [sym_switch_statement] = STATE(892),
    [sym_for_statement] = STATE(892),
    [sym_for_in_statement] = STATE(892),
    [sym_while_statement] = STATE(892),
    [sym_do_statement] = STATE(892),
    [sym_try_statement] = STATE(892),
    [sym_with_statement] = STATE(892),
    [sym_break_statement] = STATE(892),
    [sym_continue_statement] = STATE(892),
    [sym_debugger_statement] = STATE(892),
    [sym_return_statement] = STATE(892),
    [sym_throw_statement] = STATE(892),
    [sym_empty_statement] = STATE(892),
    [sym_labeled_statement] = STATE(892),
    [sym_parenthesized_expression] = STATE(1362),
    [sym_expression] = STATE(1902),
    [sym_primary_expression] = STATE(1810),
    [sym_yield_expression] = STATE(2358),
    [sym_object] = STATE(2222),
    [sym_object_pattern] = STATE(5492),
    [sym_array] = STATE(2222),
    [sym_array_pattern] = STATE(5492),
    [sym_class] = STATE(2222),
    [sym_class_declaration] = STATE(831),
    [sym_function_expression] = STATE(2222),
    [sym_function_declaration] = STATE(831),
    [sym_generator_function] = STATE(2222),
    [sym_generator_function_declaration] = STATE(831),
    [sym_arrow_function] = STATE(2222),
    [sym__call_signature] = STATE(5821),
    [sym_call_expression] = STATE(2222),
    [sym_new_expression] = STATE(1948),
    [sym_await_expression] = STATE(2358),
    [sym_member_expression] = STATE(1362),
    [sym_subscript_expression] = STATE(1362),
    [sym_assignment_expression] = STATE(2358),
    [sym__augmented_assignment_lhs] = STATE(3025),
    [sym_augmented_assignment_expression] = STATE(2358),
    [sym__destructuring_pattern] = STATE(5492),
    [sym_ternary_expression] = STATE(2358),
    [sym_binary_expression] = STATE(2358),
    [sym_unary_expression] = STATE(2358),
    [sym_update_expression] = STATE(2358),
    [sym_sequence_expression] = STATE(5305),
    [sym_string] = STATE(2222),
    [sym_template_string] = STATE(2222),
    [sym_regex] = STATE(2222),
    [sym_meta_property] = STATE(2222),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1362),
    [sym_function_signature] = STATE(831),
    [sym_type_assertion] = STATE(2358),
    [sym_as_expression] = STATE(2358),
    [sym_satisfies_expression] = STATE(2358),
    [sym_instantiation_expression] = STATE(2358),
    [sym_ambient_declaration] = STATE(831),
    [sym_abstract_class_declaration] = STATE(831),
    [sym_module] = STATE(831),
    [sym_internal_module] = STATE(2513),
    [sym_import_alias] = STATE(831),
    [sym_interface_declaration] = STATE(831),
    [sym_enum_declaration] = STATE(831),
    [sym_type_alias_declaration] = STATE(831),
    [sym_type_arguments] = STATE(428),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(3830),
    [sym_identifier] = ACTIONS(603),
    [anon_sym_export] = ACTIONS(605),
    [anon_sym_type] = ACTIONS(607),
    [anon_sym_namespace] = ACTIONS(609),
    [anon_sym_LBRACE] = ACTIONS(611),
    [anon_sym_typeof] = ACTIONS(21),
    [anon_sym_import] = ACTIONS(23),
    [anon_sym_with] = ACTIONS(613),
    [anon_sym_var] = ACTIONS(27),
    [anon_sym_let] = ACTIONS(615),
    [anon_sym_const] = ACTIONS(31),
    [anon_sym_BANG] = ACTIONS(33),
    [anon_sym_if] = ACTIONS(617),
    [anon_sym_switch] = ACTIONS(37),
    [anon_sym_for] = ACTIONS(619),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_SEMI] = ACTIONS(43),
    [anon_sym_await] = ACTIONS(45),
    [anon_sym_while] = ACTIONS(621),
    [anon_sym_do] = ACTIONS(49),
    [anon_sym_try] = ACTIONS(51),
    [anon_sym_break] = ACTIONS(53),
    [anon_sym_continue] = ACTIONS(55),
    [anon_sym_debugger] = ACTIONS(57),
    [anon_sym_return] = ACTIONS(59),
    [anon_sym_throw] = ACTIONS(61),
    [anon_sym_yield] = ACTIONS(63),
    [anon_sym_LBRACK] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(623),
    [anon_sym_async] = ACTIONS(625),
    [anon_sym_function] = ACTIONS(627),
    [anon_sym_new] = ACTIONS(629),
    [anon_sym_using] = ACTIONS(75),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_SLASH] = ACTIONS(77),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(33),
    [anon_sym_void] = ACTIONS(21),
    [anon_sym_delete] = ACTIONS(21),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_DQUOTE] = ACTIONS(83),
    [anon_sym_SQUOTE] = ACTIONS(85),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(87),
    [sym_number] = ACTIONS(89),
    [sym_private_property_identifier] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(93),
    [sym_true] = ACTIONS(93),
    [sym_false] = ACTIONS(93),
    [sym_null] = ACTIONS(93),
    [sym_undefined] = ACTIONS(95),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(631),
    [anon_sym_readonly] = ACTIONS(631),
    [anon_sym_get] = ACTIONS(631),
    [anon_sym_set] = ACTIONS(631),
    [anon_sym_declare] = ACTIONS(633),
    [anon_sym_public] = ACTIONS(631),
    [anon_sym_private] = ACTIONS(631),
    [anon_sym_protected] = ACTIONS(631),
    [anon_sym_override] = ACTIONS(631),
    [anon_sym_module] = ACTIONS(635),
    [anon_sym_any] = ACTIONS(631),
    [anon_sym_number] = ACTIONS(631),
    [anon_sym_boolean] = ACTIONS(631),
    [anon_sym_string] = ACTIONS(631),
    [anon_sym_symbol] = ACTIONS(631),
    [anon_sym_object] = ACTIONS(631),
    [anon_sym_abstract] = ACTIONS(105),
    [anon_sym_interface] = ACTIONS(107),
    [anon_sym_enum] = ACTIONS(109),
    [sym_html_comment] = ACTIONS(5),
  },
  [43] = {
    [sym_export_statement] = STATE(892),
    [sym_declaration] = STATE(892),
    [sym_import] = STATE(3636),
    [sym_import_statement] = STATE(892),
    [sym_statement] = STATE(815),
    [sym_expression_statement] = STATE(892),
    [sym_variable_declaration] = STATE(831),
    [sym_lexical_declaration] = STATE(831),
    [sym_statement_block] = STATE(892),
    [sym_if_statement] = STATE(892),
    [sym_switch_statement] = STATE(892),
    [sym_for_statement] = STATE(892),
    [sym_for_in_statement] = STATE(892),
    [sym_while_statement] = STATE(892),
    [sym_do_statement] = STATE(892),
    [sym_try_statement] = STATE(892),
    [sym_with_statement] = STATE(892),
    [sym_break_statement] = STATE(892),
    [sym_continue_statement] = STATE(892),
    [sym_debugger_statement] = STATE(892),
    [sym_return_statement] = STATE(892),
    [sym_throw_statement] = STATE(892),
    [sym_empty_statement] = STATE(892),
    [sym_labeled_statement] = STATE(892),
    [sym_parenthesized_expression] = STATE(1362),
    [sym_expression] = STATE(1902),
    [sym_primary_expression] = STATE(1810),
    [sym_yield_expression] = STATE(2358),
    [sym_object] = STATE(2222),
    [sym_object_pattern] = STATE(5492),
    [sym_array] = STATE(2222),
    [sym_array_pattern] = STATE(5492),
    [sym_class] = STATE(2222),
    [sym_class_declaration] = STATE(831),
    [sym_function_expression] = STATE(2222),
    [sym_function_declaration] = STATE(831),
    [sym_generator_function] = STATE(2222),
    [sym_generator_function_declaration] = STATE(831),
    [sym_arrow_function] = STATE(2222),
    [sym__call_signature] = STATE(5821),
    [sym_call_expression] = STATE(2222),
    [sym_new_expression] = STATE(1948),
    [sym_await_expression] = STATE(2358),
    [sym_member_expression] = STATE(1362),
    [sym_subscript_expression] = STATE(1362),
    [sym_assignment_expression] = STATE(2358),
    [sym__augmented_assignment_lhs] = STATE(3025),
    [sym_augmented_assignment_expression] = STATE(2358),
    [sym__destructuring_pattern] = STATE(5492),
    [sym_ternary_expression] = STATE(2358),
    [sym_binary_expression] = STATE(2358),
    [sym_unary_expression] = STATE(2358),
    [sym_update_expression] = STATE(2358),
    [sym_sequence_expression] = STATE(5305),
    [sym_string] = STATE(2222),
    [sym_template_string] = STATE(2222),
    [sym_regex] = STATE(2222),
    [sym_meta_property] = STATE(2222),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1362),
    [sym_function_signature] = STATE(831),
    [sym_type_assertion] = STATE(2358),
    [sym_as_expression] = STATE(2358),
    [sym_satisfies_expression] = STATE(2358),
    [sym_instantiation_expression] = STATE(2358),
    [sym_ambient_declaration] = STATE(831),
    [sym_abstract_class_declaration] = STATE(831),
    [sym_module] = STATE(831),
    [sym_internal_module] = STATE(2513),
    [sym_import_alias] = STATE(831),
    [sym_interface_declaration] = STATE(831),
    [sym_enum_declaration] = STATE(831),
    [sym_type_alias_declaration] = STATE(831),
    [sym_type_arguments] = STATE(428),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(3830),
    [sym_identifier] = ACTIONS(603),
    [anon_sym_export] = ACTIONS(605),
    [anon_sym_type] = ACTIONS(607),
    [anon_sym_namespace] = ACTIONS(609),
    [anon_sym_LBRACE] = ACTIONS(611),
    [anon_sym_typeof] = ACTIONS(21),
    [anon_sym_import] = ACTIONS(23),
    [anon_sym_with] = ACTIONS(613),
    [anon_sym_var] = ACTIONS(27),
    [anon_sym_let] = ACTIONS(615),
    [anon_sym_const] = ACTIONS(31),
    [anon_sym_BANG] = ACTIONS(33),
    [anon_sym_if] = ACTIONS(617),
    [anon_sym_switch] = ACTIONS(37),
    [anon_sym_for] = ACTIONS(619),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_SEMI] = ACTIONS(43),
    [anon_sym_await] = ACTIONS(45),
    [anon_sym_while] = ACTIONS(621),
    [anon_sym_do] = ACTIONS(49),
    [anon_sym_try] = ACTIONS(51),
    [anon_sym_break] = ACTIONS(53),
    [anon_sym_continue] = ACTIONS(55),
    [anon_sym_debugger] = ACTIONS(57),
    [anon_sym_return] = ACTIONS(59),
    [anon_sym_throw] = ACTIONS(61),
    [anon_sym_yield] = ACTIONS(63),
    [anon_sym_LBRACK] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(623),
    [anon_sym_async] = ACTIONS(625),
    [anon_sym_function] = ACTIONS(627),
    [anon_sym_new] = ACTIONS(629),
    [anon_sym_using] = ACTIONS(75),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_SLASH] = ACTIONS(77),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(33),
    [anon_sym_void] = ACTIONS(21),
    [anon_sym_delete] = ACTIONS(21),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_DQUOTE] = ACTIONS(83),
    [anon_sym_SQUOTE] = ACTIONS(85),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(87),
    [sym_number] = ACTIONS(89),
    [sym_private_property_identifier] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(93),
    [sym_true] = ACTIONS(93),
    [sym_false] = ACTIONS(93),
    [sym_null] = ACTIONS(93),
    [sym_undefined] = ACTIONS(95),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(631),
    [anon_sym_readonly] = ACTIONS(631),
    [anon_sym_get] = ACTIONS(631),
    [anon_sym_set] = ACTIONS(631),
    [anon_sym_declare] = ACTIONS(633),
    [anon_sym_public] = ACTIONS(631),
    [anon_sym_private] = ACTIONS(631),
    [anon_sym_protected] = ACTIONS(631),
    [anon_sym_override] = ACTIONS(631),
    [anon_sym_module] = ACTIONS(635),
    [anon_sym_any] = ACTIONS(631),
    [anon_sym_number] = ACTIONS(631),
    [anon_sym_boolean] = ACTIONS(631),
    [anon_sym_string] = ACTIONS(631),
    [anon_sym_symbol] = ACTIONS(631),
    [anon_sym_object] = ACTIONS(631),
    [anon_sym_abstract] = ACTIONS(105),
    [anon_sym_interface] = ACTIONS(107),
    [anon_sym_enum] = ACTIONS(109),
    [sym_html_comment] = ACTIONS(5),
  },
  [44] = {
    [sym_export_statement] = STATE(892),
    [sym_declaration] = STATE(892),
    [sym_import] = STATE(3636),
    [sym_import_statement] = STATE(892),
    [sym_statement] = STATE(819),
    [sym_expression_statement] = STATE(892),
    [sym_variable_declaration] = STATE(831),
    [sym_lexical_declaration] = STATE(831),
    [sym_statement_block] = STATE(892),
    [sym_if_statement] = STATE(892),
    [sym_switch_statement] = STATE(892),
    [sym_for_statement] = STATE(892),
    [sym_for_in_statement] = STATE(892),
    [sym_while_statement] = STATE(892),
    [sym_do_statement] = STATE(892),
    [sym_try_statement] = STATE(892),
    [sym_with_statement] = STATE(892),
    [sym_break_statement] = STATE(892),
    [sym_continue_statement] = STATE(892),
    [sym_debugger_statement] = STATE(892),
    [sym_return_statement] = STATE(892),
    [sym_throw_statement] = STATE(892),
    [sym_empty_statement] = STATE(892),
    [sym_labeled_statement] = STATE(892),
    [sym_parenthesized_expression] = STATE(1362),
    [sym_expression] = STATE(1902),
    [sym_primary_expression] = STATE(1810),
    [sym_yield_expression] = STATE(2358),
    [sym_object] = STATE(2222),
    [sym_object_pattern] = STATE(5492),
    [sym_array] = STATE(2222),
    [sym_array_pattern] = STATE(5492),
    [sym_class] = STATE(2222),
    [sym_class_declaration] = STATE(831),
    [sym_function_expression] = STATE(2222),
    [sym_function_declaration] = STATE(831),
    [sym_generator_function] = STATE(2222),
    [sym_generator_function_declaration] = STATE(831),
    [sym_arrow_function] = STATE(2222),
    [sym__call_signature] = STATE(5821),
    [sym_call_expression] = STATE(2222),
    [sym_new_expression] = STATE(1948),
    [sym_await_expression] = STATE(2358),
    [sym_member_expression] = STATE(1362),
    [sym_subscript_expression] = STATE(1362),
    [sym_assignment_expression] = STATE(2358),
    [sym__augmented_assignment_lhs] = STATE(3025),
    [sym_augmented_assignment_expression] = STATE(2358),
    [sym__destructuring_pattern] = STATE(5492),
    [sym_ternary_expression] = STATE(2358),
    [sym_binary_expression] = STATE(2358),
    [sym_unary_expression] = STATE(2358),
    [sym_update_expression] = STATE(2358),
    [sym_sequence_expression] = STATE(5305),
    [sym_string] = STATE(2222),
    [sym_template_string] = STATE(2222),
    [sym_regex] = STATE(2222),
    [sym_meta_property] = STATE(2222),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1362),
    [sym_function_signature] = STATE(831),
    [sym_type_assertion] = STATE(2358),
    [sym_as_expression] = STATE(2358),
    [sym_satisfies_expression] = STATE(2358),
    [sym_instantiation_expression] = STATE(2358),
    [sym_ambient_declaration] = STATE(831),
    [sym_abstract_class_declaration] = STATE(831),
    [sym_module] = STATE(831),
    [sym_internal_module] = STATE(2513),
    [sym_import_alias] = STATE(831),
    [sym_interface_declaration] = STATE(831),
    [sym_enum_declaration] = STATE(831),
    [sym_type_alias_declaration] = STATE(831),
    [sym_type_arguments] = STATE(428),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(3830),
    [sym_identifier] = ACTIONS(603),
    [anon_sym_export] = ACTIONS(605),
    [anon_sym_type] = ACTIONS(607),
    [anon_sym_namespace] = ACTIONS(609),
    [anon_sym_LBRACE] = ACTIONS(611),
    [anon_sym_typeof] = ACTIONS(21),
    [anon_sym_import] = ACTIONS(23),
    [anon_sym_with] = ACTIONS(613),
    [anon_sym_var] = ACTIONS(27),
    [anon_sym_let] = ACTIONS(615),
    [anon_sym_const] = ACTIONS(31),
    [anon_sym_BANG] = ACTIONS(33),
    [anon_sym_if] = ACTIONS(617),
    [anon_sym_switch] = ACTIONS(37),
    [anon_sym_for] = ACTIONS(619),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_SEMI] = ACTIONS(43),
    [anon_sym_await] = ACTIONS(45),
    [anon_sym_while] = ACTIONS(621),
    [anon_sym_do] = ACTIONS(49),
    [anon_sym_try] = ACTIONS(51),
    [anon_sym_break] = ACTIONS(53),
    [anon_sym_continue] = ACTIONS(55),
    [anon_sym_debugger] = ACTIONS(57),
    [anon_sym_return] = ACTIONS(59),
    [anon_sym_throw] = ACTIONS(61),
    [anon_sym_yield] = ACTIONS(63),
    [anon_sym_LBRACK] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(623),
    [anon_sym_async] = ACTIONS(625),
    [anon_sym_function] = ACTIONS(627),
    [anon_sym_new] = ACTIONS(629),
    [anon_sym_using] = ACTIONS(75),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_SLASH] = ACTIONS(77),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(33),
    [anon_sym_void] = ACTIONS(21),
    [anon_sym_delete] = ACTIONS(21),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_DQUOTE] = ACTIONS(83),
    [anon_sym_SQUOTE] = ACTIONS(85),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(87),
    [sym_number] = ACTIONS(89),
    [sym_private_property_identifier] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(93),
    [sym_true] = ACTIONS(93),
    [sym_false] = ACTIONS(93),
    [sym_null] = ACTIONS(93),
    [sym_undefined] = ACTIONS(95),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(631),
    [anon_sym_readonly] = ACTIONS(631),
    [anon_sym_get] = ACTIONS(631),
    [anon_sym_set] = ACTIONS(631),
    [anon_sym_declare] = ACTIONS(633),
    [anon_sym_public] = ACTIONS(631),
    [anon_sym_private] = ACTIONS(631),
    [anon_sym_protected] = ACTIONS(631),
    [anon_sym_override] = ACTIONS(631),
    [anon_sym_module] = ACTIONS(635),
    [anon_sym_any] = ACTIONS(631),
    [anon_sym_number] = ACTIONS(631),
    [anon_sym_boolean] = ACTIONS(631),
    [anon_sym_string] = ACTIONS(631),
    [anon_sym_symbol] = ACTIONS(631),
    [anon_sym_object] = ACTIONS(631),
    [anon_sym_abstract] = ACTIONS(105),
    [anon_sym_interface] = ACTIONS(107),
    [anon_sym_enum] = ACTIONS(109),
    [sym_html_comment] = ACTIONS(5),
  },
  [45] = {
    [sym_export_statement] = STATE(892),
    [sym_declaration] = STATE(892),
    [sym_import] = STATE(3636),
    [sym_import_statement] = STATE(892),
    [sym_statement] = STATE(823),
    [sym_expression_statement] = STATE(892),
    [sym_variable_declaration] = STATE(831),
    [sym_lexical_declaration] = STATE(831),
    [sym_statement_block] = STATE(892),
    [sym_if_statement] = STATE(892),
    [sym_switch_statement] = STATE(892),
    [sym_for_statement] = STATE(892),
    [sym_for_in_statement] = STATE(892),
    [sym_while_statement] = STATE(892),
    [sym_do_statement] = STATE(892),
    [sym_try_statement] = STATE(892),
    [sym_with_statement] = STATE(892),
    [sym_break_statement] = STATE(892),
    [sym_continue_statement] = STATE(892),
    [sym_debugger_statement] = STATE(892),
    [sym_return_statement] = STATE(892),
    [sym_throw_statement] = STATE(892),
    [sym_empty_statement] = STATE(892),
    [sym_labeled_statement] = STATE(892),
    [sym_parenthesized_expression] = STATE(1362),
    [sym_expression] = STATE(1902),
    [sym_primary_expression] = STATE(1810),
    [sym_yield_expression] = STATE(2358),
    [sym_object] = STATE(2222),
    [sym_object_pattern] = STATE(5492),
    [sym_array] = STATE(2222),
    [sym_array_pattern] = STATE(5492),
    [sym_class] = STATE(2222),
    [sym_class_declaration] = STATE(831),
    [sym_function_expression] = STATE(2222),
    [sym_function_declaration] = STATE(831),
    [sym_generator_function] = STATE(2222),
    [sym_generator_function_declaration] = STATE(831),
    [sym_arrow_function] = STATE(2222),
    [sym__call_signature] = STATE(5821),
    [sym_call_expression] = STATE(2222),
    [sym_new_expression] = STATE(1948),
    [sym_await_expression] = STATE(2358),
    [sym_member_expression] = STATE(1362),
    [sym_subscript_expression] = STATE(1362),
    [sym_assignment_expression] = STATE(2358),
    [sym__augmented_assignment_lhs] = STATE(3025),
    [sym_augmented_assignment_expression] = STATE(2358),
    [sym__destructuring_pattern] = STATE(5492),
    [sym_ternary_expression] = STATE(2358),
    [sym_binary_expression] = STATE(2358),
    [sym_unary_expression] = STATE(2358),
    [sym_update_expression] = STATE(2358),
    [sym_sequence_expression] = STATE(5305),
    [sym_string] = STATE(2222),
    [sym_template_string] = STATE(2222),
    [sym_regex] = STATE(2222),
    [sym_meta_property] = STATE(2222),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1362),
    [sym_function_signature] = STATE(831),
    [sym_type_assertion] = STATE(2358),
    [sym_as_expression] = STATE(2358),
    [sym_satisfies_expression] = STATE(2358),
    [sym_instantiation_expression] = STATE(2358),
    [sym_ambient_declaration] = STATE(831),
    [sym_abstract_class_declaration] = STATE(831),
    [sym_module] = STATE(831),
    [sym_internal_module] = STATE(2513),
    [sym_import_alias] = STATE(831),
    [sym_interface_declaration] = STATE(831),
    [sym_enum_declaration] = STATE(831),
    [sym_type_alias_declaration] = STATE(831),
    [sym_type_arguments] = STATE(428),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(3830),
    [sym_identifier] = ACTIONS(603),
    [anon_sym_export] = ACTIONS(605),
    [anon_sym_type] = ACTIONS(607),
    [anon_sym_namespace] = ACTIONS(609),
    [anon_sym_LBRACE] = ACTIONS(611),
    [anon_sym_typeof] = ACTIONS(21),
    [anon_sym_import] = ACTIONS(23),
    [anon_sym_with] = ACTIONS(613),
    [anon_sym_var] = ACTIONS(27),
    [anon_sym_let] = ACTIONS(615),
    [anon_sym_const] = ACTIONS(31),
    [anon_sym_BANG] = ACTIONS(33),
    [anon_sym_if] = ACTIONS(617),
    [anon_sym_switch] = ACTIONS(37),
    [anon_sym_for] = ACTIONS(619),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_SEMI] = ACTIONS(43),
    [anon_sym_await] = ACTIONS(45),
    [anon_sym_while] = ACTIONS(621),
    [anon_sym_do] = ACTIONS(49),
    [anon_sym_try] = ACTIONS(51),
    [anon_sym_break] = ACTIONS(53),
    [anon_sym_continue] = ACTIONS(55),
    [anon_sym_debugger] = ACTIONS(57),
    [anon_sym_return] = ACTIONS(59),
    [anon_sym_throw] = ACTIONS(61),
    [anon_sym_yield] = ACTIONS(63),
    [anon_sym_LBRACK] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(623),
    [anon_sym_async] = ACTIONS(625),
    [anon_sym_function] = ACTIONS(627),
    [anon_sym_new] = ACTIONS(629),
    [anon_sym_using] = ACTIONS(75),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_SLASH] = ACTIONS(77),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(33),
    [anon_sym_void] = ACTIONS(21),
    [anon_sym_delete] = ACTIONS(21),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_DQUOTE] = ACTIONS(83),
    [anon_sym_SQUOTE] = ACTIONS(85),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(87),
    [sym_number] = ACTIONS(89),
    [sym_private_property_identifier] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(93),
    [sym_true] = ACTIONS(93),
    [sym_false] = ACTIONS(93),
    [sym_null] = ACTIONS(93),
    [sym_undefined] = ACTIONS(95),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(631),
    [anon_sym_readonly] = ACTIONS(631),
    [anon_sym_get] = ACTIONS(631),
    [anon_sym_set] = ACTIONS(631),
    [anon_sym_declare] = ACTIONS(633),
    [anon_sym_public] = ACTIONS(631),
    [anon_sym_private] = ACTIONS(631),
    [anon_sym_protected] = ACTIONS(631),
    [anon_sym_override] = ACTIONS(631),
    [anon_sym_module] = ACTIONS(635),
    [anon_sym_any] = ACTIONS(631),
    [anon_sym_number] = ACTIONS(631),
    [anon_sym_boolean] = ACTIONS(631),
    [anon_sym_string] = ACTIONS(631),
    [anon_sym_symbol] = ACTIONS(631),
    [anon_sym_object] = ACTIONS(631),
    [anon_sym_abstract] = ACTIONS(105),
    [anon_sym_interface] = ACTIONS(107),
    [anon_sym_enum] = ACTIONS(109),
    [sym_html_comment] = ACTIONS(5),
  },
  [46] = {
    [sym_export_statement] = STATE(892),
    [sym_declaration] = STATE(892),
    [sym_import] = STATE(3636),
    [sym_import_statement] = STATE(892),
    [sym_statement] = STATE(830),
    [sym_expression_statement] = STATE(892),
    [sym_variable_declaration] = STATE(831),
    [sym_lexical_declaration] = STATE(831),
    [sym_statement_block] = STATE(892),
    [sym_if_statement] = STATE(892),
    [sym_switch_statement] = STATE(892),
    [sym_for_statement] = STATE(892),
    [sym_for_in_statement] = STATE(892),
    [sym_while_statement] = STATE(892),
    [sym_do_statement] = STATE(892),
    [sym_try_statement] = STATE(892),
    [sym_with_statement] = STATE(892),
    [sym_break_statement] = STATE(892),
    [sym_continue_statement] = STATE(892),
    [sym_debugger_statement] = STATE(892),
    [sym_return_statement] = STATE(892),
    [sym_throw_statement] = STATE(892),
    [sym_empty_statement] = STATE(892),
    [sym_labeled_statement] = STATE(892),
    [sym_parenthesized_expression] = STATE(1362),
    [sym_expression] = STATE(1902),
    [sym_primary_expression] = STATE(1810),
    [sym_yield_expression] = STATE(2358),
    [sym_object] = STATE(2222),
    [sym_object_pattern] = STATE(5492),
    [sym_array] = STATE(2222),
    [sym_array_pattern] = STATE(5492),
    [sym_class] = STATE(2222),
    [sym_class_declaration] = STATE(831),
    [sym_function_expression] = STATE(2222),
    [sym_function_declaration] = STATE(831),
    [sym_generator_function] = STATE(2222),
    [sym_generator_function_declaration] = STATE(831),
    [sym_arrow_function] = STATE(2222),
    [sym__call_signature] = STATE(5821),
    [sym_call_expression] = STATE(2222),
    [sym_new_expression] = STATE(1948),
    [sym_await_expression] = STATE(2358),
    [sym_member_expression] = STATE(1362),
    [sym_subscript_expression] = STATE(1362),
    [sym_assignment_expression] = STATE(2358),
    [sym__augmented_assignment_lhs] = STATE(3025),
    [sym_augmented_assignment_expression] = STATE(2358),
    [sym__destructuring_pattern] = STATE(5492),
    [sym_ternary_expression] = STATE(2358),
    [sym_binary_expression] = STATE(2358),
    [sym_unary_expression] = STATE(2358),
    [sym_update_expression] = STATE(2358),
    [sym_sequence_expression] = STATE(5305),
    [sym_string] = STATE(2222),
    [sym_template_string] = STATE(2222),
    [sym_regex] = STATE(2222),
    [sym_meta_property] = STATE(2222),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1362),
    [sym_function_signature] = STATE(831),
    [sym_type_assertion] = STATE(2358),
    [sym_as_expression] = STATE(2358),
    [sym_satisfies_expression] = STATE(2358),
    [sym_instantiation_expression] = STATE(2358),
    [sym_ambient_declaration] = STATE(831),
    [sym_abstract_class_declaration] = STATE(831),
    [sym_module] = STATE(831),
    [sym_internal_module] = STATE(2513),
    [sym_import_alias] = STATE(831),
    [sym_interface_declaration] = STATE(831),
    [sym_enum_declaration] = STATE(831),
    [sym_type_alias_declaration] = STATE(831),
    [sym_type_arguments] = STATE(428),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(3830),
    [sym_identifier] = ACTIONS(603),
    [anon_sym_export] = ACTIONS(605),
    [anon_sym_type] = ACTIONS(607),
    [anon_sym_namespace] = ACTIONS(609),
    [anon_sym_LBRACE] = ACTIONS(611),
    [anon_sym_typeof] = ACTIONS(21),
    [anon_sym_import] = ACTIONS(23),
    [anon_sym_with] = ACTIONS(613),
    [anon_sym_var] = ACTIONS(27),
    [anon_sym_let] = ACTIONS(615),
    [anon_sym_const] = ACTIONS(31),
    [anon_sym_BANG] = ACTIONS(33),
    [anon_sym_if] = ACTIONS(617),
    [anon_sym_switch] = ACTIONS(37),
    [anon_sym_for] = ACTIONS(619),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_SEMI] = ACTIONS(43),
    [anon_sym_await] = ACTIONS(45),
    [anon_sym_while] = ACTIONS(621),
    [anon_sym_do] = ACTIONS(49),
    [anon_sym_try] = ACTIONS(51),
    [anon_sym_break] = ACTIONS(53),
    [anon_sym_continue] = ACTIONS(55),
    [anon_sym_debugger] = ACTIONS(57),
    [anon_sym_return] = ACTIONS(59),
    [anon_sym_throw] = ACTIONS(61),
    [anon_sym_yield] = ACTIONS(63),
    [anon_sym_LBRACK] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(623),
    [anon_sym_async] = ACTIONS(625),
    [anon_sym_function] = ACTIONS(627),
    [anon_sym_new] = ACTIONS(629),
    [anon_sym_using] = ACTIONS(75),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_SLASH] = ACTIONS(77),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(33),
    [anon_sym_void] = ACTIONS(21),
    [anon_sym_delete] = ACTIONS(21),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_DQUOTE] = ACTIONS(83),
    [anon_sym_SQUOTE] = ACTIONS(85),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(87),
    [sym_number] = ACTIONS(89),
    [sym_private_property_identifier] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(93),
    [sym_true] = ACTIONS(93),
    [sym_false] = ACTIONS(93),
    [sym_null] = ACTIONS(93),
    [sym_undefined] = ACTIONS(95),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(631),
    [anon_sym_readonly] = ACTIONS(631),
    [anon_sym_get] = ACTIONS(631),
    [anon_sym_set] = ACTIONS(631),
    [anon_sym_declare] = ACTIONS(633),
    [anon_sym_public] = ACTIONS(631),
    [anon_sym_private] = ACTIONS(631),
    [anon_sym_protected] = ACTIONS(631),
    [anon_sym_override] = ACTIONS(631),
    [anon_sym_module] = ACTIONS(635),
    [anon_sym_any] = ACTIONS(631),
    [anon_sym_number] = ACTIONS(631),
    [anon_sym_boolean] = ACTIONS(631),
    [anon_sym_string] = ACTIONS(631),
    [anon_sym_symbol] = ACTIONS(631),
    [anon_sym_object] = ACTIONS(631),
    [anon_sym_abstract] = ACTIONS(105),
    [anon_sym_interface] = ACTIONS(107),
    [anon_sym_enum] = ACTIONS(109),
    [sym_html_comment] = ACTIONS(5),
  },
  [47] = {
    [sym_export_statement] = STATE(892),
    [sym_declaration] = STATE(892),
    [sym_import] = STATE(3636),
    [sym_import_statement] = STATE(892),
    [sym_statement] = STATE(841),
    [sym_expression_statement] = STATE(892),
    [sym_variable_declaration] = STATE(831),
    [sym_lexical_declaration] = STATE(831),
    [sym_statement_block] = STATE(892),
    [sym_if_statement] = STATE(892),
    [sym_switch_statement] = STATE(892),
    [sym_for_statement] = STATE(892),
    [sym_for_in_statement] = STATE(892),
    [sym_while_statement] = STATE(892),
    [sym_do_statement] = STATE(892),
    [sym_try_statement] = STATE(892),
    [sym_with_statement] = STATE(892),
    [sym_break_statement] = STATE(892),
    [sym_continue_statement] = STATE(892),
    [sym_debugger_statement] = STATE(892),
    [sym_return_statement] = STATE(892),
    [sym_throw_statement] = STATE(892),
    [sym_empty_statement] = STATE(892),
    [sym_labeled_statement] = STATE(892),
    [sym_parenthesized_expression] = STATE(1362),
    [sym_expression] = STATE(1902),
    [sym_primary_expression] = STATE(1810),
    [sym_yield_expression] = STATE(2358),
    [sym_object] = STATE(2222),
    [sym_object_pattern] = STATE(5492),
    [sym_array] = STATE(2222),
    [sym_array_pattern] = STATE(5492),
    [sym_class] = STATE(2222),
    [sym_class_declaration] = STATE(831),
    [sym_function_expression] = STATE(2222),
    [sym_function_declaration] = STATE(831),
    [sym_generator_function] = STATE(2222),
    [sym_generator_function_declaration] = STATE(831),
    [sym_arrow_function] = STATE(2222),
    [sym__call_signature] = STATE(5821),
    [sym_call_expression] = STATE(2222),
    [sym_new_expression] = STATE(1948),
    [sym_await_expression] = STATE(2358),
    [sym_member_expression] = STATE(1362),
    [sym_subscript_expression] = STATE(1362),
    [sym_assignment_expression] = STATE(2358),
    [sym__augmented_assignment_lhs] = STATE(3025),
    [sym_augmented_assignment_expression] = STATE(2358),
    [sym__destructuring_pattern] = STATE(5492),
    [sym_ternary_expression] = STATE(2358),
    [sym_binary_expression] = STATE(2358),
    [sym_unary_expression] = STATE(2358),
    [sym_update_expression] = STATE(2358),
    [sym_sequence_expression] = STATE(5305),
    [sym_string] = STATE(2222),
    [sym_template_string] = STATE(2222),
    [sym_regex] = STATE(2222),
    [sym_meta_property] = STATE(2222),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1362),
    [sym_function_signature] = STATE(831),
    [sym_type_assertion] = STATE(2358),
    [sym_as_expression] = STATE(2358),
    [sym_satisfies_expression] = STATE(2358),
    [sym_instantiation_expression] = STATE(2358),
    [sym_ambient_declaration] = STATE(831),
    [sym_abstract_class_declaration] = STATE(831),
    [sym_module] = STATE(831),
    [sym_internal_module] = STATE(2513),
    [sym_import_alias] = STATE(831),
    [sym_interface_declaration] = STATE(831),
    [sym_enum_declaration] = STATE(831),
    [sym_type_alias_declaration] = STATE(831),
    [sym_type_arguments] = STATE(428),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(3830),
    [sym_identifier] = ACTIONS(603),
    [anon_sym_export] = ACTIONS(605),
    [anon_sym_type] = ACTIONS(607),
    [anon_sym_namespace] = ACTIONS(609),
    [anon_sym_LBRACE] = ACTIONS(611),
    [anon_sym_typeof] = ACTIONS(21),
    [anon_sym_import] = ACTIONS(23),
    [anon_sym_with] = ACTIONS(613),
    [anon_sym_var] = ACTIONS(27),
    [anon_sym_let] = ACTIONS(615),
    [anon_sym_const] = ACTIONS(31),
    [anon_sym_BANG] = ACTIONS(33),
    [anon_sym_if] = ACTIONS(617),
    [anon_sym_switch] = ACTIONS(37),
    [anon_sym_for] = ACTIONS(619),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_SEMI] = ACTIONS(43),
    [anon_sym_await] = ACTIONS(45),
    [anon_sym_while] = ACTIONS(621),
    [anon_sym_do] = ACTIONS(49),
    [anon_sym_try] = ACTIONS(51),
    [anon_sym_break] = ACTIONS(53),
    [anon_sym_continue] = ACTIONS(55),
    [anon_sym_debugger] = ACTIONS(57),
    [anon_sym_return] = ACTIONS(59),
    [anon_sym_throw] = ACTIONS(61),
    [anon_sym_yield] = ACTIONS(63),
    [anon_sym_LBRACK] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(623),
    [anon_sym_async] = ACTIONS(625),
    [anon_sym_function] = ACTIONS(627),
    [anon_sym_new] = ACTIONS(629),
    [anon_sym_using] = ACTIONS(75),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_SLASH] = ACTIONS(77),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(33),
    [anon_sym_void] = ACTIONS(21),
    [anon_sym_delete] = ACTIONS(21),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_DQUOTE] = ACTIONS(83),
    [anon_sym_SQUOTE] = ACTIONS(85),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(87),
    [sym_number] = ACTIONS(89),
    [sym_private_property_identifier] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(93),
    [sym_true] = ACTIONS(93),
    [sym_false] = ACTIONS(93),
    [sym_null] = ACTIONS(93),
    [sym_undefined] = ACTIONS(95),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(631),
    [anon_sym_readonly] = ACTIONS(631),
    [anon_sym_get] = ACTIONS(631),
    [anon_sym_set] = ACTIONS(631),
    [anon_sym_declare] = ACTIONS(633),
    [anon_sym_public] = ACTIONS(631),
    [anon_sym_private] = ACTIONS(631),
    [anon_sym_protected] = ACTIONS(631),
    [anon_sym_override] = ACTIONS(631),
    [anon_sym_module] = ACTIONS(635),
    [anon_sym_any] = ACTIONS(631),
    [anon_sym_number] = ACTIONS(631),
    [anon_sym_boolean] = ACTIONS(631),
    [anon_sym_string] = ACTIONS(631),
    [anon_sym_symbol] = ACTIONS(631),
    [anon_sym_object] = ACTIONS(631),
    [anon_sym_abstract] = ACTIONS(105),
    [anon_sym_interface] = ACTIONS(107),
    [anon_sym_enum] = ACTIONS(109),
    [sym_html_comment] = ACTIONS(5),
  },
  [48] = {
    [sym_export_statement] = STATE(892),
    [sym_declaration] = STATE(892),
    [sym_import] = STATE(3636),
    [sym_import_statement] = STATE(892),
    [sym_statement] = STATE(843),
    [sym_expression_statement] = STATE(892),
    [sym_variable_declaration] = STATE(831),
    [sym_lexical_declaration] = STATE(831),
    [sym_statement_block] = STATE(892),
    [sym_if_statement] = STATE(892),
    [sym_switch_statement] = STATE(892),
    [sym_for_statement] = STATE(892),
    [sym_for_in_statement] = STATE(892),
    [sym_while_statement] = STATE(892),
    [sym_do_statement] = STATE(892),
    [sym_try_statement] = STATE(892),
    [sym_with_statement] = STATE(892),
    [sym_break_statement] = STATE(892),
    [sym_continue_statement] = STATE(892),
    [sym_debugger_statement] = STATE(892),
    [sym_return_statement] = STATE(892),
    [sym_throw_statement] = STATE(892),
    [sym_empty_statement] = STATE(892),
    [sym_labeled_statement] = STATE(892),
    [sym_parenthesized_expression] = STATE(1362),
    [sym_expression] = STATE(1902),
    [sym_primary_expression] = STATE(1810),
    [sym_yield_expression] = STATE(2358),
    [sym_object] = STATE(2222),
    [sym_object_pattern] = STATE(5492),
    [sym_array] = STATE(2222),
    [sym_array_pattern] = STATE(5492),
    [sym_class] = STATE(2222),
    [sym_class_declaration] = STATE(831),
    [sym_function_expression] = STATE(2222),
    [sym_function_declaration] = STATE(831),
    [sym_generator_function] = STATE(2222),
    [sym_generator_function_declaration] = STATE(831),
    [sym_arrow_function] = STATE(2222),
    [sym__call_signature] = STATE(5821),
    [sym_call_expression] = STATE(2222),
    [sym_new_expression] = STATE(1948),
    [sym_await_expression] = STATE(2358),
    [sym_member_expression] = STATE(1362),
    [sym_subscript_expression] = STATE(1362),
    [sym_assignment_expression] = STATE(2358),
    [sym__augmented_assignment_lhs] = STATE(3025),
    [sym_augmented_assignment_expression] = STATE(2358),
    [sym__destructuring_pattern] = STATE(5492),
    [sym_ternary_expression] = STATE(2358),
    [sym_binary_expression] = STATE(2358),
    [sym_unary_expression] = STATE(2358),
    [sym_update_expression] = STATE(2358),
    [sym_sequence_expression] = STATE(5305),
    [sym_string] = STATE(2222),
    [sym_template_string] = STATE(2222),
    [sym_regex] = STATE(2222),
    [sym_meta_property] = STATE(2222),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1362),
    [sym_function_signature] = STATE(831),
    [sym_type_assertion] = STATE(2358),
    [sym_as_expression] = STATE(2358),
    [sym_satisfies_expression] = STATE(2358),
    [sym_instantiation_expression] = STATE(2358),
    [sym_ambient_declaration] = STATE(831),
    [sym_abstract_class_declaration] = STATE(831),
    [sym_module] = STATE(831),
    [sym_internal_module] = STATE(2513),
    [sym_import_alias] = STATE(831),
    [sym_interface_declaration] = STATE(831),
    [sym_enum_declaration] = STATE(831),
    [sym_type_alias_declaration] = STATE(831),
    [sym_type_arguments] = STATE(428),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(3830),
    [sym_identifier] = ACTIONS(603),
    [anon_sym_export] = ACTIONS(605),
    [anon_sym_type] = ACTIONS(607),
    [anon_sym_namespace] = ACTIONS(609),
    [anon_sym_LBRACE] = ACTIONS(611),
    [anon_sym_typeof] = ACTIONS(21),
    [anon_sym_import] = ACTIONS(23),
    [anon_sym_with] = ACTIONS(613),
    [anon_sym_var] = ACTIONS(27),
    [anon_sym_let] = ACTIONS(615),
    [anon_sym_const] = ACTIONS(31),
    [anon_sym_BANG] = ACTIONS(33),
    [anon_sym_if] = ACTIONS(617),
    [anon_sym_switch] = ACTIONS(37),
    [anon_sym_for] = ACTIONS(619),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_SEMI] = ACTIONS(43),
    [anon_sym_await] = ACTIONS(45),
    [anon_sym_while] = ACTIONS(621),
    [anon_sym_do] = ACTIONS(49),
    [anon_sym_try] = ACTIONS(51),
    [anon_sym_break] = ACTIONS(53),
    [anon_sym_continue] = ACTIONS(55),
    [anon_sym_debugger] = ACTIONS(57),
    [anon_sym_return] = ACTIONS(59),
    [anon_sym_throw] = ACTIONS(61),
    [anon_sym_yield] = ACTIONS(63),
    [anon_sym_LBRACK] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(623),
    [anon_sym_async] = ACTIONS(625),
    [anon_sym_function] = ACTIONS(627),
    [anon_sym_new] = ACTIONS(629),
    [anon_sym_using] = ACTIONS(75),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_SLASH] = ACTIONS(77),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(33),
    [anon_sym_void] = ACTIONS(21),
    [anon_sym_delete] = ACTIONS(21),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_DQUOTE] = ACTIONS(83),
    [anon_sym_SQUOTE] = ACTIONS(85),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(87),
    [sym_number] = ACTIONS(89),
    [sym_private_property_identifier] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(93),
    [sym_true] = ACTIONS(93),
    [sym_false] = ACTIONS(93),
    [sym_null] = ACTIONS(93),
    [sym_undefined] = ACTIONS(95),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(631),
    [anon_sym_readonly] = ACTIONS(631),
    [anon_sym_get] = ACTIONS(631),
    [anon_sym_set] = ACTIONS(631),
    [anon_sym_declare] = ACTIONS(633),
    [anon_sym_public] = ACTIONS(631),
    [anon_sym_private] = ACTIONS(631),
    [anon_sym_protected] = ACTIONS(631),
    [anon_sym_override] = ACTIONS(631),
    [anon_sym_module] = ACTIONS(635),
    [anon_sym_any] = ACTIONS(631),
    [anon_sym_number] = ACTIONS(631),
    [anon_sym_boolean] = ACTIONS(631),
    [anon_sym_string] = ACTIONS(631),
    [anon_sym_symbol] = ACTIONS(631),
    [anon_sym_object] = ACTIONS(631),
    [anon_sym_abstract] = ACTIONS(105),
    [anon_sym_interface] = ACTIONS(107),
    [anon_sym_enum] = ACTIONS(109),
    [sym_html_comment] = ACTIONS(5),
  },
  [49] = {
    [sym_export_statement] = STATE(892),
    [sym_declaration] = STATE(892),
    [sym_import] = STATE(3636),
    [sym_import_statement] = STATE(892),
    [sym_statement] = STATE(853),
    [sym_expression_statement] = STATE(892),
    [sym_variable_declaration] = STATE(831),
    [sym_lexical_declaration] = STATE(831),
    [sym_statement_block] = STATE(892),
    [sym_if_statement] = STATE(892),
    [sym_switch_statement] = STATE(892),
    [sym_for_statement] = STATE(892),
    [sym_for_in_statement] = STATE(892),
    [sym_while_statement] = STATE(892),
    [sym_do_statement] = STATE(892),
    [sym_try_statement] = STATE(892),
    [sym_with_statement] = STATE(892),
    [sym_break_statement] = STATE(892),
    [sym_continue_statement] = STATE(892),
    [sym_debugger_statement] = STATE(892),
    [sym_return_statement] = STATE(892),
    [sym_throw_statement] = STATE(892),
    [sym_empty_statement] = STATE(892),
    [sym_labeled_statement] = STATE(892),
    [sym_parenthesized_expression] = STATE(1362),
    [sym_expression] = STATE(1902),
    [sym_primary_expression] = STATE(1810),
    [sym_yield_expression] = STATE(2358),
    [sym_object] = STATE(2222),
    [sym_object_pattern] = STATE(5492),
    [sym_array] = STATE(2222),
    [sym_array_pattern] = STATE(5492),
    [sym_class] = STATE(2222),
    [sym_class_declaration] = STATE(831),
    [sym_function_expression] = STATE(2222),
    [sym_function_declaration] = STATE(831),
    [sym_generator_function] = STATE(2222),
    [sym_generator_function_declaration] = STATE(831),
    [sym_arrow_function] = STATE(2222),
    [sym__call_signature] = STATE(5821),
    [sym_call_expression] = STATE(2222),
    [sym_new_expression] = STATE(1948),
    [sym_await_expression] = STATE(2358),
    [sym_member_expression] = STATE(1362),
    [sym_subscript_expression] = STATE(1362),
    [sym_assignment_expression] = STATE(2358),
    [sym__augmented_assignment_lhs] = STATE(3025),
    [sym_augmented_assignment_expression] = STATE(2358),
    [sym__destructuring_pattern] = STATE(5492),
    [sym_ternary_expression] = STATE(2358),
    [sym_binary_expression] = STATE(2358),
    [sym_unary_expression] = STATE(2358),
    [sym_update_expression] = STATE(2358),
    [sym_sequence_expression] = STATE(5305),
    [sym_string] = STATE(2222),
    [sym_template_string] = STATE(2222),
    [sym_regex] = STATE(2222),
    [sym_meta_property] = STATE(2222),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1362),
    [sym_function_signature] = STATE(831),
    [sym_type_assertion] = STATE(2358),
    [sym_as_expression] = STATE(2358),
    [sym_satisfies_expression] = STATE(2358),
    [sym_instantiation_expression] = STATE(2358),
    [sym_ambient_declaration] = STATE(831),
    [sym_abstract_class_declaration] = STATE(831),
    [sym_module] = STATE(831),
    [sym_internal_module] = STATE(2513),
    [sym_import_alias] = STATE(831),
    [sym_interface_declaration] = STATE(831),
    [sym_enum_declaration] = STATE(831),
    [sym_type_alias_declaration] = STATE(831),
    [sym_type_arguments] = STATE(428),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(3830),
    [sym_identifier] = ACTIONS(603),
    [anon_sym_export] = ACTIONS(605),
    [anon_sym_type] = ACTIONS(607),
    [anon_sym_namespace] = ACTIONS(609),
    [anon_sym_LBRACE] = ACTIONS(611),
    [anon_sym_typeof] = ACTIONS(21),
    [anon_sym_import] = ACTIONS(23),
    [anon_sym_with] = ACTIONS(613),
    [anon_sym_var] = ACTIONS(27),
    [anon_sym_let] = ACTIONS(615),
    [anon_sym_const] = ACTIONS(31),
    [anon_sym_BANG] = ACTIONS(33),
    [anon_sym_if] = ACTIONS(617),
    [anon_sym_switch] = ACTIONS(37),
    [anon_sym_for] = ACTIONS(619),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_SEMI] = ACTIONS(43),
    [anon_sym_await] = ACTIONS(45),
    [anon_sym_while] = ACTIONS(621),
    [anon_sym_do] = ACTIONS(49),
    [anon_sym_try] = ACTIONS(51),
    [anon_sym_break] = ACTIONS(53),
    [anon_sym_continue] = ACTIONS(55),
    [anon_sym_debugger] = ACTIONS(57),
    [anon_sym_return] = ACTIONS(59),
    [anon_sym_throw] = ACTIONS(61),
    [anon_sym_yield] = ACTIONS(63),
    [anon_sym_LBRACK] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(623),
    [anon_sym_async] = ACTIONS(625),
    [anon_sym_function] = ACTIONS(627),
    [anon_sym_new] = ACTIONS(629),
    [anon_sym_using] = ACTIONS(75),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_SLASH] = ACTIONS(77),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(33),
    [anon_sym_void] = ACTIONS(21),
    [anon_sym_delete] = ACTIONS(21),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_DQUOTE] = ACTIONS(83),
    [anon_sym_SQUOTE] = ACTIONS(85),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(87),
    [sym_number] = ACTIONS(89),
    [sym_private_property_identifier] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(93),
    [sym_true] = ACTIONS(93),
    [sym_false] = ACTIONS(93),
    [sym_null] = ACTIONS(93),
    [sym_undefined] = ACTIONS(95),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(631),
    [anon_sym_readonly] = ACTIONS(631),
    [anon_sym_get] = ACTIONS(631),
    [anon_sym_set] = ACTIONS(631),
    [anon_sym_declare] = ACTIONS(633),
    [anon_sym_public] = ACTIONS(631),
    [anon_sym_private] = ACTIONS(631),
    [anon_sym_protected] = ACTIONS(631),
    [anon_sym_override] = ACTIONS(631),
    [anon_sym_module] = ACTIONS(635),
    [anon_sym_any] = ACTIONS(631),
    [anon_sym_number] = ACTIONS(631),
    [anon_sym_boolean] = ACTIONS(631),
    [anon_sym_string] = ACTIONS(631),
    [anon_sym_symbol] = ACTIONS(631),
    [anon_sym_object] = ACTIONS(631),
    [anon_sym_abstract] = ACTIONS(105),
    [anon_sym_interface] = ACTIONS(107),
    [anon_sym_enum] = ACTIONS(109),
    [sym_html_comment] = ACTIONS(5),
  },
  [50] = {
    [sym_export_statement] = STATE(892),
    [sym_declaration] = STATE(892),
    [sym_import] = STATE(3636),
    [sym_import_statement] = STATE(892),
    [sym_statement] = STATE(884),
    [sym_expression_statement] = STATE(892),
    [sym_variable_declaration] = STATE(831),
    [sym_lexical_declaration] = STATE(831),
    [sym_statement_block] = STATE(892),
    [sym_if_statement] = STATE(892),
    [sym_switch_statement] = STATE(892),
    [sym_for_statement] = STATE(892),
    [sym_for_in_statement] = STATE(892),
    [sym_while_statement] = STATE(892),
    [sym_do_statement] = STATE(892),
    [sym_try_statement] = STATE(892),
    [sym_with_statement] = STATE(892),
    [sym_break_statement] = STATE(892),
    [sym_continue_statement] = STATE(892),
    [sym_debugger_statement] = STATE(892),
    [sym_return_statement] = STATE(892),
    [sym_throw_statement] = STATE(892),
    [sym_empty_statement] = STATE(892),
    [sym_labeled_statement] = STATE(892),
    [sym_parenthesized_expression] = STATE(1362),
    [sym_expression] = STATE(1902),
    [sym_primary_expression] = STATE(1810),
    [sym_yield_expression] = STATE(2358),
    [sym_object] = STATE(2222),
    [sym_object_pattern] = STATE(5492),
    [sym_array] = STATE(2222),
    [sym_array_pattern] = STATE(5492),
    [sym_class] = STATE(2222),
    [sym_class_declaration] = STATE(831),
    [sym_function_expression] = STATE(2222),
    [sym_function_declaration] = STATE(831),
    [sym_generator_function] = STATE(2222),
    [sym_generator_function_declaration] = STATE(831),
    [sym_arrow_function] = STATE(2222),
    [sym__call_signature] = STATE(5821),
    [sym_call_expression] = STATE(2222),
    [sym_new_expression] = STATE(1948),
    [sym_await_expression] = STATE(2358),
    [sym_member_expression] = STATE(1362),
    [sym_subscript_expression] = STATE(1362),
    [sym_assignment_expression] = STATE(2358),
    [sym__augmented_assignment_lhs] = STATE(3025),
    [sym_augmented_assignment_expression] = STATE(2358),
    [sym__destructuring_pattern] = STATE(5492),
    [sym_ternary_expression] = STATE(2358),
    [sym_binary_expression] = STATE(2358),
    [sym_unary_expression] = STATE(2358),
    [sym_update_expression] = STATE(2358),
    [sym_sequence_expression] = STATE(5305),
    [sym_string] = STATE(2222),
    [sym_template_string] = STATE(2222),
    [sym_regex] = STATE(2222),
    [sym_meta_property] = STATE(2222),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1362),
    [sym_function_signature] = STATE(831),
    [sym_type_assertion] = STATE(2358),
    [sym_as_expression] = STATE(2358),
    [sym_satisfies_expression] = STATE(2358),
    [sym_instantiation_expression] = STATE(2358),
    [sym_ambient_declaration] = STATE(831),
    [sym_abstract_class_declaration] = STATE(831),
    [sym_module] = STATE(831),
    [sym_internal_module] = STATE(214),
    [sym_import_alias] = STATE(831),
    [sym_interface_declaration] = STATE(831),
    [sym_enum_declaration] = STATE(831),
    [sym_type_alias_declaration] = STATE(831),
    [sym_type_arguments] = STATE(428),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(3774),
    [sym_identifier] = ACTIONS(9),
    [anon_sym_export] = ACTIONS(13),
    [anon_sym_type] = ACTIONS(15),
    [anon_sym_namespace] = ACTIONS(17),
    [anon_sym_LBRACE] = ACTIONS(19),
    [anon_sym_typeof] = ACTIONS(21),
    [anon_sym_import] = ACTIONS(23),
    [anon_sym_with] = ACTIONS(25),
    [anon_sym_var] = ACTIONS(27),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_const] = ACTIONS(31),
    [anon_sym_BANG] = ACTIONS(33),
    [anon_sym_if] = ACTIONS(35),
    [anon_sym_switch] = ACTIONS(37),
    [anon_sym_for] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_SEMI] = ACTIONS(43),
    [anon_sym_await] = ACTIONS(45),
    [anon_sym_while] = ACTIONS(47),
    [anon_sym_do] = ACTIONS(49),
    [anon_sym_try] = ACTIONS(51),
    [anon_sym_break] = ACTIONS(53),
    [anon_sym_continue] = ACTIONS(55),
    [anon_sym_debugger] = ACTIONS(57),
    [anon_sym_return] = ACTIONS(59),
    [anon_sym_throw] = ACTIONS(61),
    [anon_sym_yield] = ACTIONS(63),
    [anon_sym_LBRACK] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(67),
    [anon_sym_async] = ACTIONS(69),
    [anon_sym_function] = ACTIONS(71),
    [anon_sym_new] = ACTIONS(73),
    [anon_sym_using] = ACTIONS(75),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_SLASH] = ACTIONS(77),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(33),
    [anon_sym_void] = ACTIONS(21),
    [anon_sym_delete] = ACTIONS(21),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_DQUOTE] = ACTIONS(83),
    [anon_sym_SQUOTE] = ACTIONS(85),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(87),
    [sym_number] = ACTIONS(89),
    [sym_private_property_identifier] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(93),
    [sym_true] = ACTIONS(93),
    [sym_false] = ACTIONS(93),
    [sym_null] = ACTIONS(93),
    [sym_undefined] = ACTIONS(95),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(99),
    [anon_sym_readonly] = ACTIONS(99),
    [anon_sym_get] = ACTIONS(99),
    [anon_sym_set] = ACTIONS(99),
    [anon_sym_declare] = ACTIONS(101),
    [anon_sym_public] = ACTIONS(99),
    [anon_sym_private] = ACTIONS(99),
    [anon_sym_protected] = ACTIONS(99),
    [anon_sym_override] = ACTIONS(99),
    [anon_sym_module] = ACTIONS(103),
    [anon_sym_any] = ACTIONS(99),
    [anon_sym_number] = ACTIONS(99),
    [anon_sym_boolean] = ACTIONS(99),
    [anon_sym_string] = ACTIONS(99),
    [anon_sym_symbol] = ACTIONS(99),
    [anon_sym_object] = ACTIONS(99),
    [anon_sym_abstract] = ACTIONS(105),
    [anon_sym_interface] = ACTIONS(107),
    [anon_sym_enum] = ACTIONS(109),
    [sym_html_comment] = ACTIONS(5),
  },
  [51] = {
    [sym_export_statement] = STATE(892),
    [sym_declaration] = STATE(892),
    [sym_import] = STATE(3636),
    [sym_import_statement] = STATE(892),
    [sym_statement] = STATE(874),
    [sym_expression_statement] = STATE(892),
    [sym_variable_declaration] = STATE(831),
    [sym_lexical_declaration] = STATE(831),
    [sym_statement_block] = STATE(892),
    [sym_if_statement] = STATE(892),
    [sym_switch_statement] = STATE(892),
    [sym_for_statement] = STATE(892),
    [sym_for_in_statement] = STATE(892),
    [sym_while_statement] = STATE(892),
    [sym_do_statement] = STATE(892),
    [sym_try_statement] = STATE(892),
    [sym_with_statement] = STATE(892),
    [sym_break_statement] = STATE(892),
    [sym_continue_statement] = STATE(892),
    [sym_debugger_statement] = STATE(892),
    [sym_return_statement] = STATE(892),
    [sym_throw_statement] = STATE(892),
    [sym_empty_statement] = STATE(892),
    [sym_labeled_statement] = STATE(892),
    [sym_parenthesized_expression] = STATE(1362),
    [sym_expression] = STATE(1902),
    [sym_primary_expression] = STATE(1810),
    [sym_yield_expression] = STATE(2358),
    [sym_object] = STATE(2222),
    [sym_object_pattern] = STATE(5492),
    [sym_array] = STATE(2222),
    [sym_array_pattern] = STATE(5492),
    [sym_class] = STATE(2222),
    [sym_class_declaration] = STATE(831),
    [sym_function_expression] = STATE(2222),
    [sym_function_declaration] = STATE(831),
    [sym_generator_function] = STATE(2222),
    [sym_generator_function_declaration] = STATE(831),
    [sym_arrow_function] = STATE(2222),
    [sym__call_signature] = STATE(5821),
    [sym_call_expression] = STATE(2222),
    [sym_new_expression] = STATE(1948),
    [sym_await_expression] = STATE(2358),
    [sym_member_expression] = STATE(1362),
    [sym_subscript_expression] = STATE(1362),
    [sym_assignment_expression] = STATE(2358),
    [sym__augmented_assignment_lhs] = STATE(3025),
    [sym_augmented_assignment_expression] = STATE(2358),
    [sym__destructuring_pattern] = STATE(5492),
    [sym_ternary_expression] = STATE(2358),
    [sym_binary_expression] = STATE(2358),
    [sym_unary_expression] = STATE(2358),
    [sym_update_expression] = STATE(2358),
    [sym_sequence_expression] = STATE(5305),
    [sym_string] = STATE(2222),
    [sym_template_string] = STATE(2222),
    [sym_regex] = STATE(2222),
    [sym_meta_property] = STATE(2222),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1362),
    [sym_function_signature] = STATE(831),
    [sym_type_assertion] = STATE(2358),
    [sym_as_expression] = STATE(2358),
    [sym_satisfies_expression] = STATE(2358),
    [sym_instantiation_expression] = STATE(2358),
    [sym_ambient_declaration] = STATE(831),
    [sym_abstract_class_declaration] = STATE(831),
    [sym_module] = STATE(831),
    [sym_internal_module] = STATE(214),
    [sym_import_alias] = STATE(831),
    [sym_interface_declaration] = STATE(831),
    [sym_enum_declaration] = STATE(831),
    [sym_type_alias_declaration] = STATE(831),
    [sym_type_arguments] = STATE(428),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(3774),
    [sym_identifier] = ACTIONS(9),
    [anon_sym_export] = ACTIONS(13),
    [anon_sym_type] = ACTIONS(15),
    [anon_sym_namespace] = ACTIONS(17),
    [anon_sym_LBRACE] = ACTIONS(19),
    [anon_sym_typeof] = ACTIONS(21),
    [anon_sym_import] = ACTIONS(23),
    [anon_sym_with] = ACTIONS(25),
    [anon_sym_var] = ACTIONS(27),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_const] = ACTIONS(31),
    [anon_sym_BANG] = ACTIONS(33),
    [anon_sym_if] = ACTIONS(35),
    [anon_sym_switch] = ACTIONS(37),
    [anon_sym_for] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_SEMI] = ACTIONS(43),
    [anon_sym_await] = ACTIONS(45),
    [anon_sym_while] = ACTIONS(47),
    [anon_sym_do] = ACTIONS(49),
    [anon_sym_try] = ACTIONS(51),
    [anon_sym_break] = ACTIONS(53),
    [anon_sym_continue] = ACTIONS(55),
    [anon_sym_debugger] = ACTIONS(57),
    [anon_sym_return] = ACTIONS(59),
    [anon_sym_throw] = ACTIONS(61),
    [anon_sym_yield] = ACTIONS(63),
    [anon_sym_LBRACK] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(67),
    [anon_sym_async] = ACTIONS(69),
    [anon_sym_function] = ACTIONS(71),
    [anon_sym_new] = ACTIONS(73),
    [anon_sym_using] = ACTIONS(75),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_SLASH] = ACTIONS(77),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(33),
    [anon_sym_void] = ACTIONS(21),
    [anon_sym_delete] = ACTIONS(21),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_DQUOTE] = ACTIONS(83),
    [anon_sym_SQUOTE] = ACTIONS(85),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(87),
    [sym_number] = ACTIONS(89),
    [sym_private_property_identifier] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(93),
    [sym_true] = ACTIONS(93),
    [sym_false] = ACTIONS(93),
    [sym_null] = ACTIONS(93),
    [sym_undefined] = ACTIONS(95),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(99),
    [anon_sym_readonly] = ACTIONS(99),
    [anon_sym_get] = ACTIONS(99),
    [anon_sym_set] = ACTIONS(99),
    [anon_sym_declare] = ACTIONS(101),
    [anon_sym_public] = ACTIONS(99),
    [anon_sym_private] = ACTIONS(99),
    [anon_sym_protected] = ACTIONS(99),
    [anon_sym_override] = ACTIONS(99),
    [anon_sym_module] = ACTIONS(103),
    [anon_sym_any] = ACTIONS(99),
    [anon_sym_number] = ACTIONS(99),
    [anon_sym_boolean] = ACTIONS(99),
    [anon_sym_string] = ACTIONS(99),
    [anon_sym_symbol] = ACTIONS(99),
    [anon_sym_object] = ACTIONS(99),
    [anon_sym_abstract] = ACTIONS(105),
    [anon_sym_interface] = ACTIONS(107),
    [anon_sym_enum] = ACTIONS(109),
    [sym_html_comment] = ACTIONS(5),
  },
  [52] = {
    [sym_export_statement] = STATE(892),
    [sym_declaration] = STATE(892),
    [sym_import] = STATE(3636),
    [sym_import_statement] = STATE(892),
    [sym_statement] = STATE(940),
    [sym_expression_statement] = STATE(892),
    [sym_variable_declaration] = STATE(831),
    [sym_lexical_declaration] = STATE(831),
    [sym_statement_block] = STATE(892),
    [sym_if_statement] = STATE(892),
    [sym_switch_statement] = STATE(892),
    [sym_for_statement] = STATE(892),
    [sym_for_in_statement] = STATE(892),
    [sym_while_statement] = STATE(892),
    [sym_do_statement] = STATE(892),
    [sym_try_statement] = STATE(892),
    [sym_with_statement] = STATE(892),
    [sym_break_statement] = STATE(892),
    [sym_continue_statement] = STATE(892),
    [sym_debugger_statement] = STATE(892),
    [sym_return_statement] = STATE(892),
    [sym_throw_statement] = STATE(892),
    [sym_empty_statement] = STATE(892),
    [sym_labeled_statement] = STATE(892),
    [sym_parenthesized_expression] = STATE(1362),
    [sym_expression] = STATE(1902),
    [sym_primary_expression] = STATE(1810),
    [sym_yield_expression] = STATE(2358),
    [sym_object] = STATE(2222),
    [sym_object_pattern] = STATE(5492),
    [sym_array] = STATE(2222),
    [sym_array_pattern] = STATE(5492),
    [sym_class] = STATE(2222),
    [sym_class_declaration] = STATE(831),
    [sym_function_expression] = STATE(2222),
    [sym_function_declaration] = STATE(831),
    [sym_generator_function] = STATE(2222),
    [sym_generator_function_declaration] = STATE(831),
    [sym_arrow_function] = STATE(2222),
    [sym__call_signature] = STATE(5821),
    [sym_call_expression] = STATE(2222),
    [sym_new_expression] = STATE(1948),
    [sym_await_expression] = STATE(2358),
    [sym_member_expression] = STATE(1362),
    [sym_subscript_expression] = STATE(1362),
    [sym_assignment_expression] = STATE(2358),
    [sym__augmented_assignment_lhs] = STATE(3025),
    [sym_augmented_assignment_expression] = STATE(2358),
    [sym__destructuring_pattern] = STATE(5492),
    [sym_ternary_expression] = STATE(2358),
    [sym_binary_expression] = STATE(2358),
    [sym_unary_expression] = STATE(2358),
    [sym_update_expression] = STATE(2358),
    [sym_sequence_expression] = STATE(5305),
    [sym_string] = STATE(2222),
    [sym_template_string] = STATE(2222),
    [sym_regex] = STATE(2222),
    [sym_meta_property] = STATE(2222),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1362),
    [sym_function_signature] = STATE(831),
    [sym_type_assertion] = STATE(2358),
    [sym_as_expression] = STATE(2358),
    [sym_satisfies_expression] = STATE(2358),
    [sym_instantiation_expression] = STATE(2358),
    [sym_ambient_declaration] = STATE(831),
    [sym_abstract_class_declaration] = STATE(831),
    [sym_module] = STATE(831),
    [sym_internal_module] = STATE(214),
    [sym_import_alias] = STATE(831),
    [sym_interface_declaration] = STATE(831),
    [sym_enum_declaration] = STATE(831),
    [sym_type_alias_declaration] = STATE(831),
    [sym_type_arguments] = STATE(428),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(3774),
    [sym_identifier] = ACTIONS(9),
    [anon_sym_export] = ACTIONS(13),
    [anon_sym_type] = ACTIONS(15),
    [anon_sym_namespace] = ACTIONS(17),
    [anon_sym_LBRACE] = ACTIONS(19),
    [anon_sym_typeof] = ACTIONS(21),
    [anon_sym_import] = ACTIONS(23),
    [anon_sym_with] = ACTIONS(25),
    [anon_sym_var] = ACTIONS(27),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_const] = ACTIONS(31),
    [anon_sym_BANG] = ACTIONS(33),
    [anon_sym_if] = ACTIONS(35),
    [anon_sym_switch] = ACTIONS(37),
    [anon_sym_for] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_SEMI] = ACTIONS(43),
    [anon_sym_await] = ACTIONS(45),
    [anon_sym_while] = ACTIONS(47),
    [anon_sym_do] = ACTIONS(49),
    [anon_sym_try] = ACTIONS(51),
    [anon_sym_break] = ACTIONS(53),
    [anon_sym_continue] = ACTIONS(55),
    [anon_sym_debugger] = ACTIONS(57),
    [anon_sym_return] = ACTIONS(59),
    [anon_sym_throw] = ACTIONS(61),
    [anon_sym_yield] = ACTIONS(63),
    [anon_sym_LBRACK] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(67),
    [anon_sym_async] = ACTIONS(69),
    [anon_sym_function] = ACTIONS(71),
    [anon_sym_new] = ACTIONS(73),
    [anon_sym_using] = ACTIONS(75),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_SLASH] = ACTIONS(77),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(33),
    [anon_sym_void] = ACTIONS(21),
    [anon_sym_delete] = ACTIONS(21),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_DQUOTE] = ACTIONS(83),
    [anon_sym_SQUOTE] = ACTIONS(85),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(87),
    [sym_number] = ACTIONS(89),
    [sym_private_property_identifier] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(93),
    [sym_true] = ACTIONS(93),
    [sym_false] = ACTIONS(93),
    [sym_null] = ACTIONS(93),
    [sym_undefined] = ACTIONS(95),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(99),
    [anon_sym_readonly] = ACTIONS(99),
    [anon_sym_get] = ACTIONS(99),
    [anon_sym_set] = ACTIONS(99),
    [anon_sym_declare] = ACTIONS(101),
    [anon_sym_public] = ACTIONS(99),
    [anon_sym_private] = ACTIONS(99),
    [anon_sym_protected] = ACTIONS(99),
    [anon_sym_override] = ACTIONS(99),
    [anon_sym_module] = ACTIONS(103),
    [anon_sym_any] = ACTIONS(99),
    [anon_sym_number] = ACTIONS(99),
    [anon_sym_boolean] = ACTIONS(99),
    [anon_sym_string] = ACTIONS(99),
    [anon_sym_symbol] = ACTIONS(99),
    [anon_sym_object] = ACTIONS(99),
    [anon_sym_abstract] = ACTIONS(105),
    [anon_sym_interface] = ACTIONS(107),
    [anon_sym_enum] = ACTIONS(109),
    [sym_html_comment] = ACTIONS(5),
  },
  [53] = {
    [sym_import] = STATE(3663),
    [sym_parenthesized_expression] = STATE(1322),
    [sym_expression] = STATE(2126),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(4425),
    [sym_assignment_pattern] = STATE(4969),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(4425),
    [sym_nested_identifier] = STATE(5474),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5508),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1396),
    [sym_subscript_expression] = STATE(1396),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3003),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(4425),
    [sym_spread_element] = STATE(4946),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(2213),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(4317),
    [sym_pattern] = STATE(4406),
    [sym_rest_pattern] = STATE(4115),
    [sym_non_null_expression] = STATE(1396),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_nested_type_identifier] = STATE(2939),
    [sym__type_query_member_expression_in_type_annotation] = STATE(3303),
    [sym__type_query_call_expression_in_type_annotation] = STATE(2938),
    [sym_type] = STATE(3773),
    [sym_tuple_parameter] = STATE(4568),
    [sym_optional_tuple_parameter] = STATE(4568),
    [sym_optional_type] = STATE(4568),
    [sym_rest_type] = STATE(4568),
    [sym__tuple_type_member] = STATE(4568),
    [sym_constructor_type] = STATE(3007),
    [sym_primary_type] = STATE(2981),
    [sym_template_literal_type] = STATE(3039),
    [sym_infer_type] = STATE(3007),
    [sym_conditional_type] = STATE(3039),
    [sym_generic_type] = STATE(3039),
    [sym_type_query] = STATE(3039),
    [sym_index_type_query] = STATE(3039),
    [sym_lookup_type] = STATE(3039),
    [sym_literal_type] = STATE(3039),
    [sym__number] = STATE(3041),
    [sym_existential_type] = STATE(3039),
    [sym_flow_maybe_type] = STATE(3039),
    [sym_parenthesized_type] = STATE(3039),
    [sym_predefined_type] = STATE(3039),
    [sym_type_arguments] = STATE(484),
    [sym_object_type] = STATE(3039),
    [sym_type_parameters] = STATE(5455),
    [sym_array_type] = STATE(3039),
    [sym_tuple_type] = STATE(3039),
    [sym_readonly_type] = STATE(3007),
    [sym_union_type] = STATE(3039),
    [sym_intersection_type] = STATE(3039),
    [sym_function_type] = STATE(3007),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [aux_sym_array_repeat1] = STATE(4955),
    [aux_sym_array_pattern_repeat1] = STATE(4977),
    [sym_identifier] = ACTIONS(539),
    [anon_sym_export] = ACTIONS(541),
    [anon_sym_STAR] = ACTIONS(543),
    [anon_sym_type] = ACTIONS(541),
    [anon_sym_namespace] = ACTIONS(545),
    [anon_sym_LBRACE] = ACTIONS(547),
    [anon_sym_COMMA] = ACTIONS(549),
    [anon_sym_typeof] = ACTIONS(551),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(541),
    [anon_sym_const] = ACTIONS(133),
    [anon_sym_BANG] = ACTIONS(553),
    [anon_sym_LPAREN] = ACTIONS(138),
    [anon_sym_await] = ACTIONS(555),
    [anon_sym_yield] = ACTIONS(557),
    [anon_sym_LBRACK] = ACTIONS(559),
    [anon_sym_RBRACK] = ACTIONS(641),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(563),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(565),
    [anon_sym_using] = ACTIONS(567),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(569),
    [anon_sym_AMP] = ACTIONS(571),
    [anon_sym_PIPE] = ACTIONS(573),
    [anon_sym_PLUS] = ACTIONS(575),
    [anon_sym_DASH] = ACTIONS(575),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(553),
    [anon_sym_void] = ACTIONS(579),
    [anon_sym_delete] = ACTIONS(581),
    [anon_sym_PLUS_PLUS] = ACTIONS(583),
    [anon_sym_DASH_DASH] = ACTIONS(583),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(188),
    [sym_number] = ACTIONS(190),
    [sym_private_property_identifier] = ACTIONS(585),
    [sym_this] = ACTIONS(587),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(198),
    [sym_false] = ACTIONS(198),
    [sym_null] = ACTIONS(198),
    [sym_undefined] = ACTIONS(589),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(541),
    [anon_sym_readonly] = ACTIONS(591),
    [anon_sym_get] = ACTIONS(541),
    [anon_sym_set] = ACTIONS(541),
    [anon_sym_QMARK] = ACTIONS(593),
    [anon_sym_declare] = ACTIONS(541),
    [anon_sym_public] = ACTIONS(541),
    [anon_sym_private] = ACTIONS(541),
    [anon_sym_protected] = ACTIONS(541),
    [anon_sym_override] = ACTIONS(541),
    [anon_sym_module] = ACTIONS(541),
    [anon_sym_any] = ACTIONS(595),
    [anon_sym_number] = ACTIONS(595),
    [anon_sym_boolean] = ACTIONS(595),
    [anon_sym_string] = ACTIONS(595),
    [anon_sym_symbol] = ACTIONS(595),
    [anon_sym_object] = ACTIONS(595),
    [anon_sym_abstract] = ACTIONS(597),
    [anon_sym_infer] = ACTIONS(599),
    [anon_sym_keyof] = ACTIONS(601),
    [anon_sym_unique] = ACTIONS(214),
    [anon_sym_unknown] = ACTIONS(216),
    [anon_sym_never] = ACTIONS(216),
    [anon_sym_LBRACE_PIPE] = ACTIONS(218),
    [sym_html_comment] = ACTIONS(5),
  },
  [54] = {
    [sym_export_statement] = STATE(892),
    [sym_declaration] = STATE(892),
    [sym_import] = STATE(3636),
    [sym_import_statement] = STATE(892),
    [sym_statement] = STATE(5539),
    [sym_expression_statement] = STATE(892),
    [sym_variable_declaration] = STATE(831),
    [sym_lexical_declaration] = STATE(831),
    [sym_statement_block] = STATE(892),
    [sym_if_statement] = STATE(892),
    [sym_switch_statement] = STATE(892),
    [sym_for_statement] = STATE(892),
    [sym_for_in_statement] = STATE(892),
    [sym_while_statement] = STATE(892),
    [sym_do_statement] = STATE(892),
    [sym_try_statement] = STATE(892),
    [sym_with_statement] = STATE(892),
    [sym_break_statement] = STATE(892),
    [sym_continue_statement] = STATE(892),
    [sym_debugger_statement] = STATE(892),
    [sym_return_statement] = STATE(892),
    [sym_throw_statement] = STATE(892),
    [sym_empty_statement] = STATE(892),
    [sym_labeled_statement] = STATE(892),
    [sym_parenthesized_expression] = STATE(1362),
    [sym_expression] = STATE(1902),
    [sym_primary_expression] = STATE(1810),
    [sym_yield_expression] = STATE(2358),
    [sym_object] = STATE(2222),
    [sym_object_pattern] = STATE(5492),
    [sym_array] = STATE(2222),
    [sym_array_pattern] = STATE(5492),
    [sym_class] = STATE(2222),
    [sym_class_declaration] = STATE(831),
    [sym_function_expression] = STATE(2222),
    [sym_function_declaration] = STATE(831),
    [sym_generator_function] = STATE(2222),
    [sym_generator_function_declaration] = STATE(831),
    [sym_arrow_function] = STATE(2222),
    [sym__call_signature] = STATE(5821),
    [sym_call_expression] = STATE(2222),
    [sym_new_expression] = STATE(1948),
    [sym_await_expression] = STATE(2358),
    [sym_member_expression] = STATE(1362),
    [sym_subscript_expression] = STATE(1362),
    [sym_assignment_expression] = STATE(2358),
    [sym__augmented_assignment_lhs] = STATE(3025),
    [sym_augmented_assignment_expression] = STATE(2358),
    [sym__destructuring_pattern] = STATE(5492),
    [sym_ternary_expression] = STATE(2358),
    [sym_binary_expression] = STATE(2358),
    [sym_unary_expression] = STATE(2358),
    [sym_update_expression] = STATE(2358),
    [sym_sequence_expression] = STATE(5305),
    [sym_string] = STATE(2222),
    [sym_template_string] = STATE(2222),
    [sym_regex] = STATE(2222),
    [sym_meta_property] = STATE(2222),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1362),
    [sym_function_signature] = STATE(831),
    [sym_type_assertion] = STATE(2358),
    [sym_as_expression] = STATE(2358),
    [sym_satisfies_expression] = STATE(2358),
    [sym_instantiation_expression] = STATE(2358),
    [sym_ambient_declaration] = STATE(831),
    [sym_abstract_class_declaration] = STATE(831),
    [sym_module] = STATE(831),
    [sym_internal_module] = STATE(2513),
    [sym_import_alias] = STATE(831),
    [sym_interface_declaration] = STATE(831),
    [sym_enum_declaration] = STATE(831),
    [sym_type_alias_declaration] = STATE(831),
    [sym_type_arguments] = STATE(428),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(3830),
    [sym_identifier] = ACTIONS(603),
    [anon_sym_export] = ACTIONS(605),
    [anon_sym_type] = ACTIONS(607),
    [anon_sym_namespace] = ACTIONS(609),
    [anon_sym_LBRACE] = ACTIONS(611),
    [anon_sym_typeof] = ACTIONS(21),
    [anon_sym_import] = ACTIONS(23),
    [anon_sym_with] = ACTIONS(613),
    [anon_sym_var] = ACTIONS(27),
    [anon_sym_let] = ACTIONS(615),
    [anon_sym_const] = ACTIONS(31),
    [anon_sym_BANG] = ACTIONS(33),
    [anon_sym_if] = ACTIONS(617),
    [anon_sym_switch] = ACTIONS(37),
    [anon_sym_for] = ACTIONS(619),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_SEMI] = ACTIONS(43),
    [anon_sym_await] = ACTIONS(45),
    [anon_sym_while] = ACTIONS(621),
    [anon_sym_do] = ACTIONS(49),
    [anon_sym_try] = ACTIONS(51),
    [anon_sym_break] = ACTIONS(53),
    [anon_sym_continue] = ACTIONS(55),
    [anon_sym_debugger] = ACTIONS(57),
    [anon_sym_return] = ACTIONS(59),
    [anon_sym_throw] = ACTIONS(61),
    [anon_sym_yield] = ACTIONS(63),
    [anon_sym_LBRACK] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(623),
    [anon_sym_async] = ACTIONS(625),
    [anon_sym_function] = ACTIONS(627),
    [anon_sym_new] = ACTIONS(629),
    [anon_sym_using] = ACTIONS(75),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_SLASH] = ACTIONS(77),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(33),
    [anon_sym_void] = ACTIONS(21),
    [anon_sym_delete] = ACTIONS(21),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_DQUOTE] = ACTIONS(83),
    [anon_sym_SQUOTE] = ACTIONS(85),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(87),
    [sym_number] = ACTIONS(89),
    [sym_private_property_identifier] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(93),
    [sym_true] = ACTIONS(93),
    [sym_false] = ACTIONS(93),
    [sym_null] = ACTIONS(93),
    [sym_undefined] = ACTIONS(95),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(631),
    [anon_sym_readonly] = ACTIONS(631),
    [anon_sym_get] = ACTIONS(631),
    [anon_sym_set] = ACTIONS(631),
    [anon_sym_declare] = ACTIONS(633),
    [anon_sym_public] = ACTIONS(631),
    [anon_sym_private] = ACTIONS(631),
    [anon_sym_protected] = ACTIONS(631),
    [anon_sym_override] = ACTIONS(631),
    [anon_sym_module] = ACTIONS(635),
    [anon_sym_any] = ACTIONS(631),
    [anon_sym_number] = ACTIONS(631),
    [anon_sym_boolean] = ACTIONS(631),
    [anon_sym_string] = ACTIONS(631),
    [anon_sym_symbol] = ACTIONS(631),
    [anon_sym_object] = ACTIONS(631),
    [anon_sym_abstract] = ACTIONS(105),
    [anon_sym_interface] = ACTIONS(107),
    [anon_sym_enum] = ACTIONS(109),
    [sym_html_comment] = ACTIONS(5),
  },
  [55] = {
    [sym_export_statement] = STATE(892),
    [sym_declaration] = STATE(892),
    [sym_import] = STATE(3636),
    [sym_import_statement] = STATE(892),
    [sym_statement] = STATE(815),
    [sym_expression_statement] = STATE(892),
    [sym_variable_declaration] = STATE(831),
    [sym_lexical_declaration] = STATE(831),
    [sym_statement_block] = STATE(892),
    [sym_if_statement] = STATE(892),
    [sym_switch_statement] = STATE(892),
    [sym_for_statement] = STATE(892),
    [sym_for_in_statement] = STATE(892),
    [sym_while_statement] = STATE(892),
    [sym_do_statement] = STATE(892),
    [sym_try_statement] = STATE(892),
    [sym_with_statement] = STATE(892),
    [sym_break_statement] = STATE(892),
    [sym_continue_statement] = STATE(892),
    [sym_debugger_statement] = STATE(892),
    [sym_return_statement] = STATE(892),
    [sym_throw_statement] = STATE(892),
    [sym_empty_statement] = STATE(892),
    [sym_labeled_statement] = STATE(892),
    [sym_parenthesized_expression] = STATE(1362),
    [sym_expression] = STATE(1902),
    [sym_primary_expression] = STATE(1810),
    [sym_yield_expression] = STATE(2358),
    [sym_object] = STATE(2222),
    [sym_object_pattern] = STATE(5492),
    [sym_array] = STATE(2222),
    [sym_array_pattern] = STATE(5492),
    [sym_class] = STATE(2222),
    [sym_class_declaration] = STATE(831),
    [sym_function_expression] = STATE(2222),
    [sym_function_declaration] = STATE(831),
    [sym_generator_function] = STATE(2222),
    [sym_generator_function_declaration] = STATE(831),
    [sym_arrow_function] = STATE(2222),
    [sym__call_signature] = STATE(5821),
    [sym_call_expression] = STATE(2222),
    [sym_new_expression] = STATE(1948),
    [sym_await_expression] = STATE(2358),
    [sym_member_expression] = STATE(1362),
    [sym_subscript_expression] = STATE(1362),
    [sym_assignment_expression] = STATE(2358),
    [sym__augmented_assignment_lhs] = STATE(3025),
    [sym_augmented_assignment_expression] = STATE(2358),
    [sym__destructuring_pattern] = STATE(5492),
    [sym_ternary_expression] = STATE(2358),
    [sym_binary_expression] = STATE(2358),
    [sym_unary_expression] = STATE(2358),
    [sym_update_expression] = STATE(2358),
    [sym_sequence_expression] = STATE(5305),
    [sym_string] = STATE(2222),
    [sym_template_string] = STATE(2222),
    [sym_regex] = STATE(2222),
    [sym_meta_property] = STATE(2222),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1362),
    [sym_function_signature] = STATE(831),
    [sym_type_assertion] = STATE(2358),
    [sym_as_expression] = STATE(2358),
    [sym_satisfies_expression] = STATE(2358),
    [sym_instantiation_expression] = STATE(2358),
    [sym_ambient_declaration] = STATE(831),
    [sym_abstract_class_declaration] = STATE(831),
    [sym_module] = STATE(831),
    [sym_internal_module] = STATE(214),
    [sym_import_alias] = STATE(831),
    [sym_interface_declaration] = STATE(831),
    [sym_enum_declaration] = STATE(831),
    [sym_type_alias_declaration] = STATE(831),
    [sym_type_arguments] = STATE(428),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(3774),
    [sym_identifier] = ACTIONS(9),
    [anon_sym_export] = ACTIONS(13),
    [anon_sym_type] = ACTIONS(15),
    [anon_sym_namespace] = ACTIONS(17),
    [anon_sym_LBRACE] = ACTIONS(19),
    [anon_sym_typeof] = ACTIONS(21),
    [anon_sym_import] = ACTIONS(23),
    [anon_sym_with] = ACTIONS(25),
    [anon_sym_var] = ACTIONS(27),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_const] = ACTIONS(31),
    [anon_sym_BANG] = ACTIONS(33),
    [anon_sym_if] = ACTIONS(35),
    [anon_sym_switch] = ACTIONS(37),
    [anon_sym_for] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_SEMI] = ACTIONS(43),
    [anon_sym_await] = ACTIONS(45),
    [anon_sym_while] = ACTIONS(47),
    [anon_sym_do] = ACTIONS(49),
    [anon_sym_try] = ACTIONS(51),
    [anon_sym_break] = ACTIONS(53),
    [anon_sym_continue] = ACTIONS(55),
    [anon_sym_debugger] = ACTIONS(57),
    [anon_sym_return] = ACTIONS(59),
    [anon_sym_throw] = ACTIONS(61),
    [anon_sym_yield] = ACTIONS(63),
    [anon_sym_LBRACK] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(67),
    [anon_sym_async] = ACTIONS(69),
    [anon_sym_function] = ACTIONS(71),
    [anon_sym_new] = ACTIONS(73),
    [anon_sym_using] = ACTIONS(75),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_SLASH] = ACTIONS(77),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(33),
    [anon_sym_void] = ACTIONS(21),
    [anon_sym_delete] = ACTIONS(21),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_DQUOTE] = ACTIONS(83),
    [anon_sym_SQUOTE] = ACTIONS(85),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(87),
    [sym_number] = ACTIONS(89),
    [sym_private_property_identifier] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(93),
    [sym_true] = ACTIONS(93),
    [sym_false] = ACTIONS(93),
    [sym_null] = ACTIONS(93),
    [sym_undefined] = ACTIONS(95),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(99),
    [anon_sym_readonly] = ACTIONS(99),
    [anon_sym_get] = ACTIONS(99),
    [anon_sym_set] = ACTIONS(99),
    [anon_sym_declare] = ACTIONS(101),
    [anon_sym_public] = ACTIONS(99),
    [anon_sym_private] = ACTIONS(99),
    [anon_sym_protected] = ACTIONS(99),
    [anon_sym_override] = ACTIONS(99),
    [anon_sym_module] = ACTIONS(103),
    [anon_sym_any] = ACTIONS(99),
    [anon_sym_number] = ACTIONS(99),
    [anon_sym_boolean] = ACTIONS(99),
    [anon_sym_string] = ACTIONS(99),
    [anon_sym_symbol] = ACTIONS(99),
    [anon_sym_object] = ACTIONS(99),
    [anon_sym_abstract] = ACTIONS(105),
    [anon_sym_interface] = ACTIONS(107),
    [anon_sym_enum] = ACTIONS(109),
    [sym_html_comment] = ACTIONS(5),
  },
  [56] = {
    [sym_import] = STATE(3663),
    [sym_parenthesized_expression] = STATE(1322),
    [sym_expression] = STATE(2126),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(4425),
    [sym_assignment_pattern] = STATE(4969),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(4425),
    [sym_nested_identifier] = STATE(5474),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5508),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1396),
    [sym_subscript_expression] = STATE(1396),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3003),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(4425),
    [sym_spread_element] = STATE(4946),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(2213),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(4317),
    [sym_pattern] = STATE(4406),
    [sym_rest_pattern] = STATE(4115),
    [sym_non_null_expression] = STATE(1396),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_nested_type_identifier] = STATE(2939),
    [sym__type_query_member_expression_in_type_annotation] = STATE(3303),
    [sym__type_query_call_expression_in_type_annotation] = STATE(2938),
    [sym_type] = STATE(3773),
    [sym_tuple_parameter] = STATE(4568),
    [sym_optional_tuple_parameter] = STATE(4568),
    [sym_optional_type] = STATE(4568),
    [sym_rest_type] = STATE(4568),
    [sym__tuple_type_member] = STATE(4568),
    [sym_constructor_type] = STATE(3007),
    [sym_primary_type] = STATE(2981),
    [sym_template_literal_type] = STATE(3039),
    [sym_infer_type] = STATE(3007),
    [sym_conditional_type] = STATE(3039),
    [sym_generic_type] = STATE(3039),
    [sym_type_query] = STATE(3039),
    [sym_index_type_query] = STATE(3039),
    [sym_lookup_type] = STATE(3039),
    [sym_literal_type] = STATE(3039),
    [sym__number] = STATE(3041),
    [sym_existential_type] = STATE(3039),
    [sym_flow_maybe_type] = STATE(3039),
    [sym_parenthesized_type] = STATE(3039),
    [sym_predefined_type] = STATE(3039),
    [sym_type_arguments] = STATE(484),
    [sym_object_type] = STATE(3039),
    [sym_type_parameters] = STATE(5455),
    [sym_array_type] = STATE(3039),
    [sym_tuple_type] = STATE(3039),
    [sym_readonly_type] = STATE(3007),
    [sym_union_type] = STATE(3039),
    [sym_intersection_type] = STATE(3039),
    [sym_function_type] = STATE(3007),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [aux_sym_array_repeat1] = STATE(4955),
    [aux_sym_array_pattern_repeat1] = STATE(4977),
    [sym_identifier] = ACTIONS(539),
    [anon_sym_export] = ACTIONS(541),
    [anon_sym_STAR] = ACTIONS(543),
    [anon_sym_type] = ACTIONS(541),
    [anon_sym_namespace] = ACTIONS(545),
    [anon_sym_LBRACE] = ACTIONS(547),
    [anon_sym_COMMA] = ACTIONS(549),
    [anon_sym_typeof] = ACTIONS(551),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(541),
    [anon_sym_const] = ACTIONS(133),
    [anon_sym_BANG] = ACTIONS(553),
    [anon_sym_LPAREN] = ACTIONS(138),
    [anon_sym_await] = ACTIONS(555),
    [anon_sym_yield] = ACTIONS(557),
    [anon_sym_LBRACK] = ACTIONS(559),
    [anon_sym_RBRACK] = ACTIONS(643),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(563),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(565),
    [anon_sym_using] = ACTIONS(567),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(569),
    [anon_sym_AMP] = ACTIONS(571),
    [anon_sym_PIPE] = ACTIONS(573),
    [anon_sym_PLUS] = ACTIONS(575),
    [anon_sym_DASH] = ACTIONS(575),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(553),
    [anon_sym_void] = ACTIONS(579),
    [anon_sym_delete] = ACTIONS(581),
    [anon_sym_PLUS_PLUS] = ACTIONS(583),
    [anon_sym_DASH_DASH] = ACTIONS(583),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(188),
    [sym_number] = ACTIONS(190),
    [sym_private_property_identifier] = ACTIONS(585),
    [sym_this] = ACTIONS(587),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(198),
    [sym_false] = ACTIONS(198),
    [sym_null] = ACTIONS(198),
    [sym_undefined] = ACTIONS(589),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(541),
    [anon_sym_readonly] = ACTIONS(591),
    [anon_sym_get] = ACTIONS(541),
    [anon_sym_set] = ACTIONS(541),
    [anon_sym_QMARK] = ACTIONS(593),
    [anon_sym_declare] = ACTIONS(541),
    [anon_sym_public] = ACTIONS(541),
    [anon_sym_private] = ACTIONS(541),
    [anon_sym_protected] = ACTIONS(541),
    [anon_sym_override] = ACTIONS(541),
    [anon_sym_module] = ACTIONS(541),
    [anon_sym_any] = ACTIONS(595),
    [anon_sym_number] = ACTIONS(595),
    [anon_sym_boolean] = ACTIONS(595),
    [anon_sym_string] = ACTIONS(595),
    [anon_sym_symbol] = ACTIONS(595),
    [anon_sym_object] = ACTIONS(595),
    [anon_sym_abstract] = ACTIONS(597),
    [anon_sym_infer] = ACTIONS(599),
    [anon_sym_keyof] = ACTIONS(601),
    [anon_sym_unique] = ACTIONS(214),
    [anon_sym_unknown] = ACTIONS(216),
    [anon_sym_never] = ACTIONS(216),
    [anon_sym_LBRACE_PIPE] = ACTIONS(218),
    [sym_html_comment] = ACTIONS(5),
  },
  [57] = {
    [sym_export_statement] = STATE(892),
    [sym_declaration] = STATE(892),
    [sym_import] = STATE(3636),
    [sym_import_statement] = STATE(892),
    [sym_statement] = STATE(943),
    [sym_expression_statement] = STATE(892),
    [sym_variable_declaration] = STATE(831),
    [sym_lexical_declaration] = STATE(831),
    [sym_statement_block] = STATE(892),
    [sym_if_statement] = STATE(892),
    [sym_switch_statement] = STATE(892),
    [sym_for_statement] = STATE(892),
    [sym_for_in_statement] = STATE(892),
    [sym_while_statement] = STATE(892),
    [sym_do_statement] = STATE(892),
    [sym_try_statement] = STATE(892),
    [sym_with_statement] = STATE(892),
    [sym_break_statement] = STATE(892),
    [sym_continue_statement] = STATE(892),
    [sym_debugger_statement] = STATE(892),
    [sym_return_statement] = STATE(892),
    [sym_throw_statement] = STATE(892),
    [sym_empty_statement] = STATE(892),
    [sym_labeled_statement] = STATE(892),
    [sym_parenthesized_expression] = STATE(1362),
    [sym_expression] = STATE(1902),
    [sym_primary_expression] = STATE(1810),
    [sym_yield_expression] = STATE(2358),
    [sym_object] = STATE(2222),
    [sym_object_pattern] = STATE(5492),
    [sym_array] = STATE(2222),
    [sym_array_pattern] = STATE(5492),
    [sym_class] = STATE(2222),
    [sym_class_declaration] = STATE(831),
    [sym_function_expression] = STATE(2222),
    [sym_function_declaration] = STATE(831),
    [sym_generator_function] = STATE(2222),
    [sym_generator_function_declaration] = STATE(831),
    [sym_arrow_function] = STATE(2222),
    [sym__call_signature] = STATE(5821),
    [sym_call_expression] = STATE(2222),
    [sym_new_expression] = STATE(1948),
    [sym_await_expression] = STATE(2358),
    [sym_member_expression] = STATE(1362),
    [sym_subscript_expression] = STATE(1362),
    [sym_assignment_expression] = STATE(2358),
    [sym__augmented_assignment_lhs] = STATE(3025),
    [sym_augmented_assignment_expression] = STATE(2358),
    [sym__destructuring_pattern] = STATE(5492),
    [sym_ternary_expression] = STATE(2358),
    [sym_binary_expression] = STATE(2358),
    [sym_unary_expression] = STATE(2358),
    [sym_update_expression] = STATE(2358),
    [sym_sequence_expression] = STATE(5305),
    [sym_string] = STATE(2222),
    [sym_template_string] = STATE(2222),
    [sym_regex] = STATE(2222),
    [sym_meta_property] = STATE(2222),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1362),
    [sym_function_signature] = STATE(831),
    [sym_type_assertion] = STATE(2358),
    [sym_as_expression] = STATE(2358),
    [sym_satisfies_expression] = STATE(2358),
    [sym_instantiation_expression] = STATE(2358),
    [sym_ambient_declaration] = STATE(831),
    [sym_abstract_class_declaration] = STATE(831),
    [sym_module] = STATE(831),
    [sym_internal_module] = STATE(214),
    [sym_import_alias] = STATE(831),
    [sym_interface_declaration] = STATE(831),
    [sym_enum_declaration] = STATE(831),
    [sym_type_alias_declaration] = STATE(831),
    [sym_type_arguments] = STATE(428),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(3774),
    [sym_identifier] = ACTIONS(9),
    [anon_sym_export] = ACTIONS(13),
    [anon_sym_type] = ACTIONS(15),
    [anon_sym_namespace] = ACTIONS(17),
    [anon_sym_LBRACE] = ACTIONS(19),
    [anon_sym_typeof] = ACTIONS(21),
    [anon_sym_import] = ACTIONS(23),
    [anon_sym_with] = ACTIONS(25),
    [anon_sym_var] = ACTIONS(27),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_const] = ACTIONS(31),
    [anon_sym_BANG] = ACTIONS(33),
    [anon_sym_if] = ACTIONS(35),
    [anon_sym_switch] = ACTIONS(37),
    [anon_sym_for] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_SEMI] = ACTIONS(43),
    [anon_sym_await] = ACTIONS(45),
    [anon_sym_while] = ACTIONS(47),
    [anon_sym_do] = ACTIONS(49),
    [anon_sym_try] = ACTIONS(51),
    [anon_sym_break] = ACTIONS(53),
    [anon_sym_continue] = ACTIONS(55),
    [anon_sym_debugger] = ACTIONS(57),
    [anon_sym_return] = ACTIONS(59),
    [anon_sym_throw] = ACTIONS(61),
    [anon_sym_yield] = ACTIONS(63),
    [anon_sym_LBRACK] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(67),
    [anon_sym_async] = ACTIONS(69),
    [anon_sym_function] = ACTIONS(71),
    [anon_sym_new] = ACTIONS(73),
    [anon_sym_using] = ACTIONS(75),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_SLASH] = ACTIONS(77),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(33),
    [anon_sym_void] = ACTIONS(21),
    [anon_sym_delete] = ACTIONS(21),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_DQUOTE] = ACTIONS(83),
    [anon_sym_SQUOTE] = ACTIONS(85),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(87),
    [sym_number] = ACTIONS(89),
    [sym_private_property_identifier] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(93),
    [sym_true] = ACTIONS(93),
    [sym_false] = ACTIONS(93),
    [sym_null] = ACTIONS(93),
    [sym_undefined] = ACTIONS(95),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(99),
    [anon_sym_readonly] = ACTIONS(99),
    [anon_sym_get] = ACTIONS(99),
    [anon_sym_set] = ACTIONS(99),
    [anon_sym_declare] = ACTIONS(101),
    [anon_sym_public] = ACTIONS(99),
    [anon_sym_private] = ACTIONS(99),
    [anon_sym_protected] = ACTIONS(99),
    [anon_sym_override] = ACTIONS(99),
    [anon_sym_module] = ACTIONS(103),
    [anon_sym_any] = ACTIONS(99),
    [anon_sym_number] = ACTIONS(99),
    [anon_sym_boolean] = ACTIONS(99),
    [anon_sym_string] = ACTIONS(99),
    [anon_sym_symbol] = ACTIONS(99),
    [anon_sym_object] = ACTIONS(99),
    [anon_sym_abstract] = ACTIONS(105),
    [anon_sym_interface] = ACTIONS(107),
    [anon_sym_enum] = ACTIONS(109),
    [sym_html_comment] = ACTIONS(5),
  },
  [58] = {
    [sym_export_statement] = STATE(892),
    [sym_declaration] = STATE(892),
    [sym_import] = STATE(3636),
    [sym_import_statement] = STATE(892),
    [sym_statement] = STATE(819),
    [sym_expression_statement] = STATE(892),
    [sym_variable_declaration] = STATE(831),
    [sym_lexical_declaration] = STATE(831),
    [sym_statement_block] = STATE(892),
    [sym_if_statement] = STATE(892),
    [sym_switch_statement] = STATE(892),
    [sym_for_statement] = STATE(892),
    [sym_for_in_statement] = STATE(892),
    [sym_while_statement] = STATE(892),
    [sym_do_statement] = STATE(892),
    [sym_try_statement] = STATE(892),
    [sym_with_statement] = STATE(892),
    [sym_break_statement] = STATE(892),
    [sym_continue_statement] = STATE(892),
    [sym_debugger_statement] = STATE(892),
    [sym_return_statement] = STATE(892),
    [sym_throw_statement] = STATE(892),
    [sym_empty_statement] = STATE(892),
    [sym_labeled_statement] = STATE(892),
    [sym_parenthesized_expression] = STATE(1362),
    [sym_expression] = STATE(1902),
    [sym_primary_expression] = STATE(1810),
    [sym_yield_expression] = STATE(2358),
    [sym_object] = STATE(2222),
    [sym_object_pattern] = STATE(5492),
    [sym_array] = STATE(2222),
    [sym_array_pattern] = STATE(5492),
    [sym_class] = STATE(2222),
    [sym_class_declaration] = STATE(831),
    [sym_function_expression] = STATE(2222),
    [sym_function_declaration] = STATE(831),
    [sym_generator_function] = STATE(2222),
    [sym_generator_function_declaration] = STATE(831),
    [sym_arrow_function] = STATE(2222),
    [sym__call_signature] = STATE(5821),
    [sym_call_expression] = STATE(2222),
    [sym_new_expression] = STATE(1948),
    [sym_await_expression] = STATE(2358),
    [sym_member_expression] = STATE(1362),
    [sym_subscript_expression] = STATE(1362),
    [sym_assignment_expression] = STATE(2358),
    [sym__augmented_assignment_lhs] = STATE(3025),
    [sym_augmented_assignment_expression] = STATE(2358),
    [sym__destructuring_pattern] = STATE(5492),
    [sym_ternary_expression] = STATE(2358),
    [sym_binary_expression] = STATE(2358),
    [sym_unary_expression] = STATE(2358),
    [sym_update_expression] = STATE(2358),
    [sym_sequence_expression] = STATE(5305),
    [sym_string] = STATE(2222),
    [sym_template_string] = STATE(2222),
    [sym_regex] = STATE(2222),
    [sym_meta_property] = STATE(2222),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1362),
    [sym_function_signature] = STATE(831),
    [sym_type_assertion] = STATE(2358),
    [sym_as_expression] = STATE(2358),
    [sym_satisfies_expression] = STATE(2358),
    [sym_instantiation_expression] = STATE(2358),
    [sym_ambient_declaration] = STATE(831),
    [sym_abstract_class_declaration] = STATE(831),
    [sym_module] = STATE(831),
    [sym_internal_module] = STATE(214),
    [sym_import_alias] = STATE(831),
    [sym_interface_declaration] = STATE(831),
    [sym_enum_declaration] = STATE(831),
    [sym_type_alias_declaration] = STATE(831),
    [sym_type_arguments] = STATE(428),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(3774),
    [sym_identifier] = ACTIONS(9),
    [anon_sym_export] = ACTIONS(13),
    [anon_sym_type] = ACTIONS(15),
    [anon_sym_namespace] = ACTIONS(17),
    [anon_sym_LBRACE] = ACTIONS(19),
    [anon_sym_typeof] = ACTIONS(21),
    [anon_sym_import] = ACTIONS(23),
    [anon_sym_with] = ACTIONS(25),
    [anon_sym_var] = ACTIONS(27),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_const] = ACTIONS(31),
    [anon_sym_BANG] = ACTIONS(33),
    [anon_sym_if] = ACTIONS(35),
    [anon_sym_switch] = ACTIONS(37),
    [anon_sym_for] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_SEMI] = ACTIONS(43),
    [anon_sym_await] = ACTIONS(45),
    [anon_sym_while] = ACTIONS(47),
    [anon_sym_do] = ACTIONS(49),
    [anon_sym_try] = ACTIONS(51),
    [anon_sym_break] = ACTIONS(53),
    [anon_sym_continue] = ACTIONS(55),
    [anon_sym_debugger] = ACTIONS(57),
    [anon_sym_return] = ACTIONS(59),
    [anon_sym_throw] = ACTIONS(61),
    [anon_sym_yield] = ACTIONS(63),
    [anon_sym_LBRACK] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(67),
    [anon_sym_async] = ACTIONS(69),
    [anon_sym_function] = ACTIONS(71),
    [anon_sym_new] = ACTIONS(73),
    [anon_sym_using] = ACTIONS(75),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_SLASH] = ACTIONS(77),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(33),
    [anon_sym_void] = ACTIONS(21),
    [anon_sym_delete] = ACTIONS(21),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_DQUOTE] = ACTIONS(83),
    [anon_sym_SQUOTE] = ACTIONS(85),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(87),
    [sym_number] = ACTIONS(89),
    [sym_private_property_identifier] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(93),
    [sym_true] = ACTIONS(93),
    [sym_false] = ACTIONS(93),
    [sym_null] = ACTIONS(93),
    [sym_undefined] = ACTIONS(95),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(99),
    [anon_sym_readonly] = ACTIONS(99),
    [anon_sym_get] = ACTIONS(99),
    [anon_sym_set] = ACTIONS(99),
    [anon_sym_declare] = ACTIONS(101),
    [anon_sym_public] = ACTIONS(99),
    [anon_sym_private] = ACTIONS(99),
    [anon_sym_protected] = ACTIONS(99),
    [anon_sym_override] = ACTIONS(99),
    [anon_sym_module] = ACTIONS(103),
    [anon_sym_any] = ACTIONS(99),
    [anon_sym_number] = ACTIONS(99),
    [anon_sym_boolean] = ACTIONS(99),
    [anon_sym_string] = ACTIONS(99),
    [anon_sym_symbol] = ACTIONS(99),
    [anon_sym_object] = ACTIONS(99),
    [anon_sym_abstract] = ACTIONS(105),
    [anon_sym_interface] = ACTIONS(107),
    [anon_sym_enum] = ACTIONS(109),
    [sym_html_comment] = ACTIONS(5),
  },
  [59] = {
    [sym_export_statement] = STATE(892),
    [sym_declaration] = STATE(892),
    [sym_import] = STATE(3636),
    [sym_import_statement] = STATE(892),
    [sym_statement] = STATE(823),
    [sym_expression_statement] = STATE(892),
    [sym_variable_declaration] = STATE(831),
    [sym_lexical_declaration] = STATE(831),
    [sym_statement_block] = STATE(892),
    [sym_if_statement] = STATE(892),
    [sym_switch_statement] = STATE(892),
    [sym_for_statement] = STATE(892),
    [sym_for_in_statement] = STATE(892),
    [sym_while_statement] = STATE(892),
    [sym_do_statement] = STATE(892),
    [sym_try_statement] = STATE(892),
    [sym_with_statement] = STATE(892),
    [sym_break_statement] = STATE(892),
    [sym_continue_statement] = STATE(892),
    [sym_debugger_statement] = STATE(892),
    [sym_return_statement] = STATE(892),
    [sym_throw_statement] = STATE(892),
    [sym_empty_statement] = STATE(892),
    [sym_labeled_statement] = STATE(892),
    [sym_parenthesized_expression] = STATE(1362),
    [sym_expression] = STATE(1902),
    [sym_primary_expression] = STATE(1810),
    [sym_yield_expression] = STATE(2358),
    [sym_object] = STATE(2222),
    [sym_object_pattern] = STATE(5492),
    [sym_array] = STATE(2222),
    [sym_array_pattern] = STATE(5492),
    [sym_class] = STATE(2222),
    [sym_class_declaration] = STATE(831),
    [sym_function_expression] = STATE(2222),
    [sym_function_declaration] = STATE(831),
    [sym_generator_function] = STATE(2222),
    [sym_generator_function_declaration] = STATE(831),
    [sym_arrow_function] = STATE(2222),
    [sym__call_signature] = STATE(5821),
    [sym_call_expression] = STATE(2222),
    [sym_new_expression] = STATE(1948),
    [sym_await_expression] = STATE(2358),
    [sym_member_expression] = STATE(1362),
    [sym_subscript_expression] = STATE(1362),
    [sym_assignment_expression] = STATE(2358),
    [sym__augmented_assignment_lhs] = STATE(3025),
    [sym_augmented_assignment_expression] = STATE(2358),
    [sym__destructuring_pattern] = STATE(5492),
    [sym_ternary_expression] = STATE(2358),
    [sym_binary_expression] = STATE(2358),
    [sym_unary_expression] = STATE(2358),
    [sym_update_expression] = STATE(2358),
    [sym_sequence_expression] = STATE(5305),
    [sym_string] = STATE(2222),
    [sym_template_string] = STATE(2222),
    [sym_regex] = STATE(2222),
    [sym_meta_property] = STATE(2222),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1362),
    [sym_function_signature] = STATE(831),
    [sym_type_assertion] = STATE(2358),
    [sym_as_expression] = STATE(2358),
    [sym_satisfies_expression] = STATE(2358),
    [sym_instantiation_expression] = STATE(2358),
    [sym_ambient_declaration] = STATE(831),
    [sym_abstract_class_declaration] = STATE(831),
    [sym_module] = STATE(831),
    [sym_internal_module] = STATE(214),
    [sym_import_alias] = STATE(831),
    [sym_interface_declaration] = STATE(831),
    [sym_enum_declaration] = STATE(831),
    [sym_type_alias_declaration] = STATE(831),
    [sym_type_arguments] = STATE(428),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(3774),
    [sym_identifier] = ACTIONS(9),
    [anon_sym_export] = ACTIONS(13),
    [anon_sym_type] = ACTIONS(15),
    [anon_sym_namespace] = ACTIONS(17),
    [anon_sym_LBRACE] = ACTIONS(19),
    [anon_sym_typeof] = ACTIONS(21),
    [anon_sym_import] = ACTIONS(23),
    [anon_sym_with] = ACTIONS(25),
    [anon_sym_var] = ACTIONS(27),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_const] = ACTIONS(31),
    [anon_sym_BANG] = ACTIONS(33),
    [anon_sym_if] = ACTIONS(35),
    [anon_sym_switch] = ACTIONS(37),
    [anon_sym_for] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_SEMI] = ACTIONS(43),
    [anon_sym_await] = ACTIONS(45),
    [anon_sym_while] = ACTIONS(47),
    [anon_sym_do] = ACTIONS(49),
    [anon_sym_try] = ACTIONS(51),
    [anon_sym_break] = ACTIONS(53),
    [anon_sym_continue] = ACTIONS(55),
    [anon_sym_debugger] = ACTIONS(57),
    [anon_sym_return] = ACTIONS(59),
    [anon_sym_throw] = ACTIONS(61),
    [anon_sym_yield] = ACTIONS(63),
    [anon_sym_LBRACK] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(67),
    [anon_sym_async] = ACTIONS(69),
    [anon_sym_function] = ACTIONS(71),
    [anon_sym_new] = ACTIONS(73),
    [anon_sym_using] = ACTIONS(75),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_SLASH] = ACTIONS(77),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(33),
    [anon_sym_void] = ACTIONS(21),
    [anon_sym_delete] = ACTIONS(21),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_DQUOTE] = ACTIONS(83),
    [anon_sym_SQUOTE] = ACTIONS(85),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(87),
    [sym_number] = ACTIONS(89),
    [sym_private_property_identifier] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(93),
    [sym_true] = ACTIONS(93),
    [sym_false] = ACTIONS(93),
    [sym_null] = ACTIONS(93),
    [sym_undefined] = ACTIONS(95),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(99),
    [anon_sym_readonly] = ACTIONS(99),
    [anon_sym_get] = ACTIONS(99),
    [anon_sym_set] = ACTIONS(99),
    [anon_sym_declare] = ACTIONS(101),
    [anon_sym_public] = ACTIONS(99),
    [anon_sym_private] = ACTIONS(99),
    [anon_sym_protected] = ACTIONS(99),
    [anon_sym_override] = ACTIONS(99),
    [anon_sym_module] = ACTIONS(103),
    [anon_sym_any] = ACTIONS(99),
    [anon_sym_number] = ACTIONS(99),
    [anon_sym_boolean] = ACTIONS(99),
    [anon_sym_string] = ACTIONS(99),
    [anon_sym_symbol] = ACTIONS(99),
    [anon_sym_object] = ACTIONS(99),
    [anon_sym_abstract] = ACTIONS(105),
    [anon_sym_interface] = ACTIONS(107),
    [anon_sym_enum] = ACTIONS(109),
    [sym_html_comment] = ACTIONS(5),
  },
  [60] = {
    [sym_export_statement] = STATE(892),
    [sym_declaration] = STATE(892),
    [sym_import] = STATE(3636),
    [sym_import_statement] = STATE(892),
    [sym_statement] = STATE(830),
    [sym_expression_statement] = STATE(892),
    [sym_variable_declaration] = STATE(831),
    [sym_lexical_declaration] = STATE(831),
    [sym_statement_block] = STATE(892),
    [sym_if_statement] = STATE(892),
    [sym_switch_statement] = STATE(892),
    [sym_for_statement] = STATE(892),
    [sym_for_in_statement] = STATE(892),
    [sym_while_statement] = STATE(892),
    [sym_do_statement] = STATE(892),
    [sym_try_statement] = STATE(892),
    [sym_with_statement] = STATE(892),
    [sym_break_statement] = STATE(892),
    [sym_continue_statement] = STATE(892),
    [sym_debugger_statement] = STATE(892),
    [sym_return_statement] = STATE(892),
    [sym_throw_statement] = STATE(892),
    [sym_empty_statement] = STATE(892),
    [sym_labeled_statement] = STATE(892),
    [sym_parenthesized_expression] = STATE(1362),
    [sym_expression] = STATE(1902),
    [sym_primary_expression] = STATE(1810),
    [sym_yield_expression] = STATE(2358),
    [sym_object] = STATE(2222),
    [sym_object_pattern] = STATE(5492),
    [sym_array] = STATE(2222),
    [sym_array_pattern] = STATE(5492),
    [sym_class] = STATE(2222),
    [sym_class_declaration] = STATE(831),
    [sym_function_expression] = STATE(2222),
    [sym_function_declaration] = STATE(831),
    [sym_generator_function] = STATE(2222),
    [sym_generator_function_declaration] = STATE(831),
    [sym_arrow_function] = STATE(2222),
    [sym__call_signature] = STATE(5821),
    [sym_call_expression] = STATE(2222),
    [sym_new_expression] = STATE(1948),
    [sym_await_expression] = STATE(2358),
    [sym_member_expression] = STATE(1362),
    [sym_subscript_expression] = STATE(1362),
    [sym_assignment_expression] = STATE(2358),
    [sym__augmented_assignment_lhs] = STATE(3025),
    [sym_augmented_assignment_expression] = STATE(2358),
    [sym__destructuring_pattern] = STATE(5492),
    [sym_ternary_expression] = STATE(2358),
    [sym_binary_expression] = STATE(2358),
    [sym_unary_expression] = STATE(2358),
    [sym_update_expression] = STATE(2358),
    [sym_sequence_expression] = STATE(5305),
    [sym_string] = STATE(2222),
    [sym_template_string] = STATE(2222),
    [sym_regex] = STATE(2222),
    [sym_meta_property] = STATE(2222),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1362),
    [sym_function_signature] = STATE(831),
    [sym_type_assertion] = STATE(2358),
    [sym_as_expression] = STATE(2358),
    [sym_satisfies_expression] = STATE(2358),
    [sym_instantiation_expression] = STATE(2358),
    [sym_ambient_declaration] = STATE(831),
    [sym_abstract_class_declaration] = STATE(831),
    [sym_module] = STATE(831),
    [sym_internal_module] = STATE(214),
    [sym_import_alias] = STATE(831),
    [sym_interface_declaration] = STATE(831),
    [sym_enum_declaration] = STATE(831),
    [sym_type_alias_declaration] = STATE(831),
    [sym_type_arguments] = STATE(428),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(3774),
    [sym_identifier] = ACTIONS(9),
    [anon_sym_export] = ACTIONS(13),
    [anon_sym_type] = ACTIONS(15),
    [anon_sym_namespace] = ACTIONS(17),
    [anon_sym_LBRACE] = ACTIONS(19),
    [anon_sym_typeof] = ACTIONS(21),
    [anon_sym_import] = ACTIONS(23),
    [anon_sym_with] = ACTIONS(25),
    [anon_sym_var] = ACTIONS(27),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_const] = ACTIONS(31),
    [anon_sym_BANG] = ACTIONS(33),
    [anon_sym_if] = ACTIONS(35),
    [anon_sym_switch] = ACTIONS(37),
    [anon_sym_for] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_SEMI] = ACTIONS(43),
    [anon_sym_await] = ACTIONS(45),
    [anon_sym_while] = ACTIONS(47),
    [anon_sym_do] = ACTIONS(49),
    [anon_sym_try] = ACTIONS(51),
    [anon_sym_break] = ACTIONS(53),
    [anon_sym_continue] = ACTIONS(55),
    [anon_sym_debugger] = ACTIONS(57),
    [anon_sym_return] = ACTIONS(59),
    [anon_sym_throw] = ACTIONS(61),
    [anon_sym_yield] = ACTIONS(63),
    [anon_sym_LBRACK] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(67),
    [anon_sym_async] = ACTIONS(69),
    [anon_sym_function] = ACTIONS(71),
    [anon_sym_new] = ACTIONS(73),
    [anon_sym_using] = ACTIONS(75),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_SLASH] = ACTIONS(77),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(33),
    [anon_sym_void] = ACTIONS(21),
    [anon_sym_delete] = ACTIONS(21),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_DQUOTE] = ACTIONS(83),
    [anon_sym_SQUOTE] = ACTIONS(85),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(87),
    [sym_number] = ACTIONS(89),
    [sym_private_property_identifier] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(93),
    [sym_true] = ACTIONS(93),
    [sym_false] = ACTIONS(93),
    [sym_null] = ACTIONS(93),
    [sym_undefined] = ACTIONS(95),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(99),
    [anon_sym_readonly] = ACTIONS(99),
    [anon_sym_get] = ACTIONS(99),
    [anon_sym_set] = ACTIONS(99),
    [anon_sym_declare] = ACTIONS(101),
    [anon_sym_public] = ACTIONS(99),
    [anon_sym_private] = ACTIONS(99),
    [anon_sym_protected] = ACTIONS(99),
    [anon_sym_override] = ACTIONS(99),
    [anon_sym_module] = ACTIONS(103),
    [anon_sym_any] = ACTIONS(99),
    [anon_sym_number] = ACTIONS(99),
    [anon_sym_boolean] = ACTIONS(99),
    [anon_sym_string] = ACTIONS(99),
    [anon_sym_symbol] = ACTIONS(99),
    [anon_sym_object] = ACTIONS(99),
    [anon_sym_abstract] = ACTIONS(105),
    [anon_sym_interface] = ACTIONS(107),
    [anon_sym_enum] = ACTIONS(109),
    [sym_html_comment] = ACTIONS(5),
  },
  [61] = {
    [sym_export_statement] = STATE(892),
    [sym_declaration] = STATE(892),
    [sym_import] = STATE(3636),
    [sym_import_statement] = STATE(892),
    [sym_statement] = STATE(841),
    [sym_expression_statement] = STATE(892),
    [sym_variable_declaration] = STATE(831),
    [sym_lexical_declaration] = STATE(831),
    [sym_statement_block] = STATE(892),
    [sym_if_statement] = STATE(892),
    [sym_switch_statement] = STATE(892),
    [sym_for_statement] = STATE(892),
    [sym_for_in_statement] = STATE(892),
    [sym_while_statement] = STATE(892),
    [sym_do_statement] = STATE(892),
    [sym_try_statement] = STATE(892),
    [sym_with_statement] = STATE(892),
    [sym_break_statement] = STATE(892),
    [sym_continue_statement] = STATE(892),
    [sym_debugger_statement] = STATE(892),
    [sym_return_statement] = STATE(892),
    [sym_throw_statement] = STATE(892),
    [sym_empty_statement] = STATE(892),
    [sym_labeled_statement] = STATE(892),
    [sym_parenthesized_expression] = STATE(1362),
    [sym_expression] = STATE(1902),
    [sym_primary_expression] = STATE(1810),
    [sym_yield_expression] = STATE(2358),
    [sym_object] = STATE(2222),
    [sym_object_pattern] = STATE(5492),
    [sym_array] = STATE(2222),
    [sym_array_pattern] = STATE(5492),
    [sym_class] = STATE(2222),
    [sym_class_declaration] = STATE(831),
    [sym_function_expression] = STATE(2222),
    [sym_function_declaration] = STATE(831),
    [sym_generator_function] = STATE(2222),
    [sym_generator_function_declaration] = STATE(831),
    [sym_arrow_function] = STATE(2222),
    [sym__call_signature] = STATE(5821),
    [sym_call_expression] = STATE(2222),
    [sym_new_expression] = STATE(1948),
    [sym_await_expression] = STATE(2358),
    [sym_member_expression] = STATE(1362),
    [sym_subscript_expression] = STATE(1362),
    [sym_assignment_expression] = STATE(2358),
    [sym__augmented_assignment_lhs] = STATE(3025),
    [sym_augmented_assignment_expression] = STATE(2358),
    [sym__destructuring_pattern] = STATE(5492),
    [sym_ternary_expression] = STATE(2358),
    [sym_binary_expression] = STATE(2358),
    [sym_unary_expression] = STATE(2358),
    [sym_update_expression] = STATE(2358),
    [sym_sequence_expression] = STATE(5305),
    [sym_string] = STATE(2222),
    [sym_template_string] = STATE(2222),
    [sym_regex] = STATE(2222),
    [sym_meta_property] = STATE(2222),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1362),
    [sym_function_signature] = STATE(831),
    [sym_type_assertion] = STATE(2358),
    [sym_as_expression] = STATE(2358),
    [sym_satisfies_expression] = STATE(2358),
    [sym_instantiation_expression] = STATE(2358),
    [sym_ambient_declaration] = STATE(831),
    [sym_abstract_class_declaration] = STATE(831),
    [sym_module] = STATE(831),
    [sym_internal_module] = STATE(214),
    [sym_import_alias] = STATE(831),
    [sym_interface_declaration] = STATE(831),
    [sym_enum_declaration] = STATE(831),
    [sym_type_alias_declaration] = STATE(831),
    [sym_type_arguments] = STATE(428),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(3774),
    [sym_identifier] = ACTIONS(9),
    [anon_sym_export] = ACTIONS(13),
    [anon_sym_type] = ACTIONS(15),
    [anon_sym_namespace] = ACTIONS(17),
    [anon_sym_LBRACE] = ACTIONS(19),
    [anon_sym_typeof] = ACTIONS(21),
    [anon_sym_import] = ACTIONS(23),
    [anon_sym_with] = ACTIONS(25),
    [anon_sym_var] = ACTIONS(27),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_const] = ACTIONS(31),
    [anon_sym_BANG] = ACTIONS(33),
    [anon_sym_if] = ACTIONS(35),
    [anon_sym_switch] = ACTIONS(37),
    [anon_sym_for] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_SEMI] = ACTIONS(43),
    [anon_sym_await] = ACTIONS(45),
    [anon_sym_while] = ACTIONS(47),
    [anon_sym_do] = ACTIONS(49),
    [anon_sym_try] = ACTIONS(51),
    [anon_sym_break] = ACTIONS(53),
    [anon_sym_continue] = ACTIONS(55),
    [anon_sym_debugger] = ACTIONS(57),
    [anon_sym_return] = ACTIONS(59),
    [anon_sym_throw] = ACTIONS(61),
    [anon_sym_yield] = ACTIONS(63),
    [anon_sym_LBRACK] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(67),
    [anon_sym_async] = ACTIONS(69),
    [anon_sym_function] = ACTIONS(71),
    [anon_sym_new] = ACTIONS(73),
    [anon_sym_using] = ACTIONS(75),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_SLASH] = ACTIONS(77),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(33),
    [anon_sym_void] = ACTIONS(21),
    [anon_sym_delete] = ACTIONS(21),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_DQUOTE] = ACTIONS(83),
    [anon_sym_SQUOTE] = ACTIONS(85),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(87),
    [sym_number] = ACTIONS(89),
    [sym_private_property_identifier] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(93),
    [sym_true] = ACTIONS(93),
    [sym_false] = ACTIONS(93),
    [sym_null] = ACTIONS(93),
    [sym_undefined] = ACTIONS(95),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(99),
    [anon_sym_readonly] = ACTIONS(99),
    [anon_sym_get] = ACTIONS(99),
    [anon_sym_set] = ACTIONS(99),
    [anon_sym_declare] = ACTIONS(101),
    [anon_sym_public] = ACTIONS(99),
    [anon_sym_private] = ACTIONS(99),
    [anon_sym_protected] = ACTIONS(99),
    [anon_sym_override] = ACTIONS(99),
    [anon_sym_module] = ACTIONS(103),
    [anon_sym_any] = ACTIONS(99),
    [anon_sym_number] = ACTIONS(99),
    [anon_sym_boolean] = ACTIONS(99),
    [anon_sym_string] = ACTIONS(99),
    [anon_sym_symbol] = ACTIONS(99),
    [anon_sym_object] = ACTIONS(99),
    [anon_sym_abstract] = ACTIONS(105),
    [anon_sym_interface] = ACTIONS(107),
    [anon_sym_enum] = ACTIONS(109),
    [sym_html_comment] = ACTIONS(5),
  },
  [62] = {
    [sym_export_statement] = STATE(892),
    [sym_declaration] = STATE(892),
    [sym_import] = STATE(3636),
    [sym_import_statement] = STATE(892),
    [sym_statement] = STATE(843),
    [sym_expression_statement] = STATE(892),
    [sym_variable_declaration] = STATE(831),
    [sym_lexical_declaration] = STATE(831),
    [sym_statement_block] = STATE(892),
    [sym_if_statement] = STATE(892),
    [sym_switch_statement] = STATE(892),
    [sym_for_statement] = STATE(892),
    [sym_for_in_statement] = STATE(892),
    [sym_while_statement] = STATE(892),
    [sym_do_statement] = STATE(892),
    [sym_try_statement] = STATE(892),
    [sym_with_statement] = STATE(892),
    [sym_break_statement] = STATE(892),
    [sym_continue_statement] = STATE(892),
    [sym_debugger_statement] = STATE(892),
    [sym_return_statement] = STATE(892),
    [sym_throw_statement] = STATE(892),
    [sym_empty_statement] = STATE(892),
    [sym_labeled_statement] = STATE(892),
    [sym_parenthesized_expression] = STATE(1362),
    [sym_expression] = STATE(1902),
    [sym_primary_expression] = STATE(1810),
    [sym_yield_expression] = STATE(2358),
    [sym_object] = STATE(2222),
    [sym_object_pattern] = STATE(5492),
    [sym_array] = STATE(2222),
    [sym_array_pattern] = STATE(5492),
    [sym_class] = STATE(2222),
    [sym_class_declaration] = STATE(831),
    [sym_function_expression] = STATE(2222),
    [sym_function_declaration] = STATE(831),
    [sym_generator_function] = STATE(2222),
    [sym_generator_function_declaration] = STATE(831),
    [sym_arrow_function] = STATE(2222),
    [sym__call_signature] = STATE(5821),
    [sym_call_expression] = STATE(2222),
    [sym_new_expression] = STATE(1948),
    [sym_await_expression] = STATE(2358),
    [sym_member_expression] = STATE(1362),
    [sym_subscript_expression] = STATE(1362),
    [sym_assignment_expression] = STATE(2358),
    [sym__augmented_assignment_lhs] = STATE(3025),
    [sym_augmented_assignment_expression] = STATE(2358),
    [sym__destructuring_pattern] = STATE(5492),
    [sym_ternary_expression] = STATE(2358),
    [sym_binary_expression] = STATE(2358),
    [sym_unary_expression] = STATE(2358),
    [sym_update_expression] = STATE(2358),
    [sym_sequence_expression] = STATE(5305),
    [sym_string] = STATE(2222),
    [sym_template_string] = STATE(2222),
    [sym_regex] = STATE(2222),
    [sym_meta_property] = STATE(2222),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1362),
    [sym_function_signature] = STATE(831),
    [sym_type_assertion] = STATE(2358),
    [sym_as_expression] = STATE(2358),
    [sym_satisfies_expression] = STATE(2358),
    [sym_instantiation_expression] = STATE(2358),
    [sym_ambient_declaration] = STATE(831),
    [sym_abstract_class_declaration] = STATE(831),
    [sym_module] = STATE(831),
    [sym_internal_module] = STATE(214),
    [sym_import_alias] = STATE(831),
    [sym_interface_declaration] = STATE(831),
    [sym_enum_declaration] = STATE(831),
    [sym_type_alias_declaration] = STATE(831),
    [sym_type_arguments] = STATE(428),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(3774),
    [sym_identifier] = ACTIONS(9),
    [anon_sym_export] = ACTIONS(13),
    [anon_sym_type] = ACTIONS(15),
    [anon_sym_namespace] = ACTIONS(17),
    [anon_sym_LBRACE] = ACTIONS(19),
    [anon_sym_typeof] = ACTIONS(21),
    [anon_sym_import] = ACTIONS(23),
    [anon_sym_with] = ACTIONS(25),
    [anon_sym_var] = ACTIONS(27),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_const] = ACTIONS(31),
    [anon_sym_BANG] = ACTIONS(33),
    [anon_sym_if] = ACTIONS(35),
    [anon_sym_switch] = ACTIONS(37),
    [anon_sym_for] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_SEMI] = ACTIONS(43),
    [anon_sym_await] = ACTIONS(45),
    [anon_sym_while] = ACTIONS(47),
    [anon_sym_do] = ACTIONS(49),
    [anon_sym_try] = ACTIONS(51),
    [anon_sym_break] = ACTIONS(53),
    [anon_sym_continue] = ACTIONS(55),
    [anon_sym_debugger] = ACTIONS(57),
    [anon_sym_return] = ACTIONS(59),
    [anon_sym_throw] = ACTIONS(61),
    [anon_sym_yield] = ACTIONS(63),
    [anon_sym_LBRACK] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(67),
    [anon_sym_async] = ACTIONS(69),
    [anon_sym_function] = ACTIONS(71),
    [anon_sym_new] = ACTIONS(73),
    [anon_sym_using] = ACTIONS(75),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_SLASH] = ACTIONS(77),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(33),
    [anon_sym_void] = ACTIONS(21),
    [anon_sym_delete] = ACTIONS(21),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_DQUOTE] = ACTIONS(83),
    [anon_sym_SQUOTE] = ACTIONS(85),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(87),
    [sym_number] = ACTIONS(89),
    [sym_private_property_identifier] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(93),
    [sym_true] = ACTIONS(93),
    [sym_false] = ACTIONS(93),
    [sym_null] = ACTIONS(93),
    [sym_undefined] = ACTIONS(95),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(99),
    [anon_sym_readonly] = ACTIONS(99),
    [anon_sym_get] = ACTIONS(99),
    [anon_sym_set] = ACTIONS(99),
    [anon_sym_declare] = ACTIONS(101),
    [anon_sym_public] = ACTIONS(99),
    [anon_sym_private] = ACTIONS(99),
    [anon_sym_protected] = ACTIONS(99),
    [anon_sym_override] = ACTIONS(99),
    [anon_sym_module] = ACTIONS(103),
    [anon_sym_any] = ACTIONS(99),
    [anon_sym_number] = ACTIONS(99),
    [anon_sym_boolean] = ACTIONS(99),
    [anon_sym_string] = ACTIONS(99),
    [anon_sym_symbol] = ACTIONS(99),
    [anon_sym_object] = ACTIONS(99),
    [anon_sym_abstract] = ACTIONS(105),
    [anon_sym_interface] = ACTIONS(107),
    [anon_sym_enum] = ACTIONS(109),
    [sym_html_comment] = ACTIONS(5),
  },
  [63] = {
    [sym_import] = STATE(3663),
    [sym_parenthesized_expression] = STATE(1322),
    [sym_expression] = STATE(2126),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(4425),
    [sym_assignment_pattern] = STATE(4969),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(4425),
    [sym_nested_identifier] = STATE(5474),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5508),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1396),
    [sym_subscript_expression] = STATE(1396),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3003),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(4425),
    [sym_spread_element] = STATE(4946),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(2213),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(4317),
    [sym_pattern] = STATE(4406),
    [sym_rest_pattern] = STATE(4115),
    [sym_non_null_expression] = STATE(1396),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_nested_type_identifier] = STATE(2939),
    [sym__type_query_member_expression_in_type_annotation] = STATE(3303),
    [sym__type_query_call_expression_in_type_annotation] = STATE(2938),
    [sym_type] = STATE(3773),
    [sym_tuple_parameter] = STATE(4568),
    [sym_optional_tuple_parameter] = STATE(4568),
    [sym_optional_type] = STATE(4568),
    [sym_rest_type] = STATE(4568),
    [sym__tuple_type_member] = STATE(4568),
    [sym_constructor_type] = STATE(3007),
    [sym_primary_type] = STATE(2981),
    [sym_template_literal_type] = STATE(3039),
    [sym_infer_type] = STATE(3007),
    [sym_conditional_type] = STATE(3039),
    [sym_generic_type] = STATE(3039),
    [sym_type_query] = STATE(3039),
    [sym_index_type_query] = STATE(3039),
    [sym_lookup_type] = STATE(3039),
    [sym_literal_type] = STATE(3039),
    [sym__number] = STATE(3041),
    [sym_existential_type] = STATE(3039),
    [sym_flow_maybe_type] = STATE(3039),
    [sym_parenthesized_type] = STATE(3039),
    [sym_predefined_type] = STATE(3039),
    [sym_type_arguments] = STATE(484),
    [sym_object_type] = STATE(3039),
    [sym_type_parameters] = STATE(5455),
    [sym_array_type] = STATE(3039),
    [sym_tuple_type] = STATE(3039),
    [sym_readonly_type] = STATE(3007),
    [sym_union_type] = STATE(3039),
    [sym_intersection_type] = STATE(3039),
    [sym_function_type] = STATE(3007),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [aux_sym_array_repeat1] = STATE(4955),
    [aux_sym_array_pattern_repeat1] = STATE(4977),
    [sym_identifier] = ACTIONS(539),
    [anon_sym_export] = ACTIONS(541),
    [anon_sym_STAR] = ACTIONS(543),
    [anon_sym_type] = ACTIONS(541),
    [anon_sym_namespace] = ACTIONS(545),
    [anon_sym_LBRACE] = ACTIONS(547),
    [anon_sym_COMMA] = ACTIONS(549),
    [anon_sym_typeof] = ACTIONS(551),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(541),
    [anon_sym_const] = ACTIONS(133),
    [anon_sym_BANG] = ACTIONS(553),
    [anon_sym_LPAREN] = ACTIONS(138),
    [anon_sym_await] = ACTIONS(555),
    [anon_sym_yield] = ACTIONS(557),
    [anon_sym_LBRACK] = ACTIONS(559),
    [anon_sym_RBRACK] = ACTIONS(645),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(563),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(565),
    [anon_sym_using] = ACTIONS(567),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(569),
    [anon_sym_AMP] = ACTIONS(571),
    [anon_sym_PIPE] = ACTIONS(573),
    [anon_sym_PLUS] = ACTIONS(575),
    [anon_sym_DASH] = ACTIONS(575),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(553),
    [anon_sym_void] = ACTIONS(579),
    [anon_sym_delete] = ACTIONS(581),
    [anon_sym_PLUS_PLUS] = ACTIONS(583),
    [anon_sym_DASH_DASH] = ACTIONS(583),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(188),
    [sym_number] = ACTIONS(190),
    [sym_private_property_identifier] = ACTIONS(585),
    [sym_this] = ACTIONS(587),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(198),
    [sym_false] = ACTIONS(198),
    [sym_null] = ACTIONS(198),
    [sym_undefined] = ACTIONS(589),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(541),
    [anon_sym_readonly] = ACTIONS(591),
    [anon_sym_get] = ACTIONS(541),
    [anon_sym_set] = ACTIONS(541),
    [anon_sym_QMARK] = ACTIONS(593),
    [anon_sym_declare] = ACTIONS(541),
    [anon_sym_public] = ACTIONS(541),
    [anon_sym_private] = ACTIONS(541),
    [anon_sym_protected] = ACTIONS(541),
    [anon_sym_override] = ACTIONS(541),
    [anon_sym_module] = ACTIONS(541),
    [anon_sym_any] = ACTIONS(595),
    [anon_sym_number] = ACTIONS(595),
    [anon_sym_boolean] = ACTIONS(595),
    [anon_sym_string] = ACTIONS(595),
    [anon_sym_symbol] = ACTIONS(595),
    [anon_sym_object] = ACTIONS(595),
    [anon_sym_abstract] = ACTIONS(597),
    [anon_sym_infer] = ACTIONS(599),
    [anon_sym_keyof] = ACTIONS(601),
    [anon_sym_unique] = ACTIONS(214),
    [anon_sym_unknown] = ACTIONS(216),
    [anon_sym_never] = ACTIONS(216),
    [anon_sym_LBRACE_PIPE] = ACTIONS(218),
    [sym_html_comment] = ACTIONS(5),
  },
  [64] = {
    [sym_export_statement] = STATE(892),
    [sym_declaration] = STATE(892),
    [sym_import] = STATE(3636),
    [sym_import_statement] = STATE(892),
    [sym_statement] = STATE(853),
    [sym_expression_statement] = STATE(892),
    [sym_variable_declaration] = STATE(831),
    [sym_lexical_declaration] = STATE(831),
    [sym_statement_block] = STATE(892),
    [sym_if_statement] = STATE(892),
    [sym_switch_statement] = STATE(892),
    [sym_for_statement] = STATE(892),
    [sym_for_in_statement] = STATE(892),
    [sym_while_statement] = STATE(892),
    [sym_do_statement] = STATE(892),
    [sym_try_statement] = STATE(892),
    [sym_with_statement] = STATE(892),
    [sym_break_statement] = STATE(892),
    [sym_continue_statement] = STATE(892),
    [sym_debugger_statement] = STATE(892),
    [sym_return_statement] = STATE(892),
    [sym_throw_statement] = STATE(892),
    [sym_empty_statement] = STATE(892),
    [sym_labeled_statement] = STATE(892),
    [sym_parenthesized_expression] = STATE(1362),
    [sym_expression] = STATE(1902),
    [sym_primary_expression] = STATE(1810),
    [sym_yield_expression] = STATE(2358),
    [sym_object] = STATE(2222),
    [sym_object_pattern] = STATE(5492),
    [sym_array] = STATE(2222),
    [sym_array_pattern] = STATE(5492),
    [sym_class] = STATE(2222),
    [sym_class_declaration] = STATE(831),
    [sym_function_expression] = STATE(2222),
    [sym_function_declaration] = STATE(831),
    [sym_generator_function] = STATE(2222),
    [sym_generator_function_declaration] = STATE(831),
    [sym_arrow_function] = STATE(2222),
    [sym__call_signature] = STATE(5821),
    [sym_call_expression] = STATE(2222),
    [sym_new_expression] = STATE(1948),
    [sym_await_expression] = STATE(2358),
    [sym_member_expression] = STATE(1362),
    [sym_subscript_expression] = STATE(1362),
    [sym_assignment_expression] = STATE(2358),
    [sym__augmented_assignment_lhs] = STATE(3025),
    [sym_augmented_assignment_expression] = STATE(2358),
    [sym__destructuring_pattern] = STATE(5492),
    [sym_ternary_expression] = STATE(2358),
    [sym_binary_expression] = STATE(2358),
    [sym_unary_expression] = STATE(2358),
    [sym_update_expression] = STATE(2358),
    [sym_sequence_expression] = STATE(5305),
    [sym_string] = STATE(2222),
    [sym_template_string] = STATE(2222),
    [sym_regex] = STATE(2222),
    [sym_meta_property] = STATE(2222),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1362),
    [sym_function_signature] = STATE(831),
    [sym_type_assertion] = STATE(2358),
    [sym_as_expression] = STATE(2358),
    [sym_satisfies_expression] = STATE(2358),
    [sym_instantiation_expression] = STATE(2358),
    [sym_ambient_declaration] = STATE(831),
    [sym_abstract_class_declaration] = STATE(831),
    [sym_module] = STATE(831),
    [sym_internal_module] = STATE(214),
    [sym_import_alias] = STATE(831),
    [sym_interface_declaration] = STATE(831),
    [sym_enum_declaration] = STATE(831),
    [sym_type_alias_declaration] = STATE(831),
    [sym_type_arguments] = STATE(428),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(3774),
    [sym_identifier] = ACTIONS(9),
    [anon_sym_export] = ACTIONS(13),
    [anon_sym_type] = ACTIONS(15),
    [anon_sym_namespace] = ACTIONS(17),
    [anon_sym_LBRACE] = ACTIONS(19),
    [anon_sym_typeof] = ACTIONS(21),
    [anon_sym_import] = ACTIONS(23),
    [anon_sym_with] = ACTIONS(25),
    [anon_sym_var] = ACTIONS(27),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_const] = ACTIONS(31),
    [anon_sym_BANG] = ACTIONS(33),
    [anon_sym_if] = ACTIONS(35),
    [anon_sym_switch] = ACTIONS(37),
    [anon_sym_for] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_SEMI] = ACTIONS(43),
    [anon_sym_await] = ACTIONS(45),
    [anon_sym_while] = ACTIONS(47),
    [anon_sym_do] = ACTIONS(49),
    [anon_sym_try] = ACTIONS(51),
    [anon_sym_break] = ACTIONS(53),
    [anon_sym_continue] = ACTIONS(55),
    [anon_sym_debugger] = ACTIONS(57),
    [anon_sym_return] = ACTIONS(59),
    [anon_sym_throw] = ACTIONS(61),
    [anon_sym_yield] = ACTIONS(63),
    [anon_sym_LBRACK] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(67),
    [anon_sym_async] = ACTIONS(69),
    [anon_sym_function] = ACTIONS(71),
    [anon_sym_new] = ACTIONS(73),
    [anon_sym_using] = ACTIONS(75),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_SLASH] = ACTIONS(77),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(33),
    [anon_sym_void] = ACTIONS(21),
    [anon_sym_delete] = ACTIONS(21),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_DQUOTE] = ACTIONS(83),
    [anon_sym_SQUOTE] = ACTIONS(85),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(87),
    [sym_number] = ACTIONS(89),
    [sym_private_property_identifier] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(93),
    [sym_true] = ACTIONS(93),
    [sym_false] = ACTIONS(93),
    [sym_null] = ACTIONS(93),
    [sym_undefined] = ACTIONS(95),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(99),
    [anon_sym_readonly] = ACTIONS(99),
    [anon_sym_get] = ACTIONS(99),
    [anon_sym_set] = ACTIONS(99),
    [anon_sym_declare] = ACTIONS(101),
    [anon_sym_public] = ACTIONS(99),
    [anon_sym_private] = ACTIONS(99),
    [anon_sym_protected] = ACTIONS(99),
    [anon_sym_override] = ACTIONS(99),
    [anon_sym_module] = ACTIONS(103),
    [anon_sym_any] = ACTIONS(99),
    [anon_sym_number] = ACTIONS(99),
    [anon_sym_boolean] = ACTIONS(99),
    [anon_sym_string] = ACTIONS(99),
    [anon_sym_symbol] = ACTIONS(99),
    [anon_sym_object] = ACTIONS(99),
    [anon_sym_abstract] = ACTIONS(105),
    [anon_sym_interface] = ACTIONS(107),
    [anon_sym_enum] = ACTIONS(109),
    [sym_html_comment] = ACTIONS(5),
  },
  [65] = {
    [sym_export_statement] = STATE(892),
    [sym_declaration] = STATE(892),
    [sym_import] = STATE(3636),
    [sym_import_statement] = STATE(892),
    [sym_statement] = STATE(832),
    [sym_expression_statement] = STATE(892),
    [sym_variable_declaration] = STATE(831),
    [sym_lexical_declaration] = STATE(831),
    [sym_statement_block] = STATE(892),
    [sym_if_statement] = STATE(892),
    [sym_switch_statement] = STATE(892),
    [sym_for_statement] = STATE(892),
    [sym_for_in_statement] = STATE(892),
    [sym_while_statement] = STATE(892),
    [sym_do_statement] = STATE(892),
    [sym_try_statement] = STATE(892),
    [sym_with_statement] = STATE(892),
    [sym_break_statement] = STATE(892),
    [sym_continue_statement] = STATE(892),
    [sym_debugger_statement] = STATE(892),
    [sym_return_statement] = STATE(892),
    [sym_throw_statement] = STATE(892),
    [sym_empty_statement] = STATE(892),
    [sym_labeled_statement] = STATE(892),
    [sym_parenthesized_expression] = STATE(1362),
    [sym_expression] = STATE(1902),
    [sym_primary_expression] = STATE(1810),
    [sym_yield_expression] = STATE(2358),
    [sym_object] = STATE(2222),
    [sym_object_pattern] = STATE(5492),
    [sym_array] = STATE(2222),
    [sym_array_pattern] = STATE(5492),
    [sym_class] = STATE(2222),
    [sym_class_declaration] = STATE(831),
    [sym_function_expression] = STATE(2222),
    [sym_function_declaration] = STATE(831),
    [sym_generator_function] = STATE(2222),
    [sym_generator_function_declaration] = STATE(831),
    [sym_arrow_function] = STATE(2222),
    [sym__call_signature] = STATE(5821),
    [sym_call_expression] = STATE(2222),
    [sym_new_expression] = STATE(1948),
    [sym_await_expression] = STATE(2358),
    [sym_member_expression] = STATE(1362),
    [sym_subscript_expression] = STATE(1362),
    [sym_assignment_expression] = STATE(2358),
    [sym__augmented_assignment_lhs] = STATE(3025),
    [sym_augmented_assignment_expression] = STATE(2358),
    [sym__destructuring_pattern] = STATE(5492),
    [sym_ternary_expression] = STATE(2358),
    [sym_binary_expression] = STATE(2358),
    [sym_unary_expression] = STATE(2358),
    [sym_update_expression] = STATE(2358),
    [sym_sequence_expression] = STATE(5305),
    [sym_string] = STATE(2222),
    [sym_template_string] = STATE(2222),
    [sym_regex] = STATE(2222),
    [sym_meta_property] = STATE(2222),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1362),
    [sym_function_signature] = STATE(831),
    [sym_type_assertion] = STATE(2358),
    [sym_as_expression] = STATE(2358),
    [sym_satisfies_expression] = STATE(2358),
    [sym_instantiation_expression] = STATE(2358),
    [sym_ambient_declaration] = STATE(831),
    [sym_abstract_class_declaration] = STATE(831),
    [sym_module] = STATE(831),
    [sym_internal_module] = STATE(214),
    [sym_import_alias] = STATE(831),
    [sym_interface_declaration] = STATE(831),
    [sym_enum_declaration] = STATE(831),
    [sym_type_alias_declaration] = STATE(831),
    [sym_type_arguments] = STATE(428),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(3774),
    [sym_identifier] = ACTIONS(9),
    [anon_sym_export] = ACTIONS(13),
    [anon_sym_type] = ACTIONS(15),
    [anon_sym_namespace] = ACTIONS(17),
    [anon_sym_LBRACE] = ACTIONS(19),
    [anon_sym_typeof] = ACTIONS(21),
    [anon_sym_import] = ACTIONS(23),
    [anon_sym_with] = ACTIONS(25),
    [anon_sym_var] = ACTIONS(27),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_const] = ACTIONS(31),
    [anon_sym_BANG] = ACTIONS(33),
    [anon_sym_if] = ACTIONS(35),
    [anon_sym_switch] = ACTIONS(37),
    [anon_sym_for] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_SEMI] = ACTIONS(43),
    [anon_sym_await] = ACTIONS(45),
    [anon_sym_while] = ACTIONS(47),
    [anon_sym_do] = ACTIONS(49),
    [anon_sym_try] = ACTIONS(51),
    [anon_sym_break] = ACTIONS(53),
    [anon_sym_continue] = ACTIONS(55),
    [anon_sym_debugger] = ACTIONS(57),
    [anon_sym_return] = ACTIONS(59),
    [anon_sym_throw] = ACTIONS(61),
    [anon_sym_yield] = ACTIONS(63),
    [anon_sym_LBRACK] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(67),
    [anon_sym_async] = ACTIONS(69),
    [anon_sym_function] = ACTIONS(71),
    [anon_sym_new] = ACTIONS(73),
    [anon_sym_using] = ACTIONS(75),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_SLASH] = ACTIONS(77),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(33),
    [anon_sym_void] = ACTIONS(21),
    [anon_sym_delete] = ACTIONS(21),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_DQUOTE] = ACTIONS(83),
    [anon_sym_SQUOTE] = ACTIONS(85),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(87),
    [sym_number] = ACTIONS(89),
    [sym_private_property_identifier] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(93),
    [sym_true] = ACTIONS(93),
    [sym_false] = ACTIONS(93),
    [sym_null] = ACTIONS(93),
    [sym_undefined] = ACTIONS(95),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(99),
    [anon_sym_readonly] = ACTIONS(99),
    [anon_sym_get] = ACTIONS(99),
    [anon_sym_set] = ACTIONS(99),
    [anon_sym_declare] = ACTIONS(101),
    [anon_sym_public] = ACTIONS(99),
    [anon_sym_private] = ACTIONS(99),
    [anon_sym_protected] = ACTIONS(99),
    [anon_sym_override] = ACTIONS(99),
    [anon_sym_module] = ACTIONS(103),
    [anon_sym_any] = ACTIONS(99),
    [anon_sym_number] = ACTIONS(99),
    [anon_sym_boolean] = ACTIONS(99),
    [anon_sym_string] = ACTIONS(99),
    [anon_sym_symbol] = ACTIONS(99),
    [anon_sym_object] = ACTIONS(99),
    [anon_sym_abstract] = ACTIONS(105),
    [anon_sym_interface] = ACTIONS(107),
    [anon_sym_enum] = ACTIONS(109),
    [sym_html_comment] = ACTIONS(5),
  },
  [66] = {
    [sym_import] = STATE(3663),
    [sym_parenthesized_expression] = STATE(1322),
    [sym_expression] = STATE(2126),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(4425),
    [sym_assignment_pattern] = STATE(4969),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(4425),
    [sym_nested_identifier] = STATE(5474),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5508),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1396),
    [sym_subscript_expression] = STATE(1396),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3003),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(4425),
    [sym_spread_element] = STATE(4946),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(2213),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(4317),
    [sym_pattern] = STATE(4406),
    [sym_rest_pattern] = STATE(4115),
    [sym_non_null_expression] = STATE(1396),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_nested_type_identifier] = STATE(2939),
    [sym__type_query_member_expression_in_type_annotation] = STATE(3303),
    [sym__type_query_call_expression_in_type_annotation] = STATE(2938),
    [sym_type] = STATE(3773),
    [sym_tuple_parameter] = STATE(4568),
    [sym_optional_tuple_parameter] = STATE(4568),
    [sym_optional_type] = STATE(4568),
    [sym_rest_type] = STATE(4568),
    [sym__tuple_type_member] = STATE(4568),
    [sym_constructor_type] = STATE(3007),
    [sym_primary_type] = STATE(2981),
    [sym_template_literal_type] = STATE(3039),
    [sym_infer_type] = STATE(3007),
    [sym_conditional_type] = STATE(3039),
    [sym_generic_type] = STATE(3039),
    [sym_type_query] = STATE(3039),
    [sym_index_type_query] = STATE(3039),
    [sym_lookup_type] = STATE(3039),
    [sym_literal_type] = STATE(3039),
    [sym__number] = STATE(3041),
    [sym_existential_type] = STATE(3039),
    [sym_flow_maybe_type] = STATE(3039),
    [sym_parenthesized_type] = STATE(3039),
    [sym_predefined_type] = STATE(3039),
    [sym_type_arguments] = STATE(484),
    [sym_object_type] = STATE(3039),
    [sym_type_parameters] = STATE(5455),
    [sym_array_type] = STATE(3039),
    [sym_tuple_type] = STATE(3039),
    [sym_readonly_type] = STATE(3007),
    [sym_union_type] = STATE(3039),
    [sym_intersection_type] = STATE(3039),
    [sym_function_type] = STATE(3007),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [aux_sym_array_repeat1] = STATE(4955),
    [aux_sym_array_pattern_repeat1] = STATE(4977),
    [sym_identifier] = ACTIONS(539),
    [anon_sym_export] = ACTIONS(541),
    [anon_sym_STAR] = ACTIONS(543),
    [anon_sym_type] = ACTIONS(541),
    [anon_sym_namespace] = ACTIONS(545),
    [anon_sym_LBRACE] = ACTIONS(547),
    [anon_sym_COMMA] = ACTIONS(549),
    [anon_sym_typeof] = ACTIONS(551),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(541),
    [anon_sym_const] = ACTIONS(133),
    [anon_sym_BANG] = ACTIONS(553),
    [anon_sym_LPAREN] = ACTIONS(138),
    [anon_sym_await] = ACTIONS(555),
    [anon_sym_yield] = ACTIONS(557),
    [anon_sym_LBRACK] = ACTIONS(559),
    [anon_sym_RBRACK] = ACTIONS(647),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(563),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(565),
    [anon_sym_using] = ACTIONS(567),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(569),
    [anon_sym_AMP] = ACTIONS(571),
    [anon_sym_PIPE] = ACTIONS(573),
    [anon_sym_PLUS] = ACTIONS(575),
    [anon_sym_DASH] = ACTIONS(575),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(553),
    [anon_sym_void] = ACTIONS(579),
    [anon_sym_delete] = ACTIONS(581),
    [anon_sym_PLUS_PLUS] = ACTIONS(583),
    [anon_sym_DASH_DASH] = ACTIONS(583),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(188),
    [sym_number] = ACTIONS(190),
    [sym_private_property_identifier] = ACTIONS(585),
    [sym_this] = ACTIONS(587),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(198),
    [sym_false] = ACTIONS(198),
    [sym_null] = ACTIONS(198),
    [sym_undefined] = ACTIONS(589),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(541),
    [anon_sym_readonly] = ACTIONS(591),
    [anon_sym_get] = ACTIONS(541),
    [anon_sym_set] = ACTIONS(541),
    [anon_sym_QMARK] = ACTIONS(593),
    [anon_sym_declare] = ACTIONS(541),
    [anon_sym_public] = ACTIONS(541),
    [anon_sym_private] = ACTIONS(541),
    [anon_sym_protected] = ACTIONS(541),
    [anon_sym_override] = ACTIONS(541),
    [anon_sym_module] = ACTIONS(541),
    [anon_sym_any] = ACTIONS(595),
    [anon_sym_number] = ACTIONS(595),
    [anon_sym_boolean] = ACTIONS(595),
    [anon_sym_string] = ACTIONS(595),
    [anon_sym_symbol] = ACTIONS(595),
    [anon_sym_object] = ACTIONS(595),
    [anon_sym_abstract] = ACTIONS(597),
    [anon_sym_infer] = ACTIONS(599),
    [anon_sym_keyof] = ACTIONS(601),
    [anon_sym_unique] = ACTIONS(214),
    [anon_sym_unknown] = ACTIONS(216),
    [anon_sym_never] = ACTIONS(216),
    [anon_sym_LBRACE_PIPE] = ACTIONS(218),
    [sym_html_comment] = ACTIONS(5),
  },
  [67] = {
    [sym_import] = STATE(3663),
    [sym_parenthesized_expression] = STATE(1322),
    [sym_expression] = STATE(2301),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(4425),
    [sym_assignment_pattern] = STATE(4969),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(4425),
    [sym_nested_identifier] = STATE(5474),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5508),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1396),
    [sym_subscript_expression] = STATE(1396),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3003),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(4425),
    [sym_spread_element] = STATE(4971),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(2213),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(4317),
    [sym_pattern] = STATE(4406),
    [sym_rest_pattern] = STATE(4115),
    [sym_non_null_expression] = STATE(1396),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_nested_type_identifier] = STATE(2939),
    [sym__type_query_member_expression_in_type_annotation] = STATE(3303),
    [sym__type_query_call_expression_in_type_annotation] = STATE(2938),
    [sym_type] = STATE(3773),
    [sym_tuple_parameter] = STATE(4568),
    [sym_optional_tuple_parameter] = STATE(4568),
    [sym_optional_type] = STATE(4568),
    [sym_rest_type] = STATE(4568),
    [sym__tuple_type_member] = STATE(4568),
    [sym_constructor_type] = STATE(3007),
    [sym_primary_type] = STATE(2981),
    [sym_template_literal_type] = STATE(3039),
    [sym_infer_type] = STATE(3007),
    [sym_conditional_type] = STATE(3039),
    [sym_generic_type] = STATE(3039),
    [sym_type_query] = STATE(3039),
    [sym_index_type_query] = STATE(3039),
    [sym_lookup_type] = STATE(3039),
    [sym_literal_type] = STATE(3039),
    [sym__number] = STATE(3041),
    [sym_existential_type] = STATE(3039),
    [sym_flow_maybe_type] = STATE(3039),
    [sym_parenthesized_type] = STATE(3039),
    [sym_predefined_type] = STATE(3039),
    [sym_type_arguments] = STATE(484),
    [sym_object_type] = STATE(3039),
    [sym_type_parameters] = STATE(5455),
    [sym_array_type] = STATE(3039),
    [sym_tuple_type] = STATE(3039),
    [sym_readonly_type] = STATE(3007),
    [sym_union_type] = STATE(3039),
    [sym_intersection_type] = STATE(3039),
    [sym_function_type] = STATE(3007),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [aux_sym_array_repeat1] = STATE(4975),
    [aux_sym_array_pattern_repeat1] = STATE(4977),
    [sym_identifier] = ACTIONS(539),
    [anon_sym_export] = ACTIONS(541),
    [anon_sym_STAR] = ACTIONS(543),
    [anon_sym_type] = ACTIONS(541),
    [anon_sym_namespace] = ACTIONS(545),
    [anon_sym_LBRACE] = ACTIONS(547),
    [anon_sym_COMMA] = ACTIONS(549),
    [anon_sym_typeof] = ACTIONS(551),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(541),
    [anon_sym_const] = ACTIONS(133),
    [anon_sym_BANG] = ACTIONS(553),
    [anon_sym_LPAREN] = ACTIONS(138),
    [anon_sym_await] = ACTIONS(555),
    [anon_sym_yield] = ACTIONS(557),
    [anon_sym_LBRACK] = ACTIONS(559),
    [anon_sym_RBRACK] = ACTIONS(649),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(563),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(565),
    [anon_sym_using] = ACTIONS(567),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(569),
    [anon_sym_AMP] = ACTIONS(571),
    [anon_sym_PIPE] = ACTIONS(573),
    [anon_sym_PLUS] = ACTIONS(575),
    [anon_sym_DASH] = ACTIONS(575),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(553),
    [anon_sym_void] = ACTIONS(579),
    [anon_sym_delete] = ACTIONS(581),
    [anon_sym_PLUS_PLUS] = ACTIONS(583),
    [anon_sym_DASH_DASH] = ACTIONS(583),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(188),
    [sym_number] = ACTIONS(190),
    [sym_private_property_identifier] = ACTIONS(585),
    [sym_this] = ACTIONS(587),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(198),
    [sym_false] = ACTIONS(198),
    [sym_null] = ACTIONS(198),
    [sym_undefined] = ACTIONS(589),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(541),
    [anon_sym_readonly] = ACTIONS(591),
    [anon_sym_get] = ACTIONS(541),
    [anon_sym_set] = ACTIONS(541),
    [anon_sym_QMARK] = ACTIONS(593),
    [anon_sym_declare] = ACTIONS(541),
    [anon_sym_public] = ACTIONS(541),
    [anon_sym_private] = ACTIONS(541),
    [anon_sym_protected] = ACTIONS(541),
    [anon_sym_override] = ACTIONS(541),
    [anon_sym_module] = ACTIONS(541),
    [anon_sym_any] = ACTIONS(595),
    [anon_sym_number] = ACTIONS(595),
    [anon_sym_boolean] = ACTIONS(595),
    [anon_sym_string] = ACTIONS(595),
    [anon_sym_symbol] = ACTIONS(595),
    [anon_sym_object] = ACTIONS(595),
    [anon_sym_abstract] = ACTIONS(597),
    [anon_sym_infer] = ACTIONS(599),
    [anon_sym_keyof] = ACTIONS(601),
    [anon_sym_unique] = ACTIONS(214),
    [anon_sym_unknown] = ACTIONS(216),
    [anon_sym_never] = ACTIONS(216),
    [anon_sym_LBRACE_PIPE] = ACTIONS(218),
    [sym_html_comment] = ACTIONS(5),
  },
  [68] = {
    [sym_import] = STATE(3663),
    [sym_parenthesized_expression] = STATE(1322),
    [sym_expression] = STATE(2126),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(4425),
    [sym_assignment_pattern] = STATE(4969),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(4425),
    [sym_nested_identifier] = STATE(5474),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5508),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1396),
    [sym_subscript_expression] = STATE(1396),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3003),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(4425),
    [sym_spread_element] = STATE(4946),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(2213),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(4317),
    [sym_pattern] = STATE(4406),
    [sym_rest_pattern] = STATE(4115),
    [sym_non_null_expression] = STATE(1396),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_nested_type_identifier] = STATE(2939),
    [sym__type_query_member_expression_in_type_annotation] = STATE(3303),
    [sym__type_query_call_expression_in_type_annotation] = STATE(2938),
    [sym_type] = STATE(3773),
    [sym_tuple_parameter] = STATE(4568),
    [sym_optional_tuple_parameter] = STATE(4568),
    [sym_optional_type] = STATE(4568),
    [sym_rest_type] = STATE(4568),
    [sym__tuple_type_member] = STATE(4568),
    [sym_constructor_type] = STATE(3007),
    [sym_primary_type] = STATE(2981),
    [sym_template_literal_type] = STATE(3039),
    [sym_infer_type] = STATE(3007),
    [sym_conditional_type] = STATE(3039),
    [sym_generic_type] = STATE(3039),
    [sym_type_query] = STATE(3039),
    [sym_index_type_query] = STATE(3039),
    [sym_lookup_type] = STATE(3039),
    [sym_literal_type] = STATE(3039),
    [sym__number] = STATE(3041),
    [sym_existential_type] = STATE(3039),
    [sym_flow_maybe_type] = STATE(3039),
    [sym_parenthesized_type] = STATE(3039),
    [sym_predefined_type] = STATE(3039),
    [sym_type_arguments] = STATE(484),
    [sym_object_type] = STATE(3039),
    [sym_type_parameters] = STATE(5455),
    [sym_array_type] = STATE(3039),
    [sym_tuple_type] = STATE(3039),
    [sym_readonly_type] = STATE(3007),
    [sym_union_type] = STATE(3039),
    [sym_intersection_type] = STATE(3039),
    [sym_function_type] = STATE(3007),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [aux_sym_array_repeat1] = STATE(4955),
    [aux_sym_array_pattern_repeat1] = STATE(4977),
    [sym_identifier] = ACTIONS(539),
    [anon_sym_export] = ACTIONS(541),
    [anon_sym_STAR] = ACTIONS(543),
    [anon_sym_type] = ACTIONS(541),
    [anon_sym_namespace] = ACTIONS(545),
    [anon_sym_LBRACE] = ACTIONS(547),
    [anon_sym_COMMA] = ACTIONS(549),
    [anon_sym_typeof] = ACTIONS(551),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(541),
    [anon_sym_const] = ACTIONS(133),
    [anon_sym_BANG] = ACTIONS(553),
    [anon_sym_LPAREN] = ACTIONS(138),
    [anon_sym_await] = ACTIONS(555),
    [anon_sym_yield] = ACTIONS(557),
    [anon_sym_LBRACK] = ACTIONS(559),
    [anon_sym_RBRACK] = ACTIONS(651),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(563),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(565),
    [anon_sym_using] = ACTIONS(567),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(569),
    [anon_sym_AMP] = ACTIONS(571),
    [anon_sym_PIPE] = ACTIONS(573),
    [anon_sym_PLUS] = ACTIONS(575),
    [anon_sym_DASH] = ACTIONS(575),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(553),
    [anon_sym_void] = ACTIONS(579),
    [anon_sym_delete] = ACTIONS(581),
    [anon_sym_PLUS_PLUS] = ACTIONS(583),
    [anon_sym_DASH_DASH] = ACTIONS(583),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(188),
    [sym_number] = ACTIONS(190),
    [sym_private_property_identifier] = ACTIONS(585),
    [sym_this] = ACTIONS(587),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(198),
    [sym_false] = ACTIONS(198),
    [sym_null] = ACTIONS(198),
    [sym_undefined] = ACTIONS(589),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(541),
    [anon_sym_readonly] = ACTIONS(591),
    [anon_sym_get] = ACTIONS(541),
    [anon_sym_set] = ACTIONS(541),
    [anon_sym_QMARK] = ACTIONS(593),
    [anon_sym_declare] = ACTIONS(541),
    [anon_sym_public] = ACTIONS(541),
    [anon_sym_private] = ACTIONS(541),
    [anon_sym_protected] = ACTIONS(541),
    [anon_sym_override] = ACTIONS(541),
    [anon_sym_module] = ACTIONS(541),
    [anon_sym_any] = ACTIONS(595),
    [anon_sym_number] = ACTIONS(595),
    [anon_sym_boolean] = ACTIONS(595),
    [anon_sym_string] = ACTIONS(595),
    [anon_sym_symbol] = ACTIONS(595),
    [anon_sym_object] = ACTIONS(595),
    [anon_sym_abstract] = ACTIONS(597),
    [anon_sym_infer] = ACTIONS(599),
    [anon_sym_keyof] = ACTIONS(601),
    [anon_sym_unique] = ACTIONS(214),
    [anon_sym_unknown] = ACTIONS(216),
    [anon_sym_never] = ACTIONS(216),
    [anon_sym_LBRACE_PIPE] = ACTIONS(218),
    [sym_html_comment] = ACTIONS(5),
  },
  [69] = {
    [sym_import] = STATE(3663),
    [sym_parenthesized_expression] = STATE(1322),
    [sym_expression] = STATE(2126),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(4425),
    [sym_assignment_pattern] = STATE(4969),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(4425),
    [sym_nested_identifier] = STATE(5474),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5508),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1396),
    [sym_subscript_expression] = STATE(1396),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3003),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(4425),
    [sym_spread_element] = STATE(4946),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(2213),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(4317),
    [sym_pattern] = STATE(4406),
    [sym_rest_pattern] = STATE(4115),
    [sym_non_null_expression] = STATE(1396),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_nested_type_identifier] = STATE(2939),
    [sym__type_query_member_expression_in_type_annotation] = STATE(3303),
    [sym__type_query_call_expression_in_type_annotation] = STATE(2938),
    [sym_type] = STATE(3773),
    [sym_tuple_parameter] = STATE(4999),
    [sym_optional_tuple_parameter] = STATE(4999),
    [sym_optional_type] = STATE(4999),
    [sym_rest_type] = STATE(4999),
    [sym__tuple_type_member] = STATE(4999),
    [sym_constructor_type] = STATE(3007),
    [sym_primary_type] = STATE(2981),
    [sym_template_literal_type] = STATE(3039),
    [sym_infer_type] = STATE(3007),
    [sym_conditional_type] = STATE(3039),
    [sym_generic_type] = STATE(3039),
    [sym_type_query] = STATE(3039),
    [sym_index_type_query] = STATE(3039),
    [sym_lookup_type] = STATE(3039),
    [sym_literal_type] = STATE(3039),
    [sym__number] = STATE(3041),
    [sym_existential_type] = STATE(3039),
    [sym_flow_maybe_type] = STATE(3039),
    [sym_parenthesized_type] = STATE(3039),
    [sym_predefined_type] = STATE(3039),
    [sym_type_arguments] = STATE(484),
    [sym_object_type] = STATE(3039),
    [sym_type_parameters] = STATE(5455),
    [sym_array_type] = STATE(3039),
    [sym_tuple_type] = STATE(3039),
    [sym_readonly_type] = STATE(3007),
    [sym_union_type] = STATE(3039),
    [sym_intersection_type] = STATE(3039),
    [sym_function_type] = STATE(3007),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [aux_sym_array_repeat1] = STATE(4955),
    [aux_sym_array_pattern_repeat1] = STATE(4977),
    [sym_identifier] = ACTIONS(539),
    [anon_sym_export] = ACTIONS(541),
    [anon_sym_STAR] = ACTIONS(543),
    [anon_sym_type] = ACTIONS(541),
    [anon_sym_namespace] = ACTIONS(545),
    [anon_sym_LBRACE] = ACTIONS(547),
    [anon_sym_COMMA] = ACTIONS(653),
    [anon_sym_typeof] = ACTIONS(551),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(541),
    [anon_sym_const] = ACTIONS(133),
    [anon_sym_BANG] = ACTIONS(553),
    [anon_sym_LPAREN] = ACTIONS(138),
    [anon_sym_await] = ACTIONS(555),
    [anon_sym_yield] = ACTIONS(557),
    [anon_sym_LBRACK] = ACTIONS(559),
    [anon_sym_RBRACK] = ACTIONS(655),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(563),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(565),
    [anon_sym_using] = ACTIONS(567),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(569),
    [anon_sym_AMP] = ACTIONS(571),
    [anon_sym_PIPE] = ACTIONS(573),
    [anon_sym_PLUS] = ACTIONS(575),
    [anon_sym_DASH] = ACTIONS(575),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(553),
    [anon_sym_void] = ACTIONS(579),
    [anon_sym_delete] = ACTIONS(581),
    [anon_sym_PLUS_PLUS] = ACTIONS(583),
    [anon_sym_DASH_DASH] = ACTIONS(583),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(188),
    [sym_number] = ACTIONS(190),
    [sym_private_property_identifier] = ACTIONS(585),
    [sym_this] = ACTIONS(587),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(198),
    [sym_false] = ACTIONS(198),
    [sym_null] = ACTIONS(198),
    [sym_undefined] = ACTIONS(589),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(541),
    [anon_sym_readonly] = ACTIONS(591),
    [anon_sym_get] = ACTIONS(541),
    [anon_sym_set] = ACTIONS(541),
    [anon_sym_QMARK] = ACTIONS(593),
    [anon_sym_declare] = ACTIONS(541),
    [anon_sym_public] = ACTIONS(541),
    [anon_sym_private] = ACTIONS(541),
    [anon_sym_protected] = ACTIONS(541),
    [anon_sym_override] = ACTIONS(541),
    [anon_sym_module] = ACTIONS(541),
    [anon_sym_any] = ACTIONS(595),
    [anon_sym_number] = ACTIONS(595),
    [anon_sym_boolean] = ACTIONS(595),
    [anon_sym_string] = ACTIONS(595),
    [anon_sym_symbol] = ACTIONS(595),
    [anon_sym_object] = ACTIONS(595),
    [anon_sym_abstract] = ACTIONS(597),
    [anon_sym_infer] = ACTIONS(599),
    [anon_sym_keyof] = ACTIONS(601),
    [anon_sym_unique] = ACTIONS(214),
    [anon_sym_unknown] = ACTIONS(216),
    [anon_sym_never] = ACTIONS(216),
    [anon_sym_LBRACE_PIPE] = ACTIONS(218),
    [sym_html_comment] = ACTIONS(5),
  },
  [70] = {
    [sym_export_statement] = STATE(892),
    [sym_declaration] = STATE(892),
    [sym_import] = STATE(3636),
    [sym_import_statement] = STATE(892),
    [sym_statement] = STATE(790),
    [sym_expression_statement] = STATE(892),
    [sym_variable_declaration] = STATE(831),
    [sym_lexical_declaration] = STATE(831),
    [sym_statement_block] = STATE(892),
    [sym_if_statement] = STATE(892),
    [sym_switch_statement] = STATE(892),
    [sym_for_statement] = STATE(892),
    [sym_for_in_statement] = STATE(892),
    [sym_while_statement] = STATE(892),
    [sym_do_statement] = STATE(892),
    [sym_try_statement] = STATE(892),
    [sym_with_statement] = STATE(892),
    [sym_break_statement] = STATE(892),
    [sym_continue_statement] = STATE(892),
    [sym_debugger_statement] = STATE(892),
    [sym_return_statement] = STATE(892),
    [sym_throw_statement] = STATE(892),
    [sym_empty_statement] = STATE(892),
    [sym_labeled_statement] = STATE(892),
    [sym_parenthesized_expression] = STATE(1362),
    [sym_expression] = STATE(1902),
    [sym_primary_expression] = STATE(1810),
    [sym_yield_expression] = STATE(2358),
    [sym_object] = STATE(2222),
    [sym_object_pattern] = STATE(5492),
    [sym_array] = STATE(2222),
    [sym_array_pattern] = STATE(5492),
    [sym_class] = STATE(2222),
    [sym_class_declaration] = STATE(831),
    [sym_function_expression] = STATE(2222),
    [sym_function_declaration] = STATE(831),
    [sym_generator_function] = STATE(2222),
    [sym_generator_function_declaration] = STATE(831),
    [sym_arrow_function] = STATE(2222),
    [sym__call_signature] = STATE(5821),
    [sym_call_expression] = STATE(2222),
    [sym_new_expression] = STATE(1948),
    [sym_await_expression] = STATE(2358),
    [sym_member_expression] = STATE(1362),
    [sym_subscript_expression] = STATE(1362),
    [sym_assignment_expression] = STATE(2358),
    [sym__augmented_assignment_lhs] = STATE(3025),
    [sym_augmented_assignment_expression] = STATE(2358),
    [sym__destructuring_pattern] = STATE(5492),
    [sym_ternary_expression] = STATE(2358),
    [sym_binary_expression] = STATE(2358),
    [sym_unary_expression] = STATE(2358),
    [sym_update_expression] = STATE(2358),
    [sym_sequence_expression] = STATE(5305),
    [sym_string] = STATE(2222),
    [sym_template_string] = STATE(2222),
    [sym_regex] = STATE(2222),
    [sym_meta_property] = STATE(2222),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1362),
    [sym_function_signature] = STATE(831),
    [sym_type_assertion] = STATE(2358),
    [sym_as_expression] = STATE(2358),
    [sym_satisfies_expression] = STATE(2358),
    [sym_instantiation_expression] = STATE(2358),
    [sym_ambient_declaration] = STATE(831),
    [sym_abstract_class_declaration] = STATE(831),
    [sym_module] = STATE(831),
    [sym_internal_module] = STATE(214),
    [sym_import_alias] = STATE(831),
    [sym_interface_declaration] = STATE(831),
    [sym_enum_declaration] = STATE(831),
    [sym_type_alias_declaration] = STATE(831),
    [sym_type_arguments] = STATE(428),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(3774),
    [sym_identifier] = ACTIONS(9),
    [anon_sym_export] = ACTIONS(13),
    [anon_sym_type] = ACTIONS(15),
    [anon_sym_namespace] = ACTIONS(17),
    [anon_sym_LBRACE] = ACTIONS(19),
    [anon_sym_typeof] = ACTIONS(21),
    [anon_sym_import] = ACTIONS(23),
    [anon_sym_with] = ACTIONS(25),
    [anon_sym_var] = ACTIONS(27),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_const] = ACTIONS(31),
    [anon_sym_BANG] = ACTIONS(33),
    [anon_sym_if] = ACTIONS(35),
    [anon_sym_switch] = ACTIONS(37),
    [anon_sym_for] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_SEMI] = ACTIONS(43),
    [anon_sym_await] = ACTIONS(45),
    [anon_sym_while] = ACTIONS(47),
    [anon_sym_do] = ACTIONS(49),
    [anon_sym_try] = ACTIONS(51),
    [anon_sym_break] = ACTIONS(53),
    [anon_sym_continue] = ACTIONS(55),
    [anon_sym_debugger] = ACTIONS(57),
    [anon_sym_return] = ACTIONS(59),
    [anon_sym_throw] = ACTIONS(61),
    [anon_sym_yield] = ACTIONS(63),
    [anon_sym_LBRACK] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(67),
    [anon_sym_async] = ACTIONS(69),
    [anon_sym_function] = ACTIONS(71),
    [anon_sym_new] = ACTIONS(73),
    [anon_sym_using] = ACTIONS(75),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_SLASH] = ACTIONS(77),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(33),
    [anon_sym_void] = ACTIONS(21),
    [anon_sym_delete] = ACTIONS(21),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_DQUOTE] = ACTIONS(83),
    [anon_sym_SQUOTE] = ACTIONS(85),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(87),
    [sym_number] = ACTIONS(89),
    [sym_private_property_identifier] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(93),
    [sym_true] = ACTIONS(93),
    [sym_false] = ACTIONS(93),
    [sym_null] = ACTIONS(93),
    [sym_undefined] = ACTIONS(95),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(99),
    [anon_sym_readonly] = ACTIONS(99),
    [anon_sym_get] = ACTIONS(99),
    [anon_sym_set] = ACTIONS(99),
    [anon_sym_declare] = ACTIONS(101),
    [anon_sym_public] = ACTIONS(99),
    [anon_sym_private] = ACTIONS(99),
    [anon_sym_protected] = ACTIONS(99),
    [anon_sym_override] = ACTIONS(99),
    [anon_sym_module] = ACTIONS(103),
    [anon_sym_any] = ACTIONS(99),
    [anon_sym_number] = ACTIONS(99),
    [anon_sym_boolean] = ACTIONS(99),
    [anon_sym_string] = ACTIONS(99),
    [anon_sym_symbol] = ACTIONS(99),
    [anon_sym_object] = ACTIONS(99),
    [anon_sym_abstract] = ACTIONS(105),
    [anon_sym_interface] = ACTIONS(107),
    [anon_sym_enum] = ACTIONS(109),
    [sym_html_comment] = ACTIONS(5),
  },
  [71] = {
    [sym_export_statement] = STATE(892),
    [sym_declaration] = STATE(892),
    [sym_import] = STATE(3636),
    [sym_import_statement] = STATE(892),
    [sym_statement] = STATE(931),
    [sym_expression_statement] = STATE(892),
    [sym_variable_declaration] = STATE(831),
    [sym_lexical_declaration] = STATE(831),
    [sym_statement_block] = STATE(892),
    [sym_if_statement] = STATE(892),
    [sym_switch_statement] = STATE(892),
    [sym_for_statement] = STATE(892),
    [sym_for_in_statement] = STATE(892),
    [sym_while_statement] = STATE(892),
    [sym_do_statement] = STATE(892),
    [sym_try_statement] = STATE(892),
    [sym_with_statement] = STATE(892),
    [sym_break_statement] = STATE(892),
    [sym_continue_statement] = STATE(892),
    [sym_debugger_statement] = STATE(892),
    [sym_return_statement] = STATE(892),
    [sym_throw_statement] = STATE(892),
    [sym_empty_statement] = STATE(892),
    [sym_labeled_statement] = STATE(892),
    [sym_parenthesized_expression] = STATE(1362),
    [sym_expression] = STATE(1902),
    [sym_primary_expression] = STATE(1810),
    [sym_yield_expression] = STATE(2358),
    [sym_object] = STATE(2222),
    [sym_object_pattern] = STATE(5492),
    [sym_array] = STATE(2222),
    [sym_array_pattern] = STATE(5492),
    [sym_class] = STATE(2222),
    [sym_class_declaration] = STATE(831),
    [sym_function_expression] = STATE(2222),
    [sym_function_declaration] = STATE(831),
    [sym_generator_function] = STATE(2222),
    [sym_generator_function_declaration] = STATE(831),
    [sym_arrow_function] = STATE(2222),
    [sym__call_signature] = STATE(5821),
    [sym_call_expression] = STATE(2222),
    [sym_new_expression] = STATE(1948),
    [sym_await_expression] = STATE(2358),
    [sym_member_expression] = STATE(1362),
    [sym_subscript_expression] = STATE(1362),
    [sym_assignment_expression] = STATE(2358),
    [sym__augmented_assignment_lhs] = STATE(3025),
    [sym_augmented_assignment_expression] = STATE(2358),
    [sym__destructuring_pattern] = STATE(5492),
    [sym_ternary_expression] = STATE(2358),
    [sym_binary_expression] = STATE(2358),
    [sym_unary_expression] = STATE(2358),
    [sym_update_expression] = STATE(2358),
    [sym_sequence_expression] = STATE(5305),
    [sym_string] = STATE(2222),
    [sym_template_string] = STATE(2222),
    [sym_regex] = STATE(2222),
    [sym_meta_property] = STATE(2222),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1362),
    [sym_function_signature] = STATE(831),
    [sym_type_assertion] = STATE(2358),
    [sym_as_expression] = STATE(2358),
    [sym_satisfies_expression] = STATE(2358),
    [sym_instantiation_expression] = STATE(2358),
    [sym_ambient_declaration] = STATE(831),
    [sym_abstract_class_declaration] = STATE(831),
    [sym_module] = STATE(831),
    [sym_internal_module] = STATE(214),
    [sym_import_alias] = STATE(831),
    [sym_interface_declaration] = STATE(831),
    [sym_enum_declaration] = STATE(831),
    [sym_type_alias_declaration] = STATE(831),
    [sym_type_arguments] = STATE(428),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(3774),
    [sym_identifier] = ACTIONS(9),
    [anon_sym_export] = ACTIONS(13),
    [anon_sym_type] = ACTIONS(15),
    [anon_sym_namespace] = ACTIONS(17),
    [anon_sym_LBRACE] = ACTIONS(19),
    [anon_sym_typeof] = ACTIONS(21),
    [anon_sym_import] = ACTIONS(23),
    [anon_sym_with] = ACTIONS(25),
    [anon_sym_var] = ACTIONS(27),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_const] = ACTIONS(31),
    [anon_sym_BANG] = ACTIONS(33),
    [anon_sym_if] = ACTIONS(35),
    [anon_sym_switch] = ACTIONS(37),
    [anon_sym_for] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_SEMI] = ACTIONS(43),
    [anon_sym_await] = ACTIONS(45),
    [anon_sym_while] = ACTIONS(47),
    [anon_sym_do] = ACTIONS(49),
    [anon_sym_try] = ACTIONS(51),
    [anon_sym_break] = ACTIONS(53),
    [anon_sym_continue] = ACTIONS(55),
    [anon_sym_debugger] = ACTIONS(57),
    [anon_sym_return] = ACTIONS(59),
    [anon_sym_throw] = ACTIONS(61),
    [anon_sym_yield] = ACTIONS(63),
    [anon_sym_LBRACK] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(67),
    [anon_sym_async] = ACTIONS(69),
    [anon_sym_function] = ACTIONS(71),
    [anon_sym_new] = ACTIONS(73),
    [anon_sym_using] = ACTIONS(75),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_SLASH] = ACTIONS(77),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(33),
    [anon_sym_void] = ACTIONS(21),
    [anon_sym_delete] = ACTIONS(21),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_DQUOTE] = ACTIONS(83),
    [anon_sym_SQUOTE] = ACTIONS(85),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(87),
    [sym_number] = ACTIONS(89),
    [sym_private_property_identifier] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(93),
    [sym_true] = ACTIONS(93),
    [sym_false] = ACTIONS(93),
    [sym_null] = ACTIONS(93),
    [sym_undefined] = ACTIONS(95),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(99),
    [anon_sym_readonly] = ACTIONS(99),
    [anon_sym_get] = ACTIONS(99),
    [anon_sym_set] = ACTIONS(99),
    [anon_sym_declare] = ACTIONS(101),
    [anon_sym_public] = ACTIONS(99),
    [anon_sym_private] = ACTIONS(99),
    [anon_sym_protected] = ACTIONS(99),
    [anon_sym_override] = ACTIONS(99),
    [anon_sym_module] = ACTIONS(103),
    [anon_sym_any] = ACTIONS(99),
    [anon_sym_number] = ACTIONS(99),
    [anon_sym_boolean] = ACTIONS(99),
    [anon_sym_string] = ACTIONS(99),
    [anon_sym_symbol] = ACTIONS(99),
    [anon_sym_object] = ACTIONS(99),
    [anon_sym_abstract] = ACTIONS(105),
    [anon_sym_interface] = ACTIONS(107),
    [anon_sym_enum] = ACTIONS(109),
    [sym_html_comment] = ACTIONS(5),
  },
  [72] = {
    [sym_import] = STATE(3636),
    [sym_parenthesized_expression] = STATE(1334),
    [sym_expression] = STATE(2611),
    [sym_primary_expression] = STATE(1696),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(2222),
    [sym_object_pattern] = STATE(5522),
    [sym_array] = STATE(2222),
    [sym_array_pattern] = STATE(5522),
    [sym_class] = STATE(2222),
    [sym_function_expression] = STATE(2222),
    [sym_generator_function] = STATE(2222),
    [sym_arrow_function] = STATE(2222),
    [sym__call_signature] = STATE(5821),
    [sym_call_expression] = STATE(2222),
    [sym_new_expression] = STATE(2694),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1334),
    [sym_subscript_expression] = STATE(1334),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3013),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5522),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(2222),
    [sym_template_string] = STATE(2222),
    [sym_regex] = STATE(2222),
    [sym_meta_property] = STATE(2222),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1334),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(539),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4408),
    [aux_sym_object_repeat1] = STATE(4792),
    [aux_sym_object_pattern_repeat1] = STATE(4815),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_export] = ACTIONS(659),
    [anon_sym_STAR] = ACTIONS(120),
    [anon_sym_type] = ACTIONS(659),
    [anon_sym_EQ] = ACTIONS(661),
    [anon_sym_as] = ACTIONS(120),
    [anon_sym_namespace] = ACTIONS(663),
    [anon_sym_LBRACE] = ACTIONS(665),
    [anon_sym_COMMA] = ACTIONS(154),
    [anon_sym_RBRACE] = ACTIONS(667),
    [anon_sym_typeof] = ACTIONS(179),
    [anon_sym_import] = ACTIONS(669),
    [anon_sym_let] = ACTIONS(659),
    [anon_sym_BANG] = ACTIONS(179),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_SEMI] = ACTIONS(154),
    [anon_sym_await] = ACTIONS(140),
    [anon_sym_in] = ACTIONS(120),
    [anon_sym_COLON] = ACTIONS(671),
    [anon_sym_yield] = ACTIONS(142),
    [anon_sym_LBRACK] = ACTIONS(65),
    [anon_sym_DOT] = ACTIONS(674),
    [anon_sym_class] = ACTIONS(676),
    [anon_sym_async] = ACTIONS(678),
    [anon_sym_function] = ACTIONS(680),
    [anon_sym_EQ_GT] = ACTIONS(682),
    [anon_sym_QMARK_DOT] = ACTIONS(154),
    [anon_sym_new] = ACTIONS(684),
    [anon_sym_using] = ACTIONS(158),
    [anon_sym_PLUS_EQ] = ACTIONS(160),
    [anon_sym_DASH_EQ] = ACTIONS(160),
    [anon_sym_STAR_EQ] = ACTIONS(160),
    [anon_sym_SLASH_EQ] = ACTIONS(160),
    [anon_sym_PERCENT_EQ] = ACTIONS(160),
    [anon_sym_CARET_EQ] = ACTIONS(160),
    [anon_sym_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_LT_LT_EQ] = ACTIONS(160),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(160),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP] = ACTIONS(120),
    [anon_sym_PIPE_PIPE] = ACTIONS(120),
    [anon_sym_GT_GT] = ACTIONS(120),
    [anon_sym_GT_GT_GT] = ACTIONS(120),
    [anon_sym_LT_LT] = ACTIONS(120),
    [anon_sym_AMP] = ACTIONS(120),
    [anon_sym_CARET] = ACTIONS(120),
    [anon_sym_PIPE] = ACTIONS(120),
    [anon_sym_PLUS] = ACTIONS(179),
    [anon_sym_DASH] = ACTIONS(179),
    [anon_sym_SLASH] = ACTIONS(77),
    [anon_sym_PERCENT] = ACTIONS(120),
    [anon_sym_STAR_STAR] = ACTIONS(120),
    [anon_sym_LT] = ACTIONS(173),
    [anon_sym_LT_EQ] = ACTIONS(154),
    [anon_sym_EQ_EQ] = ACTIONS(120),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(154),
    [anon_sym_BANG_EQ] = ACTIONS(120),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(154),
    [anon_sym_GT_EQ] = ACTIONS(154),
    [anon_sym_GT] = ACTIONS(120),
    [anon_sym_QMARK_QMARK] = ACTIONS(120),
    [anon_sym_instanceof] = ACTIONS(120),
    [anon_sym_TILDE] = ACTIONS(175),
    [anon_sym_void] = ACTIONS(179),
    [anon_sym_delete] = ACTIONS(179),
    [anon_sym_PLUS_PLUS] = ACTIONS(686),
    [anon_sym_DASH_DASH] = ACTIONS(686),
    [anon_sym_DQUOTE] = ACTIONS(83),
    [anon_sym_SQUOTE] = ACTIONS(85),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(87),
    [sym_number] = ACTIONS(89),
    [sym_private_property_identifier] = ACTIONS(192),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(93),
    [sym_true] = ACTIONS(93),
    [sym_false] = ACTIONS(93),
    [sym_null] = ACTIONS(93),
    [sym_undefined] = ACTIONS(688),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(659),
    [anon_sym_readonly] = ACTIONS(659),
    [anon_sym_get] = ACTIONS(659),
    [anon_sym_set] = ACTIONS(659),
    [anon_sym_QMARK] = ACTIONS(690),
    [anon_sym_declare] = ACTIONS(659),
    [anon_sym_public] = ACTIONS(659),
    [anon_sym_private] = ACTIONS(659),
    [anon_sym_protected] = ACTIONS(659),
    [anon_sym_override] = ACTIONS(659),
    [anon_sym_module] = ACTIONS(659),
    [anon_sym_any] = ACTIONS(659),
    [anon_sym_number] = ACTIONS(659),
    [anon_sym_boolean] = ACTIONS(659),
    [anon_sym_string] = ACTIONS(659),
    [anon_sym_symbol] = ACTIONS(659),
    [anon_sym_object] = ACTIONS(659),
    [anon_sym_satisfies] = ACTIONS(120),
    [sym__automatic_semicolon] = ACTIONS(154),
    [sym__ternary_qmark] = ACTIONS(154),
    [sym_html_comment] = ACTIONS(5),
  },
  [73] = {
    [sym_import] = STATE(3636),
    [sym_parenthesized_expression] = STATE(1334),
    [sym_expression] = STATE(2611),
    [sym_primary_expression] = STATE(1696),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(2222),
    [sym_object_pattern] = STATE(5522),
    [sym_array] = STATE(2222),
    [sym_array_pattern] = STATE(5522),
    [sym_class] = STATE(2222),
    [sym_function_expression] = STATE(2222),
    [sym_generator_function] = STATE(2222),
    [sym_arrow_function] = STATE(2222),
    [sym__call_signature] = STATE(5821),
    [sym_call_expression] = STATE(2222),
    [sym_new_expression] = STATE(2694),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1334),
    [sym_subscript_expression] = STATE(1334),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3013),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5522),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(2222),
    [sym_template_string] = STATE(2222),
    [sym_regex] = STATE(2222),
    [sym_meta_property] = STATE(2222),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1334),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(539),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4408),
    [aux_sym_object_repeat1] = STATE(4810),
    [aux_sym_object_pattern_repeat1] = STATE(4815),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_export] = ACTIONS(659),
    [anon_sym_STAR] = ACTIONS(120),
    [anon_sym_type] = ACTIONS(659),
    [anon_sym_EQ] = ACTIONS(661),
    [anon_sym_as] = ACTIONS(120),
    [anon_sym_namespace] = ACTIONS(663),
    [anon_sym_LBRACE] = ACTIONS(665),
    [anon_sym_COMMA] = ACTIONS(154),
    [anon_sym_RBRACE] = ACTIONS(692),
    [anon_sym_typeof] = ACTIONS(179),
    [anon_sym_import] = ACTIONS(669),
    [anon_sym_let] = ACTIONS(659),
    [anon_sym_BANG] = ACTIONS(179),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_SEMI] = ACTIONS(154),
    [anon_sym_await] = ACTIONS(140),
    [anon_sym_in] = ACTIONS(120),
    [anon_sym_COLON] = ACTIONS(671),
    [anon_sym_yield] = ACTIONS(142),
    [anon_sym_LBRACK] = ACTIONS(65),
    [anon_sym_DOT] = ACTIONS(674),
    [anon_sym_class] = ACTIONS(676),
    [anon_sym_async] = ACTIONS(678),
    [anon_sym_function] = ACTIONS(680),
    [anon_sym_EQ_GT] = ACTIONS(682),
    [anon_sym_QMARK_DOT] = ACTIONS(154),
    [anon_sym_new] = ACTIONS(684),
    [anon_sym_using] = ACTIONS(158),
    [anon_sym_PLUS_EQ] = ACTIONS(160),
    [anon_sym_DASH_EQ] = ACTIONS(160),
    [anon_sym_STAR_EQ] = ACTIONS(160),
    [anon_sym_SLASH_EQ] = ACTIONS(160),
    [anon_sym_PERCENT_EQ] = ACTIONS(160),
    [anon_sym_CARET_EQ] = ACTIONS(160),
    [anon_sym_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_LT_LT_EQ] = ACTIONS(160),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(160),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP] = ACTIONS(120),
    [anon_sym_PIPE_PIPE] = ACTIONS(120),
    [anon_sym_GT_GT] = ACTIONS(120),
    [anon_sym_GT_GT_GT] = ACTIONS(120),
    [anon_sym_LT_LT] = ACTIONS(120),
    [anon_sym_AMP] = ACTIONS(120),
    [anon_sym_CARET] = ACTIONS(120),
    [anon_sym_PIPE] = ACTIONS(120),
    [anon_sym_PLUS] = ACTIONS(179),
    [anon_sym_DASH] = ACTIONS(179),
    [anon_sym_SLASH] = ACTIONS(77),
    [anon_sym_PERCENT] = ACTIONS(120),
    [anon_sym_STAR_STAR] = ACTIONS(120),
    [anon_sym_LT] = ACTIONS(173),
    [anon_sym_LT_EQ] = ACTIONS(154),
    [anon_sym_EQ_EQ] = ACTIONS(120),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(154),
    [anon_sym_BANG_EQ] = ACTIONS(120),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(154),
    [anon_sym_GT_EQ] = ACTIONS(154),
    [anon_sym_GT] = ACTIONS(120),
    [anon_sym_QMARK_QMARK] = ACTIONS(120),
    [anon_sym_instanceof] = ACTIONS(120),
    [anon_sym_TILDE] = ACTIONS(175),
    [anon_sym_void] = ACTIONS(179),
    [anon_sym_delete] = ACTIONS(179),
    [anon_sym_PLUS_PLUS] = ACTIONS(686),
    [anon_sym_DASH_DASH] = ACTIONS(686),
    [anon_sym_DQUOTE] = ACTIONS(83),
    [anon_sym_SQUOTE] = ACTIONS(85),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(87),
    [sym_number] = ACTIONS(89),
    [sym_private_property_identifier] = ACTIONS(192),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(93),
    [sym_true] = ACTIONS(93),
    [sym_false] = ACTIONS(93),
    [sym_null] = ACTIONS(93),
    [sym_undefined] = ACTIONS(688),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(659),
    [anon_sym_readonly] = ACTIONS(659),
    [anon_sym_get] = ACTIONS(659),
    [anon_sym_set] = ACTIONS(659),
    [anon_sym_QMARK] = ACTIONS(690),
    [anon_sym_declare] = ACTIONS(659),
    [anon_sym_public] = ACTIONS(659),
    [anon_sym_private] = ACTIONS(659),
    [anon_sym_protected] = ACTIONS(659),
    [anon_sym_override] = ACTIONS(659),
    [anon_sym_module] = ACTIONS(659),
    [anon_sym_any] = ACTIONS(659),
    [anon_sym_number] = ACTIONS(659),
    [anon_sym_boolean] = ACTIONS(659),
    [anon_sym_string] = ACTIONS(659),
    [anon_sym_symbol] = ACTIONS(659),
    [anon_sym_object] = ACTIONS(659),
    [anon_sym_satisfies] = ACTIONS(120),
    [sym__automatic_semicolon] = ACTIONS(154),
    [sym__ternary_qmark] = ACTIONS(154),
    [sym_html_comment] = ACTIONS(5),
  },
  [74] = {
    [sym_import] = STATE(3636),
    [sym_parenthesized_expression] = STATE(1334),
    [sym_expression] = STATE(2611),
    [sym_primary_expression] = STATE(1696),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(2222),
    [sym_object_pattern] = STATE(5522),
    [sym_array] = STATE(2222),
    [sym_array_pattern] = STATE(5522),
    [sym_class] = STATE(2222),
    [sym_function_expression] = STATE(2222),
    [sym_generator_function] = STATE(2222),
    [sym_arrow_function] = STATE(2222),
    [sym__call_signature] = STATE(5821),
    [sym_call_expression] = STATE(2222),
    [sym_new_expression] = STATE(2694),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1334),
    [sym_subscript_expression] = STATE(1334),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3013),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5522),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(2222),
    [sym_template_string] = STATE(2222),
    [sym_regex] = STATE(2222),
    [sym_meta_property] = STATE(2222),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1334),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(539),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4408),
    [aux_sym_object_repeat1] = STATE(4792),
    [aux_sym_object_pattern_repeat1] = STATE(4815),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_export] = ACTIONS(659),
    [anon_sym_STAR] = ACTIONS(120),
    [anon_sym_type] = ACTIONS(659),
    [anon_sym_EQ] = ACTIONS(661),
    [anon_sym_as] = ACTIONS(120),
    [anon_sym_namespace] = ACTIONS(663),
    [anon_sym_LBRACE] = ACTIONS(665),
    [anon_sym_COMMA] = ACTIONS(154),
    [anon_sym_RBRACE] = ACTIONS(694),
    [anon_sym_typeof] = ACTIONS(179),
    [anon_sym_import] = ACTIONS(669),
    [anon_sym_let] = ACTIONS(659),
    [anon_sym_BANG] = ACTIONS(179),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_SEMI] = ACTIONS(154),
    [anon_sym_await] = ACTIONS(140),
    [anon_sym_in] = ACTIONS(120),
    [anon_sym_COLON] = ACTIONS(671),
    [anon_sym_yield] = ACTIONS(142),
    [anon_sym_LBRACK] = ACTIONS(65),
    [anon_sym_DOT] = ACTIONS(674),
    [anon_sym_class] = ACTIONS(676),
    [anon_sym_async] = ACTIONS(678),
    [anon_sym_function] = ACTIONS(680),
    [anon_sym_EQ_GT] = ACTIONS(682),
    [anon_sym_QMARK_DOT] = ACTIONS(154),
    [anon_sym_new] = ACTIONS(684),
    [anon_sym_using] = ACTIONS(158),
    [anon_sym_PLUS_EQ] = ACTIONS(160),
    [anon_sym_DASH_EQ] = ACTIONS(160),
    [anon_sym_STAR_EQ] = ACTIONS(160),
    [anon_sym_SLASH_EQ] = ACTIONS(160),
    [anon_sym_PERCENT_EQ] = ACTIONS(160),
    [anon_sym_CARET_EQ] = ACTIONS(160),
    [anon_sym_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_LT_LT_EQ] = ACTIONS(160),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(160),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP] = ACTIONS(120),
    [anon_sym_PIPE_PIPE] = ACTIONS(120),
    [anon_sym_GT_GT] = ACTIONS(120),
    [anon_sym_GT_GT_GT] = ACTIONS(120),
    [anon_sym_LT_LT] = ACTIONS(120),
    [anon_sym_AMP] = ACTIONS(120),
    [anon_sym_CARET] = ACTIONS(120),
    [anon_sym_PIPE] = ACTIONS(120),
    [anon_sym_PLUS] = ACTIONS(179),
    [anon_sym_DASH] = ACTIONS(179),
    [anon_sym_SLASH] = ACTIONS(77),
    [anon_sym_PERCENT] = ACTIONS(120),
    [anon_sym_STAR_STAR] = ACTIONS(120),
    [anon_sym_LT] = ACTIONS(173),
    [anon_sym_LT_EQ] = ACTIONS(154),
    [anon_sym_EQ_EQ] = ACTIONS(120),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(154),
    [anon_sym_BANG_EQ] = ACTIONS(120),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(154),
    [anon_sym_GT_EQ] = ACTIONS(154),
    [anon_sym_GT] = ACTIONS(120),
    [anon_sym_QMARK_QMARK] = ACTIONS(120),
    [anon_sym_instanceof] = ACTIONS(120),
    [anon_sym_TILDE] = ACTIONS(175),
    [anon_sym_void] = ACTIONS(179),
    [anon_sym_delete] = ACTIONS(179),
    [anon_sym_PLUS_PLUS] = ACTIONS(686),
    [anon_sym_DASH_DASH] = ACTIONS(686),
    [anon_sym_DQUOTE] = ACTIONS(83),
    [anon_sym_SQUOTE] = ACTIONS(85),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(87),
    [sym_number] = ACTIONS(89),
    [sym_private_property_identifier] = ACTIONS(192),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(93),
    [sym_true] = ACTIONS(93),
    [sym_false] = ACTIONS(93),
    [sym_null] = ACTIONS(93),
    [sym_undefined] = ACTIONS(688),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(659),
    [anon_sym_readonly] = ACTIONS(659),
    [anon_sym_get] = ACTIONS(659),
    [anon_sym_set] = ACTIONS(659),
    [anon_sym_QMARK] = ACTIONS(690),
    [anon_sym_declare] = ACTIONS(659),
    [anon_sym_public] = ACTIONS(659),
    [anon_sym_private] = ACTIONS(659),
    [anon_sym_protected] = ACTIONS(659),
    [anon_sym_override] = ACTIONS(659),
    [anon_sym_module] = ACTIONS(659),
    [anon_sym_any] = ACTIONS(659),
    [anon_sym_number] = ACTIONS(659),
    [anon_sym_boolean] = ACTIONS(659),
    [anon_sym_string] = ACTIONS(659),
    [anon_sym_symbol] = ACTIONS(659),
    [anon_sym_object] = ACTIONS(659),
    [anon_sym_satisfies] = ACTIONS(120),
    [sym__automatic_semicolon] = ACTIONS(154),
    [sym__ternary_qmark] = ACTIONS(154),
    [sym_html_comment] = ACTIONS(5),
  },
  [75] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1213),
    [sym_expression] = STATE(2644),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(3722),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(3722),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5800),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1295),
    [sym_subscript_expression] = STATE(1295),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3013),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(3722),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_pattern] = STATE(4312),
    [sym_rest_pattern] = STATE(3684),
    [sym_non_null_expression] = STATE(1295),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(539),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(696),
    [anon_sym_export] = ACTIONS(113),
    [anon_sym_STAR] = ACTIONS(120),
    [anon_sym_type] = ACTIONS(113),
    [anon_sym_EQ] = ACTIONS(117),
    [anon_sym_as] = ACTIONS(120),
    [anon_sym_namespace] = ACTIONS(122),
    [anon_sym_LBRACE] = ACTIONS(698),
    [anon_sym_COMMA] = ACTIONS(126),
    [anon_sym_typeof] = ACTIONS(179),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(113),
    [anon_sym_BANG] = ACTIONS(135),
    [anon_sym_LPAREN] = ACTIONS(700),
    [anon_sym_RPAREN] = ACTIONS(126),
    [anon_sym_await] = ACTIONS(140),
    [anon_sym_in] = ACTIONS(120),
    [anon_sym_COLON] = ACTIONS(126),
    [anon_sym_yield] = ACTIONS(142),
    [anon_sym_LBRACK] = ACTIONS(703),
    [anon_sym_DOT] = ACTIONS(120),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(148),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_EQ_GT] = ACTIONS(152),
    [anon_sym_QMARK_DOT] = ACTIONS(154),
    [anon_sym_new] = ACTIONS(706),
    [anon_sym_using] = ACTIONS(158),
    [anon_sym_PLUS_EQ] = ACTIONS(160),
    [anon_sym_DASH_EQ] = ACTIONS(160),
    [anon_sym_STAR_EQ] = ACTIONS(160),
    [anon_sym_SLASH_EQ] = ACTIONS(160),
    [anon_sym_PERCENT_EQ] = ACTIONS(160),
    [anon_sym_CARET_EQ] = ACTIONS(160),
    [anon_sym_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_LT_LT_EQ] = ACTIONS(160),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(160),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(160),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(162),
    [anon_sym_AMP_AMP] = ACTIONS(120),
    [anon_sym_PIPE_PIPE] = ACTIONS(120),
    [anon_sym_GT_GT] = ACTIONS(120),
    [anon_sym_GT_GT_GT] = ACTIONS(120),
    [anon_sym_LT_LT] = ACTIONS(120),
    [anon_sym_AMP] = ACTIONS(120),
    [anon_sym_CARET] = ACTIONS(120),
    [anon_sym_PIPE] = ACTIONS(120),
    [anon_sym_PLUS] = ACTIONS(135),
    [anon_sym_DASH] = ACTIONS(135),
    [anon_sym_SLASH] = ACTIONS(170),
    [anon_sym_PERCENT] = ACTIONS(120),
    [anon_sym_STAR_STAR] = ACTIONS(120),
    [anon_sym_LT] = ACTIONS(708),
    [anon_sym_LT_EQ] = ACTIONS(154),
    [anon_sym_EQ_EQ] = ACTIONS(120),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(154),
    [anon_sym_BANG_EQ] = ACTIONS(120),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(154),
    [anon_sym_GT_EQ] = ACTIONS(154),
    [anon_sym_GT] = ACTIONS(120),
    [anon_sym_QMARK_QMARK] = ACTIONS(120),
    [anon_sym_instanceof] = ACTIONS(120),
    [anon_sym_TILDE] = ACTIONS(175),
    [anon_sym_void] = ACTIONS(179),
    [anon_sym_delete] = ACTIONS(179),
    [anon_sym_PLUS_PLUS] = ACTIONS(181),
    [anon_sym_DASH_DASH] = ACTIONS(181),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(711),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(192),
    [sym_this] = ACTIONS(716),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(718),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(113),
    [anon_sym_readonly] = ACTIONS(113),
    [anon_sym_get] = ACTIONS(113),
    [anon_sym_set] = ACTIONS(113),
    [anon_sym_QMARK] = ACTIONS(720),
    [anon_sym_declare] = ACTIONS(113),
    [anon_sym_public] = ACTIONS(113),
    [anon_sym_private] = ACTIONS(113),
    [anon_sym_protected] = ACTIONS(113),
    [anon_sym_override] = ACTIONS(113),
    [anon_sym_module] = ACTIONS(113),
    [anon_sym_any] = ACTIONS(113),
    [anon_sym_number] = ACTIONS(113),
    [anon_sym_boolean] = ACTIONS(113),
    [anon_sym_string] = ACTIONS(113),
    [anon_sym_symbol] = ACTIONS(113),
    [anon_sym_object] = ACTIONS(113),
    [anon_sym_satisfies] = ACTIONS(120),
    [sym__ternary_qmark] = ACTIONS(154),
    [sym_html_comment] = ACTIONS(5),
  },
  [76] = {
    [sym_import] = STATE(3563),
    [sym_parenthesized_expression] = STATE(1398),
    [sym_expression] = STATE(1816),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(4309),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(4309),
    [sym_nested_identifier] = STATE(5474),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5558),
    [sym__formal_parameter] = STATE(4621),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1352),
    [sym_subscript_expression] = STATE(1352),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(2980),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(4309),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_sequence_expression] = STATE(5780),
    [sym_string] = STATE(2338),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(4087),
    [sym_pattern] = STATE(4339),
    [sym_rest_pattern] = STATE(3684),
    [sym_non_null_expression] = STATE(1352),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_nested_type_identifier] = STATE(2939),
    [sym_accessibility_modifier] = STATE(288),
    [sym_override_modifier] = STATE(303),
    [sym_required_parameter] = STATE(4621),
    [sym_optional_parameter] = STATE(4621),
    [sym__parameter_name] = STATE(3624),
    [sym__type_query_member_expression_in_type_annotation] = STATE(2937),
    [sym__type_query_call_expression_in_type_annotation] = STATE(2938),
    [sym_type] = STATE(4387),
    [sym_constructor_type] = STATE(3007),
    [sym_primary_type] = STATE(2981),
    [sym_template_literal_type] = STATE(3039),
    [sym_infer_type] = STATE(3007),
    [sym_conditional_type] = STATE(3039),
    [sym_generic_type] = STATE(3039),
    [sym_type_query] = STATE(3039),
    [sym_index_type_query] = STATE(3039),
    [sym_lookup_type] = STATE(3039),
    [sym_literal_type] = STATE(3039),
    [sym__number] = STATE(3041),
    [sym_existential_type] = STATE(3039),
    [sym_flow_maybe_type] = STATE(3039),
    [sym_parenthesized_type] = STATE(3039),
    [sym_predefined_type] = STATE(3039),
    [sym_type_arguments] = STATE(638),
    [sym_object_type] = STATE(3039),
    [sym_type_parameters] = STATE(5158),
    [sym_array_type] = STATE(3039),
    [sym_tuple_type] = STATE(3039),
    [sym_readonly_type] = STATE(3007),
    [sym_union_type] = STATE(3039),
    [sym_intersection_type] = STATE(3039),
    [sym_function_type] = STATE(3007),
    [aux_sym_export_statement_repeat1] = STATE(267),
    [sym_identifier] = ACTIONS(722),
    [anon_sym_export] = ACTIONS(724),
    [anon_sym_STAR] = ACTIONS(543),
    [anon_sym_type] = ACTIONS(724),
    [anon_sym_namespace] = ACTIONS(726),
    [anon_sym_LBRACE] = ACTIONS(728),
    [anon_sym_typeof] = ACTIONS(730),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(724),
    [anon_sym_const] = ACTIONS(133),
    [anon_sym_BANG] = ACTIONS(732),
    [anon_sym_LPAREN] = ACTIONS(138),
    [anon_sym_RPAREN] = ACTIONS(734),
    [anon_sym_await] = ACTIONS(736),
    [anon_sym_yield] = ACTIONS(738),
    [anon_sym_LBRACK] = ACTIONS(740),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(742),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(744),
    [anon_sym_using] = ACTIONS(746),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(162),
    [anon_sym_AMP] = ACTIONS(748),
    [anon_sym_PIPE] = ACTIONS(750),
    [anon_sym_PLUS] = ACTIONS(752),
    [anon_sym_DASH] = ACTIONS(752),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(732),
    [anon_sym_void] = ACTIONS(754),
    [anon_sym_delete] = ACTIONS(756),
    [anon_sym_PLUS_PLUS] = ACTIONS(758),
    [anon_sym_DASH_DASH] = ACTIONS(758),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(760),
    [sym_number] = ACTIONS(762),
    [sym_private_property_identifier] = ACTIONS(764),
    [sym_this] = ACTIONS(766),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(768),
    [sym_false] = ACTIONS(768),
    [sym_null] = ACTIONS(768),
    [sym_undefined] = ACTIONS(770),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(724),
    [anon_sym_readonly] = ACTIONS(772),
    [anon_sym_get] = ACTIONS(724),
    [anon_sym_set] = ACTIONS(724),
    [anon_sym_QMARK] = ACTIONS(774),
    [anon_sym_declare] = ACTIONS(724),
    [anon_sym_public] = ACTIONS(776),
    [anon_sym_private] = ACTIONS(776),
    [anon_sym_protected] = ACTIONS(776),
    [anon_sym_override] = ACTIONS(778),
    [anon_sym_module] = ACTIONS(724),
    [anon_sym_any] = ACTIONS(780),
    [anon_sym_number] = ACTIONS(780),
    [anon_sym_boolean] = ACTIONS(780),
    [anon_sym_string] = ACTIONS(780),
    [anon_sym_symbol] = ACTIONS(780),
    [anon_sym_object] = ACTIONS(780),
    [anon_sym_abstract] = ACTIONS(208),
    [anon_sym_infer] = ACTIONS(210),
    [anon_sym_keyof] = ACTIONS(212),
    [anon_sym_unique] = ACTIONS(214),
    [anon_sym_unknown] = ACTIONS(216),
    [anon_sym_never] = ACTIONS(216),
    [anon_sym_LBRACE_PIPE] = ACTIONS(218),
    [sym_html_comment] = ACTIONS(5),
  },
  [77] = {
    [sym_import] = STATE(3563),
    [sym_parenthesized_expression] = STATE(1398),
    [sym_expression] = STATE(1832),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(4309),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(4309),
    [sym_nested_identifier] = STATE(5474),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5558),
    [sym__formal_parameter] = STATE(4621),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1352),
    [sym_subscript_expression] = STATE(1352),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(2980),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(4309),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_sequence_expression] = STATE(5679),
    [sym_string] = STATE(2338),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(4087),
    [sym_pattern] = STATE(4339),
    [sym_rest_pattern] = STATE(3684),
    [sym_non_null_expression] = STATE(1352),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_nested_type_identifier] = STATE(2939),
    [sym_accessibility_modifier] = STATE(288),
    [sym_override_modifier] = STATE(303),
    [sym_required_parameter] = STATE(4621),
    [sym_optional_parameter] = STATE(4621),
    [sym__parameter_name] = STATE(3624),
    [sym__type_query_member_expression_in_type_annotation] = STATE(2937),
    [sym__type_query_call_expression_in_type_annotation] = STATE(2938),
    [sym_type] = STATE(4434),
    [sym_constructor_type] = STATE(3007),
    [sym_primary_type] = STATE(2981),
    [sym_template_literal_type] = STATE(3039),
    [sym_infer_type] = STATE(3007),
    [sym_conditional_type] = STATE(3039),
    [sym_generic_type] = STATE(3039),
    [sym_type_query] = STATE(3039),
    [sym_index_type_query] = STATE(3039),
    [sym_lookup_type] = STATE(3039),
    [sym_literal_type] = STATE(3039),
    [sym__number] = STATE(3041),
    [sym_existential_type] = STATE(3039),
    [sym_flow_maybe_type] = STATE(3039),
    [sym_parenthesized_type] = STATE(3039),
    [sym_predefined_type] = STATE(3039),
    [sym_type_arguments] = STATE(638),
    [sym_object_type] = STATE(3039),
    [sym_type_parameters] = STATE(5158),
    [sym_array_type] = STATE(3039),
    [sym_tuple_type] = STATE(3039),
    [sym_readonly_type] = STATE(3007),
    [sym_union_type] = STATE(3039),
    [sym_intersection_type] = STATE(3039),
    [sym_function_type] = STATE(3007),
    [aux_sym_export_statement_repeat1] = STATE(267),
    [sym_identifier] = ACTIONS(722),
    [anon_sym_export] = ACTIONS(724),
    [anon_sym_STAR] = ACTIONS(543),
    [anon_sym_type] = ACTIONS(724),
    [anon_sym_namespace] = ACTIONS(726),
    [anon_sym_LBRACE] = ACTIONS(728),
    [anon_sym_typeof] = ACTIONS(730),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(724),
    [anon_sym_const] = ACTIONS(133),
    [anon_sym_BANG] = ACTIONS(732),
    [anon_sym_LPAREN] = ACTIONS(138),
    [anon_sym_RPAREN] = ACTIONS(734),
    [anon_sym_await] = ACTIONS(736),
    [anon_sym_yield] = ACTIONS(738),
    [anon_sym_LBRACK] = ACTIONS(740),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(742),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(744),
    [anon_sym_using] = ACTIONS(746),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(162),
    [anon_sym_AMP] = ACTIONS(748),
    [anon_sym_PIPE] = ACTIONS(750),
    [anon_sym_PLUS] = ACTIONS(752),
    [anon_sym_DASH] = ACTIONS(752),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(732),
    [anon_sym_void] = ACTIONS(754),
    [anon_sym_delete] = ACTIONS(756),
    [anon_sym_PLUS_PLUS] = ACTIONS(758),
    [anon_sym_DASH_DASH] = ACTIONS(758),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(760),
    [sym_number] = ACTIONS(762),
    [sym_private_property_identifier] = ACTIONS(764),
    [sym_this] = ACTIONS(766),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(768),
    [sym_false] = ACTIONS(768),
    [sym_null] = ACTIONS(768),
    [sym_undefined] = ACTIONS(770),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(724),
    [anon_sym_readonly] = ACTIONS(772),
    [anon_sym_get] = ACTIONS(724),
    [anon_sym_set] = ACTIONS(724),
    [anon_sym_QMARK] = ACTIONS(774),
    [anon_sym_declare] = ACTIONS(724),
    [anon_sym_public] = ACTIONS(776),
    [anon_sym_private] = ACTIONS(776),
    [anon_sym_protected] = ACTIONS(776),
    [anon_sym_override] = ACTIONS(778),
    [anon_sym_module] = ACTIONS(724),
    [anon_sym_any] = ACTIONS(780),
    [anon_sym_number] = ACTIONS(780),
    [anon_sym_boolean] = ACTIONS(780),
    [anon_sym_string] = ACTIONS(780),
    [anon_sym_symbol] = ACTIONS(780),
    [anon_sym_object] = ACTIONS(780),
    [anon_sym_abstract] = ACTIONS(208),
    [anon_sym_infer] = ACTIONS(210),
    [anon_sym_keyof] = ACTIONS(212),
    [anon_sym_unique] = ACTIONS(214),
    [anon_sym_unknown] = ACTIONS(216),
    [anon_sym_never] = ACTIONS(216),
    [anon_sym_LBRACE_PIPE] = ACTIONS(218),
    [sym_html_comment] = ACTIONS(5),
  },
  [78] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1213),
    [sym_expression] = STATE(2644),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(3722),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(3722),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5800),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1295),
    [sym_subscript_expression] = STATE(1295),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3013),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(3722),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_pattern] = STATE(4303),
    [sym_rest_pattern] = STATE(3684),
    [sym_non_null_expression] = STATE(1295),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(539),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(696),
    [anon_sym_export] = ACTIONS(113),
    [anon_sym_STAR] = ACTIONS(120),
    [anon_sym_type] = ACTIONS(113),
    [anon_sym_EQ] = ACTIONS(220),
    [anon_sym_as] = ACTIONS(120),
    [anon_sym_namespace] = ACTIONS(122),
    [anon_sym_LBRACE] = ACTIONS(698),
    [anon_sym_COMMA] = ACTIONS(223),
    [anon_sym_typeof] = ACTIONS(179),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(113),
    [anon_sym_BANG] = ACTIONS(135),
    [anon_sym_LPAREN] = ACTIONS(700),
    [anon_sym_RPAREN] = ACTIONS(223),
    [anon_sym_await] = ACTIONS(140),
    [anon_sym_in] = ACTIONS(120),
    [anon_sym_COLON] = ACTIONS(223),
    [anon_sym_yield] = ACTIONS(142),
    [anon_sym_LBRACK] = ACTIONS(703),
    [anon_sym_DOT] = ACTIONS(120),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(148),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_EQ_GT] = ACTIONS(225),
    [anon_sym_QMARK_DOT] = ACTIONS(154),
    [anon_sym_new] = ACTIONS(706),
    [anon_sym_using] = ACTIONS(158),
    [anon_sym_PLUS_EQ] = ACTIONS(160),
    [anon_sym_DASH_EQ] = ACTIONS(160),
    [anon_sym_STAR_EQ] = ACTIONS(160),
    [anon_sym_SLASH_EQ] = ACTIONS(160),
    [anon_sym_PERCENT_EQ] = ACTIONS(160),
    [anon_sym_CARET_EQ] = ACTIONS(160),
    [anon_sym_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_LT_LT_EQ] = ACTIONS(160),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(160),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(160),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(162),
    [anon_sym_AMP_AMP] = ACTIONS(120),
    [anon_sym_PIPE_PIPE] = ACTIONS(120),
    [anon_sym_GT_GT] = ACTIONS(120),
    [anon_sym_GT_GT_GT] = ACTIONS(120),
    [anon_sym_LT_LT] = ACTIONS(120),
    [anon_sym_AMP] = ACTIONS(120),
    [anon_sym_CARET] = ACTIONS(120),
    [anon_sym_PIPE] = ACTIONS(120),
    [anon_sym_PLUS] = ACTIONS(135),
    [anon_sym_DASH] = ACTIONS(135),
    [anon_sym_SLASH] = ACTIONS(170),
    [anon_sym_PERCENT] = ACTIONS(120),
    [anon_sym_STAR_STAR] = ACTIONS(120),
    [anon_sym_LT] = ACTIONS(708),
    [anon_sym_LT_EQ] = ACTIONS(154),
    [anon_sym_EQ_EQ] = ACTIONS(120),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(154),
    [anon_sym_BANG_EQ] = ACTIONS(120),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(154),
    [anon_sym_GT_EQ] = ACTIONS(154),
    [anon_sym_GT] = ACTIONS(120),
    [anon_sym_QMARK_QMARK] = ACTIONS(120),
    [anon_sym_instanceof] = ACTIONS(120),
    [anon_sym_TILDE] = ACTIONS(175),
    [anon_sym_void] = ACTIONS(179),
    [anon_sym_delete] = ACTIONS(179),
    [anon_sym_PLUS_PLUS] = ACTIONS(181),
    [anon_sym_DASH_DASH] = ACTIONS(181),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(711),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(192),
    [sym_this] = ACTIONS(782),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(718),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(113),
    [anon_sym_readonly] = ACTIONS(113),
    [anon_sym_get] = ACTIONS(113),
    [anon_sym_set] = ACTIONS(113),
    [anon_sym_QMARK] = ACTIONS(720),
    [anon_sym_declare] = ACTIONS(113),
    [anon_sym_public] = ACTIONS(113),
    [anon_sym_private] = ACTIONS(113),
    [anon_sym_protected] = ACTIONS(113),
    [anon_sym_override] = ACTIONS(113),
    [anon_sym_module] = ACTIONS(113),
    [anon_sym_any] = ACTIONS(113),
    [anon_sym_number] = ACTIONS(113),
    [anon_sym_boolean] = ACTIONS(113),
    [anon_sym_string] = ACTIONS(113),
    [anon_sym_symbol] = ACTIONS(113),
    [anon_sym_object] = ACTIONS(113),
    [anon_sym_satisfies] = ACTIONS(120),
    [sym__ternary_qmark] = ACTIONS(154),
    [sym_html_comment] = ACTIONS(5),
  },
  [79] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1213),
    [sym_expression] = STATE(2644),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(3722),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(3722),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5800),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1295),
    [sym_subscript_expression] = STATE(1295),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3013),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(3722),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_pattern] = STATE(3914),
    [sym_rest_pattern] = STATE(3684),
    [sym_non_null_expression] = STATE(1295),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(539),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(696),
    [anon_sym_export] = ACTIONS(113),
    [anon_sym_STAR] = ACTIONS(120),
    [anon_sym_type] = ACTIONS(113),
    [anon_sym_EQ] = ACTIONS(220),
    [anon_sym_as] = ACTIONS(120),
    [anon_sym_namespace] = ACTIONS(122),
    [anon_sym_LBRACE] = ACTIONS(698),
    [anon_sym_COMMA] = ACTIONS(223),
    [anon_sym_typeof] = ACTIONS(179),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(113),
    [anon_sym_BANG] = ACTIONS(135),
    [anon_sym_LPAREN] = ACTIONS(700),
    [anon_sym_RPAREN] = ACTIONS(223),
    [anon_sym_await] = ACTIONS(140),
    [anon_sym_in] = ACTIONS(120),
    [anon_sym_COLON] = ACTIONS(223),
    [anon_sym_yield] = ACTIONS(142),
    [anon_sym_LBRACK] = ACTIONS(703),
    [anon_sym_DOT] = ACTIONS(120),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(148),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_EQ_GT] = ACTIONS(225),
    [anon_sym_QMARK_DOT] = ACTIONS(154),
    [anon_sym_new] = ACTIONS(706),
    [anon_sym_using] = ACTIONS(158),
    [anon_sym_PLUS_EQ] = ACTIONS(160),
    [anon_sym_DASH_EQ] = ACTIONS(160),
    [anon_sym_STAR_EQ] = ACTIONS(160),
    [anon_sym_SLASH_EQ] = ACTIONS(160),
    [anon_sym_PERCENT_EQ] = ACTIONS(160),
    [anon_sym_CARET_EQ] = ACTIONS(160),
    [anon_sym_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_LT_LT_EQ] = ACTIONS(160),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(160),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(160),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(162),
    [anon_sym_AMP_AMP] = ACTIONS(120),
    [anon_sym_PIPE_PIPE] = ACTIONS(120),
    [anon_sym_GT_GT] = ACTIONS(120),
    [anon_sym_GT_GT_GT] = ACTIONS(120),
    [anon_sym_LT_LT] = ACTIONS(120),
    [anon_sym_AMP] = ACTIONS(120),
    [anon_sym_CARET] = ACTIONS(120),
    [anon_sym_PIPE] = ACTIONS(120),
    [anon_sym_PLUS] = ACTIONS(135),
    [anon_sym_DASH] = ACTIONS(135),
    [anon_sym_SLASH] = ACTIONS(170),
    [anon_sym_PERCENT] = ACTIONS(120),
    [anon_sym_STAR_STAR] = ACTIONS(120),
    [anon_sym_LT] = ACTIONS(708),
    [anon_sym_LT_EQ] = ACTIONS(154),
    [anon_sym_EQ_EQ] = ACTIONS(120),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(154),
    [anon_sym_BANG_EQ] = ACTIONS(120),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(154),
    [anon_sym_GT_EQ] = ACTIONS(154),
    [anon_sym_GT] = ACTIONS(120),
    [anon_sym_QMARK_QMARK] = ACTIONS(120),
    [anon_sym_instanceof] = ACTIONS(120),
    [anon_sym_TILDE] = ACTIONS(175),
    [anon_sym_void] = ACTIONS(179),
    [anon_sym_delete] = ACTIONS(179),
    [anon_sym_PLUS_PLUS] = ACTIONS(181),
    [anon_sym_DASH_DASH] = ACTIONS(181),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(711),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(192),
    [sym_this] = ACTIONS(784),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(718),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(113),
    [anon_sym_readonly] = ACTIONS(113),
    [anon_sym_get] = ACTIONS(113),
    [anon_sym_set] = ACTIONS(113),
    [anon_sym_QMARK] = ACTIONS(720),
    [anon_sym_declare] = ACTIONS(113),
    [anon_sym_public] = ACTIONS(113),
    [anon_sym_private] = ACTIONS(113),
    [anon_sym_protected] = ACTIONS(113),
    [anon_sym_override] = ACTIONS(113),
    [anon_sym_module] = ACTIONS(113),
    [anon_sym_any] = ACTIONS(113),
    [anon_sym_number] = ACTIONS(113),
    [anon_sym_boolean] = ACTIONS(113),
    [anon_sym_string] = ACTIONS(113),
    [anon_sym_symbol] = ACTIONS(113),
    [anon_sym_object] = ACTIONS(113),
    [anon_sym_satisfies] = ACTIONS(120),
    [sym__ternary_qmark] = ACTIONS(154),
    [sym_html_comment] = ACTIONS(5),
  },
  [80] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1213),
    [sym_expression] = STATE(2644),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(3722),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(3722),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5800),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1295),
    [sym_subscript_expression] = STATE(1295),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3013),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(3722),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_pattern] = STATE(3922),
    [sym_rest_pattern] = STATE(3684),
    [sym_non_null_expression] = STATE(1295),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(539),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(696),
    [anon_sym_export] = ACTIONS(113),
    [anon_sym_STAR] = ACTIONS(120),
    [anon_sym_type] = ACTIONS(113),
    [anon_sym_EQ] = ACTIONS(220),
    [anon_sym_as] = ACTIONS(120),
    [anon_sym_namespace] = ACTIONS(122),
    [anon_sym_LBRACE] = ACTIONS(698),
    [anon_sym_COMMA] = ACTIONS(223),
    [anon_sym_typeof] = ACTIONS(179),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(113),
    [anon_sym_BANG] = ACTIONS(135),
    [anon_sym_LPAREN] = ACTIONS(700),
    [anon_sym_RPAREN] = ACTIONS(223),
    [anon_sym_await] = ACTIONS(140),
    [anon_sym_in] = ACTIONS(120),
    [anon_sym_COLON] = ACTIONS(223),
    [anon_sym_yield] = ACTIONS(142),
    [anon_sym_LBRACK] = ACTIONS(703),
    [anon_sym_DOT] = ACTIONS(120),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(148),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_EQ_GT] = ACTIONS(225),
    [anon_sym_QMARK_DOT] = ACTIONS(154),
    [anon_sym_new] = ACTIONS(706),
    [anon_sym_using] = ACTIONS(158),
    [anon_sym_PLUS_EQ] = ACTIONS(160),
    [anon_sym_DASH_EQ] = ACTIONS(160),
    [anon_sym_STAR_EQ] = ACTIONS(160),
    [anon_sym_SLASH_EQ] = ACTIONS(160),
    [anon_sym_PERCENT_EQ] = ACTIONS(160),
    [anon_sym_CARET_EQ] = ACTIONS(160),
    [anon_sym_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_LT_LT_EQ] = ACTIONS(160),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(160),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(160),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(162),
    [anon_sym_AMP_AMP] = ACTIONS(120),
    [anon_sym_PIPE_PIPE] = ACTIONS(120),
    [anon_sym_GT_GT] = ACTIONS(120),
    [anon_sym_GT_GT_GT] = ACTIONS(120),
    [anon_sym_LT_LT] = ACTIONS(120),
    [anon_sym_AMP] = ACTIONS(120),
    [anon_sym_CARET] = ACTIONS(120),
    [anon_sym_PIPE] = ACTIONS(120),
    [anon_sym_PLUS] = ACTIONS(135),
    [anon_sym_DASH] = ACTIONS(135),
    [anon_sym_SLASH] = ACTIONS(170),
    [anon_sym_PERCENT] = ACTIONS(120),
    [anon_sym_STAR_STAR] = ACTIONS(120),
    [anon_sym_LT] = ACTIONS(708),
    [anon_sym_LT_EQ] = ACTIONS(154),
    [anon_sym_EQ_EQ] = ACTIONS(120),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(154),
    [anon_sym_BANG_EQ] = ACTIONS(120),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(154),
    [anon_sym_GT_EQ] = ACTIONS(154),
    [anon_sym_GT] = ACTIONS(120),
    [anon_sym_QMARK_QMARK] = ACTIONS(120),
    [anon_sym_instanceof] = ACTIONS(120),
    [anon_sym_TILDE] = ACTIONS(175),
    [anon_sym_void] = ACTIONS(179),
    [anon_sym_delete] = ACTIONS(179),
    [anon_sym_PLUS_PLUS] = ACTIONS(181),
    [anon_sym_DASH_DASH] = ACTIONS(181),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(711),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(192),
    [sym_this] = ACTIONS(786),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(718),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(113),
    [anon_sym_readonly] = ACTIONS(113),
    [anon_sym_get] = ACTIONS(113),
    [anon_sym_set] = ACTIONS(113),
    [anon_sym_QMARK] = ACTIONS(720),
    [anon_sym_declare] = ACTIONS(113),
    [anon_sym_public] = ACTIONS(113),
    [anon_sym_private] = ACTIONS(113),
    [anon_sym_protected] = ACTIONS(113),
    [anon_sym_override] = ACTIONS(113),
    [anon_sym_module] = ACTIONS(113),
    [anon_sym_any] = ACTIONS(113),
    [anon_sym_number] = ACTIONS(113),
    [anon_sym_boolean] = ACTIONS(113),
    [anon_sym_string] = ACTIONS(113),
    [anon_sym_symbol] = ACTIONS(113),
    [anon_sym_object] = ACTIONS(113),
    [anon_sym_satisfies] = ACTIONS(120),
    [sym__ternary_qmark] = ACTIONS(154),
    [sym_html_comment] = ACTIONS(5),
  },
  [81] = {
    [sym_import] = STATE(3563),
    [sym_parenthesized_expression] = STATE(1398),
    [sym_expression] = STATE(1816),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(4309),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(4309),
    [sym_nested_identifier] = STATE(5474),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5558),
    [sym__formal_parameter] = STATE(4621),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1352),
    [sym_subscript_expression] = STATE(1352),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(2980),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(4309),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_sequence_expression] = STATE(5780),
    [sym_string] = STATE(2338),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(4087),
    [sym_pattern] = STATE(4339),
    [sym_rest_pattern] = STATE(3684),
    [sym_non_null_expression] = STATE(1352),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_nested_type_identifier] = STATE(2939),
    [sym_accessibility_modifier] = STATE(288),
    [sym_override_modifier] = STATE(303),
    [sym_required_parameter] = STATE(4621),
    [sym_optional_parameter] = STATE(4621),
    [sym__parameter_name] = STATE(3624),
    [sym__type_query_member_expression_in_type_annotation] = STATE(2937),
    [sym__type_query_call_expression_in_type_annotation] = STATE(2938),
    [sym_type] = STATE(4434),
    [sym_constructor_type] = STATE(3007),
    [sym_primary_type] = STATE(2981),
    [sym_template_literal_type] = STATE(3039),
    [sym_infer_type] = STATE(3007),
    [sym_conditional_type] = STATE(3039),
    [sym_generic_type] = STATE(3039),
    [sym_type_query] = STATE(3039),
    [sym_index_type_query] = STATE(3039),
    [sym_lookup_type] = STATE(3039),
    [sym_literal_type] = STATE(3039),
    [sym__number] = STATE(3041),
    [sym_existential_type] = STATE(3039),
    [sym_flow_maybe_type] = STATE(3039),
    [sym_parenthesized_type] = STATE(3039),
    [sym_predefined_type] = STATE(3039),
    [sym_type_arguments] = STATE(638),
    [sym_object_type] = STATE(3039),
    [sym_type_parameters] = STATE(5158),
    [sym_array_type] = STATE(3039),
    [sym_tuple_type] = STATE(3039),
    [sym_readonly_type] = STATE(3007),
    [sym_union_type] = STATE(3039),
    [sym_intersection_type] = STATE(3039),
    [sym_function_type] = STATE(3007),
    [aux_sym_export_statement_repeat1] = STATE(267),
    [sym_identifier] = ACTIONS(722),
    [anon_sym_export] = ACTIONS(724),
    [anon_sym_STAR] = ACTIONS(543),
    [anon_sym_type] = ACTIONS(724),
    [anon_sym_namespace] = ACTIONS(726),
    [anon_sym_LBRACE] = ACTIONS(728),
    [anon_sym_typeof] = ACTIONS(730),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(724),
    [anon_sym_const] = ACTIONS(133),
    [anon_sym_BANG] = ACTIONS(732),
    [anon_sym_LPAREN] = ACTIONS(138),
    [anon_sym_RPAREN] = ACTIONS(734),
    [anon_sym_await] = ACTIONS(736),
    [anon_sym_yield] = ACTIONS(738),
    [anon_sym_LBRACK] = ACTIONS(740),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(742),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(744),
    [anon_sym_using] = ACTIONS(746),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(162),
    [anon_sym_AMP] = ACTIONS(748),
    [anon_sym_PIPE] = ACTIONS(750),
    [anon_sym_PLUS] = ACTIONS(752),
    [anon_sym_DASH] = ACTIONS(752),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(732),
    [anon_sym_void] = ACTIONS(754),
    [anon_sym_delete] = ACTIONS(756),
    [anon_sym_PLUS_PLUS] = ACTIONS(758),
    [anon_sym_DASH_DASH] = ACTIONS(758),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(760),
    [sym_number] = ACTIONS(762),
    [sym_private_property_identifier] = ACTIONS(764),
    [sym_this] = ACTIONS(766),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(768),
    [sym_false] = ACTIONS(768),
    [sym_null] = ACTIONS(768),
    [sym_undefined] = ACTIONS(770),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(724),
    [anon_sym_readonly] = ACTIONS(772),
    [anon_sym_get] = ACTIONS(724),
    [anon_sym_set] = ACTIONS(724),
    [anon_sym_QMARK] = ACTIONS(774),
    [anon_sym_declare] = ACTIONS(724),
    [anon_sym_public] = ACTIONS(776),
    [anon_sym_private] = ACTIONS(776),
    [anon_sym_protected] = ACTIONS(776),
    [anon_sym_override] = ACTIONS(778),
    [anon_sym_module] = ACTIONS(724),
    [anon_sym_any] = ACTIONS(780),
    [anon_sym_number] = ACTIONS(780),
    [anon_sym_boolean] = ACTIONS(780),
    [anon_sym_string] = ACTIONS(780),
    [anon_sym_symbol] = ACTIONS(780),
    [anon_sym_object] = ACTIONS(780),
    [anon_sym_abstract] = ACTIONS(208),
    [anon_sym_infer] = ACTIONS(210),
    [anon_sym_keyof] = ACTIONS(212),
    [anon_sym_unique] = ACTIONS(214),
    [anon_sym_unknown] = ACTIONS(216),
    [anon_sym_never] = ACTIONS(216),
    [anon_sym_LBRACE_PIPE] = ACTIONS(218),
    [sym_html_comment] = ACTIONS(5),
  },
  [82] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1213),
    [sym_expression] = STATE(2644),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(3722),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(3722),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5800),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1295),
    [sym_subscript_expression] = STATE(1295),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3013),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(3722),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_pattern] = STATE(4312),
    [sym_rest_pattern] = STATE(3684),
    [sym_non_null_expression] = STATE(1295),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(539),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(696),
    [anon_sym_export] = ACTIONS(113),
    [anon_sym_STAR] = ACTIONS(120),
    [anon_sym_type] = ACTIONS(113),
    [anon_sym_EQ] = ACTIONS(220),
    [anon_sym_as] = ACTIONS(120),
    [anon_sym_namespace] = ACTIONS(122),
    [anon_sym_LBRACE] = ACTIONS(698),
    [anon_sym_COMMA] = ACTIONS(223),
    [anon_sym_typeof] = ACTIONS(179),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(113),
    [anon_sym_BANG] = ACTIONS(135),
    [anon_sym_LPAREN] = ACTIONS(700),
    [anon_sym_RPAREN] = ACTIONS(223),
    [anon_sym_await] = ACTIONS(140),
    [anon_sym_in] = ACTIONS(120),
    [anon_sym_COLON] = ACTIONS(223),
    [anon_sym_yield] = ACTIONS(142),
    [anon_sym_LBRACK] = ACTIONS(703),
    [anon_sym_DOT] = ACTIONS(120),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(148),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_EQ_GT] = ACTIONS(225),
    [anon_sym_QMARK_DOT] = ACTIONS(154),
    [anon_sym_new] = ACTIONS(706),
    [anon_sym_using] = ACTIONS(158),
    [anon_sym_PLUS_EQ] = ACTIONS(160),
    [anon_sym_DASH_EQ] = ACTIONS(160),
    [anon_sym_STAR_EQ] = ACTIONS(160),
    [anon_sym_SLASH_EQ] = ACTIONS(160),
    [anon_sym_PERCENT_EQ] = ACTIONS(160),
    [anon_sym_CARET_EQ] = ACTIONS(160),
    [anon_sym_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_LT_LT_EQ] = ACTIONS(160),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(160),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(160),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(162),
    [anon_sym_AMP_AMP] = ACTIONS(120),
    [anon_sym_PIPE_PIPE] = ACTIONS(120),
    [anon_sym_GT_GT] = ACTIONS(120),
    [anon_sym_GT_GT_GT] = ACTIONS(120),
    [anon_sym_LT_LT] = ACTIONS(120),
    [anon_sym_AMP] = ACTIONS(120),
    [anon_sym_CARET] = ACTIONS(120),
    [anon_sym_PIPE] = ACTIONS(120),
    [anon_sym_PLUS] = ACTIONS(135),
    [anon_sym_DASH] = ACTIONS(135),
    [anon_sym_SLASH] = ACTIONS(170),
    [anon_sym_PERCENT] = ACTIONS(120),
    [anon_sym_STAR_STAR] = ACTIONS(120),
    [anon_sym_LT] = ACTIONS(708),
    [anon_sym_LT_EQ] = ACTIONS(154),
    [anon_sym_EQ_EQ] = ACTIONS(120),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(154),
    [anon_sym_BANG_EQ] = ACTIONS(120),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(154),
    [anon_sym_GT_EQ] = ACTIONS(154),
    [anon_sym_GT] = ACTIONS(120),
    [anon_sym_QMARK_QMARK] = ACTIONS(120),
    [anon_sym_instanceof] = ACTIONS(120),
    [anon_sym_TILDE] = ACTIONS(175),
    [anon_sym_void] = ACTIONS(179),
    [anon_sym_delete] = ACTIONS(179),
    [anon_sym_PLUS_PLUS] = ACTIONS(181),
    [anon_sym_DASH_DASH] = ACTIONS(181),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(711),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(192),
    [sym_this] = ACTIONS(716),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(718),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(113),
    [anon_sym_readonly] = ACTIONS(113),
    [anon_sym_get] = ACTIONS(113),
    [anon_sym_set] = ACTIONS(113),
    [anon_sym_QMARK] = ACTIONS(720),
    [anon_sym_declare] = ACTIONS(113),
    [anon_sym_public] = ACTIONS(113),
    [anon_sym_private] = ACTIONS(113),
    [anon_sym_protected] = ACTIONS(113),
    [anon_sym_override] = ACTIONS(113),
    [anon_sym_module] = ACTIONS(113),
    [anon_sym_any] = ACTIONS(113),
    [anon_sym_number] = ACTIONS(113),
    [anon_sym_boolean] = ACTIONS(113),
    [anon_sym_string] = ACTIONS(113),
    [anon_sym_symbol] = ACTIONS(113),
    [anon_sym_object] = ACTIONS(113),
    [anon_sym_satisfies] = ACTIONS(120),
    [sym__ternary_qmark] = ACTIONS(154),
    [sym_html_comment] = ACTIONS(5),
  },
  [83] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1213),
    [sym_expression] = STATE(2644),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(3722),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(3722),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5800),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1295),
    [sym_subscript_expression] = STATE(1295),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3013),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(3722),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_pattern] = STATE(4220),
    [sym_rest_pattern] = STATE(3684),
    [sym_non_null_expression] = STATE(1295),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(539),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(696),
    [anon_sym_export] = ACTIONS(113),
    [anon_sym_STAR] = ACTIONS(120),
    [anon_sym_type] = ACTIONS(113),
    [anon_sym_EQ] = ACTIONS(220),
    [anon_sym_as] = ACTIONS(120),
    [anon_sym_namespace] = ACTIONS(122),
    [anon_sym_LBRACE] = ACTIONS(698),
    [anon_sym_COMMA] = ACTIONS(223),
    [anon_sym_typeof] = ACTIONS(179),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(113),
    [anon_sym_BANG] = ACTIONS(135),
    [anon_sym_LPAREN] = ACTIONS(700),
    [anon_sym_RPAREN] = ACTIONS(223),
    [anon_sym_await] = ACTIONS(140),
    [anon_sym_in] = ACTIONS(120),
    [anon_sym_COLON] = ACTIONS(223),
    [anon_sym_yield] = ACTIONS(142),
    [anon_sym_LBRACK] = ACTIONS(703),
    [anon_sym_DOT] = ACTIONS(120),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(148),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_EQ_GT] = ACTIONS(225),
    [anon_sym_QMARK_DOT] = ACTIONS(154),
    [anon_sym_new] = ACTIONS(706),
    [anon_sym_using] = ACTIONS(158),
    [anon_sym_PLUS_EQ] = ACTIONS(160),
    [anon_sym_DASH_EQ] = ACTIONS(160),
    [anon_sym_STAR_EQ] = ACTIONS(160),
    [anon_sym_SLASH_EQ] = ACTIONS(160),
    [anon_sym_PERCENT_EQ] = ACTIONS(160),
    [anon_sym_CARET_EQ] = ACTIONS(160),
    [anon_sym_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_LT_LT_EQ] = ACTIONS(160),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(160),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(160),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(162),
    [anon_sym_AMP_AMP] = ACTIONS(120),
    [anon_sym_PIPE_PIPE] = ACTIONS(120),
    [anon_sym_GT_GT] = ACTIONS(120),
    [anon_sym_GT_GT_GT] = ACTIONS(120),
    [anon_sym_LT_LT] = ACTIONS(120),
    [anon_sym_AMP] = ACTIONS(120),
    [anon_sym_CARET] = ACTIONS(120),
    [anon_sym_PIPE] = ACTIONS(120),
    [anon_sym_PLUS] = ACTIONS(135),
    [anon_sym_DASH] = ACTIONS(135),
    [anon_sym_SLASH] = ACTIONS(170),
    [anon_sym_PERCENT] = ACTIONS(120),
    [anon_sym_STAR_STAR] = ACTIONS(120),
    [anon_sym_LT] = ACTIONS(708),
    [anon_sym_LT_EQ] = ACTIONS(154),
    [anon_sym_EQ_EQ] = ACTIONS(120),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(154),
    [anon_sym_BANG_EQ] = ACTIONS(120),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(154),
    [anon_sym_GT_EQ] = ACTIONS(154),
    [anon_sym_GT] = ACTIONS(120),
    [anon_sym_QMARK_QMARK] = ACTIONS(120),
    [anon_sym_instanceof] = ACTIONS(120),
    [anon_sym_TILDE] = ACTIONS(175),
    [anon_sym_void] = ACTIONS(179),
    [anon_sym_delete] = ACTIONS(179),
    [anon_sym_PLUS_PLUS] = ACTIONS(181),
    [anon_sym_DASH_DASH] = ACTIONS(181),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(711),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(192),
    [sym_this] = ACTIONS(788),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(718),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(113),
    [anon_sym_readonly] = ACTIONS(113),
    [anon_sym_get] = ACTIONS(113),
    [anon_sym_set] = ACTIONS(113),
    [anon_sym_QMARK] = ACTIONS(720),
    [anon_sym_declare] = ACTIONS(113),
    [anon_sym_public] = ACTIONS(113),
    [anon_sym_private] = ACTIONS(113),
    [anon_sym_protected] = ACTIONS(113),
    [anon_sym_override] = ACTIONS(113),
    [anon_sym_module] = ACTIONS(113),
    [anon_sym_any] = ACTIONS(113),
    [anon_sym_number] = ACTIONS(113),
    [anon_sym_boolean] = ACTIONS(113),
    [anon_sym_string] = ACTIONS(113),
    [anon_sym_symbol] = ACTIONS(113),
    [anon_sym_object] = ACTIONS(113),
    [anon_sym_satisfies] = ACTIONS(120),
    [sym__ternary_qmark] = ACTIONS(154),
    [sym_html_comment] = ACTIONS(5),
  },
  [84] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1213),
    [sym_expression] = STATE(2644),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(3722),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(3722),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5800),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1295),
    [sym_subscript_expression] = STATE(1295),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3013),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(3722),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_pattern] = STATE(4223),
    [sym_rest_pattern] = STATE(3684),
    [sym_non_null_expression] = STATE(1295),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(539),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(696),
    [anon_sym_export] = ACTIONS(113),
    [anon_sym_STAR] = ACTIONS(120),
    [anon_sym_type] = ACTIONS(113),
    [anon_sym_EQ] = ACTIONS(220),
    [anon_sym_as] = ACTIONS(120),
    [anon_sym_namespace] = ACTIONS(122),
    [anon_sym_LBRACE] = ACTIONS(698),
    [anon_sym_COMMA] = ACTIONS(223),
    [anon_sym_typeof] = ACTIONS(179),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(113),
    [anon_sym_BANG] = ACTIONS(135),
    [anon_sym_LPAREN] = ACTIONS(700),
    [anon_sym_RPAREN] = ACTIONS(223),
    [anon_sym_await] = ACTIONS(140),
    [anon_sym_in] = ACTIONS(120),
    [anon_sym_COLON] = ACTIONS(223),
    [anon_sym_yield] = ACTIONS(142),
    [anon_sym_LBRACK] = ACTIONS(703),
    [anon_sym_DOT] = ACTIONS(120),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(148),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_EQ_GT] = ACTIONS(225),
    [anon_sym_QMARK_DOT] = ACTIONS(154),
    [anon_sym_new] = ACTIONS(706),
    [anon_sym_using] = ACTIONS(158),
    [anon_sym_PLUS_EQ] = ACTIONS(160),
    [anon_sym_DASH_EQ] = ACTIONS(160),
    [anon_sym_STAR_EQ] = ACTIONS(160),
    [anon_sym_SLASH_EQ] = ACTIONS(160),
    [anon_sym_PERCENT_EQ] = ACTIONS(160),
    [anon_sym_CARET_EQ] = ACTIONS(160),
    [anon_sym_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_LT_LT_EQ] = ACTIONS(160),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(160),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(160),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(162),
    [anon_sym_AMP_AMP] = ACTIONS(120),
    [anon_sym_PIPE_PIPE] = ACTIONS(120),
    [anon_sym_GT_GT] = ACTIONS(120),
    [anon_sym_GT_GT_GT] = ACTIONS(120),
    [anon_sym_LT_LT] = ACTIONS(120),
    [anon_sym_AMP] = ACTIONS(120),
    [anon_sym_CARET] = ACTIONS(120),
    [anon_sym_PIPE] = ACTIONS(120),
    [anon_sym_PLUS] = ACTIONS(135),
    [anon_sym_DASH] = ACTIONS(135),
    [anon_sym_SLASH] = ACTIONS(170),
    [anon_sym_PERCENT] = ACTIONS(120),
    [anon_sym_STAR_STAR] = ACTIONS(120),
    [anon_sym_LT] = ACTIONS(708),
    [anon_sym_LT_EQ] = ACTIONS(154),
    [anon_sym_EQ_EQ] = ACTIONS(120),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(154),
    [anon_sym_BANG_EQ] = ACTIONS(120),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(154),
    [anon_sym_GT_EQ] = ACTIONS(154),
    [anon_sym_GT] = ACTIONS(120),
    [anon_sym_QMARK_QMARK] = ACTIONS(120),
    [anon_sym_instanceof] = ACTIONS(120),
    [anon_sym_TILDE] = ACTIONS(175),
    [anon_sym_void] = ACTIONS(179),
    [anon_sym_delete] = ACTIONS(179),
    [anon_sym_PLUS_PLUS] = ACTIONS(181),
    [anon_sym_DASH_DASH] = ACTIONS(181),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(711),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(192),
    [sym_this] = ACTIONS(790),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(718),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(113),
    [anon_sym_readonly] = ACTIONS(113),
    [anon_sym_get] = ACTIONS(113),
    [anon_sym_set] = ACTIONS(113),
    [anon_sym_QMARK] = ACTIONS(720),
    [anon_sym_declare] = ACTIONS(113),
    [anon_sym_public] = ACTIONS(113),
    [anon_sym_private] = ACTIONS(113),
    [anon_sym_protected] = ACTIONS(113),
    [anon_sym_override] = ACTIONS(113),
    [anon_sym_module] = ACTIONS(113),
    [anon_sym_any] = ACTIONS(113),
    [anon_sym_number] = ACTIONS(113),
    [anon_sym_boolean] = ACTIONS(113),
    [anon_sym_string] = ACTIONS(113),
    [anon_sym_symbol] = ACTIONS(113),
    [anon_sym_object] = ACTIONS(113),
    [anon_sym_satisfies] = ACTIONS(120),
    [sym__ternary_qmark] = ACTIONS(154),
    [sym_html_comment] = ACTIONS(5),
  },
  [85] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1213),
    [sym_expression] = STATE(2644),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(3722),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(3722),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5800),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1295),
    [sym_subscript_expression] = STATE(1295),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3013),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(3722),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_pattern] = STATE(4227),
    [sym_rest_pattern] = STATE(3684),
    [sym_non_null_expression] = STATE(1295),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(539),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(696),
    [anon_sym_export] = ACTIONS(113),
    [anon_sym_STAR] = ACTIONS(120),
    [anon_sym_type] = ACTIONS(113),
    [anon_sym_EQ] = ACTIONS(220),
    [anon_sym_as] = ACTIONS(120),
    [anon_sym_namespace] = ACTIONS(122),
    [anon_sym_LBRACE] = ACTIONS(698),
    [anon_sym_COMMA] = ACTIONS(223),
    [anon_sym_typeof] = ACTIONS(179),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(113),
    [anon_sym_BANG] = ACTIONS(135),
    [anon_sym_LPAREN] = ACTIONS(700),
    [anon_sym_RPAREN] = ACTIONS(223),
    [anon_sym_await] = ACTIONS(140),
    [anon_sym_in] = ACTIONS(120),
    [anon_sym_COLON] = ACTIONS(223),
    [anon_sym_yield] = ACTIONS(142),
    [anon_sym_LBRACK] = ACTIONS(703),
    [anon_sym_DOT] = ACTIONS(120),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(148),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_EQ_GT] = ACTIONS(225),
    [anon_sym_QMARK_DOT] = ACTIONS(154),
    [anon_sym_new] = ACTIONS(706),
    [anon_sym_using] = ACTIONS(158),
    [anon_sym_PLUS_EQ] = ACTIONS(160),
    [anon_sym_DASH_EQ] = ACTIONS(160),
    [anon_sym_STAR_EQ] = ACTIONS(160),
    [anon_sym_SLASH_EQ] = ACTIONS(160),
    [anon_sym_PERCENT_EQ] = ACTIONS(160),
    [anon_sym_CARET_EQ] = ACTIONS(160),
    [anon_sym_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_LT_LT_EQ] = ACTIONS(160),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(160),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(160),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(162),
    [anon_sym_AMP_AMP] = ACTIONS(120),
    [anon_sym_PIPE_PIPE] = ACTIONS(120),
    [anon_sym_GT_GT] = ACTIONS(120),
    [anon_sym_GT_GT_GT] = ACTIONS(120),
    [anon_sym_LT_LT] = ACTIONS(120),
    [anon_sym_AMP] = ACTIONS(120),
    [anon_sym_CARET] = ACTIONS(120),
    [anon_sym_PIPE] = ACTIONS(120),
    [anon_sym_PLUS] = ACTIONS(135),
    [anon_sym_DASH] = ACTIONS(135),
    [anon_sym_SLASH] = ACTIONS(170),
    [anon_sym_PERCENT] = ACTIONS(120),
    [anon_sym_STAR_STAR] = ACTIONS(120),
    [anon_sym_LT] = ACTIONS(708),
    [anon_sym_LT_EQ] = ACTIONS(154),
    [anon_sym_EQ_EQ] = ACTIONS(120),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(154),
    [anon_sym_BANG_EQ] = ACTIONS(120),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(154),
    [anon_sym_GT_EQ] = ACTIONS(154),
    [anon_sym_GT] = ACTIONS(120),
    [anon_sym_QMARK_QMARK] = ACTIONS(120),
    [anon_sym_instanceof] = ACTIONS(120),
    [anon_sym_TILDE] = ACTIONS(175),
    [anon_sym_void] = ACTIONS(179),
    [anon_sym_delete] = ACTIONS(179),
    [anon_sym_PLUS_PLUS] = ACTIONS(181),
    [anon_sym_DASH_DASH] = ACTIONS(181),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(711),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(192),
    [sym_this] = ACTIONS(792),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(718),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(113),
    [anon_sym_readonly] = ACTIONS(113),
    [anon_sym_get] = ACTIONS(113),
    [anon_sym_set] = ACTIONS(113),
    [anon_sym_QMARK] = ACTIONS(720),
    [anon_sym_declare] = ACTIONS(113),
    [anon_sym_public] = ACTIONS(113),
    [anon_sym_private] = ACTIONS(113),
    [anon_sym_protected] = ACTIONS(113),
    [anon_sym_override] = ACTIONS(113),
    [anon_sym_module] = ACTIONS(113),
    [anon_sym_any] = ACTIONS(113),
    [anon_sym_number] = ACTIONS(113),
    [anon_sym_boolean] = ACTIONS(113),
    [anon_sym_string] = ACTIONS(113),
    [anon_sym_symbol] = ACTIONS(113),
    [anon_sym_object] = ACTIONS(113),
    [anon_sym_satisfies] = ACTIONS(120),
    [sym__ternary_qmark] = ACTIONS(154),
    [sym_html_comment] = ACTIONS(5),
  },
  [86] = {
    [sym_import] = STATE(3593),
    [sym_parenthesized_expression] = STATE(1213),
    [sym_expression] = STATE(2644),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(3722),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(3722),
    [sym_nested_identifier] = STATE(5474),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5800),
    [sym__formal_parameter] = STATE(4621),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1295),
    [sym_subscript_expression] = STATE(1295),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3013),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(3722),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(2213),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(4087),
    [sym_pattern] = STATE(4339),
    [sym_rest_pattern] = STATE(3684),
    [sym_non_null_expression] = STATE(1295),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_nested_type_identifier] = STATE(2939),
    [sym_accessibility_modifier] = STATE(288),
    [sym_override_modifier] = STATE(303),
    [sym_required_parameter] = STATE(4621),
    [sym_optional_parameter] = STATE(4621),
    [sym__parameter_name] = STATE(3624),
    [sym__type_query_member_expression_in_type_annotation] = STATE(2937),
    [sym__type_query_call_expression_in_type_annotation] = STATE(2938),
    [sym_type] = STATE(4477),
    [sym_constructor_type] = STATE(3007),
    [sym_primary_type] = STATE(2981),
    [sym_template_literal_type] = STATE(3039),
    [sym_infer_type] = STATE(3007),
    [sym_conditional_type] = STATE(3039),
    [sym_generic_type] = STATE(3039),
    [sym_type_query] = STATE(3039),
    [sym_index_type_query] = STATE(3039),
    [sym_lookup_type] = STATE(3039),
    [sym_literal_type] = STATE(3039),
    [sym__number] = STATE(3041),
    [sym_existential_type] = STATE(3039),
    [sym_flow_maybe_type] = STATE(3039),
    [sym_parenthesized_type] = STATE(3039),
    [sym_predefined_type] = STATE(3039),
    [sym_type_arguments] = STATE(539),
    [sym_object_type] = STATE(3039),
    [sym_type_parameters] = STATE(5158),
    [sym_array_type] = STATE(3039),
    [sym_tuple_type] = STATE(3039),
    [sym_readonly_type] = STATE(3007),
    [sym_union_type] = STATE(3039),
    [sym_intersection_type] = STATE(3039),
    [sym_function_type] = STATE(3007),
    [aux_sym_export_statement_repeat1] = STATE(267),
    [sym_identifier] = ACTIONS(111),
    [anon_sym_export] = ACTIONS(113),
    [anon_sym_STAR] = ACTIONS(543),
    [anon_sym_type] = ACTIONS(113),
    [anon_sym_namespace] = ACTIONS(122),
    [anon_sym_LBRACE] = ACTIONS(124),
    [anon_sym_typeof] = ACTIONS(129),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(113),
    [anon_sym_const] = ACTIONS(133),
    [anon_sym_BANG] = ACTIONS(175),
    [anon_sym_LPAREN] = ACTIONS(138),
    [anon_sym_RPAREN] = ACTIONS(734),
    [anon_sym_await] = ACTIONS(140),
    [anon_sym_yield] = ACTIONS(142),
    [anon_sym_LBRACK] = ACTIONS(144),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(148),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(156),
    [anon_sym_using] = ACTIONS(158),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(162),
    [anon_sym_AMP] = ACTIONS(748),
    [anon_sym_PIPE] = ACTIONS(750),
    [anon_sym_PLUS] = ACTIONS(168),
    [anon_sym_DASH] = ACTIONS(168),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(175),
    [anon_sym_void] = ACTIONS(177),
    [anon_sym_delete] = ACTIONS(179),
    [anon_sym_PLUS_PLUS] = ACTIONS(686),
    [anon_sym_DASH_DASH] = ACTIONS(686),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(188),
    [sym_number] = ACTIONS(190),
    [sym_private_property_identifier] = ACTIONS(192),
    [sym_this] = ACTIONS(794),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(198),
    [sym_false] = ACTIONS(198),
    [sym_null] = ACTIONS(198),
    [sym_undefined] = ACTIONS(200),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(113),
    [anon_sym_readonly] = ACTIONS(796),
    [anon_sym_get] = ACTIONS(113),
    [anon_sym_set] = ACTIONS(113),
    [anon_sym_QMARK] = ACTIONS(774),
    [anon_sym_declare] = ACTIONS(113),
    [anon_sym_public] = ACTIONS(798),
    [anon_sym_private] = ACTIONS(798),
    [anon_sym_protected] = ACTIONS(798),
    [anon_sym_override] = ACTIONS(800),
    [anon_sym_module] = ACTIONS(113),
    [anon_sym_any] = ACTIONS(206),
    [anon_sym_number] = ACTIONS(206),
    [anon_sym_boolean] = ACTIONS(206),
    [anon_sym_string] = ACTIONS(206),
    [anon_sym_symbol] = ACTIONS(206),
    [anon_sym_object] = ACTIONS(206),
    [anon_sym_abstract] = ACTIONS(208),
    [anon_sym_infer] = ACTIONS(210),
    [anon_sym_keyof] = ACTIONS(212),
    [anon_sym_unique] = ACTIONS(214),
    [anon_sym_unknown] = ACTIONS(216),
    [anon_sym_never] = ACTIONS(216),
    [anon_sym_LBRACE_PIPE] = ACTIONS(218),
    [sym_html_comment] = ACTIONS(5),
  },
  [87] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1213),
    [sym_expression] = STATE(2644),
    [sym_primary_expression] = STATE(1501),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5522),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5522),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5800),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1213),
    [sym_subscript_expression] = STATE(1213),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3013),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5522),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1213),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(539),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(802),
    [anon_sym_export] = ACTIONS(804),
    [anon_sym_STAR] = ACTIONS(120),
    [anon_sym_type] = ACTIONS(804),
    [anon_sym_EQ] = ACTIONS(220),
    [anon_sym_as] = ACTIONS(120),
    [anon_sym_namespace] = ACTIONS(806),
    [anon_sym_LBRACE] = ACTIONS(808),
    [anon_sym_COMMA] = ACTIONS(223),
    [anon_sym_RBRACE] = ACTIONS(223),
    [anon_sym_typeof] = ACTIONS(179),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(804),
    [anon_sym_BANG] = ACTIONS(179),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_RPAREN] = ACTIONS(223),
    [anon_sym_await] = ACTIONS(140),
    [anon_sym_in] = ACTIONS(120),
    [anon_sym_COLON] = ACTIONS(223),
    [anon_sym_yield] = ACTIONS(142),
    [anon_sym_LBRACK] = ACTIONS(812),
    [anon_sym_RBRACK] = ACTIONS(223),
    [anon_sym_DOT] = ACTIONS(814),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(816),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_EQ_GT] = ACTIONS(225),
    [anon_sym_QMARK_DOT] = ACTIONS(154),
    [anon_sym_new] = ACTIONS(818),
    [anon_sym_using] = ACTIONS(158),
    [anon_sym_PLUS_EQ] = ACTIONS(160),
    [anon_sym_DASH_EQ] = ACTIONS(160),
    [anon_sym_STAR_EQ] = ACTIONS(160),
    [anon_sym_SLASH_EQ] = ACTIONS(160),
    [anon_sym_PERCENT_EQ] = ACTIONS(160),
    [anon_sym_CARET_EQ] = ACTIONS(160),
    [anon_sym_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_LT_LT_EQ] = ACTIONS(160),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(160),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP] = ACTIONS(120),
    [anon_sym_PIPE_PIPE] = ACTIONS(120),
    [anon_sym_GT_GT] = ACTIONS(120),
    [anon_sym_GT_GT_GT] = ACTIONS(120),
    [anon_sym_LT_LT] = ACTIONS(120),
    [anon_sym_AMP] = ACTIONS(120),
    [anon_sym_CARET] = ACTIONS(120),
    [anon_sym_PIPE] = ACTIONS(120),
    [anon_sym_PLUS] = ACTIONS(179),
    [anon_sym_DASH] = ACTIONS(179),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_PERCENT] = ACTIONS(120),
    [anon_sym_STAR_STAR] = ACTIONS(120),
    [anon_sym_LT] = ACTIONS(173),
    [anon_sym_LT_EQ] = ACTIONS(154),
    [anon_sym_EQ_EQ] = ACTIONS(120),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(154),
    [anon_sym_BANG_EQ] = ACTIONS(120),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(154),
    [anon_sym_GT_EQ] = ACTIONS(154),
    [anon_sym_GT] = ACTIONS(120),
    [anon_sym_QMARK_QMARK] = ACTIONS(120),
    [anon_sym_instanceof] = ACTIONS(120),
    [anon_sym_TILDE] = ACTIONS(175),
    [anon_sym_void] = ACTIONS(179),
    [anon_sym_delete] = ACTIONS(179),
    [anon_sym_PLUS_PLUS] = ACTIONS(686),
    [anon_sym_DASH_DASH] = ACTIONS(686),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(192),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(822),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(804),
    [anon_sym_readonly] = ACTIONS(804),
    [anon_sym_get] = ACTIONS(804),
    [anon_sym_set] = ACTIONS(804),
    [anon_sym_QMARK] = ACTIONS(720),
    [anon_sym_declare] = ACTIONS(804),
    [anon_sym_public] = ACTIONS(804),
    [anon_sym_private] = ACTIONS(804),
    [anon_sym_protected] = ACTIONS(804),
    [anon_sym_override] = ACTIONS(804),
    [anon_sym_module] = ACTIONS(804),
    [anon_sym_any] = ACTIONS(804),
    [anon_sym_number] = ACTIONS(804),
    [anon_sym_boolean] = ACTIONS(804),
    [anon_sym_string] = ACTIONS(804),
    [anon_sym_symbol] = ACTIONS(804),
    [anon_sym_object] = ACTIONS(804),
    [anon_sym_satisfies] = ACTIONS(120),
    [sym__ternary_qmark] = ACTIONS(154),
    [sym_html_comment] = ACTIONS(5),
  },
  [88] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1213),
    [sym_expression] = STATE(2644),
    [sym_primary_expression] = STATE(1501),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5522),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5522),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5800),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1213),
    [sym_subscript_expression] = STATE(1213),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3013),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5522),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1213),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(539),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(802),
    [anon_sym_export] = ACTIONS(804),
    [anon_sym_STAR] = ACTIONS(120),
    [anon_sym_type] = ACTIONS(804),
    [anon_sym_EQ] = ACTIONS(824),
    [anon_sym_as] = ACTIONS(120),
    [anon_sym_namespace] = ACTIONS(806),
    [anon_sym_LBRACE] = ACTIONS(808),
    [anon_sym_COMMA] = ACTIONS(826),
    [anon_sym_RBRACE] = ACTIONS(826),
    [anon_sym_typeof] = ACTIONS(179),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(804),
    [anon_sym_BANG] = ACTIONS(179),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_RPAREN] = ACTIONS(826),
    [anon_sym_await] = ACTIONS(140),
    [anon_sym_in] = ACTIONS(120),
    [anon_sym_COLON] = ACTIONS(826),
    [anon_sym_yield] = ACTIONS(142),
    [anon_sym_LBRACK] = ACTIONS(812),
    [anon_sym_RBRACK] = ACTIONS(826),
    [anon_sym_DOT] = ACTIONS(814),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(816),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_EQ_GT] = ACTIONS(225),
    [anon_sym_QMARK_DOT] = ACTIONS(154),
    [anon_sym_new] = ACTIONS(818),
    [anon_sym_using] = ACTIONS(158),
    [anon_sym_PLUS_EQ] = ACTIONS(160),
    [anon_sym_DASH_EQ] = ACTIONS(160),
    [anon_sym_STAR_EQ] = ACTIONS(160),
    [anon_sym_SLASH_EQ] = ACTIONS(160),
    [anon_sym_PERCENT_EQ] = ACTIONS(160),
    [anon_sym_CARET_EQ] = ACTIONS(160),
    [anon_sym_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_LT_LT_EQ] = ACTIONS(160),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(160),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP] = ACTIONS(120),
    [anon_sym_PIPE_PIPE] = ACTIONS(120),
    [anon_sym_GT_GT] = ACTIONS(120),
    [anon_sym_GT_GT_GT] = ACTIONS(120),
    [anon_sym_LT_LT] = ACTIONS(120),
    [anon_sym_AMP] = ACTIONS(120),
    [anon_sym_CARET] = ACTIONS(120),
    [anon_sym_PIPE] = ACTIONS(120),
    [anon_sym_PLUS] = ACTIONS(179),
    [anon_sym_DASH] = ACTIONS(179),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_PERCENT] = ACTIONS(120),
    [anon_sym_STAR_STAR] = ACTIONS(120),
    [anon_sym_LT] = ACTIONS(173),
    [anon_sym_LT_EQ] = ACTIONS(154),
    [anon_sym_EQ_EQ] = ACTIONS(120),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(154),
    [anon_sym_BANG_EQ] = ACTIONS(120),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(154),
    [anon_sym_GT_EQ] = ACTIONS(154),
    [anon_sym_GT] = ACTIONS(120),
    [anon_sym_QMARK_QMARK] = ACTIONS(120),
    [anon_sym_instanceof] = ACTIONS(120),
    [anon_sym_TILDE] = ACTIONS(175),
    [anon_sym_void] = ACTIONS(179),
    [anon_sym_delete] = ACTIONS(179),
    [anon_sym_PLUS_PLUS] = ACTIONS(686),
    [anon_sym_DASH_DASH] = ACTIONS(686),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(192),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(822),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(804),
    [anon_sym_readonly] = ACTIONS(804),
    [anon_sym_get] = ACTIONS(804),
    [anon_sym_set] = ACTIONS(804),
    [anon_sym_QMARK] = ACTIONS(828),
    [anon_sym_declare] = ACTIONS(804),
    [anon_sym_public] = ACTIONS(804),
    [anon_sym_private] = ACTIONS(804),
    [anon_sym_protected] = ACTIONS(804),
    [anon_sym_override] = ACTIONS(804),
    [anon_sym_module] = ACTIONS(804),
    [anon_sym_any] = ACTIONS(804),
    [anon_sym_number] = ACTIONS(804),
    [anon_sym_boolean] = ACTIONS(804),
    [anon_sym_string] = ACTIONS(804),
    [anon_sym_symbol] = ACTIONS(804),
    [anon_sym_object] = ACTIONS(804),
    [anon_sym_satisfies] = ACTIONS(120),
    [sym__ternary_qmark] = ACTIONS(154),
    [sym_html_comment] = ACTIONS(5),
  },
  [89] = {
    [sym_import] = STATE(3593),
    [sym_parenthesized_expression] = STATE(1213),
    [sym_expression] = STATE(2644),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(3722),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(3722),
    [sym_nested_identifier] = STATE(5474),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5800),
    [sym__formal_parameter] = STATE(4621),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1295),
    [sym_subscript_expression] = STATE(1295),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3013),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(3722),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(2213),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(4087),
    [sym_pattern] = STATE(4339),
    [sym_rest_pattern] = STATE(3684),
    [sym_non_null_expression] = STATE(1295),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_nested_type_identifier] = STATE(2939),
    [sym_accessibility_modifier] = STATE(288),
    [sym_override_modifier] = STATE(303),
    [sym_required_parameter] = STATE(4621),
    [sym_optional_parameter] = STATE(4621),
    [sym__parameter_name] = STATE(3624),
    [sym__type_query_member_expression_in_type_annotation] = STATE(2937),
    [sym__type_query_call_expression_in_type_annotation] = STATE(2938),
    [sym_type] = STATE(4397),
    [sym_constructor_type] = STATE(3007),
    [sym_primary_type] = STATE(2981),
    [sym_template_literal_type] = STATE(3039),
    [sym_infer_type] = STATE(3007),
    [sym_conditional_type] = STATE(3039),
    [sym_generic_type] = STATE(3039),
    [sym_type_query] = STATE(3039),
    [sym_index_type_query] = STATE(3039),
    [sym_lookup_type] = STATE(3039),
    [sym_literal_type] = STATE(3039),
    [sym__number] = STATE(3041),
    [sym_existential_type] = STATE(3039),
    [sym_flow_maybe_type] = STATE(3039),
    [sym_parenthesized_type] = STATE(3039),
    [sym_predefined_type] = STATE(3039),
    [sym_type_arguments] = STATE(539),
    [sym_object_type] = STATE(3039),
    [sym_type_parameters] = STATE(5158),
    [sym_array_type] = STATE(3039),
    [sym_tuple_type] = STATE(3039),
    [sym_readonly_type] = STATE(3007),
    [sym_union_type] = STATE(3039),
    [sym_intersection_type] = STATE(3039),
    [sym_function_type] = STATE(3007),
    [aux_sym_export_statement_repeat1] = STATE(267),
    [sym_identifier] = ACTIONS(111),
    [anon_sym_export] = ACTIONS(113),
    [anon_sym_STAR] = ACTIONS(543),
    [anon_sym_type] = ACTIONS(113),
    [anon_sym_namespace] = ACTIONS(122),
    [anon_sym_LBRACE] = ACTIONS(124),
    [anon_sym_typeof] = ACTIONS(129),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(113),
    [anon_sym_const] = ACTIONS(133),
    [anon_sym_BANG] = ACTIONS(175),
    [anon_sym_LPAREN] = ACTIONS(138),
    [anon_sym_RPAREN] = ACTIONS(734),
    [anon_sym_await] = ACTIONS(140),
    [anon_sym_yield] = ACTIONS(142),
    [anon_sym_LBRACK] = ACTIONS(144),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(148),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(156),
    [anon_sym_using] = ACTIONS(158),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(162),
    [anon_sym_AMP] = ACTIONS(748),
    [anon_sym_PIPE] = ACTIONS(750),
    [anon_sym_PLUS] = ACTIONS(168),
    [anon_sym_DASH] = ACTIONS(168),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(175),
    [anon_sym_void] = ACTIONS(177),
    [anon_sym_delete] = ACTIONS(179),
    [anon_sym_PLUS_PLUS] = ACTIONS(686),
    [anon_sym_DASH_DASH] = ACTIONS(686),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(188),
    [sym_number] = ACTIONS(190),
    [sym_private_property_identifier] = ACTIONS(192),
    [sym_this] = ACTIONS(794),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(198),
    [sym_false] = ACTIONS(198),
    [sym_null] = ACTIONS(198),
    [sym_undefined] = ACTIONS(200),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(113),
    [anon_sym_readonly] = ACTIONS(796),
    [anon_sym_get] = ACTIONS(113),
    [anon_sym_set] = ACTIONS(113),
    [anon_sym_QMARK] = ACTIONS(774),
    [anon_sym_declare] = ACTIONS(113),
    [anon_sym_public] = ACTIONS(798),
    [anon_sym_private] = ACTIONS(798),
    [anon_sym_protected] = ACTIONS(798),
    [anon_sym_override] = ACTIONS(800),
    [anon_sym_module] = ACTIONS(113),
    [anon_sym_any] = ACTIONS(206),
    [anon_sym_number] = ACTIONS(206),
    [anon_sym_boolean] = ACTIONS(206),
    [anon_sym_string] = ACTIONS(206),
    [anon_sym_symbol] = ACTIONS(206),
    [anon_sym_object] = ACTIONS(206),
    [anon_sym_abstract] = ACTIONS(208),
    [anon_sym_infer] = ACTIONS(210),
    [anon_sym_keyof] = ACTIONS(212),
    [anon_sym_unique] = ACTIONS(214),
    [anon_sym_unknown] = ACTIONS(216),
    [anon_sym_never] = ACTIONS(216),
    [anon_sym_LBRACE_PIPE] = ACTIONS(218),
    [sym_html_comment] = ACTIONS(5),
  },
  [90] = {
    [sym_import] = STATE(3593),
    [sym_parenthesized_expression] = STATE(1213),
    [sym_expression] = STATE(2644),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(3722),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(3722),
    [sym_nested_identifier] = STATE(5474),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5800),
    [sym__formal_parameter] = STATE(4621),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1295),
    [sym_subscript_expression] = STATE(1295),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3013),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(3722),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(2213),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(4087),
    [sym_pattern] = STATE(4339),
    [sym_rest_pattern] = STATE(3684),
    [sym_non_null_expression] = STATE(1295),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_nested_type_identifier] = STATE(2939),
    [sym_accessibility_modifier] = STATE(288),
    [sym_override_modifier] = STATE(303),
    [sym_required_parameter] = STATE(4621),
    [sym_optional_parameter] = STATE(4621),
    [sym__parameter_name] = STATE(3624),
    [sym__type_query_member_expression_in_type_annotation] = STATE(2937),
    [sym__type_query_call_expression_in_type_annotation] = STATE(2938),
    [sym_type] = STATE(4405),
    [sym_constructor_type] = STATE(3007),
    [sym_primary_type] = STATE(2981),
    [sym_template_literal_type] = STATE(3039),
    [sym_infer_type] = STATE(3007),
    [sym_conditional_type] = STATE(3039),
    [sym_generic_type] = STATE(3039),
    [sym_type_query] = STATE(3039),
    [sym_index_type_query] = STATE(3039),
    [sym_lookup_type] = STATE(3039),
    [sym_literal_type] = STATE(3039),
    [sym__number] = STATE(3041),
    [sym_existential_type] = STATE(3039),
    [sym_flow_maybe_type] = STATE(3039),
    [sym_parenthesized_type] = STATE(3039),
    [sym_predefined_type] = STATE(3039),
    [sym_type_arguments] = STATE(539),
    [sym_object_type] = STATE(3039),
    [sym_type_parameters] = STATE(5158),
    [sym_array_type] = STATE(3039),
    [sym_tuple_type] = STATE(3039),
    [sym_readonly_type] = STATE(3007),
    [sym_union_type] = STATE(3039),
    [sym_intersection_type] = STATE(3039),
    [sym_function_type] = STATE(3007),
    [aux_sym_export_statement_repeat1] = STATE(267),
    [sym_identifier] = ACTIONS(111),
    [anon_sym_export] = ACTIONS(113),
    [anon_sym_STAR] = ACTIONS(543),
    [anon_sym_type] = ACTIONS(113),
    [anon_sym_namespace] = ACTIONS(122),
    [anon_sym_LBRACE] = ACTIONS(124),
    [anon_sym_typeof] = ACTIONS(129),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(113),
    [anon_sym_const] = ACTIONS(133),
    [anon_sym_BANG] = ACTIONS(175),
    [anon_sym_LPAREN] = ACTIONS(138),
    [anon_sym_RPAREN] = ACTIONS(734),
    [anon_sym_await] = ACTIONS(140),
    [anon_sym_yield] = ACTIONS(142),
    [anon_sym_LBRACK] = ACTIONS(144),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(148),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(156),
    [anon_sym_using] = ACTIONS(158),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(162),
    [anon_sym_AMP] = ACTIONS(748),
    [anon_sym_PIPE] = ACTIONS(750),
    [anon_sym_PLUS] = ACTIONS(168),
    [anon_sym_DASH] = ACTIONS(168),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(175),
    [anon_sym_void] = ACTIONS(177),
    [anon_sym_delete] = ACTIONS(179),
    [anon_sym_PLUS_PLUS] = ACTIONS(686),
    [anon_sym_DASH_DASH] = ACTIONS(686),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(188),
    [sym_number] = ACTIONS(190),
    [sym_private_property_identifier] = ACTIONS(192),
    [sym_this] = ACTIONS(794),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(198),
    [sym_false] = ACTIONS(198),
    [sym_null] = ACTIONS(198),
    [sym_undefined] = ACTIONS(200),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(113),
    [anon_sym_readonly] = ACTIONS(796),
    [anon_sym_get] = ACTIONS(113),
    [anon_sym_set] = ACTIONS(113),
    [anon_sym_QMARK] = ACTIONS(774),
    [anon_sym_declare] = ACTIONS(113),
    [anon_sym_public] = ACTIONS(798),
    [anon_sym_private] = ACTIONS(798),
    [anon_sym_protected] = ACTIONS(798),
    [anon_sym_override] = ACTIONS(800),
    [anon_sym_module] = ACTIONS(113),
    [anon_sym_any] = ACTIONS(206),
    [anon_sym_number] = ACTIONS(206),
    [anon_sym_boolean] = ACTIONS(206),
    [anon_sym_string] = ACTIONS(206),
    [anon_sym_symbol] = ACTIONS(206),
    [anon_sym_object] = ACTIONS(206),
    [anon_sym_abstract] = ACTIONS(208),
    [anon_sym_infer] = ACTIONS(210),
    [anon_sym_keyof] = ACTIONS(212),
    [anon_sym_unique] = ACTIONS(214),
    [anon_sym_unknown] = ACTIONS(216),
    [anon_sym_never] = ACTIONS(216),
    [anon_sym_LBRACE_PIPE] = ACTIONS(218),
    [sym_html_comment] = ACTIONS(5),
  },
  [91] = {
    [sym_import] = STATE(3593),
    [sym_parenthesized_expression] = STATE(1213),
    [sym_expression] = STATE(2644),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(3722),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(3722),
    [sym_nested_identifier] = STATE(5474),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5800),
    [sym__formal_parameter] = STATE(4621),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1295),
    [sym_subscript_expression] = STATE(1295),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3013),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(3722),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(2213),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(4087),
    [sym_pattern] = STATE(4339),
    [sym_rest_pattern] = STATE(3684),
    [sym_non_null_expression] = STATE(1295),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_nested_type_identifier] = STATE(2939),
    [sym_accessibility_modifier] = STATE(288),
    [sym_override_modifier] = STATE(303),
    [sym_required_parameter] = STATE(4621),
    [sym_optional_parameter] = STATE(4621),
    [sym__parameter_name] = STATE(3624),
    [sym__type_query_member_expression_in_type_annotation] = STATE(2937),
    [sym__type_query_call_expression_in_type_annotation] = STATE(2938),
    [sym_type] = STATE(4434),
    [sym_constructor_type] = STATE(3007),
    [sym_primary_type] = STATE(2981),
    [sym_template_literal_type] = STATE(3039),
    [sym_infer_type] = STATE(3007),
    [sym_conditional_type] = STATE(3039),
    [sym_generic_type] = STATE(3039),
    [sym_type_query] = STATE(3039),
    [sym_index_type_query] = STATE(3039),
    [sym_lookup_type] = STATE(3039),
    [sym_literal_type] = STATE(3039),
    [sym__number] = STATE(3041),
    [sym_existential_type] = STATE(3039),
    [sym_flow_maybe_type] = STATE(3039),
    [sym_parenthesized_type] = STATE(3039),
    [sym_predefined_type] = STATE(3039),
    [sym_type_arguments] = STATE(539),
    [sym_object_type] = STATE(3039),
    [sym_type_parameters] = STATE(5158),
    [sym_array_type] = STATE(3039),
    [sym_tuple_type] = STATE(3039),
    [sym_readonly_type] = STATE(3007),
    [sym_union_type] = STATE(3039),
    [sym_intersection_type] = STATE(3039),
    [sym_function_type] = STATE(3007),
    [aux_sym_export_statement_repeat1] = STATE(267),
    [sym_identifier] = ACTIONS(111),
    [anon_sym_export] = ACTIONS(113),
    [anon_sym_STAR] = ACTIONS(543),
    [anon_sym_type] = ACTIONS(113),
    [anon_sym_namespace] = ACTIONS(122),
    [anon_sym_LBRACE] = ACTIONS(124),
    [anon_sym_typeof] = ACTIONS(129),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(113),
    [anon_sym_const] = ACTIONS(133),
    [anon_sym_BANG] = ACTIONS(175),
    [anon_sym_LPAREN] = ACTIONS(138),
    [anon_sym_RPAREN] = ACTIONS(734),
    [anon_sym_await] = ACTIONS(140),
    [anon_sym_yield] = ACTIONS(142),
    [anon_sym_LBRACK] = ACTIONS(144),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(148),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(156),
    [anon_sym_using] = ACTIONS(158),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(162),
    [anon_sym_AMP] = ACTIONS(748),
    [anon_sym_PIPE] = ACTIONS(750),
    [anon_sym_PLUS] = ACTIONS(168),
    [anon_sym_DASH] = ACTIONS(168),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(175),
    [anon_sym_void] = ACTIONS(177),
    [anon_sym_delete] = ACTIONS(179),
    [anon_sym_PLUS_PLUS] = ACTIONS(686),
    [anon_sym_DASH_DASH] = ACTIONS(686),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(188),
    [sym_number] = ACTIONS(190),
    [sym_private_property_identifier] = ACTIONS(192),
    [sym_this] = ACTIONS(794),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(198),
    [sym_false] = ACTIONS(198),
    [sym_null] = ACTIONS(198),
    [sym_undefined] = ACTIONS(200),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(113),
    [anon_sym_readonly] = ACTIONS(796),
    [anon_sym_get] = ACTIONS(113),
    [anon_sym_set] = ACTIONS(113),
    [anon_sym_QMARK] = ACTIONS(774),
    [anon_sym_declare] = ACTIONS(113),
    [anon_sym_public] = ACTIONS(798),
    [anon_sym_private] = ACTIONS(798),
    [anon_sym_protected] = ACTIONS(798),
    [anon_sym_override] = ACTIONS(800),
    [anon_sym_module] = ACTIONS(113),
    [anon_sym_any] = ACTIONS(206),
    [anon_sym_number] = ACTIONS(206),
    [anon_sym_boolean] = ACTIONS(206),
    [anon_sym_string] = ACTIONS(206),
    [anon_sym_symbol] = ACTIONS(206),
    [anon_sym_object] = ACTIONS(206),
    [anon_sym_abstract] = ACTIONS(208),
    [anon_sym_infer] = ACTIONS(210),
    [anon_sym_keyof] = ACTIONS(212),
    [anon_sym_unique] = ACTIONS(214),
    [anon_sym_unknown] = ACTIONS(216),
    [anon_sym_never] = ACTIONS(216),
    [anon_sym_LBRACE_PIPE] = ACTIONS(218),
    [sym_html_comment] = ACTIONS(5),
  },
  [92] = {
    [sym_import] = STATE(3593),
    [sym_parenthesized_expression] = STATE(1213),
    [sym_expression] = STATE(2644),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(3722),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(3722),
    [sym_nested_identifier] = STATE(5474),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5800),
    [sym__formal_parameter] = STATE(4621),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1295),
    [sym_subscript_expression] = STATE(1295),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3013),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(3722),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(2213),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(4087),
    [sym_pattern] = STATE(4339),
    [sym_rest_pattern] = STATE(3684),
    [sym_non_null_expression] = STATE(1295),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_nested_type_identifier] = STATE(2939),
    [sym_accessibility_modifier] = STATE(288),
    [sym_override_modifier] = STATE(303),
    [sym_required_parameter] = STATE(4621),
    [sym_optional_parameter] = STATE(4621),
    [sym__parameter_name] = STATE(3624),
    [sym__type_query_member_expression_in_type_annotation] = STATE(2937),
    [sym__type_query_call_expression_in_type_annotation] = STATE(2938),
    [sym_type] = STATE(4387),
    [sym_constructor_type] = STATE(3007),
    [sym_primary_type] = STATE(2981),
    [sym_template_literal_type] = STATE(3039),
    [sym_infer_type] = STATE(3007),
    [sym_conditional_type] = STATE(3039),
    [sym_generic_type] = STATE(3039),
    [sym_type_query] = STATE(3039),
    [sym_index_type_query] = STATE(3039),
    [sym_lookup_type] = STATE(3039),
    [sym_literal_type] = STATE(3039),
    [sym__number] = STATE(3041),
    [sym_existential_type] = STATE(3039),
    [sym_flow_maybe_type] = STATE(3039),
    [sym_parenthesized_type] = STATE(3039),
    [sym_predefined_type] = STATE(3039),
    [sym_type_arguments] = STATE(539),
    [sym_object_type] = STATE(3039),
    [sym_type_parameters] = STATE(5158),
    [sym_array_type] = STATE(3039),
    [sym_tuple_type] = STATE(3039),
    [sym_readonly_type] = STATE(3007),
    [sym_union_type] = STATE(3039),
    [sym_intersection_type] = STATE(3039),
    [sym_function_type] = STATE(3007),
    [aux_sym_export_statement_repeat1] = STATE(267),
    [sym_identifier] = ACTIONS(111),
    [anon_sym_export] = ACTIONS(113),
    [anon_sym_STAR] = ACTIONS(543),
    [anon_sym_type] = ACTIONS(113),
    [anon_sym_namespace] = ACTIONS(122),
    [anon_sym_LBRACE] = ACTIONS(124),
    [anon_sym_typeof] = ACTIONS(129),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(113),
    [anon_sym_const] = ACTIONS(133),
    [anon_sym_BANG] = ACTIONS(175),
    [anon_sym_LPAREN] = ACTIONS(138),
    [anon_sym_RPAREN] = ACTIONS(734),
    [anon_sym_await] = ACTIONS(140),
    [anon_sym_yield] = ACTIONS(142),
    [anon_sym_LBRACK] = ACTIONS(144),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(148),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(156),
    [anon_sym_using] = ACTIONS(158),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(162),
    [anon_sym_AMP] = ACTIONS(748),
    [anon_sym_PIPE] = ACTIONS(750),
    [anon_sym_PLUS] = ACTIONS(168),
    [anon_sym_DASH] = ACTIONS(168),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(175),
    [anon_sym_void] = ACTIONS(177),
    [anon_sym_delete] = ACTIONS(179),
    [anon_sym_PLUS_PLUS] = ACTIONS(686),
    [anon_sym_DASH_DASH] = ACTIONS(686),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(188),
    [sym_number] = ACTIONS(190),
    [sym_private_property_identifier] = ACTIONS(192),
    [sym_this] = ACTIONS(794),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(198),
    [sym_false] = ACTIONS(198),
    [sym_null] = ACTIONS(198),
    [sym_undefined] = ACTIONS(200),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(113),
    [anon_sym_readonly] = ACTIONS(796),
    [anon_sym_get] = ACTIONS(113),
    [anon_sym_set] = ACTIONS(113),
    [anon_sym_QMARK] = ACTIONS(774),
    [anon_sym_declare] = ACTIONS(113),
    [anon_sym_public] = ACTIONS(798),
    [anon_sym_private] = ACTIONS(798),
    [anon_sym_protected] = ACTIONS(798),
    [anon_sym_override] = ACTIONS(800),
    [anon_sym_module] = ACTIONS(113),
    [anon_sym_any] = ACTIONS(206),
    [anon_sym_number] = ACTIONS(206),
    [anon_sym_boolean] = ACTIONS(206),
    [anon_sym_string] = ACTIONS(206),
    [anon_sym_symbol] = ACTIONS(206),
    [anon_sym_object] = ACTIONS(206),
    [anon_sym_abstract] = ACTIONS(208),
    [anon_sym_infer] = ACTIONS(210),
    [anon_sym_keyof] = ACTIONS(212),
    [anon_sym_unique] = ACTIONS(214),
    [anon_sym_unknown] = ACTIONS(216),
    [anon_sym_never] = ACTIONS(216),
    [anon_sym_LBRACE_PIPE] = ACTIONS(218),
    [sym_html_comment] = ACTIONS(5),
  },
  [93] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1213),
    [sym_expression] = STATE(2644),
    [sym_primary_expression] = STATE(1501),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5522),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5522),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5508),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1213),
    [sym_subscript_expression] = STATE(1213),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3013),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5522),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(4116),
    [sym_non_null_expression] = STATE(1213),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(539),
    [sym_type_parameters] = STATE(5344),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(830),
    [anon_sym_export] = ACTIONS(832),
    [anon_sym_STAR] = ACTIONS(120),
    [anon_sym_type] = ACTIONS(832),
    [anon_sym_EQ] = ACTIONS(834),
    [anon_sym_as] = ACTIONS(120),
    [anon_sym_namespace] = ACTIONS(836),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_COMMA] = ACTIONS(154),
    [anon_sym_RBRACE] = ACTIONS(154),
    [anon_sym_typeof] = ACTIONS(179),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(832),
    [anon_sym_BANG] = ACTIONS(179),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_SEMI] = ACTIONS(154),
    [anon_sym_await] = ACTIONS(140),
    [anon_sym_in] = ACTIONS(120),
    [anon_sym_COLON] = ACTIONS(154),
    [anon_sym_yield] = ACTIONS(142),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_RBRACK] = ACTIONS(154),
    [anon_sym_DOT] = ACTIONS(814),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(842),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_EQ_GT] = ACTIONS(844),
    [anon_sym_QMARK_DOT] = ACTIONS(154),
    [anon_sym_new] = ACTIONS(846),
    [anon_sym_using] = ACTIONS(158),
    [anon_sym_PLUS_EQ] = ACTIONS(160),
    [anon_sym_DASH_EQ] = ACTIONS(160),
    [anon_sym_STAR_EQ] = ACTIONS(160),
    [anon_sym_SLASH_EQ] = ACTIONS(160),
    [anon_sym_PERCENT_EQ] = ACTIONS(160),
    [anon_sym_CARET_EQ] = ACTIONS(160),
    [anon_sym_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_LT_LT_EQ] = ACTIONS(160),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(160),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP] = ACTIONS(120),
    [anon_sym_PIPE_PIPE] = ACTIONS(120),
    [anon_sym_GT_GT] = ACTIONS(120),
    [anon_sym_GT_GT_GT] = ACTIONS(120),
    [anon_sym_LT_LT] = ACTIONS(120),
    [anon_sym_AMP] = ACTIONS(120),
    [anon_sym_CARET] = ACTIONS(120),
    [anon_sym_PIPE] = ACTIONS(120),
    [anon_sym_PLUS] = ACTIONS(179),
    [anon_sym_DASH] = ACTIONS(179),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_PERCENT] = ACTIONS(120),
    [anon_sym_STAR_STAR] = ACTIONS(120),
    [anon_sym_LT] = ACTIONS(173),
    [anon_sym_LT_EQ] = ACTIONS(154),
    [anon_sym_EQ_EQ] = ACTIONS(120),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(154),
    [anon_sym_BANG_EQ] = ACTIONS(120),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(154),
    [anon_sym_GT_EQ] = ACTIONS(154),
    [anon_sym_GT] = ACTIONS(120),
    [anon_sym_QMARK_QMARK] = ACTIONS(120),
    [anon_sym_instanceof] = ACTIONS(120),
    [anon_sym_TILDE] = ACTIONS(175),
    [anon_sym_void] = ACTIONS(179),
    [anon_sym_delete] = ACTIONS(179),
    [anon_sym_PLUS_PLUS] = ACTIONS(686),
    [anon_sym_DASH_DASH] = ACTIONS(686),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(192),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(822),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(832),
    [anon_sym_readonly] = ACTIONS(832),
    [anon_sym_get] = ACTIONS(832),
    [anon_sym_set] = ACTIONS(832),
    [anon_sym_declare] = ACTIONS(832),
    [anon_sym_public] = ACTIONS(832),
    [anon_sym_private] = ACTIONS(832),
    [anon_sym_protected] = ACTIONS(832),
    [anon_sym_override] = ACTIONS(832),
    [anon_sym_module] = ACTIONS(832),
    [anon_sym_any] = ACTIONS(832),
    [anon_sym_number] = ACTIONS(832),
    [anon_sym_boolean] = ACTIONS(832),
    [anon_sym_string] = ACTIONS(832),
    [anon_sym_symbol] = ACTIONS(832),
    [anon_sym_object] = ACTIONS(832),
    [anon_sym_satisfies] = ACTIONS(120),
    [sym__ternary_qmark] = ACTIONS(154),
    [sym_html_comment] = ACTIONS(5),
  },
  [94] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1213),
    [sym_expression] = STATE(2644),
    [sym_primary_expression] = STATE(1501),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5522),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5522),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5800),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1213),
    [sym_subscript_expression] = STATE(1213),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3013),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5522),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1213),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(539),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(802),
    [anon_sym_export] = ACTIONS(804),
    [anon_sym_STAR] = ACTIONS(120),
    [anon_sym_type] = ACTIONS(804),
    [anon_sym_EQ] = ACTIONS(824),
    [anon_sym_as] = ACTIONS(120),
    [anon_sym_namespace] = ACTIONS(806),
    [anon_sym_LBRACE] = ACTIONS(808),
    [anon_sym_COMMA] = ACTIONS(154),
    [anon_sym_RBRACE] = ACTIONS(154),
    [anon_sym_typeof] = ACTIONS(179),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(804),
    [anon_sym_BANG] = ACTIONS(179),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_SEMI] = ACTIONS(154),
    [anon_sym_await] = ACTIONS(140),
    [anon_sym_in] = ACTIONS(120),
    [anon_sym_COLON] = ACTIONS(154),
    [anon_sym_yield] = ACTIONS(142),
    [anon_sym_LBRACK] = ACTIONS(812),
    [anon_sym_RBRACK] = ACTIONS(154),
    [anon_sym_DOT] = ACTIONS(814),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(816),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_EQ_GT] = ACTIONS(844),
    [anon_sym_QMARK_DOT] = ACTIONS(154),
    [anon_sym_new] = ACTIONS(818),
    [anon_sym_using] = ACTIONS(158),
    [anon_sym_PLUS_EQ] = ACTIONS(160),
    [anon_sym_DASH_EQ] = ACTIONS(160),
    [anon_sym_STAR_EQ] = ACTIONS(160),
    [anon_sym_SLASH_EQ] = ACTIONS(160),
    [anon_sym_PERCENT_EQ] = ACTIONS(160),
    [anon_sym_CARET_EQ] = ACTIONS(160),
    [anon_sym_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_LT_LT_EQ] = ACTIONS(160),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(160),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP] = ACTIONS(120),
    [anon_sym_PIPE_PIPE] = ACTIONS(120),
    [anon_sym_GT_GT] = ACTIONS(120),
    [anon_sym_GT_GT_GT] = ACTIONS(120),
    [anon_sym_LT_LT] = ACTIONS(120),
    [anon_sym_AMP] = ACTIONS(120),
    [anon_sym_CARET] = ACTIONS(120),
    [anon_sym_PIPE] = ACTIONS(120),
    [anon_sym_PLUS] = ACTIONS(179),
    [anon_sym_DASH] = ACTIONS(179),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_PERCENT] = ACTIONS(120),
    [anon_sym_STAR_STAR] = ACTIONS(120),
    [anon_sym_LT] = ACTIONS(173),
    [anon_sym_LT_EQ] = ACTIONS(154),
    [anon_sym_EQ_EQ] = ACTIONS(120),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(154),
    [anon_sym_BANG_EQ] = ACTIONS(120),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(154),
    [anon_sym_GT_EQ] = ACTIONS(154),
    [anon_sym_GT] = ACTIONS(120),
    [anon_sym_QMARK_QMARK] = ACTIONS(120),
    [anon_sym_instanceof] = ACTIONS(120),
    [anon_sym_TILDE] = ACTIONS(175),
    [anon_sym_void] = ACTIONS(179),
    [anon_sym_delete] = ACTIONS(179),
    [anon_sym_PLUS_PLUS] = ACTIONS(686),
    [anon_sym_DASH_DASH] = ACTIONS(686),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(192),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(822),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(804),
    [anon_sym_readonly] = ACTIONS(804),
    [anon_sym_get] = ACTIONS(804),
    [anon_sym_set] = ACTIONS(804),
    [anon_sym_declare] = ACTIONS(804),
    [anon_sym_public] = ACTIONS(804),
    [anon_sym_private] = ACTIONS(804),
    [anon_sym_protected] = ACTIONS(804),
    [anon_sym_override] = ACTIONS(804),
    [anon_sym_module] = ACTIONS(804),
    [anon_sym_any] = ACTIONS(804),
    [anon_sym_number] = ACTIONS(804),
    [anon_sym_boolean] = ACTIONS(804),
    [anon_sym_string] = ACTIONS(804),
    [anon_sym_symbol] = ACTIONS(804),
    [anon_sym_object] = ACTIONS(804),
    [anon_sym_satisfies] = ACTIONS(120),
    [sym__ternary_qmark] = ACTIONS(154),
    [sym_html_comment] = ACTIONS(5),
  },
  [95] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1213),
    [sym_expression] = STATE(2644),
    [sym_primary_expression] = STATE(1501),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5522),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5522),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5508),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1213),
    [sym_subscript_expression] = STATE(1213),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3013),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5522),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1213),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(539),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(830),
    [anon_sym_export] = ACTIONS(832),
    [anon_sym_STAR] = ACTIONS(120),
    [anon_sym_type] = ACTIONS(832),
    [anon_sym_EQ] = ACTIONS(834),
    [anon_sym_as] = ACTIONS(120),
    [anon_sym_namespace] = ACTIONS(836),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_COMMA] = ACTIONS(154),
    [anon_sym_RBRACE] = ACTIONS(154),
    [anon_sym_typeof] = ACTIONS(179),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(832),
    [anon_sym_BANG] = ACTIONS(179),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_SEMI] = ACTIONS(154),
    [anon_sym_await] = ACTIONS(140),
    [anon_sym_in] = ACTIONS(120),
    [anon_sym_COLON] = ACTIONS(154),
    [anon_sym_yield] = ACTIONS(142),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_RBRACK] = ACTIONS(154),
    [anon_sym_DOT] = ACTIONS(814),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(842),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_EQ_GT] = ACTIONS(844),
    [anon_sym_QMARK_DOT] = ACTIONS(154),
    [anon_sym_new] = ACTIONS(846),
    [anon_sym_using] = ACTIONS(158),
    [anon_sym_PLUS_EQ] = ACTIONS(160),
    [anon_sym_DASH_EQ] = ACTIONS(160),
    [anon_sym_STAR_EQ] = ACTIONS(160),
    [anon_sym_SLASH_EQ] = ACTIONS(160),
    [anon_sym_PERCENT_EQ] = ACTIONS(160),
    [anon_sym_CARET_EQ] = ACTIONS(160),
    [anon_sym_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_LT_LT_EQ] = ACTIONS(160),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(160),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP] = ACTIONS(120),
    [anon_sym_PIPE_PIPE] = ACTIONS(120),
    [anon_sym_GT_GT] = ACTIONS(120),
    [anon_sym_GT_GT_GT] = ACTIONS(120),
    [anon_sym_LT_LT] = ACTIONS(120),
    [anon_sym_AMP] = ACTIONS(120),
    [anon_sym_CARET] = ACTIONS(120),
    [anon_sym_PIPE] = ACTIONS(120),
    [anon_sym_PLUS] = ACTIONS(179),
    [anon_sym_DASH] = ACTIONS(179),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_PERCENT] = ACTIONS(120),
    [anon_sym_STAR_STAR] = ACTIONS(120),
    [anon_sym_LT] = ACTIONS(173),
    [anon_sym_LT_EQ] = ACTIONS(154),
    [anon_sym_EQ_EQ] = ACTIONS(120),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(154),
    [anon_sym_BANG_EQ] = ACTIONS(120),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(154),
    [anon_sym_GT_EQ] = ACTIONS(154),
    [anon_sym_GT] = ACTIONS(120),
    [anon_sym_QMARK_QMARK] = ACTIONS(120),
    [anon_sym_instanceof] = ACTIONS(120),
    [anon_sym_TILDE] = ACTIONS(175),
    [anon_sym_void] = ACTIONS(179),
    [anon_sym_delete] = ACTIONS(179),
    [anon_sym_PLUS_PLUS] = ACTIONS(686),
    [anon_sym_DASH_DASH] = ACTIONS(686),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(192),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(822),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(832),
    [anon_sym_readonly] = ACTIONS(832),
    [anon_sym_get] = ACTIONS(832),
    [anon_sym_set] = ACTIONS(832),
    [anon_sym_declare] = ACTIONS(832),
    [anon_sym_public] = ACTIONS(832),
    [anon_sym_private] = ACTIONS(832),
    [anon_sym_protected] = ACTIONS(832),
    [anon_sym_override] = ACTIONS(832),
    [anon_sym_module] = ACTIONS(832),
    [anon_sym_any] = ACTIONS(832),
    [anon_sym_number] = ACTIONS(832),
    [anon_sym_boolean] = ACTIONS(832),
    [anon_sym_string] = ACTIONS(832),
    [anon_sym_symbol] = ACTIONS(832),
    [anon_sym_object] = ACTIONS(832),
    [anon_sym_satisfies] = ACTIONS(120),
    [sym__ternary_qmark] = ACTIONS(154),
    [sym_html_comment] = ACTIONS(5),
  },
  [96] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1213),
    [sym_expression] = STATE(2644),
    [sym_primary_expression] = STATE(1501),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5522),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5522),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5558),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1213),
    [sym_subscript_expression] = STATE(1213),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3013),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5522),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1213),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(539),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(848),
    [anon_sym_export] = ACTIONS(850),
    [anon_sym_STAR] = ACTIONS(120),
    [anon_sym_type] = ACTIONS(850),
    [anon_sym_EQ] = ACTIONS(117),
    [anon_sym_as] = ACTIONS(120),
    [anon_sym_namespace] = ACTIONS(852),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_COMMA] = ACTIONS(126),
    [anon_sym_typeof] = ACTIONS(179),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(850),
    [anon_sym_BANG] = ACTIONS(179),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_RPAREN] = ACTIONS(126),
    [anon_sym_await] = ACTIONS(140),
    [anon_sym_in] = ACTIONS(120),
    [anon_sym_COLON] = ACTIONS(126),
    [anon_sym_yield] = ACTIONS(142),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_DOT] = ACTIONS(814),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(854),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_EQ_GT] = ACTIONS(152),
    [anon_sym_QMARK_DOT] = ACTIONS(154),
    [anon_sym_new] = ACTIONS(856),
    [anon_sym_using] = ACTIONS(158),
    [anon_sym_PLUS_EQ] = ACTIONS(160),
    [anon_sym_DASH_EQ] = ACTIONS(160),
    [anon_sym_STAR_EQ] = ACTIONS(160),
    [anon_sym_SLASH_EQ] = ACTIONS(160),
    [anon_sym_PERCENT_EQ] = ACTIONS(160),
    [anon_sym_CARET_EQ] = ACTIONS(160),
    [anon_sym_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_LT_LT_EQ] = ACTIONS(160),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(160),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP] = ACTIONS(120),
    [anon_sym_PIPE_PIPE] = ACTIONS(120),
    [anon_sym_GT_GT] = ACTIONS(120),
    [anon_sym_GT_GT_GT] = ACTIONS(120),
    [anon_sym_LT_LT] = ACTIONS(120),
    [anon_sym_AMP] = ACTIONS(120),
    [anon_sym_CARET] = ACTIONS(120),
    [anon_sym_PIPE] = ACTIONS(120),
    [anon_sym_PLUS] = ACTIONS(179),
    [anon_sym_DASH] = ACTIONS(179),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_PERCENT] = ACTIONS(120),
    [anon_sym_STAR_STAR] = ACTIONS(120),
    [anon_sym_LT] = ACTIONS(173),
    [anon_sym_LT_EQ] = ACTIONS(154),
    [anon_sym_EQ_EQ] = ACTIONS(120),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(154),
    [anon_sym_BANG_EQ] = ACTIONS(120),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(154),
    [anon_sym_GT_EQ] = ACTIONS(154),
    [anon_sym_GT] = ACTIONS(120),
    [anon_sym_QMARK_QMARK] = ACTIONS(120),
    [anon_sym_instanceof] = ACTIONS(120),
    [anon_sym_TILDE] = ACTIONS(175),
    [anon_sym_void] = ACTIONS(179),
    [anon_sym_delete] = ACTIONS(179),
    [anon_sym_PLUS_PLUS] = ACTIONS(686),
    [anon_sym_DASH_DASH] = ACTIONS(686),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(192),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(822),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(850),
    [anon_sym_readonly] = ACTIONS(850),
    [anon_sym_get] = ACTIONS(850),
    [anon_sym_set] = ACTIONS(850),
    [anon_sym_QMARK] = ACTIONS(720),
    [anon_sym_declare] = ACTIONS(850),
    [anon_sym_public] = ACTIONS(850),
    [anon_sym_private] = ACTIONS(850),
    [anon_sym_protected] = ACTIONS(850),
    [anon_sym_override] = ACTIONS(850),
    [anon_sym_module] = ACTIONS(850),
    [anon_sym_any] = ACTIONS(850),
    [anon_sym_number] = ACTIONS(850),
    [anon_sym_boolean] = ACTIONS(850),
    [anon_sym_string] = ACTIONS(850),
    [anon_sym_symbol] = ACTIONS(850),
    [anon_sym_object] = ACTIONS(850),
    [anon_sym_satisfies] = ACTIONS(120),
    [sym__ternary_qmark] = ACTIONS(154),
    [sym_html_comment] = ACTIONS(5),
  },
  [97] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1213),
    [sym_expression] = STATE(2644),
    [sym_primary_expression] = STATE(1501),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5522),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5522),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5800),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1213),
    [sym_subscript_expression] = STATE(1213),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3013),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5522),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1213),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(539),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(802),
    [anon_sym_export] = ACTIONS(804),
    [anon_sym_STAR] = ACTIONS(120),
    [anon_sym_type] = ACTIONS(804),
    [anon_sym_EQ] = ACTIONS(824),
    [anon_sym_as] = ACTIONS(120),
    [anon_sym_namespace] = ACTIONS(806),
    [anon_sym_LBRACE] = ACTIONS(808),
    [anon_sym_COMMA] = ACTIONS(154),
    [anon_sym_RBRACE] = ACTIONS(154),
    [anon_sym_typeof] = ACTIONS(179),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(804),
    [anon_sym_BANG] = ACTIONS(179),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_SEMI] = ACTIONS(154),
    [anon_sym_await] = ACTIONS(140),
    [anon_sym_in] = ACTIONS(120),
    [anon_sym_yield] = ACTIONS(142),
    [anon_sym_LBRACK] = ACTIONS(812),
    [anon_sym_DOT] = ACTIONS(674),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(816),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_EQ_GT] = ACTIONS(682),
    [anon_sym_QMARK_DOT] = ACTIONS(154),
    [anon_sym_new] = ACTIONS(818),
    [anon_sym_using] = ACTIONS(158),
    [anon_sym_PLUS_EQ] = ACTIONS(160),
    [anon_sym_DASH_EQ] = ACTIONS(160),
    [anon_sym_STAR_EQ] = ACTIONS(160),
    [anon_sym_SLASH_EQ] = ACTIONS(160),
    [anon_sym_PERCENT_EQ] = ACTIONS(160),
    [anon_sym_CARET_EQ] = ACTIONS(160),
    [anon_sym_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_LT_LT_EQ] = ACTIONS(160),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(160),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP] = ACTIONS(120),
    [anon_sym_PIPE_PIPE] = ACTIONS(120),
    [anon_sym_GT_GT] = ACTIONS(120),
    [anon_sym_GT_GT_GT] = ACTIONS(120),
    [anon_sym_LT_LT] = ACTIONS(120),
    [anon_sym_AMP] = ACTIONS(120),
    [anon_sym_CARET] = ACTIONS(120),
    [anon_sym_PIPE] = ACTIONS(120),
    [anon_sym_PLUS] = ACTIONS(179),
    [anon_sym_DASH] = ACTIONS(179),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_PERCENT] = ACTIONS(120),
    [anon_sym_STAR_STAR] = ACTIONS(120),
    [anon_sym_LT] = ACTIONS(173),
    [anon_sym_LT_EQ] = ACTIONS(154),
    [anon_sym_EQ_EQ] = ACTIONS(120),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(154),
    [anon_sym_BANG_EQ] = ACTIONS(120),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(154),
    [anon_sym_GT_EQ] = ACTIONS(154),
    [anon_sym_GT] = ACTIONS(120),
    [anon_sym_QMARK_QMARK] = ACTIONS(120),
    [anon_sym_instanceof] = ACTIONS(120),
    [anon_sym_TILDE] = ACTIONS(175),
    [anon_sym_void] = ACTIONS(179),
    [anon_sym_delete] = ACTIONS(179),
    [anon_sym_PLUS_PLUS] = ACTIONS(686),
    [anon_sym_DASH_DASH] = ACTIONS(686),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(192),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(822),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(804),
    [anon_sym_readonly] = ACTIONS(804),
    [anon_sym_get] = ACTIONS(804),
    [anon_sym_set] = ACTIONS(804),
    [anon_sym_declare] = ACTIONS(804),
    [anon_sym_public] = ACTIONS(804),
    [anon_sym_private] = ACTIONS(804),
    [anon_sym_protected] = ACTIONS(804),
    [anon_sym_override] = ACTIONS(804),
    [anon_sym_module] = ACTIONS(804),
    [anon_sym_any] = ACTIONS(804),
    [anon_sym_number] = ACTIONS(804),
    [anon_sym_boolean] = ACTIONS(804),
    [anon_sym_string] = ACTIONS(804),
    [anon_sym_symbol] = ACTIONS(804),
    [anon_sym_object] = ACTIONS(804),
    [anon_sym_satisfies] = ACTIONS(120),
    [sym__automatic_semicolon] = ACTIONS(154),
    [sym__ternary_qmark] = ACTIONS(154),
    [sym_html_comment] = ACTIONS(5),
  },
  [98] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1213),
    [sym_expression] = STATE(2644),
    [sym_primary_expression] = STATE(1501),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5522),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5522),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5800),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1213),
    [sym_subscript_expression] = STATE(1213),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3013),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5522),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(4116),
    [sym_non_null_expression] = STATE(1213),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(539),
    [sym_type_parameters] = STATE(5344),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(802),
    [anon_sym_export] = ACTIONS(804),
    [anon_sym_STAR] = ACTIONS(120),
    [anon_sym_type] = ACTIONS(804),
    [anon_sym_EQ] = ACTIONS(220),
    [anon_sym_as] = ACTIONS(120),
    [anon_sym_namespace] = ACTIONS(806),
    [anon_sym_LBRACE] = ACTIONS(808),
    [anon_sym_COMMA] = ACTIONS(223),
    [anon_sym_typeof] = ACTIONS(179),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(804),
    [anon_sym_BANG] = ACTIONS(179),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_RPAREN] = ACTIONS(223),
    [anon_sym_await] = ACTIONS(140),
    [anon_sym_in] = ACTIONS(120),
    [anon_sym_COLON] = ACTIONS(223),
    [anon_sym_yield] = ACTIONS(142),
    [anon_sym_LBRACK] = ACTIONS(812),
    [anon_sym_DOT] = ACTIONS(814),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(816),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_EQ_GT] = ACTIONS(225),
    [anon_sym_QMARK_DOT] = ACTIONS(154),
    [anon_sym_new] = ACTIONS(818),
    [anon_sym_using] = ACTIONS(158),
    [anon_sym_PLUS_EQ] = ACTIONS(160),
    [anon_sym_DASH_EQ] = ACTIONS(160),
    [anon_sym_STAR_EQ] = ACTIONS(160),
    [anon_sym_SLASH_EQ] = ACTIONS(160),
    [anon_sym_PERCENT_EQ] = ACTIONS(160),
    [anon_sym_CARET_EQ] = ACTIONS(160),
    [anon_sym_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_LT_LT_EQ] = ACTIONS(160),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(160),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP] = ACTIONS(120),
    [anon_sym_PIPE_PIPE] = ACTIONS(120),
    [anon_sym_GT_GT] = ACTIONS(120),
    [anon_sym_GT_GT_GT] = ACTIONS(120),
    [anon_sym_LT_LT] = ACTIONS(120),
    [anon_sym_AMP] = ACTIONS(120),
    [anon_sym_CARET] = ACTIONS(120),
    [anon_sym_PIPE] = ACTIONS(120),
    [anon_sym_PLUS] = ACTIONS(179),
    [anon_sym_DASH] = ACTIONS(179),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_PERCENT] = ACTIONS(120),
    [anon_sym_STAR_STAR] = ACTIONS(120),
    [anon_sym_LT] = ACTIONS(173),
    [anon_sym_LT_EQ] = ACTIONS(154),
    [anon_sym_EQ_EQ] = ACTIONS(120),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(154),
    [anon_sym_BANG_EQ] = ACTIONS(120),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(154),
    [anon_sym_GT_EQ] = ACTIONS(154),
    [anon_sym_GT] = ACTIONS(120),
    [anon_sym_QMARK_QMARK] = ACTIONS(120),
    [anon_sym_instanceof] = ACTIONS(120),
    [anon_sym_TILDE] = ACTIONS(175),
    [anon_sym_void] = ACTIONS(179),
    [anon_sym_delete] = ACTIONS(179),
    [anon_sym_PLUS_PLUS] = ACTIONS(686),
    [anon_sym_DASH_DASH] = ACTIONS(686),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(192),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(822),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(804),
    [anon_sym_readonly] = ACTIONS(804),
    [anon_sym_get] = ACTIONS(804),
    [anon_sym_set] = ACTIONS(804),
    [anon_sym_QMARK] = ACTIONS(720),
    [anon_sym_declare] = ACTIONS(804),
    [anon_sym_public] = ACTIONS(804),
    [anon_sym_private] = ACTIONS(804),
    [anon_sym_protected] = ACTIONS(804),
    [anon_sym_override] = ACTIONS(804),
    [anon_sym_module] = ACTIONS(804),
    [anon_sym_any] = ACTIONS(804),
    [anon_sym_number] = ACTIONS(804),
    [anon_sym_boolean] = ACTIONS(804),
    [anon_sym_string] = ACTIONS(804),
    [anon_sym_symbol] = ACTIONS(804),
    [anon_sym_object] = ACTIONS(804),
    [anon_sym_satisfies] = ACTIONS(120),
    [sym__ternary_qmark] = ACTIONS(154),
    [sym_html_comment] = ACTIONS(5),
  },
  [99] = {
    [sym_import] = STATE(3636),
    [sym_parenthesized_expression] = STATE(1334),
    [sym_expression] = STATE(2611),
    [sym_primary_expression] = STATE(1696),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(2222),
    [sym_object_pattern] = STATE(5522),
    [sym_array] = STATE(2222),
    [sym_array_pattern] = STATE(5522),
    [sym_class] = STATE(2222),
    [sym_function_expression] = STATE(2222),
    [sym_generator_function] = STATE(2222),
    [sym_arrow_function] = STATE(2222),
    [sym__call_signature] = STATE(5821),
    [sym_call_expression] = STATE(2222),
    [sym_new_expression] = STATE(2694),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1334),
    [sym_subscript_expression] = STATE(1334),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3013),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5522),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(2222),
    [sym_template_string] = STATE(2222),
    [sym_regex] = STATE(2222),
    [sym_meta_property] = STATE(2222),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1334),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(539),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4408),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_export] = ACTIONS(659),
    [anon_sym_STAR] = ACTIONS(120),
    [anon_sym_type] = ACTIONS(659),
    [anon_sym_EQ] = ACTIONS(858),
    [anon_sym_as] = ACTIONS(120),
    [anon_sym_namespace] = ACTIONS(663),
    [anon_sym_LBRACE] = ACTIONS(665),
    [anon_sym_COMMA] = ACTIONS(154),
    [anon_sym_typeof] = ACTIONS(179),
    [anon_sym_import] = ACTIONS(669),
    [anon_sym_let] = ACTIONS(659),
    [anon_sym_BANG] = ACTIONS(179),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_SEMI] = ACTIONS(154),
    [anon_sym_await] = ACTIONS(140),
    [anon_sym_in] = ACTIONS(120),
    [anon_sym_COLON] = ACTIONS(860),
    [anon_sym_yield] = ACTIONS(142),
    [anon_sym_LBRACK] = ACTIONS(65),
    [anon_sym_DOT] = ACTIONS(674),
    [anon_sym_class] = ACTIONS(676),
    [anon_sym_async] = ACTIONS(678),
    [anon_sym_function] = ACTIONS(680),
    [anon_sym_EQ_GT] = ACTIONS(682),
    [anon_sym_QMARK_DOT] = ACTIONS(154),
    [anon_sym_new] = ACTIONS(684),
    [anon_sym_using] = ACTIONS(158),
    [anon_sym_PLUS_EQ] = ACTIONS(160),
    [anon_sym_DASH_EQ] = ACTIONS(160),
    [anon_sym_STAR_EQ] = ACTIONS(160),
    [anon_sym_SLASH_EQ] = ACTIONS(160),
    [anon_sym_PERCENT_EQ] = ACTIONS(160),
    [anon_sym_CARET_EQ] = ACTIONS(160),
    [anon_sym_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_LT_LT_EQ] = ACTIONS(160),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(160),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP] = ACTIONS(120),
    [anon_sym_PIPE_PIPE] = ACTIONS(120),
    [anon_sym_GT_GT] = ACTIONS(120),
    [anon_sym_GT_GT_GT] = ACTIONS(120),
    [anon_sym_LT_LT] = ACTIONS(120),
    [anon_sym_AMP] = ACTIONS(120),
    [anon_sym_CARET] = ACTIONS(120),
    [anon_sym_PIPE] = ACTIONS(120),
    [anon_sym_PLUS] = ACTIONS(179),
    [anon_sym_DASH] = ACTIONS(179),
    [anon_sym_SLASH] = ACTIONS(77),
    [anon_sym_PERCENT] = ACTIONS(120),
    [anon_sym_STAR_STAR] = ACTIONS(120),
    [anon_sym_LT] = ACTIONS(173),
    [anon_sym_LT_EQ] = ACTIONS(154),
    [anon_sym_EQ_EQ] = ACTIONS(120),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(154),
    [anon_sym_BANG_EQ] = ACTIONS(120),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(154),
    [anon_sym_GT_EQ] = ACTIONS(154),
    [anon_sym_GT] = ACTIONS(120),
    [anon_sym_QMARK_QMARK] = ACTIONS(120),
    [anon_sym_instanceof] = ACTIONS(120),
    [anon_sym_TILDE] = ACTIONS(175),
    [anon_sym_void] = ACTIONS(179),
    [anon_sym_delete] = ACTIONS(179),
    [anon_sym_PLUS_PLUS] = ACTIONS(686),
    [anon_sym_DASH_DASH] = ACTIONS(686),
    [anon_sym_DQUOTE] = ACTIONS(83),
    [anon_sym_SQUOTE] = ACTIONS(85),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(87),
    [sym_number] = ACTIONS(89),
    [sym_private_property_identifier] = ACTIONS(192),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(93),
    [sym_true] = ACTIONS(93),
    [sym_false] = ACTIONS(93),
    [sym_null] = ACTIONS(93),
    [sym_undefined] = ACTIONS(688),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(659),
    [anon_sym_readonly] = ACTIONS(659),
    [anon_sym_get] = ACTIONS(659),
    [anon_sym_set] = ACTIONS(659),
    [anon_sym_declare] = ACTIONS(659),
    [anon_sym_public] = ACTIONS(659),
    [anon_sym_private] = ACTIONS(659),
    [anon_sym_protected] = ACTIONS(659),
    [anon_sym_override] = ACTIONS(659),
    [anon_sym_module] = ACTIONS(659),
    [anon_sym_any] = ACTIONS(659),
    [anon_sym_number] = ACTIONS(659),
    [anon_sym_boolean] = ACTIONS(659),
    [anon_sym_string] = ACTIONS(659),
    [anon_sym_symbol] = ACTIONS(659),
    [anon_sym_object] = ACTIONS(659),
    [anon_sym_satisfies] = ACTIONS(120),
    [sym__automatic_semicolon] = ACTIONS(154),
    [sym__ternary_qmark] = ACTIONS(154),
    [sym_html_comment] = ACTIONS(5),
  },
  [100] = {
    [sym_import] = STATE(3636),
    [sym_parenthesized_expression] = STATE(1334),
    [sym_expression] = STATE(2611),
    [sym_primary_expression] = STATE(1696),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(2222),
    [sym_object_pattern] = STATE(5522),
    [sym_array] = STATE(2222),
    [sym_array_pattern] = STATE(5522),
    [sym_class] = STATE(2222),
    [sym_function_expression] = STATE(2222),
    [sym_generator_function] = STATE(2222),
    [sym_arrow_function] = STATE(2222),
    [sym__call_signature] = STATE(5821),
    [sym_call_expression] = STATE(2222),
    [sym_new_expression] = STATE(2694),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1334),
    [sym_subscript_expression] = STATE(1334),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3013),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5522),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(2222),
    [sym_template_string] = STATE(2222),
    [sym_regex] = STATE(2222),
    [sym_meta_property] = STATE(2222),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(4116),
    [sym_non_null_expression] = STATE(1334),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(539),
    [sym_type_parameters] = STATE(5344),
    [aux_sym_export_statement_repeat1] = STATE(4408),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_export] = ACTIONS(659),
    [anon_sym_STAR] = ACTIONS(120),
    [anon_sym_type] = ACTIONS(659),
    [anon_sym_EQ] = ACTIONS(858),
    [anon_sym_as] = ACTIONS(120),
    [anon_sym_namespace] = ACTIONS(663),
    [anon_sym_LBRACE] = ACTIONS(665),
    [anon_sym_COMMA] = ACTIONS(154),
    [anon_sym_RBRACE] = ACTIONS(154),
    [anon_sym_typeof] = ACTIONS(179),
    [anon_sym_import] = ACTIONS(669),
    [anon_sym_let] = ACTIONS(659),
    [anon_sym_BANG] = ACTIONS(179),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_SEMI] = ACTIONS(154),
    [anon_sym_await] = ACTIONS(140),
    [anon_sym_in] = ACTIONS(120),
    [anon_sym_yield] = ACTIONS(142),
    [anon_sym_LBRACK] = ACTIONS(65),
    [anon_sym_DOT] = ACTIONS(674),
    [anon_sym_class] = ACTIONS(676),
    [anon_sym_async] = ACTIONS(678),
    [anon_sym_function] = ACTIONS(680),
    [anon_sym_EQ_GT] = ACTIONS(682),
    [anon_sym_QMARK_DOT] = ACTIONS(154),
    [anon_sym_new] = ACTIONS(684),
    [anon_sym_using] = ACTIONS(158),
    [anon_sym_PLUS_EQ] = ACTIONS(160),
    [anon_sym_DASH_EQ] = ACTIONS(160),
    [anon_sym_STAR_EQ] = ACTIONS(160),
    [anon_sym_SLASH_EQ] = ACTIONS(160),
    [anon_sym_PERCENT_EQ] = ACTIONS(160),
    [anon_sym_CARET_EQ] = ACTIONS(160),
    [anon_sym_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_LT_LT_EQ] = ACTIONS(160),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(160),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP] = ACTIONS(120),
    [anon_sym_PIPE_PIPE] = ACTIONS(120),
    [anon_sym_GT_GT] = ACTIONS(120),
    [anon_sym_GT_GT_GT] = ACTIONS(120),
    [anon_sym_LT_LT] = ACTIONS(120),
    [anon_sym_AMP] = ACTIONS(120),
    [anon_sym_CARET] = ACTIONS(120),
    [anon_sym_PIPE] = ACTIONS(120),
    [anon_sym_PLUS] = ACTIONS(179),
    [anon_sym_DASH] = ACTIONS(179),
    [anon_sym_SLASH] = ACTIONS(77),
    [anon_sym_PERCENT] = ACTIONS(120),
    [anon_sym_STAR_STAR] = ACTIONS(120),
    [anon_sym_LT] = ACTIONS(173),
    [anon_sym_LT_EQ] = ACTIONS(154),
    [anon_sym_EQ_EQ] = ACTIONS(120),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(154),
    [anon_sym_BANG_EQ] = ACTIONS(120),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(154),
    [anon_sym_GT_EQ] = ACTIONS(154),
    [anon_sym_GT] = ACTIONS(120),
    [anon_sym_QMARK_QMARK] = ACTIONS(120),
    [anon_sym_instanceof] = ACTIONS(120),
    [anon_sym_TILDE] = ACTIONS(175),
    [anon_sym_void] = ACTIONS(179),
    [anon_sym_delete] = ACTIONS(179),
    [anon_sym_PLUS_PLUS] = ACTIONS(686),
    [anon_sym_DASH_DASH] = ACTIONS(686),
    [anon_sym_DQUOTE] = ACTIONS(83),
    [anon_sym_SQUOTE] = ACTIONS(85),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(87),
    [sym_number] = ACTIONS(89),
    [sym_private_property_identifier] = ACTIONS(192),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(93),
    [sym_true] = ACTIONS(93),
    [sym_false] = ACTIONS(93),
    [sym_null] = ACTIONS(93),
    [sym_undefined] = ACTIONS(688),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(659),
    [anon_sym_readonly] = ACTIONS(659),
    [anon_sym_get] = ACTIONS(659),
    [anon_sym_set] = ACTIONS(659),
    [anon_sym_declare] = ACTIONS(659),
    [anon_sym_public] = ACTIONS(659),
    [anon_sym_private] = ACTIONS(659),
    [anon_sym_protected] = ACTIONS(659),
    [anon_sym_override] = ACTIONS(659),
    [anon_sym_module] = ACTIONS(659),
    [anon_sym_any] = ACTIONS(659),
    [anon_sym_number] = ACTIONS(659),
    [anon_sym_boolean] = ACTIONS(659),
    [anon_sym_string] = ACTIONS(659),
    [anon_sym_symbol] = ACTIONS(659),
    [anon_sym_object] = ACTIONS(659),
    [anon_sym_satisfies] = ACTIONS(120),
    [sym__automatic_semicolon] = ACTIONS(154),
    [sym__ternary_qmark] = ACTIONS(154),
    [sym_html_comment] = ACTIONS(5),
  },
  [101] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1213),
    [sym_expression] = STATE(2644),
    [sym_primary_expression] = STATE(1501),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5522),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5522),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5558),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1213),
    [sym_subscript_expression] = STATE(1213),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3013),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5522),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(4116),
    [sym_non_null_expression] = STATE(1213),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(539),
    [sym_type_parameters] = STATE(5344),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(848),
    [anon_sym_export] = ACTIONS(850),
    [anon_sym_STAR] = ACTIONS(120),
    [anon_sym_type] = ACTIONS(850),
    [anon_sym_EQ] = ACTIONS(117),
    [anon_sym_as] = ACTIONS(120),
    [anon_sym_namespace] = ACTIONS(852),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_COMMA] = ACTIONS(126),
    [anon_sym_typeof] = ACTIONS(179),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(850),
    [anon_sym_BANG] = ACTIONS(179),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_RPAREN] = ACTIONS(126),
    [anon_sym_await] = ACTIONS(140),
    [anon_sym_in] = ACTIONS(120),
    [anon_sym_COLON] = ACTIONS(126),
    [anon_sym_yield] = ACTIONS(142),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_DOT] = ACTIONS(814),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(854),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_EQ_GT] = ACTIONS(152),
    [anon_sym_QMARK_DOT] = ACTIONS(154),
    [anon_sym_new] = ACTIONS(856),
    [anon_sym_using] = ACTIONS(158),
    [anon_sym_PLUS_EQ] = ACTIONS(160),
    [anon_sym_DASH_EQ] = ACTIONS(160),
    [anon_sym_STAR_EQ] = ACTIONS(160),
    [anon_sym_SLASH_EQ] = ACTIONS(160),
    [anon_sym_PERCENT_EQ] = ACTIONS(160),
    [anon_sym_CARET_EQ] = ACTIONS(160),
    [anon_sym_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_LT_LT_EQ] = ACTIONS(160),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(160),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP] = ACTIONS(120),
    [anon_sym_PIPE_PIPE] = ACTIONS(120),
    [anon_sym_GT_GT] = ACTIONS(120),
    [anon_sym_GT_GT_GT] = ACTIONS(120),
    [anon_sym_LT_LT] = ACTIONS(120),
    [anon_sym_AMP] = ACTIONS(120),
    [anon_sym_CARET] = ACTIONS(120),
    [anon_sym_PIPE] = ACTIONS(120),
    [anon_sym_PLUS] = ACTIONS(179),
    [anon_sym_DASH] = ACTIONS(179),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_PERCENT] = ACTIONS(120),
    [anon_sym_STAR_STAR] = ACTIONS(120),
    [anon_sym_LT] = ACTIONS(173),
    [anon_sym_LT_EQ] = ACTIONS(154),
    [anon_sym_EQ_EQ] = ACTIONS(120),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(154),
    [anon_sym_BANG_EQ] = ACTIONS(120),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(154),
    [anon_sym_GT_EQ] = ACTIONS(154),
    [anon_sym_GT] = ACTIONS(120),
    [anon_sym_QMARK_QMARK] = ACTIONS(120),
    [anon_sym_instanceof] = ACTIONS(120),
    [anon_sym_TILDE] = ACTIONS(175),
    [anon_sym_void] = ACTIONS(179),
    [anon_sym_delete] = ACTIONS(179),
    [anon_sym_PLUS_PLUS] = ACTIONS(686),
    [anon_sym_DASH_DASH] = ACTIONS(686),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(192),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(822),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(850),
    [anon_sym_readonly] = ACTIONS(850),
    [anon_sym_get] = ACTIONS(850),
    [anon_sym_set] = ACTIONS(850),
    [anon_sym_QMARK] = ACTIONS(720),
    [anon_sym_declare] = ACTIONS(850),
    [anon_sym_public] = ACTIONS(850),
    [anon_sym_private] = ACTIONS(850),
    [anon_sym_protected] = ACTIONS(850),
    [anon_sym_override] = ACTIONS(850),
    [anon_sym_module] = ACTIONS(850),
    [anon_sym_any] = ACTIONS(850),
    [anon_sym_number] = ACTIONS(850),
    [anon_sym_boolean] = ACTIONS(850),
    [anon_sym_string] = ACTIONS(850),
    [anon_sym_symbol] = ACTIONS(850),
    [anon_sym_object] = ACTIONS(850),
    [anon_sym_satisfies] = ACTIONS(120),
    [sym__ternary_qmark] = ACTIONS(154),
    [sym_html_comment] = ACTIONS(5),
  },
  [102] = {
    [sym_import] = STATE(3636),
    [sym_parenthesized_expression] = STATE(1334),
    [sym_expression] = STATE(2611),
    [sym_primary_expression] = STATE(1696),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(2222),
    [sym_object_pattern] = STATE(5522),
    [sym_array] = STATE(2222),
    [sym_array_pattern] = STATE(5522),
    [sym_class] = STATE(2222),
    [sym_function_expression] = STATE(2222),
    [sym_generator_function] = STATE(2222),
    [sym_arrow_function] = STATE(2222),
    [sym__call_signature] = STATE(5821),
    [sym_call_expression] = STATE(2222),
    [sym_new_expression] = STATE(2694),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1334),
    [sym_subscript_expression] = STATE(1334),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3013),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5522),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(2222),
    [sym_template_string] = STATE(2222),
    [sym_regex] = STATE(2222),
    [sym_meta_property] = STATE(2222),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1334),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(539),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4408),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_export] = ACTIONS(659),
    [anon_sym_STAR] = ACTIONS(120),
    [anon_sym_type] = ACTIONS(659),
    [anon_sym_EQ] = ACTIONS(858),
    [anon_sym_as] = ACTIONS(120),
    [anon_sym_namespace] = ACTIONS(663),
    [anon_sym_LBRACE] = ACTIONS(665),
    [anon_sym_COMMA] = ACTIONS(154),
    [anon_sym_RBRACE] = ACTIONS(154),
    [anon_sym_typeof] = ACTIONS(179),
    [anon_sym_import] = ACTIONS(669),
    [anon_sym_let] = ACTIONS(659),
    [anon_sym_BANG] = ACTIONS(179),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_SEMI] = ACTIONS(154),
    [anon_sym_await] = ACTIONS(140),
    [anon_sym_in] = ACTIONS(120),
    [anon_sym_yield] = ACTIONS(142),
    [anon_sym_LBRACK] = ACTIONS(65),
    [anon_sym_DOT] = ACTIONS(674),
    [anon_sym_class] = ACTIONS(676),
    [anon_sym_async] = ACTIONS(678),
    [anon_sym_function] = ACTIONS(680),
    [anon_sym_EQ_GT] = ACTIONS(682),
    [anon_sym_QMARK_DOT] = ACTIONS(154),
    [anon_sym_new] = ACTIONS(684),
    [anon_sym_using] = ACTIONS(158),
    [anon_sym_PLUS_EQ] = ACTIONS(160),
    [anon_sym_DASH_EQ] = ACTIONS(160),
    [anon_sym_STAR_EQ] = ACTIONS(160),
    [anon_sym_SLASH_EQ] = ACTIONS(160),
    [anon_sym_PERCENT_EQ] = ACTIONS(160),
    [anon_sym_CARET_EQ] = ACTIONS(160),
    [anon_sym_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_LT_LT_EQ] = ACTIONS(160),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(160),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP] = ACTIONS(120),
    [anon_sym_PIPE_PIPE] = ACTIONS(120),
    [anon_sym_GT_GT] = ACTIONS(120),
    [anon_sym_GT_GT_GT] = ACTIONS(120),
    [anon_sym_LT_LT] = ACTIONS(120),
    [anon_sym_AMP] = ACTIONS(120),
    [anon_sym_CARET] = ACTIONS(120),
    [anon_sym_PIPE] = ACTIONS(120),
    [anon_sym_PLUS] = ACTIONS(179),
    [anon_sym_DASH] = ACTIONS(179),
    [anon_sym_SLASH] = ACTIONS(77),
    [anon_sym_PERCENT] = ACTIONS(120),
    [anon_sym_STAR_STAR] = ACTIONS(120),
    [anon_sym_LT] = ACTIONS(173),
    [anon_sym_LT_EQ] = ACTIONS(154),
    [anon_sym_EQ_EQ] = ACTIONS(120),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(154),
    [anon_sym_BANG_EQ] = ACTIONS(120),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(154),
    [anon_sym_GT_EQ] = ACTIONS(154),
    [anon_sym_GT] = ACTIONS(120),
    [anon_sym_QMARK_QMARK] = ACTIONS(120),
    [anon_sym_instanceof] = ACTIONS(120),
    [anon_sym_TILDE] = ACTIONS(175),
    [anon_sym_void] = ACTIONS(179),
    [anon_sym_delete] = ACTIONS(179),
    [anon_sym_PLUS_PLUS] = ACTIONS(686),
    [anon_sym_DASH_DASH] = ACTIONS(686),
    [anon_sym_DQUOTE] = ACTIONS(83),
    [anon_sym_SQUOTE] = ACTIONS(85),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(87),
    [sym_number] = ACTIONS(89),
    [sym_private_property_identifier] = ACTIONS(192),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(93),
    [sym_true] = ACTIONS(93),
    [sym_false] = ACTIONS(93),
    [sym_null] = ACTIONS(93),
    [sym_undefined] = ACTIONS(688),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(659),
    [anon_sym_readonly] = ACTIONS(659),
    [anon_sym_get] = ACTIONS(659),
    [anon_sym_set] = ACTIONS(659),
    [anon_sym_declare] = ACTIONS(659),
    [anon_sym_public] = ACTIONS(659),
    [anon_sym_private] = ACTIONS(659),
    [anon_sym_protected] = ACTIONS(659),
    [anon_sym_override] = ACTIONS(659),
    [anon_sym_module] = ACTIONS(659),
    [anon_sym_any] = ACTIONS(659),
    [anon_sym_number] = ACTIONS(659),
    [anon_sym_boolean] = ACTIONS(659),
    [anon_sym_string] = ACTIONS(659),
    [anon_sym_symbol] = ACTIONS(659),
    [anon_sym_object] = ACTIONS(659),
    [anon_sym_satisfies] = ACTIONS(120),
    [sym__automatic_semicolon] = ACTIONS(154),
    [sym__ternary_qmark] = ACTIONS(154),
    [sym_html_comment] = ACTIONS(5),
  },
  [103] = {
    [sym_import] = STATE(3636),
    [sym_parenthesized_expression] = STATE(1334),
    [sym_expression] = STATE(2611),
    [sym_primary_expression] = STATE(1696),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(2222),
    [sym_object_pattern] = STATE(5522),
    [sym_array] = STATE(2222),
    [sym_array_pattern] = STATE(5522),
    [sym_class] = STATE(2222),
    [sym_function_expression] = STATE(2222),
    [sym_generator_function] = STATE(2222),
    [sym_arrow_function] = STATE(2222),
    [sym__call_signature] = STATE(5771),
    [sym_call_expression] = STATE(2222),
    [sym_new_expression] = STATE(2694),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1334),
    [sym_subscript_expression] = STATE(1334),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3013),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5522),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(2222),
    [sym_template_string] = STATE(2222),
    [sym_regex] = STATE(2222),
    [sym_meta_property] = STATE(2222),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1334),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(539),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4408),
    [sym_identifier] = ACTIONS(862),
    [anon_sym_export] = ACTIONS(864),
    [anon_sym_STAR] = ACTIONS(120),
    [anon_sym_type] = ACTIONS(864),
    [anon_sym_EQ] = ACTIONS(866),
    [anon_sym_as] = ACTIONS(120),
    [anon_sym_namespace] = ACTIONS(868),
    [anon_sym_LBRACE] = ACTIONS(665),
    [anon_sym_COMMA] = ACTIONS(154),
    [anon_sym_typeof] = ACTIONS(179),
    [anon_sym_import] = ACTIONS(669),
    [anon_sym_let] = ACTIONS(864),
    [anon_sym_BANG] = ACTIONS(179),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_SEMI] = ACTIONS(154),
    [anon_sym_await] = ACTIONS(140),
    [anon_sym_in] = ACTIONS(120),
    [anon_sym_of] = ACTIONS(120),
    [anon_sym_yield] = ACTIONS(142),
    [anon_sym_LBRACK] = ACTIONS(65),
    [anon_sym_DOT] = ACTIONS(674),
    [anon_sym_class] = ACTIONS(676),
    [anon_sym_async] = ACTIONS(870),
    [anon_sym_function] = ACTIONS(680),
    [anon_sym_EQ_GT] = ACTIONS(872),
    [anon_sym_QMARK_DOT] = ACTIONS(154),
    [anon_sym_new] = ACTIONS(874),
    [anon_sym_using] = ACTIONS(158),
    [anon_sym_PLUS_EQ] = ACTIONS(160),
    [anon_sym_DASH_EQ] = ACTIONS(160),
    [anon_sym_STAR_EQ] = ACTIONS(160),
    [anon_sym_SLASH_EQ] = ACTIONS(160),
    [anon_sym_PERCENT_EQ] = ACTIONS(160),
    [anon_sym_CARET_EQ] = ACTIONS(160),
    [anon_sym_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_LT_LT_EQ] = ACTIONS(160),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(160),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP] = ACTIONS(120),
    [anon_sym_PIPE_PIPE] = ACTIONS(120),
    [anon_sym_GT_GT] = ACTIONS(120),
    [anon_sym_GT_GT_GT] = ACTIONS(120),
    [anon_sym_LT_LT] = ACTIONS(120),
    [anon_sym_AMP] = ACTIONS(120),
    [anon_sym_CARET] = ACTIONS(120),
    [anon_sym_PIPE] = ACTIONS(120),
    [anon_sym_PLUS] = ACTIONS(179),
    [anon_sym_DASH] = ACTIONS(179),
    [anon_sym_SLASH] = ACTIONS(876),
    [anon_sym_PERCENT] = ACTIONS(120),
    [anon_sym_STAR_STAR] = ACTIONS(120),
    [anon_sym_LT] = ACTIONS(173),
    [anon_sym_LT_EQ] = ACTIONS(154),
    [anon_sym_EQ_EQ] = ACTIONS(120),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(154),
    [anon_sym_BANG_EQ] = ACTIONS(120),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(154),
    [anon_sym_GT_EQ] = ACTIONS(154),
    [anon_sym_GT] = ACTIONS(120),
    [anon_sym_QMARK_QMARK] = ACTIONS(120),
    [anon_sym_instanceof] = ACTIONS(120),
    [anon_sym_TILDE] = ACTIONS(175),
    [anon_sym_void] = ACTIONS(179),
    [anon_sym_delete] = ACTIONS(179),
    [anon_sym_PLUS_PLUS] = ACTIONS(686),
    [anon_sym_DASH_DASH] = ACTIONS(686),
    [anon_sym_DQUOTE] = ACTIONS(83),
    [anon_sym_SQUOTE] = ACTIONS(85),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(87),
    [sym_number] = ACTIONS(89),
    [sym_private_property_identifier] = ACTIONS(192),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(93),
    [sym_true] = ACTIONS(93),
    [sym_false] = ACTIONS(93),
    [sym_null] = ACTIONS(93),
    [sym_undefined] = ACTIONS(688),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(864),
    [anon_sym_readonly] = ACTIONS(864),
    [anon_sym_get] = ACTIONS(864),
    [anon_sym_set] = ACTIONS(864),
    [anon_sym_declare] = ACTIONS(864),
    [anon_sym_public] = ACTIONS(864),
    [anon_sym_private] = ACTIONS(864),
    [anon_sym_protected] = ACTIONS(864),
    [anon_sym_override] = ACTIONS(864),
    [anon_sym_module] = ACTIONS(864),
    [anon_sym_any] = ACTIONS(864),
    [anon_sym_number] = ACTIONS(864),
    [anon_sym_boolean] = ACTIONS(864),
    [anon_sym_string] = ACTIONS(864),
    [anon_sym_symbol] = ACTIONS(864),
    [anon_sym_object] = ACTIONS(864),
    [anon_sym_satisfies] = ACTIONS(120),
    [sym__automatic_semicolon] = ACTIONS(154),
    [sym__ternary_qmark] = ACTIONS(154),
    [sym_html_comment] = ACTIONS(5),
  },
  [104] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1213),
    [sym_expression] = STATE(2644),
    [sym_primary_expression] = STATE(1501),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5522),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5522),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5800),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1213),
    [sym_subscript_expression] = STATE(1213),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3013),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5522),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1213),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(539),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(802),
    [anon_sym_export] = ACTIONS(804),
    [anon_sym_STAR] = ACTIONS(120),
    [anon_sym_type] = ACTIONS(804),
    [anon_sym_EQ] = ACTIONS(824),
    [anon_sym_as] = ACTIONS(120),
    [anon_sym_namespace] = ACTIONS(806),
    [anon_sym_LBRACE] = ACTIONS(808),
    [anon_sym_COMMA] = ACTIONS(154),
    [anon_sym_typeof] = ACTIONS(179),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(804),
    [anon_sym_BANG] = ACTIONS(179),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_SEMI] = ACTIONS(154),
    [anon_sym_await] = ACTIONS(140),
    [anon_sym_in] = ACTIONS(120),
    [anon_sym_of] = ACTIONS(120),
    [anon_sym_yield] = ACTIONS(142),
    [anon_sym_LBRACK] = ACTIONS(812),
    [anon_sym_DOT] = ACTIONS(674),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(816),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_EQ_GT] = ACTIONS(872),
    [anon_sym_QMARK_DOT] = ACTIONS(154),
    [anon_sym_new] = ACTIONS(818),
    [anon_sym_using] = ACTIONS(158),
    [anon_sym_PLUS_EQ] = ACTIONS(160),
    [anon_sym_DASH_EQ] = ACTIONS(160),
    [anon_sym_STAR_EQ] = ACTIONS(160),
    [anon_sym_SLASH_EQ] = ACTIONS(160),
    [anon_sym_PERCENT_EQ] = ACTIONS(160),
    [anon_sym_CARET_EQ] = ACTIONS(160),
    [anon_sym_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_LT_LT_EQ] = ACTIONS(160),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(160),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP] = ACTIONS(120),
    [anon_sym_PIPE_PIPE] = ACTIONS(120),
    [anon_sym_GT_GT] = ACTIONS(120),
    [anon_sym_GT_GT_GT] = ACTIONS(120),
    [anon_sym_LT_LT] = ACTIONS(120),
    [anon_sym_AMP] = ACTIONS(120),
    [anon_sym_CARET] = ACTIONS(120),
    [anon_sym_PIPE] = ACTIONS(120),
    [anon_sym_PLUS] = ACTIONS(179),
    [anon_sym_DASH] = ACTIONS(179),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_PERCENT] = ACTIONS(120),
    [anon_sym_STAR_STAR] = ACTIONS(120),
    [anon_sym_LT] = ACTIONS(173),
    [anon_sym_LT_EQ] = ACTIONS(154),
    [anon_sym_EQ_EQ] = ACTIONS(120),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(154),
    [anon_sym_BANG_EQ] = ACTIONS(120),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(154),
    [anon_sym_GT_EQ] = ACTIONS(154),
    [anon_sym_GT] = ACTIONS(120),
    [anon_sym_QMARK_QMARK] = ACTIONS(120),
    [anon_sym_instanceof] = ACTIONS(120),
    [anon_sym_TILDE] = ACTIONS(175),
    [anon_sym_void] = ACTIONS(179),
    [anon_sym_delete] = ACTIONS(179),
    [anon_sym_PLUS_PLUS] = ACTIONS(686),
    [anon_sym_DASH_DASH] = ACTIONS(686),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(192),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(822),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(804),
    [anon_sym_readonly] = ACTIONS(804),
    [anon_sym_get] = ACTIONS(804),
    [anon_sym_set] = ACTIONS(804),
    [anon_sym_declare] = ACTIONS(804),
    [anon_sym_public] = ACTIONS(804),
    [anon_sym_private] = ACTIONS(804),
    [anon_sym_protected] = ACTIONS(804),
    [anon_sym_override] = ACTIONS(804),
    [anon_sym_module] = ACTIONS(804),
    [anon_sym_any] = ACTIONS(804),
    [anon_sym_number] = ACTIONS(804),
    [anon_sym_boolean] = ACTIONS(804),
    [anon_sym_string] = ACTIONS(804),
    [anon_sym_symbol] = ACTIONS(804),
    [anon_sym_object] = ACTIONS(804),
    [anon_sym_satisfies] = ACTIONS(120),
    [sym__automatic_semicolon] = ACTIONS(154),
    [sym__ternary_qmark] = ACTIONS(154),
    [sym_html_comment] = ACTIONS(5),
  },
  [105] = {
    [sym_import] = STATE(3636),
    [sym_parenthesized_expression] = STATE(1334),
    [sym_expression] = STATE(2611),
    [sym_primary_expression] = STATE(1696),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(2222),
    [sym_object_pattern] = STATE(5522),
    [sym_array] = STATE(2222),
    [sym_array_pattern] = STATE(5522),
    [sym_class] = STATE(2222),
    [sym_function_expression] = STATE(2222),
    [sym_generator_function] = STATE(2222),
    [sym_arrow_function] = STATE(2222),
    [sym__call_signature] = STATE(5771),
    [sym_call_expression] = STATE(2222),
    [sym_new_expression] = STATE(2694),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1334),
    [sym_subscript_expression] = STATE(1334),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3013),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5522),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(2222),
    [sym_template_string] = STATE(2222),
    [sym_regex] = STATE(2222),
    [sym_meta_property] = STATE(2222),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(4116),
    [sym_non_null_expression] = STATE(1334),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(539),
    [sym_type_parameters] = STATE(5344),
    [aux_sym_export_statement_repeat1] = STATE(4408),
    [sym_identifier] = ACTIONS(862),
    [anon_sym_export] = ACTIONS(864),
    [anon_sym_STAR] = ACTIONS(120),
    [anon_sym_type] = ACTIONS(864),
    [anon_sym_EQ] = ACTIONS(866),
    [anon_sym_as] = ACTIONS(120),
    [anon_sym_namespace] = ACTIONS(868),
    [anon_sym_LBRACE] = ACTIONS(665),
    [anon_sym_COMMA] = ACTIONS(154),
    [anon_sym_typeof] = ACTIONS(179),
    [anon_sym_import] = ACTIONS(669),
    [anon_sym_let] = ACTIONS(864),
    [anon_sym_BANG] = ACTIONS(179),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_SEMI] = ACTIONS(154),
    [anon_sym_await] = ACTIONS(140),
    [anon_sym_in] = ACTIONS(120),
    [anon_sym_of] = ACTIONS(120),
    [anon_sym_yield] = ACTIONS(142),
    [anon_sym_LBRACK] = ACTIONS(65),
    [anon_sym_DOT] = ACTIONS(674),
    [anon_sym_class] = ACTIONS(676),
    [anon_sym_async] = ACTIONS(870),
    [anon_sym_function] = ACTIONS(680),
    [anon_sym_EQ_GT] = ACTIONS(872),
    [anon_sym_QMARK_DOT] = ACTIONS(154),
    [anon_sym_new] = ACTIONS(874),
    [anon_sym_using] = ACTIONS(158),
    [anon_sym_PLUS_EQ] = ACTIONS(160),
    [anon_sym_DASH_EQ] = ACTIONS(160),
    [anon_sym_STAR_EQ] = ACTIONS(160),
    [anon_sym_SLASH_EQ] = ACTIONS(160),
    [anon_sym_PERCENT_EQ] = ACTIONS(160),
    [anon_sym_CARET_EQ] = ACTIONS(160),
    [anon_sym_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_LT_LT_EQ] = ACTIONS(160),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(160),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP] = ACTIONS(120),
    [anon_sym_PIPE_PIPE] = ACTIONS(120),
    [anon_sym_GT_GT] = ACTIONS(120),
    [anon_sym_GT_GT_GT] = ACTIONS(120),
    [anon_sym_LT_LT] = ACTIONS(120),
    [anon_sym_AMP] = ACTIONS(120),
    [anon_sym_CARET] = ACTIONS(120),
    [anon_sym_PIPE] = ACTIONS(120),
    [anon_sym_PLUS] = ACTIONS(179),
    [anon_sym_DASH] = ACTIONS(179),
    [anon_sym_SLASH] = ACTIONS(876),
    [anon_sym_PERCENT] = ACTIONS(120),
    [anon_sym_STAR_STAR] = ACTIONS(120),
    [anon_sym_LT] = ACTIONS(173),
    [anon_sym_LT_EQ] = ACTIONS(154),
    [anon_sym_EQ_EQ] = ACTIONS(120),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(154),
    [anon_sym_BANG_EQ] = ACTIONS(120),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(154),
    [anon_sym_GT_EQ] = ACTIONS(154),
    [anon_sym_GT] = ACTIONS(120),
    [anon_sym_QMARK_QMARK] = ACTIONS(120),
    [anon_sym_instanceof] = ACTIONS(120),
    [anon_sym_TILDE] = ACTIONS(175),
    [anon_sym_void] = ACTIONS(179),
    [anon_sym_delete] = ACTIONS(179),
    [anon_sym_PLUS_PLUS] = ACTIONS(686),
    [anon_sym_DASH_DASH] = ACTIONS(686),
    [anon_sym_DQUOTE] = ACTIONS(83),
    [anon_sym_SQUOTE] = ACTIONS(85),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(87),
    [sym_number] = ACTIONS(89),
    [sym_private_property_identifier] = ACTIONS(192),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(93),
    [sym_true] = ACTIONS(93),
    [sym_false] = ACTIONS(93),
    [sym_null] = ACTIONS(93),
    [sym_undefined] = ACTIONS(688),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(864),
    [anon_sym_readonly] = ACTIONS(864),
    [anon_sym_get] = ACTIONS(864),
    [anon_sym_set] = ACTIONS(864),
    [anon_sym_declare] = ACTIONS(864),
    [anon_sym_public] = ACTIONS(864),
    [anon_sym_private] = ACTIONS(864),
    [anon_sym_protected] = ACTIONS(864),
    [anon_sym_override] = ACTIONS(864),
    [anon_sym_module] = ACTIONS(864),
    [anon_sym_any] = ACTIONS(864),
    [anon_sym_number] = ACTIONS(864),
    [anon_sym_boolean] = ACTIONS(864),
    [anon_sym_string] = ACTIONS(864),
    [anon_sym_symbol] = ACTIONS(864),
    [anon_sym_object] = ACTIONS(864),
    [anon_sym_satisfies] = ACTIONS(120),
    [sym__automatic_semicolon] = ACTIONS(154),
    [sym__ternary_qmark] = ACTIONS(154),
    [sym_html_comment] = ACTIONS(5),
  },
  [106] = {
    [sym_import] = STATE(3636),
    [sym_parenthesized_expression] = STATE(1334),
    [sym_expression] = STATE(2611),
    [sym_primary_expression] = STATE(1696),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(2222),
    [sym_object_pattern] = STATE(5522),
    [sym_array] = STATE(2222),
    [sym_array_pattern] = STATE(5522),
    [sym_class] = STATE(2222),
    [sym_function_expression] = STATE(2222),
    [sym_generator_function] = STATE(2222),
    [sym_arrow_function] = STATE(2222),
    [sym__call_signature] = STATE(5821),
    [sym_call_expression] = STATE(2222),
    [sym_new_expression] = STATE(2694),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1334),
    [sym_subscript_expression] = STATE(1334),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3013),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5522),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(2222),
    [sym_template_string] = STATE(2222),
    [sym_regex] = STATE(2222),
    [sym_meta_property] = STATE(2222),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1334),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(539),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4408),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_export] = ACTIONS(659),
    [anon_sym_STAR] = ACTIONS(120),
    [anon_sym_type] = ACTIONS(659),
    [anon_sym_EQ] = ACTIONS(858),
    [anon_sym_as] = ACTIONS(120),
    [anon_sym_namespace] = ACTIONS(663),
    [anon_sym_LBRACE] = ACTIONS(665),
    [anon_sym_COMMA] = ACTIONS(154),
    [anon_sym_typeof] = ACTIONS(179),
    [anon_sym_import] = ACTIONS(669),
    [anon_sym_let] = ACTIONS(659),
    [anon_sym_BANG] = ACTIONS(179),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_SEMI] = ACTIONS(154),
    [anon_sym_await] = ACTIONS(140),
    [anon_sym_in] = ACTIONS(120),
    [anon_sym_COLON] = ACTIONS(878),
    [anon_sym_yield] = ACTIONS(142),
    [anon_sym_LBRACK] = ACTIONS(65),
    [anon_sym_DOT] = ACTIONS(674),
    [anon_sym_class] = ACTIONS(676),
    [anon_sym_async] = ACTIONS(678),
    [anon_sym_function] = ACTIONS(680),
    [anon_sym_EQ_GT] = ACTIONS(682),
    [anon_sym_QMARK_DOT] = ACTIONS(154),
    [anon_sym_new] = ACTIONS(684),
    [anon_sym_using] = ACTIONS(158),
    [anon_sym_PLUS_EQ] = ACTIONS(160),
    [anon_sym_DASH_EQ] = ACTIONS(160),
    [anon_sym_STAR_EQ] = ACTIONS(160),
    [anon_sym_SLASH_EQ] = ACTIONS(160),
    [anon_sym_PERCENT_EQ] = ACTIONS(160),
    [anon_sym_CARET_EQ] = ACTIONS(160),
    [anon_sym_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_LT_LT_EQ] = ACTIONS(160),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(160),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP] = ACTIONS(120),
    [anon_sym_PIPE_PIPE] = ACTIONS(120),
    [anon_sym_GT_GT] = ACTIONS(120),
    [anon_sym_GT_GT_GT] = ACTIONS(120),
    [anon_sym_LT_LT] = ACTIONS(120),
    [anon_sym_AMP] = ACTIONS(120),
    [anon_sym_CARET] = ACTIONS(120),
    [anon_sym_PIPE] = ACTIONS(120),
    [anon_sym_PLUS] = ACTIONS(179),
    [anon_sym_DASH] = ACTIONS(179),
    [anon_sym_SLASH] = ACTIONS(77),
    [anon_sym_PERCENT] = ACTIONS(120),
    [anon_sym_STAR_STAR] = ACTIONS(120),
    [anon_sym_LT] = ACTIONS(173),
    [anon_sym_LT_EQ] = ACTIONS(154),
    [anon_sym_EQ_EQ] = ACTIONS(120),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(154),
    [anon_sym_BANG_EQ] = ACTIONS(120),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(154),
    [anon_sym_GT_EQ] = ACTIONS(154),
    [anon_sym_GT] = ACTIONS(120),
    [anon_sym_QMARK_QMARK] = ACTIONS(120),
    [anon_sym_instanceof] = ACTIONS(120),
    [anon_sym_TILDE] = ACTIONS(175),
    [anon_sym_void] = ACTIONS(179),
    [anon_sym_delete] = ACTIONS(179),
    [anon_sym_PLUS_PLUS] = ACTIONS(686),
    [anon_sym_DASH_DASH] = ACTIONS(686),
    [anon_sym_DQUOTE] = ACTIONS(83),
    [anon_sym_SQUOTE] = ACTIONS(85),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(87),
    [sym_number] = ACTIONS(89),
    [sym_private_property_identifier] = ACTIONS(192),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(93),
    [sym_true] = ACTIONS(93),
    [sym_false] = ACTIONS(93),
    [sym_null] = ACTIONS(93),
    [sym_undefined] = ACTIONS(688),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(659),
    [anon_sym_readonly] = ACTIONS(659),
    [anon_sym_get] = ACTIONS(659),
    [anon_sym_set] = ACTIONS(659),
    [anon_sym_declare] = ACTIONS(659),
    [anon_sym_public] = ACTIONS(659),
    [anon_sym_private] = ACTIONS(659),
    [anon_sym_protected] = ACTIONS(659),
    [anon_sym_override] = ACTIONS(659),
    [anon_sym_module] = ACTIONS(659),
    [anon_sym_any] = ACTIONS(659),
    [anon_sym_number] = ACTIONS(659),
    [anon_sym_boolean] = ACTIONS(659),
    [anon_sym_string] = ACTIONS(659),
    [anon_sym_symbol] = ACTIONS(659),
    [anon_sym_object] = ACTIONS(659),
    [anon_sym_satisfies] = ACTIONS(120),
    [sym__automatic_semicolon] = ACTIONS(154),
    [sym__ternary_qmark] = ACTIONS(154),
    [sym_html_comment] = ACTIONS(5),
  },
  [107] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1213),
    [sym_expression] = STATE(2644),
    [sym_primary_expression] = STATE(1501),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5522),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5522),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5558),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1213),
    [sym_subscript_expression] = STATE(1213),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3013),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5522),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(4116),
    [sym_non_null_expression] = STATE(1213),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(539),
    [sym_type_parameters] = STATE(5344),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(848),
    [anon_sym_export] = ACTIONS(850),
    [anon_sym_STAR] = ACTIONS(120),
    [anon_sym_type] = ACTIONS(850),
    [anon_sym_EQ] = ACTIONS(880),
    [anon_sym_as] = ACTIONS(120),
    [anon_sym_namespace] = ACTIONS(852),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_COMMA] = ACTIONS(154),
    [anon_sym_typeof] = ACTIONS(179),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(850),
    [anon_sym_BANG] = ACTIONS(179),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_RPAREN] = ACTIONS(154),
    [anon_sym_await] = ACTIONS(140),
    [anon_sym_in] = ACTIONS(120),
    [anon_sym_COLON] = ACTIONS(154),
    [anon_sym_yield] = ACTIONS(142),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_DOT] = ACTIONS(814),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(854),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_EQ_GT] = ACTIONS(152),
    [anon_sym_QMARK_DOT] = ACTIONS(154),
    [anon_sym_new] = ACTIONS(856),
    [anon_sym_using] = ACTIONS(158),
    [anon_sym_PLUS_EQ] = ACTIONS(160),
    [anon_sym_DASH_EQ] = ACTIONS(160),
    [anon_sym_STAR_EQ] = ACTIONS(160),
    [anon_sym_SLASH_EQ] = ACTIONS(160),
    [anon_sym_PERCENT_EQ] = ACTIONS(160),
    [anon_sym_CARET_EQ] = ACTIONS(160),
    [anon_sym_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_LT_LT_EQ] = ACTIONS(160),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(160),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP] = ACTIONS(120),
    [anon_sym_PIPE_PIPE] = ACTIONS(120),
    [anon_sym_GT_GT] = ACTIONS(120),
    [anon_sym_GT_GT_GT] = ACTIONS(120),
    [anon_sym_LT_LT] = ACTIONS(120),
    [anon_sym_AMP] = ACTIONS(120),
    [anon_sym_CARET] = ACTIONS(120),
    [anon_sym_PIPE] = ACTIONS(120),
    [anon_sym_PLUS] = ACTIONS(179),
    [anon_sym_DASH] = ACTIONS(179),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_PERCENT] = ACTIONS(120),
    [anon_sym_STAR_STAR] = ACTIONS(120),
    [anon_sym_LT] = ACTIONS(173),
    [anon_sym_LT_EQ] = ACTIONS(154),
    [anon_sym_EQ_EQ] = ACTIONS(120),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(154),
    [anon_sym_BANG_EQ] = ACTIONS(120),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(154),
    [anon_sym_GT_EQ] = ACTIONS(154),
    [anon_sym_GT] = ACTIONS(120),
    [anon_sym_QMARK_QMARK] = ACTIONS(120),
    [anon_sym_instanceof] = ACTIONS(120),
    [anon_sym_TILDE] = ACTIONS(175),
    [anon_sym_void] = ACTIONS(179),
    [anon_sym_delete] = ACTIONS(179),
    [anon_sym_PLUS_PLUS] = ACTIONS(686),
    [anon_sym_DASH_DASH] = ACTIONS(686),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(192),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(822),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(850),
    [anon_sym_readonly] = ACTIONS(850),
    [anon_sym_get] = ACTIONS(850),
    [anon_sym_set] = ACTIONS(850),
    [anon_sym_declare] = ACTIONS(850),
    [anon_sym_public] = ACTIONS(850),
    [anon_sym_private] = ACTIONS(850),
    [anon_sym_protected] = ACTIONS(850),
    [anon_sym_override] = ACTIONS(850),
    [anon_sym_module] = ACTIONS(850),
    [anon_sym_any] = ACTIONS(850),
    [anon_sym_number] = ACTIONS(850),
    [anon_sym_boolean] = ACTIONS(850),
    [anon_sym_string] = ACTIONS(850),
    [anon_sym_symbol] = ACTIONS(850),
    [anon_sym_object] = ACTIONS(850),
    [anon_sym_satisfies] = ACTIONS(120),
    [sym__ternary_qmark] = ACTIONS(154),
    [sym_html_comment] = ACTIONS(5),
  },
  [108] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1213),
    [sym_expression] = STATE(2644),
    [sym_primary_expression] = STATE(1501),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5522),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5522),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5558),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1213),
    [sym_subscript_expression] = STATE(1213),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3013),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5522),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1213),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(539),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(848),
    [anon_sym_export] = ACTIONS(850),
    [anon_sym_STAR] = ACTIONS(120),
    [anon_sym_type] = ACTIONS(850),
    [anon_sym_EQ] = ACTIONS(880),
    [anon_sym_as] = ACTIONS(120),
    [anon_sym_namespace] = ACTIONS(852),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_COMMA] = ACTIONS(154),
    [anon_sym_typeof] = ACTIONS(179),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(850),
    [anon_sym_BANG] = ACTIONS(179),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_RPAREN] = ACTIONS(154),
    [anon_sym_await] = ACTIONS(140),
    [anon_sym_in] = ACTIONS(120),
    [anon_sym_COLON] = ACTIONS(154),
    [anon_sym_yield] = ACTIONS(142),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_DOT] = ACTIONS(814),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(854),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_EQ_GT] = ACTIONS(152),
    [anon_sym_QMARK_DOT] = ACTIONS(154),
    [anon_sym_new] = ACTIONS(856),
    [anon_sym_using] = ACTIONS(158),
    [anon_sym_PLUS_EQ] = ACTIONS(160),
    [anon_sym_DASH_EQ] = ACTIONS(160),
    [anon_sym_STAR_EQ] = ACTIONS(160),
    [anon_sym_SLASH_EQ] = ACTIONS(160),
    [anon_sym_PERCENT_EQ] = ACTIONS(160),
    [anon_sym_CARET_EQ] = ACTIONS(160),
    [anon_sym_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_LT_LT_EQ] = ACTIONS(160),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(160),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP] = ACTIONS(120),
    [anon_sym_PIPE_PIPE] = ACTIONS(120),
    [anon_sym_GT_GT] = ACTIONS(120),
    [anon_sym_GT_GT_GT] = ACTIONS(120),
    [anon_sym_LT_LT] = ACTIONS(120),
    [anon_sym_AMP] = ACTIONS(120),
    [anon_sym_CARET] = ACTIONS(120),
    [anon_sym_PIPE] = ACTIONS(120),
    [anon_sym_PLUS] = ACTIONS(179),
    [anon_sym_DASH] = ACTIONS(179),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_PERCENT] = ACTIONS(120),
    [anon_sym_STAR_STAR] = ACTIONS(120),
    [anon_sym_LT] = ACTIONS(173),
    [anon_sym_LT_EQ] = ACTIONS(154),
    [anon_sym_EQ_EQ] = ACTIONS(120),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(154),
    [anon_sym_BANG_EQ] = ACTIONS(120),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(154),
    [anon_sym_GT_EQ] = ACTIONS(154),
    [anon_sym_GT] = ACTIONS(120),
    [anon_sym_QMARK_QMARK] = ACTIONS(120),
    [anon_sym_instanceof] = ACTIONS(120),
    [anon_sym_TILDE] = ACTIONS(175),
    [anon_sym_void] = ACTIONS(179),
    [anon_sym_delete] = ACTIONS(179),
    [anon_sym_PLUS_PLUS] = ACTIONS(686),
    [anon_sym_DASH_DASH] = ACTIONS(686),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(192),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(822),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(850),
    [anon_sym_readonly] = ACTIONS(850),
    [anon_sym_get] = ACTIONS(850),
    [anon_sym_set] = ACTIONS(850),
    [anon_sym_declare] = ACTIONS(850),
    [anon_sym_public] = ACTIONS(850),
    [anon_sym_private] = ACTIONS(850),
    [anon_sym_protected] = ACTIONS(850),
    [anon_sym_override] = ACTIONS(850),
    [anon_sym_module] = ACTIONS(850),
    [anon_sym_any] = ACTIONS(850),
    [anon_sym_number] = ACTIONS(850),
    [anon_sym_boolean] = ACTIONS(850),
    [anon_sym_string] = ACTIONS(850),
    [anon_sym_symbol] = ACTIONS(850),
    [anon_sym_object] = ACTIONS(850),
    [anon_sym_satisfies] = ACTIONS(120),
    [sym__ternary_qmark] = ACTIONS(154),
    [sym_html_comment] = ACTIONS(5),
  },
  [109] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1213),
    [sym_expression] = STATE(2644),
    [sym_primary_expression] = STATE(1501),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5522),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5522),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5477),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1213),
    [sym_subscript_expression] = STATE(1213),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3013),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5522),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1213),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(539),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(882),
    [anon_sym_export] = ACTIONS(884),
    [anon_sym_STAR] = ACTIONS(120),
    [anon_sym_type] = ACTIONS(884),
    [anon_sym_EQ] = ACTIONS(886),
    [anon_sym_as] = ACTIONS(120),
    [anon_sym_namespace] = ACTIONS(889),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_COMMA] = ACTIONS(223),
    [anon_sym_typeof] = ACTIONS(179),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(884),
    [anon_sym_BANG] = ACTIONS(179),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(140),
    [anon_sym_in] = ACTIONS(120),
    [anon_sym_COLON] = ACTIONS(891),
    [anon_sym_yield] = ACTIONS(142),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_RBRACK] = ACTIONS(126),
    [anon_sym_DOT] = ACTIONS(814),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(893),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_EQ_GT] = ACTIONS(895),
    [anon_sym_QMARK_DOT] = ACTIONS(154),
    [anon_sym_new] = ACTIONS(897),
    [anon_sym_using] = ACTIONS(158),
    [anon_sym_PLUS_EQ] = ACTIONS(160),
    [anon_sym_DASH_EQ] = ACTIONS(160),
    [anon_sym_STAR_EQ] = ACTIONS(160),
    [anon_sym_SLASH_EQ] = ACTIONS(160),
    [anon_sym_PERCENT_EQ] = ACTIONS(160),
    [anon_sym_CARET_EQ] = ACTIONS(160),
    [anon_sym_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_LT_LT_EQ] = ACTIONS(160),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(160),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP] = ACTIONS(120),
    [anon_sym_PIPE_PIPE] = ACTIONS(120),
    [anon_sym_GT_GT] = ACTIONS(120),
    [anon_sym_GT_GT_GT] = ACTIONS(120),
    [anon_sym_LT_LT] = ACTIONS(120),
    [anon_sym_AMP] = ACTIONS(120),
    [anon_sym_CARET] = ACTIONS(120),
    [anon_sym_PIPE] = ACTIONS(120),
    [anon_sym_PLUS] = ACTIONS(179),
    [anon_sym_DASH] = ACTIONS(179),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_PERCENT] = ACTIONS(120),
    [anon_sym_STAR_STAR] = ACTIONS(120),
    [anon_sym_LT] = ACTIONS(173),
    [anon_sym_LT_EQ] = ACTIONS(154),
    [anon_sym_EQ_EQ] = ACTIONS(120),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(154),
    [anon_sym_BANG_EQ] = ACTIONS(120),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(154),
    [anon_sym_GT_EQ] = ACTIONS(154),
    [anon_sym_GT] = ACTIONS(120),
    [anon_sym_QMARK_QMARK] = ACTIONS(120),
    [anon_sym_instanceof] = ACTIONS(120),
    [anon_sym_TILDE] = ACTIONS(175),
    [anon_sym_void] = ACTIONS(179),
    [anon_sym_delete] = ACTIONS(179),
    [anon_sym_PLUS_PLUS] = ACTIONS(686),
    [anon_sym_DASH_DASH] = ACTIONS(686),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(192),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(822),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(884),
    [anon_sym_readonly] = ACTIONS(884),
    [anon_sym_get] = ACTIONS(884),
    [anon_sym_set] = ACTIONS(884),
    [anon_sym_declare] = ACTIONS(884),
    [anon_sym_public] = ACTIONS(884),
    [anon_sym_private] = ACTIONS(884),
    [anon_sym_protected] = ACTIONS(884),
    [anon_sym_override] = ACTIONS(884),
    [anon_sym_module] = ACTIONS(884),
    [anon_sym_any] = ACTIONS(884),
    [anon_sym_number] = ACTIONS(884),
    [anon_sym_boolean] = ACTIONS(884),
    [anon_sym_string] = ACTIONS(884),
    [anon_sym_symbol] = ACTIONS(884),
    [anon_sym_object] = ACTIONS(884),
    [anon_sym_satisfies] = ACTIONS(120),
    [sym__ternary_qmark] = ACTIONS(154),
    [sym_html_comment] = ACTIONS(5),
  },
  [110] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1213),
    [sym_expression] = STATE(2644),
    [sym_primary_expression] = STATE(1501),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5522),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5522),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5508),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1213),
    [sym_subscript_expression] = STATE(1213),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3013),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5522),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1213),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(539),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(830),
    [anon_sym_export] = ACTIONS(832),
    [anon_sym_STAR] = ACTIONS(120),
    [anon_sym_type] = ACTIONS(832),
    [anon_sym_EQ] = ACTIONS(834),
    [anon_sym_as] = ACTIONS(120),
    [anon_sym_namespace] = ACTIONS(836),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_COMMA] = ACTIONS(899),
    [anon_sym_RBRACE] = ACTIONS(899),
    [anon_sym_typeof] = ACTIONS(179),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(832),
    [anon_sym_BANG] = ACTIONS(179),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(140),
    [anon_sym_in] = ACTIONS(120),
    [anon_sym_yield] = ACTIONS(142),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_RBRACK] = ACTIONS(899),
    [anon_sym_DOT] = ACTIONS(814),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(842),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_EQ_GT] = ACTIONS(844),
    [anon_sym_QMARK_DOT] = ACTIONS(154),
    [anon_sym_new] = ACTIONS(846),
    [anon_sym_using] = ACTIONS(158),
    [anon_sym_PLUS_EQ] = ACTIONS(160),
    [anon_sym_DASH_EQ] = ACTIONS(160),
    [anon_sym_STAR_EQ] = ACTIONS(160),
    [anon_sym_SLASH_EQ] = ACTIONS(160),
    [anon_sym_PERCENT_EQ] = ACTIONS(160),
    [anon_sym_CARET_EQ] = ACTIONS(160),
    [anon_sym_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_LT_LT_EQ] = ACTIONS(160),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(160),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP] = ACTIONS(120),
    [anon_sym_PIPE_PIPE] = ACTIONS(120),
    [anon_sym_GT_GT] = ACTIONS(120),
    [anon_sym_GT_GT_GT] = ACTIONS(120),
    [anon_sym_LT_LT] = ACTIONS(120),
    [anon_sym_AMP] = ACTIONS(120),
    [anon_sym_CARET] = ACTIONS(120),
    [anon_sym_PIPE] = ACTIONS(120),
    [anon_sym_PLUS] = ACTIONS(179),
    [anon_sym_DASH] = ACTIONS(179),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_PERCENT] = ACTIONS(120),
    [anon_sym_STAR_STAR] = ACTIONS(120),
    [anon_sym_LT] = ACTIONS(173),
    [anon_sym_LT_EQ] = ACTIONS(154),
    [anon_sym_EQ_EQ] = ACTIONS(120),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(154),
    [anon_sym_BANG_EQ] = ACTIONS(120),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(154),
    [anon_sym_GT_EQ] = ACTIONS(154),
    [anon_sym_GT] = ACTIONS(120),
    [anon_sym_QMARK_QMARK] = ACTIONS(120),
    [anon_sym_instanceof] = ACTIONS(120),
    [anon_sym_TILDE] = ACTIONS(175),
    [anon_sym_void] = ACTIONS(179),
    [anon_sym_delete] = ACTIONS(179),
    [anon_sym_PLUS_PLUS] = ACTIONS(686),
    [anon_sym_DASH_DASH] = ACTIONS(686),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(192),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(822),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(832),
    [anon_sym_readonly] = ACTIONS(832),
    [anon_sym_get] = ACTIONS(832),
    [anon_sym_set] = ACTIONS(832),
    [anon_sym_declare] = ACTIONS(832),
    [anon_sym_public] = ACTIONS(832),
    [anon_sym_private] = ACTIONS(832),
    [anon_sym_protected] = ACTIONS(832),
    [anon_sym_override] = ACTIONS(832),
    [anon_sym_module] = ACTIONS(832),
    [anon_sym_any] = ACTIONS(832),
    [anon_sym_number] = ACTIONS(832),
    [anon_sym_boolean] = ACTIONS(832),
    [anon_sym_string] = ACTIONS(832),
    [anon_sym_symbol] = ACTIONS(832),
    [anon_sym_object] = ACTIONS(832),
    [anon_sym_satisfies] = ACTIONS(120),
    [sym__ternary_qmark] = ACTIONS(154),
    [sym_html_comment] = ACTIONS(5),
  },
  [111] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1213),
    [sym_expression] = STATE(2644),
    [sym_primary_expression] = STATE(1501),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5522),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5522),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5508),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1213),
    [sym_subscript_expression] = STATE(1213),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3013),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5522),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1213),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(539),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(830),
    [anon_sym_export] = ACTIONS(832),
    [anon_sym_STAR] = ACTIONS(120),
    [anon_sym_type] = ACTIONS(832),
    [anon_sym_EQ] = ACTIONS(834),
    [anon_sym_as] = ACTIONS(120),
    [anon_sym_namespace] = ACTIONS(836),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_COMMA] = ACTIONS(154),
    [anon_sym_typeof] = ACTIONS(179),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(832),
    [anon_sym_BANG] = ACTIONS(179),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_SEMI] = ACTIONS(154),
    [anon_sym_await] = ACTIONS(140),
    [anon_sym_in] = ACTIONS(902),
    [anon_sym_of] = ACTIONS(905),
    [anon_sym_yield] = ACTIONS(142),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_DOT] = ACTIONS(814),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(842),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_EQ_GT] = ACTIONS(844),
    [anon_sym_QMARK_DOT] = ACTIONS(154),
    [anon_sym_new] = ACTIONS(846),
    [anon_sym_using] = ACTIONS(158),
    [anon_sym_PLUS_EQ] = ACTIONS(160),
    [anon_sym_DASH_EQ] = ACTIONS(160),
    [anon_sym_STAR_EQ] = ACTIONS(160),
    [anon_sym_SLASH_EQ] = ACTIONS(160),
    [anon_sym_PERCENT_EQ] = ACTIONS(160),
    [anon_sym_CARET_EQ] = ACTIONS(160),
    [anon_sym_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_LT_LT_EQ] = ACTIONS(160),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(160),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP] = ACTIONS(120),
    [anon_sym_PIPE_PIPE] = ACTIONS(120),
    [anon_sym_GT_GT] = ACTIONS(120),
    [anon_sym_GT_GT_GT] = ACTIONS(120),
    [anon_sym_LT_LT] = ACTIONS(120),
    [anon_sym_AMP] = ACTIONS(120),
    [anon_sym_CARET] = ACTIONS(120),
    [anon_sym_PIPE] = ACTIONS(120),
    [anon_sym_PLUS] = ACTIONS(179),
    [anon_sym_DASH] = ACTIONS(179),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_PERCENT] = ACTIONS(120),
    [anon_sym_STAR_STAR] = ACTIONS(120),
    [anon_sym_LT] = ACTIONS(173),
    [anon_sym_LT_EQ] = ACTIONS(154),
    [anon_sym_EQ_EQ] = ACTIONS(120),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(154),
    [anon_sym_BANG_EQ] = ACTIONS(120),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(154),
    [anon_sym_GT_EQ] = ACTIONS(154),
    [anon_sym_GT] = ACTIONS(120),
    [anon_sym_QMARK_QMARK] = ACTIONS(120),
    [anon_sym_instanceof] = ACTIONS(120),
    [anon_sym_TILDE] = ACTIONS(175),
    [anon_sym_void] = ACTIONS(179),
    [anon_sym_delete] = ACTIONS(179),
    [anon_sym_PLUS_PLUS] = ACTIONS(686),
    [anon_sym_DASH_DASH] = ACTIONS(686),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(192),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(822),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(832),
    [anon_sym_readonly] = ACTIONS(832),
    [anon_sym_get] = ACTIONS(832),
    [anon_sym_set] = ACTIONS(832),
    [anon_sym_declare] = ACTIONS(832),
    [anon_sym_public] = ACTIONS(832),
    [anon_sym_private] = ACTIONS(832),
    [anon_sym_protected] = ACTIONS(832),
    [anon_sym_override] = ACTIONS(832),
    [anon_sym_module] = ACTIONS(832),
    [anon_sym_any] = ACTIONS(832),
    [anon_sym_number] = ACTIONS(832),
    [anon_sym_boolean] = ACTIONS(832),
    [anon_sym_string] = ACTIONS(832),
    [anon_sym_symbol] = ACTIONS(832),
    [anon_sym_object] = ACTIONS(832),
    [anon_sym_satisfies] = ACTIONS(120),
    [sym__ternary_qmark] = ACTIONS(154),
    [sym_html_comment] = ACTIONS(5),
  },
  [112] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1213),
    [sym_expression] = STATE(2644),
    [sym_primary_expression] = STATE(1501),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5522),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5522),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5508),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1213),
    [sym_subscript_expression] = STATE(1213),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3013),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5522),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(4116),
    [sym_non_null_expression] = STATE(1213),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(539),
    [sym_type_parameters] = STATE(5344),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(830),
    [anon_sym_export] = ACTIONS(832),
    [anon_sym_STAR] = ACTIONS(120),
    [anon_sym_type] = ACTIONS(832),
    [anon_sym_EQ] = ACTIONS(834),
    [anon_sym_as] = ACTIONS(120),
    [anon_sym_namespace] = ACTIONS(836),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_COMMA] = ACTIONS(899),
    [anon_sym_typeof] = ACTIONS(179),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(832),
    [anon_sym_BANG] = ACTIONS(179),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(140),
    [anon_sym_in] = ACTIONS(120),
    [anon_sym_COLON] = ACTIONS(826),
    [anon_sym_yield] = ACTIONS(142),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_RBRACK] = ACTIONS(899),
    [anon_sym_DOT] = ACTIONS(814),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(842),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_EQ_GT] = ACTIONS(844),
    [anon_sym_QMARK_DOT] = ACTIONS(154),
    [anon_sym_new] = ACTIONS(846),
    [anon_sym_using] = ACTIONS(158),
    [anon_sym_PLUS_EQ] = ACTIONS(160),
    [anon_sym_DASH_EQ] = ACTIONS(160),
    [anon_sym_STAR_EQ] = ACTIONS(160),
    [anon_sym_SLASH_EQ] = ACTIONS(160),
    [anon_sym_PERCENT_EQ] = ACTIONS(160),
    [anon_sym_CARET_EQ] = ACTIONS(160),
    [anon_sym_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_LT_LT_EQ] = ACTIONS(160),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(160),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP] = ACTIONS(120),
    [anon_sym_PIPE_PIPE] = ACTIONS(120),
    [anon_sym_GT_GT] = ACTIONS(120),
    [anon_sym_GT_GT_GT] = ACTIONS(120),
    [anon_sym_LT_LT] = ACTIONS(120),
    [anon_sym_AMP] = ACTIONS(120),
    [anon_sym_CARET] = ACTIONS(120),
    [anon_sym_PIPE] = ACTIONS(120),
    [anon_sym_PLUS] = ACTIONS(179),
    [anon_sym_DASH] = ACTIONS(179),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_PERCENT] = ACTIONS(120),
    [anon_sym_STAR_STAR] = ACTIONS(120),
    [anon_sym_LT] = ACTIONS(173),
    [anon_sym_LT_EQ] = ACTIONS(154),
    [anon_sym_EQ_EQ] = ACTIONS(120),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(154),
    [anon_sym_BANG_EQ] = ACTIONS(120),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(154),
    [anon_sym_GT_EQ] = ACTIONS(154),
    [anon_sym_GT] = ACTIONS(120),
    [anon_sym_QMARK_QMARK] = ACTIONS(120),
    [anon_sym_instanceof] = ACTIONS(120),
    [anon_sym_TILDE] = ACTIONS(175),
    [anon_sym_void] = ACTIONS(179),
    [anon_sym_delete] = ACTIONS(179),
    [anon_sym_PLUS_PLUS] = ACTIONS(686),
    [anon_sym_DASH_DASH] = ACTIONS(686),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(192),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(822),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(832),
    [anon_sym_readonly] = ACTIONS(832),
    [anon_sym_get] = ACTIONS(832),
    [anon_sym_set] = ACTIONS(832),
    [anon_sym_declare] = ACTIONS(832),
    [anon_sym_public] = ACTIONS(832),
    [anon_sym_private] = ACTIONS(832),
    [anon_sym_protected] = ACTIONS(832),
    [anon_sym_override] = ACTIONS(832),
    [anon_sym_module] = ACTIONS(832),
    [anon_sym_any] = ACTIONS(832),
    [anon_sym_number] = ACTIONS(832),
    [anon_sym_boolean] = ACTIONS(832),
    [anon_sym_string] = ACTIONS(832),
    [anon_sym_symbol] = ACTIONS(832),
    [anon_sym_object] = ACTIONS(832),
    [anon_sym_satisfies] = ACTIONS(120),
    [sym__ternary_qmark] = ACTIONS(154),
    [sym_html_comment] = ACTIONS(5),
  },
  [113] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1213),
    [sym_expression] = STATE(2644),
    [sym_primary_expression] = STATE(1501),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5522),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5522),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5800),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1213),
    [sym_subscript_expression] = STATE(1213),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3013),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5522),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1213),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(539),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(802),
    [anon_sym_export] = ACTIONS(804),
    [anon_sym_STAR] = ACTIONS(120),
    [anon_sym_type] = ACTIONS(804),
    [anon_sym_EQ] = ACTIONS(824),
    [anon_sym_as] = ACTIONS(120),
    [anon_sym_namespace] = ACTIONS(806),
    [anon_sym_LBRACE] = ACTIONS(808),
    [anon_sym_COMMA] = ACTIONS(154),
    [anon_sym_typeof] = ACTIONS(179),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(804),
    [anon_sym_BANG] = ACTIONS(179),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_RPAREN] = ACTIONS(154),
    [anon_sym_await] = ACTIONS(140),
    [anon_sym_in] = ACTIONS(120),
    [anon_sym_COLON] = ACTIONS(154),
    [anon_sym_yield] = ACTIONS(142),
    [anon_sym_LBRACK] = ACTIONS(812),
    [anon_sym_DOT] = ACTIONS(814),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(816),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_EQ_GT] = ACTIONS(152),
    [anon_sym_QMARK_DOT] = ACTIONS(154),
    [anon_sym_new] = ACTIONS(818),
    [anon_sym_using] = ACTIONS(158),
    [anon_sym_PLUS_EQ] = ACTIONS(160),
    [anon_sym_DASH_EQ] = ACTIONS(160),
    [anon_sym_STAR_EQ] = ACTIONS(160),
    [anon_sym_SLASH_EQ] = ACTIONS(160),
    [anon_sym_PERCENT_EQ] = ACTIONS(160),
    [anon_sym_CARET_EQ] = ACTIONS(160),
    [anon_sym_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_LT_LT_EQ] = ACTIONS(160),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(160),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP] = ACTIONS(120),
    [anon_sym_PIPE_PIPE] = ACTIONS(120),
    [anon_sym_GT_GT] = ACTIONS(120),
    [anon_sym_GT_GT_GT] = ACTIONS(120),
    [anon_sym_LT_LT] = ACTIONS(120),
    [anon_sym_AMP] = ACTIONS(120),
    [anon_sym_CARET] = ACTIONS(120),
    [anon_sym_PIPE] = ACTIONS(120),
    [anon_sym_PLUS] = ACTIONS(179),
    [anon_sym_DASH] = ACTIONS(179),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_PERCENT] = ACTIONS(120),
    [anon_sym_STAR_STAR] = ACTIONS(120),
    [anon_sym_LT] = ACTIONS(173),
    [anon_sym_LT_EQ] = ACTIONS(154),
    [anon_sym_EQ_EQ] = ACTIONS(120),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(154),
    [anon_sym_BANG_EQ] = ACTIONS(120),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(154),
    [anon_sym_GT_EQ] = ACTIONS(154),
    [anon_sym_GT] = ACTIONS(120),
    [anon_sym_QMARK_QMARK] = ACTIONS(120),
    [anon_sym_instanceof] = ACTIONS(120),
    [anon_sym_TILDE] = ACTIONS(175),
    [anon_sym_void] = ACTIONS(179),
    [anon_sym_delete] = ACTIONS(179),
    [anon_sym_PLUS_PLUS] = ACTIONS(686),
    [anon_sym_DASH_DASH] = ACTIONS(686),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(192),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(822),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(804),
    [anon_sym_readonly] = ACTIONS(804),
    [anon_sym_get] = ACTIONS(804),
    [anon_sym_set] = ACTIONS(804),
    [anon_sym_declare] = ACTIONS(804),
    [anon_sym_public] = ACTIONS(804),
    [anon_sym_private] = ACTIONS(804),
    [anon_sym_protected] = ACTIONS(804),
    [anon_sym_override] = ACTIONS(804),
    [anon_sym_module] = ACTIONS(804),
    [anon_sym_any] = ACTIONS(804),
    [anon_sym_number] = ACTIONS(804),
    [anon_sym_boolean] = ACTIONS(804),
    [anon_sym_string] = ACTIONS(804),
    [anon_sym_symbol] = ACTIONS(804),
    [anon_sym_object] = ACTIONS(804),
    [anon_sym_satisfies] = ACTIONS(120),
    [sym__ternary_qmark] = ACTIONS(154),
    [sym_html_comment] = ACTIONS(5),
  },
  [114] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1213),
    [sym_expression] = STATE(2644),
    [sym_primary_expression] = STATE(1501),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5522),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5522),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5508),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1213),
    [sym_subscript_expression] = STATE(1213),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3013),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5522),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1213),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(539),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(830),
    [anon_sym_export] = ACTIONS(832),
    [anon_sym_STAR] = ACTIONS(120),
    [anon_sym_type] = ACTIONS(832),
    [anon_sym_EQ] = ACTIONS(907),
    [anon_sym_as] = ACTIONS(120),
    [anon_sym_namespace] = ACTIONS(836),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_COMMA] = ACTIONS(126),
    [anon_sym_RBRACE] = ACTIONS(126),
    [anon_sym_typeof] = ACTIONS(179),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(832),
    [anon_sym_BANG] = ACTIONS(179),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(140),
    [anon_sym_in] = ACTIONS(120),
    [anon_sym_yield] = ACTIONS(142),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_RBRACK] = ACTIONS(126),
    [anon_sym_DOT] = ACTIONS(814),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(842),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_EQ_GT] = ACTIONS(844),
    [anon_sym_QMARK_DOT] = ACTIONS(154),
    [anon_sym_new] = ACTIONS(846),
    [anon_sym_using] = ACTIONS(158),
    [anon_sym_PLUS_EQ] = ACTIONS(160),
    [anon_sym_DASH_EQ] = ACTIONS(160),
    [anon_sym_STAR_EQ] = ACTIONS(160),
    [anon_sym_SLASH_EQ] = ACTIONS(160),
    [anon_sym_PERCENT_EQ] = ACTIONS(160),
    [anon_sym_CARET_EQ] = ACTIONS(160),
    [anon_sym_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_LT_LT_EQ] = ACTIONS(160),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(160),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP] = ACTIONS(120),
    [anon_sym_PIPE_PIPE] = ACTIONS(120),
    [anon_sym_GT_GT] = ACTIONS(120),
    [anon_sym_GT_GT_GT] = ACTIONS(120),
    [anon_sym_LT_LT] = ACTIONS(120),
    [anon_sym_AMP] = ACTIONS(120),
    [anon_sym_CARET] = ACTIONS(120),
    [anon_sym_PIPE] = ACTIONS(120),
    [anon_sym_PLUS] = ACTIONS(179),
    [anon_sym_DASH] = ACTIONS(179),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_PERCENT] = ACTIONS(120),
    [anon_sym_STAR_STAR] = ACTIONS(120),
    [anon_sym_LT] = ACTIONS(173),
    [anon_sym_LT_EQ] = ACTIONS(154),
    [anon_sym_EQ_EQ] = ACTIONS(120),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(154),
    [anon_sym_BANG_EQ] = ACTIONS(120),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(154),
    [anon_sym_GT_EQ] = ACTIONS(154),
    [anon_sym_GT] = ACTIONS(120),
    [anon_sym_QMARK_QMARK] = ACTIONS(120),
    [anon_sym_instanceof] = ACTIONS(120),
    [anon_sym_TILDE] = ACTIONS(175),
    [anon_sym_void] = ACTIONS(179),
    [anon_sym_delete] = ACTIONS(179),
    [anon_sym_PLUS_PLUS] = ACTIONS(686),
    [anon_sym_DASH_DASH] = ACTIONS(686),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(192),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(822),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(832),
    [anon_sym_readonly] = ACTIONS(832),
    [anon_sym_get] = ACTIONS(832),
    [anon_sym_set] = ACTIONS(832),
    [anon_sym_declare] = ACTIONS(832),
    [anon_sym_public] = ACTIONS(832),
    [anon_sym_private] = ACTIONS(832),
    [anon_sym_protected] = ACTIONS(832),
    [anon_sym_override] = ACTIONS(832),
    [anon_sym_module] = ACTIONS(832),
    [anon_sym_any] = ACTIONS(832),
    [anon_sym_number] = ACTIONS(832),
    [anon_sym_boolean] = ACTIONS(832),
    [anon_sym_string] = ACTIONS(832),
    [anon_sym_symbol] = ACTIONS(832),
    [anon_sym_object] = ACTIONS(832),
    [anon_sym_satisfies] = ACTIONS(120),
    [sym__ternary_qmark] = ACTIONS(154),
    [sym_html_comment] = ACTIONS(5),
  },
  [115] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1213),
    [sym_expression] = STATE(2644),
    [sym_primary_expression] = STATE(1501),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5522),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5522),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5477),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1213),
    [sym_subscript_expression] = STATE(1213),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3013),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5522),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1213),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(539),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(882),
    [anon_sym_export] = ACTIONS(884),
    [anon_sym_STAR] = ACTIONS(120),
    [anon_sym_type] = ACTIONS(884),
    [anon_sym_EQ] = ACTIONS(910),
    [anon_sym_as] = ACTIONS(120),
    [anon_sym_namespace] = ACTIONS(889),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_typeof] = ACTIONS(179),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(884),
    [anon_sym_BANG] = ACTIONS(179),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(140),
    [anon_sym_in] = ACTIONS(120),
    [anon_sym_COLON] = ACTIONS(912),
    [anon_sym_yield] = ACTIONS(142),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_RBRACK] = ACTIONS(154),
    [anon_sym_DOT] = ACTIONS(814),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(893),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_EQ_GT] = ACTIONS(895),
    [anon_sym_QMARK_DOT] = ACTIONS(154),
    [anon_sym_new] = ACTIONS(897),
    [anon_sym_using] = ACTIONS(158),
    [anon_sym_PLUS_EQ] = ACTIONS(160),
    [anon_sym_DASH_EQ] = ACTIONS(160),
    [anon_sym_STAR_EQ] = ACTIONS(160),
    [anon_sym_SLASH_EQ] = ACTIONS(160),
    [anon_sym_PERCENT_EQ] = ACTIONS(160),
    [anon_sym_CARET_EQ] = ACTIONS(160),
    [anon_sym_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_LT_LT_EQ] = ACTIONS(160),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(160),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP] = ACTIONS(120),
    [anon_sym_PIPE_PIPE] = ACTIONS(120),
    [anon_sym_GT_GT] = ACTIONS(120),
    [anon_sym_GT_GT_GT] = ACTIONS(120),
    [anon_sym_LT_LT] = ACTIONS(120),
    [anon_sym_AMP] = ACTIONS(120),
    [anon_sym_CARET] = ACTIONS(120),
    [anon_sym_PIPE] = ACTIONS(120),
    [anon_sym_PLUS] = ACTIONS(179),
    [anon_sym_DASH] = ACTIONS(179),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_PERCENT] = ACTIONS(120),
    [anon_sym_STAR_STAR] = ACTIONS(120),
    [anon_sym_LT] = ACTIONS(173),
    [anon_sym_LT_EQ] = ACTIONS(154),
    [anon_sym_EQ_EQ] = ACTIONS(120),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(154),
    [anon_sym_BANG_EQ] = ACTIONS(120),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(154),
    [anon_sym_GT_EQ] = ACTIONS(154),
    [anon_sym_GT] = ACTIONS(120),
    [anon_sym_QMARK_QMARK] = ACTIONS(120),
    [anon_sym_instanceof] = ACTIONS(120),
    [anon_sym_TILDE] = ACTIONS(175),
    [anon_sym_void] = ACTIONS(179),
    [anon_sym_delete] = ACTIONS(179),
    [anon_sym_PLUS_PLUS] = ACTIONS(686),
    [anon_sym_DASH_DASH] = ACTIONS(686),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(192),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(822),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(884),
    [anon_sym_readonly] = ACTIONS(884),
    [anon_sym_get] = ACTIONS(884),
    [anon_sym_set] = ACTIONS(884),
    [anon_sym_declare] = ACTIONS(884),
    [anon_sym_public] = ACTIONS(884),
    [anon_sym_private] = ACTIONS(884),
    [anon_sym_protected] = ACTIONS(884),
    [anon_sym_override] = ACTIONS(884),
    [anon_sym_module] = ACTIONS(884),
    [anon_sym_any] = ACTIONS(884),
    [anon_sym_number] = ACTIONS(884),
    [anon_sym_boolean] = ACTIONS(884),
    [anon_sym_string] = ACTIONS(884),
    [anon_sym_symbol] = ACTIONS(884),
    [anon_sym_object] = ACTIONS(884),
    [anon_sym_satisfies] = ACTIONS(120),
    [sym__ternary_qmark] = ACTIONS(154),
    [sym_html_comment] = ACTIONS(5),
  },
  [116] = {
    [sym_import] = STATE(3636),
    [sym_parenthesized_expression] = STATE(1334),
    [sym_expression] = STATE(2611),
    [sym_primary_expression] = STATE(1696),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(2222),
    [sym_object_pattern] = STATE(5522),
    [sym_array] = STATE(2222),
    [sym_array_pattern] = STATE(5522),
    [sym_class] = STATE(2222),
    [sym_function_expression] = STATE(2222),
    [sym_generator_function] = STATE(2222),
    [sym_arrow_function] = STATE(2222),
    [sym__call_signature] = STATE(5466),
    [sym_call_expression] = STATE(2222),
    [sym_new_expression] = STATE(2694),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1334),
    [sym_subscript_expression] = STATE(1334),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3013),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5522),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(2222),
    [sym_template_string] = STATE(2222),
    [sym_regex] = STATE(2222),
    [sym_meta_property] = STATE(2222),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(4116),
    [sym_non_null_expression] = STATE(1334),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(539),
    [sym_type_parameters] = STATE(5344),
    [aux_sym_export_statement_repeat1] = STATE(4408),
    [sym_identifier] = ACTIONS(914),
    [anon_sym_export] = ACTIONS(916),
    [anon_sym_STAR] = ACTIONS(120),
    [anon_sym_type] = ACTIONS(916),
    [anon_sym_EQ] = ACTIONS(918),
    [anon_sym_as] = ACTIONS(120),
    [anon_sym_namespace] = ACTIONS(920),
    [anon_sym_LBRACE] = ACTIONS(665),
    [anon_sym_typeof] = ACTIONS(179),
    [anon_sym_import] = ACTIONS(669),
    [anon_sym_let] = ACTIONS(916),
    [anon_sym_BANG] = ACTIONS(179),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_SEMI] = ACTIONS(154),
    [anon_sym_await] = ACTIONS(140),
    [anon_sym_in] = ACTIONS(120),
    [anon_sym_yield] = ACTIONS(142),
    [anon_sym_LBRACK] = ACTIONS(65),
    [anon_sym_DOT] = ACTIONS(674),
    [anon_sym_class] = ACTIONS(676),
    [anon_sym_async] = ACTIONS(922),
    [anon_sym_function] = ACTIONS(680),
    [anon_sym_EQ_GT] = ACTIONS(924),
    [anon_sym_QMARK_DOT] = ACTIONS(154),
    [anon_sym_new] = ACTIONS(926),
    [anon_sym_using] = ACTIONS(158),
    [anon_sym_PLUS_EQ] = ACTIONS(160),
    [anon_sym_DASH_EQ] = ACTIONS(160),
    [anon_sym_STAR_EQ] = ACTIONS(160),
    [anon_sym_SLASH_EQ] = ACTIONS(160),
    [anon_sym_PERCENT_EQ] = ACTIONS(160),
    [anon_sym_CARET_EQ] = ACTIONS(160),
    [anon_sym_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_LT_LT_EQ] = ACTIONS(160),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(160),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP] = ACTIONS(120),
    [anon_sym_PIPE_PIPE] = ACTIONS(120),
    [anon_sym_GT_GT] = ACTIONS(120),
    [anon_sym_GT_GT_GT] = ACTIONS(120),
    [anon_sym_LT_LT] = ACTIONS(120),
    [anon_sym_AMP] = ACTIONS(120),
    [anon_sym_CARET] = ACTIONS(120),
    [anon_sym_PIPE] = ACTIONS(120),
    [anon_sym_PLUS] = ACTIONS(179),
    [anon_sym_DASH] = ACTIONS(179),
    [anon_sym_SLASH] = ACTIONS(77),
    [anon_sym_PERCENT] = ACTIONS(120),
    [anon_sym_STAR_STAR] = ACTIONS(120),
    [anon_sym_LT] = ACTIONS(173),
    [anon_sym_LT_EQ] = ACTIONS(154),
    [anon_sym_EQ_EQ] = ACTIONS(120),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(154),
    [anon_sym_BANG_EQ] = ACTIONS(120),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(154),
    [anon_sym_GT_EQ] = ACTIONS(154),
    [anon_sym_GT] = ACTIONS(120),
    [anon_sym_QMARK_QMARK] = ACTIONS(120),
    [anon_sym_instanceof] = ACTIONS(120),
    [anon_sym_TILDE] = ACTIONS(175),
    [anon_sym_void] = ACTIONS(179),
    [anon_sym_delete] = ACTIONS(179),
    [anon_sym_PLUS_PLUS] = ACTIONS(686),
    [anon_sym_DASH_DASH] = ACTIONS(686),
    [anon_sym_DQUOTE] = ACTIONS(83),
    [anon_sym_SQUOTE] = ACTIONS(85),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(87),
    [sym_number] = ACTIONS(89),
    [sym_private_property_identifier] = ACTIONS(192),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(93),
    [sym_true] = ACTIONS(93),
    [sym_false] = ACTIONS(93),
    [sym_null] = ACTIONS(93),
    [sym_undefined] = ACTIONS(688),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(916),
    [anon_sym_readonly] = ACTIONS(916),
    [anon_sym_get] = ACTIONS(916),
    [anon_sym_set] = ACTIONS(916),
    [anon_sym_declare] = ACTIONS(916),
    [anon_sym_public] = ACTIONS(916),
    [anon_sym_private] = ACTIONS(916),
    [anon_sym_protected] = ACTIONS(916),
    [anon_sym_override] = ACTIONS(916),
    [anon_sym_module] = ACTIONS(916),
    [anon_sym_any] = ACTIONS(916),
    [anon_sym_number] = ACTIONS(916),
    [anon_sym_boolean] = ACTIONS(916),
    [anon_sym_string] = ACTIONS(916),
    [anon_sym_symbol] = ACTIONS(916),
    [anon_sym_object] = ACTIONS(916),
    [anon_sym_satisfies] = ACTIONS(120),
    [sym__automatic_semicolon] = ACTIONS(154),
    [sym__ternary_qmark] = ACTIONS(154),
    [sym_html_comment] = ACTIONS(5),
  },
  [117] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1213),
    [sym_expression] = STATE(2644),
    [sym_primary_expression] = STATE(1501),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5522),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5522),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5477),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1213),
    [sym_subscript_expression] = STATE(1213),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3013),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5522),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1213),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(539),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(882),
    [anon_sym_export] = ACTIONS(884),
    [anon_sym_STAR] = ACTIONS(120),
    [anon_sym_type] = ACTIONS(884),
    [anon_sym_EQ] = ACTIONS(910),
    [anon_sym_as] = ACTIONS(120),
    [anon_sym_namespace] = ACTIONS(889),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_typeof] = ACTIONS(179),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(884),
    [anon_sym_BANG] = ACTIONS(179),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(140),
    [anon_sym_in] = ACTIONS(120),
    [anon_sym_COLON] = ACTIONS(891),
    [anon_sym_yield] = ACTIONS(142),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_RBRACK] = ACTIONS(154),
    [anon_sym_DOT] = ACTIONS(814),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(893),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_EQ_GT] = ACTIONS(895),
    [anon_sym_QMARK_DOT] = ACTIONS(154),
    [anon_sym_new] = ACTIONS(897),
    [anon_sym_using] = ACTIONS(158),
    [anon_sym_PLUS_EQ] = ACTIONS(160),
    [anon_sym_DASH_EQ] = ACTIONS(160),
    [anon_sym_STAR_EQ] = ACTIONS(160),
    [anon_sym_SLASH_EQ] = ACTIONS(160),
    [anon_sym_PERCENT_EQ] = ACTIONS(160),
    [anon_sym_CARET_EQ] = ACTIONS(160),
    [anon_sym_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_LT_LT_EQ] = ACTIONS(160),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(160),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP] = ACTIONS(120),
    [anon_sym_PIPE_PIPE] = ACTIONS(120),
    [anon_sym_GT_GT] = ACTIONS(120),
    [anon_sym_GT_GT_GT] = ACTIONS(120),
    [anon_sym_LT_LT] = ACTIONS(120),
    [anon_sym_AMP] = ACTIONS(120),
    [anon_sym_CARET] = ACTIONS(120),
    [anon_sym_PIPE] = ACTIONS(120),
    [anon_sym_PLUS] = ACTIONS(179),
    [anon_sym_DASH] = ACTIONS(179),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_PERCENT] = ACTIONS(120),
    [anon_sym_STAR_STAR] = ACTIONS(120),
    [anon_sym_LT] = ACTIONS(173),
    [anon_sym_LT_EQ] = ACTIONS(154),
    [anon_sym_EQ_EQ] = ACTIONS(120),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(154),
    [anon_sym_BANG_EQ] = ACTIONS(120),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(154),
    [anon_sym_GT_EQ] = ACTIONS(154),
    [anon_sym_GT] = ACTIONS(120),
    [anon_sym_QMARK_QMARK] = ACTIONS(120),
    [anon_sym_instanceof] = ACTIONS(120),
    [anon_sym_TILDE] = ACTIONS(175),
    [anon_sym_void] = ACTIONS(179),
    [anon_sym_delete] = ACTIONS(179),
    [anon_sym_PLUS_PLUS] = ACTIONS(686),
    [anon_sym_DASH_DASH] = ACTIONS(686),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(192),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(822),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(884),
    [anon_sym_readonly] = ACTIONS(884),
    [anon_sym_get] = ACTIONS(884),
    [anon_sym_set] = ACTIONS(884),
    [anon_sym_declare] = ACTIONS(884),
    [anon_sym_public] = ACTIONS(884),
    [anon_sym_private] = ACTIONS(884),
    [anon_sym_protected] = ACTIONS(884),
    [anon_sym_override] = ACTIONS(884),
    [anon_sym_module] = ACTIONS(884),
    [anon_sym_any] = ACTIONS(884),
    [anon_sym_number] = ACTIONS(884),
    [anon_sym_boolean] = ACTIONS(884),
    [anon_sym_string] = ACTIONS(884),
    [anon_sym_symbol] = ACTIONS(884),
    [anon_sym_object] = ACTIONS(884),
    [anon_sym_satisfies] = ACTIONS(120),
    [sym__ternary_qmark] = ACTIONS(154),
    [sym_html_comment] = ACTIONS(5),
  },
  [118] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1213),
    [sym_expression] = STATE(2644),
    [sym_primary_expression] = STATE(1501),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5522),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5522),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5800),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1213),
    [sym_subscript_expression] = STATE(1213),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3013),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5522),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1213),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(539),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(802),
    [anon_sym_export] = ACTIONS(804),
    [anon_sym_STAR] = ACTIONS(120),
    [anon_sym_type] = ACTIONS(804),
    [anon_sym_EQ] = ACTIONS(824),
    [anon_sym_as] = ACTIONS(120),
    [anon_sym_namespace] = ACTIONS(806),
    [anon_sym_LBRACE] = ACTIONS(808),
    [anon_sym_typeof] = ACTIONS(179),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(804),
    [anon_sym_BANG] = ACTIONS(179),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_SEMI] = ACTIONS(154),
    [anon_sym_await] = ACTIONS(140),
    [anon_sym_in] = ACTIONS(120),
    [anon_sym_yield] = ACTIONS(142),
    [anon_sym_LBRACK] = ACTIONS(812),
    [anon_sym_DOT] = ACTIONS(674),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(816),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_EQ_GT] = ACTIONS(924),
    [anon_sym_QMARK_DOT] = ACTIONS(154),
    [anon_sym_new] = ACTIONS(818),
    [anon_sym_using] = ACTIONS(158),
    [anon_sym_PLUS_EQ] = ACTIONS(160),
    [anon_sym_DASH_EQ] = ACTIONS(160),
    [anon_sym_STAR_EQ] = ACTIONS(160),
    [anon_sym_SLASH_EQ] = ACTIONS(160),
    [anon_sym_PERCENT_EQ] = ACTIONS(160),
    [anon_sym_CARET_EQ] = ACTIONS(160),
    [anon_sym_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_LT_LT_EQ] = ACTIONS(160),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(160),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP] = ACTIONS(120),
    [anon_sym_PIPE_PIPE] = ACTIONS(120),
    [anon_sym_GT_GT] = ACTIONS(120),
    [anon_sym_GT_GT_GT] = ACTIONS(120),
    [anon_sym_LT_LT] = ACTIONS(120),
    [anon_sym_AMP] = ACTIONS(120),
    [anon_sym_CARET] = ACTIONS(120),
    [anon_sym_PIPE] = ACTIONS(120),
    [anon_sym_PLUS] = ACTIONS(179),
    [anon_sym_DASH] = ACTIONS(179),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_PERCENT] = ACTIONS(120),
    [anon_sym_STAR_STAR] = ACTIONS(120),
    [anon_sym_LT] = ACTIONS(173),
    [anon_sym_LT_EQ] = ACTIONS(154),
    [anon_sym_EQ_EQ] = ACTIONS(120),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(154),
    [anon_sym_BANG_EQ] = ACTIONS(120),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(154),
    [anon_sym_GT_EQ] = ACTIONS(154),
    [anon_sym_GT] = ACTIONS(120),
    [anon_sym_QMARK_QMARK] = ACTIONS(120),
    [anon_sym_instanceof] = ACTIONS(120),
    [anon_sym_TILDE] = ACTIONS(175),
    [anon_sym_void] = ACTIONS(179),
    [anon_sym_delete] = ACTIONS(179),
    [anon_sym_PLUS_PLUS] = ACTIONS(686),
    [anon_sym_DASH_DASH] = ACTIONS(686),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(192),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(822),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(804),
    [anon_sym_readonly] = ACTIONS(804),
    [anon_sym_get] = ACTIONS(804),
    [anon_sym_set] = ACTIONS(804),
    [anon_sym_declare] = ACTIONS(804),
    [anon_sym_public] = ACTIONS(804),
    [anon_sym_private] = ACTIONS(804),
    [anon_sym_protected] = ACTIONS(804),
    [anon_sym_override] = ACTIONS(804),
    [anon_sym_module] = ACTIONS(804),
    [anon_sym_any] = ACTIONS(804),
    [anon_sym_number] = ACTIONS(804),
    [anon_sym_boolean] = ACTIONS(804),
    [anon_sym_string] = ACTIONS(804),
    [anon_sym_symbol] = ACTIONS(804),
    [anon_sym_object] = ACTIONS(804),
    [anon_sym_satisfies] = ACTIONS(120),
    [sym__automatic_semicolon] = ACTIONS(154),
    [sym__ternary_qmark] = ACTIONS(154),
    [sym_html_comment] = ACTIONS(5),
  },
  [119] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1213),
    [sym_expression] = STATE(2644),
    [sym_primary_expression] = STATE(1501),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5522),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5522),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5508),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1213),
    [sym_subscript_expression] = STATE(1213),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3013),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5522),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(4321),
    [sym_non_null_expression] = STATE(1213),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(539),
    [sym_type_parameters] = STATE(5458),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(830),
    [anon_sym_export] = ACTIONS(832),
    [anon_sym_STAR] = ACTIONS(120),
    [anon_sym_type] = ACTIONS(832),
    [anon_sym_EQ] = ACTIONS(907),
    [anon_sym_as] = ACTIONS(120),
    [anon_sym_namespace] = ACTIONS(836),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_COMMA] = ACTIONS(126),
    [anon_sym_typeof] = ACTIONS(179),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(832),
    [anon_sym_BANG] = ACTIONS(179),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(140),
    [anon_sym_in] = ACTIONS(120),
    [anon_sym_yield] = ACTIONS(142),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_RBRACK] = ACTIONS(126),
    [anon_sym_DOT] = ACTIONS(814),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(842),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_EQ_GT] = ACTIONS(844),
    [anon_sym_QMARK_DOT] = ACTIONS(154),
    [anon_sym_new] = ACTIONS(846),
    [anon_sym_using] = ACTIONS(158),
    [anon_sym_PLUS_EQ] = ACTIONS(160),
    [anon_sym_DASH_EQ] = ACTIONS(160),
    [anon_sym_STAR_EQ] = ACTIONS(160),
    [anon_sym_SLASH_EQ] = ACTIONS(160),
    [anon_sym_PERCENT_EQ] = ACTIONS(160),
    [anon_sym_CARET_EQ] = ACTIONS(160),
    [anon_sym_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_LT_LT_EQ] = ACTIONS(160),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(160),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP] = ACTIONS(120),
    [anon_sym_PIPE_PIPE] = ACTIONS(120),
    [anon_sym_GT_GT] = ACTIONS(120),
    [anon_sym_GT_GT_GT] = ACTIONS(120),
    [anon_sym_LT_LT] = ACTIONS(120),
    [anon_sym_AMP] = ACTIONS(120),
    [anon_sym_CARET] = ACTIONS(120),
    [anon_sym_PIPE] = ACTIONS(120),
    [anon_sym_PLUS] = ACTIONS(179),
    [anon_sym_DASH] = ACTIONS(179),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_PERCENT] = ACTIONS(120),
    [anon_sym_STAR_STAR] = ACTIONS(120),
    [anon_sym_LT] = ACTIONS(173),
    [anon_sym_LT_EQ] = ACTIONS(154),
    [anon_sym_EQ_EQ] = ACTIONS(120),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(154),
    [anon_sym_BANG_EQ] = ACTIONS(120),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(154),
    [anon_sym_GT_EQ] = ACTIONS(154),
    [anon_sym_GT] = ACTIONS(120),
    [anon_sym_QMARK_QMARK] = ACTIONS(120),
    [anon_sym_instanceof] = ACTIONS(120),
    [anon_sym_TILDE] = ACTIONS(175),
    [anon_sym_void] = ACTIONS(179),
    [anon_sym_delete] = ACTIONS(179),
    [anon_sym_PLUS_PLUS] = ACTIONS(686),
    [anon_sym_DASH_DASH] = ACTIONS(686),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(192),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(822),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(832),
    [anon_sym_readonly] = ACTIONS(832),
    [anon_sym_get] = ACTIONS(832),
    [anon_sym_set] = ACTIONS(832),
    [anon_sym_declare] = ACTIONS(832),
    [anon_sym_public] = ACTIONS(832),
    [anon_sym_private] = ACTIONS(832),
    [anon_sym_protected] = ACTIONS(832),
    [anon_sym_override] = ACTIONS(832),
    [anon_sym_module] = ACTIONS(832),
    [anon_sym_any] = ACTIONS(832),
    [anon_sym_number] = ACTIONS(832),
    [anon_sym_boolean] = ACTIONS(832),
    [anon_sym_string] = ACTIONS(832),
    [anon_sym_symbol] = ACTIONS(832),
    [anon_sym_object] = ACTIONS(832),
    [anon_sym_satisfies] = ACTIONS(120),
    [sym__ternary_qmark] = ACTIONS(154),
    [sym_html_comment] = ACTIONS(5),
  },
  [120] = {
    [sym_import] = STATE(3636),
    [sym_parenthesized_expression] = STATE(1334),
    [sym_expression] = STATE(2611),
    [sym_primary_expression] = STATE(1696),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(2222),
    [sym_object_pattern] = STATE(5522),
    [sym_array] = STATE(2222),
    [sym_array_pattern] = STATE(5522),
    [sym_class] = STATE(2222),
    [sym_function_expression] = STATE(2222),
    [sym_generator_function] = STATE(2222),
    [sym_arrow_function] = STATE(2222),
    [sym__call_signature] = STATE(5466),
    [sym_call_expression] = STATE(2222),
    [sym_new_expression] = STATE(2694),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1334),
    [sym_subscript_expression] = STATE(1334),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3013),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5522),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(2222),
    [sym_template_string] = STATE(2222),
    [sym_regex] = STATE(2222),
    [sym_meta_property] = STATE(2222),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1334),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(539),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4408),
    [sym_identifier] = ACTIONS(914),
    [anon_sym_export] = ACTIONS(916),
    [anon_sym_STAR] = ACTIONS(120),
    [anon_sym_type] = ACTIONS(916),
    [anon_sym_EQ] = ACTIONS(918),
    [anon_sym_as] = ACTIONS(120),
    [anon_sym_namespace] = ACTIONS(920),
    [anon_sym_LBRACE] = ACTIONS(665),
    [anon_sym_typeof] = ACTIONS(179),
    [anon_sym_import] = ACTIONS(669),
    [anon_sym_let] = ACTIONS(916),
    [anon_sym_BANG] = ACTIONS(179),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_SEMI] = ACTIONS(154),
    [anon_sym_await] = ACTIONS(140),
    [anon_sym_in] = ACTIONS(120),
    [anon_sym_yield] = ACTIONS(142),
    [anon_sym_LBRACK] = ACTIONS(65),
    [anon_sym_DOT] = ACTIONS(674),
    [anon_sym_class] = ACTIONS(676),
    [anon_sym_async] = ACTIONS(922),
    [anon_sym_function] = ACTIONS(680),
    [anon_sym_EQ_GT] = ACTIONS(924),
    [anon_sym_QMARK_DOT] = ACTIONS(154),
    [anon_sym_new] = ACTIONS(926),
    [anon_sym_using] = ACTIONS(158),
    [anon_sym_PLUS_EQ] = ACTIONS(160),
    [anon_sym_DASH_EQ] = ACTIONS(160),
    [anon_sym_STAR_EQ] = ACTIONS(160),
    [anon_sym_SLASH_EQ] = ACTIONS(160),
    [anon_sym_PERCENT_EQ] = ACTIONS(160),
    [anon_sym_CARET_EQ] = ACTIONS(160),
    [anon_sym_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_LT_LT_EQ] = ACTIONS(160),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(160),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP] = ACTIONS(120),
    [anon_sym_PIPE_PIPE] = ACTIONS(120),
    [anon_sym_GT_GT] = ACTIONS(120),
    [anon_sym_GT_GT_GT] = ACTIONS(120),
    [anon_sym_LT_LT] = ACTIONS(120),
    [anon_sym_AMP] = ACTIONS(120),
    [anon_sym_CARET] = ACTIONS(120),
    [anon_sym_PIPE] = ACTIONS(120),
    [anon_sym_PLUS] = ACTIONS(179),
    [anon_sym_DASH] = ACTIONS(179),
    [anon_sym_SLASH] = ACTIONS(77),
    [anon_sym_PERCENT] = ACTIONS(120),
    [anon_sym_STAR_STAR] = ACTIONS(120),
    [anon_sym_LT] = ACTIONS(173),
    [anon_sym_LT_EQ] = ACTIONS(154),
    [anon_sym_EQ_EQ] = ACTIONS(120),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(154),
    [anon_sym_BANG_EQ] = ACTIONS(120),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(154),
    [anon_sym_GT_EQ] = ACTIONS(154),
    [anon_sym_GT] = ACTIONS(120),
    [anon_sym_QMARK_QMARK] = ACTIONS(120),
    [anon_sym_instanceof] = ACTIONS(120),
    [anon_sym_TILDE] = ACTIONS(175),
    [anon_sym_void] = ACTIONS(179),
    [anon_sym_delete] = ACTIONS(179),
    [anon_sym_PLUS_PLUS] = ACTIONS(686),
    [anon_sym_DASH_DASH] = ACTIONS(686),
    [anon_sym_DQUOTE] = ACTIONS(83),
    [anon_sym_SQUOTE] = ACTIONS(85),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(87),
    [sym_number] = ACTIONS(89),
    [sym_private_property_identifier] = ACTIONS(192),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(93),
    [sym_true] = ACTIONS(93),
    [sym_false] = ACTIONS(93),
    [sym_null] = ACTIONS(93),
    [sym_undefined] = ACTIONS(688),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(916),
    [anon_sym_readonly] = ACTIONS(916),
    [anon_sym_get] = ACTIONS(916),
    [anon_sym_set] = ACTIONS(916),
    [anon_sym_declare] = ACTIONS(916),
    [anon_sym_public] = ACTIONS(916),
    [anon_sym_private] = ACTIONS(916),
    [anon_sym_protected] = ACTIONS(916),
    [anon_sym_override] = ACTIONS(916),
    [anon_sym_module] = ACTIONS(916),
    [anon_sym_any] = ACTIONS(916),
    [anon_sym_number] = ACTIONS(916),
    [anon_sym_boolean] = ACTIONS(916),
    [anon_sym_string] = ACTIONS(916),
    [anon_sym_symbol] = ACTIONS(916),
    [anon_sym_object] = ACTIONS(916),
    [anon_sym_satisfies] = ACTIONS(120),
    [sym__automatic_semicolon] = ACTIONS(154),
    [sym__ternary_qmark] = ACTIONS(154),
    [sym_html_comment] = ACTIONS(5),
  },
  [121] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1213),
    [sym_expression] = STATE(2644),
    [sym_primary_expression] = STATE(1501),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5522),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5522),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5585),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1213),
    [sym_subscript_expression] = STATE(1213),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3013),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5522),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(4116),
    [sym_non_null_expression] = STATE(1213),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(539),
    [sym_type_parameters] = STATE(5344),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(928),
    [anon_sym_export] = ACTIONS(930),
    [anon_sym_STAR] = ACTIONS(120),
    [anon_sym_type] = ACTIONS(930),
    [anon_sym_EQ] = ACTIONS(932),
    [anon_sym_as] = ACTIONS(120),
    [anon_sym_namespace] = ACTIONS(934),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_COMMA] = ACTIONS(154),
    [anon_sym_typeof] = ACTIONS(179),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(930),
    [anon_sym_BANG] = ACTIONS(179),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(140),
    [anon_sym_in] = ACTIONS(120),
    [anon_sym_yield] = ACTIONS(142),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_DOT] = ACTIONS(814),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(936),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_EQ_GT] = ACTIONS(938),
    [anon_sym_QMARK_DOT] = ACTIONS(154),
    [anon_sym_new] = ACTIONS(940),
    [anon_sym_using] = ACTIONS(158),
    [anon_sym_PLUS_EQ] = ACTIONS(160),
    [anon_sym_DASH_EQ] = ACTIONS(160),
    [anon_sym_STAR_EQ] = ACTIONS(160),
    [anon_sym_SLASH_EQ] = ACTIONS(160),
    [anon_sym_PERCENT_EQ] = ACTIONS(160),
    [anon_sym_CARET_EQ] = ACTIONS(160),
    [anon_sym_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_LT_LT_EQ] = ACTIONS(160),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(160),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP] = ACTIONS(120),
    [anon_sym_PIPE_PIPE] = ACTIONS(120),
    [anon_sym_GT_GT] = ACTIONS(120),
    [anon_sym_GT_GT_GT] = ACTIONS(120),
    [anon_sym_LT_LT] = ACTIONS(120),
    [anon_sym_AMP] = ACTIONS(120),
    [anon_sym_CARET] = ACTIONS(120),
    [anon_sym_PIPE] = ACTIONS(120),
    [anon_sym_PLUS] = ACTIONS(179),
    [anon_sym_DASH] = ACTIONS(179),
    [anon_sym_SLASH] = ACTIONS(942),
    [anon_sym_PERCENT] = ACTIONS(120),
    [anon_sym_STAR_STAR] = ACTIONS(120),
    [anon_sym_LT] = ACTIONS(173),
    [anon_sym_LT_EQ] = ACTIONS(154),
    [anon_sym_EQ_EQ] = ACTIONS(120),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(154),
    [anon_sym_BANG_EQ] = ACTIONS(120),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(154),
    [anon_sym_GT_EQ] = ACTIONS(154),
    [anon_sym_GT] = ACTIONS(120),
    [anon_sym_QMARK_QMARK] = ACTIONS(120),
    [anon_sym_instanceof] = ACTIONS(120),
    [anon_sym_TILDE] = ACTIONS(175),
    [anon_sym_void] = ACTIONS(179),
    [anon_sym_delete] = ACTIONS(179),
    [anon_sym_PLUS_PLUS] = ACTIONS(686),
    [anon_sym_DASH_DASH] = ACTIONS(686),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(192),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(822),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(930),
    [anon_sym_readonly] = ACTIONS(930),
    [anon_sym_get] = ACTIONS(930),
    [anon_sym_set] = ACTIONS(930),
    [anon_sym_declare] = ACTIONS(930),
    [anon_sym_public] = ACTIONS(930),
    [anon_sym_private] = ACTIONS(930),
    [anon_sym_protected] = ACTIONS(930),
    [anon_sym_override] = ACTIONS(930),
    [anon_sym_module] = ACTIONS(930),
    [anon_sym_any] = ACTIONS(930),
    [anon_sym_number] = ACTIONS(930),
    [anon_sym_boolean] = ACTIONS(930),
    [anon_sym_string] = ACTIONS(930),
    [anon_sym_symbol] = ACTIONS(930),
    [anon_sym_object] = ACTIONS(930),
    [anon_sym_satisfies] = ACTIONS(120),
    [anon_sym_implements] = ACTIONS(120),
    [sym__ternary_qmark] = ACTIONS(154),
    [sym_html_comment] = ACTIONS(5),
  },
  [122] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1213),
    [sym_expression] = STATE(2644),
    [sym_primary_expression] = STATE(1501),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5522),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5522),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5508),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1213),
    [sym_subscript_expression] = STATE(1213),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3013),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5522),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3971),
    [sym_non_null_expression] = STATE(1213),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(539),
    [sym_type_parameters] = STATE(5372),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(830),
    [anon_sym_export] = ACTIONS(832),
    [anon_sym_STAR] = ACTIONS(120),
    [anon_sym_type] = ACTIONS(832),
    [anon_sym_EQ] = ACTIONS(907),
    [anon_sym_as] = ACTIONS(120),
    [anon_sym_namespace] = ACTIONS(836),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_COMMA] = ACTIONS(126),
    [anon_sym_RBRACE] = ACTIONS(126),
    [anon_sym_typeof] = ACTIONS(179),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(832),
    [anon_sym_BANG] = ACTIONS(179),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(140),
    [anon_sym_in] = ACTIONS(120),
    [anon_sym_yield] = ACTIONS(142),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_DOT] = ACTIONS(814),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(842),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_EQ_GT] = ACTIONS(844),
    [anon_sym_QMARK_DOT] = ACTIONS(154),
    [anon_sym_new] = ACTIONS(846),
    [anon_sym_using] = ACTIONS(158),
    [anon_sym_PLUS_EQ] = ACTIONS(160),
    [anon_sym_DASH_EQ] = ACTIONS(160),
    [anon_sym_STAR_EQ] = ACTIONS(160),
    [anon_sym_SLASH_EQ] = ACTIONS(160),
    [anon_sym_PERCENT_EQ] = ACTIONS(160),
    [anon_sym_CARET_EQ] = ACTIONS(160),
    [anon_sym_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_LT_LT_EQ] = ACTIONS(160),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(160),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP] = ACTIONS(120),
    [anon_sym_PIPE_PIPE] = ACTIONS(120),
    [anon_sym_GT_GT] = ACTIONS(120),
    [anon_sym_GT_GT_GT] = ACTIONS(120),
    [anon_sym_LT_LT] = ACTIONS(120),
    [anon_sym_AMP] = ACTIONS(120),
    [anon_sym_CARET] = ACTIONS(120),
    [anon_sym_PIPE] = ACTIONS(120),
    [anon_sym_PLUS] = ACTIONS(179),
    [anon_sym_DASH] = ACTIONS(179),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_PERCENT] = ACTIONS(120),
    [anon_sym_STAR_STAR] = ACTIONS(120),
    [anon_sym_LT] = ACTIONS(173),
    [anon_sym_LT_EQ] = ACTIONS(154),
    [anon_sym_EQ_EQ] = ACTIONS(120),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(154),
    [anon_sym_BANG_EQ] = ACTIONS(120),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(154),
    [anon_sym_GT_EQ] = ACTIONS(154),
    [anon_sym_GT] = ACTIONS(120),
    [anon_sym_QMARK_QMARK] = ACTIONS(120),
    [anon_sym_instanceof] = ACTIONS(120),
    [anon_sym_TILDE] = ACTIONS(175),
    [anon_sym_void] = ACTIONS(179),
    [anon_sym_delete] = ACTIONS(179),
    [anon_sym_PLUS_PLUS] = ACTIONS(686),
    [anon_sym_DASH_DASH] = ACTIONS(686),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(192),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(822),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(832),
    [anon_sym_readonly] = ACTIONS(832),
    [anon_sym_get] = ACTIONS(832),
    [anon_sym_set] = ACTIONS(832),
    [anon_sym_declare] = ACTIONS(832),
    [anon_sym_public] = ACTIONS(832),
    [anon_sym_private] = ACTIONS(832),
    [anon_sym_protected] = ACTIONS(832),
    [anon_sym_override] = ACTIONS(832),
    [anon_sym_module] = ACTIONS(832),
    [anon_sym_any] = ACTIONS(832),
    [anon_sym_number] = ACTIONS(832),
    [anon_sym_boolean] = ACTIONS(832),
    [anon_sym_string] = ACTIONS(832),
    [anon_sym_symbol] = ACTIONS(832),
    [anon_sym_object] = ACTIONS(832),
    [anon_sym_satisfies] = ACTIONS(120),
    [sym__ternary_qmark] = ACTIONS(154),
    [sym_html_comment] = ACTIONS(5),
  },
  [123] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1213),
    [sym_expression] = STATE(2644),
    [sym_primary_expression] = STATE(1501),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5522),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5522),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5477),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1213),
    [sym_subscript_expression] = STATE(1213),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3013),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5522),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1213),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(539),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(882),
    [anon_sym_export] = ACTIONS(884),
    [anon_sym_STAR] = ACTIONS(120),
    [anon_sym_type] = ACTIONS(884),
    [anon_sym_EQ] = ACTIONS(886),
    [anon_sym_as] = ACTIONS(120),
    [anon_sym_namespace] = ACTIONS(889),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_COMMA] = ACTIONS(223),
    [anon_sym_typeof] = ACTIONS(179),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(884),
    [anon_sym_BANG] = ACTIONS(179),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(140),
    [anon_sym_in] = ACTIONS(120),
    [anon_sym_yield] = ACTIONS(142),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_RBRACK] = ACTIONS(126),
    [anon_sym_DOT] = ACTIONS(814),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(893),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_EQ_GT] = ACTIONS(895),
    [anon_sym_QMARK_DOT] = ACTIONS(154),
    [anon_sym_new] = ACTIONS(897),
    [anon_sym_using] = ACTIONS(158),
    [anon_sym_PLUS_EQ] = ACTIONS(160),
    [anon_sym_DASH_EQ] = ACTIONS(160),
    [anon_sym_STAR_EQ] = ACTIONS(160),
    [anon_sym_SLASH_EQ] = ACTIONS(160),
    [anon_sym_PERCENT_EQ] = ACTIONS(160),
    [anon_sym_CARET_EQ] = ACTIONS(160),
    [anon_sym_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_LT_LT_EQ] = ACTIONS(160),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(160),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP] = ACTIONS(120),
    [anon_sym_PIPE_PIPE] = ACTIONS(120),
    [anon_sym_GT_GT] = ACTIONS(120),
    [anon_sym_GT_GT_GT] = ACTIONS(120),
    [anon_sym_LT_LT] = ACTIONS(120),
    [anon_sym_AMP] = ACTIONS(120),
    [anon_sym_CARET] = ACTIONS(120),
    [anon_sym_PIPE] = ACTIONS(120),
    [anon_sym_PLUS] = ACTIONS(179),
    [anon_sym_DASH] = ACTIONS(179),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_PERCENT] = ACTIONS(120),
    [anon_sym_STAR_STAR] = ACTIONS(120),
    [anon_sym_LT] = ACTIONS(173),
    [anon_sym_LT_EQ] = ACTIONS(154),
    [anon_sym_EQ_EQ] = ACTIONS(120),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(154),
    [anon_sym_BANG_EQ] = ACTIONS(120),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(154),
    [anon_sym_GT_EQ] = ACTIONS(154),
    [anon_sym_GT] = ACTIONS(120),
    [anon_sym_QMARK_QMARK] = ACTIONS(120),
    [anon_sym_instanceof] = ACTIONS(120),
    [anon_sym_TILDE] = ACTIONS(175),
    [anon_sym_void] = ACTIONS(179),
    [anon_sym_delete] = ACTIONS(179),
    [anon_sym_PLUS_PLUS] = ACTIONS(686),
    [anon_sym_DASH_DASH] = ACTIONS(686),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(192),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(822),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(884),
    [anon_sym_readonly] = ACTIONS(884),
    [anon_sym_get] = ACTIONS(884),
    [anon_sym_set] = ACTIONS(884),
    [anon_sym_declare] = ACTIONS(884),
    [anon_sym_public] = ACTIONS(884),
    [anon_sym_private] = ACTIONS(884),
    [anon_sym_protected] = ACTIONS(884),
    [anon_sym_override] = ACTIONS(884),
    [anon_sym_module] = ACTIONS(884),
    [anon_sym_any] = ACTIONS(884),
    [anon_sym_number] = ACTIONS(884),
    [anon_sym_boolean] = ACTIONS(884),
    [anon_sym_string] = ACTIONS(884),
    [anon_sym_symbol] = ACTIONS(884),
    [anon_sym_object] = ACTIONS(884),
    [anon_sym_satisfies] = ACTIONS(120),
    [sym__ternary_qmark] = ACTIONS(154),
    [sym_html_comment] = ACTIONS(5),
  },
  [124] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1213),
    [sym_expression] = STATE(2644),
    [sym_primary_expression] = STATE(1501),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5522),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5522),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5585),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1213),
    [sym_subscript_expression] = STATE(1213),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3013),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5522),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1213),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(539),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(928),
    [anon_sym_export] = ACTIONS(930),
    [anon_sym_STAR] = ACTIONS(120),
    [anon_sym_type] = ACTIONS(930),
    [anon_sym_EQ] = ACTIONS(932),
    [anon_sym_as] = ACTIONS(120),
    [anon_sym_namespace] = ACTIONS(934),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_COMMA] = ACTIONS(154),
    [anon_sym_typeof] = ACTIONS(179),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(930),
    [anon_sym_BANG] = ACTIONS(179),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(140),
    [anon_sym_in] = ACTIONS(120),
    [anon_sym_yield] = ACTIONS(142),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_DOT] = ACTIONS(814),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(936),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_EQ_GT] = ACTIONS(938),
    [anon_sym_QMARK_DOT] = ACTIONS(154),
    [anon_sym_new] = ACTIONS(940),
    [anon_sym_using] = ACTIONS(158),
    [anon_sym_PLUS_EQ] = ACTIONS(160),
    [anon_sym_DASH_EQ] = ACTIONS(160),
    [anon_sym_STAR_EQ] = ACTIONS(160),
    [anon_sym_SLASH_EQ] = ACTIONS(160),
    [anon_sym_PERCENT_EQ] = ACTIONS(160),
    [anon_sym_CARET_EQ] = ACTIONS(160),
    [anon_sym_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_LT_LT_EQ] = ACTIONS(160),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(160),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP] = ACTIONS(120),
    [anon_sym_PIPE_PIPE] = ACTIONS(120),
    [anon_sym_GT_GT] = ACTIONS(120),
    [anon_sym_GT_GT_GT] = ACTIONS(120),
    [anon_sym_LT_LT] = ACTIONS(120),
    [anon_sym_AMP] = ACTIONS(120),
    [anon_sym_CARET] = ACTIONS(120),
    [anon_sym_PIPE] = ACTIONS(120),
    [anon_sym_PLUS] = ACTIONS(179),
    [anon_sym_DASH] = ACTIONS(179),
    [anon_sym_SLASH] = ACTIONS(942),
    [anon_sym_PERCENT] = ACTIONS(120),
    [anon_sym_STAR_STAR] = ACTIONS(120),
    [anon_sym_LT] = ACTIONS(173),
    [anon_sym_LT_EQ] = ACTIONS(154),
    [anon_sym_EQ_EQ] = ACTIONS(120),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(154),
    [anon_sym_BANG_EQ] = ACTIONS(120),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(154),
    [anon_sym_GT_EQ] = ACTIONS(154),
    [anon_sym_GT] = ACTIONS(120),
    [anon_sym_QMARK_QMARK] = ACTIONS(120),
    [anon_sym_instanceof] = ACTIONS(120),
    [anon_sym_TILDE] = ACTIONS(175),
    [anon_sym_void] = ACTIONS(179),
    [anon_sym_delete] = ACTIONS(179),
    [anon_sym_PLUS_PLUS] = ACTIONS(686),
    [anon_sym_DASH_DASH] = ACTIONS(686),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(192),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(822),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(930),
    [anon_sym_readonly] = ACTIONS(930),
    [anon_sym_get] = ACTIONS(930),
    [anon_sym_set] = ACTIONS(930),
    [anon_sym_declare] = ACTIONS(930),
    [anon_sym_public] = ACTIONS(930),
    [anon_sym_private] = ACTIONS(930),
    [anon_sym_protected] = ACTIONS(930),
    [anon_sym_override] = ACTIONS(930),
    [anon_sym_module] = ACTIONS(930),
    [anon_sym_any] = ACTIONS(930),
    [anon_sym_number] = ACTIONS(930),
    [anon_sym_boolean] = ACTIONS(930),
    [anon_sym_string] = ACTIONS(930),
    [anon_sym_symbol] = ACTIONS(930),
    [anon_sym_object] = ACTIONS(930),
    [anon_sym_satisfies] = ACTIONS(120),
    [anon_sym_implements] = ACTIONS(120),
    [sym__ternary_qmark] = ACTIONS(154),
    [sym_html_comment] = ACTIONS(5),
  },
  [125] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1213),
    [sym_expression] = STATE(2644),
    [sym_primary_expression] = STATE(1501),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5522),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5522),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5800),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1213),
    [sym_subscript_expression] = STATE(1213),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3013),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5522),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1213),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(539),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(802),
    [anon_sym_export] = ACTIONS(804),
    [anon_sym_STAR] = ACTIONS(120),
    [anon_sym_type] = ACTIONS(804),
    [anon_sym_EQ] = ACTIONS(824),
    [anon_sym_as] = ACTIONS(120),
    [anon_sym_namespace] = ACTIONS(806),
    [anon_sym_LBRACE] = ACTIONS(808),
    [anon_sym_COMMA] = ACTIONS(154),
    [anon_sym_typeof] = ACTIONS(179),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(804),
    [anon_sym_BANG] = ACTIONS(179),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(140),
    [anon_sym_in] = ACTIONS(120),
    [anon_sym_yield] = ACTIONS(142),
    [anon_sym_LBRACK] = ACTIONS(812),
    [anon_sym_DOT] = ACTIONS(814),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(816),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_EQ_GT] = ACTIONS(938),
    [anon_sym_QMARK_DOT] = ACTIONS(154),
    [anon_sym_new] = ACTIONS(818),
    [anon_sym_using] = ACTIONS(158),
    [anon_sym_PLUS_EQ] = ACTIONS(160),
    [anon_sym_DASH_EQ] = ACTIONS(160),
    [anon_sym_STAR_EQ] = ACTIONS(160),
    [anon_sym_SLASH_EQ] = ACTIONS(160),
    [anon_sym_PERCENT_EQ] = ACTIONS(160),
    [anon_sym_CARET_EQ] = ACTIONS(160),
    [anon_sym_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_LT_LT_EQ] = ACTIONS(160),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(160),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP] = ACTIONS(120),
    [anon_sym_PIPE_PIPE] = ACTIONS(120),
    [anon_sym_GT_GT] = ACTIONS(120),
    [anon_sym_GT_GT_GT] = ACTIONS(120),
    [anon_sym_LT_LT] = ACTIONS(120),
    [anon_sym_AMP] = ACTIONS(120),
    [anon_sym_CARET] = ACTIONS(120),
    [anon_sym_PIPE] = ACTIONS(120),
    [anon_sym_PLUS] = ACTIONS(179),
    [anon_sym_DASH] = ACTIONS(179),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_PERCENT] = ACTIONS(120),
    [anon_sym_STAR_STAR] = ACTIONS(120),
    [anon_sym_LT] = ACTIONS(173),
    [anon_sym_LT_EQ] = ACTIONS(154),
    [anon_sym_EQ_EQ] = ACTIONS(120),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(154),
    [anon_sym_BANG_EQ] = ACTIONS(120),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(154),
    [anon_sym_GT_EQ] = ACTIONS(154),
    [anon_sym_GT] = ACTIONS(120),
    [anon_sym_QMARK_QMARK] = ACTIONS(120),
    [anon_sym_instanceof] = ACTIONS(120),
    [anon_sym_TILDE] = ACTIONS(175),
    [anon_sym_void] = ACTIONS(179),
    [anon_sym_delete] = ACTIONS(179),
    [anon_sym_PLUS_PLUS] = ACTIONS(686),
    [anon_sym_DASH_DASH] = ACTIONS(686),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(192),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(822),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(804),
    [anon_sym_readonly] = ACTIONS(804),
    [anon_sym_get] = ACTIONS(804),
    [anon_sym_set] = ACTIONS(804),
    [anon_sym_declare] = ACTIONS(804),
    [anon_sym_public] = ACTIONS(804),
    [anon_sym_private] = ACTIONS(804),
    [anon_sym_protected] = ACTIONS(804),
    [anon_sym_override] = ACTIONS(804),
    [anon_sym_module] = ACTIONS(804),
    [anon_sym_any] = ACTIONS(804),
    [anon_sym_number] = ACTIONS(804),
    [anon_sym_boolean] = ACTIONS(804),
    [anon_sym_string] = ACTIONS(804),
    [anon_sym_symbol] = ACTIONS(804),
    [anon_sym_object] = ACTIONS(804),
    [anon_sym_satisfies] = ACTIONS(120),
    [anon_sym_implements] = ACTIONS(120),
    [sym__ternary_qmark] = ACTIONS(154),
    [sym_html_comment] = ACTIONS(5),
  },
  [126] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1213),
    [sym_expression] = STATE(2644),
    [sym_primary_expression] = STATE(1501),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5522),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5522),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5529),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1213),
    [sym_subscript_expression] = STATE(1213),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3013),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5522),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(4116),
    [sym_non_null_expression] = STATE(1213),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(539),
    [sym_type_parameters] = STATE(5344),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(944),
    [anon_sym_export] = ACTIONS(946),
    [anon_sym_STAR] = ACTIONS(120),
    [anon_sym_type] = ACTIONS(946),
    [anon_sym_EQ] = ACTIONS(948),
    [anon_sym_as] = ACTIONS(120),
    [anon_sym_namespace] = ACTIONS(950),
    [anon_sym_LBRACE] = ACTIONS(808),
    [anon_sym_typeof] = ACTIONS(179),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(946),
    [anon_sym_BANG] = ACTIONS(179),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(140),
    [anon_sym_in] = ACTIONS(120),
    [anon_sym_of] = ACTIONS(120),
    [anon_sym_yield] = ACTIONS(142),
    [anon_sym_LBRACK] = ACTIONS(812),
    [anon_sym_DOT] = ACTIONS(814),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(952),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_EQ_GT] = ACTIONS(954),
    [anon_sym_QMARK_DOT] = ACTIONS(154),
    [anon_sym_new] = ACTIONS(956),
    [anon_sym_using] = ACTIONS(158),
    [anon_sym_PLUS_EQ] = ACTIONS(160),
    [anon_sym_DASH_EQ] = ACTIONS(160),
    [anon_sym_STAR_EQ] = ACTIONS(160),
    [anon_sym_SLASH_EQ] = ACTIONS(160),
    [anon_sym_PERCENT_EQ] = ACTIONS(160),
    [anon_sym_CARET_EQ] = ACTIONS(160),
    [anon_sym_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_LT_LT_EQ] = ACTIONS(160),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(160),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP] = ACTIONS(120),
    [anon_sym_PIPE_PIPE] = ACTIONS(120),
    [anon_sym_GT_GT] = ACTIONS(120),
    [anon_sym_GT_GT_GT] = ACTIONS(120),
    [anon_sym_LT_LT] = ACTIONS(120),
    [anon_sym_AMP] = ACTIONS(120),
    [anon_sym_CARET] = ACTIONS(120),
    [anon_sym_PIPE] = ACTIONS(120),
    [anon_sym_PLUS] = ACTIONS(179),
    [anon_sym_DASH] = ACTIONS(179),
    [anon_sym_SLASH] = ACTIONS(958),
    [anon_sym_PERCENT] = ACTIONS(120),
    [anon_sym_STAR_STAR] = ACTIONS(120),
    [anon_sym_LT] = ACTIONS(173),
    [anon_sym_LT_EQ] = ACTIONS(154),
    [anon_sym_EQ_EQ] = ACTIONS(120),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(154),
    [anon_sym_BANG_EQ] = ACTIONS(120),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(154),
    [anon_sym_GT_EQ] = ACTIONS(154),
    [anon_sym_GT] = ACTIONS(120),
    [anon_sym_QMARK_QMARK] = ACTIONS(120),
    [anon_sym_instanceof] = ACTIONS(120),
    [anon_sym_TILDE] = ACTIONS(175),
    [anon_sym_void] = ACTIONS(179),
    [anon_sym_delete] = ACTIONS(179),
    [anon_sym_PLUS_PLUS] = ACTIONS(686),
    [anon_sym_DASH_DASH] = ACTIONS(686),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(192),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(822),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(946),
    [anon_sym_readonly] = ACTIONS(946),
    [anon_sym_get] = ACTIONS(946),
    [anon_sym_set] = ACTIONS(946),
    [anon_sym_declare] = ACTIONS(946),
    [anon_sym_public] = ACTIONS(946),
    [anon_sym_private] = ACTIONS(946),
    [anon_sym_protected] = ACTIONS(946),
    [anon_sym_override] = ACTIONS(946),
    [anon_sym_module] = ACTIONS(946),
    [anon_sym_any] = ACTIONS(946),
    [anon_sym_number] = ACTIONS(946),
    [anon_sym_boolean] = ACTIONS(946),
    [anon_sym_string] = ACTIONS(946),
    [anon_sym_symbol] = ACTIONS(946),
    [anon_sym_object] = ACTIONS(946),
    [anon_sym_satisfies] = ACTIONS(120),
    [sym__ternary_qmark] = ACTIONS(154),
    [sym_html_comment] = ACTIONS(5),
  },
  [127] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1213),
    [sym_expression] = STATE(2644),
    [sym_primary_expression] = STATE(1501),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5522),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5522),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5800),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1213),
    [sym_subscript_expression] = STATE(1213),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3013),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5522),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1213),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(539),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(802),
    [anon_sym_export] = ACTIONS(804),
    [anon_sym_STAR] = ACTIONS(120),
    [anon_sym_type] = ACTIONS(804),
    [anon_sym_EQ] = ACTIONS(824),
    [anon_sym_as] = ACTIONS(120),
    [anon_sym_namespace] = ACTIONS(806),
    [anon_sym_LBRACE] = ACTIONS(808),
    [anon_sym_typeof] = ACTIONS(179),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(804),
    [anon_sym_BANG] = ACTIONS(179),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(140),
    [anon_sym_in] = ACTIONS(902),
    [anon_sym_of] = ACTIONS(905),
    [anon_sym_yield] = ACTIONS(142),
    [anon_sym_LBRACK] = ACTIONS(812),
    [anon_sym_DOT] = ACTIONS(814),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(816),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_EQ_GT] = ACTIONS(225),
    [anon_sym_QMARK_DOT] = ACTIONS(154),
    [anon_sym_new] = ACTIONS(818),
    [anon_sym_using] = ACTIONS(158),
    [anon_sym_PLUS_EQ] = ACTIONS(160),
    [anon_sym_DASH_EQ] = ACTIONS(160),
    [anon_sym_STAR_EQ] = ACTIONS(160),
    [anon_sym_SLASH_EQ] = ACTIONS(160),
    [anon_sym_PERCENT_EQ] = ACTIONS(160),
    [anon_sym_CARET_EQ] = ACTIONS(160),
    [anon_sym_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_LT_LT_EQ] = ACTIONS(160),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(160),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP] = ACTIONS(120),
    [anon_sym_PIPE_PIPE] = ACTIONS(120),
    [anon_sym_GT_GT] = ACTIONS(120),
    [anon_sym_GT_GT_GT] = ACTIONS(120),
    [anon_sym_LT_LT] = ACTIONS(120),
    [anon_sym_AMP] = ACTIONS(120),
    [anon_sym_CARET] = ACTIONS(120),
    [anon_sym_PIPE] = ACTIONS(120),
    [anon_sym_PLUS] = ACTIONS(179),
    [anon_sym_DASH] = ACTIONS(179),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_PERCENT] = ACTIONS(120),
    [anon_sym_STAR_STAR] = ACTIONS(120),
    [anon_sym_LT] = ACTIONS(173),
    [anon_sym_LT_EQ] = ACTIONS(154),
    [anon_sym_EQ_EQ] = ACTIONS(120),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(154),
    [anon_sym_BANG_EQ] = ACTIONS(120),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(154),
    [anon_sym_GT_EQ] = ACTIONS(154),
    [anon_sym_GT] = ACTIONS(120),
    [anon_sym_QMARK_QMARK] = ACTIONS(120),
    [anon_sym_instanceof] = ACTIONS(120),
    [anon_sym_TILDE] = ACTIONS(175),
    [anon_sym_void] = ACTIONS(179),
    [anon_sym_delete] = ACTIONS(179),
    [anon_sym_PLUS_PLUS] = ACTIONS(686),
    [anon_sym_DASH_DASH] = ACTIONS(686),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(192),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(822),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(804),
    [anon_sym_readonly] = ACTIONS(804),
    [anon_sym_get] = ACTIONS(804),
    [anon_sym_set] = ACTIONS(804),
    [anon_sym_declare] = ACTIONS(804),
    [anon_sym_public] = ACTIONS(804),
    [anon_sym_private] = ACTIONS(804),
    [anon_sym_protected] = ACTIONS(804),
    [anon_sym_override] = ACTIONS(804),
    [anon_sym_module] = ACTIONS(804),
    [anon_sym_any] = ACTIONS(804),
    [anon_sym_number] = ACTIONS(804),
    [anon_sym_boolean] = ACTIONS(804),
    [anon_sym_string] = ACTIONS(804),
    [anon_sym_symbol] = ACTIONS(804),
    [anon_sym_object] = ACTIONS(804),
    [anon_sym_satisfies] = ACTIONS(120),
    [sym__ternary_qmark] = ACTIONS(154),
    [sym_html_comment] = ACTIONS(5),
  },
  [128] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1213),
    [sym_expression] = STATE(2644),
    [sym_primary_expression] = STATE(1501),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5522),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5522),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5477),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1213),
    [sym_subscript_expression] = STATE(1213),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3013),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5522),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(4116),
    [sym_non_null_expression] = STATE(1213),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(539),
    [sym_type_parameters] = STATE(5344),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(882),
    [anon_sym_export] = ACTIONS(884),
    [anon_sym_STAR] = ACTIONS(120),
    [anon_sym_type] = ACTIONS(884),
    [anon_sym_EQ] = ACTIONS(910),
    [anon_sym_as] = ACTIONS(120),
    [anon_sym_namespace] = ACTIONS(889),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_typeof] = ACTIONS(179),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(884),
    [anon_sym_BANG] = ACTIONS(179),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(140),
    [anon_sym_in] = ACTIONS(120),
    [anon_sym_yield] = ACTIONS(142),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_RBRACK] = ACTIONS(154),
    [anon_sym_DOT] = ACTIONS(814),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(893),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_EQ_GT] = ACTIONS(895),
    [anon_sym_QMARK_DOT] = ACTIONS(154),
    [anon_sym_new] = ACTIONS(897),
    [anon_sym_using] = ACTIONS(158),
    [anon_sym_PLUS_EQ] = ACTIONS(160),
    [anon_sym_DASH_EQ] = ACTIONS(160),
    [anon_sym_STAR_EQ] = ACTIONS(160),
    [anon_sym_SLASH_EQ] = ACTIONS(160),
    [anon_sym_PERCENT_EQ] = ACTIONS(160),
    [anon_sym_CARET_EQ] = ACTIONS(160),
    [anon_sym_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_LT_LT_EQ] = ACTIONS(160),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(160),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP] = ACTIONS(120),
    [anon_sym_PIPE_PIPE] = ACTIONS(120),
    [anon_sym_GT_GT] = ACTIONS(120),
    [anon_sym_GT_GT_GT] = ACTIONS(120),
    [anon_sym_LT_LT] = ACTIONS(120),
    [anon_sym_AMP] = ACTIONS(120),
    [anon_sym_CARET] = ACTIONS(120),
    [anon_sym_PIPE] = ACTIONS(120),
    [anon_sym_PLUS] = ACTIONS(179),
    [anon_sym_DASH] = ACTIONS(179),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_PERCENT] = ACTIONS(120),
    [anon_sym_STAR_STAR] = ACTIONS(120),
    [anon_sym_LT] = ACTIONS(173),
    [anon_sym_LT_EQ] = ACTIONS(154),
    [anon_sym_EQ_EQ] = ACTIONS(120),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(154),
    [anon_sym_BANG_EQ] = ACTIONS(120),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(154),
    [anon_sym_GT_EQ] = ACTIONS(154),
    [anon_sym_GT] = ACTIONS(120),
    [anon_sym_QMARK_QMARK] = ACTIONS(120),
    [anon_sym_instanceof] = ACTIONS(120),
    [anon_sym_TILDE] = ACTIONS(175),
    [anon_sym_void] = ACTIONS(179),
    [anon_sym_delete] = ACTIONS(179),
    [anon_sym_PLUS_PLUS] = ACTIONS(686),
    [anon_sym_DASH_DASH] = ACTIONS(686),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(192),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(822),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(884),
    [anon_sym_readonly] = ACTIONS(884),
    [anon_sym_get] = ACTIONS(884),
    [anon_sym_set] = ACTIONS(884),
    [anon_sym_declare] = ACTIONS(884),
    [anon_sym_public] = ACTIONS(884),
    [anon_sym_private] = ACTIONS(884),
    [anon_sym_protected] = ACTIONS(884),
    [anon_sym_override] = ACTIONS(884),
    [anon_sym_module] = ACTIONS(884),
    [anon_sym_any] = ACTIONS(884),
    [anon_sym_number] = ACTIONS(884),
    [anon_sym_boolean] = ACTIONS(884),
    [anon_sym_string] = ACTIONS(884),
    [anon_sym_symbol] = ACTIONS(884),
    [anon_sym_object] = ACTIONS(884),
    [anon_sym_satisfies] = ACTIONS(120),
    [sym__ternary_qmark] = ACTIONS(154),
    [sym_html_comment] = ACTIONS(5),
  },
  [129] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1213),
    [sym_expression] = STATE(2644),
    [sym_primary_expression] = STATE(1501),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5522),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5522),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5800),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1213),
    [sym_subscript_expression] = STATE(1213),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3013),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5522),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(4116),
    [sym_non_null_expression] = STATE(1213),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(539),
    [sym_type_parameters] = STATE(5344),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(802),
    [anon_sym_export] = ACTIONS(804),
    [anon_sym_STAR] = ACTIONS(120),
    [anon_sym_type] = ACTIONS(804),
    [anon_sym_EQ] = ACTIONS(824),
    [anon_sym_as] = ACTIONS(120),
    [anon_sym_namespace] = ACTIONS(806),
    [anon_sym_LBRACE] = ACTIONS(808),
    [anon_sym_typeof] = ACTIONS(179),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(804),
    [anon_sym_BANG] = ACTIONS(179),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(140),
    [anon_sym_in] = ACTIONS(120),
    [anon_sym_COLON] = ACTIONS(826),
    [anon_sym_yield] = ACTIONS(142),
    [anon_sym_LBRACK] = ACTIONS(812),
    [anon_sym_DOT] = ACTIONS(814),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(816),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_EQ_GT] = ACTIONS(225),
    [anon_sym_QMARK_DOT] = ACTIONS(154),
    [anon_sym_new] = ACTIONS(818),
    [anon_sym_using] = ACTIONS(158),
    [anon_sym_PLUS_EQ] = ACTIONS(160),
    [anon_sym_DASH_EQ] = ACTIONS(160),
    [anon_sym_STAR_EQ] = ACTIONS(160),
    [anon_sym_SLASH_EQ] = ACTIONS(160),
    [anon_sym_PERCENT_EQ] = ACTIONS(160),
    [anon_sym_CARET_EQ] = ACTIONS(160),
    [anon_sym_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_LT_LT_EQ] = ACTIONS(160),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(160),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP] = ACTIONS(120),
    [anon_sym_PIPE_PIPE] = ACTIONS(120),
    [anon_sym_GT_GT] = ACTIONS(120),
    [anon_sym_GT_GT_GT] = ACTIONS(120),
    [anon_sym_LT_LT] = ACTIONS(120),
    [anon_sym_AMP] = ACTIONS(120),
    [anon_sym_CARET] = ACTIONS(120),
    [anon_sym_PIPE] = ACTIONS(120),
    [anon_sym_PLUS] = ACTIONS(179),
    [anon_sym_DASH] = ACTIONS(179),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_PERCENT] = ACTIONS(120),
    [anon_sym_STAR_STAR] = ACTIONS(120),
    [anon_sym_LT] = ACTIONS(173),
    [anon_sym_LT_EQ] = ACTIONS(154),
    [anon_sym_EQ_EQ] = ACTIONS(120),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(154),
    [anon_sym_BANG_EQ] = ACTIONS(120),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(154),
    [anon_sym_GT_EQ] = ACTIONS(154),
    [anon_sym_GT] = ACTIONS(120),
    [anon_sym_QMARK_QMARK] = ACTIONS(120),
    [anon_sym_instanceof] = ACTIONS(120),
    [anon_sym_TILDE] = ACTIONS(175),
    [anon_sym_void] = ACTIONS(179),
    [anon_sym_delete] = ACTIONS(179),
    [anon_sym_PLUS_PLUS] = ACTIONS(686),
    [anon_sym_DASH_DASH] = ACTIONS(686),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(192),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(822),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(804),
    [anon_sym_readonly] = ACTIONS(804),
    [anon_sym_get] = ACTIONS(804),
    [anon_sym_set] = ACTIONS(804),
    [anon_sym_declare] = ACTIONS(804),
    [anon_sym_public] = ACTIONS(804),
    [anon_sym_private] = ACTIONS(804),
    [anon_sym_protected] = ACTIONS(804),
    [anon_sym_override] = ACTIONS(804),
    [anon_sym_module] = ACTIONS(804),
    [anon_sym_any] = ACTIONS(804),
    [anon_sym_number] = ACTIONS(804),
    [anon_sym_boolean] = ACTIONS(804),
    [anon_sym_string] = ACTIONS(804),
    [anon_sym_symbol] = ACTIONS(804),
    [anon_sym_object] = ACTIONS(804),
    [anon_sym_satisfies] = ACTIONS(120),
    [sym__ternary_qmark] = ACTIONS(154),
    [sym_html_comment] = ACTIONS(5),
  },
  [130] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1213),
    [sym_expression] = STATE(2644),
    [sym_primary_expression] = STATE(1501),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5522),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5522),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5755),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1213),
    [sym_subscript_expression] = STATE(1213),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3013),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5522),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1213),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(539),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(960),
    [anon_sym_export] = ACTIONS(962),
    [anon_sym_STAR] = ACTIONS(120),
    [anon_sym_type] = ACTIONS(962),
    [anon_sym_EQ] = ACTIONS(964),
    [anon_sym_as] = ACTIONS(120),
    [anon_sym_namespace] = ACTIONS(966),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_typeof] = ACTIONS(179),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(962),
    [anon_sym_BANG] = ACTIONS(179),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(140),
    [anon_sym_in] = ACTIONS(120),
    [anon_sym_COLON] = ACTIONS(154),
    [anon_sym_yield] = ACTIONS(142),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_DOT] = ACTIONS(814),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(968),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_EQ_GT] = ACTIONS(970),
    [anon_sym_QMARK_DOT] = ACTIONS(154),
    [anon_sym_new] = ACTIONS(972),
    [anon_sym_using] = ACTIONS(158),
    [anon_sym_PLUS_EQ] = ACTIONS(160),
    [anon_sym_DASH_EQ] = ACTIONS(160),
    [anon_sym_STAR_EQ] = ACTIONS(160),
    [anon_sym_SLASH_EQ] = ACTIONS(160),
    [anon_sym_PERCENT_EQ] = ACTIONS(160),
    [anon_sym_CARET_EQ] = ACTIONS(160),
    [anon_sym_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_LT_LT_EQ] = ACTIONS(160),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(160),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP] = ACTIONS(120),
    [anon_sym_PIPE_PIPE] = ACTIONS(120),
    [anon_sym_GT_GT] = ACTIONS(120),
    [anon_sym_GT_GT_GT] = ACTIONS(120),
    [anon_sym_LT_LT] = ACTIONS(120),
    [anon_sym_AMP] = ACTIONS(120),
    [anon_sym_CARET] = ACTIONS(120),
    [anon_sym_PIPE] = ACTIONS(120),
    [anon_sym_PLUS] = ACTIONS(179),
    [anon_sym_DASH] = ACTIONS(179),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_PERCENT] = ACTIONS(120),
    [anon_sym_STAR_STAR] = ACTIONS(120),
    [anon_sym_LT] = ACTIONS(173),
    [anon_sym_LT_EQ] = ACTIONS(154),
    [anon_sym_EQ_EQ] = ACTIONS(120),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(154),
    [anon_sym_BANG_EQ] = ACTIONS(120),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(154),
    [anon_sym_GT_EQ] = ACTIONS(154),
    [anon_sym_GT] = ACTIONS(120),
    [anon_sym_QMARK_QMARK] = ACTIONS(120),
    [anon_sym_instanceof] = ACTIONS(120),
    [anon_sym_TILDE] = ACTIONS(175),
    [anon_sym_void] = ACTIONS(179),
    [anon_sym_delete] = ACTIONS(179),
    [anon_sym_PLUS_PLUS] = ACTIONS(686),
    [anon_sym_DASH_DASH] = ACTIONS(686),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(192),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(822),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(962),
    [anon_sym_readonly] = ACTIONS(962),
    [anon_sym_get] = ACTIONS(962),
    [anon_sym_set] = ACTIONS(962),
    [anon_sym_declare] = ACTIONS(962),
    [anon_sym_public] = ACTIONS(962),
    [anon_sym_private] = ACTIONS(962),
    [anon_sym_protected] = ACTIONS(962),
    [anon_sym_override] = ACTIONS(962),
    [anon_sym_module] = ACTIONS(962),
    [anon_sym_any] = ACTIONS(962),
    [anon_sym_number] = ACTIONS(962),
    [anon_sym_boolean] = ACTIONS(962),
    [anon_sym_string] = ACTIONS(962),
    [anon_sym_symbol] = ACTIONS(962),
    [anon_sym_object] = ACTIONS(962),
    [anon_sym_satisfies] = ACTIONS(120),
    [sym__ternary_qmark] = ACTIONS(154),
    [sym_html_comment] = ACTIONS(5),
  },
  [131] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1213),
    [sym_expression] = STATE(2644),
    [sym_primary_expression] = STATE(1501),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5522),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5522),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5477),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1213),
    [sym_subscript_expression] = STATE(1213),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3013),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5522),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1213),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(539),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(882),
    [anon_sym_export] = ACTIONS(884),
    [anon_sym_STAR] = ACTIONS(120),
    [anon_sym_type] = ACTIONS(884),
    [anon_sym_EQ] = ACTIONS(910),
    [anon_sym_as] = ACTIONS(120),
    [anon_sym_namespace] = ACTIONS(889),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_typeof] = ACTIONS(179),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(884),
    [anon_sym_BANG] = ACTIONS(179),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(140),
    [anon_sym_in] = ACTIONS(120),
    [anon_sym_yield] = ACTIONS(142),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_RBRACK] = ACTIONS(154),
    [anon_sym_DOT] = ACTIONS(814),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(893),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_EQ_GT] = ACTIONS(895),
    [anon_sym_QMARK_DOT] = ACTIONS(154),
    [anon_sym_new] = ACTIONS(897),
    [anon_sym_using] = ACTIONS(158),
    [anon_sym_PLUS_EQ] = ACTIONS(160),
    [anon_sym_DASH_EQ] = ACTIONS(160),
    [anon_sym_STAR_EQ] = ACTIONS(160),
    [anon_sym_SLASH_EQ] = ACTIONS(160),
    [anon_sym_PERCENT_EQ] = ACTIONS(160),
    [anon_sym_CARET_EQ] = ACTIONS(160),
    [anon_sym_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_LT_LT_EQ] = ACTIONS(160),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(160),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP] = ACTIONS(120),
    [anon_sym_PIPE_PIPE] = ACTIONS(120),
    [anon_sym_GT_GT] = ACTIONS(120),
    [anon_sym_GT_GT_GT] = ACTIONS(120),
    [anon_sym_LT_LT] = ACTIONS(120),
    [anon_sym_AMP] = ACTIONS(120),
    [anon_sym_CARET] = ACTIONS(120),
    [anon_sym_PIPE] = ACTIONS(120),
    [anon_sym_PLUS] = ACTIONS(179),
    [anon_sym_DASH] = ACTIONS(179),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_PERCENT] = ACTIONS(120),
    [anon_sym_STAR_STAR] = ACTIONS(120),
    [anon_sym_LT] = ACTIONS(173),
    [anon_sym_LT_EQ] = ACTIONS(154),
    [anon_sym_EQ_EQ] = ACTIONS(120),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(154),
    [anon_sym_BANG_EQ] = ACTIONS(120),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(154),
    [anon_sym_GT_EQ] = ACTIONS(154),
    [anon_sym_GT] = ACTIONS(120),
    [anon_sym_QMARK_QMARK] = ACTIONS(120),
    [anon_sym_instanceof] = ACTIONS(120),
    [anon_sym_TILDE] = ACTIONS(175),
    [anon_sym_void] = ACTIONS(179),
    [anon_sym_delete] = ACTIONS(179),
    [anon_sym_PLUS_PLUS] = ACTIONS(686),
    [anon_sym_DASH_DASH] = ACTIONS(686),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(192),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(822),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(884),
    [anon_sym_readonly] = ACTIONS(884),
    [anon_sym_get] = ACTIONS(884),
    [anon_sym_set] = ACTIONS(884),
    [anon_sym_declare] = ACTIONS(884),
    [anon_sym_public] = ACTIONS(884),
    [anon_sym_private] = ACTIONS(884),
    [anon_sym_protected] = ACTIONS(884),
    [anon_sym_override] = ACTIONS(884),
    [anon_sym_module] = ACTIONS(884),
    [anon_sym_any] = ACTIONS(884),
    [anon_sym_number] = ACTIONS(884),
    [anon_sym_boolean] = ACTIONS(884),
    [anon_sym_string] = ACTIONS(884),
    [anon_sym_symbol] = ACTIONS(884),
    [anon_sym_object] = ACTIONS(884),
    [anon_sym_satisfies] = ACTIONS(120),
    [sym__ternary_qmark] = ACTIONS(154),
    [sym_html_comment] = ACTIONS(5),
  },
  [132] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1213),
    [sym_expression] = STATE(2644),
    [sym_primary_expression] = STATE(1501),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5522),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5522),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5755),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1213),
    [sym_subscript_expression] = STATE(1213),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3013),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5522),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(4116),
    [sym_non_null_expression] = STATE(1213),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(539),
    [sym_type_parameters] = STATE(5344),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(960),
    [anon_sym_export] = ACTIONS(962),
    [anon_sym_STAR] = ACTIONS(120),
    [anon_sym_type] = ACTIONS(962),
    [anon_sym_EQ] = ACTIONS(964),
    [anon_sym_as] = ACTIONS(120),
    [anon_sym_namespace] = ACTIONS(966),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_typeof] = ACTIONS(179),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(962),
    [anon_sym_BANG] = ACTIONS(179),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(140),
    [anon_sym_in] = ACTIONS(120),
    [anon_sym_COLON] = ACTIONS(154),
    [anon_sym_yield] = ACTIONS(142),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_DOT] = ACTIONS(814),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(968),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_EQ_GT] = ACTIONS(970),
    [anon_sym_QMARK_DOT] = ACTIONS(154),
    [anon_sym_new] = ACTIONS(972),
    [anon_sym_using] = ACTIONS(158),
    [anon_sym_PLUS_EQ] = ACTIONS(160),
    [anon_sym_DASH_EQ] = ACTIONS(160),
    [anon_sym_STAR_EQ] = ACTIONS(160),
    [anon_sym_SLASH_EQ] = ACTIONS(160),
    [anon_sym_PERCENT_EQ] = ACTIONS(160),
    [anon_sym_CARET_EQ] = ACTIONS(160),
    [anon_sym_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_LT_LT_EQ] = ACTIONS(160),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(160),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP] = ACTIONS(120),
    [anon_sym_PIPE_PIPE] = ACTIONS(120),
    [anon_sym_GT_GT] = ACTIONS(120),
    [anon_sym_GT_GT_GT] = ACTIONS(120),
    [anon_sym_LT_LT] = ACTIONS(120),
    [anon_sym_AMP] = ACTIONS(120),
    [anon_sym_CARET] = ACTIONS(120),
    [anon_sym_PIPE] = ACTIONS(120),
    [anon_sym_PLUS] = ACTIONS(179),
    [anon_sym_DASH] = ACTIONS(179),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_PERCENT] = ACTIONS(120),
    [anon_sym_STAR_STAR] = ACTIONS(120),
    [anon_sym_LT] = ACTIONS(173),
    [anon_sym_LT_EQ] = ACTIONS(154),
    [anon_sym_EQ_EQ] = ACTIONS(120),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(154),
    [anon_sym_BANG_EQ] = ACTIONS(120),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(154),
    [anon_sym_GT_EQ] = ACTIONS(154),
    [anon_sym_GT] = ACTIONS(120),
    [anon_sym_QMARK_QMARK] = ACTIONS(120),
    [anon_sym_instanceof] = ACTIONS(120),
    [anon_sym_TILDE] = ACTIONS(175),
    [anon_sym_void] = ACTIONS(179),
    [anon_sym_delete] = ACTIONS(179),
    [anon_sym_PLUS_PLUS] = ACTIONS(686),
    [anon_sym_DASH_DASH] = ACTIONS(686),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(192),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(822),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(962),
    [anon_sym_readonly] = ACTIONS(962),
    [anon_sym_get] = ACTIONS(962),
    [anon_sym_set] = ACTIONS(962),
    [anon_sym_declare] = ACTIONS(962),
    [anon_sym_public] = ACTIONS(962),
    [anon_sym_private] = ACTIONS(962),
    [anon_sym_protected] = ACTIONS(962),
    [anon_sym_override] = ACTIONS(962),
    [anon_sym_module] = ACTIONS(962),
    [anon_sym_any] = ACTIONS(962),
    [anon_sym_number] = ACTIONS(962),
    [anon_sym_boolean] = ACTIONS(962),
    [anon_sym_string] = ACTIONS(962),
    [anon_sym_symbol] = ACTIONS(962),
    [anon_sym_object] = ACTIONS(962),
    [anon_sym_satisfies] = ACTIONS(120),
    [sym__ternary_qmark] = ACTIONS(154),
    [sym_html_comment] = ACTIONS(5),
  },
  [133] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1213),
    [sym_expression] = STATE(2644),
    [sym_primary_expression] = STATE(1501),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5522),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5522),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5800),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1213),
    [sym_subscript_expression] = STATE(1213),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3013),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5522),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1213),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(539),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(802),
    [anon_sym_export] = ACTIONS(804),
    [anon_sym_STAR] = ACTIONS(120),
    [anon_sym_type] = ACTIONS(804),
    [anon_sym_EQ] = ACTIONS(824),
    [anon_sym_as] = ACTIONS(120),
    [anon_sym_namespace] = ACTIONS(806),
    [anon_sym_LBRACE] = ACTIONS(808),
    [anon_sym_typeof] = ACTIONS(179),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(804),
    [anon_sym_BANG] = ACTIONS(179),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(140),
    [anon_sym_in] = ACTIONS(120),
    [anon_sym_COLON] = ACTIONS(154),
    [anon_sym_yield] = ACTIONS(142),
    [anon_sym_LBRACK] = ACTIONS(812),
    [anon_sym_DOT] = ACTIONS(814),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(816),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_EQ_GT] = ACTIONS(970),
    [anon_sym_QMARK_DOT] = ACTIONS(154),
    [anon_sym_new] = ACTIONS(818),
    [anon_sym_using] = ACTIONS(158),
    [anon_sym_PLUS_EQ] = ACTIONS(160),
    [anon_sym_DASH_EQ] = ACTIONS(160),
    [anon_sym_STAR_EQ] = ACTIONS(160),
    [anon_sym_SLASH_EQ] = ACTIONS(160),
    [anon_sym_PERCENT_EQ] = ACTIONS(160),
    [anon_sym_CARET_EQ] = ACTIONS(160),
    [anon_sym_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_LT_LT_EQ] = ACTIONS(160),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(160),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP] = ACTIONS(120),
    [anon_sym_PIPE_PIPE] = ACTIONS(120),
    [anon_sym_GT_GT] = ACTIONS(120),
    [anon_sym_GT_GT_GT] = ACTIONS(120),
    [anon_sym_LT_LT] = ACTIONS(120),
    [anon_sym_AMP] = ACTIONS(120),
    [anon_sym_CARET] = ACTIONS(120),
    [anon_sym_PIPE] = ACTIONS(120),
    [anon_sym_PLUS] = ACTIONS(179),
    [anon_sym_DASH] = ACTIONS(179),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_PERCENT] = ACTIONS(120),
    [anon_sym_STAR_STAR] = ACTIONS(120),
    [anon_sym_LT] = ACTIONS(173),
    [anon_sym_LT_EQ] = ACTIONS(154),
    [anon_sym_EQ_EQ] = ACTIONS(120),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(154),
    [anon_sym_BANG_EQ] = ACTIONS(120),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(154),
    [anon_sym_GT_EQ] = ACTIONS(154),
    [anon_sym_GT] = ACTIONS(120),
    [anon_sym_QMARK_QMARK] = ACTIONS(120),
    [anon_sym_instanceof] = ACTIONS(120),
    [anon_sym_TILDE] = ACTIONS(175),
    [anon_sym_void] = ACTIONS(179),
    [anon_sym_delete] = ACTIONS(179),
    [anon_sym_PLUS_PLUS] = ACTIONS(686),
    [anon_sym_DASH_DASH] = ACTIONS(686),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(192),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(822),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(804),
    [anon_sym_readonly] = ACTIONS(804),
    [anon_sym_get] = ACTIONS(804),
    [anon_sym_set] = ACTIONS(804),
    [anon_sym_declare] = ACTIONS(804),
    [anon_sym_public] = ACTIONS(804),
    [anon_sym_private] = ACTIONS(804),
    [anon_sym_protected] = ACTIONS(804),
    [anon_sym_override] = ACTIONS(804),
    [anon_sym_module] = ACTIONS(804),
    [anon_sym_any] = ACTIONS(804),
    [anon_sym_number] = ACTIONS(804),
    [anon_sym_boolean] = ACTIONS(804),
    [anon_sym_string] = ACTIONS(804),
    [anon_sym_symbol] = ACTIONS(804),
    [anon_sym_object] = ACTIONS(804),
    [anon_sym_satisfies] = ACTIONS(120),
    [sym__ternary_qmark] = ACTIONS(154),
    [sym_html_comment] = ACTIONS(5),
  },
  [134] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1213),
    [sym_expression] = STATE(2644),
    [sym_primary_expression] = STATE(1501),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5522),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5522),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5800),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1213),
    [sym_subscript_expression] = STATE(1213),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3013),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5522),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1213),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(539),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(802),
    [anon_sym_export] = ACTIONS(804),
    [anon_sym_STAR] = ACTIONS(120),
    [anon_sym_type] = ACTIONS(804),
    [anon_sym_EQ] = ACTIONS(824),
    [anon_sym_as] = ACTIONS(120),
    [anon_sym_namespace] = ACTIONS(806),
    [anon_sym_LBRACE] = ACTIONS(808),
    [anon_sym_typeof] = ACTIONS(179),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(804),
    [anon_sym_BANG] = ACTIONS(179),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(140),
    [anon_sym_in] = ACTIONS(120),
    [anon_sym_yield] = ACTIONS(142),
    [anon_sym_LBRACK] = ACTIONS(812),
    [anon_sym_RBRACK] = ACTIONS(154),
    [anon_sym_DOT] = ACTIONS(814),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(816),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_EQ_GT] = ACTIONS(895),
    [anon_sym_QMARK_DOT] = ACTIONS(154),
    [anon_sym_new] = ACTIONS(818),
    [anon_sym_using] = ACTIONS(158),
    [anon_sym_PLUS_EQ] = ACTIONS(160),
    [anon_sym_DASH_EQ] = ACTIONS(160),
    [anon_sym_STAR_EQ] = ACTIONS(160),
    [anon_sym_SLASH_EQ] = ACTIONS(160),
    [anon_sym_PERCENT_EQ] = ACTIONS(160),
    [anon_sym_CARET_EQ] = ACTIONS(160),
    [anon_sym_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_LT_LT_EQ] = ACTIONS(160),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(160),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP] = ACTIONS(120),
    [anon_sym_PIPE_PIPE] = ACTIONS(120),
    [anon_sym_GT_GT] = ACTIONS(120),
    [anon_sym_GT_GT_GT] = ACTIONS(120),
    [anon_sym_LT_LT] = ACTIONS(120),
    [anon_sym_AMP] = ACTIONS(120),
    [anon_sym_CARET] = ACTIONS(120),
    [anon_sym_PIPE] = ACTIONS(120),
    [anon_sym_PLUS] = ACTIONS(179),
    [anon_sym_DASH] = ACTIONS(179),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_PERCENT] = ACTIONS(120),
    [anon_sym_STAR_STAR] = ACTIONS(120),
    [anon_sym_LT] = ACTIONS(173),
    [anon_sym_LT_EQ] = ACTIONS(154),
    [anon_sym_EQ_EQ] = ACTIONS(120),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(154),
    [anon_sym_BANG_EQ] = ACTIONS(120),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(154),
    [anon_sym_GT_EQ] = ACTIONS(154),
    [anon_sym_GT] = ACTIONS(120),
    [anon_sym_QMARK_QMARK] = ACTIONS(120),
    [anon_sym_instanceof] = ACTIONS(120),
    [anon_sym_TILDE] = ACTIONS(175),
    [anon_sym_void] = ACTIONS(179),
    [anon_sym_delete] = ACTIONS(179),
    [anon_sym_PLUS_PLUS] = ACTIONS(686),
    [anon_sym_DASH_DASH] = ACTIONS(686),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(192),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(822),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(804),
    [anon_sym_readonly] = ACTIONS(804),
    [anon_sym_get] = ACTIONS(804),
    [anon_sym_set] = ACTIONS(804),
    [anon_sym_declare] = ACTIONS(804),
    [anon_sym_public] = ACTIONS(804),
    [anon_sym_private] = ACTIONS(804),
    [anon_sym_protected] = ACTIONS(804),
    [anon_sym_override] = ACTIONS(804),
    [anon_sym_module] = ACTIONS(804),
    [anon_sym_any] = ACTIONS(804),
    [anon_sym_number] = ACTIONS(804),
    [anon_sym_boolean] = ACTIONS(804),
    [anon_sym_string] = ACTIONS(804),
    [anon_sym_symbol] = ACTIONS(804),
    [anon_sym_object] = ACTIONS(804),
    [anon_sym_satisfies] = ACTIONS(120),
    [sym__ternary_qmark] = ACTIONS(154),
    [sym_html_comment] = ACTIONS(5),
  },
  [135] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1213),
    [sym_expression] = STATE(2644),
    [sym_primary_expression] = STATE(1501),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5522),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5522),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5529),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1213),
    [sym_subscript_expression] = STATE(1213),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3013),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5522),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1213),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(539),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(944),
    [anon_sym_export] = ACTIONS(946),
    [anon_sym_STAR] = ACTIONS(120),
    [anon_sym_type] = ACTIONS(946),
    [anon_sym_EQ] = ACTIONS(948),
    [anon_sym_as] = ACTIONS(120),
    [anon_sym_namespace] = ACTIONS(950),
    [anon_sym_LBRACE] = ACTIONS(808),
    [anon_sym_typeof] = ACTIONS(179),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(946),
    [anon_sym_BANG] = ACTIONS(179),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(140),
    [anon_sym_in] = ACTIONS(120),
    [anon_sym_of] = ACTIONS(120),
    [anon_sym_yield] = ACTIONS(142),
    [anon_sym_LBRACK] = ACTIONS(812),
    [anon_sym_DOT] = ACTIONS(814),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(952),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_EQ_GT] = ACTIONS(954),
    [anon_sym_QMARK_DOT] = ACTIONS(154),
    [anon_sym_new] = ACTIONS(956),
    [anon_sym_using] = ACTIONS(158),
    [anon_sym_PLUS_EQ] = ACTIONS(160),
    [anon_sym_DASH_EQ] = ACTIONS(160),
    [anon_sym_STAR_EQ] = ACTIONS(160),
    [anon_sym_SLASH_EQ] = ACTIONS(160),
    [anon_sym_PERCENT_EQ] = ACTIONS(160),
    [anon_sym_CARET_EQ] = ACTIONS(160),
    [anon_sym_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_LT_LT_EQ] = ACTIONS(160),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(160),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP] = ACTIONS(120),
    [anon_sym_PIPE_PIPE] = ACTIONS(120),
    [anon_sym_GT_GT] = ACTIONS(120),
    [anon_sym_GT_GT_GT] = ACTIONS(120),
    [anon_sym_LT_LT] = ACTIONS(120),
    [anon_sym_AMP] = ACTIONS(120),
    [anon_sym_CARET] = ACTIONS(120),
    [anon_sym_PIPE] = ACTIONS(120),
    [anon_sym_PLUS] = ACTIONS(179),
    [anon_sym_DASH] = ACTIONS(179),
    [anon_sym_SLASH] = ACTIONS(958),
    [anon_sym_PERCENT] = ACTIONS(120),
    [anon_sym_STAR_STAR] = ACTIONS(120),
    [anon_sym_LT] = ACTIONS(173),
    [anon_sym_LT_EQ] = ACTIONS(154),
    [anon_sym_EQ_EQ] = ACTIONS(120),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(154),
    [anon_sym_BANG_EQ] = ACTIONS(120),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(154),
    [anon_sym_GT_EQ] = ACTIONS(154),
    [anon_sym_GT] = ACTIONS(120),
    [anon_sym_QMARK_QMARK] = ACTIONS(120),
    [anon_sym_instanceof] = ACTIONS(120),
    [anon_sym_TILDE] = ACTIONS(175),
    [anon_sym_void] = ACTIONS(179),
    [anon_sym_delete] = ACTIONS(179),
    [anon_sym_PLUS_PLUS] = ACTIONS(686),
    [anon_sym_DASH_DASH] = ACTIONS(686),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(192),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(822),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(946),
    [anon_sym_readonly] = ACTIONS(946),
    [anon_sym_get] = ACTIONS(946),
    [anon_sym_set] = ACTIONS(946),
    [anon_sym_declare] = ACTIONS(946),
    [anon_sym_public] = ACTIONS(946),
    [anon_sym_private] = ACTIONS(946),
    [anon_sym_protected] = ACTIONS(946),
    [anon_sym_override] = ACTIONS(946),
    [anon_sym_module] = ACTIONS(946),
    [anon_sym_any] = ACTIONS(946),
    [anon_sym_number] = ACTIONS(946),
    [anon_sym_boolean] = ACTIONS(946),
    [anon_sym_string] = ACTIONS(946),
    [anon_sym_symbol] = ACTIONS(946),
    [anon_sym_object] = ACTIONS(946),
    [anon_sym_satisfies] = ACTIONS(120),
    [sym__ternary_qmark] = ACTIONS(154),
    [sym_html_comment] = ACTIONS(5),
  },
  [136] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1213),
    [sym_expression] = STATE(2644),
    [sym_primary_expression] = STATE(1501),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5522),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5522),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5800),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1213),
    [sym_subscript_expression] = STATE(1213),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3013),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5522),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1213),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(539),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(802),
    [anon_sym_export] = ACTIONS(804),
    [anon_sym_STAR] = ACTIONS(120),
    [anon_sym_type] = ACTIONS(804),
    [anon_sym_EQ] = ACTIONS(824),
    [anon_sym_as] = ACTIONS(120),
    [anon_sym_namespace] = ACTIONS(806),
    [anon_sym_LBRACE] = ACTIONS(808),
    [anon_sym_typeof] = ACTIONS(179),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(804),
    [anon_sym_BANG] = ACTIONS(179),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(140),
    [anon_sym_in] = ACTIONS(120),
    [anon_sym_of] = ACTIONS(120),
    [anon_sym_yield] = ACTIONS(142),
    [anon_sym_LBRACK] = ACTIONS(812),
    [anon_sym_DOT] = ACTIONS(814),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(816),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_EQ_GT] = ACTIONS(954),
    [anon_sym_QMARK_DOT] = ACTIONS(154),
    [anon_sym_new] = ACTIONS(818),
    [anon_sym_using] = ACTIONS(158),
    [anon_sym_PLUS_EQ] = ACTIONS(160),
    [anon_sym_DASH_EQ] = ACTIONS(160),
    [anon_sym_STAR_EQ] = ACTIONS(160),
    [anon_sym_SLASH_EQ] = ACTIONS(160),
    [anon_sym_PERCENT_EQ] = ACTIONS(160),
    [anon_sym_CARET_EQ] = ACTIONS(160),
    [anon_sym_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_LT_LT_EQ] = ACTIONS(160),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(160),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP] = ACTIONS(120),
    [anon_sym_PIPE_PIPE] = ACTIONS(120),
    [anon_sym_GT_GT] = ACTIONS(120),
    [anon_sym_GT_GT_GT] = ACTIONS(120),
    [anon_sym_LT_LT] = ACTIONS(120),
    [anon_sym_AMP] = ACTIONS(120),
    [anon_sym_CARET] = ACTIONS(120),
    [anon_sym_PIPE] = ACTIONS(120),
    [anon_sym_PLUS] = ACTIONS(179),
    [anon_sym_DASH] = ACTIONS(179),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_PERCENT] = ACTIONS(120),
    [anon_sym_STAR_STAR] = ACTIONS(120),
    [anon_sym_LT] = ACTIONS(173),
    [anon_sym_LT_EQ] = ACTIONS(154),
    [anon_sym_EQ_EQ] = ACTIONS(120),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(154),
    [anon_sym_BANG_EQ] = ACTIONS(120),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(154),
    [anon_sym_GT_EQ] = ACTIONS(154),
    [anon_sym_GT] = ACTIONS(120),
    [anon_sym_QMARK_QMARK] = ACTIONS(120),
    [anon_sym_instanceof] = ACTIONS(120),
    [anon_sym_TILDE] = ACTIONS(175),
    [anon_sym_void] = ACTIONS(179),
    [anon_sym_delete] = ACTIONS(179),
    [anon_sym_PLUS_PLUS] = ACTIONS(686),
    [anon_sym_DASH_DASH] = ACTIONS(686),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(192),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(822),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(804),
    [anon_sym_readonly] = ACTIONS(804),
    [anon_sym_get] = ACTIONS(804),
    [anon_sym_set] = ACTIONS(804),
    [anon_sym_declare] = ACTIONS(804),
    [anon_sym_public] = ACTIONS(804),
    [anon_sym_private] = ACTIONS(804),
    [anon_sym_protected] = ACTIONS(804),
    [anon_sym_override] = ACTIONS(804),
    [anon_sym_module] = ACTIONS(804),
    [anon_sym_any] = ACTIONS(804),
    [anon_sym_number] = ACTIONS(804),
    [anon_sym_boolean] = ACTIONS(804),
    [anon_sym_string] = ACTIONS(804),
    [anon_sym_symbol] = ACTIONS(804),
    [anon_sym_object] = ACTIONS(804),
    [anon_sym_satisfies] = ACTIONS(120),
    [sym__ternary_qmark] = ACTIONS(154),
    [sym_html_comment] = ACTIONS(5),
  },
  [137] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1213),
    [sym_expression] = STATE(2644),
    [sym_primary_expression] = STATE(1501),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5522),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5522),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5800),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1213),
    [sym_subscript_expression] = STATE(1213),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3013),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5522),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1213),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(539),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(802),
    [anon_sym_export] = ACTIONS(804),
    [anon_sym_STAR] = ACTIONS(120),
    [anon_sym_type] = ACTIONS(804),
    [anon_sym_EQ] = ACTIONS(974),
    [anon_sym_as] = ACTIONS(120),
    [anon_sym_namespace] = ACTIONS(806),
    [anon_sym_LBRACE] = ACTIONS(808),
    [anon_sym_typeof] = ACTIONS(179),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(804),
    [anon_sym_BANG] = ACTIONS(179),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(140),
    [anon_sym_in] = ACTIONS(120),
    [anon_sym_yield] = ACTIONS(142),
    [anon_sym_LBRACK] = ACTIONS(812),
    [anon_sym_DOT] = ACTIONS(814),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(816),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_EQ_GT] = ACTIONS(225),
    [anon_sym_QMARK_DOT] = ACTIONS(154),
    [anon_sym_new] = ACTIONS(818),
    [anon_sym_using] = ACTIONS(158),
    [anon_sym_PLUS_EQ] = ACTIONS(160),
    [anon_sym_DASH_EQ] = ACTIONS(160),
    [anon_sym_STAR_EQ] = ACTIONS(160),
    [anon_sym_SLASH_EQ] = ACTIONS(160),
    [anon_sym_PERCENT_EQ] = ACTIONS(160),
    [anon_sym_CARET_EQ] = ACTIONS(160),
    [anon_sym_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_LT_LT_EQ] = ACTIONS(160),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(160),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP] = ACTIONS(120),
    [anon_sym_PIPE_PIPE] = ACTIONS(120),
    [anon_sym_GT_GT] = ACTIONS(120),
    [anon_sym_GT_GT_GT] = ACTIONS(120),
    [anon_sym_LT_LT] = ACTIONS(120),
    [anon_sym_AMP] = ACTIONS(120),
    [anon_sym_CARET] = ACTIONS(120),
    [anon_sym_PIPE] = ACTIONS(120),
    [anon_sym_PLUS] = ACTIONS(179),
    [anon_sym_DASH] = ACTIONS(179),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_PERCENT] = ACTIONS(120),
    [anon_sym_STAR_STAR] = ACTIONS(120),
    [anon_sym_LT] = ACTIONS(173),
    [anon_sym_LT_EQ] = ACTIONS(154),
    [anon_sym_EQ_EQ] = ACTIONS(120),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(154),
    [anon_sym_BANG_EQ] = ACTIONS(120),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(154),
    [anon_sym_GT_EQ] = ACTIONS(154),
    [anon_sym_GT] = ACTIONS(120),
    [anon_sym_QMARK_QMARK] = ACTIONS(120),
    [anon_sym_instanceof] = ACTIONS(120),
    [anon_sym_TILDE] = ACTIONS(175),
    [anon_sym_void] = ACTIONS(179),
    [anon_sym_delete] = ACTIONS(179),
    [anon_sym_PLUS_PLUS] = ACTIONS(686),
    [anon_sym_DASH_DASH] = ACTIONS(686),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(192),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(822),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(804),
    [anon_sym_readonly] = ACTIONS(804),
    [anon_sym_get] = ACTIONS(804),
    [anon_sym_set] = ACTIONS(804),
    [anon_sym_declare] = ACTIONS(804),
    [anon_sym_public] = ACTIONS(804),
    [anon_sym_private] = ACTIONS(804),
    [anon_sym_protected] = ACTIONS(804),
    [anon_sym_override] = ACTIONS(804),
    [anon_sym_module] = ACTIONS(804),
    [anon_sym_any] = ACTIONS(804),
    [anon_sym_number] = ACTIONS(804),
    [anon_sym_boolean] = ACTIONS(804),
    [anon_sym_string] = ACTIONS(804),
    [anon_sym_symbol] = ACTIONS(804),
    [anon_sym_object] = ACTIONS(804),
    [anon_sym_satisfies] = ACTIONS(120),
    [sym__ternary_qmark] = ACTIONS(154),
    [sym_html_comment] = ACTIONS(5),
  },
  [138] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1213),
    [sym_expression] = STATE(2644),
    [sym_primary_expression] = STATE(1501),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5522),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5522),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5800),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1213),
    [sym_subscript_expression] = STATE(1213),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3013),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5522),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1213),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(539),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(802),
    [anon_sym_export] = ACTIONS(804),
    [anon_sym_STAR] = ACTIONS(120),
    [anon_sym_type] = ACTIONS(804),
    [anon_sym_EQ] = ACTIONS(976),
    [anon_sym_as] = ACTIONS(120),
    [anon_sym_namespace] = ACTIONS(806),
    [anon_sym_LBRACE] = ACTIONS(808),
    [anon_sym_typeof] = ACTIONS(179),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(804),
    [anon_sym_BANG] = ACTIONS(179),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(140),
    [anon_sym_in] = ACTIONS(120),
    [anon_sym_yield] = ACTIONS(142),
    [anon_sym_LBRACK] = ACTIONS(812),
    [anon_sym_DOT] = ACTIONS(814),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(816),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_EQ_GT] = ACTIONS(225),
    [anon_sym_QMARK_DOT] = ACTIONS(154),
    [anon_sym_new] = ACTIONS(818),
    [anon_sym_using] = ACTIONS(158),
    [anon_sym_PLUS_EQ] = ACTIONS(160),
    [anon_sym_DASH_EQ] = ACTIONS(160),
    [anon_sym_STAR_EQ] = ACTIONS(160),
    [anon_sym_SLASH_EQ] = ACTIONS(160),
    [anon_sym_PERCENT_EQ] = ACTIONS(160),
    [anon_sym_CARET_EQ] = ACTIONS(160),
    [anon_sym_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_LT_LT_EQ] = ACTIONS(160),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(160),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP] = ACTIONS(120),
    [anon_sym_PIPE_PIPE] = ACTIONS(120),
    [anon_sym_GT_GT] = ACTIONS(120),
    [anon_sym_GT_GT_GT] = ACTIONS(120),
    [anon_sym_LT_LT] = ACTIONS(120),
    [anon_sym_AMP] = ACTIONS(120),
    [anon_sym_CARET] = ACTIONS(120),
    [anon_sym_PIPE] = ACTIONS(120),
    [anon_sym_PLUS] = ACTIONS(179),
    [anon_sym_DASH] = ACTIONS(179),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_PERCENT] = ACTIONS(120),
    [anon_sym_STAR_STAR] = ACTIONS(120),
    [anon_sym_LT] = ACTIONS(173),
    [anon_sym_LT_EQ] = ACTIONS(154),
    [anon_sym_EQ_EQ] = ACTIONS(120),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(154),
    [anon_sym_BANG_EQ] = ACTIONS(120),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(154),
    [anon_sym_GT_EQ] = ACTIONS(154),
    [anon_sym_GT] = ACTIONS(120),
    [anon_sym_QMARK_QMARK] = ACTIONS(120),
    [anon_sym_instanceof] = ACTIONS(120),
    [anon_sym_TILDE] = ACTIONS(175),
    [anon_sym_void] = ACTIONS(179),
    [anon_sym_delete] = ACTIONS(179),
    [anon_sym_PLUS_PLUS] = ACTIONS(686),
    [anon_sym_DASH_DASH] = ACTIONS(686),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(192),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(822),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(804),
    [anon_sym_readonly] = ACTIONS(804),
    [anon_sym_get] = ACTIONS(804),
    [anon_sym_set] = ACTIONS(804),
    [anon_sym_declare] = ACTIONS(804),
    [anon_sym_public] = ACTIONS(804),
    [anon_sym_private] = ACTIONS(804),
    [anon_sym_protected] = ACTIONS(804),
    [anon_sym_override] = ACTIONS(804),
    [anon_sym_module] = ACTIONS(804),
    [anon_sym_any] = ACTIONS(804),
    [anon_sym_number] = ACTIONS(804),
    [anon_sym_boolean] = ACTIONS(804),
    [anon_sym_string] = ACTIONS(804),
    [anon_sym_symbol] = ACTIONS(804),
    [anon_sym_object] = ACTIONS(804),
    [anon_sym_satisfies] = ACTIONS(120),
    [sym__ternary_qmark] = ACTIONS(154),
    [sym_html_comment] = ACTIONS(5),
  },
  [139] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1213),
    [sym_expression] = STATE(2644),
    [sym_primary_expression] = STATE(1501),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5522),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5522),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5800),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1213),
    [sym_subscript_expression] = STATE(1213),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3013),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5522),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(4116),
    [sym_non_null_expression] = STATE(1213),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(539),
    [sym_type_parameters] = STATE(5344),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(802),
    [anon_sym_export] = ACTIONS(804),
    [anon_sym_STAR] = ACTIONS(120),
    [anon_sym_type] = ACTIONS(804),
    [anon_sym_EQ] = ACTIONS(824),
    [anon_sym_as] = ACTIONS(120),
    [anon_sym_namespace] = ACTIONS(806),
    [anon_sym_LBRACE] = ACTIONS(808),
    [anon_sym_typeof] = ACTIONS(179),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(804),
    [anon_sym_BANG] = ACTIONS(179),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(140),
    [anon_sym_in] = ACTIONS(120),
    [anon_sym_yield] = ACTIONS(142),
    [anon_sym_LBRACK] = ACTIONS(812),
    [anon_sym_DOT] = ACTIONS(814),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(816),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_EQ_GT] = ACTIONS(225),
    [anon_sym_QMARK_DOT] = ACTIONS(154),
    [anon_sym_new] = ACTIONS(818),
    [anon_sym_using] = ACTIONS(158),
    [anon_sym_PLUS_EQ] = ACTIONS(160),
    [anon_sym_DASH_EQ] = ACTIONS(160),
    [anon_sym_STAR_EQ] = ACTIONS(160),
    [anon_sym_SLASH_EQ] = ACTIONS(160),
    [anon_sym_PERCENT_EQ] = ACTIONS(160),
    [anon_sym_CARET_EQ] = ACTIONS(160),
    [anon_sym_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_LT_LT_EQ] = ACTIONS(160),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(160),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP] = ACTIONS(120),
    [anon_sym_PIPE_PIPE] = ACTIONS(120),
    [anon_sym_GT_GT] = ACTIONS(120),
    [anon_sym_GT_GT_GT] = ACTIONS(120),
    [anon_sym_LT_LT] = ACTIONS(120),
    [anon_sym_AMP] = ACTIONS(120),
    [anon_sym_CARET] = ACTIONS(120),
    [anon_sym_PIPE] = ACTIONS(120),
    [anon_sym_PLUS] = ACTIONS(179),
    [anon_sym_DASH] = ACTIONS(179),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_PERCENT] = ACTIONS(120),
    [anon_sym_STAR_STAR] = ACTIONS(120),
    [anon_sym_LT] = ACTIONS(173),
    [anon_sym_LT_EQ] = ACTIONS(154),
    [anon_sym_EQ_EQ] = ACTIONS(120),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(154),
    [anon_sym_BANG_EQ] = ACTIONS(120),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(154),
    [anon_sym_GT_EQ] = ACTIONS(154),
    [anon_sym_GT] = ACTIONS(120),
    [anon_sym_QMARK_QMARK] = ACTIONS(120),
    [anon_sym_instanceof] = ACTIONS(120),
    [anon_sym_TILDE] = ACTIONS(175),
    [anon_sym_void] = ACTIONS(179),
    [anon_sym_delete] = ACTIONS(179),
    [anon_sym_PLUS_PLUS] = ACTIONS(686),
    [anon_sym_DASH_DASH] = ACTIONS(686),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(192),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(822),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(804),
    [anon_sym_readonly] = ACTIONS(804),
    [anon_sym_get] = ACTIONS(804),
    [anon_sym_set] = ACTIONS(804),
    [anon_sym_declare] = ACTIONS(804),
    [anon_sym_public] = ACTIONS(804),
    [anon_sym_private] = ACTIONS(804),
    [anon_sym_protected] = ACTIONS(804),
    [anon_sym_override] = ACTIONS(804),
    [anon_sym_module] = ACTIONS(804),
    [anon_sym_any] = ACTIONS(804),
    [anon_sym_number] = ACTIONS(804),
    [anon_sym_boolean] = ACTIONS(804),
    [anon_sym_string] = ACTIONS(804),
    [anon_sym_symbol] = ACTIONS(804),
    [anon_sym_object] = ACTIONS(804),
    [anon_sym_satisfies] = ACTIONS(120),
    [sym__ternary_qmark] = ACTIONS(154),
    [sym_html_comment] = ACTIONS(5),
  },
  [140] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1213),
    [sym_expression] = STATE(2644),
    [sym_primary_expression] = STATE(1501),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5522),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5522),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5800),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1213),
    [sym_subscript_expression] = STATE(1213),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3013),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5522),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1213),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(539),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(802),
    [anon_sym_export] = ACTIONS(804),
    [anon_sym_STAR] = ACTIONS(120),
    [anon_sym_type] = ACTIONS(804),
    [anon_sym_EQ] = ACTIONS(978),
    [anon_sym_as] = ACTIONS(120),
    [anon_sym_namespace] = ACTIONS(806),
    [anon_sym_LBRACE] = ACTIONS(808),
    [anon_sym_typeof] = ACTIONS(179),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(804),
    [anon_sym_BANG] = ACTIONS(179),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(140),
    [anon_sym_in] = ACTIONS(120),
    [anon_sym_yield] = ACTIONS(142),
    [anon_sym_LBRACK] = ACTIONS(812),
    [anon_sym_DOT] = ACTIONS(814),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(816),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_EQ_GT] = ACTIONS(225),
    [anon_sym_QMARK_DOT] = ACTIONS(154),
    [anon_sym_new] = ACTIONS(818),
    [anon_sym_using] = ACTIONS(158),
    [anon_sym_PLUS_EQ] = ACTIONS(160),
    [anon_sym_DASH_EQ] = ACTIONS(160),
    [anon_sym_STAR_EQ] = ACTIONS(160),
    [anon_sym_SLASH_EQ] = ACTIONS(160),
    [anon_sym_PERCENT_EQ] = ACTIONS(160),
    [anon_sym_CARET_EQ] = ACTIONS(160),
    [anon_sym_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_LT_LT_EQ] = ACTIONS(160),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(160),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP] = ACTIONS(120),
    [anon_sym_PIPE_PIPE] = ACTIONS(120),
    [anon_sym_GT_GT] = ACTIONS(120),
    [anon_sym_GT_GT_GT] = ACTIONS(120),
    [anon_sym_LT_LT] = ACTIONS(120),
    [anon_sym_AMP] = ACTIONS(120),
    [anon_sym_CARET] = ACTIONS(120),
    [anon_sym_PIPE] = ACTIONS(120),
    [anon_sym_PLUS] = ACTIONS(179),
    [anon_sym_DASH] = ACTIONS(179),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_PERCENT] = ACTIONS(120),
    [anon_sym_STAR_STAR] = ACTIONS(120),
    [anon_sym_LT] = ACTIONS(173),
    [anon_sym_LT_EQ] = ACTIONS(154),
    [anon_sym_EQ_EQ] = ACTIONS(120),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(154),
    [anon_sym_BANG_EQ] = ACTIONS(120),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(154),
    [anon_sym_GT_EQ] = ACTIONS(154),
    [anon_sym_GT] = ACTIONS(120),
    [anon_sym_QMARK_QMARK] = ACTIONS(120),
    [anon_sym_instanceof] = ACTIONS(120),
    [anon_sym_TILDE] = ACTIONS(175),
    [anon_sym_void] = ACTIONS(179),
    [anon_sym_delete] = ACTIONS(179),
    [anon_sym_PLUS_PLUS] = ACTIONS(686),
    [anon_sym_DASH_DASH] = ACTIONS(686),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(192),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(822),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(804),
    [anon_sym_readonly] = ACTIONS(804),
    [anon_sym_get] = ACTIONS(804),
    [anon_sym_set] = ACTIONS(804),
    [anon_sym_declare] = ACTIONS(804),
    [anon_sym_public] = ACTIONS(804),
    [anon_sym_private] = ACTIONS(804),
    [anon_sym_protected] = ACTIONS(804),
    [anon_sym_override] = ACTIONS(804),
    [anon_sym_module] = ACTIONS(804),
    [anon_sym_any] = ACTIONS(804),
    [anon_sym_number] = ACTIONS(804),
    [anon_sym_boolean] = ACTIONS(804),
    [anon_sym_string] = ACTIONS(804),
    [anon_sym_symbol] = ACTIONS(804),
    [anon_sym_object] = ACTIONS(804),
    [anon_sym_satisfies] = ACTIONS(120),
    [sym__ternary_qmark] = ACTIONS(154),
    [sym_html_comment] = ACTIONS(5),
  },
  [141] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1213),
    [sym_expression] = STATE(2644),
    [sym_primary_expression] = STATE(1501),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5522),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5522),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5800),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1213),
    [sym_subscript_expression] = STATE(1213),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3013),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5522),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1213),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(539),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(802),
    [anon_sym_export] = ACTIONS(804),
    [anon_sym_STAR] = ACTIONS(120),
    [anon_sym_type] = ACTIONS(804),
    [anon_sym_EQ] = ACTIONS(980),
    [anon_sym_as] = ACTIONS(120),
    [anon_sym_namespace] = ACTIONS(806),
    [anon_sym_LBRACE] = ACTIONS(808),
    [anon_sym_typeof] = ACTIONS(179),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(804),
    [anon_sym_BANG] = ACTIONS(179),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(140),
    [anon_sym_in] = ACTIONS(120),
    [anon_sym_yield] = ACTIONS(142),
    [anon_sym_LBRACK] = ACTIONS(812),
    [anon_sym_DOT] = ACTIONS(814),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(816),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_EQ_GT] = ACTIONS(225),
    [anon_sym_QMARK_DOT] = ACTIONS(154),
    [anon_sym_new] = ACTIONS(818),
    [anon_sym_using] = ACTIONS(158),
    [anon_sym_PLUS_EQ] = ACTIONS(160),
    [anon_sym_DASH_EQ] = ACTIONS(160),
    [anon_sym_STAR_EQ] = ACTIONS(160),
    [anon_sym_SLASH_EQ] = ACTIONS(160),
    [anon_sym_PERCENT_EQ] = ACTIONS(160),
    [anon_sym_CARET_EQ] = ACTIONS(160),
    [anon_sym_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_LT_LT_EQ] = ACTIONS(160),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(160),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP] = ACTIONS(120),
    [anon_sym_PIPE_PIPE] = ACTIONS(120),
    [anon_sym_GT_GT] = ACTIONS(120),
    [anon_sym_GT_GT_GT] = ACTIONS(120),
    [anon_sym_LT_LT] = ACTIONS(120),
    [anon_sym_AMP] = ACTIONS(120),
    [anon_sym_CARET] = ACTIONS(120),
    [anon_sym_PIPE] = ACTIONS(120),
    [anon_sym_PLUS] = ACTIONS(179),
    [anon_sym_DASH] = ACTIONS(179),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_PERCENT] = ACTIONS(120),
    [anon_sym_STAR_STAR] = ACTIONS(120),
    [anon_sym_LT] = ACTIONS(173),
    [anon_sym_LT_EQ] = ACTIONS(154),
    [anon_sym_EQ_EQ] = ACTIONS(120),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(154),
    [anon_sym_BANG_EQ] = ACTIONS(120),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(154),
    [anon_sym_GT_EQ] = ACTIONS(154),
    [anon_sym_GT] = ACTIONS(120),
    [anon_sym_QMARK_QMARK] = ACTIONS(120),
    [anon_sym_instanceof] = ACTIONS(120),
    [anon_sym_TILDE] = ACTIONS(175),
    [anon_sym_void] = ACTIONS(179),
    [anon_sym_delete] = ACTIONS(179),
    [anon_sym_PLUS_PLUS] = ACTIONS(686),
    [anon_sym_DASH_DASH] = ACTIONS(686),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(192),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(822),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(804),
    [anon_sym_readonly] = ACTIONS(804),
    [anon_sym_get] = ACTIONS(804),
    [anon_sym_set] = ACTIONS(804),
    [anon_sym_declare] = ACTIONS(804),
    [anon_sym_public] = ACTIONS(804),
    [anon_sym_private] = ACTIONS(804),
    [anon_sym_protected] = ACTIONS(804),
    [anon_sym_override] = ACTIONS(804),
    [anon_sym_module] = ACTIONS(804),
    [anon_sym_any] = ACTIONS(804),
    [anon_sym_number] = ACTIONS(804),
    [anon_sym_boolean] = ACTIONS(804),
    [anon_sym_string] = ACTIONS(804),
    [anon_sym_symbol] = ACTIONS(804),
    [anon_sym_object] = ACTIONS(804),
    [anon_sym_satisfies] = ACTIONS(120),
    [sym__ternary_qmark] = ACTIONS(154),
    [sym_html_comment] = ACTIONS(5),
  },
  [142] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1213),
    [sym_expression] = STATE(2644),
    [sym_primary_expression] = STATE(1501),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5522),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5522),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5800),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1213),
    [sym_subscript_expression] = STATE(1213),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3013),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5522),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1213),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(539),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(802),
    [anon_sym_export] = ACTIONS(804),
    [anon_sym_STAR] = ACTIONS(120),
    [anon_sym_type] = ACTIONS(804),
    [anon_sym_EQ] = ACTIONS(982),
    [anon_sym_as] = ACTIONS(120),
    [anon_sym_namespace] = ACTIONS(806),
    [anon_sym_LBRACE] = ACTIONS(808),
    [anon_sym_typeof] = ACTIONS(179),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(804),
    [anon_sym_BANG] = ACTIONS(179),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(140),
    [anon_sym_in] = ACTIONS(120),
    [anon_sym_yield] = ACTIONS(142),
    [anon_sym_LBRACK] = ACTIONS(812),
    [anon_sym_DOT] = ACTIONS(814),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(816),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_EQ_GT] = ACTIONS(225),
    [anon_sym_QMARK_DOT] = ACTIONS(154),
    [anon_sym_new] = ACTIONS(818),
    [anon_sym_using] = ACTIONS(158),
    [anon_sym_PLUS_EQ] = ACTIONS(160),
    [anon_sym_DASH_EQ] = ACTIONS(160),
    [anon_sym_STAR_EQ] = ACTIONS(160),
    [anon_sym_SLASH_EQ] = ACTIONS(160),
    [anon_sym_PERCENT_EQ] = ACTIONS(160),
    [anon_sym_CARET_EQ] = ACTIONS(160),
    [anon_sym_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_LT_LT_EQ] = ACTIONS(160),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(160),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP] = ACTIONS(120),
    [anon_sym_PIPE_PIPE] = ACTIONS(120),
    [anon_sym_GT_GT] = ACTIONS(120),
    [anon_sym_GT_GT_GT] = ACTIONS(120),
    [anon_sym_LT_LT] = ACTIONS(120),
    [anon_sym_AMP] = ACTIONS(120),
    [anon_sym_CARET] = ACTIONS(120),
    [anon_sym_PIPE] = ACTIONS(120),
    [anon_sym_PLUS] = ACTIONS(179),
    [anon_sym_DASH] = ACTIONS(179),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_PERCENT] = ACTIONS(120),
    [anon_sym_STAR_STAR] = ACTIONS(120),
    [anon_sym_LT] = ACTIONS(173),
    [anon_sym_LT_EQ] = ACTIONS(154),
    [anon_sym_EQ_EQ] = ACTIONS(120),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(154),
    [anon_sym_BANG_EQ] = ACTIONS(120),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(154),
    [anon_sym_GT_EQ] = ACTIONS(154),
    [anon_sym_GT] = ACTIONS(120),
    [anon_sym_QMARK_QMARK] = ACTIONS(120),
    [anon_sym_instanceof] = ACTIONS(120),
    [anon_sym_TILDE] = ACTIONS(175),
    [anon_sym_void] = ACTIONS(179),
    [anon_sym_delete] = ACTIONS(179),
    [anon_sym_PLUS_PLUS] = ACTIONS(686),
    [anon_sym_DASH_DASH] = ACTIONS(686),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(192),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(822),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(804),
    [anon_sym_readonly] = ACTIONS(804),
    [anon_sym_get] = ACTIONS(804),
    [anon_sym_set] = ACTIONS(804),
    [anon_sym_declare] = ACTIONS(804),
    [anon_sym_public] = ACTIONS(804),
    [anon_sym_private] = ACTIONS(804),
    [anon_sym_protected] = ACTIONS(804),
    [anon_sym_override] = ACTIONS(804),
    [anon_sym_module] = ACTIONS(804),
    [anon_sym_any] = ACTIONS(804),
    [anon_sym_number] = ACTIONS(804),
    [anon_sym_boolean] = ACTIONS(804),
    [anon_sym_string] = ACTIONS(804),
    [anon_sym_symbol] = ACTIONS(804),
    [anon_sym_object] = ACTIONS(804),
    [anon_sym_satisfies] = ACTIONS(120),
    [sym__ternary_qmark] = ACTIONS(154),
    [sym_html_comment] = ACTIONS(5),
  },
  [143] = {
    [sym_import] = STATE(3574),
    [sym_parenthesized_expression] = STATE(1322),
    [sym_expression] = STATE(2425),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(4425),
    [sym_assignment_pattern] = STATE(5260),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(4425),
    [sym_nested_identifier] = STATE(5535),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5508),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1396),
    [sym_subscript_expression] = STATE(1396),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3003),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(4425),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1956),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3948),
    [sym_pattern] = STATE(4930),
    [sym_rest_pattern] = STATE(3684),
    [sym_non_null_expression] = STATE(1396),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_nested_type_identifier] = STATE(3151),
    [sym__type_query_member_expression_in_type_annotation] = STATE(3076),
    [sym__type_query_call_expression_in_type_annotation] = STATE(3200),
    [sym_type] = STATE(3302),
    [sym_constructor_type] = STATE(3271),
    [sym_primary_type] = STATE(3272),
    [sym_template_literal_type] = STATE(3273),
    [sym_infer_type] = STATE(3271),
    [sym_conditional_type] = STATE(3273),
    [sym_generic_type] = STATE(3273),
    [sym_type_query] = STATE(3273),
    [sym_index_type_query] = STATE(3273),
    [sym_lookup_type] = STATE(3273),
    [sym_literal_type] = STATE(3273),
    [sym__number] = STATE(3274),
    [sym_existential_type] = STATE(3273),
    [sym_flow_maybe_type] = STATE(3273),
    [sym_parenthesized_type] = STATE(3273),
    [sym_predefined_type] = STATE(3273),
    [sym_type_arguments] = STATE(484),
    [sym_object_type] = STATE(3273),
    [sym_type_parameters] = STATE(5291),
    [sym_array_type] = STATE(3273),
    [sym_tuple_type] = STATE(3273),
    [sym_readonly_type] = STATE(3271),
    [sym_union_type] = STATE(3273),
    [sym_intersection_type] = STATE(3273),
    [sym_function_type] = STATE(3271),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(984),
    [anon_sym_export] = ACTIONS(541),
    [anon_sym_STAR] = ACTIONS(986),
    [anon_sym_type] = ACTIONS(541),
    [anon_sym_namespace] = ACTIONS(545),
    [anon_sym_LBRACE] = ACTIONS(988),
    [anon_sym_typeof] = ACTIONS(990),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(541),
    [anon_sym_const] = ACTIONS(992),
    [anon_sym_BANG] = ACTIONS(553),
    [anon_sym_LPAREN] = ACTIONS(994),
    [anon_sym_await] = ACTIONS(555),
    [anon_sym_yield] = ACTIONS(557),
    [anon_sym_LBRACK] = ACTIONS(996),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(563),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(998),
    [anon_sym_using] = ACTIONS(567),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(162),
    [anon_sym_AMP] = ACTIONS(1000),
    [anon_sym_PIPE] = ACTIONS(1002),
    [anon_sym_PLUS] = ACTIONS(1004),
    [anon_sym_DASH] = ACTIONS(1004),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(553),
    [anon_sym_void] = ACTIONS(1006),
    [anon_sym_delete] = ACTIONS(581),
    [anon_sym_PLUS_PLUS] = ACTIONS(583),
    [anon_sym_DASH_DASH] = ACTIONS(583),
    [anon_sym_DQUOTE] = ACTIONS(83),
    [anon_sym_SQUOTE] = ACTIONS(85),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1008),
    [sym_number] = ACTIONS(1010),
    [sym_private_property_identifier] = ACTIONS(585),
    [sym_this] = ACTIONS(1012),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(1014),
    [sym_false] = ACTIONS(1014),
    [sym_null] = ACTIONS(1014),
    [sym_undefined] = ACTIONS(1016),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(541),
    [anon_sym_readonly] = ACTIONS(1018),
    [anon_sym_get] = ACTIONS(541),
    [anon_sym_set] = ACTIONS(541),
    [anon_sym_QMARK] = ACTIONS(1020),
    [anon_sym_declare] = ACTIONS(541),
    [anon_sym_public] = ACTIONS(541),
    [anon_sym_private] = ACTIONS(541),
    [anon_sym_protected] = ACTIONS(541),
    [anon_sym_override] = ACTIONS(541),
    [anon_sym_module] = ACTIONS(541),
    [anon_sym_any] = ACTIONS(1022),
    [anon_sym_number] = ACTIONS(1022),
    [anon_sym_boolean] = ACTIONS(1022),
    [anon_sym_string] = ACTIONS(1022),
    [anon_sym_symbol] = ACTIONS(1022),
    [anon_sym_object] = ACTIONS(1022),
    [anon_sym_abstract] = ACTIONS(1024),
    [anon_sym_infer] = ACTIONS(1026),
    [anon_sym_keyof] = ACTIONS(1028),
    [anon_sym_unique] = ACTIONS(1030),
    [anon_sym_unknown] = ACTIONS(1032),
    [anon_sym_never] = ACTIONS(1032),
    [anon_sym_LBRACE_PIPE] = ACTIONS(1034),
    [sym_html_comment] = ACTIONS(5),
  },
  [144] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1213),
    [sym_expression] = STATE(2644),
    [sym_primary_expression] = STATE(1501),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5522),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5522),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5800),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1213),
    [sym_subscript_expression] = STATE(1213),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3013),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5522),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1213),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(539),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(802),
    [anon_sym_export] = ACTIONS(804),
    [anon_sym_STAR] = ACTIONS(120),
    [anon_sym_type] = ACTIONS(804),
    [anon_sym_EQ] = ACTIONS(1036),
    [anon_sym_as] = ACTIONS(120),
    [anon_sym_namespace] = ACTIONS(806),
    [anon_sym_LBRACE] = ACTIONS(808),
    [anon_sym_typeof] = ACTIONS(179),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(804),
    [anon_sym_BANG] = ACTIONS(179),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(140),
    [anon_sym_in] = ACTIONS(120),
    [anon_sym_yield] = ACTIONS(142),
    [anon_sym_LBRACK] = ACTIONS(812),
    [anon_sym_DOT] = ACTIONS(814),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(816),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_EQ_GT] = ACTIONS(225),
    [anon_sym_QMARK_DOT] = ACTIONS(154),
    [anon_sym_new] = ACTIONS(818),
    [anon_sym_using] = ACTIONS(158),
    [anon_sym_PLUS_EQ] = ACTIONS(160),
    [anon_sym_DASH_EQ] = ACTIONS(160),
    [anon_sym_STAR_EQ] = ACTIONS(160),
    [anon_sym_SLASH_EQ] = ACTIONS(160),
    [anon_sym_PERCENT_EQ] = ACTIONS(160),
    [anon_sym_CARET_EQ] = ACTIONS(160),
    [anon_sym_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_LT_LT_EQ] = ACTIONS(160),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(160),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP] = ACTIONS(120),
    [anon_sym_PIPE_PIPE] = ACTIONS(120),
    [anon_sym_GT_GT] = ACTIONS(120),
    [anon_sym_GT_GT_GT] = ACTIONS(120),
    [anon_sym_LT_LT] = ACTIONS(120),
    [anon_sym_AMP] = ACTIONS(120),
    [anon_sym_CARET] = ACTIONS(120),
    [anon_sym_PIPE] = ACTIONS(120),
    [anon_sym_PLUS] = ACTIONS(179),
    [anon_sym_DASH] = ACTIONS(179),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_PERCENT] = ACTIONS(120),
    [anon_sym_STAR_STAR] = ACTIONS(120),
    [anon_sym_LT] = ACTIONS(173),
    [anon_sym_LT_EQ] = ACTIONS(154),
    [anon_sym_EQ_EQ] = ACTIONS(120),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(154),
    [anon_sym_BANG_EQ] = ACTIONS(120),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(154),
    [anon_sym_GT_EQ] = ACTIONS(154),
    [anon_sym_GT] = ACTIONS(120),
    [anon_sym_QMARK_QMARK] = ACTIONS(120),
    [anon_sym_instanceof] = ACTIONS(120),
    [anon_sym_TILDE] = ACTIONS(175),
    [anon_sym_void] = ACTIONS(179),
    [anon_sym_delete] = ACTIONS(179),
    [anon_sym_PLUS_PLUS] = ACTIONS(686),
    [anon_sym_DASH_DASH] = ACTIONS(686),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(192),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(822),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(804),
    [anon_sym_readonly] = ACTIONS(804),
    [anon_sym_get] = ACTIONS(804),
    [anon_sym_set] = ACTIONS(804),
    [anon_sym_declare] = ACTIONS(804),
    [anon_sym_public] = ACTIONS(804),
    [anon_sym_private] = ACTIONS(804),
    [anon_sym_protected] = ACTIONS(804),
    [anon_sym_override] = ACTIONS(804),
    [anon_sym_module] = ACTIONS(804),
    [anon_sym_any] = ACTIONS(804),
    [anon_sym_number] = ACTIONS(804),
    [anon_sym_boolean] = ACTIONS(804),
    [anon_sym_string] = ACTIONS(804),
    [anon_sym_symbol] = ACTIONS(804),
    [anon_sym_object] = ACTIONS(804),
    [anon_sym_satisfies] = ACTIONS(120),
    [sym__ternary_qmark] = ACTIONS(154),
    [sym_html_comment] = ACTIONS(5),
  },
  [145] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1213),
    [sym_expression] = STATE(2644),
    [sym_primary_expression] = STATE(1501),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5522),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5522),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5800),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1213),
    [sym_subscript_expression] = STATE(1213),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3013),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5522),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1213),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(539),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(802),
    [anon_sym_export] = ACTIONS(804),
    [anon_sym_STAR] = ACTIONS(120),
    [anon_sym_type] = ACTIONS(804),
    [anon_sym_EQ] = ACTIONS(824),
    [anon_sym_as] = ACTIONS(120),
    [anon_sym_namespace] = ACTIONS(806),
    [anon_sym_LBRACE] = ACTIONS(808),
    [anon_sym_typeof] = ACTIONS(179),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(804),
    [anon_sym_BANG] = ACTIONS(179),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(140),
    [anon_sym_in] = ACTIONS(120),
    [anon_sym_yield] = ACTIONS(142),
    [anon_sym_LBRACK] = ACTIONS(812),
    [anon_sym_DOT] = ACTIONS(814),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(816),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_EQ_GT] = ACTIONS(225),
    [anon_sym_QMARK_DOT] = ACTIONS(154),
    [anon_sym_new] = ACTIONS(818),
    [anon_sym_using] = ACTIONS(158),
    [anon_sym_PLUS_EQ] = ACTIONS(160),
    [anon_sym_DASH_EQ] = ACTIONS(160),
    [anon_sym_STAR_EQ] = ACTIONS(160),
    [anon_sym_SLASH_EQ] = ACTIONS(160),
    [anon_sym_PERCENT_EQ] = ACTIONS(160),
    [anon_sym_CARET_EQ] = ACTIONS(160),
    [anon_sym_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_LT_LT_EQ] = ACTIONS(160),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(160),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP] = ACTIONS(120),
    [anon_sym_PIPE_PIPE] = ACTIONS(120),
    [anon_sym_GT_GT] = ACTIONS(120),
    [anon_sym_GT_GT_GT] = ACTIONS(120),
    [anon_sym_LT_LT] = ACTIONS(120),
    [anon_sym_AMP] = ACTIONS(120),
    [anon_sym_CARET] = ACTIONS(120),
    [anon_sym_PIPE] = ACTIONS(120),
    [anon_sym_PLUS] = ACTIONS(179),
    [anon_sym_DASH] = ACTIONS(179),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_PERCENT] = ACTIONS(120),
    [anon_sym_STAR_STAR] = ACTIONS(120),
    [anon_sym_LT] = ACTIONS(173),
    [anon_sym_LT_EQ] = ACTIONS(154),
    [anon_sym_EQ_EQ] = ACTIONS(120),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(154),
    [anon_sym_BANG_EQ] = ACTIONS(120),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(154),
    [anon_sym_GT_EQ] = ACTIONS(154),
    [anon_sym_GT] = ACTIONS(120),
    [anon_sym_QMARK_QMARK] = ACTIONS(120),
    [anon_sym_instanceof] = ACTIONS(120),
    [anon_sym_TILDE] = ACTIONS(175),
    [anon_sym_void] = ACTIONS(179),
    [anon_sym_delete] = ACTIONS(179),
    [anon_sym_PLUS_PLUS] = ACTIONS(686),
    [anon_sym_DASH_DASH] = ACTIONS(686),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(192),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(822),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(804),
    [anon_sym_readonly] = ACTIONS(804),
    [anon_sym_get] = ACTIONS(804),
    [anon_sym_set] = ACTIONS(804),
    [anon_sym_declare] = ACTIONS(804),
    [anon_sym_public] = ACTIONS(804),
    [anon_sym_private] = ACTIONS(804),
    [anon_sym_protected] = ACTIONS(804),
    [anon_sym_override] = ACTIONS(804),
    [anon_sym_module] = ACTIONS(804),
    [anon_sym_any] = ACTIONS(804),
    [anon_sym_number] = ACTIONS(804),
    [anon_sym_boolean] = ACTIONS(804),
    [anon_sym_string] = ACTIONS(804),
    [anon_sym_symbol] = ACTIONS(804),
    [anon_sym_object] = ACTIONS(804),
    [anon_sym_satisfies] = ACTIONS(120),
    [sym__ternary_qmark] = ACTIONS(154),
    [sym_html_comment] = ACTIONS(5),
  },
  [146] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1213),
    [sym_expression] = STATE(2644),
    [sym_primary_expression] = STATE(1501),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5522),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5522),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5800),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1213),
    [sym_subscript_expression] = STATE(1213),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3013),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5522),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1213),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(539),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(802),
    [anon_sym_export] = ACTIONS(804),
    [anon_sym_STAR] = ACTIONS(120),
    [anon_sym_type] = ACTIONS(804),
    [anon_sym_EQ] = ACTIONS(1038),
    [anon_sym_as] = ACTIONS(120),
    [anon_sym_namespace] = ACTIONS(806),
    [anon_sym_LBRACE] = ACTIONS(808),
    [anon_sym_typeof] = ACTIONS(179),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(804),
    [anon_sym_BANG] = ACTIONS(179),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(140),
    [anon_sym_in] = ACTIONS(120),
    [anon_sym_yield] = ACTIONS(142),
    [anon_sym_LBRACK] = ACTIONS(812),
    [anon_sym_DOT] = ACTIONS(814),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(816),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_EQ_GT] = ACTIONS(225),
    [anon_sym_QMARK_DOT] = ACTIONS(154),
    [anon_sym_new] = ACTIONS(818),
    [anon_sym_using] = ACTIONS(158),
    [anon_sym_PLUS_EQ] = ACTIONS(160),
    [anon_sym_DASH_EQ] = ACTIONS(160),
    [anon_sym_STAR_EQ] = ACTIONS(160),
    [anon_sym_SLASH_EQ] = ACTIONS(160),
    [anon_sym_PERCENT_EQ] = ACTIONS(160),
    [anon_sym_CARET_EQ] = ACTIONS(160),
    [anon_sym_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_LT_LT_EQ] = ACTIONS(160),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(160),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP] = ACTIONS(120),
    [anon_sym_PIPE_PIPE] = ACTIONS(120),
    [anon_sym_GT_GT] = ACTIONS(120),
    [anon_sym_GT_GT_GT] = ACTIONS(120),
    [anon_sym_LT_LT] = ACTIONS(120),
    [anon_sym_AMP] = ACTIONS(120),
    [anon_sym_CARET] = ACTIONS(120),
    [anon_sym_PIPE] = ACTIONS(120),
    [anon_sym_PLUS] = ACTIONS(179),
    [anon_sym_DASH] = ACTIONS(179),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_PERCENT] = ACTIONS(120),
    [anon_sym_STAR_STAR] = ACTIONS(120),
    [anon_sym_LT] = ACTIONS(173),
    [anon_sym_LT_EQ] = ACTIONS(154),
    [anon_sym_EQ_EQ] = ACTIONS(120),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(154),
    [anon_sym_BANG_EQ] = ACTIONS(120),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(154),
    [anon_sym_GT_EQ] = ACTIONS(154),
    [anon_sym_GT] = ACTIONS(120),
    [anon_sym_QMARK_QMARK] = ACTIONS(120),
    [anon_sym_instanceof] = ACTIONS(120),
    [anon_sym_TILDE] = ACTIONS(175),
    [anon_sym_void] = ACTIONS(179),
    [anon_sym_delete] = ACTIONS(179),
    [anon_sym_PLUS_PLUS] = ACTIONS(686),
    [anon_sym_DASH_DASH] = ACTIONS(686),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(192),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(822),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(804),
    [anon_sym_readonly] = ACTIONS(804),
    [anon_sym_get] = ACTIONS(804),
    [anon_sym_set] = ACTIONS(804),
    [anon_sym_declare] = ACTIONS(804),
    [anon_sym_public] = ACTIONS(804),
    [anon_sym_private] = ACTIONS(804),
    [anon_sym_protected] = ACTIONS(804),
    [anon_sym_override] = ACTIONS(804),
    [anon_sym_module] = ACTIONS(804),
    [anon_sym_any] = ACTIONS(804),
    [anon_sym_number] = ACTIONS(804),
    [anon_sym_boolean] = ACTIONS(804),
    [anon_sym_string] = ACTIONS(804),
    [anon_sym_symbol] = ACTIONS(804),
    [anon_sym_object] = ACTIONS(804),
    [anon_sym_satisfies] = ACTIONS(120),
    [sym__ternary_qmark] = ACTIONS(154),
    [sym_html_comment] = ACTIONS(5),
  },
  [147] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1213),
    [sym_expression] = STATE(2644),
    [sym_primary_expression] = STATE(1501),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5522),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5522),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5800),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1213),
    [sym_subscript_expression] = STATE(1213),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3013),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5522),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1213),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(539),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(802),
    [anon_sym_export] = ACTIONS(804),
    [anon_sym_STAR] = ACTIONS(120),
    [anon_sym_type] = ACTIONS(804),
    [anon_sym_EQ] = ACTIONS(1040),
    [anon_sym_as] = ACTIONS(120),
    [anon_sym_namespace] = ACTIONS(806),
    [anon_sym_LBRACE] = ACTIONS(808),
    [anon_sym_typeof] = ACTIONS(179),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(804),
    [anon_sym_BANG] = ACTIONS(179),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(140),
    [anon_sym_in] = ACTIONS(120),
    [anon_sym_yield] = ACTIONS(142),
    [anon_sym_LBRACK] = ACTIONS(812),
    [anon_sym_DOT] = ACTIONS(814),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(816),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_EQ_GT] = ACTIONS(225),
    [anon_sym_QMARK_DOT] = ACTIONS(154),
    [anon_sym_new] = ACTIONS(818),
    [anon_sym_using] = ACTIONS(158),
    [anon_sym_PLUS_EQ] = ACTIONS(160),
    [anon_sym_DASH_EQ] = ACTIONS(160),
    [anon_sym_STAR_EQ] = ACTIONS(160),
    [anon_sym_SLASH_EQ] = ACTIONS(160),
    [anon_sym_PERCENT_EQ] = ACTIONS(160),
    [anon_sym_CARET_EQ] = ACTIONS(160),
    [anon_sym_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_LT_LT_EQ] = ACTIONS(160),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(160),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP] = ACTIONS(120),
    [anon_sym_PIPE_PIPE] = ACTIONS(120),
    [anon_sym_GT_GT] = ACTIONS(120),
    [anon_sym_GT_GT_GT] = ACTIONS(120),
    [anon_sym_LT_LT] = ACTIONS(120),
    [anon_sym_AMP] = ACTIONS(120),
    [anon_sym_CARET] = ACTIONS(120),
    [anon_sym_PIPE] = ACTIONS(120),
    [anon_sym_PLUS] = ACTIONS(179),
    [anon_sym_DASH] = ACTIONS(179),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_PERCENT] = ACTIONS(120),
    [anon_sym_STAR_STAR] = ACTIONS(120),
    [anon_sym_LT] = ACTIONS(173),
    [anon_sym_LT_EQ] = ACTIONS(154),
    [anon_sym_EQ_EQ] = ACTIONS(120),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(154),
    [anon_sym_BANG_EQ] = ACTIONS(120),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(154),
    [anon_sym_GT_EQ] = ACTIONS(154),
    [anon_sym_GT] = ACTIONS(120),
    [anon_sym_QMARK_QMARK] = ACTIONS(120),
    [anon_sym_instanceof] = ACTIONS(120),
    [anon_sym_TILDE] = ACTIONS(175),
    [anon_sym_void] = ACTIONS(179),
    [anon_sym_delete] = ACTIONS(179),
    [anon_sym_PLUS_PLUS] = ACTIONS(686),
    [anon_sym_DASH_DASH] = ACTIONS(686),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(192),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(822),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(804),
    [anon_sym_readonly] = ACTIONS(804),
    [anon_sym_get] = ACTIONS(804),
    [anon_sym_set] = ACTIONS(804),
    [anon_sym_declare] = ACTIONS(804),
    [anon_sym_public] = ACTIONS(804),
    [anon_sym_private] = ACTIONS(804),
    [anon_sym_protected] = ACTIONS(804),
    [anon_sym_override] = ACTIONS(804),
    [anon_sym_module] = ACTIONS(804),
    [anon_sym_any] = ACTIONS(804),
    [anon_sym_number] = ACTIONS(804),
    [anon_sym_boolean] = ACTIONS(804),
    [anon_sym_string] = ACTIONS(804),
    [anon_sym_symbol] = ACTIONS(804),
    [anon_sym_object] = ACTIONS(804),
    [anon_sym_satisfies] = ACTIONS(120),
    [sym__ternary_qmark] = ACTIONS(154),
    [sym_html_comment] = ACTIONS(5),
  },
  [148] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1213),
    [sym_expression] = STATE(2644),
    [sym_primary_expression] = STATE(1501),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5522),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5522),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5800),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1213),
    [sym_subscript_expression] = STATE(1213),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3013),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5522),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1213),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(539),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(802),
    [anon_sym_export] = ACTIONS(804),
    [anon_sym_STAR] = ACTIONS(120),
    [anon_sym_type] = ACTIONS(804),
    [anon_sym_EQ] = ACTIONS(1042),
    [anon_sym_as] = ACTIONS(120),
    [anon_sym_namespace] = ACTIONS(806),
    [anon_sym_LBRACE] = ACTIONS(808),
    [anon_sym_typeof] = ACTIONS(179),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(804),
    [anon_sym_BANG] = ACTIONS(179),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(140),
    [anon_sym_in] = ACTIONS(120),
    [anon_sym_yield] = ACTIONS(142),
    [anon_sym_LBRACK] = ACTIONS(812),
    [anon_sym_DOT] = ACTIONS(814),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(816),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_EQ_GT] = ACTIONS(225),
    [anon_sym_QMARK_DOT] = ACTIONS(154),
    [anon_sym_new] = ACTIONS(818),
    [anon_sym_using] = ACTIONS(158),
    [anon_sym_PLUS_EQ] = ACTIONS(160),
    [anon_sym_DASH_EQ] = ACTIONS(160),
    [anon_sym_STAR_EQ] = ACTIONS(160),
    [anon_sym_SLASH_EQ] = ACTIONS(160),
    [anon_sym_PERCENT_EQ] = ACTIONS(160),
    [anon_sym_CARET_EQ] = ACTIONS(160),
    [anon_sym_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_LT_LT_EQ] = ACTIONS(160),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(160),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP] = ACTIONS(120),
    [anon_sym_PIPE_PIPE] = ACTIONS(120),
    [anon_sym_GT_GT] = ACTIONS(120),
    [anon_sym_GT_GT_GT] = ACTIONS(120),
    [anon_sym_LT_LT] = ACTIONS(120),
    [anon_sym_AMP] = ACTIONS(120),
    [anon_sym_CARET] = ACTIONS(120),
    [anon_sym_PIPE] = ACTIONS(120),
    [anon_sym_PLUS] = ACTIONS(179),
    [anon_sym_DASH] = ACTIONS(179),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_PERCENT] = ACTIONS(120),
    [anon_sym_STAR_STAR] = ACTIONS(120),
    [anon_sym_LT] = ACTIONS(173),
    [anon_sym_LT_EQ] = ACTIONS(154),
    [anon_sym_EQ_EQ] = ACTIONS(120),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(154),
    [anon_sym_BANG_EQ] = ACTIONS(120),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(154),
    [anon_sym_GT_EQ] = ACTIONS(154),
    [anon_sym_GT] = ACTIONS(120),
    [anon_sym_QMARK_QMARK] = ACTIONS(120),
    [anon_sym_instanceof] = ACTIONS(120),
    [anon_sym_TILDE] = ACTIONS(175),
    [anon_sym_void] = ACTIONS(179),
    [anon_sym_delete] = ACTIONS(179),
    [anon_sym_PLUS_PLUS] = ACTIONS(686),
    [anon_sym_DASH_DASH] = ACTIONS(686),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(192),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(822),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(804),
    [anon_sym_readonly] = ACTIONS(804),
    [anon_sym_get] = ACTIONS(804),
    [anon_sym_set] = ACTIONS(804),
    [anon_sym_declare] = ACTIONS(804),
    [anon_sym_public] = ACTIONS(804),
    [anon_sym_private] = ACTIONS(804),
    [anon_sym_protected] = ACTIONS(804),
    [anon_sym_override] = ACTIONS(804),
    [anon_sym_module] = ACTIONS(804),
    [anon_sym_any] = ACTIONS(804),
    [anon_sym_number] = ACTIONS(804),
    [anon_sym_boolean] = ACTIONS(804),
    [anon_sym_string] = ACTIONS(804),
    [anon_sym_symbol] = ACTIONS(804),
    [anon_sym_object] = ACTIONS(804),
    [anon_sym_satisfies] = ACTIONS(120),
    [sym__ternary_qmark] = ACTIONS(154),
    [sym_html_comment] = ACTIONS(5),
  },
  [149] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1213),
    [sym_expression] = STATE(2644),
    [sym_primary_expression] = STATE(1501),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5522),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5522),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5800),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1213),
    [sym_subscript_expression] = STATE(1213),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3013),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5522),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1213),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(539),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(802),
    [anon_sym_export] = ACTIONS(804),
    [anon_sym_STAR] = ACTIONS(120),
    [anon_sym_type] = ACTIONS(804),
    [anon_sym_EQ] = ACTIONS(1044),
    [anon_sym_as] = ACTIONS(120),
    [anon_sym_namespace] = ACTIONS(806),
    [anon_sym_LBRACE] = ACTIONS(808),
    [anon_sym_typeof] = ACTIONS(179),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(804),
    [anon_sym_BANG] = ACTIONS(179),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(140),
    [anon_sym_in] = ACTIONS(120),
    [anon_sym_yield] = ACTIONS(142),
    [anon_sym_LBRACK] = ACTIONS(812),
    [anon_sym_DOT] = ACTIONS(814),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(816),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_EQ_GT] = ACTIONS(225),
    [anon_sym_QMARK_DOT] = ACTIONS(154),
    [anon_sym_new] = ACTIONS(818),
    [anon_sym_using] = ACTIONS(158),
    [anon_sym_PLUS_EQ] = ACTIONS(160),
    [anon_sym_DASH_EQ] = ACTIONS(160),
    [anon_sym_STAR_EQ] = ACTIONS(160),
    [anon_sym_SLASH_EQ] = ACTIONS(160),
    [anon_sym_PERCENT_EQ] = ACTIONS(160),
    [anon_sym_CARET_EQ] = ACTIONS(160),
    [anon_sym_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_LT_LT_EQ] = ACTIONS(160),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(160),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP] = ACTIONS(120),
    [anon_sym_PIPE_PIPE] = ACTIONS(120),
    [anon_sym_GT_GT] = ACTIONS(120),
    [anon_sym_GT_GT_GT] = ACTIONS(120),
    [anon_sym_LT_LT] = ACTIONS(120),
    [anon_sym_AMP] = ACTIONS(120),
    [anon_sym_CARET] = ACTIONS(120),
    [anon_sym_PIPE] = ACTIONS(120),
    [anon_sym_PLUS] = ACTIONS(179),
    [anon_sym_DASH] = ACTIONS(179),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_PERCENT] = ACTIONS(120),
    [anon_sym_STAR_STAR] = ACTIONS(120),
    [anon_sym_LT] = ACTIONS(173),
    [anon_sym_LT_EQ] = ACTIONS(154),
    [anon_sym_EQ_EQ] = ACTIONS(120),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(154),
    [anon_sym_BANG_EQ] = ACTIONS(120),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(154),
    [anon_sym_GT_EQ] = ACTIONS(154),
    [anon_sym_GT] = ACTIONS(120),
    [anon_sym_QMARK_QMARK] = ACTIONS(120),
    [anon_sym_instanceof] = ACTIONS(120),
    [anon_sym_TILDE] = ACTIONS(175),
    [anon_sym_void] = ACTIONS(179),
    [anon_sym_delete] = ACTIONS(179),
    [anon_sym_PLUS_PLUS] = ACTIONS(686),
    [anon_sym_DASH_DASH] = ACTIONS(686),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(192),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(822),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(804),
    [anon_sym_readonly] = ACTIONS(804),
    [anon_sym_get] = ACTIONS(804),
    [anon_sym_set] = ACTIONS(804),
    [anon_sym_declare] = ACTIONS(804),
    [anon_sym_public] = ACTIONS(804),
    [anon_sym_private] = ACTIONS(804),
    [anon_sym_protected] = ACTIONS(804),
    [anon_sym_override] = ACTIONS(804),
    [anon_sym_module] = ACTIONS(804),
    [anon_sym_any] = ACTIONS(804),
    [anon_sym_number] = ACTIONS(804),
    [anon_sym_boolean] = ACTIONS(804),
    [anon_sym_string] = ACTIONS(804),
    [anon_sym_symbol] = ACTIONS(804),
    [anon_sym_object] = ACTIONS(804),
    [anon_sym_satisfies] = ACTIONS(120),
    [sym__ternary_qmark] = ACTIONS(154),
    [sym_html_comment] = ACTIONS(5),
  },
  [150] = {
    [sym_import] = STATE(3593),
    [sym_parenthesized_expression] = STATE(1322),
    [sym_expression] = STATE(2188),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5698),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5698),
    [sym_nested_identifier] = STATE(5474),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5508),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1322),
    [sym_subscript_expression] = STATE(1322),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3003),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5698),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_sequence_expression] = STATE(5640),
    [sym_string] = STATE(2338),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(4087),
    [sym_non_null_expression] = STATE(1322),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_nested_type_identifier] = STATE(2939),
    [sym__type_query_member_expression_in_type_annotation] = STATE(2937),
    [sym__type_query_call_expression_in_type_annotation] = STATE(2938),
    [sym_type] = STATE(4622),
    [sym_constructor_type] = STATE(3007),
    [sym_primary_type] = STATE(4133),
    [sym_template_literal_type] = STATE(3039),
    [sym_infer_type] = STATE(4403),
    [sym_conditional_type] = STATE(3039),
    [sym_generic_type] = STATE(3039),
    [sym_type_query] = STATE(3039),
    [sym_index_type_query] = STATE(3039),
    [sym_lookup_type] = STATE(3039),
    [sym_literal_type] = STATE(3039),
    [sym__number] = STATE(3041),
    [sym_existential_type] = STATE(3039),
    [sym_flow_maybe_type] = STATE(3039),
    [sym_parenthesized_type] = STATE(3039),
    [sym_predefined_type] = STATE(3039),
    [sym_type_arguments] = STATE(484),
    [sym_object_type] = STATE(3039),
    [sym_type_parameters] = STATE(5158),
    [sym_array_type] = STATE(3039),
    [sym_tuple_type] = STATE(3039),
    [sym_readonly_type] = STATE(3007),
    [sym_union_type] = STATE(3039),
    [sym_intersection_type] = STATE(3039),
    [sym_function_type] = STATE(3007),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1046),
    [anon_sym_export] = ACTIONS(1048),
    [anon_sym_STAR] = ACTIONS(543),
    [anon_sym_type] = ACTIONS(1048),
    [anon_sym_namespace] = ACTIONS(1050),
    [anon_sym_LBRACE] = ACTIONS(1052),
    [anon_sym_typeof] = ACTIONS(1054),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1048),
    [anon_sym_const] = ACTIONS(133),
    [anon_sym_BANG] = ACTIONS(553),
    [anon_sym_LPAREN] = ACTIONS(138),
    [anon_sym_await] = ACTIONS(555),
    [anon_sym_yield] = ACTIONS(557),
    [anon_sym_LBRACK] = ACTIONS(1056),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1058),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1060),
    [anon_sym_using] = ACTIONS(567),
    [anon_sym_AMP] = ACTIONS(748),
    [anon_sym_PIPE] = ACTIONS(750),
    [anon_sym_PLUS] = ACTIONS(1062),
    [anon_sym_DASH] = ACTIONS(1062),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(553),
    [anon_sym_void] = ACTIONS(579),
    [anon_sym_delete] = ACTIONS(581),
    [anon_sym_PLUS_PLUS] = ACTIONS(583),
    [anon_sym_DASH_DASH] = ACTIONS(583),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(760),
    [sym_number] = ACTIONS(762),
    [sym_private_property_identifier] = ACTIONS(585),
    [sym_this] = ACTIONS(1064),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(768),
    [sym_false] = ACTIONS(768),
    [sym_null] = ACTIONS(768),
    [sym_undefined] = ACTIONS(1066),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1048),
    [anon_sym_readonly] = ACTIONS(1068),
    [anon_sym_get] = ACTIONS(1048),
    [anon_sym_set] = ACTIONS(1048),
    [anon_sym_QMARK] = ACTIONS(774),
    [anon_sym_declare] = ACTIONS(1048),
    [anon_sym_public] = ACTIONS(1048),
    [anon_sym_private] = ACTIONS(1048),
    [anon_sym_protected] = ACTIONS(1048),
    [anon_sym_override] = ACTIONS(1048),
    [anon_sym_module] = ACTIONS(1048),
    [anon_sym_any] = ACTIONS(1070),
    [anon_sym_number] = ACTIONS(1070),
    [anon_sym_boolean] = ACTIONS(1070),
    [anon_sym_string] = ACTIONS(1070),
    [anon_sym_symbol] = ACTIONS(1070),
    [anon_sym_object] = ACTIONS(1070),
    [anon_sym_abstract] = ACTIONS(208),
    [anon_sym_infer] = ACTIONS(210),
    [anon_sym_keyof] = ACTIONS(212),
    [anon_sym_unique] = ACTIONS(214),
    [anon_sym_unknown] = ACTIONS(216),
    [anon_sym_never] = ACTIONS(216),
    [anon_sym_LBRACE_PIPE] = ACTIONS(218),
    [sym_html_comment] = ACTIONS(5),
  },
  [151] = {
    [sym_import] = STATE(3508),
    [sym_parenthesized_expression] = STATE(1459),
    [sym_expression] = STATE(2490),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5827),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5827),
    [sym_nested_identifier] = STATE(5474),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5529),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1459),
    [sym_subscript_expression] = STATE(1459),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(2979),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5827),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(2226),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(4087),
    [sym_non_null_expression] = STATE(1459),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_nested_type_identifier] = STATE(2939),
    [sym__type_query_member_expression_in_type_annotation] = STATE(2937),
    [sym__type_query_call_expression_in_type_annotation] = STATE(2938),
    [sym_type] = STATE(3788),
    [sym_constructor_type] = STATE(3007),
    [sym_primary_type] = STATE(2981),
    [sym_template_literal_type] = STATE(3039),
    [sym_infer_type] = STATE(3007),
    [sym_conditional_type] = STATE(3039),
    [sym_generic_type] = STATE(3039),
    [sym_type_query] = STATE(3039),
    [sym_index_type_query] = STATE(3039),
    [sym_lookup_type] = STATE(3039),
    [sym_literal_type] = STATE(3039),
    [sym__number] = STATE(3041),
    [sym_existential_type] = STATE(3039),
    [sym_flow_maybe_type] = STATE(3039),
    [sym_parenthesized_type] = STATE(3039),
    [sym_predefined_type] = STATE(3039),
    [sym_type_arguments] = STATE(647),
    [sym_object_type] = STATE(3039),
    [sym_type_parameters] = STATE(5158),
    [sym_array_type] = STATE(3039),
    [sym_tuple_type] = STATE(3039),
    [sym_readonly_type] = STATE(3007),
    [sym_union_type] = STATE(3039),
    [sym_intersection_type] = STATE(3039),
    [sym_function_type] = STATE(3007),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1072),
    [anon_sym_export] = ACTIONS(1074),
    [anon_sym_STAR] = ACTIONS(543),
    [anon_sym_type] = ACTIONS(1074),
    [anon_sym_namespace] = ACTIONS(1076),
    [anon_sym_LBRACE] = ACTIONS(1078),
    [anon_sym_typeof] = ACTIONS(1080),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1074),
    [anon_sym_const] = ACTIONS(133),
    [anon_sym_BANG] = ACTIONS(1082),
    [anon_sym_LPAREN] = ACTIONS(138),
    [anon_sym_await] = ACTIONS(1084),
    [anon_sym_yield] = ACTIONS(1086),
    [anon_sym_LBRACK] = ACTIONS(1088),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1090),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1092),
    [anon_sym_using] = ACTIONS(1094),
    [anon_sym_AMP] = ACTIONS(748),
    [anon_sym_PIPE] = ACTIONS(750),
    [anon_sym_PLUS] = ACTIONS(1096),
    [anon_sym_DASH] = ACTIONS(1096),
    [anon_sym_SLASH] = ACTIONS(958),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(1082),
    [anon_sym_void] = ACTIONS(1098),
    [anon_sym_delete] = ACTIONS(1100),
    [anon_sym_PLUS_PLUS] = ACTIONS(1102),
    [anon_sym_DASH_DASH] = ACTIONS(1102),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1104),
    [sym_number] = ACTIONS(1106),
    [sym_private_property_identifier] = ACTIONS(1108),
    [sym_this] = ACTIONS(1110),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(1112),
    [sym_false] = ACTIONS(1112),
    [sym_null] = ACTIONS(1112),
    [sym_undefined] = ACTIONS(1114),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1074),
    [anon_sym_readonly] = ACTIONS(1116),
    [anon_sym_get] = ACTIONS(1074),
    [anon_sym_set] = ACTIONS(1074),
    [anon_sym_QMARK] = ACTIONS(774),
    [anon_sym_declare] = ACTIONS(1074),
    [anon_sym_public] = ACTIONS(1074),
    [anon_sym_private] = ACTIONS(1074),
    [anon_sym_protected] = ACTIONS(1074),
    [anon_sym_override] = ACTIONS(1074),
    [anon_sym_module] = ACTIONS(1074),
    [anon_sym_any] = ACTIONS(1118),
    [anon_sym_number] = ACTIONS(1118),
    [anon_sym_boolean] = ACTIONS(1118),
    [anon_sym_string] = ACTIONS(1118),
    [anon_sym_symbol] = ACTIONS(1118),
    [anon_sym_object] = ACTIONS(1118),
    [anon_sym_abstract] = ACTIONS(208),
    [anon_sym_infer] = ACTIONS(210),
    [anon_sym_keyof] = ACTIONS(212),
    [anon_sym_unique] = ACTIONS(214),
    [anon_sym_unknown] = ACTIONS(216),
    [anon_sym_never] = ACTIONS(216),
    [anon_sym_LBRACE_PIPE] = ACTIONS(218),
    [sym_html_comment] = ACTIONS(5),
  },
  [152] = {
    [sym_import] = STATE(3508),
    [sym_parenthesized_expression] = STATE(1213),
    [sym_expression] = STATE(2532),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5522),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5522),
    [sym_nested_identifier] = STATE(5474),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5800),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1213),
    [sym_subscript_expression] = STATE(1213),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3013),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5522),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(2226),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(4087),
    [sym_non_null_expression] = STATE(1213),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_nested_type_identifier] = STATE(2939),
    [sym__type_query_member_expression_in_type_annotation] = STATE(2937),
    [sym__type_query_call_expression_in_type_annotation] = STATE(2938),
    [sym_type] = STATE(3788),
    [sym_constructor_type] = STATE(3007),
    [sym_primary_type] = STATE(2981),
    [sym_template_literal_type] = STATE(3039),
    [sym_infer_type] = STATE(3007),
    [sym_conditional_type] = STATE(3039),
    [sym_generic_type] = STATE(3039),
    [sym_type_query] = STATE(3039),
    [sym_index_type_query] = STATE(3039),
    [sym_lookup_type] = STATE(3039),
    [sym_literal_type] = STATE(3039),
    [sym__number] = STATE(3041),
    [sym_existential_type] = STATE(3039),
    [sym_flow_maybe_type] = STATE(3039),
    [sym_parenthesized_type] = STATE(3039),
    [sym_predefined_type] = STATE(3039),
    [sym_type_arguments] = STATE(539),
    [sym_object_type] = STATE(3039),
    [sym_type_parameters] = STATE(5158),
    [sym_array_type] = STATE(3039),
    [sym_tuple_type] = STATE(3039),
    [sym_readonly_type] = STATE(3007),
    [sym_union_type] = STATE(3039),
    [sym_intersection_type] = STATE(3039),
    [sym_function_type] = STATE(3007),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1120),
    [anon_sym_export] = ACTIONS(804),
    [anon_sym_STAR] = ACTIONS(543),
    [anon_sym_type] = ACTIONS(804),
    [anon_sym_namespace] = ACTIONS(806),
    [anon_sym_LBRACE] = ACTIONS(1078),
    [anon_sym_typeof] = ACTIONS(1122),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(804),
    [anon_sym_const] = ACTIONS(133),
    [anon_sym_BANG] = ACTIONS(175),
    [anon_sym_LPAREN] = ACTIONS(138),
    [anon_sym_await] = ACTIONS(140),
    [anon_sym_yield] = ACTIONS(142),
    [anon_sym_LBRACK] = ACTIONS(1088),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(816),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1124),
    [anon_sym_using] = ACTIONS(158),
    [anon_sym_AMP] = ACTIONS(748),
    [anon_sym_PIPE] = ACTIONS(750),
    [anon_sym_PLUS] = ACTIONS(1126),
    [anon_sym_DASH] = ACTIONS(1126),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(175),
    [anon_sym_void] = ACTIONS(177),
    [anon_sym_delete] = ACTIONS(179),
    [anon_sym_PLUS_PLUS] = ACTIONS(686),
    [anon_sym_DASH_DASH] = ACTIONS(686),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1104),
    [sym_number] = ACTIONS(1106),
    [sym_private_property_identifier] = ACTIONS(192),
    [sym_this] = ACTIONS(1110),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(1112),
    [sym_false] = ACTIONS(1112),
    [sym_null] = ACTIONS(1112),
    [sym_undefined] = ACTIONS(1128),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(804),
    [anon_sym_readonly] = ACTIONS(1130),
    [anon_sym_get] = ACTIONS(804),
    [anon_sym_set] = ACTIONS(804),
    [anon_sym_QMARK] = ACTIONS(774),
    [anon_sym_declare] = ACTIONS(804),
    [anon_sym_public] = ACTIONS(804),
    [anon_sym_private] = ACTIONS(804),
    [anon_sym_protected] = ACTIONS(804),
    [anon_sym_override] = ACTIONS(804),
    [anon_sym_module] = ACTIONS(804),
    [anon_sym_any] = ACTIONS(1132),
    [anon_sym_number] = ACTIONS(1132),
    [anon_sym_boolean] = ACTIONS(1132),
    [anon_sym_string] = ACTIONS(1132),
    [anon_sym_symbol] = ACTIONS(1132),
    [anon_sym_object] = ACTIONS(1132),
    [anon_sym_abstract] = ACTIONS(208),
    [anon_sym_infer] = ACTIONS(210),
    [anon_sym_keyof] = ACTIONS(212),
    [anon_sym_unique] = ACTIONS(214),
    [anon_sym_unknown] = ACTIONS(216),
    [anon_sym_never] = ACTIONS(216),
    [anon_sym_LBRACE_PIPE] = ACTIONS(218),
    [sym_html_comment] = ACTIONS(5),
  },
  [153] = {
    [sym_import] = STATE(3593),
    [sym_parenthesized_expression] = STATE(1322),
    [sym_expression] = STATE(1746),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5698),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5698),
    [sym_nested_identifier] = STATE(5474),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5508),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1322),
    [sym_subscript_expression] = STATE(1322),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3003),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5698),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1707),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(4087),
    [sym_non_null_expression] = STATE(1322),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_nested_type_identifier] = STATE(2939),
    [sym__type_query_member_expression_in_type_annotation] = STATE(2937),
    [sym__type_query_call_expression_in_type_annotation] = STATE(2938),
    [sym_type] = STATE(3788),
    [sym_constructor_type] = STATE(3007),
    [sym_primary_type] = STATE(2981),
    [sym_template_literal_type] = STATE(3039),
    [sym_infer_type] = STATE(3007),
    [sym_conditional_type] = STATE(3039),
    [sym_generic_type] = STATE(3039),
    [sym_type_query] = STATE(3039),
    [sym_index_type_query] = STATE(3039),
    [sym_lookup_type] = STATE(3039),
    [sym_literal_type] = STATE(3039),
    [sym__number] = STATE(3041),
    [sym_existential_type] = STATE(3039),
    [sym_flow_maybe_type] = STATE(3039),
    [sym_parenthesized_type] = STATE(3039),
    [sym_predefined_type] = STATE(3039),
    [sym_type_arguments] = STATE(484),
    [sym_object_type] = STATE(3039),
    [sym_type_parameters] = STATE(5158),
    [sym_array_type] = STATE(3039),
    [sym_tuple_type] = STATE(3039),
    [sym_readonly_type] = STATE(3007),
    [sym_union_type] = STATE(3039),
    [sym_intersection_type] = STATE(3039),
    [sym_function_type] = STATE(3007),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1134),
    [anon_sym_export] = ACTIONS(1048),
    [anon_sym_STAR] = ACTIONS(543),
    [anon_sym_type] = ACTIONS(1048),
    [anon_sym_namespace] = ACTIONS(1050),
    [anon_sym_LBRACE] = ACTIONS(1136),
    [anon_sym_typeof] = ACTIONS(1138),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1048),
    [anon_sym_const] = ACTIONS(133),
    [anon_sym_BANG] = ACTIONS(553),
    [anon_sym_LPAREN] = ACTIONS(138),
    [anon_sym_await] = ACTIONS(555),
    [anon_sym_yield] = ACTIONS(557),
    [anon_sym_LBRACK] = ACTIONS(1140),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1058),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1060),
    [anon_sym_using] = ACTIONS(567),
    [anon_sym_AMP] = ACTIONS(748),
    [anon_sym_PIPE] = ACTIONS(750),
    [anon_sym_PLUS] = ACTIONS(1142),
    [anon_sym_DASH] = ACTIONS(1142),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(553),
    [anon_sym_void] = ACTIONS(579),
    [anon_sym_delete] = ACTIONS(581),
    [anon_sym_PLUS_PLUS] = ACTIONS(583),
    [anon_sym_DASH_DASH] = ACTIONS(583),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1144),
    [sym_number] = ACTIONS(1146),
    [sym_private_property_identifier] = ACTIONS(585),
    [sym_this] = ACTIONS(1148),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(1150),
    [sym_false] = ACTIONS(1150),
    [sym_null] = ACTIONS(1150),
    [sym_undefined] = ACTIONS(1152),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1048),
    [anon_sym_readonly] = ACTIONS(1068),
    [anon_sym_get] = ACTIONS(1048),
    [anon_sym_set] = ACTIONS(1048),
    [anon_sym_QMARK] = ACTIONS(774),
    [anon_sym_declare] = ACTIONS(1048),
    [anon_sym_public] = ACTIONS(1048),
    [anon_sym_private] = ACTIONS(1048),
    [anon_sym_protected] = ACTIONS(1048),
    [anon_sym_override] = ACTIONS(1048),
    [anon_sym_module] = ACTIONS(1048),
    [anon_sym_any] = ACTIONS(1154),
    [anon_sym_number] = ACTIONS(1154),
    [anon_sym_boolean] = ACTIONS(1154),
    [anon_sym_string] = ACTIONS(1154),
    [anon_sym_symbol] = ACTIONS(1154),
    [anon_sym_object] = ACTIONS(1154),
    [anon_sym_abstract] = ACTIONS(208),
    [anon_sym_infer] = ACTIONS(210),
    [anon_sym_keyof] = ACTIONS(212),
    [anon_sym_unique] = ACTIONS(214),
    [anon_sym_unknown] = ACTIONS(216),
    [anon_sym_never] = ACTIONS(216),
    [anon_sym_LBRACE_PIPE] = ACTIONS(218),
    [sym_html_comment] = ACTIONS(5),
  },
  [154] = {
    [sym_import] = STATE(3563),
    [sym_parenthesized_expression] = STATE(1398),
    [sym_expression] = STATE(1891),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5544),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5544),
    [sym_nested_identifier] = STATE(5474),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5558),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1398),
    [sym_subscript_expression] = STATE(1398),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(2980),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5544),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1707),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(4087),
    [sym_non_null_expression] = STATE(1398),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_nested_type_identifier] = STATE(2939),
    [sym__type_query_member_expression_in_type_annotation] = STATE(2937),
    [sym__type_query_call_expression_in_type_annotation] = STATE(2938),
    [sym_type] = STATE(3788),
    [sym_constructor_type] = STATE(3007),
    [sym_primary_type] = STATE(2981),
    [sym_template_literal_type] = STATE(3039),
    [sym_infer_type] = STATE(3007),
    [sym_conditional_type] = STATE(3039),
    [sym_generic_type] = STATE(3039),
    [sym_type_query] = STATE(3039),
    [sym_index_type_query] = STATE(3039),
    [sym_lookup_type] = STATE(3039),
    [sym_literal_type] = STATE(3039),
    [sym__number] = STATE(3041),
    [sym_existential_type] = STATE(3039),
    [sym_flow_maybe_type] = STATE(3039),
    [sym_parenthesized_type] = STATE(3039),
    [sym_predefined_type] = STATE(3039),
    [sym_type_arguments] = STATE(638),
    [sym_object_type] = STATE(3039),
    [sym_type_parameters] = STATE(5158),
    [sym_array_type] = STATE(3039),
    [sym_tuple_type] = STATE(3039),
    [sym_readonly_type] = STATE(3007),
    [sym_union_type] = STATE(3039),
    [sym_intersection_type] = STATE(3039),
    [sym_function_type] = STATE(3007),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1156),
    [anon_sym_export] = ACTIONS(1158),
    [anon_sym_STAR] = ACTIONS(543),
    [anon_sym_type] = ACTIONS(1158),
    [anon_sym_namespace] = ACTIONS(1160),
    [anon_sym_LBRACE] = ACTIONS(1136),
    [anon_sym_typeof] = ACTIONS(1162),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1158),
    [anon_sym_const] = ACTIONS(133),
    [anon_sym_BANG] = ACTIONS(732),
    [anon_sym_LPAREN] = ACTIONS(138),
    [anon_sym_await] = ACTIONS(736),
    [anon_sym_yield] = ACTIONS(738),
    [anon_sym_LBRACK] = ACTIONS(1140),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1164),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1166),
    [anon_sym_using] = ACTIONS(746),
    [anon_sym_AMP] = ACTIONS(748),
    [anon_sym_PIPE] = ACTIONS(750),
    [anon_sym_PLUS] = ACTIONS(1168),
    [anon_sym_DASH] = ACTIONS(1168),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(732),
    [anon_sym_void] = ACTIONS(754),
    [anon_sym_delete] = ACTIONS(756),
    [anon_sym_PLUS_PLUS] = ACTIONS(758),
    [anon_sym_DASH_DASH] = ACTIONS(758),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1144),
    [sym_number] = ACTIONS(1146),
    [sym_private_property_identifier] = ACTIONS(764),
    [sym_this] = ACTIONS(1148),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(1150),
    [sym_false] = ACTIONS(1150),
    [sym_null] = ACTIONS(1150),
    [sym_undefined] = ACTIONS(1170),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1158),
    [anon_sym_readonly] = ACTIONS(1172),
    [anon_sym_get] = ACTIONS(1158),
    [anon_sym_set] = ACTIONS(1158),
    [anon_sym_QMARK] = ACTIONS(774),
    [anon_sym_declare] = ACTIONS(1158),
    [anon_sym_public] = ACTIONS(1158),
    [anon_sym_private] = ACTIONS(1158),
    [anon_sym_protected] = ACTIONS(1158),
    [anon_sym_override] = ACTIONS(1158),
    [anon_sym_module] = ACTIONS(1158),
    [anon_sym_any] = ACTIONS(1174),
    [anon_sym_number] = ACTIONS(1174),
    [anon_sym_boolean] = ACTIONS(1174),
    [anon_sym_string] = ACTIONS(1174),
    [anon_sym_symbol] = ACTIONS(1174),
    [anon_sym_object] = ACTIONS(1174),
    [anon_sym_abstract] = ACTIONS(208),
    [anon_sym_infer] = ACTIONS(210),
    [anon_sym_keyof] = ACTIONS(212),
    [anon_sym_unique] = ACTIONS(214),
    [anon_sym_unknown] = ACTIONS(216),
    [anon_sym_never] = ACTIONS(216),
    [anon_sym_LBRACE_PIPE] = ACTIONS(218),
    [sym_html_comment] = ACTIONS(5),
  },
  [155] = {
    [sym_import] = STATE(3570),
    [sym_parenthesized_expression] = STATE(1457),
    [sym_expression] = STATE(2393),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5823),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5823),
    [sym_nested_identifier] = STATE(5474),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5477),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1457),
    [sym_subscript_expression] = STATE(1457),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(2986),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5823),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(2226),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(4087),
    [sym_non_null_expression] = STATE(1457),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_nested_type_identifier] = STATE(2939),
    [sym__type_query_member_expression_in_type_annotation] = STATE(2937),
    [sym__type_query_call_expression_in_type_annotation] = STATE(2938),
    [sym_type] = STATE(3788),
    [sym_constructor_type] = STATE(3007),
    [sym_primary_type] = STATE(2981),
    [sym_template_literal_type] = STATE(3039),
    [sym_infer_type] = STATE(3007),
    [sym_conditional_type] = STATE(3039),
    [sym_generic_type] = STATE(3039),
    [sym_type_query] = STATE(3039),
    [sym_index_type_query] = STATE(3039),
    [sym_lookup_type] = STATE(3039),
    [sym_literal_type] = STATE(3039),
    [sym__number] = STATE(3041),
    [sym_existential_type] = STATE(3039),
    [sym_flow_maybe_type] = STATE(3039),
    [sym_parenthesized_type] = STATE(3039),
    [sym_predefined_type] = STATE(3039),
    [sym_type_arguments] = STATE(620),
    [sym_object_type] = STATE(3039),
    [sym_type_parameters] = STATE(5158),
    [sym_array_type] = STATE(3039),
    [sym_tuple_type] = STATE(3039),
    [sym_readonly_type] = STATE(3007),
    [sym_union_type] = STATE(3039),
    [sym_intersection_type] = STATE(3039),
    [sym_function_type] = STATE(3007),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1176),
    [anon_sym_export] = ACTIONS(1178),
    [anon_sym_STAR] = ACTIONS(543),
    [anon_sym_type] = ACTIONS(1178),
    [anon_sym_namespace] = ACTIONS(1180),
    [anon_sym_LBRACE] = ACTIONS(1182),
    [anon_sym_typeof] = ACTIONS(1184),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1178),
    [anon_sym_const] = ACTIONS(133),
    [anon_sym_BANG] = ACTIONS(1186),
    [anon_sym_LPAREN] = ACTIONS(138),
    [anon_sym_await] = ACTIONS(1188),
    [anon_sym_yield] = ACTIONS(1190),
    [anon_sym_LBRACK] = ACTIONS(1088),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1192),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1194),
    [anon_sym_using] = ACTIONS(1196),
    [anon_sym_AMP] = ACTIONS(748),
    [anon_sym_PIPE] = ACTIONS(750),
    [anon_sym_PLUS] = ACTIONS(1198),
    [anon_sym_DASH] = ACTIONS(1198),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(1186),
    [anon_sym_void] = ACTIONS(1200),
    [anon_sym_delete] = ACTIONS(1202),
    [anon_sym_PLUS_PLUS] = ACTIONS(1204),
    [anon_sym_DASH_DASH] = ACTIONS(1204),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1104),
    [sym_number] = ACTIONS(1106),
    [sym_private_property_identifier] = ACTIONS(1206),
    [sym_this] = ACTIONS(1110),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(1112),
    [sym_false] = ACTIONS(1112),
    [sym_null] = ACTIONS(1112),
    [sym_undefined] = ACTIONS(1208),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1178),
    [anon_sym_readonly] = ACTIONS(1210),
    [anon_sym_get] = ACTIONS(1178),
    [anon_sym_set] = ACTIONS(1178),
    [anon_sym_QMARK] = ACTIONS(774),
    [anon_sym_declare] = ACTIONS(1178),
    [anon_sym_public] = ACTIONS(1178),
    [anon_sym_private] = ACTIONS(1178),
    [anon_sym_protected] = ACTIONS(1178),
    [anon_sym_override] = ACTIONS(1178),
    [anon_sym_module] = ACTIONS(1178),
    [anon_sym_any] = ACTIONS(1212),
    [anon_sym_number] = ACTIONS(1212),
    [anon_sym_boolean] = ACTIONS(1212),
    [anon_sym_string] = ACTIONS(1212),
    [anon_sym_symbol] = ACTIONS(1212),
    [anon_sym_object] = ACTIONS(1212),
    [anon_sym_abstract] = ACTIONS(208),
    [anon_sym_infer] = ACTIONS(210),
    [anon_sym_keyof] = ACTIONS(212),
    [anon_sym_unique] = ACTIONS(214),
    [anon_sym_unknown] = ACTIONS(216),
    [anon_sym_never] = ACTIONS(216),
    [anon_sym_LBRACE_PIPE] = ACTIONS(218),
    [sym_html_comment] = ACTIONS(5),
  },
  [156] = {
    [sym_import] = STATE(3593),
    [sym_parenthesized_expression] = STATE(1322),
    [sym_expression] = STATE(2312),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(4276),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(4276),
    [sym_nested_identifier] = STATE(5474),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5508),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1363),
    [sym_subscript_expression] = STATE(1363),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3003),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(4276),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(2213),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(4087),
    [sym_non_null_expression] = STATE(1363),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_nested_type_identifier] = STATE(2939),
    [sym__type_query_member_expression_in_type_annotation] = STATE(2937),
    [sym__type_query_call_expression_in_type_annotation] = STATE(2938),
    [sym_type] = STATE(4129),
    [sym_constructor_type] = STATE(3007),
    [sym_primary_type] = STATE(2981),
    [sym_template_literal_type] = STATE(3039),
    [sym_infer_type] = STATE(3007),
    [sym_conditional_type] = STATE(3039),
    [sym_generic_type] = STATE(3039),
    [sym_type_query] = STATE(3039),
    [sym_index_type_query] = STATE(3039),
    [sym_lookup_type] = STATE(3039),
    [sym_literal_type] = STATE(3039),
    [sym__number] = STATE(3041),
    [sym_existential_type] = STATE(3039),
    [sym_flow_maybe_type] = STATE(3039),
    [sym_parenthesized_type] = STATE(3039),
    [sym_predefined_type] = STATE(3039),
    [sym_type_arguments] = STATE(484),
    [sym_object_type] = STATE(3039),
    [sym_type_parameters] = STATE(5158),
    [sym_array_type] = STATE(3039),
    [sym_tuple_type] = STATE(3039),
    [sym_readonly_type] = STATE(3007),
    [sym_union_type] = STATE(3039),
    [sym_intersection_type] = STATE(3039),
    [sym_function_type] = STATE(3007),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1214),
    [anon_sym_export] = ACTIONS(1216),
    [anon_sym_STAR] = ACTIONS(543),
    [anon_sym_type] = ACTIONS(1216),
    [anon_sym_namespace] = ACTIONS(1218),
    [anon_sym_LBRACE] = ACTIONS(1220),
    [anon_sym_typeof] = ACTIONS(551),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1216),
    [anon_sym_const] = ACTIONS(133),
    [anon_sym_BANG] = ACTIONS(553),
    [anon_sym_LPAREN] = ACTIONS(138),
    [anon_sym_await] = ACTIONS(555),
    [anon_sym_yield] = ACTIONS(557),
    [anon_sym_LBRACK] = ACTIONS(559),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1222),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1224),
    [anon_sym_using] = ACTIONS(567),
    [anon_sym_AMP] = ACTIONS(748),
    [anon_sym_PIPE] = ACTIONS(750),
    [anon_sym_PLUS] = ACTIONS(575),
    [anon_sym_DASH] = ACTIONS(575),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(553),
    [anon_sym_void] = ACTIONS(579),
    [anon_sym_delete] = ACTIONS(581),
    [anon_sym_PLUS_PLUS] = ACTIONS(583),
    [anon_sym_DASH_DASH] = ACTIONS(583),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(188),
    [sym_number] = ACTIONS(190),
    [sym_private_property_identifier] = ACTIONS(585),
    [sym_this] = ACTIONS(587),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(198),
    [sym_false] = ACTIONS(198),
    [sym_null] = ACTIONS(198),
    [sym_undefined] = ACTIONS(1226),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1216),
    [anon_sym_readonly] = ACTIONS(1228),
    [anon_sym_get] = ACTIONS(1216),
    [anon_sym_set] = ACTIONS(1216),
    [anon_sym_QMARK] = ACTIONS(774),
    [anon_sym_declare] = ACTIONS(1216),
    [anon_sym_public] = ACTIONS(1216),
    [anon_sym_private] = ACTIONS(1216),
    [anon_sym_protected] = ACTIONS(1216),
    [anon_sym_override] = ACTIONS(1216),
    [anon_sym_module] = ACTIONS(1216),
    [anon_sym_any] = ACTIONS(1230),
    [anon_sym_number] = ACTIONS(1230),
    [anon_sym_boolean] = ACTIONS(1230),
    [anon_sym_string] = ACTIONS(1230),
    [anon_sym_symbol] = ACTIONS(1230),
    [anon_sym_object] = ACTIONS(1230),
    [anon_sym_abstract] = ACTIONS(208),
    [anon_sym_infer] = ACTIONS(210),
    [anon_sym_keyof] = ACTIONS(212),
    [anon_sym_unique] = ACTIONS(214),
    [anon_sym_unknown] = ACTIONS(216),
    [anon_sym_never] = ACTIONS(216),
    [anon_sym_LBRACE_PIPE] = ACTIONS(218),
    [sym_html_comment] = ACTIONS(5),
  },
  [157] = {
    [sym_import] = STATE(3508),
    [sym_parenthesized_expression] = STATE(1456),
    [sym_expression] = STATE(2479),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5815),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5815),
    [sym_nested_identifier] = STATE(5474),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5755),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1456),
    [sym_subscript_expression] = STATE(1456),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3029),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5815),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(2226),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(4087),
    [sym_non_null_expression] = STATE(1456),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_nested_type_identifier] = STATE(2939),
    [sym__type_query_member_expression_in_type_annotation] = STATE(2937),
    [sym__type_query_call_expression_in_type_annotation] = STATE(2938),
    [sym_type] = STATE(3788),
    [sym_constructor_type] = STATE(3007),
    [sym_primary_type] = STATE(2981),
    [sym_template_literal_type] = STATE(3039),
    [sym_infer_type] = STATE(3007),
    [sym_conditional_type] = STATE(3039),
    [sym_generic_type] = STATE(3039),
    [sym_type_query] = STATE(3039),
    [sym_index_type_query] = STATE(3039),
    [sym_lookup_type] = STATE(3039),
    [sym_literal_type] = STATE(3039),
    [sym__number] = STATE(3041),
    [sym_existential_type] = STATE(3039),
    [sym_flow_maybe_type] = STATE(3039),
    [sym_parenthesized_type] = STATE(3039),
    [sym_predefined_type] = STATE(3039),
    [sym_type_arguments] = STATE(594),
    [sym_object_type] = STATE(3039),
    [sym_type_parameters] = STATE(5158),
    [sym_array_type] = STATE(3039),
    [sym_tuple_type] = STATE(3039),
    [sym_readonly_type] = STATE(3007),
    [sym_union_type] = STATE(3039),
    [sym_intersection_type] = STATE(3039),
    [sym_function_type] = STATE(3007),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1232),
    [anon_sym_export] = ACTIONS(1234),
    [anon_sym_STAR] = ACTIONS(543),
    [anon_sym_type] = ACTIONS(1234),
    [anon_sym_namespace] = ACTIONS(1236),
    [anon_sym_LBRACE] = ACTIONS(1182),
    [anon_sym_typeof] = ACTIONS(1238),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1234),
    [anon_sym_const] = ACTIONS(133),
    [anon_sym_BANG] = ACTIONS(1240),
    [anon_sym_LPAREN] = ACTIONS(138),
    [anon_sym_await] = ACTIONS(1242),
    [anon_sym_yield] = ACTIONS(1244),
    [anon_sym_LBRACK] = ACTIONS(1088),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1246),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1248),
    [anon_sym_using] = ACTIONS(1250),
    [anon_sym_AMP] = ACTIONS(748),
    [anon_sym_PIPE] = ACTIONS(750),
    [anon_sym_PLUS] = ACTIONS(1252),
    [anon_sym_DASH] = ACTIONS(1252),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(1240),
    [anon_sym_void] = ACTIONS(1254),
    [anon_sym_delete] = ACTIONS(1256),
    [anon_sym_PLUS_PLUS] = ACTIONS(1258),
    [anon_sym_DASH_DASH] = ACTIONS(1258),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1104),
    [sym_number] = ACTIONS(1106),
    [sym_private_property_identifier] = ACTIONS(1260),
    [sym_this] = ACTIONS(1110),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(1112),
    [sym_false] = ACTIONS(1112),
    [sym_null] = ACTIONS(1112),
    [sym_undefined] = ACTIONS(1262),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1234),
    [anon_sym_readonly] = ACTIONS(1264),
    [anon_sym_get] = ACTIONS(1234),
    [anon_sym_set] = ACTIONS(1234),
    [anon_sym_QMARK] = ACTIONS(774),
    [anon_sym_declare] = ACTIONS(1234),
    [anon_sym_public] = ACTIONS(1234),
    [anon_sym_private] = ACTIONS(1234),
    [anon_sym_protected] = ACTIONS(1234),
    [anon_sym_override] = ACTIONS(1234),
    [anon_sym_module] = ACTIONS(1234),
    [anon_sym_any] = ACTIONS(1266),
    [anon_sym_number] = ACTIONS(1266),
    [anon_sym_boolean] = ACTIONS(1266),
    [anon_sym_string] = ACTIONS(1266),
    [anon_sym_symbol] = ACTIONS(1266),
    [anon_sym_object] = ACTIONS(1266),
    [anon_sym_abstract] = ACTIONS(208),
    [anon_sym_infer] = ACTIONS(210),
    [anon_sym_keyof] = ACTIONS(212),
    [anon_sym_unique] = ACTIONS(214),
    [anon_sym_unknown] = ACTIONS(216),
    [anon_sym_never] = ACTIONS(216),
    [anon_sym_LBRACE_PIPE] = ACTIONS(218),
    [sym_html_comment] = ACTIONS(5),
  },
  [158] = {
    [sym_import] = STATE(3543),
    [sym_parenthesized_expression] = STATE(1410),
    [sym_expression] = STATE(2141),
    [sym_primary_expression] = STATE(1810),
    [sym_yield_expression] = STATE(2358),
    [sym_object] = STATE(2222),
    [sym_object_pattern] = STATE(5580),
    [sym_array] = STATE(2222),
    [sym_array_pattern] = STATE(5580),
    [sym_nested_identifier] = STATE(5474),
    [sym_class] = STATE(2222),
    [sym_function_expression] = STATE(2222),
    [sym_generator_function] = STATE(2222),
    [sym_arrow_function] = STATE(2222),
    [sym__call_signature] = STATE(5466),
    [sym_call_expression] = STATE(2222),
    [sym_new_expression] = STATE(1948),
    [sym_await_expression] = STATE(2358),
    [sym_member_expression] = STATE(1410),
    [sym_subscript_expression] = STATE(1410),
    [sym_assignment_expression] = STATE(2358),
    [sym__augmented_assignment_lhs] = STATE(3004),
    [sym_augmented_assignment_expression] = STATE(2358),
    [sym__destructuring_pattern] = STATE(5580),
    [sym_ternary_expression] = STATE(2358),
    [sym_binary_expression] = STATE(2358),
    [sym_unary_expression] = STATE(2358),
    [sym_update_expression] = STATE(2358),
    [sym_string] = STATE(2476),
    [sym_template_string] = STATE(2222),
    [sym_regex] = STATE(2222),
    [sym_meta_property] = STATE(2222),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(4087),
    [sym_non_null_expression] = STATE(1410),
    [sym_type_assertion] = STATE(2358),
    [sym_as_expression] = STATE(2358),
    [sym_satisfies_expression] = STATE(2358),
    [sym_instantiation_expression] = STATE(2358),
    [sym_internal_module] = STATE(2358),
    [sym_nested_type_identifier] = STATE(2939),
    [sym__type_query_member_expression_in_type_annotation] = STATE(2937),
    [sym__type_query_call_expression_in_type_annotation] = STATE(2938),
    [sym_type] = STATE(3784),
    [sym_constructor_type] = STATE(3007),
    [sym_primary_type] = STATE(2981),
    [sym_template_literal_type] = STATE(3039),
    [sym_infer_type] = STATE(3007),
    [sym_conditional_type] = STATE(3039),
    [sym_generic_type] = STATE(3039),
    [sym_type_query] = STATE(3039),
    [sym_index_type_query] = STATE(3039),
    [sym_lookup_type] = STATE(3039),
    [sym_literal_type] = STATE(3039),
    [sym__number] = STATE(3041),
    [sym_existential_type] = STATE(3039),
    [sym_flow_maybe_type] = STATE(3039),
    [sym_parenthesized_type] = STATE(3039),
    [sym_predefined_type] = STATE(3039),
    [sym_type_arguments] = STATE(452),
    [sym_object_type] = STATE(3039),
    [sym_type_parameters] = STATE(5158),
    [sym_array_type] = STATE(3039),
    [sym_tuple_type] = STATE(3039),
    [sym_readonly_type] = STATE(3007),
    [sym_union_type] = STATE(3039),
    [sym_intersection_type] = STATE(3039),
    [sym_function_type] = STATE(3007),
    [aux_sym_export_statement_repeat1] = STATE(4408),
    [sym_identifier] = ACTIONS(1268),
    [anon_sym_export] = ACTIONS(1270),
    [anon_sym_STAR] = ACTIONS(543),
    [anon_sym_type] = ACTIONS(1270),
    [anon_sym_namespace] = ACTIONS(1272),
    [anon_sym_LBRACE] = ACTIONS(1274),
    [anon_sym_typeof] = ACTIONS(1276),
    [anon_sym_import] = ACTIONS(669),
    [anon_sym_let] = ACTIONS(1270),
    [anon_sym_const] = ACTIONS(133),
    [anon_sym_BANG] = ACTIONS(1278),
    [anon_sym_LPAREN] = ACTIONS(1280),
    [anon_sym_await] = ACTIONS(1282),
    [anon_sym_yield] = ACTIONS(1284),
    [anon_sym_LBRACK] = ACTIONS(1286),
    [anon_sym_class] = ACTIONS(676),
    [anon_sym_async] = ACTIONS(1288),
    [anon_sym_function] = ACTIONS(680),
    [anon_sym_new] = ACTIONS(1290),
    [anon_sym_using] = ACTIONS(1292),
    [anon_sym_AMP] = ACTIONS(748),
    [anon_sym_PIPE] = ACTIONS(750),
    [anon_sym_PLUS] = ACTIONS(1294),
    [anon_sym_DASH] = ACTIONS(1294),
    [anon_sym_SLASH] = ACTIONS(77),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(1278),
    [anon_sym_void] = ACTIONS(1296),
    [anon_sym_delete] = ACTIONS(1298),
    [anon_sym_PLUS_PLUS] = ACTIONS(1300),
    [anon_sym_DASH_DASH] = ACTIONS(1300),
    [anon_sym_DQUOTE] = ACTIONS(83),
    [anon_sym_SQUOTE] = ACTIONS(85),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1302),
    [sym_number] = ACTIONS(1304),
    [sym_private_property_identifier] = ACTIONS(1306),
    [sym_this] = ACTIONS(1308),
    [sym_super] = ACTIONS(93),
    [sym_true] = ACTIONS(1310),
    [sym_false] = ACTIONS(1310),
    [sym_null] = ACTIONS(1310),
    [sym_undefined] = ACTIONS(1312),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1270),
    [anon_sym_readonly] = ACTIONS(1314),
    [anon_sym_get] = ACTIONS(1270),
    [anon_sym_set] = ACTIONS(1270),
    [anon_sym_QMARK] = ACTIONS(774),
    [anon_sym_declare] = ACTIONS(1270),
    [anon_sym_public] = ACTIONS(1270),
    [anon_sym_private] = ACTIONS(1270),
    [anon_sym_protected] = ACTIONS(1270),
    [anon_sym_override] = ACTIONS(1270),
    [anon_sym_module] = ACTIONS(1270),
    [anon_sym_any] = ACTIONS(1316),
    [anon_sym_number] = ACTIONS(1316),
    [anon_sym_boolean] = ACTIONS(1316),
    [anon_sym_string] = ACTIONS(1316),
    [anon_sym_symbol] = ACTIONS(1316),
    [anon_sym_object] = ACTIONS(1316),
    [anon_sym_abstract] = ACTIONS(208),
    [anon_sym_infer] = ACTIONS(210),
    [anon_sym_keyof] = ACTIONS(212),
    [anon_sym_unique] = ACTIONS(214),
    [anon_sym_unknown] = ACTIONS(216),
    [anon_sym_never] = ACTIONS(216),
    [anon_sym_LBRACE_PIPE] = ACTIONS(218),
    [sym_html_comment] = ACTIONS(5),
  },
  [159] = {
    [sym_import] = STATE(3508),
    [sym_parenthesized_expression] = STATE(1213),
    [sym_expression] = STATE(2644),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(3654),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(3654),
    [sym_nested_identifier] = STATE(5474),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5800),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1446),
    [sym_subscript_expression] = STATE(1446),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3013),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(3654),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(2567),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(4087),
    [sym_non_null_expression] = STATE(1446),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_nested_type_identifier] = STATE(2939),
    [sym__type_query_member_expression_in_type_annotation] = STATE(2937),
    [sym__type_query_call_expression_in_type_annotation] = STATE(2938),
    [sym_type] = STATE(4129),
    [sym_constructor_type] = STATE(3007),
    [sym_primary_type] = STATE(2981),
    [sym_template_literal_type] = STATE(3039),
    [sym_infer_type] = STATE(3007),
    [sym_conditional_type] = STATE(3039),
    [sym_generic_type] = STATE(3039),
    [sym_type_query] = STATE(3039),
    [sym_index_type_query] = STATE(3039),
    [sym_lookup_type] = STATE(3039),
    [sym_literal_type] = STATE(3039),
    [sym__number] = STATE(3041),
    [sym_existential_type] = STATE(3039),
    [sym_flow_maybe_type] = STATE(3039),
    [sym_parenthesized_type] = STATE(3039),
    [sym_predefined_type] = STATE(3039),
    [sym_type_arguments] = STATE(539),
    [sym_object_type] = STATE(3039),
    [sym_type_parameters] = STATE(5158),
    [sym_array_type] = STATE(3039),
    [sym_tuple_type] = STATE(3039),
    [sym_readonly_type] = STATE(3007),
    [sym_union_type] = STATE(3039),
    [sym_intersection_type] = STATE(3039),
    [sym_function_type] = STATE(3007),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1318),
    [anon_sym_export] = ACTIONS(1320),
    [anon_sym_STAR] = ACTIONS(543),
    [anon_sym_type] = ACTIONS(1320),
    [anon_sym_namespace] = ACTIONS(1322),
    [anon_sym_LBRACE] = ACTIONS(1324),
    [anon_sym_typeof] = ACTIONS(1326),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1320),
    [anon_sym_const] = ACTIONS(133),
    [anon_sym_BANG] = ACTIONS(175),
    [anon_sym_LPAREN] = ACTIONS(138),
    [anon_sym_await] = ACTIONS(140),
    [anon_sym_yield] = ACTIONS(142),
    [anon_sym_LBRACK] = ACTIONS(1328),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1330),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1332),
    [anon_sym_using] = ACTIONS(158),
    [anon_sym_AMP] = ACTIONS(748),
    [anon_sym_PIPE] = ACTIONS(750),
    [anon_sym_PLUS] = ACTIONS(1334),
    [anon_sym_DASH] = ACTIONS(1334),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(175),
    [anon_sym_void] = ACTIONS(177),
    [anon_sym_delete] = ACTIONS(179),
    [anon_sym_PLUS_PLUS] = ACTIONS(686),
    [anon_sym_DASH_DASH] = ACTIONS(686),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1336),
    [sym_number] = ACTIONS(1338),
    [sym_private_property_identifier] = ACTIONS(192),
    [sym_this] = ACTIONS(1340),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(1342),
    [sym_false] = ACTIONS(1342),
    [sym_null] = ACTIONS(1342),
    [sym_undefined] = ACTIONS(1344),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1320),
    [anon_sym_readonly] = ACTIONS(1346),
    [anon_sym_get] = ACTIONS(1320),
    [anon_sym_set] = ACTIONS(1320),
    [anon_sym_QMARK] = ACTIONS(774),
    [anon_sym_declare] = ACTIONS(1320),
    [anon_sym_public] = ACTIONS(1320),
    [anon_sym_private] = ACTIONS(1320),
    [anon_sym_protected] = ACTIONS(1320),
    [anon_sym_override] = ACTIONS(1320),
    [anon_sym_module] = ACTIONS(1320),
    [anon_sym_any] = ACTIONS(1348),
    [anon_sym_number] = ACTIONS(1348),
    [anon_sym_boolean] = ACTIONS(1348),
    [anon_sym_string] = ACTIONS(1348),
    [anon_sym_symbol] = ACTIONS(1348),
    [anon_sym_object] = ACTIONS(1348),
    [anon_sym_abstract] = ACTIONS(208),
    [anon_sym_infer] = ACTIONS(210),
    [anon_sym_keyof] = ACTIONS(212),
    [anon_sym_unique] = ACTIONS(214),
    [anon_sym_unknown] = ACTIONS(216),
    [anon_sym_never] = ACTIONS(216),
    [anon_sym_LBRACE_PIPE] = ACTIONS(218),
    [sym_html_comment] = ACTIONS(5),
  },
  [160] = {
    [sym_import] = STATE(3695),
    [sym_parenthesized_expression] = STATE(1362),
    [sym_expression] = STATE(1791),
    [sym_primary_expression] = STATE(1810),
    [sym_yield_expression] = STATE(2358),
    [sym_object] = STATE(2222),
    [sym_object_pattern] = STATE(5492),
    [sym_array] = STATE(2222),
    [sym_array_pattern] = STATE(5492),
    [sym_nested_identifier] = STATE(5474),
    [sym_class] = STATE(2222),
    [sym_function_expression] = STATE(2222),
    [sym_generator_function] = STATE(2222),
    [sym_arrow_function] = STATE(2222),
    [sym__call_signature] = STATE(5821),
    [sym_call_expression] = STATE(2222),
    [sym_new_expression] = STATE(1948),
    [sym_await_expression] = STATE(2358),
    [sym_member_expression] = STATE(1362),
    [sym_subscript_expression] = STATE(1362),
    [sym_assignment_expression] = STATE(2358),
    [sym__augmented_assignment_lhs] = STATE(3025),
    [sym_augmented_assignment_expression] = STATE(2358),
    [sym__destructuring_pattern] = STATE(5492),
    [sym_ternary_expression] = STATE(2358),
    [sym_binary_expression] = STATE(2358),
    [sym_unary_expression] = STATE(2358),
    [sym_update_expression] = STATE(2358),
    [sym_string] = STATE(1980),
    [sym_template_string] = STATE(2222),
    [sym_regex] = STATE(2222),
    [sym_meta_property] = STATE(2222),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(4087),
    [sym_non_null_expression] = STATE(1362),
    [sym_type_assertion] = STATE(2358),
    [sym_as_expression] = STATE(2358),
    [sym_satisfies_expression] = STATE(2358),
    [sym_instantiation_expression] = STATE(2358),
    [sym_internal_module] = STATE(2358),
    [sym_nested_type_identifier] = STATE(2939),
    [sym__type_query_member_expression_in_type_annotation] = STATE(2937),
    [sym__type_query_call_expression_in_type_annotation] = STATE(2938),
    [sym_type] = STATE(3784),
    [sym_constructor_type] = STATE(3007),
    [sym_primary_type] = STATE(2981),
    [sym_template_literal_type] = STATE(3039),
    [sym_infer_type] = STATE(3007),
    [sym_conditional_type] = STATE(3039),
    [sym_generic_type] = STATE(3039),
    [sym_type_query] = STATE(3039),
    [sym_index_type_query] = STATE(3039),
    [sym_lookup_type] = STATE(3039),
    [sym_literal_type] = STATE(3039),
    [sym__number] = STATE(3041),
    [sym_existential_type] = STATE(3039),
    [sym_flow_maybe_type] = STATE(3039),
    [sym_parenthesized_type] = STATE(3039),
    [sym_predefined_type] = STATE(3039),
    [sym_type_arguments] = STATE(428),
    [sym_object_type] = STATE(3039),
    [sym_type_parameters] = STATE(5158),
    [sym_array_type] = STATE(3039),
    [sym_tuple_type] = STATE(3039),
    [sym_readonly_type] = STATE(3007),
    [sym_union_type] = STATE(3039),
    [sym_intersection_type] = STATE(3039),
    [sym_function_type] = STATE(3007),
    [aux_sym_export_statement_repeat1] = STATE(4408),
    [sym_identifier] = ACTIONS(1350),
    [anon_sym_export] = ACTIONS(1352),
    [anon_sym_STAR] = ACTIONS(543),
    [anon_sym_type] = ACTIONS(1352),
    [anon_sym_namespace] = ACTIONS(1354),
    [anon_sym_LBRACE] = ACTIONS(1356),
    [anon_sym_typeof] = ACTIONS(1358),
    [anon_sym_import] = ACTIONS(669),
    [anon_sym_let] = ACTIONS(1352),
    [anon_sym_const] = ACTIONS(133),
    [anon_sym_BANG] = ACTIONS(33),
    [anon_sym_LPAREN] = ACTIONS(1280),
    [anon_sym_await] = ACTIONS(45),
    [anon_sym_yield] = ACTIONS(63),
    [anon_sym_LBRACK] = ACTIONS(1360),
    [anon_sym_class] = ACTIONS(676),
    [anon_sym_async] = ACTIONS(1362),
    [anon_sym_function] = ACTIONS(680),
    [anon_sym_new] = ACTIONS(1364),
    [anon_sym_using] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(748),
    [anon_sym_PIPE] = ACTIONS(750),
    [anon_sym_PLUS] = ACTIONS(1366),
    [anon_sym_DASH] = ACTIONS(1366),
    [anon_sym_SLASH] = ACTIONS(77),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(33),
    [anon_sym_void] = ACTIONS(1368),
    [anon_sym_delete] = ACTIONS(21),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_DQUOTE] = ACTIONS(83),
    [anon_sym_SQUOTE] = ACTIONS(85),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1370),
    [sym_number] = ACTIONS(1372),
    [sym_private_property_identifier] = ACTIONS(91),
    [sym_this] = ACTIONS(1374),
    [sym_super] = ACTIONS(93),
    [sym_true] = ACTIONS(1376),
    [sym_false] = ACTIONS(1376),
    [sym_null] = ACTIONS(1376),
    [sym_undefined] = ACTIONS(1378),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1352),
    [anon_sym_readonly] = ACTIONS(1380),
    [anon_sym_get] = ACTIONS(1352),
    [anon_sym_set] = ACTIONS(1352),
    [anon_sym_QMARK] = ACTIONS(774),
    [anon_sym_declare] = ACTIONS(1352),
    [anon_sym_public] = ACTIONS(1352),
    [anon_sym_private] = ACTIONS(1352),
    [anon_sym_protected] = ACTIONS(1352),
    [anon_sym_override] = ACTIONS(1352),
    [anon_sym_module] = ACTIONS(1352),
    [anon_sym_any] = ACTIONS(1382),
    [anon_sym_number] = ACTIONS(1382),
    [anon_sym_boolean] = ACTIONS(1382),
    [anon_sym_string] = ACTIONS(1382),
    [anon_sym_symbol] = ACTIONS(1382),
    [anon_sym_object] = ACTIONS(1382),
    [anon_sym_abstract] = ACTIONS(208),
    [anon_sym_infer] = ACTIONS(210),
    [anon_sym_keyof] = ACTIONS(212),
    [anon_sym_unique] = ACTIONS(214),
    [anon_sym_unknown] = ACTIONS(216),
    [anon_sym_never] = ACTIONS(216),
    [anon_sym_LBRACE_PIPE] = ACTIONS(218),
    [sym_html_comment] = ACTIONS(5),
  },
  [161] = {
    [sym_import] = STATE(3695),
    [sym_parenthesized_expression] = STATE(1364),
    [sym_expression] = STATE(1842),
    [sym_primary_expression] = STATE(1810),
    [sym_yield_expression] = STATE(2358),
    [sym_object] = STATE(2222),
    [sym_object_pattern] = STATE(5773),
    [sym_array] = STATE(2222),
    [sym_array_pattern] = STATE(5773),
    [sym_nested_identifier] = STATE(5474),
    [sym_class] = STATE(2222),
    [sym_function_expression] = STATE(2222),
    [sym_generator_function] = STATE(2222),
    [sym_arrow_function] = STATE(2222),
    [sym__call_signature] = STATE(5771),
    [sym_call_expression] = STATE(2222),
    [sym_new_expression] = STATE(1948),
    [sym_await_expression] = STATE(2358),
    [sym_member_expression] = STATE(1364),
    [sym_subscript_expression] = STATE(1364),
    [sym_assignment_expression] = STATE(2358),
    [sym__augmented_assignment_lhs] = STATE(3020),
    [sym_augmented_assignment_expression] = STATE(2358),
    [sym__destructuring_pattern] = STATE(5773),
    [sym_ternary_expression] = STATE(2358),
    [sym_binary_expression] = STATE(2358),
    [sym_unary_expression] = STATE(2358),
    [sym_update_expression] = STATE(2358),
    [sym_string] = STATE(1980),
    [sym_template_string] = STATE(2222),
    [sym_regex] = STATE(2222),
    [sym_meta_property] = STATE(2222),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(4087),
    [sym_non_null_expression] = STATE(1364),
    [sym_type_assertion] = STATE(2358),
    [sym_as_expression] = STATE(2358),
    [sym_satisfies_expression] = STATE(2358),
    [sym_instantiation_expression] = STATE(2358),
    [sym_internal_module] = STATE(2358),
    [sym_nested_type_identifier] = STATE(2939),
    [sym__type_query_member_expression_in_type_annotation] = STATE(2937),
    [sym__type_query_call_expression_in_type_annotation] = STATE(2938),
    [sym_type] = STATE(3784),
    [sym_constructor_type] = STATE(3007),
    [sym_primary_type] = STATE(2981),
    [sym_template_literal_type] = STATE(3039),
    [sym_infer_type] = STATE(3007),
    [sym_conditional_type] = STATE(3039),
    [sym_generic_type] = STATE(3039),
    [sym_type_query] = STATE(3039),
    [sym_index_type_query] = STATE(3039),
    [sym_lookup_type] = STATE(3039),
    [sym_literal_type] = STATE(3039),
    [sym__number] = STATE(3041),
    [sym_existential_type] = STATE(3039),
    [sym_flow_maybe_type] = STATE(3039),
    [sym_parenthesized_type] = STATE(3039),
    [sym_predefined_type] = STATE(3039),
    [sym_type_arguments] = STATE(513),
    [sym_object_type] = STATE(3039),
    [sym_type_parameters] = STATE(5158),
    [sym_array_type] = STATE(3039),
    [sym_tuple_type] = STATE(3039),
    [sym_readonly_type] = STATE(3007),
    [sym_union_type] = STATE(3039),
    [sym_intersection_type] = STATE(3039),
    [sym_function_type] = STATE(3007),
    [aux_sym_export_statement_repeat1] = STATE(4408),
    [sym_identifier] = ACTIONS(1384),
    [anon_sym_export] = ACTIONS(1386),
    [anon_sym_STAR] = ACTIONS(543),
    [anon_sym_type] = ACTIONS(1386),
    [anon_sym_namespace] = ACTIONS(1388),
    [anon_sym_LBRACE] = ACTIONS(1356),
    [anon_sym_typeof] = ACTIONS(1390),
    [anon_sym_import] = ACTIONS(669),
    [anon_sym_let] = ACTIONS(1386),
    [anon_sym_const] = ACTIONS(133),
    [anon_sym_BANG] = ACTIONS(1392),
    [anon_sym_LPAREN] = ACTIONS(1280),
    [anon_sym_await] = ACTIONS(1394),
    [anon_sym_yield] = ACTIONS(1396),
    [anon_sym_LBRACK] = ACTIONS(1360),
    [anon_sym_class] = ACTIONS(676),
    [anon_sym_async] = ACTIONS(1398),
    [anon_sym_function] = ACTIONS(680),
    [anon_sym_new] = ACTIONS(1400),
    [anon_sym_using] = ACTIONS(1402),
    [anon_sym_AMP] = ACTIONS(748),
    [anon_sym_PIPE] = ACTIONS(750),
    [anon_sym_PLUS] = ACTIONS(1404),
    [anon_sym_DASH] = ACTIONS(1404),
    [anon_sym_SLASH] = ACTIONS(876),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(1392),
    [anon_sym_void] = ACTIONS(1406),
    [anon_sym_delete] = ACTIONS(1408),
    [anon_sym_PLUS_PLUS] = ACTIONS(1410),
    [anon_sym_DASH_DASH] = ACTIONS(1410),
    [anon_sym_DQUOTE] = ACTIONS(83),
    [anon_sym_SQUOTE] = ACTIONS(85),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1370),
    [sym_number] = ACTIONS(1372),
    [sym_private_property_identifier] = ACTIONS(1412),
    [sym_this] = ACTIONS(1374),
    [sym_super] = ACTIONS(93),
    [sym_true] = ACTIONS(1376),
    [sym_false] = ACTIONS(1376),
    [sym_null] = ACTIONS(1376),
    [sym_undefined] = ACTIONS(1414),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1386),
    [anon_sym_readonly] = ACTIONS(1416),
    [anon_sym_get] = ACTIONS(1386),
    [anon_sym_set] = ACTIONS(1386),
    [anon_sym_QMARK] = ACTIONS(774),
    [anon_sym_declare] = ACTIONS(1386),
    [anon_sym_public] = ACTIONS(1386),
    [anon_sym_private] = ACTIONS(1386),
    [anon_sym_protected] = ACTIONS(1386),
    [anon_sym_override] = ACTIONS(1386),
    [anon_sym_module] = ACTIONS(1386),
    [anon_sym_any] = ACTIONS(1418),
    [anon_sym_number] = ACTIONS(1418),
    [anon_sym_boolean] = ACTIONS(1418),
    [anon_sym_string] = ACTIONS(1418),
    [anon_sym_symbol] = ACTIONS(1418),
    [anon_sym_object] = ACTIONS(1418),
    [anon_sym_abstract] = ACTIONS(208),
    [anon_sym_infer] = ACTIONS(210),
    [anon_sym_keyof] = ACTIONS(212),
    [anon_sym_unique] = ACTIONS(214),
    [anon_sym_unknown] = ACTIONS(216),
    [anon_sym_never] = ACTIONS(216),
    [anon_sym_LBRACE_PIPE] = ACTIONS(218),
    [sym_html_comment] = ACTIONS(5),
  },
  [162] = {
    [sym_import] = STATE(3593),
    [sym_parenthesized_expression] = STATE(1387),
    [sym_expression] = STATE(2086),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5803),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5803),
    [sym_nested_identifier] = STATE(5474),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5585),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1387),
    [sym_subscript_expression] = STATE(1387),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3009),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5803),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1707),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(4087),
    [sym_non_null_expression] = STATE(1387),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_nested_type_identifier] = STATE(2939),
    [sym__type_query_member_expression_in_type_annotation] = STATE(2937),
    [sym__type_query_call_expression_in_type_annotation] = STATE(2938),
    [sym_type] = STATE(3788),
    [sym_constructor_type] = STATE(3007),
    [sym_primary_type] = STATE(2981),
    [sym_template_literal_type] = STATE(3039),
    [sym_infer_type] = STATE(3007),
    [sym_conditional_type] = STATE(3039),
    [sym_generic_type] = STATE(3039),
    [sym_type_query] = STATE(3039),
    [sym_index_type_query] = STATE(3039),
    [sym_lookup_type] = STATE(3039),
    [sym_literal_type] = STATE(3039),
    [sym__number] = STATE(3041),
    [sym_existential_type] = STATE(3039),
    [sym_flow_maybe_type] = STATE(3039),
    [sym_parenthesized_type] = STATE(3039),
    [sym_predefined_type] = STATE(3039),
    [sym_type_arguments] = STATE(566),
    [sym_object_type] = STATE(3039),
    [sym_type_parameters] = STATE(5158),
    [sym_array_type] = STATE(3039),
    [sym_tuple_type] = STATE(3039),
    [sym_readonly_type] = STATE(3007),
    [sym_union_type] = STATE(3039),
    [sym_intersection_type] = STATE(3039),
    [sym_function_type] = STATE(3007),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1420),
    [anon_sym_export] = ACTIONS(1422),
    [anon_sym_STAR] = ACTIONS(543),
    [anon_sym_type] = ACTIONS(1422),
    [anon_sym_namespace] = ACTIONS(1424),
    [anon_sym_LBRACE] = ACTIONS(1136),
    [anon_sym_typeof] = ACTIONS(1426),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1422),
    [anon_sym_const] = ACTIONS(133),
    [anon_sym_BANG] = ACTIONS(1428),
    [anon_sym_LPAREN] = ACTIONS(138),
    [anon_sym_await] = ACTIONS(1430),
    [anon_sym_yield] = ACTIONS(1432),
    [anon_sym_LBRACK] = ACTIONS(1140),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1434),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1436),
    [anon_sym_using] = ACTIONS(1438),
    [anon_sym_AMP] = ACTIONS(748),
    [anon_sym_PIPE] = ACTIONS(750),
    [anon_sym_PLUS] = ACTIONS(1440),
    [anon_sym_DASH] = ACTIONS(1440),
    [anon_sym_SLASH] = ACTIONS(942),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(1428),
    [anon_sym_void] = ACTIONS(1442),
    [anon_sym_delete] = ACTIONS(1444),
    [anon_sym_PLUS_PLUS] = ACTIONS(1446),
    [anon_sym_DASH_DASH] = ACTIONS(1446),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1144),
    [sym_number] = ACTIONS(1146),
    [sym_private_property_identifier] = ACTIONS(1448),
    [sym_this] = ACTIONS(1148),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(1150),
    [sym_false] = ACTIONS(1150),
    [sym_null] = ACTIONS(1150),
    [sym_undefined] = ACTIONS(1450),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1422),
    [anon_sym_readonly] = ACTIONS(1452),
    [anon_sym_get] = ACTIONS(1422),
    [anon_sym_set] = ACTIONS(1422),
    [anon_sym_QMARK] = ACTIONS(774),
    [anon_sym_declare] = ACTIONS(1422),
    [anon_sym_public] = ACTIONS(1422),
    [anon_sym_private] = ACTIONS(1422),
    [anon_sym_protected] = ACTIONS(1422),
    [anon_sym_override] = ACTIONS(1422),
    [anon_sym_module] = ACTIONS(1422),
    [anon_sym_any] = ACTIONS(1454),
    [anon_sym_number] = ACTIONS(1454),
    [anon_sym_boolean] = ACTIONS(1454),
    [anon_sym_string] = ACTIONS(1454),
    [anon_sym_symbol] = ACTIONS(1454),
    [anon_sym_object] = ACTIONS(1454),
    [anon_sym_abstract] = ACTIONS(208),
    [anon_sym_infer] = ACTIONS(210),
    [anon_sym_keyof] = ACTIONS(212),
    [anon_sym_unique] = ACTIONS(214),
    [anon_sym_unknown] = ACTIONS(216),
    [anon_sym_never] = ACTIONS(216),
    [anon_sym_LBRACE_PIPE] = ACTIONS(218),
    [sym_html_comment] = ACTIONS(5),
  },
  [163] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1322),
    [sym_expression] = STATE(1778),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5698),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5698),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5508),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1322),
    [sym_subscript_expression] = STATE(1322),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3003),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5698),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1322),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(484),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1456),
    [anon_sym_export] = ACTIONS(1048),
    [anon_sym_STAR] = ACTIONS(1458),
    [anon_sym_type] = ACTIONS(1048),
    [anon_sym_as] = ACTIONS(1460),
    [anon_sym_namespace] = ACTIONS(1050),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_COMMA] = ACTIONS(1462),
    [anon_sym_RBRACE] = ACTIONS(1462),
    [anon_sym_typeof] = ACTIONS(581),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1048),
    [anon_sym_BANG] = ACTIONS(581),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_SEMI] = ACTIONS(1462),
    [anon_sym_await] = ACTIONS(555),
    [anon_sym_in] = ACTIONS(1460),
    [anon_sym_COLON] = ACTIONS(1462),
    [anon_sym_yield] = ACTIONS(557),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_RBRACK] = ACTIONS(1462),
    [anon_sym_DOT] = ACTIONS(1460),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1058),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_QMARK_DOT] = ACTIONS(1462),
    [anon_sym_new] = ACTIONS(1464),
    [anon_sym_using] = ACTIONS(567),
    [anon_sym_AMP_AMP] = ACTIONS(1462),
    [anon_sym_PIPE_PIPE] = ACTIONS(1462),
    [anon_sym_GT_GT] = ACTIONS(1460),
    [anon_sym_GT_GT_GT] = ACTIONS(1462),
    [anon_sym_LT_LT] = ACTIONS(1462),
    [anon_sym_AMP] = ACTIONS(1460),
    [anon_sym_CARET] = ACTIONS(1462),
    [anon_sym_PIPE] = ACTIONS(1460),
    [anon_sym_PLUS] = ACTIONS(581),
    [anon_sym_DASH] = ACTIONS(581),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_PERCENT] = ACTIONS(1462),
    [anon_sym_STAR_STAR] = ACTIONS(1462),
    [anon_sym_LT] = ACTIONS(173),
    [anon_sym_LT_EQ] = ACTIONS(1462),
    [anon_sym_EQ_EQ] = ACTIONS(1460),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(1462),
    [anon_sym_BANG_EQ] = ACTIONS(1460),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(1462),
    [anon_sym_GT_EQ] = ACTIONS(1462),
    [anon_sym_GT] = ACTIONS(1460),
    [anon_sym_QMARK_QMARK] = ACTIONS(1462),
    [anon_sym_instanceof] = ACTIONS(1460),
    [anon_sym_TILDE] = ACTIONS(553),
    [anon_sym_void] = ACTIONS(581),
    [anon_sym_delete] = ACTIONS(581),
    [anon_sym_PLUS_PLUS] = ACTIONS(583),
    [anon_sym_DASH_DASH] = ACTIONS(583),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(585),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1466),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1048),
    [anon_sym_readonly] = ACTIONS(1048),
    [anon_sym_get] = ACTIONS(1048),
    [anon_sym_set] = ACTIONS(1048),
    [anon_sym_declare] = ACTIONS(1048),
    [anon_sym_public] = ACTIONS(1048),
    [anon_sym_private] = ACTIONS(1048),
    [anon_sym_protected] = ACTIONS(1048),
    [anon_sym_override] = ACTIONS(1048),
    [anon_sym_module] = ACTIONS(1048),
    [anon_sym_any] = ACTIONS(1048),
    [anon_sym_number] = ACTIONS(1048),
    [anon_sym_boolean] = ACTIONS(1048),
    [anon_sym_string] = ACTIONS(1048),
    [anon_sym_symbol] = ACTIONS(1048),
    [anon_sym_object] = ACTIONS(1048),
    [anon_sym_satisfies] = ACTIONS(1460),
    [sym__ternary_qmark] = ACTIONS(1462),
    [sym_html_comment] = ACTIONS(5),
  },
  [164] = {
    [sym_import] = STATE(3636),
    [sym_parenthesized_expression] = STATE(1362),
    [sym_expression] = STATE(1823),
    [sym_primary_expression] = STATE(1810),
    [sym_yield_expression] = STATE(2358),
    [sym_object] = STATE(2222),
    [sym_object_pattern] = STATE(5492),
    [sym_array] = STATE(2222),
    [sym_array_pattern] = STATE(5492),
    [sym_class] = STATE(2222),
    [sym_function_expression] = STATE(2222),
    [sym_generator_function] = STATE(2222),
    [sym_arrow_function] = STATE(2222),
    [sym__call_signature] = STATE(5821),
    [sym_call_expression] = STATE(2222),
    [sym_new_expression] = STATE(1948),
    [sym_await_expression] = STATE(2358),
    [sym_member_expression] = STATE(1362),
    [sym_subscript_expression] = STATE(1362),
    [sym_assignment_expression] = STATE(2358),
    [sym__augmented_assignment_lhs] = STATE(3025),
    [sym_augmented_assignment_expression] = STATE(2358),
    [sym__destructuring_pattern] = STATE(5492),
    [sym_ternary_expression] = STATE(2358),
    [sym_binary_expression] = STATE(2358),
    [sym_unary_expression] = STATE(2358),
    [sym_update_expression] = STATE(2358),
    [sym_string] = STATE(2222),
    [sym_template_string] = STATE(2222),
    [sym_regex] = STATE(2222),
    [sym_meta_property] = STATE(2222),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1362),
    [sym_type_assertion] = STATE(2358),
    [sym_as_expression] = STATE(2358),
    [sym_satisfies_expression] = STATE(2358),
    [sym_instantiation_expression] = STATE(2358),
    [sym_internal_module] = STATE(2358),
    [sym_type_arguments] = STATE(428),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4408),
    [sym_identifier] = ACTIONS(1468),
    [anon_sym_export] = ACTIONS(1352),
    [anon_sym_STAR] = ACTIONS(1470),
    [anon_sym_type] = ACTIONS(1352),
    [anon_sym_as] = ACTIONS(1460),
    [anon_sym_namespace] = ACTIONS(1354),
    [anon_sym_LBRACE] = ACTIONS(665),
    [anon_sym_COMMA] = ACTIONS(1462),
    [anon_sym_RBRACE] = ACTIONS(1462),
    [anon_sym_typeof] = ACTIONS(21),
    [anon_sym_import] = ACTIONS(669),
    [anon_sym_let] = ACTIONS(1352),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_SEMI] = ACTIONS(1462),
    [anon_sym_await] = ACTIONS(45),
    [anon_sym_in] = ACTIONS(1460),
    [anon_sym_yield] = ACTIONS(63),
    [anon_sym_LBRACK] = ACTIONS(65),
    [anon_sym_DOT] = ACTIONS(1460),
    [anon_sym_class] = ACTIONS(676),
    [anon_sym_async] = ACTIONS(1362),
    [anon_sym_function] = ACTIONS(680),
    [anon_sym_QMARK_DOT] = ACTIONS(1462),
    [anon_sym_new] = ACTIONS(1472),
    [anon_sym_using] = ACTIONS(75),
    [anon_sym_AMP_AMP] = ACTIONS(1462),
    [anon_sym_PIPE_PIPE] = ACTIONS(1462),
    [anon_sym_GT_GT] = ACTIONS(1460),
    [anon_sym_GT_GT_GT] = ACTIONS(1462),
    [anon_sym_LT_LT] = ACTIONS(1462),
    [anon_sym_AMP] = ACTIONS(1460),
    [anon_sym_CARET] = ACTIONS(1462),
    [anon_sym_PIPE] = ACTIONS(1460),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_SLASH] = ACTIONS(77),
    [anon_sym_PERCENT] = ACTIONS(1462),
    [anon_sym_STAR_STAR] = ACTIONS(1462),
    [anon_sym_LT] = ACTIONS(173),
    [anon_sym_LT_EQ] = ACTIONS(1462),
    [anon_sym_EQ_EQ] = ACTIONS(1460),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(1462),
    [anon_sym_BANG_EQ] = ACTIONS(1460),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(1462),
    [anon_sym_GT_EQ] = ACTIONS(1462),
    [anon_sym_GT] = ACTIONS(1460),
    [anon_sym_QMARK_QMARK] = ACTIONS(1462),
    [anon_sym_instanceof] = ACTIONS(1460),
    [anon_sym_TILDE] = ACTIONS(33),
    [anon_sym_void] = ACTIONS(21),
    [anon_sym_delete] = ACTIONS(21),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_DQUOTE] = ACTIONS(83),
    [anon_sym_SQUOTE] = ACTIONS(85),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(87),
    [sym_number] = ACTIONS(89),
    [sym_private_property_identifier] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(93),
    [sym_true] = ACTIONS(93),
    [sym_false] = ACTIONS(93),
    [sym_null] = ACTIONS(93),
    [sym_undefined] = ACTIONS(95),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1352),
    [anon_sym_readonly] = ACTIONS(1352),
    [anon_sym_get] = ACTIONS(1352),
    [anon_sym_set] = ACTIONS(1352),
    [anon_sym_declare] = ACTIONS(1352),
    [anon_sym_public] = ACTIONS(1352),
    [anon_sym_private] = ACTIONS(1352),
    [anon_sym_protected] = ACTIONS(1352),
    [anon_sym_override] = ACTIONS(1352),
    [anon_sym_module] = ACTIONS(1352),
    [anon_sym_any] = ACTIONS(1352),
    [anon_sym_number] = ACTIONS(1352),
    [anon_sym_boolean] = ACTIONS(1352),
    [anon_sym_string] = ACTIONS(1352),
    [anon_sym_symbol] = ACTIONS(1352),
    [anon_sym_object] = ACTIONS(1352),
    [anon_sym_satisfies] = ACTIONS(1460),
    [sym__automatic_semicolon] = ACTIONS(1462),
    [sym__ternary_qmark] = ACTIONS(1462),
    [sym_html_comment] = ACTIONS(5),
  },
  [165] = {
    [sym_import] = STATE(3636),
    [sym_parenthesized_expression] = STATE(1364),
    [sym_expression] = STATE(1875),
    [sym_primary_expression] = STATE(1810),
    [sym_yield_expression] = STATE(2358),
    [sym_object] = STATE(2222),
    [sym_object_pattern] = STATE(5773),
    [sym_array] = STATE(2222),
    [sym_array_pattern] = STATE(5773),
    [sym_class] = STATE(2222),
    [sym_function_expression] = STATE(2222),
    [sym_generator_function] = STATE(2222),
    [sym_arrow_function] = STATE(2222),
    [sym__call_signature] = STATE(5771),
    [sym_call_expression] = STATE(2222),
    [sym_new_expression] = STATE(1948),
    [sym_await_expression] = STATE(2358),
    [sym_member_expression] = STATE(1364),
    [sym_subscript_expression] = STATE(1364),
    [sym_assignment_expression] = STATE(2358),
    [sym__augmented_assignment_lhs] = STATE(3020),
    [sym_augmented_assignment_expression] = STATE(2358),
    [sym__destructuring_pattern] = STATE(5773),
    [sym_ternary_expression] = STATE(2358),
    [sym_binary_expression] = STATE(2358),
    [sym_unary_expression] = STATE(2358),
    [sym_update_expression] = STATE(2358),
    [sym_string] = STATE(2222),
    [sym_template_string] = STATE(2222),
    [sym_regex] = STATE(2222),
    [sym_meta_property] = STATE(2222),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1364),
    [sym_type_assertion] = STATE(2358),
    [sym_as_expression] = STATE(2358),
    [sym_satisfies_expression] = STATE(2358),
    [sym_instantiation_expression] = STATE(2358),
    [sym_internal_module] = STATE(2358),
    [sym_type_arguments] = STATE(513),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4408),
    [sym_identifier] = ACTIONS(1474),
    [anon_sym_export] = ACTIONS(1386),
    [anon_sym_STAR] = ACTIONS(1476),
    [anon_sym_type] = ACTIONS(1386),
    [anon_sym_as] = ACTIONS(1460),
    [anon_sym_namespace] = ACTIONS(1388),
    [anon_sym_LBRACE] = ACTIONS(665),
    [anon_sym_COMMA] = ACTIONS(1462),
    [anon_sym_typeof] = ACTIONS(1408),
    [anon_sym_import] = ACTIONS(669),
    [anon_sym_let] = ACTIONS(1386),
    [anon_sym_BANG] = ACTIONS(1408),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_SEMI] = ACTIONS(1462),
    [anon_sym_await] = ACTIONS(1394),
    [anon_sym_in] = ACTIONS(1460),
    [anon_sym_of] = ACTIONS(1460),
    [anon_sym_yield] = ACTIONS(1396),
    [anon_sym_LBRACK] = ACTIONS(65),
    [anon_sym_DOT] = ACTIONS(1460),
    [anon_sym_class] = ACTIONS(676),
    [anon_sym_async] = ACTIONS(1398),
    [anon_sym_function] = ACTIONS(680),
    [anon_sym_QMARK_DOT] = ACTIONS(1462),
    [anon_sym_new] = ACTIONS(1478),
    [anon_sym_using] = ACTIONS(1402),
    [anon_sym_AMP_AMP] = ACTIONS(1462),
    [anon_sym_PIPE_PIPE] = ACTIONS(1462),
    [anon_sym_GT_GT] = ACTIONS(1460),
    [anon_sym_GT_GT_GT] = ACTIONS(1462),
    [anon_sym_LT_LT] = ACTIONS(1462),
    [anon_sym_AMP] = ACTIONS(1460),
    [anon_sym_CARET] = ACTIONS(1462),
    [anon_sym_PIPE] = ACTIONS(1460),
    [anon_sym_PLUS] = ACTIONS(1408),
    [anon_sym_DASH] = ACTIONS(1408),
    [anon_sym_SLASH] = ACTIONS(876),
    [anon_sym_PERCENT] = ACTIONS(1462),
    [anon_sym_STAR_STAR] = ACTIONS(1462),
    [anon_sym_LT] = ACTIONS(173),
    [anon_sym_LT_EQ] = ACTIONS(1462),
    [anon_sym_EQ_EQ] = ACTIONS(1460),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(1462),
    [anon_sym_BANG_EQ] = ACTIONS(1460),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(1462),
    [anon_sym_GT_EQ] = ACTIONS(1462),
    [anon_sym_GT] = ACTIONS(1460),
    [anon_sym_QMARK_QMARK] = ACTIONS(1462),
    [anon_sym_instanceof] = ACTIONS(1460),
    [anon_sym_TILDE] = ACTIONS(1392),
    [anon_sym_void] = ACTIONS(1408),
    [anon_sym_delete] = ACTIONS(1408),
    [anon_sym_PLUS_PLUS] = ACTIONS(1410),
    [anon_sym_DASH_DASH] = ACTIONS(1410),
    [anon_sym_DQUOTE] = ACTIONS(83),
    [anon_sym_SQUOTE] = ACTIONS(85),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(87),
    [sym_number] = ACTIONS(89),
    [sym_private_property_identifier] = ACTIONS(1412),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(93),
    [sym_true] = ACTIONS(93),
    [sym_false] = ACTIONS(93),
    [sym_null] = ACTIONS(93),
    [sym_undefined] = ACTIONS(1480),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1386),
    [anon_sym_readonly] = ACTIONS(1386),
    [anon_sym_get] = ACTIONS(1386),
    [anon_sym_set] = ACTIONS(1386),
    [anon_sym_declare] = ACTIONS(1386),
    [anon_sym_public] = ACTIONS(1386),
    [anon_sym_private] = ACTIONS(1386),
    [anon_sym_protected] = ACTIONS(1386),
    [anon_sym_override] = ACTIONS(1386),
    [anon_sym_module] = ACTIONS(1386),
    [anon_sym_any] = ACTIONS(1386),
    [anon_sym_number] = ACTIONS(1386),
    [anon_sym_boolean] = ACTIONS(1386),
    [anon_sym_string] = ACTIONS(1386),
    [anon_sym_symbol] = ACTIONS(1386),
    [anon_sym_object] = ACTIONS(1386),
    [anon_sym_satisfies] = ACTIONS(1460),
    [sym__automatic_semicolon] = ACTIONS(1462),
    [sym__ternary_qmark] = ACTIONS(1462),
    [sym_html_comment] = ACTIONS(5),
  },
  [166] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1398),
    [sym_expression] = STATE(1924),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5544),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5544),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5558),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1398),
    [sym_subscript_expression] = STATE(1398),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(2980),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5544),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1398),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(638),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1482),
    [anon_sym_export] = ACTIONS(1158),
    [anon_sym_STAR] = ACTIONS(1484),
    [anon_sym_type] = ACTIONS(1158),
    [anon_sym_as] = ACTIONS(1460),
    [anon_sym_namespace] = ACTIONS(1160),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_COMMA] = ACTIONS(1462),
    [anon_sym_typeof] = ACTIONS(756),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1158),
    [anon_sym_BANG] = ACTIONS(756),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_RPAREN] = ACTIONS(1462),
    [anon_sym_await] = ACTIONS(736),
    [anon_sym_in] = ACTIONS(1460),
    [anon_sym_COLON] = ACTIONS(1462),
    [anon_sym_yield] = ACTIONS(738),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_DOT] = ACTIONS(1460),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1164),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_QMARK_DOT] = ACTIONS(1462),
    [anon_sym_new] = ACTIONS(1486),
    [anon_sym_using] = ACTIONS(746),
    [anon_sym_AMP_AMP] = ACTIONS(1462),
    [anon_sym_PIPE_PIPE] = ACTIONS(1462),
    [anon_sym_GT_GT] = ACTIONS(1460),
    [anon_sym_GT_GT_GT] = ACTIONS(1462),
    [anon_sym_LT_LT] = ACTIONS(1462),
    [anon_sym_AMP] = ACTIONS(1460),
    [anon_sym_CARET] = ACTIONS(1462),
    [anon_sym_PIPE] = ACTIONS(1460),
    [anon_sym_PLUS] = ACTIONS(756),
    [anon_sym_DASH] = ACTIONS(756),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_PERCENT] = ACTIONS(1462),
    [anon_sym_STAR_STAR] = ACTIONS(1462),
    [anon_sym_LT] = ACTIONS(173),
    [anon_sym_LT_EQ] = ACTIONS(1462),
    [anon_sym_EQ_EQ] = ACTIONS(1460),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(1462),
    [anon_sym_BANG_EQ] = ACTIONS(1460),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(1462),
    [anon_sym_GT_EQ] = ACTIONS(1462),
    [anon_sym_GT] = ACTIONS(1460),
    [anon_sym_QMARK_QMARK] = ACTIONS(1462),
    [anon_sym_instanceof] = ACTIONS(1460),
    [anon_sym_TILDE] = ACTIONS(732),
    [anon_sym_void] = ACTIONS(756),
    [anon_sym_delete] = ACTIONS(756),
    [anon_sym_PLUS_PLUS] = ACTIONS(758),
    [anon_sym_DASH_DASH] = ACTIONS(758),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(764),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1488),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1158),
    [anon_sym_readonly] = ACTIONS(1158),
    [anon_sym_get] = ACTIONS(1158),
    [anon_sym_set] = ACTIONS(1158),
    [anon_sym_declare] = ACTIONS(1158),
    [anon_sym_public] = ACTIONS(1158),
    [anon_sym_private] = ACTIONS(1158),
    [anon_sym_protected] = ACTIONS(1158),
    [anon_sym_override] = ACTIONS(1158),
    [anon_sym_module] = ACTIONS(1158),
    [anon_sym_any] = ACTIONS(1158),
    [anon_sym_number] = ACTIONS(1158),
    [anon_sym_boolean] = ACTIONS(1158),
    [anon_sym_string] = ACTIONS(1158),
    [anon_sym_symbol] = ACTIONS(1158),
    [anon_sym_object] = ACTIONS(1158),
    [anon_sym_satisfies] = ACTIONS(1460),
    [sym__ternary_qmark] = ACTIONS(1462),
    [sym_html_comment] = ACTIONS(5),
  },
  [167] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1387),
    [sym_expression] = STATE(2108),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5803),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5803),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5585),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1387),
    [sym_subscript_expression] = STATE(1387),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3009),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5803),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1387),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(566),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1490),
    [anon_sym_export] = ACTIONS(1422),
    [anon_sym_STAR] = ACTIONS(1492),
    [anon_sym_type] = ACTIONS(1422),
    [anon_sym_as] = ACTIONS(1460),
    [anon_sym_namespace] = ACTIONS(1424),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_COMMA] = ACTIONS(1462),
    [anon_sym_typeof] = ACTIONS(1444),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1422),
    [anon_sym_BANG] = ACTIONS(1444),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(1430),
    [anon_sym_in] = ACTIONS(1460),
    [anon_sym_yield] = ACTIONS(1432),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_DOT] = ACTIONS(1460),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1434),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_QMARK_DOT] = ACTIONS(1462),
    [anon_sym_new] = ACTIONS(1494),
    [anon_sym_using] = ACTIONS(1438),
    [anon_sym_AMP_AMP] = ACTIONS(1462),
    [anon_sym_PIPE_PIPE] = ACTIONS(1462),
    [anon_sym_GT_GT] = ACTIONS(1460),
    [anon_sym_GT_GT_GT] = ACTIONS(1462),
    [anon_sym_LT_LT] = ACTIONS(1462),
    [anon_sym_AMP] = ACTIONS(1460),
    [anon_sym_CARET] = ACTIONS(1462),
    [anon_sym_PIPE] = ACTIONS(1460),
    [anon_sym_PLUS] = ACTIONS(1444),
    [anon_sym_DASH] = ACTIONS(1444),
    [anon_sym_SLASH] = ACTIONS(942),
    [anon_sym_PERCENT] = ACTIONS(1462),
    [anon_sym_STAR_STAR] = ACTIONS(1462),
    [anon_sym_LT] = ACTIONS(173),
    [anon_sym_LT_EQ] = ACTIONS(1462),
    [anon_sym_EQ_EQ] = ACTIONS(1460),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(1462),
    [anon_sym_BANG_EQ] = ACTIONS(1460),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(1462),
    [anon_sym_GT_EQ] = ACTIONS(1462),
    [anon_sym_GT] = ACTIONS(1460),
    [anon_sym_QMARK_QMARK] = ACTIONS(1462),
    [anon_sym_instanceof] = ACTIONS(1460),
    [anon_sym_TILDE] = ACTIONS(1428),
    [anon_sym_void] = ACTIONS(1444),
    [anon_sym_delete] = ACTIONS(1444),
    [anon_sym_PLUS_PLUS] = ACTIONS(1446),
    [anon_sym_DASH_DASH] = ACTIONS(1446),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(1448),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1496),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1422),
    [anon_sym_readonly] = ACTIONS(1422),
    [anon_sym_get] = ACTIONS(1422),
    [anon_sym_set] = ACTIONS(1422),
    [anon_sym_declare] = ACTIONS(1422),
    [anon_sym_public] = ACTIONS(1422),
    [anon_sym_private] = ACTIONS(1422),
    [anon_sym_protected] = ACTIONS(1422),
    [anon_sym_override] = ACTIONS(1422),
    [anon_sym_module] = ACTIONS(1422),
    [anon_sym_any] = ACTIONS(1422),
    [anon_sym_number] = ACTIONS(1422),
    [anon_sym_boolean] = ACTIONS(1422),
    [anon_sym_string] = ACTIONS(1422),
    [anon_sym_symbol] = ACTIONS(1422),
    [anon_sym_object] = ACTIONS(1422),
    [anon_sym_satisfies] = ACTIONS(1460),
    [anon_sym_implements] = ACTIONS(1460),
    [sym__ternary_qmark] = ACTIONS(1462),
    [sym_html_comment] = ACTIONS(5),
  },
  [168] = {
    [sym_import] = STATE(3636),
    [sym_parenthesized_expression] = STATE(1410),
    [sym_expression] = STATE(2241),
    [sym_primary_expression] = STATE(1810),
    [sym_yield_expression] = STATE(2358),
    [sym_object] = STATE(2222),
    [sym_object_pattern] = STATE(5580),
    [sym_array] = STATE(2222),
    [sym_array_pattern] = STATE(5580),
    [sym_class] = STATE(2222),
    [sym_function_expression] = STATE(2222),
    [sym_generator_function] = STATE(2222),
    [sym_arrow_function] = STATE(2222),
    [sym__call_signature] = STATE(5466),
    [sym_call_expression] = STATE(2222),
    [sym_new_expression] = STATE(1948),
    [sym_await_expression] = STATE(2358),
    [sym_member_expression] = STATE(1410),
    [sym_subscript_expression] = STATE(1410),
    [sym_assignment_expression] = STATE(2358),
    [sym__augmented_assignment_lhs] = STATE(3004),
    [sym_augmented_assignment_expression] = STATE(2358),
    [sym__destructuring_pattern] = STATE(5580),
    [sym_ternary_expression] = STATE(2358),
    [sym_binary_expression] = STATE(2358),
    [sym_unary_expression] = STATE(2358),
    [sym_update_expression] = STATE(2358),
    [sym_string] = STATE(2222),
    [sym_template_string] = STATE(2222),
    [sym_regex] = STATE(2222),
    [sym_meta_property] = STATE(2222),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1410),
    [sym_type_assertion] = STATE(2358),
    [sym_as_expression] = STATE(2358),
    [sym_satisfies_expression] = STATE(2358),
    [sym_instantiation_expression] = STATE(2358),
    [sym_internal_module] = STATE(2358),
    [sym_type_arguments] = STATE(452),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4408),
    [sym_identifier] = ACTIONS(1498),
    [anon_sym_export] = ACTIONS(1270),
    [anon_sym_STAR] = ACTIONS(1500),
    [anon_sym_type] = ACTIONS(1270),
    [anon_sym_as] = ACTIONS(1460),
    [anon_sym_namespace] = ACTIONS(1272),
    [anon_sym_LBRACE] = ACTIONS(665),
    [anon_sym_typeof] = ACTIONS(1298),
    [anon_sym_import] = ACTIONS(669),
    [anon_sym_let] = ACTIONS(1270),
    [anon_sym_BANG] = ACTIONS(1298),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_SEMI] = ACTIONS(1462),
    [anon_sym_await] = ACTIONS(1282),
    [anon_sym_in] = ACTIONS(1460),
    [anon_sym_yield] = ACTIONS(1284),
    [anon_sym_LBRACK] = ACTIONS(65),
    [anon_sym_DOT] = ACTIONS(1460),
    [anon_sym_class] = ACTIONS(676),
    [anon_sym_async] = ACTIONS(1288),
    [anon_sym_function] = ACTIONS(680),
    [anon_sym_QMARK_DOT] = ACTIONS(1462),
    [anon_sym_new] = ACTIONS(1502),
    [anon_sym_using] = ACTIONS(1292),
    [anon_sym_AMP_AMP] = ACTIONS(1462),
    [anon_sym_PIPE_PIPE] = ACTIONS(1462),
    [anon_sym_GT_GT] = ACTIONS(1460),
    [anon_sym_GT_GT_GT] = ACTIONS(1462),
    [anon_sym_LT_LT] = ACTIONS(1462),
    [anon_sym_AMP] = ACTIONS(1460),
    [anon_sym_CARET] = ACTIONS(1462),
    [anon_sym_PIPE] = ACTIONS(1460),
    [anon_sym_PLUS] = ACTIONS(1298),
    [anon_sym_DASH] = ACTIONS(1298),
    [anon_sym_SLASH] = ACTIONS(77),
    [anon_sym_PERCENT] = ACTIONS(1462),
    [anon_sym_STAR_STAR] = ACTIONS(1462),
    [anon_sym_LT] = ACTIONS(173),
    [anon_sym_LT_EQ] = ACTIONS(1462),
    [anon_sym_EQ_EQ] = ACTIONS(1460),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(1462),
    [anon_sym_BANG_EQ] = ACTIONS(1460),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(1462),
    [anon_sym_GT_EQ] = ACTIONS(1462),
    [anon_sym_GT] = ACTIONS(1460),
    [anon_sym_QMARK_QMARK] = ACTIONS(1462),
    [anon_sym_instanceof] = ACTIONS(1460),
    [anon_sym_TILDE] = ACTIONS(1278),
    [anon_sym_void] = ACTIONS(1298),
    [anon_sym_delete] = ACTIONS(1298),
    [anon_sym_PLUS_PLUS] = ACTIONS(1300),
    [anon_sym_DASH_DASH] = ACTIONS(1300),
    [anon_sym_DQUOTE] = ACTIONS(83),
    [anon_sym_SQUOTE] = ACTIONS(85),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(87),
    [sym_number] = ACTIONS(89),
    [sym_private_property_identifier] = ACTIONS(1306),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(93),
    [sym_true] = ACTIONS(93),
    [sym_false] = ACTIONS(93),
    [sym_null] = ACTIONS(93),
    [sym_undefined] = ACTIONS(1504),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1270),
    [anon_sym_readonly] = ACTIONS(1270),
    [anon_sym_get] = ACTIONS(1270),
    [anon_sym_set] = ACTIONS(1270),
    [anon_sym_declare] = ACTIONS(1270),
    [anon_sym_public] = ACTIONS(1270),
    [anon_sym_private] = ACTIONS(1270),
    [anon_sym_protected] = ACTIONS(1270),
    [anon_sym_override] = ACTIONS(1270),
    [anon_sym_module] = ACTIONS(1270),
    [anon_sym_any] = ACTIONS(1270),
    [anon_sym_number] = ACTIONS(1270),
    [anon_sym_boolean] = ACTIONS(1270),
    [anon_sym_string] = ACTIONS(1270),
    [anon_sym_symbol] = ACTIONS(1270),
    [anon_sym_object] = ACTIONS(1270),
    [anon_sym_satisfies] = ACTIONS(1460),
    [sym__automatic_semicolon] = ACTIONS(1462),
    [sym__ternary_qmark] = ACTIONS(1462),
    [sym_html_comment] = ACTIONS(5),
  },
  [169] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1456),
    [sym_expression] = STATE(2406),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5815),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5815),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5755),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1456),
    [sym_subscript_expression] = STATE(1456),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3029),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5815),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1456),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(594),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1506),
    [anon_sym_export] = ACTIONS(1234),
    [anon_sym_STAR] = ACTIONS(1508),
    [anon_sym_type] = ACTIONS(1234),
    [anon_sym_as] = ACTIONS(1460),
    [anon_sym_namespace] = ACTIONS(1236),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_typeof] = ACTIONS(1256),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1234),
    [anon_sym_BANG] = ACTIONS(1256),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(1242),
    [anon_sym_in] = ACTIONS(1460),
    [anon_sym_COLON] = ACTIONS(1462),
    [anon_sym_yield] = ACTIONS(1244),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_DOT] = ACTIONS(1460),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1246),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_QMARK_DOT] = ACTIONS(1462),
    [anon_sym_new] = ACTIONS(1510),
    [anon_sym_using] = ACTIONS(1250),
    [anon_sym_AMP_AMP] = ACTIONS(1462),
    [anon_sym_PIPE_PIPE] = ACTIONS(1462),
    [anon_sym_GT_GT] = ACTIONS(1460),
    [anon_sym_GT_GT_GT] = ACTIONS(1462),
    [anon_sym_LT_LT] = ACTIONS(1462),
    [anon_sym_AMP] = ACTIONS(1460),
    [anon_sym_CARET] = ACTIONS(1462),
    [anon_sym_PIPE] = ACTIONS(1460),
    [anon_sym_PLUS] = ACTIONS(1256),
    [anon_sym_DASH] = ACTIONS(1256),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_PERCENT] = ACTIONS(1462),
    [anon_sym_STAR_STAR] = ACTIONS(1462),
    [anon_sym_LT] = ACTIONS(173),
    [anon_sym_LT_EQ] = ACTIONS(1462),
    [anon_sym_EQ_EQ] = ACTIONS(1460),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(1462),
    [anon_sym_BANG_EQ] = ACTIONS(1460),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(1462),
    [anon_sym_GT_EQ] = ACTIONS(1462),
    [anon_sym_GT] = ACTIONS(1460),
    [anon_sym_QMARK_QMARK] = ACTIONS(1462),
    [anon_sym_instanceof] = ACTIONS(1460),
    [anon_sym_TILDE] = ACTIONS(1240),
    [anon_sym_void] = ACTIONS(1256),
    [anon_sym_delete] = ACTIONS(1256),
    [anon_sym_PLUS_PLUS] = ACTIONS(1258),
    [anon_sym_DASH_DASH] = ACTIONS(1258),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(1260),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1512),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1234),
    [anon_sym_readonly] = ACTIONS(1234),
    [anon_sym_get] = ACTIONS(1234),
    [anon_sym_set] = ACTIONS(1234),
    [anon_sym_declare] = ACTIONS(1234),
    [anon_sym_public] = ACTIONS(1234),
    [anon_sym_private] = ACTIONS(1234),
    [anon_sym_protected] = ACTIONS(1234),
    [anon_sym_override] = ACTIONS(1234),
    [anon_sym_module] = ACTIONS(1234),
    [anon_sym_any] = ACTIONS(1234),
    [anon_sym_number] = ACTIONS(1234),
    [anon_sym_boolean] = ACTIONS(1234),
    [anon_sym_string] = ACTIONS(1234),
    [anon_sym_symbol] = ACTIONS(1234),
    [anon_sym_object] = ACTIONS(1234),
    [anon_sym_satisfies] = ACTIONS(1460),
    [sym__ternary_qmark] = ACTIONS(1462),
    [sym_html_comment] = ACTIONS(5),
  },
  [170] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1459),
    [sym_expression] = STATE(2516),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5827),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5827),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5529),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1459),
    [sym_subscript_expression] = STATE(1459),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(2979),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5827),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1459),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(647),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1514),
    [anon_sym_export] = ACTIONS(1074),
    [anon_sym_STAR] = ACTIONS(1516),
    [anon_sym_type] = ACTIONS(1074),
    [anon_sym_as] = ACTIONS(1460),
    [anon_sym_namespace] = ACTIONS(1076),
    [anon_sym_LBRACE] = ACTIONS(808),
    [anon_sym_typeof] = ACTIONS(1100),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1074),
    [anon_sym_BANG] = ACTIONS(1100),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(1084),
    [anon_sym_in] = ACTIONS(1460),
    [anon_sym_of] = ACTIONS(1460),
    [anon_sym_yield] = ACTIONS(1086),
    [anon_sym_LBRACK] = ACTIONS(812),
    [anon_sym_DOT] = ACTIONS(1460),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1090),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_QMARK_DOT] = ACTIONS(1462),
    [anon_sym_new] = ACTIONS(1518),
    [anon_sym_using] = ACTIONS(1094),
    [anon_sym_AMP_AMP] = ACTIONS(1462),
    [anon_sym_PIPE_PIPE] = ACTIONS(1462),
    [anon_sym_GT_GT] = ACTIONS(1460),
    [anon_sym_GT_GT_GT] = ACTIONS(1462),
    [anon_sym_LT_LT] = ACTIONS(1462),
    [anon_sym_AMP] = ACTIONS(1460),
    [anon_sym_CARET] = ACTIONS(1462),
    [anon_sym_PIPE] = ACTIONS(1460),
    [anon_sym_PLUS] = ACTIONS(1100),
    [anon_sym_DASH] = ACTIONS(1100),
    [anon_sym_SLASH] = ACTIONS(958),
    [anon_sym_PERCENT] = ACTIONS(1462),
    [anon_sym_STAR_STAR] = ACTIONS(1462),
    [anon_sym_LT] = ACTIONS(173),
    [anon_sym_LT_EQ] = ACTIONS(1462),
    [anon_sym_EQ_EQ] = ACTIONS(1460),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(1462),
    [anon_sym_BANG_EQ] = ACTIONS(1460),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(1462),
    [anon_sym_GT_EQ] = ACTIONS(1462),
    [anon_sym_GT] = ACTIONS(1460),
    [anon_sym_QMARK_QMARK] = ACTIONS(1462),
    [anon_sym_instanceof] = ACTIONS(1460),
    [anon_sym_TILDE] = ACTIONS(1082),
    [anon_sym_void] = ACTIONS(1100),
    [anon_sym_delete] = ACTIONS(1100),
    [anon_sym_PLUS_PLUS] = ACTIONS(1102),
    [anon_sym_DASH_DASH] = ACTIONS(1102),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(1108),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1520),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1074),
    [anon_sym_readonly] = ACTIONS(1074),
    [anon_sym_get] = ACTIONS(1074),
    [anon_sym_set] = ACTIONS(1074),
    [anon_sym_declare] = ACTIONS(1074),
    [anon_sym_public] = ACTIONS(1074),
    [anon_sym_private] = ACTIONS(1074),
    [anon_sym_protected] = ACTIONS(1074),
    [anon_sym_override] = ACTIONS(1074),
    [anon_sym_module] = ACTIONS(1074),
    [anon_sym_any] = ACTIONS(1074),
    [anon_sym_number] = ACTIONS(1074),
    [anon_sym_boolean] = ACTIONS(1074),
    [anon_sym_string] = ACTIONS(1074),
    [anon_sym_symbol] = ACTIONS(1074),
    [anon_sym_object] = ACTIONS(1074),
    [anon_sym_satisfies] = ACTIONS(1460),
    [sym__ternary_qmark] = ACTIONS(1462),
    [sym_html_comment] = ACTIONS(5),
  },
  [171] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1457),
    [sym_expression] = STATE(2416),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5823),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5823),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5477),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1457),
    [sym_subscript_expression] = STATE(1457),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(2986),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5823),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1457),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(620),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1522),
    [anon_sym_export] = ACTIONS(1178),
    [anon_sym_STAR] = ACTIONS(1524),
    [anon_sym_type] = ACTIONS(1178),
    [anon_sym_as] = ACTIONS(1460),
    [anon_sym_namespace] = ACTIONS(1180),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_typeof] = ACTIONS(1202),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1178),
    [anon_sym_BANG] = ACTIONS(1202),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(1188),
    [anon_sym_in] = ACTIONS(1460),
    [anon_sym_yield] = ACTIONS(1190),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_RBRACK] = ACTIONS(1462),
    [anon_sym_DOT] = ACTIONS(1460),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1192),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_QMARK_DOT] = ACTIONS(1462),
    [anon_sym_new] = ACTIONS(1526),
    [anon_sym_using] = ACTIONS(1196),
    [anon_sym_AMP_AMP] = ACTIONS(1462),
    [anon_sym_PIPE_PIPE] = ACTIONS(1462),
    [anon_sym_GT_GT] = ACTIONS(1460),
    [anon_sym_GT_GT_GT] = ACTIONS(1462),
    [anon_sym_LT_LT] = ACTIONS(1462),
    [anon_sym_AMP] = ACTIONS(1460),
    [anon_sym_CARET] = ACTIONS(1462),
    [anon_sym_PIPE] = ACTIONS(1460),
    [anon_sym_PLUS] = ACTIONS(1202),
    [anon_sym_DASH] = ACTIONS(1202),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_PERCENT] = ACTIONS(1462),
    [anon_sym_STAR_STAR] = ACTIONS(1462),
    [anon_sym_LT] = ACTIONS(173),
    [anon_sym_LT_EQ] = ACTIONS(1462),
    [anon_sym_EQ_EQ] = ACTIONS(1460),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(1462),
    [anon_sym_BANG_EQ] = ACTIONS(1460),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(1462),
    [anon_sym_GT_EQ] = ACTIONS(1462),
    [anon_sym_GT] = ACTIONS(1460),
    [anon_sym_QMARK_QMARK] = ACTIONS(1462),
    [anon_sym_instanceof] = ACTIONS(1460),
    [anon_sym_TILDE] = ACTIONS(1186),
    [anon_sym_void] = ACTIONS(1202),
    [anon_sym_delete] = ACTIONS(1202),
    [anon_sym_PLUS_PLUS] = ACTIONS(1204),
    [anon_sym_DASH_DASH] = ACTIONS(1204),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(1206),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1528),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1178),
    [anon_sym_readonly] = ACTIONS(1178),
    [anon_sym_get] = ACTIONS(1178),
    [anon_sym_set] = ACTIONS(1178),
    [anon_sym_declare] = ACTIONS(1178),
    [anon_sym_public] = ACTIONS(1178),
    [anon_sym_private] = ACTIONS(1178),
    [anon_sym_protected] = ACTIONS(1178),
    [anon_sym_override] = ACTIONS(1178),
    [anon_sym_module] = ACTIONS(1178),
    [anon_sym_any] = ACTIONS(1178),
    [anon_sym_number] = ACTIONS(1178),
    [anon_sym_boolean] = ACTIONS(1178),
    [anon_sym_string] = ACTIONS(1178),
    [anon_sym_symbol] = ACTIONS(1178),
    [anon_sym_object] = ACTIONS(1178),
    [anon_sym_satisfies] = ACTIONS(1460),
    [sym__ternary_qmark] = ACTIONS(1462),
    [sym_html_comment] = ACTIONS(5),
  },
  [172] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1213),
    [sym_expression] = STATE(2579),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5522),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5522),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5800),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1213),
    [sym_subscript_expression] = STATE(1213),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3013),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5522),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1213),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(539),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(802),
    [anon_sym_export] = ACTIONS(804),
    [anon_sym_STAR] = ACTIONS(1530),
    [anon_sym_type] = ACTIONS(804),
    [anon_sym_as] = ACTIONS(1460),
    [anon_sym_namespace] = ACTIONS(806),
    [anon_sym_LBRACE] = ACTIONS(808),
    [anon_sym_typeof] = ACTIONS(179),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(804),
    [anon_sym_BANG] = ACTIONS(179),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(140),
    [anon_sym_in] = ACTIONS(1460),
    [anon_sym_yield] = ACTIONS(142),
    [anon_sym_LBRACK] = ACTIONS(812),
    [anon_sym_DOT] = ACTIONS(1460),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(816),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_QMARK_DOT] = ACTIONS(1462),
    [anon_sym_new] = ACTIONS(818),
    [anon_sym_using] = ACTIONS(158),
    [anon_sym_AMP_AMP] = ACTIONS(1462),
    [anon_sym_PIPE_PIPE] = ACTIONS(1462),
    [anon_sym_GT_GT] = ACTIONS(1460),
    [anon_sym_GT_GT_GT] = ACTIONS(1462),
    [anon_sym_LT_LT] = ACTIONS(1462),
    [anon_sym_AMP] = ACTIONS(1460),
    [anon_sym_CARET] = ACTIONS(1462),
    [anon_sym_PIPE] = ACTIONS(1460),
    [anon_sym_PLUS] = ACTIONS(179),
    [anon_sym_DASH] = ACTIONS(179),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_PERCENT] = ACTIONS(1462),
    [anon_sym_STAR_STAR] = ACTIONS(1462),
    [anon_sym_LT] = ACTIONS(173),
    [anon_sym_LT_EQ] = ACTIONS(1462),
    [anon_sym_EQ_EQ] = ACTIONS(1460),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(1462),
    [anon_sym_BANG_EQ] = ACTIONS(1460),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(1462),
    [anon_sym_GT_EQ] = ACTIONS(1462),
    [anon_sym_GT] = ACTIONS(1460),
    [anon_sym_QMARK_QMARK] = ACTIONS(1462),
    [anon_sym_instanceof] = ACTIONS(1460),
    [anon_sym_TILDE] = ACTIONS(175),
    [anon_sym_void] = ACTIONS(179),
    [anon_sym_delete] = ACTIONS(179),
    [anon_sym_PLUS_PLUS] = ACTIONS(686),
    [anon_sym_DASH_DASH] = ACTIONS(686),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(192),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(822),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(804),
    [anon_sym_readonly] = ACTIONS(804),
    [anon_sym_get] = ACTIONS(804),
    [anon_sym_set] = ACTIONS(804),
    [anon_sym_declare] = ACTIONS(804),
    [anon_sym_public] = ACTIONS(804),
    [anon_sym_private] = ACTIONS(804),
    [anon_sym_protected] = ACTIONS(804),
    [anon_sym_override] = ACTIONS(804),
    [anon_sym_module] = ACTIONS(804),
    [anon_sym_any] = ACTIONS(804),
    [anon_sym_number] = ACTIONS(804),
    [anon_sym_boolean] = ACTIONS(804),
    [anon_sym_string] = ACTIONS(804),
    [anon_sym_symbol] = ACTIONS(804),
    [anon_sym_object] = ACTIONS(804),
    [anon_sym_satisfies] = ACTIONS(1460),
    [sym__ternary_qmark] = ACTIONS(1462),
    [sym_html_comment] = ACTIONS(5),
  },
  [173] = {
    [sym_import] = STATE(4878),
    [sym_nested_identifier] = STATE(5474),
    [sym_string] = STATE(2994),
    [sym_formal_parameters] = STATE(5475),
    [sym_nested_type_identifier] = STATE(2939),
    [sym__type_query_member_expression_in_type_annotation] = STATE(2937),
    [sym__type_query_call_expression_in_type_annotation] = STATE(2938),
    [sym_type] = STATE(3153),
    [sym_constructor_type] = STATE(3007),
    [sym_primary_type] = STATE(2981),
    [sym_template_literal_type] = STATE(3039),
    [sym_infer_type] = STATE(3007),
    [sym_conditional_type] = STATE(3039),
    [sym_generic_type] = STATE(3039),
    [sym_type_query] = STATE(3039),
    [sym_index_type_query] = STATE(3039),
    [sym_lookup_type] = STATE(3039),
    [sym_literal_type] = STATE(3039),
    [sym__number] = STATE(3041),
    [sym_existential_type] = STATE(3039),
    [sym_flow_maybe_type] = STATE(3039),
    [sym_parenthesized_type] = STATE(3039),
    [sym_predefined_type] = STATE(3039),
    [sym_object_type] = STATE(3039),
    [sym_type_parameters] = STATE(5248),
    [sym_array_type] = STATE(3039),
    [sym_tuple_type] = STATE(3039),
    [sym_readonly_type] = STATE(3007),
    [sym_union_type] = STATE(3039),
    [sym_intersection_type] = STATE(3039),
    [sym_function_type] = STATE(3007),
    [sym_identifier] = ACTIONS(1532),
    [anon_sym_STAR] = ACTIONS(115),
    [anon_sym_EQ] = ACTIONS(834),
    [anon_sym_as] = ACTIONS(120),
    [anon_sym_LBRACE] = ACTIONS(1534),
    [anon_sym_COMMA] = ACTIONS(154),
    [anon_sym_RBRACE] = ACTIONS(154),
    [anon_sym_typeof] = ACTIONS(1536),
    [anon_sym_import] = ACTIONS(1538),
    [anon_sym_const] = ACTIONS(133),
    [anon_sym_BANG] = ACTIONS(120),
    [anon_sym_LPAREN] = ACTIONS(1540),
    [anon_sym_SEMI] = ACTIONS(154),
    [anon_sym_in] = ACTIONS(120),
    [anon_sym_COLON] = ACTIONS(154),
    [anon_sym_LBRACK] = ACTIONS(1542),
    [anon_sym_RBRACK] = ACTIONS(154),
    [anon_sym_DOT] = ACTIONS(120),
    [anon_sym_EQ_GT] = ACTIONS(844),
    [anon_sym_QMARK_DOT] = ACTIONS(154),
    [anon_sym_new] = ACTIONS(1544),
    [anon_sym_PLUS_EQ] = ACTIONS(160),
    [anon_sym_DASH_EQ] = ACTIONS(160),
    [anon_sym_STAR_EQ] = ACTIONS(160),
    [anon_sym_SLASH_EQ] = ACTIONS(160),
    [anon_sym_PERCENT_EQ] = ACTIONS(160),
    [anon_sym_CARET_EQ] = ACTIONS(160),
    [anon_sym_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_LT_LT_EQ] = ACTIONS(160),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(160),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP] = ACTIONS(120),
    [anon_sym_PIPE_PIPE] = ACTIONS(120),
    [anon_sym_GT_GT] = ACTIONS(120),
    [anon_sym_GT_GT_GT] = ACTIONS(120),
    [anon_sym_LT_LT] = ACTIONS(120),
    [anon_sym_AMP] = ACTIONS(164),
    [anon_sym_CARET] = ACTIONS(120),
    [anon_sym_PIPE] = ACTIONS(166),
    [anon_sym_PLUS] = ACTIONS(1546),
    [anon_sym_DASH] = ACTIONS(1546),
    [anon_sym_SLASH] = ACTIONS(120),
    [anon_sym_PERCENT] = ACTIONS(120),
    [anon_sym_STAR_STAR] = ACTIONS(120),
    [anon_sym_LT] = ACTIONS(1548),
    [anon_sym_LT_EQ] = ACTIONS(154),
    [anon_sym_EQ_EQ] = ACTIONS(120),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(154),
    [anon_sym_BANG_EQ] = ACTIONS(120),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(154),
    [anon_sym_GT_EQ] = ACTIONS(154),
    [anon_sym_GT] = ACTIONS(120),
    [anon_sym_QMARK_QMARK] = ACTIONS(120),
    [anon_sym_instanceof] = ACTIONS(120),
    [anon_sym_void] = ACTIONS(216),
    [anon_sym_PLUS_PLUS] = ACTIONS(154),
    [anon_sym_DASH_DASH] = ACTIONS(154),
    [anon_sym_DQUOTE] = ACTIONS(1550),
    [anon_sym_SQUOTE] = ACTIONS(1552),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1554),
    [sym_number] = ACTIONS(1556),
    [sym_this] = ACTIONS(1558),
    [sym_true] = ACTIONS(1560),
    [sym_false] = ACTIONS(1560),
    [sym_null] = ACTIONS(1560),
    [sym_undefined] = ACTIONS(1560),
    [anon_sym_readonly] = ACTIONS(1562),
    [anon_sym_QMARK] = ACTIONS(204),
    [anon_sym_any] = ACTIONS(216),
    [anon_sym_number] = ACTIONS(216),
    [anon_sym_boolean] = ACTIONS(216),
    [anon_sym_string] = ACTIONS(216),
    [anon_sym_symbol] = ACTIONS(216),
    [anon_sym_object] = ACTIONS(216),
    [anon_sym_abstract] = ACTIONS(208),
    [anon_sym_satisfies] = ACTIONS(120),
    [anon_sym_infer] = ACTIONS(210),
    [anon_sym_keyof] = ACTIONS(212),
    [anon_sym_unique] = ACTIONS(214),
    [anon_sym_unknown] = ACTIONS(216),
    [anon_sym_never] = ACTIONS(216),
    [anon_sym_LBRACE_PIPE] = ACTIONS(218),
    [sym__ternary_qmark] = ACTIONS(154),
    [sym_html_comment] = ACTIONS(5),
  },
  [174] = {
    [sym_import] = STATE(4878),
    [sym_nested_identifier] = STATE(5474),
    [sym_string] = STATE(2994),
    [sym_formal_parameters] = STATE(5475),
    [sym_nested_type_identifier] = STATE(2939),
    [sym__type_query_member_expression_in_type_annotation] = STATE(2937),
    [sym__type_query_call_expression_in_type_annotation] = STATE(2938),
    [sym_type] = STATE(3153),
    [sym_constructor_type] = STATE(3007),
    [sym_primary_type] = STATE(2981),
    [sym_template_literal_type] = STATE(3039),
    [sym_infer_type] = STATE(3007),
    [sym_conditional_type] = STATE(3039),
    [sym_generic_type] = STATE(3039),
    [sym_type_query] = STATE(3039),
    [sym_index_type_query] = STATE(3039),
    [sym_lookup_type] = STATE(3039),
    [sym_literal_type] = STATE(3039),
    [sym__number] = STATE(3041),
    [sym_existential_type] = STATE(3039),
    [sym_flow_maybe_type] = STATE(3039),
    [sym_parenthesized_type] = STATE(3039),
    [sym_predefined_type] = STATE(3039),
    [sym_object_type] = STATE(3039),
    [sym_type_parameters] = STATE(5248),
    [sym_array_type] = STATE(3039),
    [sym_tuple_type] = STATE(3039),
    [sym_readonly_type] = STATE(3007),
    [sym_union_type] = STATE(3039),
    [sym_intersection_type] = STATE(3039),
    [sym_function_type] = STATE(3007),
    [sym_identifier] = ACTIONS(1532),
    [anon_sym_STAR] = ACTIONS(115),
    [anon_sym_EQ] = ACTIONS(866),
    [anon_sym_as] = ACTIONS(120),
    [anon_sym_LBRACE] = ACTIONS(1534),
    [anon_sym_COMMA] = ACTIONS(154),
    [anon_sym_typeof] = ACTIONS(1536),
    [anon_sym_import] = ACTIONS(1538),
    [anon_sym_const] = ACTIONS(133),
    [anon_sym_BANG] = ACTIONS(120),
    [anon_sym_LPAREN] = ACTIONS(1540),
    [anon_sym_SEMI] = ACTIONS(154),
    [anon_sym_in] = ACTIONS(120),
    [anon_sym_of] = ACTIONS(120),
    [anon_sym_LBRACK] = ACTIONS(1542),
    [anon_sym_DOT] = ACTIONS(120),
    [anon_sym_EQ_GT] = ACTIONS(872),
    [anon_sym_QMARK_DOT] = ACTIONS(154),
    [anon_sym_new] = ACTIONS(1544),
    [anon_sym_PLUS_EQ] = ACTIONS(160),
    [anon_sym_DASH_EQ] = ACTIONS(160),
    [anon_sym_STAR_EQ] = ACTIONS(160),
    [anon_sym_SLASH_EQ] = ACTIONS(160),
    [anon_sym_PERCENT_EQ] = ACTIONS(160),
    [anon_sym_CARET_EQ] = ACTIONS(160),
    [anon_sym_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_LT_LT_EQ] = ACTIONS(160),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(160),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP] = ACTIONS(120),
    [anon_sym_PIPE_PIPE] = ACTIONS(120),
    [anon_sym_GT_GT] = ACTIONS(120),
    [anon_sym_GT_GT_GT] = ACTIONS(120),
    [anon_sym_LT_LT] = ACTIONS(120),
    [anon_sym_AMP] = ACTIONS(164),
    [anon_sym_CARET] = ACTIONS(120),
    [anon_sym_PIPE] = ACTIONS(166),
    [anon_sym_PLUS] = ACTIONS(1546),
    [anon_sym_DASH] = ACTIONS(1546),
    [anon_sym_SLASH] = ACTIONS(120),
    [anon_sym_PERCENT] = ACTIONS(120),
    [anon_sym_STAR_STAR] = ACTIONS(120),
    [anon_sym_LT] = ACTIONS(1548),
    [anon_sym_LT_EQ] = ACTIONS(154),
    [anon_sym_EQ_EQ] = ACTIONS(120),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(154),
    [anon_sym_BANG_EQ] = ACTIONS(120),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(154),
    [anon_sym_GT_EQ] = ACTIONS(154),
    [anon_sym_GT] = ACTIONS(120),
    [anon_sym_QMARK_QMARK] = ACTIONS(120),
    [anon_sym_instanceof] = ACTIONS(120),
    [anon_sym_void] = ACTIONS(216),
    [anon_sym_PLUS_PLUS] = ACTIONS(154),
    [anon_sym_DASH_DASH] = ACTIONS(154),
    [anon_sym_DQUOTE] = ACTIONS(1550),
    [anon_sym_SQUOTE] = ACTIONS(1552),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1554),
    [sym_number] = ACTIONS(1556),
    [sym_this] = ACTIONS(1558),
    [sym_true] = ACTIONS(1560),
    [sym_false] = ACTIONS(1560),
    [sym_null] = ACTIONS(1560),
    [sym_undefined] = ACTIONS(1560),
    [anon_sym_readonly] = ACTIONS(1562),
    [anon_sym_QMARK] = ACTIONS(204),
    [anon_sym_any] = ACTIONS(216),
    [anon_sym_number] = ACTIONS(216),
    [anon_sym_boolean] = ACTIONS(216),
    [anon_sym_string] = ACTIONS(216),
    [anon_sym_symbol] = ACTIONS(216),
    [anon_sym_object] = ACTIONS(216),
    [anon_sym_abstract] = ACTIONS(208),
    [anon_sym_satisfies] = ACTIONS(120),
    [anon_sym_infer] = ACTIONS(210),
    [anon_sym_keyof] = ACTIONS(212),
    [anon_sym_unique] = ACTIONS(214),
    [anon_sym_unknown] = ACTIONS(216),
    [anon_sym_never] = ACTIONS(216),
    [anon_sym_LBRACE_PIPE] = ACTIONS(218),
    [sym__automatic_semicolon] = ACTIONS(154),
    [sym__ternary_qmark] = ACTIONS(154),
    [sym_html_comment] = ACTIONS(5),
  },
  [175] = {
    [sym_import] = STATE(4878),
    [sym_nested_identifier] = STATE(5474),
    [sym_string] = STATE(2994),
    [sym_formal_parameters] = STATE(5475),
    [sym_nested_type_identifier] = STATE(2939),
    [sym__type_query_member_expression_in_type_annotation] = STATE(2937),
    [sym__type_query_call_expression_in_type_annotation] = STATE(2938),
    [sym_type] = STATE(3153),
    [sym_constructor_type] = STATE(3007),
    [sym_primary_type] = STATE(2981),
    [sym_template_literal_type] = STATE(3039),
    [sym_infer_type] = STATE(3007),
    [sym_conditional_type] = STATE(3039),
    [sym_generic_type] = STATE(3039),
    [sym_type_query] = STATE(3039),
    [sym_index_type_query] = STATE(3039),
    [sym_lookup_type] = STATE(3039),
    [sym_literal_type] = STATE(3039),
    [sym__number] = STATE(3041),
    [sym_existential_type] = STATE(3039),
    [sym_flow_maybe_type] = STATE(3039),
    [sym_parenthesized_type] = STATE(3039),
    [sym_predefined_type] = STATE(3039),
    [sym_object_type] = STATE(3039),
    [sym_type_parameters] = STATE(5248),
    [sym_array_type] = STATE(3039),
    [sym_tuple_type] = STATE(3039),
    [sym_readonly_type] = STATE(3007),
    [sym_union_type] = STATE(3039),
    [sym_intersection_type] = STATE(3039),
    [sym_function_type] = STATE(3007),
    [sym_identifier] = ACTIONS(1532),
    [anon_sym_STAR] = ACTIONS(115),
    [anon_sym_EQ] = ACTIONS(858),
    [anon_sym_as] = ACTIONS(120),
    [anon_sym_LBRACE] = ACTIONS(1534),
    [anon_sym_COMMA] = ACTIONS(154),
    [anon_sym_RBRACE] = ACTIONS(154),
    [anon_sym_typeof] = ACTIONS(1536),
    [anon_sym_import] = ACTIONS(1538),
    [anon_sym_const] = ACTIONS(133),
    [anon_sym_BANG] = ACTIONS(120),
    [anon_sym_LPAREN] = ACTIONS(1540),
    [anon_sym_SEMI] = ACTIONS(154),
    [anon_sym_in] = ACTIONS(120),
    [anon_sym_LBRACK] = ACTIONS(1542),
    [anon_sym_DOT] = ACTIONS(120),
    [anon_sym_EQ_GT] = ACTIONS(682),
    [anon_sym_QMARK_DOT] = ACTIONS(154),
    [anon_sym_new] = ACTIONS(1544),
    [anon_sym_PLUS_EQ] = ACTIONS(160),
    [anon_sym_DASH_EQ] = ACTIONS(160),
    [anon_sym_STAR_EQ] = ACTIONS(160),
    [anon_sym_SLASH_EQ] = ACTIONS(160),
    [anon_sym_PERCENT_EQ] = ACTIONS(160),
    [anon_sym_CARET_EQ] = ACTIONS(160),
    [anon_sym_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_LT_LT_EQ] = ACTIONS(160),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(160),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP] = ACTIONS(120),
    [anon_sym_PIPE_PIPE] = ACTIONS(120),
    [anon_sym_GT_GT] = ACTIONS(120),
    [anon_sym_GT_GT_GT] = ACTIONS(120),
    [anon_sym_LT_LT] = ACTIONS(120),
    [anon_sym_AMP] = ACTIONS(164),
    [anon_sym_CARET] = ACTIONS(120),
    [anon_sym_PIPE] = ACTIONS(166),
    [anon_sym_PLUS] = ACTIONS(1546),
    [anon_sym_DASH] = ACTIONS(1546),
    [anon_sym_SLASH] = ACTIONS(120),
    [anon_sym_PERCENT] = ACTIONS(120),
    [anon_sym_STAR_STAR] = ACTIONS(120),
    [anon_sym_LT] = ACTIONS(1548),
    [anon_sym_LT_EQ] = ACTIONS(154),
    [anon_sym_EQ_EQ] = ACTIONS(120),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(154),
    [anon_sym_BANG_EQ] = ACTIONS(120),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(154),
    [anon_sym_GT_EQ] = ACTIONS(154),
    [anon_sym_GT] = ACTIONS(120),
    [anon_sym_QMARK_QMARK] = ACTIONS(120),
    [anon_sym_instanceof] = ACTIONS(120),
    [anon_sym_void] = ACTIONS(216),
    [anon_sym_PLUS_PLUS] = ACTIONS(154),
    [anon_sym_DASH_DASH] = ACTIONS(154),
    [anon_sym_DQUOTE] = ACTIONS(1550),
    [anon_sym_SQUOTE] = ACTIONS(1552),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1554),
    [sym_number] = ACTIONS(1556),
    [sym_this] = ACTIONS(1558),
    [sym_true] = ACTIONS(1560),
    [sym_false] = ACTIONS(1560),
    [sym_null] = ACTIONS(1560),
    [sym_undefined] = ACTIONS(1560),
    [anon_sym_readonly] = ACTIONS(1562),
    [anon_sym_QMARK] = ACTIONS(204),
    [anon_sym_any] = ACTIONS(216),
    [anon_sym_number] = ACTIONS(216),
    [anon_sym_boolean] = ACTIONS(216),
    [anon_sym_string] = ACTIONS(216),
    [anon_sym_symbol] = ACTIONS(216),
    [anon_sym_object] = ACTIONS(216),
    [anon_sym_abstract] = ACTIONS(208),
    [anon_sym_satisfies] = ACTIONS(120),
    [anon_sym_infer] = ACTIONS(210),
    [anon_sym_keyof] = ACTIONS(212),
    [anon_sym_unique] = ACTIONS(214),
    [anon_sym_unknown] = ACTIONS(216),
    [anon_sym_never] = ACTIONS(216),
    [anon_sym_LBRACE_PIPE] = ACTIONS(218),
    [sym__automatic_semicolon] = ACTIONS(154),
    [sym__ternary_qmark] = ACTIONS(154),
    [sym_html_comment] = ACTIONS(5),
  },
  [176] = {
    [sym_import] = STATE(4878),
    [sym_nested_identifier] = STATE(5474),
    [sym_string] = STATE(2994),
    [sym_formal_parameters] = STATE(5475),
    [sym_nested_type_identifier] = STATE(2939),
    [sym__type_query_member_expression_in_type_annotation] = STATE(2937),
    [sym__type_query_call_expression_in_type_annotation] = STATE(2938),
    [sym_type] = STATE(3153),
    [sym_constructor_type] = STATE(3007),
    [sym_primary_type] = STATE(2981),
    [sym_template_literal_type] = STATE(3039),
    [sym_infer_type] = STATE(3007),
    [sym_conditional_type] = STATE(3039),
    [sym_generic_type] = STATE(3039),
    [sym_type_query] = STATE(3039),
    [sym_index_type_query] = STATE(3039),
    [sym_lookup_type] = STATE(3039),
    [sym_literal_type] = STATE(3039),
    [sym__number] = STATE(3041),
    [sym_existential_type] = STATE(3039),
    [sym_flow_maybe_type] = STATE(3039),
    [sym_parenthesized_type] = STATE(3039),
    [sym_predefined_type] = STATE(3039),
    [sym_object_type] = STATE(3039),
    [sym_type_parameters] = STATE(5248),
    [sym_array_type] = STATE(3039),
    [sym_tuple_type] = STATE(3039),
    [sym_readonly_type] = STATE(3007),
    [sym_union_type] = STATE(3039),
    [sym_intersection_type] = STATE(3039),
    [sym_function_type] = STATE(3007),
    [sym_identifier] = ACTIONS(1532),
    [anon_sym_STAR] = ACTIONS(115),
    [anon_sym_EQ] = ACTIONS(220),
    [anon_sym_as] = ACTIONS(120),
    [anon_sym_LBRACE] = ACTIONS(1534),
    [anon_sym_COMMA] = ACTIONS(223),
    [anon_sym_typeof] = ACTIONS(1536),
    [anon_sym_import] = ACTIONS(1538),
    [anon_sym_const] = ACTIONS(133),
    [anon_sym_BANG] = ACTIONS(120),
    [anon_sym_LPAREN] = ACTIONS(1540),
    [anon_sym_RPAREN] = ACTIONS(223),
    [anon_sym_in] = ACTIONS(120),
    [anon_sym_COLON] = ACTIONS(223),
    [anon_sym_LBRACK] = ACTIONS(1542),
    [anon_sym_DOT] = ACTIONS(120),
    [anon_sym_EQ_GT] = ACTIONS(225),
    [anon_sym_QMARK_DOT] = ACTIONS(154),
    [anon_sym_new] = ACTIONS(1544),
    [anon_sym_PLUS_EQ] = ACTIONS(160),
    [anon_sym_DASH_EQ] = ACTIONS(160),
    [anon_sym_STAR_EQ] = ACTIONS(160),
    [anon_sym_SLASH_EQ] = ACTIONS(160),
    [anon_sym_PERCENT_EQ] = ACTIONS(160),
    [anon_sym_CARET_EQ] = ACTIONS(160),
    [anon_sym_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_LT_LT_EQ] = ACTIONS(160),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(160),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP] = ACTIONS(120),
    [anon_sym_PIPE_PIPE] = ACTIONS(120),
    [anon_sym_GT_GT] = ACTIONS(120),
    [anon_sym_GT_GT_GT] = ACTIONS(120),
    [anon_sym_LT_LT] = ACTIONS(120),
    [anon_sym_AMP] = ACTIONS(164),
    [anon_sym_CARET] = ACTIONS(120),
    [anon_sym_PIPE] = ACTIONS(166),
    [anon_sym_PLUS] = ACTIONS(1546),
    [anon_sym_DASH] = ACTIONS(1546),
    [anon_sym_SLASH] = ACTIONS(120),
    [anon_sym_PERCENT] = ACTIONS(120),
    [anon_sym_STAR_STAR] = ACTIONS(120),
    [anon_sym_LT] = ACTIONS(1548),
    [anon_sym_LT_EQ] = ACTIONS(154),
    [anon_sym_EQ_EQ] = ACTIONS(120),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(154),
    [anon_sym_BANG_EQ] = ACTIONS(120),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(154),
    [anon_sym_GT_EQ] = ACTIONS(154),
    [anon_sym_GT] = ACTIONS(120),
    [anon_sym_QMARK_QMARK] = ACTIONS(120),
    [anon_sym_instanceof] = ACTIONS(120),
    [anon_sym_void] = ACTIONS(216),
    [anon_sym_PLUS_PLUS] = ACTIONS(154),
    [anon_sym_DASH_DASH] = ACTIONS(154),
    [anon_sym_DQUOTE] = ACTIONS(1550),
    [anon_sym_SQUOTE] = ACTIONS(1552),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1554),
    [sym_number] = ACTIONS(1556),
    [sym_this] = ACTIONS(1558),
    [sym_true] = ACTIONS(1560),
    [sym_false] = ACTIONS(1560),
    [sym_null] = ACTIONS(1560),
    [sym_undefined] = ACTIONS(1560),
    [anon_sym_readonly] = ACTIONS(1562),
    [anon_sym_QMARK] = ACTIONS(204),
    [anon_sym_any] = ACTIONS(216),
    [anon_sym_number] = ACTIONS(216),
    [anon_sym_boolean] = ACTIONS(216),
    [anon_sym_string] = ACTIONS(216),
    [anon_sym_symbol] = ACTIONS(216),
    [anon_sym_object] = ACTIONS(216),
    [anon_sym_abstract] = ACTIONS(208),
    [anon_sym_satisfies] = ACTIONS(120),
    [anon_sym_infer] = ACTIONS(210),
    [anon_sym_keyof] = ACTIONS(212),
    [anon_sym_unique] = ACTIONS(214),
    [anon_sym_unknown] = ACTIONS(216),
    [anon_sym_never] = ACTIONS(216),
    [anon_sym_LBRACE_PIPE] = ACTIONS(218),
    [sym__ternary_qmark] = ACTIONS(154),
    [sym_html_comment] = ACTIONS(5),
  },
  [177] = {
    [sym_import] = STATE(4878),
    [sym_nested_identifier] = STATE(5474),
    [sym_string] = STATE(2994),
    [sym_formal_parameters] = STATE(5475),
    [sym_nested_type_identifier] = STATE(2939),
    [sym__type_query_member_expression_in_type_annotation] = STATE(2937),
    [sym__type_query_call_expression_in_type_annotation] = STATE(2938),
    [sym_type] = STATE(3153),
    [sym_constructor_type] = STATE(3007),
    [sym_primary_type] = STATE(2981),
    [sym_template_literal_type] = STATE(3039),
    [sym_infer_type] = STATE(3007),
    [sym_conditional_type] = STATE(3039),
    [sym_generic_type] = STATE(3039),
    [sym_type_query] = STATE(3039),
    [sym_index_type_query] = STATE(3039),
    [sym_lookup_type] = STATE(3039),
    [sym_literal_type] = STATE(3039),
    [sym__number] = STATE(3041),
    [sym_existential_type] = STATE(3039),
    [sym_flow_maybe_type] = STATE(3039),
    [sym_parenthesized_type] = STATE(3039),
    [sym_predefined_type] = STATE(3039),
    [sym_object_type] = STATE(3039),
    [sym_type_parameters] = STATE(5248),
    [sym_array_type] = STATE(3039),
    [sym_tuple_type] = STATE(3039),
    [sym_readonly_type] = STATE(3007),
    [sym_union_type] = STATE(3039),
    [sym_intersection_type] = STATE(3039),
    [sym_function_type] = STATE(3007),
    [sym_identifier] = ACTIONS(1532),
    [anon_sym_STAR] = ACTIONS(115),
    [anon_sym_EQ] = ACTIONS(880),
    [anon_sym_as] = ACTIONS(120),
    [anon_sym_LBRACE] = ACTIONS(1534),
    [anon_sym_COMMA] = ACTIONS(154),
    [anon_sym_typeof] = ACTIONS(1536),
    [anon_sym_import] = ACTIONS(1538),
    [anon_sym_const] = ACTIONS(133),
    [anon_sym_BANG] = ACTIONS(120),
    [anon_sym_LPAREN] = ACTIONS(1540),
    [anon_sym_RPAREN] = ACTIONS(154),
    [anon_sym_in] = ACTIONS(120),
    [anon_sym_COLON] = ACTIONS(154),
    [anon_sym_LBRACK] = ACTIONS(1542),
    [anon_sym_DOT] = ACTIONS(120),
    [anon_sym_EQ_GT] = ACTIONS(152),
    [anon_sym_QMARK_DOT] = ACTIONS(154),
    [anon_sym_new] = ACTIONS(1544),
    [anon_sym_PLUS_EQ] = ACTIONS(160),
    [anon_sym_DASH_EQ] = ACTIONS(160),
    [anon_sym_STAR_EQ] = ACTIONS(160),
    [anon_sym_SLASH_EQ] = ACTIONS(160),
    [anon_sym_PERCENT_EQ] = ACTIONS(160),
    [anon_sym_CARET_EQ] = ACTIONS(160),
    [anon_sym_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_LT_LT_EQ] = ACTIONS(160),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(160),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP] = ACTIONS(120),
    [anon_sym_PIPE_PIPE] = ACTIONS(120),
    [anon_sym_GT_GT] = ACTIONS(120),
    [anon_sym_GT_GT_GT] = ACTIONS(120),
    [anon_sym_LT_LT] = ACTIONS(120),
    [anon_sym_AMP] = ACTIONS(164),
    [anon_sym_CARET] = ACTIONS(120),
    [anon_sym_PIPE] = ACTIONS(166),
    [anon_sym_PLUS] = ACTIONS(1546),
    [anon_sym_DASH] = ACTIONS(1546),
    [anon_sym_SLASH] = ACTIONS(120),
    [anon_sym_PERCENT] = ACTIONS(120),
    [anon_sym_STAR_STAR] = ACTIONS(120),
    [anon_sym_LT] = ACTIONS(1548),
    [anon_sym_LT_EQ] = ACTIONS(154),
    [anon_sym_EQ_EQ] = ACTIONS(120),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(154),
    [anon_sym_BANG_EQ] = ACTIONS(120),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(154),
    [anon_sym_GT_EQ] = ACTIONS(154),
    [anon_sym_GT] = ACTIONS(120),
    [anon_sym_QMARK_QMARK] = ACTIONS(120),
    [anon_sym_instanceof] = ACTIONS(120),
    [anon_sym_void] = ACTIONS(216),
    [anon_sym_PLUS_PLUS] = ACTIONS(154),
    [anon_sym_DASH_DASH] = ACTIONS(154),
    [anon_sym_DQUOTE] = ACTIONS(1550),
    [anon_sym_SQUOTE] = ACTIONS(1552),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1554),
    [sym_number] = ACTIONS(1556),
    [sym_this] = ACTIONS(1558),
    [sym_true] = ACTIONS(1560),
    [sym_false] = ACTIONS(1560),
    [sym_null] = ACTIONS(1560),
    [sym_undefined] = ACTIONS(1560),
    [anon_sym_readonly] = ACTIONS(1562),
    [anon_sym_QMARK] = ACTIONS(204),
    [anon_sym_any] = ACTIONS(216),
    [anon_sym_number] = ACTIONS(216),
    [anon_sym_boolean] = ACTIONS(216),
    [anon_sym_string] = ACTIONS(216),
    [anon_sym_symbol] = ACTIONS(216),
    [anon_sym_object] = ACTIONS(216),
    [anon_sym_abstract] = ACTIONS(208),
    [anon_sym_satisfies] = ACTIONS(120),
    [anon_sym_infer] = ACTIONS(210),
    [anon_sym_keyof] = ACTIONS(212),
    [anon_sym_unique] = ACTIONS(214),
    [anon_sym_unknown] = ACTIONS(216),
    [anon_sym_never] = ACTIONS(216),
    [anon_sym_LBRACE_PIPE] = ACTIONS(218),
    [sym__ternary_qmark] = ACTIONS(154),
    [sym_html_comment] = ACTIONS(5),
  },
  [178] = {
    [sym_import] = STATE(4878),
    [sym_nested_identifier] = STATE(5474),
    [sym_string] = STATE(2994),
    [sym_formal_parameters] = STATE(5475),
    [sym_nested_type_identifier] = STATE(2939),
    [sym__type_query_member_expression_in_type_annotation] = STATE(2937),
    [sym__type_query_call_expression_in_type_annotation] = STATE(2938),
    [sym_type] = STATE(3153),
    [sym_constructor_type] = STATE(3007),
    [sym_primary_type] = STATE(2981),
    [sym_template_literal_type] = STATE(3039),
    [sym_infer_type] = STATE(3007),
    [sym_conditional_type] = STATE(3039),
    [sym_generic_type] = STATE(3039),
    [sym_type_query] = STATE(3039),
    [sym_index_type_query] = STATE(3039),
    [sym_lookup_type] = STATE(3039),
    [sym_literal_type] = STATE(3039),
    [sym__number] = STATE(3041),
    [sym_existential_type] = STATE(3039),
    [sym_flow_maybe_type] = STATE(3039),
    [sym_parenthesized_type] = STATE(3039),
    [sym_predefined_type] = STATE(3039),
    [sym_object_type] = STATE(3039),
    [sym_type_parameters] = STATE(5248),
    [sym_array_type] = STATE(3039),
    [sym_tuple_type] = STATE(3039),
    [sym_readonly_type] = STATE(3007),
    [sym_union_type] = STATE(3039),
    [sym_intersection_type] = STATE(3039),
    [sym_function_type] = STATE(3007),
    [sym_identifier] = ACTIONS(1532),
    [anon_sym_STAR] = ACTIONS(115),
    [anon_sym_EQ] = ACTIONS(834),
    [anon_sym_as] = ACTIONS(120),
    [anon_sym_LBRACE] = ACTIONS(1534),
    [anon_sym_COMMA] = ACTIONS(899),
    [anon_sym_typeof] = ACTIONS(1536),
    [anon_sym_import] = ACTIONS(1538),
    [anon_sym_const] = ACTIONS(133),
    [anon_sym_BANG] = ACTIONS(120),
    [anon_sym_LPAREN] = ACTIONS(1540),
    [anon_sym_in] = ACTIONS(120),
    [anon_sym_COLON] = ACTIONS(826),
    [anon_sym_LBRACK] = ACTIONS(1542),
    [anon_sym_RBRACK] = ACTIONS(899),
    [anon_sym_DOT] = ACTIONS(120),
    [anon_sym_EQ_GT] = ACTIONS(844),
    [anon_sym_QMARK_DOT] = ACTIONS(154),
    [anon_sym_new] = ACTIONS(1544),
    [anon_sym_PLUS_EQ] = ACTIONS(160),
    [anon_sym_DASH_EQ] = ACTIONS(160),
    [anon_sym_STAR_EQ] = ACTIONS(160),
    [anon_sym_SLASH_EQ] = ACTIONS(160),
    [anon_sym_PERCENT_EQ] = ACTIONS(160),
    [anon_sym_CARET_EQ] = ACTIONS(160),
    [anon_sym_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_LT_LT_EQ] = ACTIONS(160),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(160),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP] = ACTIONS(120),
    [anon_sym_PIPE_PIPE] = ACTIONS(120),
    [anon_sym_GT_GT] = ACTIONS(120),
    [anon_sym_GT_GT_GT] = ACTIONS(120),
    [anon_sym_LT_LT] = ACTIONS(120),
    [anon_sym_AMP] = ACTIONS(164),
    [anon_sym_CARET] = ACTIONS(120),
    [anon_sym_PIPE] = ACTIONS(166),
    [anon_sym_PLUS] = ACTIONS(1546),
    [anon_sym_DASH] = ACTIONS(1546),
    [anon_sym_SLASH] = ACTIONS(120),
    [anon_sym_PERCENT] = ACTIONS(120),
    [anon_sym_STAR_STAR] = ACTIONS(120),
    [anon_sym_LT] = ACTIONS(1548),
    [anon_sym_LT_EQ] = ACTIONS(154),
    [anon_sym_EQ_EQ] = ACTIONS(120),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(154),
    [anon_sym_BANG_EQ] = ACTIONS(120),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(154),
    [anon_sym_GT_EQ] = ACTIONS(154),
    [anon_sym_GT] = ACTIONS(120),
    [anon_sym_QMARK_QMARK] = ACTIONS(120),
    [anon_sym_instanceof] = ACTIONS(120),
    [anon_sym_void] = ACTIONS(216),
    [anon_sym_PLUS_PLUS] = ACTIONS(154),
    [anon_sym_DASH_DASH] = ACTIONS(154),
    [anon_sym_DQUOTE] = ACTIONS(1550),
    [anon_sym_SQUOTE] = ACTIONS(1552),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1554),
    [sym_number] = ACTIONS(1556),
    [sym_this] = ACTIONS(1558),
    [sym_true] = ACTIONS(1560),
    [sym_false] = ACTIONS(1560),
    [sym_null] = ACTIONS(1560),
    [sym_undefined] = ACTIONS(1560),
    [anon_sym_readonly] = ACTIONS(1562),
    [anon_sym_QMARK] = ACTIONS(204),
    [anon_sym_any] = ACTIONS(216),
    [anon_sym_number] = ACTIONS(216),
    [anon_sym_boolean] = ACTIONS(216),
    [anon_sym_string] = ACTIONS(216),
    [anon_sym_symbol] = ACTIONS(216),
    [anon_sym_object] = ACTIONS(216),
    [anon_sym_abstract] = ACTIONS(208),
    [anon_sym_satisfies] = ACTIONS(120),
    [anon_sym_infer] = ACTIONS(210),
    [anon_sym_keyof] = ACTIONS(212),
    [anon_sym_unique] = ACTIONS(214),
    [anon_sym_unknown] = ACTIONS(216),
    [anon_sym_never] = ACTIONS(216),
    [anon_sym_LBRACE_PIPE] = ACTIONS(218),
    [sym__ternary_qmark] = ACTIONS(154),
    [sym_html_comment] = ACTIONS(5),
  },
  [179] = {
    [sym_declaration] = STATE(3992),
    [sym_import] = STATE(3636),
    [sym_variable_declaration] = STATE(4275),
    [sym_lexical_declaration] = STATE(4275),
    [sym_parenthesized_expression] = STATE(1410),
    [sym_expression] = STATE(2435),
    [sym_primary_expression] = STATE(1810),
    [sym_yield_expression] = STATE(2358),
    [sym_object] = STATE(2222),
    [sym_object_pattern] = STATE(5580),
    [sym_array] = STATE(2222),
    [sym_array_pattern] = STATE(5580),
    [sym_class] = STATE(2222),
    [sym_class_declaration] = STATE(4275),
    [sym_function_expression] = STATE(2222),
    [sym_function_declaration] = STATE(4275),
    [sym_generator_function] = STATE(2222),
    [sym_generator_function_declaration] = STATE(4275),
    [sym_arrow_function] = STATE(2222),
    [sym__call_signature] = STATE(5466),
    [sym_call_expression] = STATE(2222),
    [sym_new_expression] = STATE(1948),
    [sym_await_expression] = STATE(2358),
    [sym_member_expression] = STATE(1410),
    [sym_subscript_expression] = STATE(1410),
    [sym_assignment_expression] = STATE(2358),
    [sym__augmented_assignment_lhs] = STATE(3004),
    [sym_augmented_assignment_expression] = STATE(2358),
    [sym__destructuring_pattern] = STATE(5580),
    [sym_ternary_expression] = STATE(2358),
    [sym_binary_expression] = STATE(2358),
    [sym_unary_expression] = STATE(2358),
    [sym_update_expression] = STATE(2358),
    [sym_string] = STATE(2222),
    [sym_template_string] = STATE(2222),
    [sym_regex] = STATE(2222),
    [sym_meta_property] = STATE(2222),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1410),
    [sym_function_signature] = STATE(4275),
    [sym_type_assertion] = STATE(2358),
    [sym_as_expression] = STATE(2358),
    [sym_satisfies_expression] = STATE(2358),
    [sym_instantiation_expression] = STATE(2358),
    [sym_ambient_declaration] = STATE(4275),
    [sym_abstract_class_declaration] = STATE(4275),
    [sym_module] = STATE(4275),
    [sym_internal_module] = STATE(2453),
    [sym_import_alias] = STATE(4275),
    [sym_interface_declaration] = STATE(4275),
    [sym_enum_declaration] = STATE(4275),
    [sym_type_alias_declaration] = STATE(4275),
    [sym_type_arguments] = STATE(452),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4222),
    [sym_identifier] = ACTIONS(1498),
    [anon_sym_export] = ACTIONS(1270),
    [anon_sym_type] = ACTIONS(1564),
    [anon_sym_namespace] = ACTIONS(1272),
    [anon_sym_LBRACE] = ACTIONS(665),
    [anon_sym_typeof] = ACTIONS(1298),
    [anon_sym_import] = ACTIONS(1566),
    [anon_sym_var] = ACTIONS(1568),
    [anon_sym_let] = ACTIONS(1570),
    [anon_sym_const] = ACTIONS(1572),
    [anon_sym_BANG] = ACTIONS(1278),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_await] = ACTIONS(1282),
    [anon_sym_yield] = ACTIONS(1284),
    [anon_sym_LBRACK] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(1574),
    [anon_sym_async] = ACTIONS(1576),
    [anon_sym_function] = ACTIONS(1578),
    [anon_sym_new] = ACTIONS(1502),
    [anon_sym_using] = ACTIONS(1292),
    [anon_sym_PLUS] = ACTIONS(1298),
    [anon_sym_DASH] = ACTIONS(1298),
    [anon_sym_SLASH] = ACTIONS(77),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(1278),
    [anon_sym_void] = ACTIONS(1298),
    [anon_sym_delete] = ACTIONS(1298),
    [anon_sym_PLUS_PLUS] = ACTIONS(1300),
    [anon_sym_DASH_DASH] = ACTIONS(1300),
    [anon_sym_DQUOTE] = ACTIONS(83),
    [anon_sym_SQUOTE] = ACTIONS(85),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(87),
    [sym_number] = ACTIONS(89),
    [sym_private_property_identifier] = ACTIONS(1306),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(93),
    [sym_true] = ACTIONS(93),
    [sym_false] = ACTIONS(93),
    [sym_null] = ACTIONS(93),
    [sym_undefined] = ACTIONS(1504),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1270),
    [anon_sym_readonly] = ACTIONS(1270),
    [anon_sym_get] = ACTIONS(1270),
    [anon_sym_set] = ACTIONS(1270),
    [anon_sym_declare] = ACTIONS(1580),
    [anon_sym_public] = ACTIONS(1270),
    [anon_sym_private] = ACTIONS(1270),
    [anon_sym_protected] = ACTIONS(1270),
    [anon_sym_override] = ACTIONS(1270),
    [anon_sym_module] = ACTIONS(1582),
    [anon_sym_any] = ACTIONS(1270),
    [anon_sym_number] = ACTIONS(1270),
    [anon_sym_boolean] = ACTIONS(1270),
    [anon_sym_string] = ACTIONS(1270),
    [anon_sym_symbol] = ACTIONS(1270),
    [anon_sym_object] = ACTIONS(1270),
    [anon_sym_abstract] = ACTIONS(1584),
    [anon_sym_interface] = ACTIONS(1586),
    [anon_sym_enum] = ACTIONS(1588),
    [sym_html_comment] = ACTIONS(5),
  },
  [180] = {
    [sym_declaration] = STATE(937),
    [sym_import] = STATE(3636),
    [sym_variable_declaration] = STATE(831),
    [sym_lexical_declaration] = STATE(831),
    [sym_parenthesized_expression] = STATE(1410),
    [sym_expression] = STATE(2441),
    [sym_primary_expression] = STATE(1810),
    [sym_yield_expression] = STATE(2358),
    [sym_object] = STATE(2222),
    [sym_object_pattern] = STATE(5580),
    [sym_array] = STATE(2222),
    [sym_array_pattern] = STATE(5580),
    [sym_class] = STATE(2222),
    [sym_class_declaration] = STATE(831),
    [sym_function_expression] = STATE(2222),
    [sym_function_declaration] = STATE(831),
    [sym_generator_function] = STATE(2222),
    [sym_generator_function_declaration] = STATE(831),
    [sym_arrow_function] = STATE(2222),
    [sym__call_signature] = STATE(5466),
    [sym_call_expression] = STATE(2222),
    [sym_new_expression] = STATE(1948),
    [sym_await_expression] = STATE(2358),
    [sym_member_expression] = STATE(1410),
    [sym_subscript_expression] = STATE(1410),
    [sym_assignment_expression] = STATE(2358),
    [sym__augmented_assignment_lhs] = STATE(3004),
    [sym_augmented_assignment_expression] = STATE(2358),
    [sym__destructuring_pattern] = STATE(5580),
    [sym_ternary_expression] = STATE(2358),
    [sym_binary_expression] = STATE(2358),
    [sym_unary_expression] = STATE(2358),
    [sym_update_expression] = STATE(2358),
    [sym_string] = STATE(2222),
    [sym_template_string] = STATE(2222),
    [sym_regex] = STATE(2222),
    [sym_meta_property] = STATE(2222),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1410),
    [sym_function_signature] = STATE(831),
    [sym_type_assertion] = STATE(2358),
    [sym_as_expression] = STATE(2358),
    [sym_satisfies_expression] = STATE(2358),
    [sym_instantiation_expression] = STATE(2358),
    [sym_ambient_declaration] = STATE(831),
    [sym_abstract_class_declaration] = STATE(831),
    [sym_module] = STATE(831),
    [sym_internal_module] = STATE(214),
    [sym_import_alias] = STATE(831),
    [sym_interface_declaration] = STATE(831),
    [sym_enum_declaration] = STATE(831),
    [sym_type_alias_declaration] = STATE(831),
    [sym_type_arguments] = STATE(452),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4150),
    [sym_identifier] = ACTIONS(1498),
    [anon_sym_export] = ACTIONS(1270),
    [anon_sym_type] = ACTIONS(1590),
    [anon_sym_namespace] = ACTIONS(1592),
    [anon_sym_LBRACE] = ACTIONS(665),
    [anon_sym_typeof] = ACTIONS(1298),
    [anon_sym_import] = ACTIONS(1594),
    [anon_sym_var] = ACTIONS(27),
    [anon_sym_let] = ACTIONS(1596),
    [anon_sym_const] = ACTIONS(31),
    [anon_sym_BANG] = ACTIONS(1278),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_await] = ACTIONS(1282),
    [anon_sym_yield] = ACTIONS(1284),
    [anon_sym_LBRACK] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(67),
    [anon_sym_async] = ACTIONS(1598),
    [anon_sym_function] = ACTIONS(71),
    [anon_sym_new] = ACTIONS(1502),
    [anon_sym_using] = ACTIONS(1292),
    [anon_sym_PLUS] = ACTIONS(1298),
    [anon_sym_DASH] = ACTIONS(1298),
    [anon_sym_SLASH] = ACTIONS(77),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(1278),
    [anon_sym_void] = ACTIONS(1298),
    [anon_sym_delete] = ACTIONS(1298),
    [anon_sym_PLUS_PLUS] = ACTIONS(1300),
    [anon_sym_DASH_DASH] = ACTIONS(1300),
    [anon_sym_DQUOTE] = ACTIONS(83),
    [anon_sym_SQUOTE] = ACTIONS(85),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(87),
    [sym_number] = ACTIONS(89),
    [sym_private_property_identifier] = ACTIONS(1306),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(93),
    [sym_true] = ACTIONS(93),
    [sym_false] = ACTIONS(93),
    [sym_null] = ACTIONS(93),
    [sym_undefined] = ACTIONS(1504),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1270),
    [anon_sym_readonly] = ACTIONS(1270),
    [anon_sym_get] = ACTIONS(1270),
    [anon_sym_set] = ACTIONS(1270),
    [anon_sym_declare] = ACTIONS(1600),
    [anon_sym_public] = ACTIONS(1270),
    [anon_sym_private] = ACTIONS(1270),
    [anon_sym_protected] = ACTIONS(1270),
    [anon_sym_override] = ACTIONS(1270),
    [anon_sym_module] = ACTIONS(1602),
    [anon_sym_any] = ACTIONS(1270),
    [anon_sym_number] = ACTIONS(1270),
    [anon_sym_boolean] = ACTIONS(1270),
    [anon_sym_string] = ACTIONS(1270),
    [anon_sym_symbol] = ACTIONS(1270),
    [anon_sym_object] = ACTIONS(1270),
    [anon_sym_abstract] = ACTIONS(105),
    [anon_sym_interface] = ACTIONS(107),
    [anon_sym_enum] = ACTIONS(109),
    [sym_html_comment] = ACTIONS(5),
  },
  [181] = {
    [sym_declaration] = STATE(937),
    [sym_import] = STATE(3636),
    [sym_variable_declaration] = STATE(831),
    [sym_lexical_declaration] = STATE(831),
    [sym_parenthesized_expression] = STATE(1410),
    [sym_expression] = STATE(2441),
    [sym_primary_expression] = STATE(1810),
    [sym_yield_expression] = STATE(2358),
    [sym_object] = STATE(2222),
    [sym_object_pattern] = STATE(5580),
    [sym_array] = STATE(2222),
    [sym_array_pattern] = STATE(5580),
    [sym_class] = STATE(2222),
    [sym_class_declaration] = STATE(831),
    [sym_function_expression] = STATE(2222),
    [sym_function_declaration] = STATE(831),
    [sym_generator_function] = STATE(2222),
    [sym_generator_function_declaration] = STATE(831),
    [sym_arrow_function] = STATE(2222),
    [sym__call_signature] = STATE(5466),
    [sym_call_expression] = STATE(2222),
    [sym_new_expression] = STATE(1948),
    [sym_await_expression] = STATE(2358),
    [sym_member_expression] = STATE(1410),
    [sym_subscript_expression] = STATE(1410),
    [sym_assignment_expression] = STATE(2358),
    [sym__augmented_assignment_lhs] = STATE(3004),
    [sym_augmented_assignment_expression] = STATE(2358),
    [sym__destructuring_pattern] = STATE(5580),
    [sym_ternary_expression] = STATE(2358),
    [sym_binary_expression] = STATE(2358),
    [sym_unary_expression] = STATE(2358),
    [sym_update_expression] = STATE(2358),
    [sym_string] = STATE(2222),
    [sym_template_string] = STATE(2222),
    [sym_regex] = STATE(2222),
    [sym_meta_property] = STATE(2222),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1410),
    [sym_function_signature] = STATE(831),
    [sym_type_assertion] = STATE(2358),
    [sym_as_expression] = STATE(2358),
    [sym_satisfies_expression] = STATE(2358),
    [sym_instantiation_expression] = STATE(2358),
    [sym_ambient_declaration] = STATE(831),
    [sym_abstract_class_declaration] = STATE(831),
    [sym_module] = STATE(831),
    [sym_internal_module] = STATE(2513),
    [sym_import_alias] = STATE(831),
    [sym_interface_declaration] = STATE(831),
    [sym_enum_declaration] = STATE(831),
    [sym_type_alias_declaration] = STATE(831),
    [sym_type_arguments] = STATE(452),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4153),
    [sym_identifier] = ACTIONS(1498),
    [anon_sym_export] = ACTIONS(1270),
    [anon_sym_type] = ACTIONS(1590),
    [anon_sym_namespace] = ACTIONS(1272),
    [anon_sym_LBRACE] = ACTIONS(665),
    [anon_sym_typeof] = ACTIONS(1298),
    [anon_sym_import] = ACTIONS(1594),
    [anon_sym_var] = ACTIONS(27),
    [anon_sym_let] = ACTIONS(1596),
    [anon_sym_const] = ACTIONS(31),
    [anon_sym_BANG] = ACTIONS(1278),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_await] = ACTIONS(1282),
    [anon_sym_yield] = ACTIONS(1284),
    [anon_sym_LBRACK] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(623),
    [anon_sym_async] = ACTIONS(1604),
    [anon_sym_function] = ACTIONS(627),
    [anon_sym_new] = ACTIONS(1502),
    [anon_sym_using] = ACTIONS(1292),
    [anon_sym_PLUS] = ACTIONS(1298),
    [anon_sym_DASH] = ACTIONS(1298),
    [anon_sym_SLASH] = ACTIONS(77),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(1278),
    [anon_sym_void] = ACTIONS(1298),
    [anon_sym_delete] = ACTIONS(1298),
    [anon_sym_PLUS_PLUS] = ACTIONS(1300),
    [anon_sym_DASH_DASH] = ACTIONS(1300),
    [anon_sym_DQUOTE] = ACTIONS(83),
    [anon_sym_SQUOTE] = ACTIONS(85),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(87),
    [sym_number] = ACTIONS(89),
    [sym_private_property_identifier] = ACTIONS(1306),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(93),
    [sym_true] = ACTIONS(93),
    [sym_false] = ACTIONS(93),
    [sym_null] = ACTIONS(93),
    [sym_undefined] = ACTIONS(1504),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1270),
    [anon_sym_readonly] = ACTIONS(1270),
    [anon_sym_get] = ACTIONS(1270),
    [anon_sym_set] = ACTIONS(1270),
    [anon_sym_declare] = ACTIONS(1600),
    [anon_sym_public] = ACTIONS(1270),
    [anon_sym_private] = ACTIONS(1270),
    [anon_sym_protected] = ACTIONS(1270),
    [anon_sym_override] = ACTIONS(1270),
    [anon_sym_module] = ACTIONS(1602),
    [anon_sym_any] = ACTIONS(1270),
    [anon_sym_number] = ACTIONS(1270),
    [anon_sym_boolean] = ACTIONS(1270),
    [anon_sym_string] = ACTIONS(1270),
    [anon_sym_symbol] = ACTIONS(1270),
    [anon_sym_object] = ACTIONS(1270),
    [anon_sym_abstract] = ACTIONS(105),
    [anon_sym_interface] = ACTIONS(107),
    [anon_sym_enum] = ACTIONS(109),
    [sym_html_comment] = ACTIONS(5),
  },
  [182] = {
    [sym_import] = STATE(4950),
    [sym_nested_identifier] = STATE(5535),
    [sym_string] = STATE(3265),
    [sym_formal_parameters] = STATE(5840),
    [sym_nested_type_identifier] = STATE(3151),
    [sym__type_query_member_expression_in_type_annotation] = STATE(3076),
    [sym__type_query_call_expression_in_type_annotation] = STATE(3200),
    [sym_type] = STATE(3222),
    [sym_constructor_type] = STATE(3271),
    [sym_primary_type] = STATE(3272),
    [sym_template_literal_type] = STATE(3273),
    [sym_infer_type] = STATE(3271),
    [sym_conditional_type] = STATE(3273),
    [sym_generic_type] = STATE(3273),
    [sym_type_query] = STATE(3273),
    [sym_index_type_query] = STATE(3273),
    [sym_lookup_type] = STATE(3273),
    [sym_literal_type] = STATE(3273),
    [sym__number] = STATE(3274),
    [sym_existential_type] = STATE(3273),
    [sym_flow_maybe_type] = STATE(3273),
    [sym_parenthesized_type] = STATE(3273),
    [sym_predefined_type] = STATE(3273),
    [sym_object_type] = STATE(3273),
    [sym_type_parameters] = STATE(5146),
    [sym_array_type] = STATE(3273),
    [sym_tuple_type] = STATE(3273),
    [sym_readonly_type] = STATE(3271),
    [sym_union_type] = STATE(3273),
    [sym_intersection_type] = STATE(3273),
    [sym_function_type] = STATE(3271),
    [sym_identifier] = ACTIONS(1606),
    [anon_sym_STAR] = ACTIONS(1608),
    [anon_sym_EQ] = ACTIONS(907),
    [anon_sym_as] = ACTIONS(120),
    [anon_sym_LBRACE] = ACTIONS(1610),
    [anon_sym_COMMA] = ACTIONS(126),
    [anon_sym_RBRACE] = ACTIONS(126),
    [anon_sym_typeof] = ACTIONS(1612),
    [anon_sym_import] = ACTIONS(1538),
    [anon_sym_const] = ACTIONS(992),
    [anon_sym_BANG] = ACTIONS(120),
    [anon_sym_LPAREN] = ACTIONS(1614),
    [anon_sym_in] = ACTIONS(120),
    [anon_sym_LBRACK] = ACTIONS(1616),
    [anon_sym_DOT] = ACTIONS(120),
    [anon_sym_EQ_GT] = ACTIONS(844),
    [anon_sym_QMARK_DOT] = ACTIONS(154),
    [anon_sym_new] = ACTIONS(1618),
    [anon_sym_PLUS_EQ] = ACTIONS(160),
    [anon_sym_DASH_EQ] = ACTIONS(160),
    [anon_sym_STAR_EQ] = ACTIONS(160),
    [anon_sym_SLASH_EQ] = ACTIONS(160),
    [anon_sym_PERCENT_EQ] = ACTIONS(160),
    [anon_sym_CARET_EQ] = ACTIONS(160),
    [anon_sym_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_LT_LT_EQ] = ACTIONS(160),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(160),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP] = ACTIONS(120),
    [anon_sym_PIPE_PIPE] = ACTIONS(120),
    [anon_sym_GT_GT] = ACTIONS(120),
    [anon_sym_GT_GT_GT] = ACTIONS(120),
    [anon_sym_LT_LT] = ACTIONS(120),
    [anon_sym_AMP] = ACTIONS(1620),
    [anon_sym_CARET] = ACTIONS(120),
    [anon_sym_PIPE] = ACTIONS(1622),
    [anon_sym_PLUS] = ACTIONS(1624),
    [anon_sym_DASH] = ACTIONS(1624),
    [anon_sym_SLASH] = ACTIONS(120),
    [anon_sym_PERCENT] = ACTIONS(120),
    [anon_sym_STAR_STAR] = ACTIONS(120),
    [anon_sym_LT] = ACTIONS(1548),
    [anon_sym_LT_EQ] = ACTIONS(154),
    [anon_sym_EQ_EQ] = ACTIONS(120),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(154),
    [anon_sym_BANG_EQ] = ACTIONS(120),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(154),
    [anon_sym_GT_EQ] = ACTIONS(154),
    [anon_sym_GT] = ACTIONS(120),
    [anon_sym_QMARK_QMARK] = ACTIONS(120),
    [anon_sym_instanceof] = ACTIONS(120),
    [anon_sym_void] = ACTIONS(1032),
    [anon_sym_PLUS_PLUS] = ACTIONS(154),
    [anon_sym_DASH_DASH] = ACTIONS(154),
    [anon_sym_DQUOTE] = ACTIONS(1626),
    [anon_sym_SQUOTE] = ACTIONS(1628),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1630),
    [sym_number] = ACTIONS(1632),
    [sym_this] = ACTIONS(1634),
    [sym_true] = ACTIONS(1636),
    [sym_false] = ACTIONS(1636),
    [sym_null] = ACTIONS(1636),
    [sym_undefined] = ACTIONS(1636),
    [anon_sym_readonly] = ACTIONS(1638),
    [anon_sym_QMARK] = ACTIONS(1640),
    [anon_sym_any] = ACTIONS(1032),
    [anon_sym_number] = ACTIONS(1032),
    [anon_sym_boolean] = ACTIONS(1032),
    [anon_sym_string] = ACTIONS(1032),
    [anon_sym_symbol] = ACTIONS(1032),
    [anon_sym_object] = ACTIONS(1032),
    [anon_sym_abstract] = ACTIONS(1024),
    [anon_sym_satisfies] = ACTIONS(120),
    [anon_sym_infer] = ACTIONS(1026),
    [anon_sym_keyof] = ACTIONS(1028),
    [anon_sym_unique] = ACTIONS(1030),
    [anon_sym_unknown] = ACTIONS(1032),
    [anon_sym_never] = ACTIONS(1032),
    [anon_sym_LBRACE_PIPE] = ACTIONS(1034),
    [sym__ternary_qmark] = ACTIONS(154),
    [sym_html_comment] = ACTIONS(5),
  },
  [183] = {
    [sym_import] = STATE(4878),
    [sym_nested_identifier] = STATE(5474),
    [sym_string] = STATE(2994),
    [sym_formal_parameters] = STATE(5475),
    [sym_nested_type_identifier] = STATE(2939),
    [sym__type_query_member_expression_in_type_annotation] = STATE(2937),
    [sym__type_query_call_expression_in_type_annotation] = STATE(2938),
    [sym_type] = STATE(3153),
    [sym_constructor_type] = STATE(3007),
    [sym_primary_type] = STATE(2981),
    [sym_template_literal_type] = STATE(3039),
    [sym_infer_type] = STATE(3007),
    [sym_conditional_type] = STATE(3039),
    [sym_generic_type] = STATE(3039),
    [sym_type_query] = STATE(3039),
    [sym_index_type_query] = STATE(3039),
    [sym_lookup_type] = STATE(3039),
    [sym_literal_type] = STATE(3039),
    [sym__number] = STATE(3041),
    [sym_existential_type] = STATE(3039),
    [sym_flow_maybe_type] = STATE(3039),
    [sym_parenthesized_type] = STATE(3039),
    [sym_predefined_type] = STATE(3039),
    [sym_object_type] = STATE(3039),
    [sym_type_parameters] = STATE(5248),
    [sym_array_type] = STATE(3039),
    [sym_tuple_type] = STATE(3039),
    [sym_readonly_type] = STATE(3007),
    [sym_union_type] = STATE(3039),
    [sym_intersection_type] = STATE(3039),
    [sym_function_type] = STATE(3007),
    [sym_identifier] = ACTIONS(1532),
    [anon_sym_STAR] = ACTIONS(115),
    [anon_sym_EQ] = ACTIONS(918),
    [anon_sym_as] = ACTIONS(120),
    [anon_sym_LBRACE] = ACTIONS(1534),
    [anon_sym_typeof] = ACTIONS(1536),
    [anon_sym_import] = ACTIONS(1538),
    [anon_sym_const] = ACTIONS(133),
    [anon_sym_BANG] = ACTIONS(120),
    [anon_sym_LPAREN] = ACTIONS(1540),
    [anon_sym_SEMI] = ACTIONS(154),
    [anon_sym_in] = ACTIONS(120),
    [anon_sym_LBRACK] = ACTIONS(1542),
    [anon_sym_DOT] = ACTIONS(120),
    [anon_sym_EQ_GT] = ACTIONS(924),
    [anon_sym_QMARK_DOT] = ACTIONS(154),
    [anon_sym_new] = ACTIONS(1544),
    [anon_sym_PLUS_EQ] = ACTIONS(160),
    [anon_sym_DASH_EQ] = ACTIONS(160),
    [anon_sym_STAR_EQ] = ACTIONS(160),
    [anon_sym_SLASH_EQ] = ACTIONS(160),
    [anon_sym_PERCENT_EQ] = ACTIONS(160),
    [anon_sym_CARET_EQ] = ACTIONS(160),
    [anon_sym_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_LT_LT_EQ] = ACTIONS(160),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(160),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP] = ACTIONS(120),
    [anon_sym_PIPE_PIPE] = ACTIONS(120),
    [anon_sym_GT_GT] = ACTIONS(120),
    [anon_sym_GT_GT_GT] = ACTIONS(120),
    [anon_sym_LT_LT] = ACTIONS(120),
    [anon_sym_AMP] = ACTIONS(164),
    [anon_sym_CARET] = ACTIONS(120),
    [anon_sym_PIPE] = ACTIONS(166),
    [anon_sym_PLUS] = ACTIONS(1546),
    [anon_sym_DASH] = ACTIONS(1546),
    [anon_sym_SLASH] = ACTIONS(120),
    [anon_sym_PERCENT] = ACTIONS(120),
    [anon_sym_STAR_STAR] = ACTIONS(120),
    [anon_sym_LT] = ACTIONS(1548),
    [anon_sym_LT_EQ] = ACTIONS(154),
    [anon_sym_EQ_EQ] = ACTIONS(120),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(154),
    [anon_sym_BANG_EQ] = ACTIONS(120),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(154),
    [anon_sym_GT_EQ] = ACTIONS(154),
    [anon_sym_GT] = ACTIONS(120),
    [anon_sym_QMARK_QMARK] = ACTIONS(120),
    [anon_sym_instanceof] = ACTIONS(120),
    [anon_sym_void] = ACTIONS(216),
    [anon_sym_PLUS_PLUS] = ACTIONS(154),
    [anon_sym_DASH_DASH] = ACTIONS(154),
    [anon_sym_DQUOTE] = ACTIONS(1550),
    [anon_sym_SQUOTE] = ACTIONS(1552),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1554),
    [sym_number] = ACTIONS(1556),
    [sym_this] = ACTIONS(1558),
    [sym_true] = ACTIONS(1560),
    [sym_false] = ACTIONS(1560),
    [sym_null] = ACTIONS(1560),
    [sym_undefined] = ACTIONS(1560),
    [anon_sym_readonly] = ACTIONS(1562),
    [anon_sym_QMARK] = ACTIONS(204),
    [anon_sym_any] = ACTIONS(216),
    [anon_sym_number] = ACTIONS(216),
    [anon_sym_boolean] = ACTIONS(216),
    [anon_sym_string] = ACTIONS(216),
    [anon_sym_symbol] = ACTIONS(216),
    [anon_sym_object] = ACTIONS(216),
    [anon_sym_abstract] = ACTIONS(208),
    [anon_sym_satisfies] = ACTIONS(120),
    [anon_sym_infer] = ACTIONS(210),
    [anon_sym_keyof] = ACTIONS(212),
    [anon_sym_unique] = ACTIONS(214),
    [anon_sym_unknown] = ACTIONS(216),
    [anon_sym_never] = ACTIONS(216),
    [anon_sym_LBRACE_PIPE] = ACTIONS(218),
    [sym__automatic_semicolon] = ACTIONS(154),
    [sym__ternary_qmark] = ACTIONS(154),
    [sym_html_comment] = ACTIONS(5),
  },
  [184] = {
    [sym_declaration] = STATE(873),
    [sym_import] = STATE(3636),
    [sym_variable_declaration] = STATE(831),
    [sym_lexical_declaration] = STATE(831),
    [sym_parenthesized_expression] = STATE(1410),
    [sym_expression] = STATE(2454),
    [sym_primary_expression] = STATE(1810),
    [sym_yield_expression] = STATE(2358),
    [sym_object] = STATE(2222),
    [sym_object_pattern] = STATE(5580),
    [sym_array] = STATE(2222),
    [sym_array_pattern] = STATE(5580),
    [sym_class] = STATE(2222),
    [sym_class_declaration] = STATE(831),
    [sym_function_expression] = STATE(2222),
    [sym_function_declaration] = STATE(831),
    [sym_generator_function] = STATE(2222),
    [sym_generator_function_declaration] = STATE(831),
    [sym_arrow_function] = STATE(2222),
    [sym__call_signature] = STATE(5466),
    [sym_call_expression] = STATE(2222),
    [sym_new_expression] = STATE(1948),
    [sym_await_expression] = STATE(2358),
    [sym_member_expression] = STATE(1410),
    [sym_subscript_expression] = STATE(1410),
    [sym_assignment_expression] = STATE(2358),
    [sym__augmented_assignment_lhs] = STATE(3004),
    [sym_augmented_assignment_expression] = STATE(2358),
    [sym__destructuring_pattern] = STATE(5580),
    [sym_ternary_expression] = STATE(2358),
    [sym_binary_expression] = STATE(2358),
    [sym_unary_expression] = STATE(2358),
    [sym_update_expression] = STATE(2358),
    [sym_string] = STATE(2222),
    [sym_template_string] = STATE(2222),
    [sym_regex] = STATE(2222),
    [sym_meta_property] = STATE(2222),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1410),
    [sym_function_signature] = STATE(831),
    [sym_type_assertion] = STATE(2358),
    [sym_as_expression] = STATE(2358),
    [sym_satisfies_expression] = STATE(2358),
    [sym_instantiation_expression] = STATE(2358),
    [sym_ambient_declaration] = STATE(831),
    [sym_abstract_class_declaration] = STATE(831),
    [sym_module] = STATE(831),
    [sym_internal_module] = STATE(2513),
    [sym_import_alias] = STATE(831),
    [sym_interface_declaration] = STATE(831),
    [sym_enum_declaration] = STATE(831),
    [sym_type_alias_declaration] = STATE(831),
    [sym_type_arguments] = STATE(452),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4153),
    [sym_identifier] = ACTIONS(1498),
    [anon_sym_export] = ACTIONS(1270),
    [anon_sym_type] = ACTIONS(1590),
    [anon_sym_namespace] = ACTIONS(1272),
    [anon_sym_LBRACE] = ACTIONS(665),
    [anon_sym_typeof] = ACTIONS(1298),
    [anon_sym_import] = ACTIONS(1594),
    [anon_sym_var] = ACTIONS(27),
    [anon_sym_let] = ACTIONS(1596),
    [anon_sym_const] = ACTIONS(31),
    [anon_sym_BANG] = ACTIONS(1278),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_await] = ACTIONS(1282),
    [anon_sym_yield] = ACTIONS(1284),
    [anon_sym_LBRACK] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(623),
    [anon_sym_async] = ACTIONS(1604),
    [anon_sym_function] = ACTIONS(627),
    [anon_sym_new] = ACTIONS(1502),
    [anon_sym_using] = ACTIONS(1292),
    [anon_sym_PLUS] = ACTIONS(1298),
    [anon_sym_DASH] = ACTIONS(1298),
    [anon_sym_SLASH] = ACTIONS(77),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(1278),
    [anon_sym_void] = ACTIONS(1298),
    [anon_sym_delete] = ACTIONS(1298),
    [anon_sym_PLUS_PLUS] = ACTIONS(1300),
    [anon_sym_DASH_DASH] = ACTIONS(1300),
    [anon_sym_DQUOTE] = ACTIONS(83),
    [anon_sym_SQUOTE] = ACTIONS(85),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(87),
    [sym_number] = ACTIONS(89),
    [sym_private_property_identifier] = ACTIONS(1306),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(93),
    [sym_true] = ACTIONS(93),
    [sym_false] = ACTIONS(93),
    [sym_null] = ACTIONS(93),
    [sym_undefined] = ACTIONS(1504),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1270),
    [anon_sym_readonly] = ACTIONS(1270),
    [anon_sym_get] = ACTIONS(1270),
    [anon_sym_set] = ACTIONS(1270),
    [anon_sym_declare] = ACTIONS(1600),
    [anon_sym_public] = ACTIONS(1270),
    [anon_sym_private] = ACTIONS(1270),
    [anon_sym_protected] = ACTIONS(1270),
    [anon_sym_override] = ACTIONS(1270),
    [anon_sym_module] = ACTIONS(1602),
    [anon_sym_any] = ACTIONS(1270),
    [anon_sym_number] = ACTIONS(1270),
    [anon_sym_boolean] = ACTIONS(1270),
    [anon_sym_string] = ACTIONS(1270),
    [anon_sym_symbol] = ACTIONS(1270),
    [anon_sym_object] = ACTIONS(1270),
    [anon_sym_abstract] = ACTIONS(105),
    [anon_sym_interface] = ACTIONS(107),
    [anon_sym_enum] = ACTIONS(109),
    [sym_html_comment] = ACTIONS(5),
  },
  [185] = {
    [sym_import] = STATE(4681),
    [sym_nested_identifier] = STATE(5474),
    [sym_string] = STATE(2994),
    [sym_formal_parameters] = STATE(5619),
    [sym_nested_type_identifier] = STATE(2939),
    [sym__type_query_member_expression_in_type_annotation] = STATE(3303),
    [sym__type_query_call_expression_in_type_annotation] = STATE(2938),
    [sym_type] = STATE(3661),
    [sym_constructor_type] = STATE(3007),
    [sym_primary_type] = STATE(2981),
    [sym_template_literal_type] = STATE(3039),
    [sym_infer_type] = STATE(3007),
    [sym_conditional_type] = STATE(3039),
    [sym_generic_type] = STATE(3039),
    [sym_type_query] = STATE(3039),
    [sym_index_type_query] = STATE(3039),
    [sym_lookup_type] = STATE(3039),
    [sym_literal_type] = STATE(3039),
    [sym__number] = STATE(3041),
    [sym_existential_type] = STATE(3039),
    [sym_flow_maybe_type] = STATE(3039),
    [sym_parenthesized_type] = STATE(3039),
    [sym_predefined_type] = STATE(3039),
    [sym_object_type] = STATE(3039),
    [sym_type_parameters] = STATE(5454),
    [sym_array_type] = STATE(3039),
    [sym_tuple_type] = STATE(3039),
    [sym_readonly_type] = STATE(3007),
    [sym_union_type] = STATE(3039),
    [sym_intersection_type] = STATE(3039),
    [sym_function_type] = STATE(3007),
    [sym_identifier] = ACTIONS(1532),
    [anon_sym_STAR] = ACTIONS(115),
    [anon_sym_EQ] = ACTIONS(907),
    [anon_sym_as] = ACTIONS(120),
    [anon_sym_LBRACE] = ACTIONS(1534),
    [anon_sym_COMMA] = ACTIONS(126),
    [anon_sym_typeof] = ACTIONS(1536),
    [anon_sym_import] = ACTIONS(1538),
    [anon_sym_const] = ACTIONS(133),
    [anon_sym_BANG] = ACTIONS(120),
    [anon_sym_LPAREN] = ACTIONS(1540),
    [anon_sym_in] = ACTIONS(120),
    [anon_sym_LBRACK] = ACTIONS(1542),
    [anon_sym_RBRACK] = ACTIONS(126),
    [anon_sym_DOT] = ACTIONS(120),
    [anon_sym_EQ_GT] = ACTIONS(844),
    [anon_sym_QMARK_DOT] = ACTIONS(154),
    [anon_sym_new] = ACTIONS(1642),
    [anon_sym_PLUS_EQ] = ACTIONS(160),
    [anon_sym_DASH_EQ] = ACTIONS(160),
    [anon_sym_STAR_EQ] = ACTIONS(160),
    [anon_sym_SLASH_EQ] = ACTIONS(160),
    [anon_sym_PERCENT_EQ] = ACTIONS(160),
    [anon_sym_CARET_EQ] = ACTIONS(160),
    [anon_sym_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_LT_LT_EQ] = ACTIONS(160),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(160),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP] = ACTIONS(120),
    [anon_sym_PIPE_PIPE] = ACTIONS(120),
    [anon_sym_GT_GT] = ACTIONS(120),
    [anon_sym_GT_GT_GT] = ACTIONS(120),
    [anon_sym_LT_LT] = ACTIONS(120),
    [anon_sym_AMP] = ACTIONS(1644),
    [anon_sym_CARET] = ACTIONS(120),
    [anon_sym_PIPE] = ACTIONS(1646),
    [anon_sym_PLUS] = ACTIONS(1546),
    [anon_sym_DASH] = ACTIONS(1546),
    [anon_sym_SLASH] = ACTIONS(120),
    [anon_sym_PERCENT] = ACTIONS(120),
    [anon_sym_STAR_STAR] = ACTIONS(120),
    [anon_sym_LT] = ACTIONS(1548),
    [anon_sym_LT_EQ] = ACTIONS(154),
    [anon_sym_EQ_EQ] = ACTIONS(120),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(154),
    [anon_sym_BANG_EQ] = ACTIONS(120),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(154),
    [anon_sym_GT_EQ] = ACTIONS(154),
    [anon_sym_GT] = ACTIONS(120),
    [anon_sym_QMARK_QMARK] = ACTIONS(120),
    [anon_sym_instanceof] = ACTIONS(120),
    [anon_sym_void] = ACTIONS(216),
    [anon_sym_PLUS_PLUS] = ACTIONS(154),
    [anon_sym_DASH_DASH] = ACTIONS(154),
    [anon_sym_DQUOTE] = ACTIONS(1550),
    [anon_sym_SQUOTE] = ACTIONS(1552),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1554),
    [sym_number] = ACTIONS(1556),
    [sym_this] = ACTIONS(1558),
    [sym_true] = ACTIONS(1560),
    [sym_false] = ACTIONS(1560),
    [sym_null] = ACTIONS(1560),
    [sym_undefined] = ACTIONS(1560),
    [anon_sym_readonly] = ACTIONS(1648),
    [anon_sym_QMARK] = ACTIONS(1650),
    [anon_sym_any] = ACTIONS(216),
    [anon_sym_number] = ACTIONS(216),
    [anon_sym_boolean] = ACTIONS(216),
    [anon_sym_string] = ACTIONS(216),
    [anon_sym_symbol] = ACTIONS(216),
    [anon_sym_object] = ACTIONS(216),
    [anon_sym_abstract] = ACTIONS(597),
    [anon_sym_satisfies] = ACTIONS(120),
    [anon_sym_infer] = ACTIONS(599),
    [anon_sym_keyof] = ACTIONS(601),
    [anon_sym_unique] = ACTIONS(214),
    [anon_sym_unknown] = ACTIONS(216),
    [anon_sym_never] = ACTIONS(216),
    [anon_sym_LBRACE_PIPE] = ACTIONS(218),
    [sym__ternary_qmark] = ACTIONS(154),
    [sym_html_comment] = ACTIONS(5),
  },
  [186] = {
    [sym_declaration] = STATE(4327),
    [sym_import] = STATE(3636),
    [sym_variable_declaration] = STATE(4275),
    [sym_lexical_declaration] = STATE(4275),
    [sym_parenthesized_expression] = STATE(1410),
    [sym_expression] = STATE(2377),
    [sym_primary_expression] = STATE(1810),
    [sym_yield_expression] = STATE(2358),
    [sym_object] = STATE(2222),
    [sym_object_pattern] = STATE(5580),
    [sym_array] = STATE(2222),
    [sym_array_pattern] = STATE(5580),
    [sym_class] = STATE(2222),
    [sym_class_declaration] = STATE(4275),
    [sym_function_expression] = STATE(2222),
    [sym_function_declaration] = STATE(4275),
    [sym_generator_function] = STATE(2222),
    [sym_generator_function_declaration] = STATE(4275),
    [sym_arrow_function] = STATE(2222),
    [sym__call_signature] = STATE(5466),
    [sym_call_expression] = STATE(2222),
    [sym_new_expression] = STATE(1948),
    [sym_await_expression] = STATE(2358),
    [sym_member_expression] = STATE(1410),
    [sym_subscript_expression] = STATE(1410),
    [sym_assignment_expression] = STATE(2358),
    [sym__augmented_assignment_lhs] = STATE(3004),
    [sym_augmented_assignment_expression] = STATE(2358),
    [sym__destructuring_pattern] = STATE(5580),
    [sym_ternary_expression] = STATE(2358),
    [sym_binary_expression] = STATE(2358),
    [sym_unary_expression] = STATE(2358),
    [sym_update_expression] = STATE(2358),
    [sym_string] = STATE(2222),
    [sym_template_string] = STATE(2222),
    [sym_regex] = STATE(2222),
    [sym_meta_property] = STATE(2222),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1410),
    [sym_function_signature] = STATE(4275),
    [sym_type_assertion] = STATE(2358),
    [sym_as_expression] = STATE(2358),
    [sym_satisfies_expression] = STATE(2358),
    [sym_instantiation_expression] = STATE(2358),
    [sym_ambient_declaration] = STATE(4275),
    [sym_abstract_class_declaration] = STATE(4275),
    [sym_module] = STATE(4275),
    [sym_internal_module] = STATE(2453),
    [sym_import_alias] = STATE(4275),
    [sym_interface_declaration] = STATE(4275),
    [sym_enum_declaration] = STATE(4275),
    [sym_type_alias_declaration] = STATE(4275),
    [sym_type_arguments] = STATE(452),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4222),
    [sym_identifier] = ACTIONS(1498),
    [anon_sym_export] = ACTIONS(1270),
    [anon_sym_type] = ACTIONS(1564),
    [anon_sym_namespace] = ACTIONS(1272),
    [anon_sym_LBRACE] = ACTIONS(665),
    [anon_sym_typeof] = ACTIONS(1298),
    [anon_sym_import] = ACTIONS(1566),
    [anon_sym_var] = ACTIONS(1568),
    [anon_sym_let] = ACTIONS(1570),
    [anon_sym_const] = ACTIONS(1572),
    [anon_sym_BANG] = ACTIONS(1278),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_await] = ACTIONS(1282),
    [anon_sym_yield] = ACTIONS(1284),
    [anon_sym_LBRACK] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(1574),
    [anon_sym_async] = ACTIONS(1576),
    [anon_sym_function] = ACTIONS(1578),
    [anon_sym_new] = ACTIONS(1502),
    [anon_sym_using] = ACTIONS(1292),
    [anon_sym_PLUS] = ACTIONS(1298),
    [anon_sym_DASH] = ACTIONS(1298),
    [anon_sym_SLASH] = ACTIONS(77),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(1278),
    [anon_sym_void] = ACTIONS(1298),
    [anon_sym_delete] = ACTIONS(1298),
    [anon_sym_PLUS_PLUS] = ACTIONS(1300),
    [anon_sym_DASH_DASH] = ACTIONS(1300),
    [anon_sym_DQUOTE] = ACTIONS(83),
    [anon_sym_SQUOTE] = ACTIONS(85),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(87),
    [sym_number] = ACTIONS(89),
    [sym_private_property_identifier] = ACTIONS(1306),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(93),
    [sym_true] = ACTIONS(93),
    [sym_false] = ACTIONS(93),
    [sym_null] = ACTIONS(93),
    [sym_undefined] = ACTIONS(1504),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1270),
    [anon_sym_readonly] = ACTIONS(1270),
    [anon_sym_get] = ACTIONS(1270),
    [anon_sym_set] = ACTIONS(1270),
    [anon_sym_declare] = ACTIONS(1580),
    [anon_sym_public] = ACTIONS(1270),
    [anon_sym_private] = ACTIONS(1270),
    [anon_sym_protected] = ACTIONS(1270),
    [anon_sym_override] = ACTIONS(1270),
    [anon_sym_module] = ACTIONS(1582),
    [anon_sym_any] = ACTIONS(1270),
    [anon_sym_number] = ACTIONS(1270),
    [anon_sym_boolean] = ACTIONS(1270),
    [anon_sym_string] = ACTIONS(1270),
    [anon_sym_symbol] = ACTIONS(1270),
    [anon_sym_object] = ACTIONS(1270),
    [anon_sym_abstract] = ACTIONS(1584),
    [anon_sym_interface] = ACTIONS(1586),
    [anon_sym_enum] = ACTIONS(1588),
    [sym_html_comment] = ACTIONS(5),
  },
  [187] = {
    [sym_import] = STATE(4878),
    [sym_nested_identifier] = STATE(5474),
    [sym_string] = STATE(2994),
    [sym_formal_parameters] = STATE(5475),
    [sym_nested_type_identifier] = STATE(2939),
    [sym__type_query_member_expression_in_type_annotation] = STATE(2937),
    [sym__type_query_call_expression_in_type_annotation] = STATE(2938),
    [sym_type] = STATE(3153),
    [sym_constructor_type] = STATE(3007),
    [sym_primary_type] = STATE(2981),
    [sym_template_literal_type] = STATE(3039),
    [sym_infer_type] = STATE(3007),
    [sym_conditional_type] = STATE(3039),
    [sym_generic_type] = STATE(3039),
    [sym_type_query] = STATE(3039),
    [sym_index_type_query] = STATE(3039),
    [sym_lookup_type] = STATE(3039),
    [sym_literal_type] = STATE(3039),
    [sym__number] = STATE(3041),
    [sym_existential_type] = STATE(3039),
    [sym_flow_maybe_type] = STATE(3039),
    [sym_parenthesized_type] = STATE(3039),
    [sym_predefined_type] = STATE(3039),
    [sym_object_type] = STATE(3039),
    [sym_type_parameters] = STATE(5248),
    [sym_array_type] = STATE(3039),
    [sym_tuple_type] = STATE(3039),
    [sym_readonly_type] = STATE(3007),
    [sym_union_type] = STATE(3039),
    [sym_intersection_type] = STATE(3039),
    [sym_function_type] = STATE(3007),
    [sym_identifier] = ACTIONS(1532),
    [anon_sym_STAR] = ACTIONS(115),
    [anon_sym_EQ] = ACTIONS(932),
    [anon_sym_as] = ACTIONS(120),
    [anon_sym_LBRACE] = ACTIONS(1534),
    [anon_sym_COMMA] = ACTIONS(154),
    [anon_sym_typeof] = ACTIONS(1536),
    [anon_sym_import] = ACTIONS(1538),
    [anon_sym_const] = ACTIONS(133),
    [anon_sym_BANG] = ACTIONS(120),
    [anon_sym_LPAREN] = ACTIONS(1540),
    [anon_sym_in] = ACTIONS(120),
    [anon_sym_LBRACK] = ACTIONS(1542),
    [anon_sym_DOT] = ACTIONS(120),
    [anon_sym_EQ_GT] = ACTIONS(938),
    [anon_sym_QMARK_DOT] = ACTIONS(154),
    [anon_sym_new] = ACTIONS(1544),
    [anon_sym_PLUS_EQ] = ACTIONS(160),
    [anon_sym_DASH_EQ] = ACTIONS(160),
    [anon_sym_STAR_EQ] = ACTIONS(160),
    [anon_sym_SLASH_EQ] = ACTIONS(160),
    [anon_sym_PERCENT_EQ] = ACTIONS(160),
    [anon_sym_CARET_EQ] = ACTIONS(160),
    [anon_sym_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_LT_LT_EQ] = ACTIONS(160),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(160),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP] = ACTIONS(120),
    [anon_sym_PIPE_PIPE] = ACTIONS(120),
    [anon_sym_GT_GT] = ACTIONS(120),
    [anon_sym_GT_GT_GT] = ACTIONS(120),
    [anon_sym_LT_LT] = ACTIONS(120),
    [anon_sym_AMP] = ACTIONS(164),
    [anon_sym_CARET] = ACTIONS(120),
    [anon_sym_PIPE] = ACTIONS(166),
    [anon_sym_PLUS] = ACTIONS(1546),
    [anon_sym_DASH] = ACTIONS(1546),
    [anon_sym_SLASH] = ACTIONS(120),
    [anon_sym_PERCENT] = ACTIONS(120),
    [anon_sym_STAR_STAR] = ACTIONS(120),
    [anon_sym_LT] = ACTIONS(1548),
    [anon_sym_LT_EQ] = ACTIONS(154),
    [anon_sym_EQ_EQ] = ACTIONS(120),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(154),
    [anon_sym_BANG_EQ] = ACTIONS(120),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(154),
    [anon_sym_GT_EQ] = ACTIONS(154),
    [anon_sym_GT] = ACTIONS(120),
    [anon_sym_QMARK_QMARK] = ACTIONS(120),
    [anon_sym_instanceof] = ACTIONS(120),
    [anon_sym_void] = ACTIONS(216),
    [anon_sym_PLUS_PLUS] = ACTIONS(154),
    [anon_sym_DASH_DASH] = ACTIONS(154),
    [anon_sym_DQUOTE] = ACTIONS(1550),
    [anon_sym_SQUOTE] = ACTIONS(1552),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1554),
    [sym_number] = ACTIONS(1556),
    [sym_this] = ACTIONS(1558),
    [sym_true] = ACTIONS(1560),
    [sym_false] = ACTIONS(1560),
    [sym_null] = ACTIONS(1560),
    [sym_undefined] = ACTIONS(1560),
    [anon_sym_readonly] = ACTIONS(1562),
    [anon_sym_QMARK] = ACTIONS(204),
    [anon_sym_any] = ACTIONS(216),
    [anon_sym_number] = ACTIONS(216),
    [anon_sym_boolean] = ACTIONS(216),
    [anon_sym_string] = ACTIONS(216),
    [anon_sym_symbol] = ACTIONS(216),
    [anon_sym_object] = ACTIONS(216),
    [anon_sym_abstract] = ACTIONS(208),
    [anon_sym_satisfies] = ACTIONS(120),
    [anon_sym_implements] = ACTIONS(120),
    [anon_sym_infer] = ACTIONS(210),
    [anon_sym_keyof] = ACTIONS(212),
    [anon_sym_unique] = ACTIONS(214),
    [anon_sym_unknown] = ACTIONS(216),
    [anon_sym_never] = ACTIONS(216),
    [anon_sym_LBRACE_PIPE] = ACTIONS(218),
    [sym__ternary_qmark] = ACTIONS(154),
    [sym_html_comment] = ACTIONS(5),
  },
  [188] = {
    [sym_declaration] = STATE(873),
    [sym_import] = STATE(3636),
    [sym_variable_declaration] = STATE(831),
    [sym_lexical_declaration] = STATE(831),
    [sym_parenthesized_expression] = STATE(1410),
    [sym_expression] = STATE(2454),
    [sym_primary_expression] = STATE(1810),
    [sym_yield_expression] = STATE(2358),
    [sym_object] = STATE(2222),
    [sym_object_pattern] = STATE(5580),
    [sym_array] = STATE(2222),
    [sym_array_pattern] = STATE(5580),
    [sym_class] = STATE(2222),
    [sym_class_declaration] = STATE(831),
    [sym_function_expression] = STATE(2222),
    [sym_function_declaration] = STATE(831),
    [sym_generator_function] = STATE(2222),
    [sym_generator_function_declaration] = STATE(831),
    [sym_arrow_function] = STATE(2222),
    [sym__call_signature] = STATE(5466),
    [sym_call_expression] = STATE(2222),
    [sym_new_expression] = STATE(1948),
    [sym_await_expression] = STATE(2358),
    [sym_member_expression] = STATE(1410),
    [sym_subscript_expression] = STATE(1410),
    [sym_assignment_expression] = STATE(2358),
    [sym__augmented_assignment_lhs] = STATE(3004),
    [sym_augmented_assignment_expression] = STATE(2358),
    [sym__destructuring_pattern] = STATE(5580),
    [sym_ternary_expression] = STATE(2358),
    [sym_binary_expression] = STATE(2358),
    [sym_unary_expression] = STATE(2358),
    [sym_update_expression] = STATE(2358),
    [sym_string] = STATE(2222),
    [sym_template_string] = STATE(2222),
    [sym_regex] = STATE(2222),
    [sym_meta_property] = STATE(2222),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1410),
    [sym_function_signature] = STATE(831),
    [sym_type_assertion] = STATE(2358),
    [sym_as_expression] = STATE(2358),
    [sym_satisfies_expression] = STATE(2358),
    [sym_instantiation_expression] = STATE(2358),
    [sym_ambient_declaration] = STATE(831),
    [sym_abstract_class_declaration] = STATE(831),
    [sym_module] = STATE(831),
    [sym_internal_module] = STATE(214),
    [sym_import_alias] = STATE(831),
    [sym_interface_declaration] = STATE(831),
    [sym_enum_declaration] = STATE(831),
    [sym_type_alias_declaration] = STATE(831),
    [sym_type_arguments] = STATE(452),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4150),
    [sym_identifier] = ACTIONS(1498),
    [anon_sym_export] = ACTIONS(1270),
    [anon_sym_type] = ACTIONS(1590),
    [anon_sym_namespace] = ACTIONS(1592),
    [anon_sym_LBRACE] = ACTIONS(665),
    [anon_sym_typeof] = ACTIONS(1298),
    [anon_sym_import] = ACTIONS(1594),
    [anon_sym_var] = ACTIONS(27),
    [anon_sym_let] = ACTIONS(1596),
    [anon_sym_const] = ACTIONS(31),
    [anon_sym_BANG] = ACTIONS(1278),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_await] = ACTIONS(1282),
    [anon_sym_yield] = ACTIONS(1284),
    [anon_sym_LBRACK] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(67),
    [anon_sym_async] = ACTIONS(1598),
    [anon_sym_function] = ACTIONS(71),
    [anon_sym_new] = ACTIONS(1502),
    [anon_sym_using] = ACTIONS(1292),
    [anon_sym_PLUS] = ACTIONS(1298),
    [anon_sym_DASH] = ACTIONS(1298),
    [anon_sym_SLASH] = ACTIONS(77),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(1278),
    [anon_sym_void] = ACTIONS(1298),
    [anon_sym_delete] = ACTIONS(1298),
    [anon_sym_PLUS_PLUS] = ACTIONS(1300),
    [anon_sym_DASH_DASH] = ACTIONS(1300),
    [anon_sym_DQUOTE] = ACTIONS(83),
    [anon_sym_SQUOTE] = ACTIONS(85),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(87),
    [sym_number] = ACTIONS(89),
    [sym_private_property_identifier] = ACTIONS(1306),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(93),
    [sym_true] = ACTIONS(93),
    [sym_false] = ACTIONS(93),
    [sym_null] = ACTIONS(93),
    [sym_undefined] = ACTIONS(1504),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1270),
    [anon_sym_readonly] = ACTIONS(1270),
    [anon_sym_get] = ACTIONS(1270),
    [anon_sym_set] = ACTIONS(1270),
    [anon_sym_declare] = ACTIONS(1600),
    [anon_sym_public] = ACTIONS(1270),
    [anon_sym_private] = ACTIONS(1270),
    [anon_sym_protected] = ACTIONS(1270),
    [anon_sym_override] = ACTIONS(1270),
    [anon_sym_module] = ACTIONS(1602),
    [anon_sym_any] = ACTIONS(1270),
    [anon_sym_number] = ACTIONS(1270),
    [anon_sym_boolean] = ACTIONS(1270),
    [anon_sym_string] = ACTIONS(1270),
    [anon_sym_symbol] = ACTIONS(1270),
    [anon_sym_object] = ACTIONS(1270),
    [anon_sym_abstract] = ACTIONS(105),
    [anon_sym_interface] = ACTIONS(107),
    [anon_sym_enum] = ACTIONS(109),
    [sym_html_comment] = ACTIONS(5),
  },
  [189] = {
    [sym_import] = STATE(4878),
    [sym_nested_identifier] = STATE(5474),
    [sym_string] = STATE(2994),
    [sym_formal_parameters] = STATE(5475),
    [sym_nested_type_identifier] = STATE(2939),
    [sym__type_query_member_expression_in_type_annotation] = STATE(2937),
    [sym__type_query_call_expression_in_type_annotation] = STATE(2938),
    [sym_type] = STATE(3153),
    [sym_constructor_type] = STATE(3007),
    [sym_primary_type] = STATE(2981),
    [sym_template_literal_type] = STATE(3039),
    [sym_infer_type] = STATE(3007),
    [sym_conditional_type] = STATE(3039),
    [sym_generic_type] = STATE(3039),
    [sym_type_query] = STATE(3039),
    [sym_index_type_query] = STATE(3039),
    [sym_lookup_type] = STATE(3039),
    [sym_literal_type] = STATE(3039),
    [sym__number] = STATE(3041),
    [sym_existential_type] = STATE(3039),
    [sym_flow_maybe_type] = STATE(3039),
    [sym_parenthesized_type] = STATE(3039),
    [sym_predefined_type] = STATE(3039),
    [sym_object_type] = STATE(3039),
    [sym_type_parameters] = STATE(5248),
    [sym_array_type] = STATE(3039),
    [sym_tuple_type] = STATE(3039),
    [sym_readonly_type] = STATE(3007),
    [sym_union_type] = STATE(3039),
    [sym_intersection_type] = STATE(3039),
    [sym_function_type] = STATE(3007),
    [sym_identifier] = ACTIONS(1532),
    [anon_sym_STAR] = ACTIONS(115),
    [anon_sym_EQ] = ACTIONS(824),
    [anon_sym_as] = ACTIONS(120),
    [anon_sym_LBRACE] = ACTIONS(1534),
    [anon_sym_typeof] = ACTIONS(1536),
    [anon_sym_import] = ACTIONS(1538),
    [anon_sym_const] = ACTIONS(133),
    [anon_sym_BANG] = ACTIONS(120),
    [anon_sym_LPAREN] = ACTIONS(1540),
    [anon_sym_in] = ACTIONS(120),
    [anon_sym_COLON] = ACTIONS(826),
    [anon_sym_LBRACK] = ACTIONS(1542),
    [anon_sym_DOT] = ACTIONS(120),
    [anon_sym_EQ_GT] = ACTIONS(225),
    [anon_sym_QMARK_DOT] = ACTIONS(154),
    [anon_sym_new] = ACTIONS(1544),
    [anon_sym_PLUS_EQ] = ACTIONS(160),
    [anon_sym_DASH_EQ] = ACTIONS(160),
    [anon_sym_STAR_EQ] = ACTIONS(160),
    [anon_sym_SLASH_EQ] = ACTIONS(160),
    [anon_sym_PERCENT_EQ] = ACTIONS(160),
    [anon_sym_CARET_EQ] = ACTIONS(160),
    [anon_sym_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_LT_LT_EQ] = ACTIONS(160),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(160),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP] = ACTIONS(120),
    [anon_sym_PIPE_PIPE] = ACTIONS(120),
    [anon_sym_GT_GT] = ACTIONS(120),
    [anon_sym_GT_GT_GT] = ACTIONS(120),
    [anon_sym_LT_LT] = ACTIONS(120),
    [anon_sym_AMP] = ACTIONS(164),
    [anon_sym_CARET] = ACTIONS(120),
    [anon_sym_PIPE] = ACTIONS(166),
    [anon_sym_PLUS] = ACTIONS(1546),
    [anon_sym_DASH] = ACTIONS(1546),
    [anon_sym_SLASH] = ACTIONS(120),
    [anon_sym_PERCENT] = ACTIONS(120),
    [anon_sym_STAR_STAR] = ACTIONS(120),
    [anon_sym_LT] = ACTIONS(1548),
    [anon_sym_LT_EQ] = ACTIONS(154),
    [anon_sym_EQ_EQ] = ACTIONS(120),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(154),
    [anon_sym_BANG_EQ] = ACTIONS(120),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(154),
    [anon_sym_GT_EQ] = ACTIONS(154),
    [anon_sym_GT] = ACTIONS(120),
    [anon_sym_QMARK_QMARK] = ACTIONS(120),
    [anon_sym_instanceof] = ACTIONS(120),
    [anon_sym_void] = ACTIONS(216),
    [anon_sym_PLUS_PLUS] = ACTIONS(154),
    [anon_sym_DASH_DASH] = ACTIONS(154),
    [anon_sym_DQUOTE] = ACTIONS(1550),
    [anon_sym_SQUOTE] = ACTIONS(1552),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1554),
    [sym_number] = ACTIONS(1556),
    [sym_this] = ACTIONS(1558),
    [sym_true] = ACTIONS(1560),
    [sym_false] = ACTIONS(1560),
    [sym_null] = ACTIONS(1560),
    [sym_undefined] = ACTIONS(1560),
    [anon_sym_readonly] = ACTIONS(1562),
    [anon_sym_QMARK] = ACTIONS(204),
    [anon_sym_any] = ACTIONS(216),
    [anon_sym_number] = ACTIONS(216),
    [anon_sym_boolean] = ACTIONS(216),
    [anon_sym_string] = ACTIONS(216),
    [anon_sym_symbol] = ACTIONS(216),
    [anon_sym_object] = ACTIONS(216),
    [anon_sym_abstract] = ACTIONS(208),
    [anon_sym_satisfies] = ACTIONS(120),
    [anon_sym_infer] = ACTIONS(210),
    [anon_sym_keyof] = ACTIONS(212),
    [anon_sym_unique] = ACTIONS(214),
    [anon_sym_unknown] = ACTIONS(216),
    [anon_sym_never] = ACTIONS(216),
    [anon_sym_LBRACE_PIPE] = ACTIONS(218),
    [sym__ternary_qmark] = ACTIONS(154),
    [sym_html_comment] = ACTIONS(5),
  },
  [190] = {
    [sym_import] = STATE(4878),
    [sym_nested_identifier] = STATE(5474),
    [sym_string] = STATE(2994),
    [sym_formal_parameters] = STATE(5475),
    [sym_nested_type_identifier] = STATE(2939),
    [sym__type_query_member_expression_in_type_annotation] = STATE(2937),
    [sym__type_query_call_expression_in_type_annotation] = STATE(2938),
    [sym_type] = STATE(3153),
    [sym_constructor_type] = STATE(3007),
    [sym_primary_type] = STATE(2981),
    [sym_template_literal_type] = STATE(3039),
    [sym_infer_type] = STATE(3007),
    [sym_conditional_type] = STATE(3039),
    [sym_generic_type] = STATE(3039),
    [sym_type_query] = STATE(3039),
    [sym_index_type_query] = STATE(3039),
    [sym_lookup_type] = STATE(3039),
    [sym_literal_type] = STATE(3039),
    [sym__number] = STATE(3041),
    [sym_existential_type] = STATE(3039),
    [sym_flow_maybe_type] = STATE(3039),
    [sym_parenthesized_type] = STATE(3039),
    [sym_predefined_type] = STATE(3039),
    [sym_object_type] = STATE(3039),
    [sym_type_parameters] = STATE(5248),
    [sym_array_type] = STATE(3039),
    [sym_tuple_type] = STATE(3039),
    [sym_readonly_type] = STATE(3007),
    [sym_union_type] = STATE(3039),
    [sym_intersection_type] = STATE(3039),
    [sym_function_type] = STATE(3007),
    [sym_identifier] = ACTIONS(1532),
    [anon_sym_STAR] = ACTIONS(115),
    [anon_sym_EQ] = ACTIONS(964),
    [anon_sym_as] = ACTIONS(120),
    [anon_sym_LBRACE] = ACTIONS(1534),
    [anon_sym_typeof] = ACTIONS(1536),
    [anon_sym_import] = ACTIONS(1538),
    [anon_sym_const] = ACTIONS(133),
    [anon_sym_BANG] = ACTIONS(120),
    [anon_sym_LPAREN] = ACTIONS(1540),
    [anon_sym_in] = ACTIONS(120),
    [anon_sym_COLON] = ACTIONS(154),
    [anon_sym_LBRACK] = ACTIONS(1542),
    [anon_sym_DOT] = ACTIONS(120),
    [anon_sym_EQ_GT] = ACTIONS(970),
    [anon_sym_QMARK_DOT] = ACTIONS(154),
    [anon_sym_new] = ACTIONS(1544),
    [anon_sym_PLUS_EQ] = ACTIONS(160),
    [anon_sym_DASH_EQ] = ACTIONS(160),
    [anon_sym_STAR_EQ] = ACTIONS(160),
    [anon_sym_SLASH_EQ] = ACTIONS(160),
    [anon_sym_PERCENT_EQ] = ACTIONS(160),
    [anon_sym_CARET_EQ] = ACTIONS(160),
    [anon_sym_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_LT_LT_EQ] = ACTIONS(160),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(160),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP] = ACTIONS(120),
    [anon_sym_PIPE_PIPE] = ACTIONS(120),
    [anon_sym_GT_GT] = ACTIONS(120),
    [anon_sym_GT_GT_GT] = ACTIONS(120),
    [anon_sym_LT_LT] = ACTIONS(120),
    [anon_sym_AMP] = ACTIONS(164),
    [anon_sym_CARET] = ACTIONS(120),
    [anon_sym_PIPE] = ACTIONS(166),
    [anon_sym_PLUS] = ACTIONS(1546),
    [anon_sym_DASH] = ACTIONS(1546),
    [anon_sym_SLASH] = ACTIONS(120),
    [anon_sym_PERCENT] = ACTIONS(120),
    [anon_sym_STAR_STAR] = ACTIONS(120),
    [anon_sym_LT] = ACTIONS(1548),
    [anon_sym_LT_EQ] = ACTIONS(154),
    [anon_sym_EQ_EQ] = ACTIONS(120),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(154),
    [anon_sym_BANG_EQ] = ACTIONS(120),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(154),
    [anon_sym_GT_EQ] = ACTIONS(154),
    [anon_sym_GT] = ACTIONS(120),
    [anon_sym_QMARK_QMARK] = ACTIONS(120),
    [anon_sym_instanceof] = ACTIONS(120),
    [anon_sym_void] = ACTIONS(216),
    [anon_sym_PLUS_PLUS] = ACTIONS(154),
    [anon_sym_DASH_DASH] = ACTIONS(154),
    [anon_sym_DQUOTE] = ACTIONS(1550),
    [anon_sym_SQUOTE] = ACTIONS(1552),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1554),
    [sym_number] = ACTIONS(1556),
    [sym_this] = ACTIONS(1558),
    [sym_true] = ACTIONS(1560),
    [sym_false] = ACTIONS(1560),
    [sym_null] = ACTIONS(1560),
    [sym_undefined] = ACTIONS(1560),
    [anon_sym_readonly] = ACTIONS(1562),
    [anon_sym_QMARK] = ACTIONS(204),
    [anon_sym_any] = ACTIONS(216),
    [anon_sym_number] = ACTIONS(216),
    [anon_sym_boolean] = ACTIONS(216),
    [anon_sym_string] = ACTIONS(216),
    [anon_sym_symbol] = ACTIONS(216),
    [anon_sym_object] = ACTIONS(216),
    [anon_sym_abstract] = ACTIONS(208),
    [anon_sym_satisfies] = ACTIONS(120),
    [anon_sym_infer] = ACTIONS(210),
    [anon_sym_keyof] = ACTIONS(212),
    [anon_sym_unique] = ACTIONS(214),
    [anon_sym_unknown] = ACTIONS(216),
    [anon_sym_never] = ACTIONS(216),
    [anon_sym_LBRACE_PIPE] = ACTIONS(218),
    [sym__ternary_qmark] = ACTIONS(154),
    [sym_html_comment] = ACTIONS(5),
  },
  [191] = {
    [sym_import] = STATE(4878),
    [sym_nested_identifier] = STATE(5474),
    [sym_string] = STATE(2994),
    [sym_formal_parameters] = STATE(5475),
    [sym_nested_type_identifier] = STATE(2939),
    [sym__type_query_member_expression_in_type_annotation] = STATE(2937),
    [sym__type_query_call_expression_in_type_annotation] = STATE(2938),
    [sym_type] = STATE(3153),
    [sym_constructor_type] = STATE(3007),
    [sym_primary_type] = STATE(2981),
    [sym_template_literal_type] = STATE(3039),
    [sym_infer_type] = STATE(3007),
    [sym_conditional_type] = STATE(3039),
    [sym_generic_type] = STATE(3039),
    [sym_type_query] = STATE(3039),
    [sym_index_type_query] = STATE(3039),
    [sym_lookup_type] = STATE(3039),
    [sym_literal_type] = STATE(3039),
    [sym__number] = STATE(3041),
    [sym_existential_type] = STATE(3039),
    [sym_flow_maybe_type] = STATE(3039),
    [sym_parenthesized_type] = STATE(3039),
    [sym_predefined_type] = STATE(3039),
    [sym_object_type] = STATE(3039),
    [sym_type_parameters] = STATE(5248),
    [sym_array_type] = STATE(3039),
    [sym_tuple_type] = STATE(3039),
    [sym_readonly_type] = STATE(3007),
    [sym_union_type] = STATE(3039),
    [sym_intersection_type] = STATE(3039),
    [sym_function_type] = STATE(3007),
    [sym_identifier] = ACTIONS(1532),
    [anon_sym_STAR] = ACTIONS(115),
    [anon_sym_EQ] = ACTIONS(910),
    [anon_sym_as] = ACTIONS(120),
    [anon_sym_LBRACE] = ACTIONS(1534),
    [anon_sym_typeof] = ACTIONS(1536),
    [anon_sym_import] = ACTIONS(1538),
    [anon_sym_const] = ACTIONS(133),
    [anon_sym_BANG] = ACTIONS(120),
    [anon_sym_LPAREN] = ACTIONS(1540),
    [anon_sym_in] = ACTIONS(120),
    [anon_sym_LBRACK] = ACTIONS(1542),
    [anon_sym_RBRACK] = ACTIONS(154),
    [anon_sym_DOT] = ACTIONS(120),
    [anon_sym_EQ_GT] = ACTIONS(895),
    [anon_sym_QMARK_DOT] = ACTIONS(154),
    [anon_sym_new] = ACTIONS(1544),
    [anon_sym_PLUS_EQ] = ACTIONS(160),
    [anon_sym_DASH_EQ] = ACTIONS(160),
    [anon_sym_STAR_EQ] = ACTIONS(160),
    [anon_sym_SLASH_EQ] = ACTIONS(160),
    [anon_sym_PERCENT_EQ] = ACTIONS(160),
    [anon_sym_CARET_EQ] = ACTIONS(160),
    [anon_sym_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_LT_LT_EQ] = ACTIONS(160),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(160),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP] = ACTIONS(120),
    [anon_sym_PIPE_PIPE] = ACTIONS(120),
    [anon_sym_GT_GT] = ACTIONS(120),
    [anon_sym_GT_GT_GT] = ACTIONS(120),
    [anon_sym_LT_LT] = ACTIONS(120),
    [anon_sym_AMP] = ACTIONS(164),
    [anon_sym_CARET] = ACTIONS(120),
    [anon_sym_PIPE] = ACTIONS(166),
    [anon_sym_PLUS] = ACTIONS(1546),
    [anon_sym_DASH] = ACTIONS(1546),
    [anon_sym_SLASH] = ACTIONS(120),
    [anon_sym_PERCENT] = ACTIONS(120),
    [anon_sym_STAR_STAR] = ACTIONS(120),
    [anon_sym_LT] = ACTIONS(1548),
    [anon_sym_LT_EQ] = ACTIONS(154),
    [anon_sym_EQ_EQ] = ACTIONS(120),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(154),
    [anon_sym_BANG_EQ] = ACTIONS(120),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(154),
    [anon_sym_GT_EQ] = ACTIONS(154),
    [anon_sym_GT] = ACTIONS(120),
    [anon_sym_QMARK_QMARK] = ACTIONS(120),
    [anon_sym_instanceof] = ACTIONS(120),
    [anon_sym_void] = ACTIONS(216),
    [anon_sym_PLUS_PLUS] = ACTIONS(154),
    [anon_sym_DASH_DASH] = ACTIONS(154),
    [anon_sym_DQUOTE] = ACTIONS(1550),
    [anon_sym_SQUOTE] = ACTIONS(1552),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1554),
    [sym_number] = ACTIONS(1556),
    [sym_this] = ACTIONS(1558),
    [sym_true] = ACTIONS(1560),
    [sym_false] = ACTIONS(1560),
    [sym_null] = ACTIONS(1560),
    [sym_undefined] = ACTIONS(1560),
    [anon_sym_readonly] = ACTIONS(1562),
    [anon_sym_QMARK] = ACTIONS(204),
    [anon_sym_any] = ACTIONS(216),
    [anon_sym_number] = ACTIONS(216),
    [anon_sym_boolean] = ACTIONS(216),
    [anon_sym_string] = ACTIONS(216),
    [anon_sym_symbol] = ACTIONS(216),
    [anon_sym_object] = ACTIONS(216),
    [anon_sym_abstract] = ACTIONS(208),
    [anon_sym_satisfies] = ACTIONS(120),
    [anon_sym_infer] = ACTIONS(210),
    [anon_sym_keyof] = ACTIONS(212),
    [anon_sym_unique] = ACTIONS(214),
    [anon_sym_unknown] = ACTIONS(216),
    [anon_sym_never] = ACTIONS(216),
    [anon_sym_LBRACE_PIPE] = ACTIONS(218),
    [sym__ternary_qmark] = ACTIONS(154),
    [sym_html_comment] = ACTIONS(5),
  },
  [192] = {
    [sym_import] = STATE(4878),
    [sym_nested_identifier] = STATE(5474),
    [sym_string] = STATE(2994),
    [sym_formal_parameters] = STATE(5475),
    [sym_nested_type_identifier] = STATE(2939),
    [sym__type_query_member_expression_in_type_annotation] = STATE(2937),
    [sym__type_query_call_expression_in_type_annotation] = STATE(2938),
    [sym_type] = STATE(3153),
    [sym_constructor_type] = STATE(3007),
    [sym_primary_type] = STATE(2981),
    [sym_template_literal_type] = STATE(3039),
    [sym_infer_type] = STATE(3007),
    [sym_conditional_type] = STATE(3039),
    [sym_generic_type] = STATE(3039),
    [sym_type_query] = STATE(3039),
    [sym_index_type_query] = STATE(3039),
    [sym_lookup_type] = STATE(3039),
    [sym_literal_type] = STATE(3039),
    [sym__number] = STATE(3041),
    [sym_existential_type] = STATE(3039),
    [sym_flow_maybe_type] = STATE(3039),
    [sym_parenthesized_type] = STATE(3039),
    [sym_predefined_type] = STATE(3039),
    [sym_object_type] = STATE(3039),
    [sym_type_parameters] = STATE(5248),
    [sym_array_type] = STATE(3039),
    [sym_tuple_type] = STATE(3039),
    [sym_readonly_type] = STATE(3007),
    [sym_union_type] = STATE(3039),
    [sym_intersection_type] = STATE(3039),
    [sym_function_type] = STATE(3007),
    [sym_identifier] = ACTIONS(1532),
    [anon_sym_STAR] = ACTIONS(115),
    [anon_sym_EQ] = ACTIONS(948),
    [anon_sym_as] = ACTIONS(120),
    [anon_sym_LBRACE] = ACTIONS(1534),
    [anon_sym_typeof] = ACTIONS(1536),
    [anon_sym_import] = ACTIONS(1538),
    [anon_sym_const] = ACTIONS(133),
    [anon_sym_BANG] = ACTIONS(120),
    [anon_sym_LPAREN] = ACTIONS(1540),
    [anon_sym_in] = ACTIONS(120),
    [anon_sym_of] = ACTIONS(120),
    [anon_sym_LBRACK] = ACTIONS(1542),
    [anon_sym_DOT] = ACTIONS(120),
    [anon_sym_EQ_GT] = ACTIONS(954),
    [anon_sym_QMARK_DOT] = ACTIONS(154),
    [anon_sym_new] = ACTIONS(1544),
    [anon_sym_PLUS_EQ] = ACTIONS(160),
    [anon_sym_DASH_EQ] = ACTIONS(160),
    [anon_sym_STAR_EQ] = ACTIONS(160),
    [anon_sym_SLASH_EQ] = ACTIONS(160),
    [anon_sym_PERCENT_EQ] = ACTIONS(160),
    [anon_sym_CARET_EQ] = ACTIONS(160),
    [anon_sym_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_LT_LT_EQ] = ACTIONS(160),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(160),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP] = ACTIONS(120),
    [anon_sym_PIPE_PIPE] = ACTIONS(120),
    [anon_sym_GT_GT] = ACTIONS(120),
    [anon_sym_GT_GT_GT] = ACTIONS(120),
    [anon_sym_LT_LT] = ACTIONS(120),
    [anon_sym_AMP] = ACTIONS(164),
    [anon_sym_CARET] = ACTIONS(120),
    [anon_sym_PIPE] = ACTIONS(166),
    [anon_sym_PLUS] = ACTIONS(1546),
    [anon_sym_DASH] = ACTIONS(1546),
    [anon_sym_SLASH] = ACTIONS(120),
    [anon_sym_PERCENT] = ACTIONS(120),
    [anon_sym_STAR_STAR] = ACTIONS(120),
    [anon_sym_LT] = ACTIONS(1548),
    [anon_sym_LT_EQ] = ACTIONS(154),
    [anon_sym_EQ_EQ] = ACTIONS(120),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(154),
    [anon_sym_BANG_EQ] = ACTIONS(120),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(154),
    [anon_sym_GT_EQ] = ACTIONS(154),
    [anon_sym_GT] = ACTIONS(120),
    [anon_sym_QMARK_QMARK] = ACTIONS(120),
    [anon_sym_instanceof] = ACTIONS(120),
    [anon_sym_void] = ACTIONS(216),
    [anon_sym_PLUS_PLUS] = ACTIONS(154),
    [anon_sym_DASH_DASH] = ACTIONS(154),
    [anon_sym_DQUOTE] = ACTIONS(1550),
    [anon_sym_SQUOTE] = ACTIONS(1552),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1554),
    [sym_number] = ACTIONS(1556),
    [sym_this] = ACTIONS(1558),
    [sym_true] = ACTIONS(1560),
    [sym_false] = ACTIONS(1560),
    [sym_null] = ACTIONS(1560),
    [sym_undefined] = ACTIONS(1560),
    [anon_sym_readonly] = ACTIONS(1562),
    [anon_sym_QMARK] = ACTIONS(204),
    [anon_sym_any] = ACTIONS(216),
    [anon_sym_number] = ACTIONS(216),
    [anon_sym_boolean] = ACTIONS(216),
    [anon_sym_string] = ACTIONS(216),
    [anon_sym_symbol] = ACTIONS(216),
    [anon_sym_object] = ACTIONS(216),
    [anon_sym_abstract] = ACTIONS(208),
    [anon_sym_satisfies] = ACTIONS(120),
    [anon_sym_infer] = ACTIONS(210),
    [anon_sym_keyof] = ACTIONS(212),
    [anon_sym_unique] = ACTIONS(214),
    [anon_sym_unknown] = ACTIONS(216),
    [anon_sym_never] = ACTIONS(216),
    [anon_sym_LBRACE_PIPE] = ACTIONS(218),
    [sym__ternary_qmark] = ACTIONS(154),
    [sym_html_comment] = ACTIONS(5),
  },
  [193] = {
    [sym_import] = STATE(4878),
    [sym_nested_identifier] = STATE(5474),
    [sym_string] = STATE(2994),
    [sym_formal_parameters] = STATE(5475),
    [sym_nested_type_identifier] = STATE(2939),
    [sym__type_query_member_expression_in_type_annotation] = STATE(2937),
    [sym__type_query_call_expression_in_type_annotation] = STATE(2938),
    [sym_type] = STATE(3153),
    [sym_constructor_type] = STATE(3007),
    [sym_primary_type] = STATE(2981),
    [sym_template_literal_type] = STATE(3039),
    [sym_infer_type] = STATE(3007),
    [sym_conditional_type] = STATE(3039),
    [sym_generic_type] = STATE(3039),
    [sym_type_query] = STATE(3039),
    [sym_index_type_query] = STATE(3039),
    [sym_lookup_type] = STATE(3039),
    [sym_literal_type] = STATE(3039),
    [sym__number] = STATE(3041),
    [sym_existential_type] = STATE(3039),
    [sym_flow_maybe_type] = STATE(3039),
    [sym_parenthesized_type] = STATE(3039),
    [sym_predefined_type] = STATE(3039),
    [sym_object_type] = STATE(3039),
    [sym_type_parameters] = STATE(5248),
    [sym_array_type] = STATE(3039),
    [sym_tuple_type] = STATE(3039),
    [sym_readonly_type] = STATE(3007),
    [sym_union_type] = STATE(3039),
    [sym_intersection_type] = STATE(3039),
    [sym_function_type] = STATE(3007),
    [sym_identifier] = ACTIONS(1532),
    [anon_sym_STAR] = ACTIONS(115),
    [anon_sym_EQ] = ACTIONS(824),
    [anon_sym_as] = ACTIONS(120),
    [anon_sym_LBRACE] = ACTIONS(1534),
    [anon_sym_typeof] = ACTIONS(1536),
    [anon_sym_import] = ACTIONS(1538),
    [anon_sym_const] = ACTIONS(133),
    [anon_sym_BANG] = ACTIONS(120),
    [anon_sym_LPAREN] = ACTIONS(1540),
    [anon_sym_in] = ACTIONS(120),
    [anon_sym_LBRACK] = ACTIONS(1542),
    [anon_sym_DOT] = ACTIONS(120),
    [anon_sym_EQ_GT] = ACTIONS(225),
    [anon_sym_QMARK_DOT] = ACTIONS(154),
    [anon_sym_new] = ACTIONS(1544),
    [anon_sym_PLUS_EQ] = ACTIONS(160),
    [anon_sym_DASH_EQ] = ACTIONS(160),
    [anon_sym_STAR_EQ] = ACTIONS(160),
    [anon_sym_SLASH_EQ] = ACTIONS(160),
    [anon_sym_PERCENT_EQ] = ACTIONS(160),
    [anon_sym_CARET_EQ] = ACTIONS(160),
    [anon_sym_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_LT_LT_EQ] = ACTIONS(160),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(160),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP] = ACTIONS(120),
    [anon_sym_PIPE_PIPE] = ACTIONS(120),
    [anon_sym_GT_GT] = ACTIONS(120),
    [anon_sym_GT_GT_GT] = ACTIONS(120),
    [anon_sym_LT_LT] = ACTIONS(120),
    [anon_sym_AMP] = ACTIONS(164),
    [anon_sym_CARET] = ACTIONS(120),
    [anon_sym_PIPE] = ACTIONS(166),
    [anon_sym_PLUS] = ACTIONS(1546),
    [anon_sym_DASH] = ACTIONS(1546),
    [anon_sym_SLASH] = ACTIONS(120),
    [anon_sym_PERCENT] = ACTIONS(120),
    [anon_sym_STAR_STAR] = ACTIONS(120),
    [anon_sym_LT] = ACTIONS(1548),
    [anon_sym_LT_EQ] = ACTIONS(154),
    [anon_sym_EQ_EQ] = ACTIONS(120),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(154),
    [anon_sym_BANG_EQ] = ACTIONS(120),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(154),
    [anon_sym_GT_EQ] = ACTIONS(154),
    [anon_sym_GT] = ACTIONS(120),
    [anon_sym_QMARK_QMARK] = ACTIONS(120),
    [anon_sym_instanceof] = ACTIONS(120),
    [anon_sym_void] = ACTIONS(216),
    [anon_sym_PLUS_PLUS] = ACTIONS(154),
    [anon_sym_DASH_DASH] = ACTIONS(154),
    [anon_sym_DQUOTE] = ACTIONS(1550),
    [anon_sym_SQUOTE] = ACTIONS(1552),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1554),
    [sym_number] = ACTIONS(1556),
    [sym_this] = ACTIONS(1558),
    [sym_true] = ACTIONS(1560),
    [sym_false] = ACTIONS(1560),
    [sym_null] = ACTIONS(1560),
    [sym_undefined] = ACTIONS(1560),
    [anon_sym_readonly] = ACTIONS(1562),
    [anon_sym_QMARK] = ACTIONS(204),
    [anon_sym_any] = ACTIONS(216),
    [anon_sym_number] = ACTIONS(216),
    [anon_sym_boolean] = ACTIONS(216),
    [anon_sym_string] = ACTIONS(216),
    [anon_sym_symbol] = ACTIONS(216),
    [anon_sym_object] = ACTIONS(216),
    [anon_sym_abstract] = ACTIONS(208),
    [anon_sym_satisfies] = ACTIONS(120),
    [anon_sym_infer] = ACTIONS(210),
    [anon_sym_keyof] = ACTIONS(212),
    [anon_sym_unique] = ACTIONS(214),
    [anon_sym_unknown] = ACTIONS(216),
    [anon_sym_never] = ACTIONS(216),
    [anon_sym_LBRACE_PIPE] = ACTIONS(218),
    [sym__ternary_qmark] = ACTIONS(154),
    [sym_html_comment] = ACTIONS(5),
  },
  [194] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1398),
    [sym_expression] = STATE(1832),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(4309),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(4309),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5558),
    [sym__formal_parameter] = STATE(4621),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1352),
    [sym_subscript_expression] = STATE(1352),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(2980),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(4309),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_sequence_expression] = STATE(5679),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_pattern] = STATE(4339),
    [sym_rest_pattern] = STATE(3684),
    [sym_non_null_expression] = STATE(1352),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_accessibility_modifier] = STATE(288),
    [sym_override_modifier] = STATE(303),
    [sym_required_parameter] = STATE(4621),
    [sym_optional_parameter] = STATE(4621),
    [sym__parameter_name] = STATE(3624),
    [sym_type_arguments] = STATE(638),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(267),
    [sym_identifier] = ACTIONS(1652),
    [anon_sym_export] = ACTIONS(724),
    [anon_sym_type] = ACTIONS(724),
    [anon_sym_namespace] = ACTIONS(726),
    [anon_sym_LBRACE] = ACTIONS(808),
    [anon_sym_typeof] = ACTIONS(756),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(724),
    [anon_sym_BANG] = ACTIONS(732),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_RPAREN] = ACTIONS(734),
    [anon_sym_await] = ACTIONS(736),
    [anon_sym_yield] = ACTIONS(738),
    [anon_sym_LBRACK] = ACTIONS(812),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(742),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1654),
    [anon_sym_using] = ACTIONS(746),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(162),
    [anon_sym_PLUS] = ACTIONS(756),
    [anon_sym_DASH] = ACTIONS(756),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(732),
    [anon_sym_void] = ACTIONS(756),
    [anon_sym_delete] = ACTIONS(756),
    [anon_sym_PLUS_PLUS] = ACTIONS(758),
    [anon_sym_DASH_DASH] = ACTIONS(758),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(764),
    [sym_this] = ACTIONS(1656),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1658),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(724),
    [anon_sym_readonly] = ACTIONS(1660),
    [anon_sym_get] = ACTIONS(724),
    [anon_sym_set] = ACTIONS(724),
    [anon_sym_declare] = ACTIONS(724),
    [anon_sym_public] = ACTIONS(776),
    [anon_sym_private] = ACTIONS(776),
    [anon_sym_protected] = ACTIONS(776),
    [anon_sym_override] = ACTIONS(778),
    [anon_sym_module] = ACTIONS(724),
    [anon_sym_any] = ACTIONS(724),
    [anon_sym_number] = ACTIONS(724),
    [anon_sym_boolean] = ACTIONS(724),
    [anon_sym_string] = ACTIONS(724),
    [anon_sym_symbol] = ACTIONS(724),
    [anon_sym_object] = ACTIONS(724),
    [sym_html_comment] = ACTIONS(5),
  },
  [195] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1398),
    [sym_expression] = STATE(1816),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(4309),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(4309),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5558),
    [sym__formal_parameter] = STATE(4621),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1352),
    [sym_subscript_expression] = STATE(1352),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(2980),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(4309),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_sequence_expression] = STATE(5780),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_pattern] = STATE(4339),
    [sym_rest_pattern] = STATE(3684),
    [sym_non_null_expression] = STATE(1352),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_accessibility_modifier] = STATE(288),
    [sym_override_modifier] = STATE(303),
    [sym_required_parameter] = STATE(4621),
    [sym_optional_parameter] = STATE(4621),
    [sym__parameter_name] = STATE(3624),
    [sym_type_arguments] = STATE(638),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(267),
    [sym_identifier] = ACTIONS(1652),
    [anon_sym_export] = ACTIONS(724),
    [anon_sym_type] = ACTIONS(724),
    [anon_sym_namespace] = ACTIONS(726),
    [anon_sym_LBRACE] = ACTIONS(808),
    [anon_sym_typeof] = ACTIONS(756),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(724),
    [anon_sym_BANG] = ACTIONS(732),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_RPAREN] = ACTIONS(734),
    [anon_sym_await] = ACTIONS(736),
    [anon_sym_yield] = ACTIONS(738),
    [anon_sym_LBRACK] = ACTIONS(812),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(742),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1654),
    [anon_sym_using] = ACTIONS(746),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(162),
    [anon_sym_PLUS] = ACTIONS(756),
    [anon_sym_DASH] = ACTIONS(756),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(732),
    [anon_sym_void] = ACTIONS(756),
    [anon_sym_delete] = ACTIONS(756),
    [anon_sym_PLUS_PLUS] = ACTIONS(758),
    [anon_sym_DASH_DASH] = ACTIONS(758),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(764),
    [sym_this] = ACTIONS(1656),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1658),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(724),
    [anon_sym_readonly] = ACTIONS(1660),
    [anon_sym_get] = ACTIONS(724),
    [anon_sym_set] = ACTIONS(724),
    [anon_sym_declare] = ACTIONS(724),
    [anon_sym_public] = ACTIONS(776),
    [anon_sym_private] = ACTIONS(776),
    [anon_sym_protected] = ACTIONS(776),
    [anon_sym_override] = ACTIONS(778),
    [anon_sym_module] = ACTIONS(724),
    [anon_sym_any] = ACTIONS(724),
    [anon_sym_number] = ACTIONS(724),
    [anon_sym_boolean] = ACTIONS(724),
    [anon_sym_string] = ACTIONS(724),
    [anon_sym_symbol] = ACTIONS(724),
    [anon_sym_object] = ACTIONS(724),
    [sym_html_comment] = ACTIONS(5),
  },
  [196] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1213),
    [sym_expression] = STATE(2644),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(3722),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(3722),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5800),
    [sym__formal_parameter] = STATE(5169),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1295),
    [sym_subscript_expression] = STATE(1295),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3013),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(3722),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_pattern] = STATE(4339),
    [sym_rest_pattern] = STATE(3684),
    [sym_non_null_expression] = STATE(1295),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_accessibility_modifier] = STATE(288),
    [sym_override_modifier] = STATE(303),
    [sym_required_parameter] = STATE(5169),
    [sym_optional_parameter] = STATE(5169),
    [sym__parameter_name] = STATE(3624),
    [sym_type_arguments] = STATE(539),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(267),
    [sym_identifier] = ACTIONS(696),
    [anon_sym_export] = ACTIONS(113),
    [anon_sym_type] = ACTIONS(113),
    [anon_sym_namespace] = ACTIONS(122),
    [anon_sym_LBRACE] = ACTIONS(698),
    [anon_sym_typeof] = ACTIONS(179),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(113),
    [anon_sym_BANG] = ACTIONS(175),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_RPAREN] = ACTIONS(1662),
    [anon_sym_await] = ACTIONS(140),
    [anon_sym_yield] = ACTIONS(142),
    [anon_sym_LBRACK] = ACTIONS(1664),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(148),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(706),
    [anon_sym_using] = ACTIONS(158),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(162),
    [anon_sym_PLUS] = ACTIONS(179),
    [anon_sym_DASH] = ACTIONS(179),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(175),
    [anon_sym_void] = ACTIONS(179),
    [anon_sym_delete] = ACTIONS(179),
    [anon_sym_PLUS_PLUS] = ACTIONS(686),
    [anon_sym_DASH_DASH] = ACTIONS(686),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(192),
    [sym_this] = ACTIONS(1666),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(718),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(113),
    [anon_sym_readonly] = ACTIONS(1668),
    [anon_sym_get] = ACTIONS(113),
    [anon_sym_set] = ACTIONS(113),
    [anon_sym_declare] = ACTIONS(113),
    [anon_sym_public] = ACTIONS(798),
    [anon_sym_private] = ACTIONS(798),
    [anon_sym_protected] = ACTIONS(798),
    [anon_sym_override] = ACTIONS(800),
    [anon_sym_module] = ACTIONS(113),
    [anon_sym_any] = ACTIONS(113),
    [anon_sym_number] = ACTIONS(113),
    [anon_sym_boolean] = ACTIONS(113),
    [anon_sym_string] = ACTIONS(113),
    [anon_sym_symbol] = ACTIONS(113),
    [anon_sym_object] = ACTIONS(113),
    [sym_html_comment] = ACTIONS(5),
  },
  [197] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1213),
    [sym_expression] = STATE(2644),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(3722),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(3722),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5800),
    [sym__formal_parameter] = STATE(4899),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1295),
    [sym_subscript_expression] = STATE(1295),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3013),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(3722),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_pattern] = STATE(4339),
    [sym_rest_pattern] = STATE(3684),
    [sym_non_null_expression] = STATE(1295),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_accessibility_modifier] = STATE(288),
    [sym_override_modifier] = STATE(303),
    [sym_required_parameter] = STATE(4899),
    [sym_optional_parameter] = STATE(4899),
    [sym__parameter_name] = STATE(3624),
    [sym_type_arguments] = STATE(539),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(267),
    [sym_identifier] = ACTIONS(696),
    [anon_sym_export] = ACTIONS(113),
    [anon_sym_type] = ACTIONS(113),
    [anon_sym_namespace] = ACTIONS(122),
    [anon_sym_LBRACE] = ACTIONS(698),
    [anon_sym_typeof] = ACTIONS(179),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(113),
    [anon_sym_BANG] = ACTIONS(175),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_RPAREN] = ACTIONS(1670),
    [anon_sym_await] = ACTIONS(140),
    [anon_sym_yield] = ACTIONS(142),
    [anon_sym_LBRACK] = ACTIONS(1664),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(148),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(706),
    [anon_sym_using] = ACTIONS(158),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(162),
    [anon_sym_PLUS] = ACTIONS(179),
    [anon_sym_DASH] = ACTIONS(179),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(175),
    [anon_sym_void] = ACTIONS(179),
    [anon_sym_delete] = ACTIONS(179),
    [anon_sym_PLUS_PLUS] = ACTIONS(686),
    [anon_sym_DASH_DASH] = ACTIONS(686),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(192),
    [sym_this] = ACTIONS(1666),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(718),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(113),
    [anon_sym_readonly] = ACTIONS(1668),
    [anon_sym_get] = ACTIONS(113),
    [anon_sym_set] = ACTIONS(113),
    [anon_sym_declare] = ACTIONS(113),
    [anon_sym_public] = ACTIONS(798),
    [anon_sym_private] = ACTIONS(798),
    [anon_sym_protected] = ACTIONS(798),
    [anon_sym_override] = ACTIONS(800),
    [anon_sym_module] = ACTIONS(113),
    [anon_sym_any] = ACTIONS(113),
    [anon_sym_number] = ACTIONS(113),
    [anon_sym_boolean] = ACTIONS(113),
    [anon_sym_string] = ACTIONS(113),
    [anon_sym_symbol] = ACTIONS(113),
    [anon_sym_object] = ACTIONS(113),
    [sym_html_comment] = ACTIONS(5),
  },
  [198] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1213),
    [sym_expression] = STATE(2644),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(3722),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(3722),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5800),
    [sym__formal_parameter] = STATE(4939),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1295),
    [sym_subscript_expression] = STATE(1295),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3013),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(3722),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_pattern] = STATE(4339),
    [sym_rest_pattern] = STATE(3684),
    [sym_non_null_expression] = STATE(1295),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_accessibility_modifier] = STATE(288),
    [sym_override_modifier] = STATE(303),
    [sym_required_parameter] = STATE(4939),
    [sym_optional_parameter] = STATE(4939),
    [sym__parameter_name] = STATE(3624),
    [sym_type_arguments] = STATE(539),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(267),
    [sym_identifier] = ACTIONS(696),
    [anon_sym_export] = ACTIONS(113),
    [anon_sym_type] = ACTIONS(113),
    [anon_sym_namespace] = ACTIONS(122),
    [anon_sym_LBRACE] = ACTIONS(698),
    [anon_sym_typeof] = ACTIONS(179),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(113),
    [anon_sym_BANG] = ACTIONS(175),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_RPAREN] = ACTIONS(1672),
    [anon_sym_await] = ACTIONS(140),
    [anon_sym_yield] = ACTIONS(142),
    [anon_sym_LBRACK] = ACTIONS(1664),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(148),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(706),
    [anon_sym_using] = ACTIONS(158),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(162),
    [anon_sym_PLUS] = ACTIONS(179),
    [anon_sym_DASH] = ACTIONS(179),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(175),
    [anon_sym_void] = ACTIONS(179),
    [anon_sym_delete] = ACTIONS(179),
    [anon_sym_PLUS_PLUS] = ACTIONS(686),
    [anon_sym_DASH_DASH] = ACTIONS(686),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(192),
    [sym_this] = ACTIONS(1666),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(718),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(113),
    [anon_sym_readonly] = ACTIONS(1668),
    [anon_sym_get] = ACTIONS(113),
    [anon_sym_set] = ACTIONS(113),
    [anon_sym_declare] = ACTIONS(113),
    [anon_sym_public] = ACTIONS(798),
    [anon_sym_private] = ACTIONS(798),
    [anon_sym_protected] = ACTIONS(798),
    [anon_sym_override] = ACTIONS(800),
    [anon_sym_module] = ACTIONS(113),
    [anon_sym_any] = ACTIONS(113),
    [anon_sym_number] = ACTIONS(113),
    [anon_sym_boolean] = ACTIONS(113),
    [anon_sym_string] = ACTIONS(113),
    [anon_sym_symbol] = ACTIONS(113),
    [anon_sym_object] = ACTIONS(113),
    [sym_html_comment] = ACTIONS(5),
  },
  [199] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1213),
    [sym_expression] = STATE(2644),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(3722),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(3722),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5800),
    [sym__formal_parameter] = STATE(4621),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1295),
    [sym_subscript_expression] = STATE(1295),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3013),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(3722),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_pattern] = STATE(4339),
    [sym_rest_pattern] = STATE(3684),
    [sym_non_null_expression] = STATE(1295),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_accessibility_modifier] = STATE(288),
    [sym_override_modifier] = STATE(303),
    [sym_required_parameter] = STATE(4621),
    [sym_optional_parameter] = STATE(4621),
    [sym__parameter_name] = STATE(3624),
    [sym_type_arguments] = STATE(539),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(267),
    [sym_identifier] = ACTIONS(696),
    [anon_sym_export] = ACTIONS(113),
    [anon_sym_type] = ACTIONS(113),
    [anon_sym_namespace] = ACTIONS(122),
    [anon_sym_LBRACE] = ACTIONS(698),
    [anon_sym_typeof] = ACTIONS(179),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(113),
    [anon_sym_BANG] = ACTIONS(175),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_RPAREN] = ACTIONS(734),
    [anon_sym_await] = ACTIONS(140),
    [anon_sym_yield] = ACTIONS(142),
    [anon_sym_LBRACK] = ACTIONS(1664),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(148),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(706),
    [anon_sym_using] = ACTIONS(158),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(162),
    [anon_sym_PLUS] = ACTIONS(179),
    [anon_sym_DASH] = ACTIONS(179),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(175),
    [anon_sym_void] = ACTIONS(179),
    [anon_sym_delete] = ACTIONS(179),
    [anon_sym_PLUS_PLUS] = ACTIONS(686),
    [anon_sym_DASH_DASH] = ACTIONS(686),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(192),
    [sym_this] = ACTIONS(1666),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(718),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(113),
    [anon_sym_readonly] = ACTIONS(1668),
    [anon_sym_get] = ACTIONS(113),
    [anon_sym_set] = ACTIONS(113),
    [anon_sym_declare] = ACTIONS(113),
    [anon_sym_public] = ACTIONS(798),
    [anon_sym_private] = ACTIONS(798),
    [anon_sym_protected] = ACTIONS(798),
    [anon_sym_override] = ACTIONS(800),
    [anon_sym_module] = ACTIONS(113),
    [anon_sym_any] = ACTIONS(113),
    [anon_sym_number] = ACTIONS(113),
    [anon_sym_boolean] = ACTIONS(113),
    [anon_sym_string] = ACTIONS(113),
    [anon_sym_symbol] = ACTIONS(113),
    [anon_sym_object] = ACTIONS(113),
    [sym_html_comment] = ACTIONS(5),
  },
  [200] = {
    [sym_statement_block] = STATE(217),
    [ts_builtin_sym_end] = ACTIONS(1674),
    [sym_identifier] = ACTIONS(1676),
    [anon_sym_export] = ACTIONS(1676),
    [anon_sym_STAR] = ACTIONS(1676),
    [anon_sym_default] = ACTIONS(1676),
    [anon_sym_type] = ACTIONS(1676),
    [anon_sym_as] = ACTIONS(1676),
    [anon_sym_namespace] = ACTIONS(1676),
    [anon_sym_LBRACE] = ACTIONS(1678),
    [anon_sym_COMMA] = ACTIONS(1674),
    [anon_sym_RBRACE] = ACTIONS(1674),
    [anon_sym_typeof] = ACTIONS(1676),
    [anon_sym_import] = ACTIONS(1676),
    [anon_sym_with] = ACTIONS(1676),
    [anon_sym_var] = ACTIONS(1676),
    [anon_sym_let] = ACTIONS(1676),
    [anon_sym_const] = ACTIONS(1676),
    [anon_sym_BANG] = ACTIONS(1676),
    [anon_sym_else] = ACTIONS(1676),
    [anon_sym_if] = ACTIONS(1676),
    [anon_sym_switch] = ACTIONS(1676),
    [anon_sym_for] = ACTIONS(1676),
    [anon_sym_LPAREN] = ACTIONS(1674),
    [anon_sym_SEMI] = ACTIONS(1674),
    [anon_sym_await] = ACTIONS(1676),
    [anon_sym_in] = ACTIONS(1676),
    [anon_sym_while] = ACTIONS(1676),
    [anon_sym_do] = ACTIONS(1676),
    [anon_sym_try] = ACTIONS(1676),
    [anon_sym_break] = ACTIONS(1676),
    [anon_sym_continue] = ACTIONS(1676),
    [anon_sym_debugger] = ACTIONS(1676),
    [anon_sym_return] = ACTIONS(1676),
    [anon_sym_throw] = ACTIONS(1676),
    [anon_sym_case] = ACTIONS(1676),
    [anon_sym_yield] = ACTIONS(1676),
    [anon_sym_LBRACK] = ACTIONS(1674),
    [anon_sym_DOT] = ACTIONS(1680),
    [anon_sym_class] = ACTIONS(1676),
    [anon_sym_async] = ACTIONS(1676),
    [anon_sym_function] = ACTIONS(1676),
    [anon_sym_QMARK_DOT] = ACTIONS(1674),
    [anon_sym_new] = ACTIONS(1676),
    [anon_sym_using] = ACTIONS(1676),
    [anon_sym_AMP_AMP] = ACTIONS(1674),
    [anon_sym_PIPE_PIPE] = ACTIONS(1674),
    [anon_sym_GT_GT] = ACTIONS(1676),
    [anon_sym_GT_GT_GT] = ACTIONS(1674),
    [anon_sym_LT_LT] = ACTIONS(1674),
    [anon_sym_AMP] = ACTIONS(1676),
    [anon_sym_CARET] = ACTIONS(1674),
    [anon_sym_PIPE] = ACTIONS(1676),
    [anon_sym_PLUS] = ACTIONS(1676),
    [anon_sym_DASH] = ACTIONS(1676),
    [anon_sym_SLASH] = ACTIONS(1676),
    [anon_sym_PERCENT] = ACTIONS(1674),
    [anon_sym_STAR_STAR] = ACTIONS(1674),
    [anon_sym_LT] = ACTIONS(1676),
    [anon_sym_LT_EQ] = ACTIONS(1674),
    [anon_sym_EQ_EQ] = ACTIONS(1676),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(1674),
    [anon_sym_BANG_EQ] = ACTIONS(1676),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(1674),
    [anon_sym_GT_EQ] = ACTIONS(1674),
    [anon_sym_GT] = ACTIONS(1676),
    [anon_sym_QMARK_QMARK] = ACTIONS(1674),
    [anon_sym_instanceof] = ACTIONS(1676),
    [anon_sym_TILDE] = ACTIONS(1674),
    [anon_sym_void] = ACTIONS(1676),
    [anon_sym_delete] = ACTIONS(1676),
    [anon_sym_PLUS_PLUS] = ACTIONS(1674),
    [anon_sym_DASH_DASH] = ACTIONS(1674),
    [anon_sym_DQUOTE] = ACTIONS(1674),
    [anon_sym_SQUOTE] = ACTIONS(1674),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1674),
    [sym_number] = ACTIONS(1674),
    [sym_private_property_identifier] = ACTIONS(1674),
    [sym_this] = ACTIONS(1676),
    [sym_super] = ACTIONS(1676),
    [sym_true] = ACTIONS(1676),
    [sym_false] = ACTIONS(1676),
    [sym_null] = ACTIONS(1676),
    [sym_undefined] = ACTIONS(1676),
    [anon_sym_AT] = ACTIONS(1674),
    [anon_sym_static] = ACTIONS(1676),
    [anon_sym_readonly] = ACTIONS(1676),
    [anon_sym_get] = ACTIONS(1676),
    [anon_sym_set] = ACTIONS(1676),
    [anon_sym_declare] = ACTIONS(1676),
    [anon_sym_public] = ACTIONS(1676),
    [anon_sym_private] = ACTIONS(1676),
    [anon_sym_protected] = ACTIONS(1676),
    [anon_sym_override] = ACTIONS(1676),
    [anon_sym_module] = ACTIONS(1676),
    [anon_sym_any] = ACTIONS(1676),
    [anon_sym_number] = ACTIONS(1676),
    [anon_sym_boolean] = ACTIONS(1676),
    [anon_sym_string] = ACTIONS(1676),
    [anon_sym_symbol] = ACTIONS(1676),
    [anon_sym_object] = ACTIONS(1676),
    [anon_sym_abstract] = ACTIONS(1676),
    [anon_sym_satisfies] = ACTIONS(1676),
    [anon_sym_interface] = ACTIONS(1676),
    [anon_sym_enum] = ACTIONS(1676),
    [sym__automatic_semicolon] = ACTIONS(1674),
    [sym__ternary_qmark] = ACTIONS(1674),
    [sym_html_comment] = ACTIONS(5),
  },
  [201] = {
    [sym_statement_block] = STATE(217),
    [ts_builtin_sym_end] = ACTIONS(1674),
    [sym_identifier] = ACTIONS(1676),
    [anon_sym_export] = ACTIONS(1676),
    [anon_sym_STAR] = ACTIONS(1676),
    [anon_sym_default] = ACTIONS(1676),
    [anon_sym_type] = ACTIONS(1676),
    [anon_sym_as] = ACTIONS(1676),
    [anon_sym_namespace] = ACTIONS(1676),
    [anon_sym_LBRACE] = ACTIONS(1678),
    [anon_sym_COMMA] = ACTIONS(1674),
    [anon_sym_RBRACE] = ACTIONS(1674),
    [anon_sym_typeof] = ACTIONS(1676),
    [anon_sym_import] = ACTIONS(1676),
    [anon_sym_with] = ACTIONS(1676),
    [anon_sym_var] = ACTIONS(1676),
    [anon_sym_let] = ACTIONS(1676),
    [anon_sym_const] = ACTIONS(1676),
    [anon_sym_BANG] = ACTIONS(1676),
    [anon_sym_else] = ACTIONS(1676),
    [anon_sym_if] = ACTIONS(1676),
    [anon_sym_switch] = ACTIONS(1676),
    [anon_sym_for] = ACTIONS(1676),
    [anon_sym_LPAREN] = ACTIONS(1674),
    [anon_sym_SEMI] = ACTIONS(1674),
    [anon_sym_await] = ACTIONS(1676),
    [anon_sym_in] = ACTIONS(1676),
    [anon_sym_while] = ACTIONS(1676),
    [anon_sym_do] = ACTIONS(1676),
    [anon_sym_try] = ACTIONS(1676),
    [anon_sym_break] = ACTIONS(1676),
    [anon_sym_continue] = ACTIONS(1676),
    [anon_sym_debugger] = ACTIONS(1676),
    [anon_sym_return] = ACTIONS(1676),
    [anon_sym_throw] = ACTIONS(1676),
    [anon_sym_case] = ACTIONS(1676),
    [anon_sym_yield] = ACTIONS(1676),
    [anon_sym_LBRACK] = ACTIONS(1674),
    [anon_sym_DOT] = ACTIONS(1682),
    [anon_sym_class] = ACTIONS(1676),
    [anon_sym_async] = ACTIONS(1676),
    [anon_sym_function] = ACTIONS(1676),
    [anon_sym_QMARK_DOT] = ACTIONS(1674),
    [anon_sym_new] = ACTIONS(1676),
    [anon_sym_using] = ACTIONS(1676),
    [anon_sym_AMP_AMP] = ACTIONS(1674),
    [anon_sym_PIPE_PIPE] = ACTIONS(1674),
    [anon_sym_GT_GT] = ACTIONS(1676),
    [anon_sym_GT_GT_GT] = ACTIONS(1674),
    [anon_sym_LT_LT] = ACTIONS(1674),
    [anon_sym_AMP] = ACTIONS(1676),
    [anon_sym_CARET] = ACTIONS(1674),
    [anon_sym_PIPE] = ACTIONS(1676),
    [anon_sym_PLUS] = ACTIONS(1676),
    [anon_sym_DASH] = ACTIONS(1676),
    [anon_sym_SLASH] = ACTIONS(1676),
    [anon_sym_PERCENT] = ACTIONS(1674),
    [anon_sym_STAR_STAR] = ACTIONS(1674),
    [anon_sym_LT] = ACTIONS(1676),
    [anon_sym_LT_EQ] = ACTIONS(1674),
    [anon_sym_EQ_EQ] = ACTIONS(1676),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(1674),
    [anon_sym_BANG_EQ] = ACTIONS(1676),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(1674),
    [anon_sym_GT_EQ] = ACTIONS(1674),
    [anon_sym_GT] = ACTIONS(1676),
    [anon_sym_QMARK_QMARK] = ACTIONS(1674),
    [anon_sym_instanceof] = ACTIONS(1676),
    [anon_sym_TILDE] = ACTIONS(1674),
    [anon_sym_void] = ACTIONS(1676),
    [anon_sym_delete] = ACTIONS(1676),
    [anon_sym_PLUS_PLUS] = ACTIONS(1674),
    [anon_sym_DASH_DASH] = ACTIONS(1674),
    [anon_sym_DQUOTE] = ACTIONS(1674),
    [anon_sym_SQUOTE] = ACTIONS(1674),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1674),
    [sym_number] = ACTIONS(1674),
    [sym_private_property_identifier] = ACTIONS(1674),
    [sym_this] = ACTIONS(1676),
    [sym_super] = ACTIONS(1676),
    [sym_true] = ACTIONS(1676),
    [sym_false] = ACTIONS(1676),
    [sym_null] = ACTIONS(1676),
    [sym_undefined] = ACTIONS(1676),
    [anon_sym_AT] = ACTIONS(1674),
    [anon_sym_static] = ACTIONS(1676),
    [anon_sym_readonly] = ACTIONS(1676),
    [anon_sym_get] = ACTIONS(1676),
    [anon_sym_set] = ACTIONS(1676),
    [anon_sym_declare] = ACTIONS(1676),
    [anon_sym_public] = ACTIONS(1676),
    [anon_sym_private] = ACTIONS(1676),
    [anon_sym_protected] = ACTIONS(1676),
    [anon_sym_override] = ACTIONS(1676),
    [anon_sym_module] = ACTIONS(1676),
    [anon_sym_any] = ACTIONS(1676),
    [anon_sym_number] = ACTIONS(1676),
    [anon_sym_boolean] = ACTIONS(1676),
    [anon_sym_string] = ACTIONS(1676),
    [anon_sym_symbol] = ACTIONS(1676),
    [anon_sym_object] = ACTIONS(1676),
    [anon_sym_abstract] = ACTIONS(1676),
    [anon_sym_satisfies] = ACTIONS(1676),
    [anon_sym_interface] = ACTIONS(1676),
    [anon_sym_enum] = ACTIONS(1676),
    [sym__automatic_semicolon] = ACTIONS(1674),
    [sym__ternary_qmark] = ACTIONS(1674),
    [sym_html_comment] = ACTIONS(5),
  },
  [202] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1213),
    [sym_expression] = STATE(2644),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(3722),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(3722),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5800),
    [sym__formal_parameter] = STATE(5169),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1295),
    [sym_subscript_expression] = STATE(1295),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3013),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(3722),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_pattern] = STATE(4339),
    [sym_rest_pattern] = STATE(3684),
    [sym_non_null_expression] = STATE(1295),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_accessibility_modifier] = STATE(288),
    [sym_override_modifier] = STATE(303),
    [sym_required_parameter] = STATE(5169),
    [sym_optional_parameter] = STATE(5169),
    [sym__parameter_name] = STATE(3624),
    [sym_type_arguments] = STATE(539),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(267),
    [sym_identifier] = ACTIONS(696),
    [anon_sym_export] = ACTIONS(113),
    [anon_sym_type] = ACTIONS(113),
    [anon_sym_namespace] = ACTIONS(122),
    [anon_sym_LBRACE] = ACTIONS(698),
    [anon_sym_typeof] = ACTIONS(179),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(113),
    [anon_sym_BANG] = ACTIONS(175),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_RPAREN] = ACTIONS(1684),
    [anon_sym_await] = ACTIONS(140),
    [anon_sym_yield] = ACTIONS(142),
    [anon_sym_LBRACK] = ACTIONS(1664),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(148),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(706),
    [anon_sym_using] = ACTIONS(158),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(162),
    [anon_sym_PLUS] = ACTIONS(179),
    [anon_sym_DASH] = ACTIONS(179),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(175),
    [anon_sym_void] = ACTIONS(179),
    [anon_sym_delete] = ACTIONS(179),
    [anon_sym_PLUS_PLUS] = ACTIONS(686),
    [anon_sym_DASH_DASH] = ACTIONS(686),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(192),
    [sym_this] = ACTIONS(1666),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(718),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(113),
    [anon_sym_readonly] = ACTIONS(1668),
    [anon_sym_get] = ACTIONS(113),
    [anon_sym_set] = ACTIONS(113),
    [anon_sym_declare] = ACTIONS(113),
    [anon_sym_public] = ACTIONS(798),
    [anon_sym_private] = ACTIONS(798),
    [anon_sym_protected] = ACTIONS(798),
    [anon_sym_override] = ACTIONS(800),
    [anon_sym_module] = ACTIONS(113),
    [anon_sym_any] = ACTIONS(113),
    [anon_sym_number] = ACTIONS(113),
    [anon_sym_boolean] = ACTIONS(113),
    [anon_sym_string] = ACTIONS(113),
    [anon_sym_symbol] = ACTIONS(113),
    [anon_sym_object] = ACTIONS(113),
    [sym_html_comment] = ACTIONS(5),
  },
  [203] = {
    [sym_statement_block] = STATE(217),
    [ts_builtin_sym_end] = ACTIONS(1674),
    [sym_identifier] = ACTIONS(1676),
    [anon_sym_export] = ACTIONS(1676),
    [anon_sym_STAR] = ACTIONS(1676),
    [anon_sym_default] = ACTIONS(1676),
    [anon_sym_type] = ACTIONS(1676),
    [anon_sym_as] = ACTIONS(1676),
    [anon_sym_namespace] = ACTIONS(1676),
    [anon_sym_LBRACE] = ACTIONS(1678),
    [anon_sym_COMMA] = ACTIONS(1674),
    [anon_sym_RBRACE] = ACTIONS(1674),
    [anon_sym_typeof] = ACTIONS(1676),
    [anon_sym_import] = ACTIONS(1676),
    [anon_sym_with] = ACTIONS(1676),
    [anon_sym_var] = ACTIONS(1676),
    [anon_sym_let] = ACTIONS(1676),
    [anon_sym_const] = ACTIONS(1676),
    [anon_sym_BANG] = ACTIONS(1676),
    [anon_sym_else] = ACTIONS(1676),
    [anon_sym_if] = ACTIONS(1676),
    [anon_sym_switch] = ACTIONS(1676),
    [anon_sym_for] = ACTIONS(1676),
    [anon_sym_LPAREN] = ACTIONS(1674),
    [anon_sym_SEMI] = ACTIONS(1674),
    [anon_sym_await] = ACTIONS(1676),
    [anon_sym_in] = ACTIONS(1676),
    [anon_sym_while] = ACTIONS(1676),
    [anon_sym_do] = ACTIONS(1676),
    [anon_sym_try] = ACTIONS(1676),
    [anon_sym_break] = ACTIONS(1676),
    [anon_sym_continue] = ACTIONS(1676),
    [anon_sym_debugger] = ACTIONS(1676),
    [anon_sym_return] = ACTIONS(1676),
    [anon_sym_throw] = ACTIONS(1676),
    [anon_sym_case] = ACTIONS(1676),
    [anon_sym_yield] = ACTIONS(1676),
    [anon_sym_LBRACK] = ACTIONS(1674),
    [anon_sym_DOT] = ACTIONS(1676),
    [anon_sym_class] = ACTIONS(1676),
    [anon_sym_async] = ACTIONS(1676),
    [anon_sym_function] = ACTIONS(1676),
    [anon_sym_QMARK_DOT] = ACTIONS(1674),
    [anon_sym_new] = ACTIONS(1676),
    [anon_sym_using] = ACTIONS(1676),
    [anon_sym_AMP_AMP] = ACTIONS(1674),
    [anon_sym_PIPE_PIPE] = ACTIONS(1674),
    [anon_sym_GT_GT] = ACTIONS(1676),
    [anon_sym_GT_GT_GT] = ACTIONS(1674),
    [anon_sym_LT_LT] = ACTIONS(1674),
    [anon_sym_AMP] = ACTIONS(1676),
    [anon_sym_CARET] = ACTIONS(1674),
    [anon_sym_PIPE] = ACTIONS(1676),
    [anon_sym_PLUS] = ACTIONS(1676),
    [anon_sym_DASH] = ACTIONS(1676),
    [anon_sym_SLASH] = ACTIONS(1676),
    [anon_sym_PERCENT] = ACTIONS(1674),
    [anon_sym_STAR_STAR] = ACTIONS(1674),
    [anon_sym_LT] = ACTIONS(1676),
    [anon_sym_LT_EQ] = ACTIONS(1674),
    [anon_sym_EQ_EQ] = ACTIONS(1676),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(1674),
    [anon_sym_BANG_EQ] = ACTIONS(1676),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(1674),
    [anon_sym_GT_EQ] = ACTIONS(1674),
    [anon_sym_GT] = ACTIONS(1676),
    [anon_sym_QMARK_QMARK] = ACTIONS(1674),
    [anon_sym_instanceof] = ACTIONS(1676),
    [anon_sym_TILDE] = ACTIONS(1674),
    [anon_sym_void] = ACTIONS(1676),
    [anon_sym_delete] = ACTIONS(1676),
    [anon_sym_PLUS_PLUS] = ACTIONS(1674),
    [anon_sym_DASH_DASH] = ACTIONS(1674),
    [anon_sym_DQUOTE] = ACTIONS(1674),
    [anon_sym_SQUOTE] = ACTIONS(1674),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1674),
    [sym_number] = ACTIONS(1674),
    [sym_private_property_identifier] = ACTIONS(1674),
    [sym_this] = ACTIONS(1676),
    [sym_super] = ACTIONS(1676),
    [sym_true] = ACTIONS(1676),
    [sym_false] = ACTIONS(1676),
    [sym_null] = ACTIONS(1676),
    [sym_undefined] = ACTIONS(1676),
    [anon_sym_AT] = ACTIONS(1674),
    [anon_sym_static] = ACTIONS(1676),
    [anon_sym_readonly] = ACTIONS(1676),
    [anon_sym_get] = ACTIONS(1676),
    [anon_sym_set] = ACTIONS(1676),
    [anon_sym_declare] = ACTIONS(1676),
    [anon_sym_public] = ACTIONS(1676),
    [anon_sym_private] = ACTIONS(1676),
    [anon_sym_protected] = ACTIONS(1676),
    [anon_sym_override] = ACTIONS(1676),
    [anon_sym_module] = ACTIONS(1676),
    [anon_sym_any] = ACTIONS(1676),
    [anon_sym_number] = ACTIONS(1676),
    [anon_sym_boolean] = ACTIONS(1676),
    [anon_sym_string] = ACTIONS(1676),
    [anon_sym_symbol] = ACTIONS(1676),
    [anon_sym_object] = ACTIONS(1676),
    [anon_sym_abstract] = ACTIONS(1676),
    [anon_sym_satisfies] = ACTIONS(1676),
    [anon_sym_interface] = ACTIONS(1676),
    [anon_sym_enum] = ACTIONS(1676),
    [sym__automatic_semicolon] = ACTIONS(1674),
    [sym__ternary_qmark] = ACTIONS(1674),
    [sym_html_comment] = ACTIONS(5),
  },
  [204] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1213),
    [sym_expression] = STATE(2644),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(3722),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(3722),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5800),
    [sym__formal_parameter] = STATE(5169),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1295),
    [sym_subscript_expression] = STATE(1295),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3013),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(3722),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_pattern] = STATE(4339),
    [sym_rest_pattern] = STATE(3684),
    [sym_non_null_expression] = STATE(1295),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_accessibility_modifier] = STATE(288),
    [sym_override_modifier] = STATE(303),
    [sym_required_parameter] = STATE(5169),
    [sym_optional_parameter] = STATE(5169),
    [sym__parameter_name] = STATE(3624),
    [sym_type_arguments] = STATE(539),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(267),
    [sym_identifier] = ACTIONS(696),
    [anon_sym_export] = ACTIONS(113),
    [anon_sym_type] = ACTIONS(113),
    [anon_sym_namespace] = ACTIONS(122),
    [anon_sym_LBRACE] = ACTIONS(698),
    [anon_sym_typeof] = ACTIONS(179),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(113),
    [anon_sym_BANG] = ACTIONS(175),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_RPAREN] = ACTIONS(1686),
    [anon_sym_await] = ACTIONS(140),
    [anon_sym_yield] = ACTIONS(142),
    [anon_sym_LBRACK] = ACTIONS(1664),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(148),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(706),
    [anon_sym_using] = ACTIONS(158),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(162),
    [anon_sym_PLUS] = ACTIONS(179),
    [anon_sym_DASH] = ACTIONS(179),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(175),
    [anon_sym_void] = ACTIONS(179),
    [anon_sym_delete] = ACTIONS(179),
    [anon_sym_PLUS_PLUS] = ACTIONS(686),
    [anon_sym_DASH_DASH] = ACTIONS(686),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(192),
    [sym_this] = ACTIONS(1666),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(718),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(113),
    [anon_sym_readonly] = ACTIONS(1668),
    [anon_sym_get] = ACTIONS(113),
    [anon_sym_set] = ACTIONS(113),
    [anon_sym_declare] = ACTIONS(113),
    [anon_sym_public] = ACTIONS(798),
    [anon_sym_private] = ACTIONS(798),
    [anon_sym_protected] = ACTIONS(798),
    [anon_sym_override] = ACTIONS(800),
    [anon_sym_module] = ACTIONS(113),
    [anon_sym_any] = ACTIONS(113),
    [anon_sym_number] = ACTIONS(113),
    [anon_sym_boolean] = ACTIONS(113),
    [anon_sym_string] = ACTIONS(113),
    [anon_sym_symbol] = ACTIONS(113),
    [anon_sym_object] = ACTIONS(113),
    [sym_html_comment] = ACTIONS(5),
  },
  [205] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1213),
    [sym_expression] = STATE(2644),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(3722),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(3722),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5800),
    [sym__formal_parameter] = STATE(5169),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1295),
    [sym_subscript_expression] = STATE(1295),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3013),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(3722),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_pattern] = STATE(4339),
    [sym_rest_pattern] = STATE(3684),
    [sym_non_null_expression] = STATE(1295),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_accessibility_modifier] = STATE(288),
    [sym_override_modifier] = STATE(303),
    [sym_required_parameter] = STATE(5169),
    [sym_optional_parameter] = STATE(5169),
    [sym__parameter_name] = STATE(3624),
    [sym_type_arguments] = STATE(539),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(267),
    [sym_identifier] = ACTIONS(696),
    [anon_sym_export] = ACTIONS(113),
    [anon_sym_type] = ACTIONS(113),
    [anon_sym_namespace] = ACTIONS(122),
    [anon_sym_LBRACE] = ACTIONS(698),
    [anon_sym_typeof] = ACTIONS(179),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(113),
    [anon_sym_BANG] = ACTIONS(175),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_RPAREN] = ACTIONS(1688),
    [anon_sym_await] = ACTIONS(140),
    [anon_sym_yield] = ACTIONS(142),
    [anon_sym_LBRACK] = ACTIONS(1664),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(148),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(706),
    [anon_sym_using] = ACTIONS(158),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(162),
    [anon_sym_PLUS] = ACTIONS(179),
    [anon_sym_DASH] = ACTIONS(179),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(175),
    [anon_sym_void] = ACTIONS(179),
    [anon_sym_delete] = ACTIONS(179),
    [anon_sym_PLUS_PLUS] = ACTIONS(686),
    [anon_sym_DASH_DASH] = ACTIONS(686),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(192),
    [sym_this] = ACTIONS(1666),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(718),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(113),
    [anon_sym_readonly] = ACTIONS(1668),
    [anon_sym_get] = ACTIONS(113),
    [anon_sym_set] = ACTIONS(113),
    [anon_sym_declare] = ACTIONS(113),
    [anon_sym_public] = ACTIONS(798),
    [anon_sym_private] = ACTIONS(798),
    [anon_sym_protected] = ACTIONS(798),
    [anon_sym_override] = ACTIONS(800),
    [anon_sym_module] = ACTIONS(113),
    [anon_sym_any] = ACTIONS(113),
    [anon_sym_number] = ACTIONS(113),
    [anon_sym_boolean] = ACTIONS(113),
    [anon_sym_string] = ACTIONS(113),
    [anon_sym_symbol] = ACTIONS(113),
    [anon_sym_object] = ACTIONS(113),
    [sym_html_comment] = ACTIONS(5),
  },
  [206] = {
    [ts_builtin_sym_end] = ACTIONS(1690),
    [sym_identifier] = ACTIONS(1692),
    [anon_sym_export] = ACTIONS(1692),
    [anon_sym_STAR] = ACTIONS(1694),
    [anon_sym_default] = ACTIONS(1692),
    [anon_sym_type] = ACTIONS(1692),
    [anon_sym_EQ] = ACTIONS(1696),
    [anon_sym_as] = ACTIONS(1694),
    [anon_sym_namespace] = ACTIONS(1692),
    [anon_sym_LBRACE] = ACTIONS(1690),
    [anon_sym_COMMA] = ACTIONS(1698),
    [anon_sym_RBRACE] = ACTIONS(1690),
    [anon_sym_typeof] = ACTIONS(1692),
    [anon_sym_import] = ACTIONS(1692),
    [anon_sym_with] = ACTIONS(1692),
    [anon_sym_var] = ACTIONS(1692),
    [anon_sym_let] = ACTIONS(1692),
    [anon_sym_const] = ACTIONS(1692),
    [anon_sym_BANG] = ACTIONS(1692),
    [anon_sym_else] = ACTIONS(1692),
    [anon_sym_if] = ACTIONS(1692),
    [anon_sym_switch] = ACTIONS(1692),
    [anon_sym_for] = ACTIONS(1692),
    [anon_sym_LPAREN] = ACTIONS(1690),
    [anon_sym_SEMI] = ACTIONS(1690),
    [anon_sym_await] = ACTIONS(1692),
    [anon_sym_in] = ACTIONS(1694),
    [anon_sym_while] = ACTIONS(1692),
    [anon_sym_do] = ACTIONS(1692),
    [anon_sym_try] = ACTIONS(1692),
    [anon_sym_break] = ACTIONS(1692),
    [anon_sym_continue] = ACTIONS(1692),
    [anon_sym_debugger] = ACTIONS(1692),
    [anon_sym_return] = ACTIONS(1692),
    [anon_sym_throw] = ACTIONS(1692),
    [anon_sym_case] = ACTIONS(1692),
    [anon_sym_yield] = ACTIONS(1692),
    [anon_sym_LBRACK] = ACTIONS(1690),
    [anon_sym_DOT] = ACTIONS(1694),
    [anon_sym_class] = ACTIONS(1692),
    [anon_sym_async] = ACTIONS(1692),
    [anon_sym_function] = ACTIONS(1692),
    [anon_sym_QMARK_DOT] = ACTIONS(1698),
    [anon_sym_new] = ACTIONS(1692),
    [anon_sym_using] = ACTIONS(1692),
    [anon_sym_AMP_AMP] = ACTIONS(1698),
    [anon_sym_PIPE_PIPE] = ACTIONS(1698),
    [anon_sym_GT_GT] = ACTIONS(1694),
    [anon_sym_GT_GT_GT] = ACTIONS(1698),
    [anon_sym_LT_LT] = ACTIONS(1698),
    [anon_sym_AMP] = ACTIONS(1694),
    [anon_sym_CARET] = ACTIONS(1698),
    [anon_sym_PIPE] = ACTIONS(1694),
    [anon_sym_PLUS] = ACTIONS(1692),
    [anon_sym_DASH] = ACTIONS(1692),
    [anon_sym_SLASH] = ACTIONS(1692),
    [anon_sym_PERCENT] = ACTIONS(1698),
    [anon_sym_STAR_STAR] = ACTIONS(1698),
    [anon_sym_LT] = ACTIONS(1692),
    [anon_sym_LT_EQ] = ACTIONS(1698),
    [anon_sym_EQ_EQ] = ACTIONS(1694),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(1698),
    [anon_sym_BANG_EQ] = ACTIONS(1694),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(1698),
    [anon_sym_GT_EQ] = ACTIONS(1698),
    [anon_sym_GT] = ACTIONS(1694),
    [anon_sym_QMARK_QMARK] = ACTIONS(1698),
    [anon_sym_instanceof] = ACTIONS(1694),
    [anon_sym_TILDE] = ACTIONS(1690),
    [anon_sym_void] = ACTIONS(1692),
    [anon_sym_delete] = ACTIONS(1692),
    [anon_sym_PLUS_PLUS] = ACTIONS(1690),
    [anon_sym_DASH_DASH] = ACTIONS(1690),
    [anon_sym_DQUOTE] = ACTIONS(1690),
    [anon_sym_SQUOTE] = ACTIONS(1690),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1690),
    [sym_number] = ACTIONS(1690),
    [sym_private_property_identifier] = ACTIONS(1690),
    [sym_this] = ACTIONS(1692),
    [sym_super] = ACTIONS(1692),
    [sym_true] = ACTIONS(1692),
    [sym_false] = ACTIONS(1692),
    [sym_null] = ACTIONS(1692),
    [sym_undefined] = ACTIONS(1692),
    [anon_sym_AT] = ACTIONS(1690),
    [anon_sym_static] = ACTIONS(1692),
    [anon_sym_readonly] = ACTIONS(1692),
    [anon_sym_get] = ACTIONS(1692),
    [anon_sym_set] = ACTIONS(1692),
    [anon_sym_declare] = ACTIONS(1692),
    [anon_sym_public] = ACTIONS(1692),
    [anon_sym_private] = ACTIONS(1692),
    [anon_sym_protected] = ACTIONS(1692),
    [anon_sym_override] = ACTIONS(1692),
    [anon_sym_module] = ACTIONS(1692),
    [anon_sym_any] = ACTIONS(1692),
    [anon_sym_number] = ACTIONS(1692),
    [anon_sym_boolean] = ACTIONS(1692),
    [anon_sym_string] = ACTIONS(1692),
    [anon_sym_symbol] = ACTIONS(1692),
    [anon_sym_object] = ACTIONS(1692),
    [anon_sym_abstract] = ACTIONS(1692),
    [anon_sym_satisfies] = ACTIONS(1694),
    [anon_sym_interface] = ACTIONS(1692),
    [anon_sym_enum] = ACTIONS(1692),
    [sym__automatic_semicolon] = ACTIONS(1700),
    [sym__ternary_qmark] = ACTIONS(1698),
    [sym_html_comment] = ACTIONS(5),
  },
  [207] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1213),
    [sym_expression] = STATE(2644),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(3722),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(3722),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5800),
    [sym__formal_parameter] = STATE(5169),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1295),
    [sym_subscript_expression] = STATE(1295),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3013),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(3722),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_pattern] = STATE(4339),
    [sym_rest_pattern] = STATE(3684),
    [sym_non_null_expression] = STATE(1295),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_accessibility_modifier] = STATE(288),
    [sym_override_modifier] = STATE(303),
    [sym_required_parameter] = STATE(5169),
    [sym_optional_parameter] = STATE(5169),
    [sym__parameter_name] = STATE(3624),
    [sym_type_arguments] = STATE(539),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(267),
    [sym_identifier] = ACTIONS(696),
    [anon_sym_export] = ACTIONS(113),
    [anon_sym_type] = ACTIONS(113),
    [anon_sym_namespace] = ACTIONS(122),
    [anon_sym_LBRACE] = ACTIONS(698),
    [anon_sym_typeof] = ACTIONS(179),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(113),
    [anon_sym_BANG] = ACTIONS(175),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_RPAREN] = ACTIONS(1702),
    [anon_sym_await] = ACTIONS(140),
    [anon_sym_yield] = ACTIONS(142),
    [anon_sym_LBRACK] = ACTIONS(1664),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(148),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(706),
    [anon_sym_using] = ACTIONS(158),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(162),
    [anon_sym_PLUS] = ACTIONS(179),
    [anon_sym_DASH] = ACTIONS(179),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(175),
    [anon_sym_void] = ACTIONS(179),
    [anon_sym_delete] = ACTIONS(179),
    [anon_sym_PLUS_PLUS] = ACTIONS(686),
    [anon_sym_DASH_DASH] = ACTIONS(686),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(192),
    [sym_this] = ACTIONS(1666),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(718),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(113),
    [anon_sym_readonly] = ACTIONS(1668),
    [anon_sym_get] = ACTIONS(113),
    [anon_sym_set] = ACTIONS(113),
    [anon_sym_declare] = ACTIONS(113),
    [anon_sym_public] = ACTIONS(798),
    [anon_sym_private] = ACTIONS(798),
    [anon_sym_protected] = ACTIONS(798),
    [anon_sym_override] = ACTIONS(800),
    [anon_sym_module] = ACTIONS(113),
    [anon_sym_any] = ACTIONS(113),
    [anon_sym_number] = ACTIONS(113),
    [anon_sym_boolean] = ACTIONS(113),
    [anon_sym_string] = ACTIONS(113),
    [anon_sym_symbol] = ACTIONS(113),
    [anon_sym_object] = ACTIONS(113),
    [sym_html_comment] = ACTIONS(5),
  },
  [208] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1213),
    [sym_expression] = STATE(2644),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(3722),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(3722),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5800),
    [sym__formal_parameter] = STATE(5169),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1295),
    [sym_subscript_expression] = STATE(1295),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3013),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(3722),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_pattern] = STATE(4339),
    [sym_rest_pattern] = STATE(3684),
    [sym_non_null_expression] = STATE(1295),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_accessibility_modifier] = STATE(288),
    [sym_override_modifier] = STATE(303),
    [sym_required_parameter] = STATE(5169),
    [sym_optional_parameter] = STATE(5169),
    [sym__parameter_name] = STATE(3624),
    [sym_type_arguments] = STATE(539),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(267),
    [sym_identifier] = ACTIONS(696),
    [anon_sym_export] = ACTIONS(113),
    [anon_sym_type] = ACTIONS(113),
    [anon_sym_namespace] = ACTIONS(122),
    [anon_sym_LBRACE] = ACTIONS(698),
    [anon_sym_typeof] = ACTIONS(179),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(113),
    [anon_sym_BANG] = ACTIONS(175),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_RPAREN] = ACTIONS(1704),
    [anon_sym_await] = ACTIONS(140),
    [anon_sym_yield] = ACTIONS(142),
    [anon_sym_LBRACK] = ACTIONS(1664),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(148),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(706),
    [anon_sym_using] = ACTIONS(158),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(162),
    [anon_sym_PLUS] = ACTIONS(179),
    [anon_sym_DASH] = ACTIONS(179),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(175),
    [anon_sym_void] = ACTIONS(179),
    [anon_sym_delete] = ACTIONS(179),
    [anon_sym_PLUS_PLUS] = ACTIONS(686),
    [anon_sym_DASH_DASH] = ACTIONS(686),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(192),
    [sym_this] = ACTIONS(1666),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(718),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(113),
    [anon_sym_readonly] = ACTIONS(1668),
    [anon_sym_get] = ACTIONS(113),
    [anon_sym_set] = ACTIONS(113),
    [anon_sym_declare] = ACTIONS(113),
    [anon_sym_public] = ACTIONS(798),
    [anon_sym_private] = ACTIONS(798),
    [anon_sym_protected] = ACTIONS(798),
    [anon_sym_override] = ACTIONS(800),
    [anon_sym_module] = ACTIONS(113),
    [anon_sym_any] = ACTIONS(113),
    [anon_sym_number] = ACTIONS(113),
    [anon_sym_boolean] = ACTIONS(113),
    [anon_sym_string] = ACTIONS(113),
    [anon_sym_symbol] = ACTIONS(113),
    [anon_sym_object] = ACTIONS(113),
    [sym_html_comment] = ACTIONS(5),
  },
  [209] = {
    [ts_builtin_sym_end] = ACTIONS(1706),
    [sym_identifier] = ACTIONS(1708),
    [anon_sym_export] = ACTIONS(1708),
    [anon_sym_STAR] = ACTIONS(1710),
    [anon_sym_default] = ACTIONS(1708),
    [anon_sym_type] = ACTIONS(1708),
    [anon_sym_as] = ACTIONS(1710),
    [anon_sym_namespace] = ACTIONS(1708),
    [anon_sym_LBRACE] = ACTIONS(1706),
    [anon_sym_COMMA] = ACTIONS(1712),
    [anon_sym_RBRACE] = ACTIONS(1706),
    [anon_sym_typeof] = ACTIONS(1708),
    [anon_sym_import] = ACTIONS(1708),
    [anon_sym_with] = ACTIONS(1708),
    [anon_sym_var] = ACTIONS(1708),
    [anon_sym_let] = ACTIONS(1708),
    [anon_sym_const] = ACTIONS(1708),
    [anon_sym_BANG] = ACTIONS(1708),
    [anon_sym_else] = ACTIONS(1708),
    [anon_sym_if] = ACTIONS(1708),
    [anon_sym_switch] = ACTIONS(1708),
    [anon_sym_for] = ACTIONS(1708),
    [anon_sym_LPAREN] = ACTIONS(1706),
    [anon_sym_SEMI] = ACTIONS(1706),
    [anon_sym_await] = ACTIONS(1708),
    [anon_sym_in] = ACTIONS(1710),
    [anon_sym_while] = ACTIONS(1708),
    [anon_sym_do] = ACTIONS(1708),
    [anon_sym_try] = ACTIONS(1708),
    [anon_sym_break] = ACTIONS(1708),
    [anon_sym_continue] = ACTIONS(1708),
    [anon_sym_debugger] = ACTIONS(1708),
    [anon_sym_return] = ACTIONS(1708),
    [anon_sym_throw] = ACTIONS(1708),
    [anon_sym_case] = ACTIONS(1708),
    [anon_sym_yield] = ACTIONS(1708),
    [anon_sym_LBRACK] = ACTIONS(1706),
    [anon_sym_DOT] = ACTIONS(1710),
    [anon_sym_class] = ACTIONS(1708),
    [anon_sym_async] = ACTIONS(1708),
    [anon_sym_function] = ACTIONS(1708),
    [anon_sym_QMARK_DOT] = ACTIONS(1712),
    [anon_sym_new] = ACTIONS(1708),
    [anon_sym_using] = ACTIONS(1708),
    [anon_sym_AMP_AMP] = ACTIONS(1712),
    [anon_sym_PIPE_PIPE] = ACTIONS(1712),
    [anon_sym_GT_GT] = ACTIONS(1710),
    [anon_sym_GT_GT_GT] = ACTIONS(1712),
    [anon_sym_LT_LT] = ACTIONS(1712),
    [anon_sym_AMP] = ACTIONS(1710),
    [anon_sym_CARET] = ACTIONS(1712),
    [anon_sym_PIPE] = ACTIONS(1710),
    [anon_sym_PLUS] = ACTIONS(1708),
    [anon_sym_DASH] = ACTIONS(1708),
    [anon_sym_SLASH] = ACTIONS(1708),
    [anon_sym_PERCENT] = ACTIONS(1712),
    [anon_sym_STAR_STAR] = ACTIONS(1712),
    [anon_sym_LT] = ACTIONS(1708),
    [anon_sym_LT_EQ] = ACTIONS(1712),
    [anon_sym_EQ_EQ] = ACTIONS(1710),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(1712),
    [anon_sym_BANG_EQ] = ACTIONS(1710),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(1712),
    [anon_sym_GT_EQ] = ACTIONS(1712),
    [anon_sym_GT] = ACTIONS(1710),
    [anon_sym_QMARK_QMARK] = ACTIONS(1712),
    [anon_sym_instanceof] = ACTIONS(1710),
    [anon_sym_TILDE] = ACTIONS(1706),
    [anon_sym_void] = ACTIONS(1708),
    [anon_sym_delete] = ACTIONS(1708),
    [anon_sym_PLUS_PLUS] = ACTIONS(1706),
    [anon_sym_DASH_DASH] = ACTIONS(1706),
    [anon_sym_DQUOTE] = ACTIONS(1706),
    [anon_sym_SQUOTE] = ACTIONS(1706),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1706),
    [sym_number] = ACTIONS(1706),
    [sym_private_property_identifier] = ACTIONS(1706),
    [sym_this] = ACTIONS(1708),
    [sym_super] = ACTIONS(1708),
    [sym_true] = ACTIONS(1708),
    [sym_false] = ACTIONS(1708),
    [sym_null] = ACTIONS(1708),
    [sym_undefined] = ACTIONS(1708),
    [anon_sym_AT] = ACTIONS(1706),
    [anon_sym_static] = ACTIONS(1708),
    [anon_sym_readonly] = ACTIONS(1708),
    [anon_sym_get] = ACTIONS(1708),
    [anon_sym_set] = ACTIONS(1708),
    [anon_sym_declare] = ACTIONS(1708),
    [anon_sym_public] = ACTIONS(1708),
    [anon_sym_private] = ACTIONS(1708),
    [anon_sym_protected] = ACTIONS(1708),
    [anon_sym_override] = ACTIONS(1708),
    [anon_sym_module] = ACTIONS(1708),
    [anon_sym_any] = ACTIONS(1708),
    [anon_sym_number] = ACTIONS(1708),
    [anon_sym_boolean] = ACTIONS(1708),
    [anon_sym_string] = ACTIONS(1708),
    [anon_sym_symbol] = ACTIONS(1708),
    [anon_sym_object] = ACTIONS(1708),
    [anon_sym_abstract] = ACTIONS(1708),
    [anon_sym_satisfies] = ACTIONS(1710),
    [anon_sym_interface] = ACTIONS(1708),
    [anon_sym_enum] = ACTIONS(1708),
    [sym__automatic_semicolon] = ACTIONS(1714),
    [sym__ternary_qmark] = ACTIONS(1712),
    [sym_html_comment] = ACTIONS(5),
  },
  [210] = {
    [ts_builtin_sym_end] = ACTIONS(1716),
    [sym_identifier] = ACTIONS(1718),
    [anon_sym_export] = ACTIONS(1718),
    [anon_sym_STAR] = ACTIONS(1718),
    [anon_sym_default] = ACTIONS(1718),
    [anon_sym_type] = ACTIONS(1718),
    [anon_sym_as] = ACTIONS(1718),
    [anon_sym_namespace] = ACTIONS(1718),
    [anon_sym_LBRACE] = ACTIONS(1716),
    [anon_sym_COMMA] = ACTIONS(1716),
    [anon_sym_RBRACE] = ACTIONS(1716),
    [anon_sym_typeof] = ACTIONS(1718),
    [anon_sym_import] = ACTIONS(1718),
    [anon_sym_with] = ACTIONS(1718),
    [anon_sym_var] = ACTIONS(1718),
    [anon_sym_let] = ACTIONS(1718),
    [anon_sym_const] = ACTIONS(1718),
    [anon_sym_BANG] = ACTIONS(1718),
    [anon_sym_else] = ACTIONS(1718),
    [anon_sym_if] = ACTIONS(1718),
    [anon_sym_switch] = ACTIONS(1718),
    [anon_sym_for] = ACTIONS(1718),
    [anon_sym_LPAREN] = ACTIONS(1716),
    [anon_sym_SEMI] = ACTIONS(1716),
    [anon_sym_await] = ACTIONS(1718),
    [anon_sym_in] = ACTIONS(1718),
    [anon_sym_while] = ACTIONS(1718),
    [anon_sym_do] = ACTIONS(1718),
    [anon_sym_try] = ACTIONS(1718),
    [anon_sym_break] = ACTIONS(1718),
    [anon_sym_continue] = ACTIONS(1718),
    [anon_sym_debugger] = ACTIONS(1718),
    [anon_sym_return] = ACTIONS(1718),
    [anon_sym_throw] = ACTIONS(1718),
    [anon_sym_case] = ACTIONS(1718),
    [anon_sym_yield] = ACTIONS(1718),
    [anon_sym_LBRACK] = ACTIONS(1716),
    [anon_sym_DOT] = ACTIONS(1718),
    [anon_sym_class] = ACTIONS(1718),
    [anon_sym_async] = ACTIONS(1718),
    [anon_sym_function] = ACTIONS(1718),
    [anon_sym_QMARK_DOT] = ACTIONS(1716),
    [anon_sym_new] = ACTIONS(1718),
    [anon_sym_using] = ACTIONS(1718),
    [anon_sym_AMP_AMP] = ACTIONS(1716),
    [anon_sym_PIPE_PIPE] = ACTIONS(1716),
    [anon_sym_GT_GT] = ACTIONS(1718),
    [anon_sym_GT_GT_GT] = ACTIONS(1716),
    [anon_sym_LT_LT] = ACTIONS(1716),
    [anon_sym_AMP] = ACTIONS(1718),
    [anon_sym_CARET] = ACTIONS(1716),
    [anon_sym_PIPE] = ACTIONS(1718),
    [anon_sym_PLUS] = ACTIONS(1718),
    [anon_sym_DASH] = ACTIONS(1718),
    [anon_sym_SLASH] = ACTIONS(1718),
    [anon_sym_PERCENT] = ACTIONS(1716),
    [anon_sym_STAR_STAR] = ACTIONS(1716),
    [anon_sym_LT] = ACTIONS(1718),
    [anon_sym_LT_EQ] = ACTIONS(1716),
    [anon_sym_EQ_EQ] = ACTIONS(1718),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(1716),
    [anon_sym_BANG_EQ] = ACTIONS(1718),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(1716),
    [anon_sym_GT_EQ] = ACTIONS(1716),
    [anon_sym_GT] = ACTIONS(1718),
    [anon_sym_QMARK_QMARK] = ACTIONS(1716),
    [anon_sym_instanceof] = ACTIONS(1718),
    [anon_sym_TILDE] = ACTIONS(1716),
    [anon_sym_void] = ACTIONS(1718),
    [anon_sym_delete] = ACTIONS(1718),
    [anon_sym_PLUS_PLUS] = ACTIONS(1716),
    [anon_sym_DASH_DASH] = ACTIONS(1716),
    [anon_sym_DQUOTE] = ACTIONS(1716),
    [anon_sym_SQUOTE] = ACTIONS(1716),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1716),
    [sym_number] = ACTIONS(1716),
    [sym_private_property_identifier] = ACTIONS(1716),
    [sym_this] = ACTIONS(1718),
    [sym_super] = ACTIONS(1718),
    [sym_true] = ACTIONS(1718),
    [sym_false] = ACTIONS(1718),
    [sym_null] = ACTIONS(1718),
    [sym_undefined] = ACTIONS(1718),
    [anon_sym_AT] = ACTIONS(1716),
    [anon_sym_static] = ACTIONS(1718),
    [anon_sym_readonly] = ACTIONS(1718),
    [anon_sym_get] = ACTIONS(1718),
    [anon_sym_set] = ACTIONS(1718),
    [anon_sym_declare] = ACTIONS(1718),
    [anon_sym_public] = ACTIONS(1718),
    [anon_sym_private] = ACTIONS(1718),
    [anon_sym_protected] = ACTIONS(1718),
    [anon_sym_override] = ACTIONS(1718),
    [anon_sym_module] = ACTIONS(1718),
    [anon_sym_any] = ACTIONS(1718),
    [anon_sym_number] = ACTIONS(1718),
    [anon_sym_boolean] = ACTIONS(1718),
    [anon_sym_string] = ACTIONS(1718),
    [anon_sym_symbol] = ACTIONS(1718),
    [anon_sym_object] = ACTIONS(1718),
    [anon_sym_abstract] = ACTIONS(1718),
    [anon_sym_satisfies] = ACTIONS(1718),
    [anon_sym_interface] = ACTIONS(1718),
    [anon_sym_enum] = ACTIONS(1718),
    [sym__automatic_semicolon] = ACTIONS(1716),
    [sym__ternary_qmark] = ACTIONS(1716),
    [sym_html_comment] = ACTIONS(5),
  },
  [211] = {
    [ts_builtin_sym_end] = ACTIONS(1720),
    [sym_identifier] = ACTIONS(1722),
    [anon_sym_export] = ACTIONS(1722),
    [anon_sym_STAR] = ACTIONS(1722),
    [anon_sym_default] = ACTIONS(1722),
    [anon_sym_type] = ACTIONS(1722),
    [anon_sym_as] = ACTIONS(1722),
    [anon_sym_namespace] = ACTIONS(1722),
    [anon_sym_LBRACE] = ACTIONS(1720),
    [anon_sym_COMMA] = ACTIONS(1720),
    [anon_sym_RBRACE] = ACTIONS(1720),
    [anon_sym_typeof] = ACTIONS(1722),
    [anon_sym_import] = ACTIONS(1722),
    [anon_sym_with] = ACTIONS(1722),
    [anon_sym_var] = ACTIONS(1722),
    [anon_sym_let] = ACTIONS(1722),
    [anon_sym_const] = ACTIONS(1722),
    [anon_sym_BANG] = ACTIONS(1722),
    [anon_sym_else] = ACTIONS(1722),
    [anon_sym_if] = ACTIONS(1722),
    [anon_sym_switch] = ACTIONS(1722),
    [anon_sym_for] = ACTIONS(1722),
    [anon_sym_LPAREN] = ACTIONS(1720),
    [anon_sym_SEMI] = ACTIONS(1720),
    [anon_sym_await] = ACTIONS(1722),
    [anon_sym_in] = ACTIONS(1722),
    [anon_sym_while] = ACTIONS(1722),
    [anon_sym_do] = ACTIONS(1722),
    [anon_sym_try] = ACTIONS(1722),
    [anon_sym_break] = ACTIONS(1722),
    [anon_sym_continue] = ACTIONS(1722),
    [anon_sym_debugger] = ACTIONS(1722),
    [anon_sym_return] = ACTIONS(1722),
    [anon_sym_throw] = ACTIONS(1722),
    [anon_sym_case] = ACTIONS(1722),
    [anon_sym_yield] = ACTIONS(1722),
    [anon_sym_LBRACK] = ACTIONS(1720),
    [anon_sym_DOT] = ACTIONS(1722),
    [anon_sym_class] = ACTIONS(1722),
    [anon_sym_async] = ACTIONS(1722),
    [anon_sym_function] = ACTIONS(1722),
    [anon_sym_QMARK_DOT] = ACTIONS(1720),
    [anon_sym_new] = ACTIONS(1722),
    [anon_sym_using] = ACTIONS(1722),
    [anon_sym_AMP_AMP] = ACTIONS(1720),
    [anon_sym_PIPE_PIPE] = ACTIONS(1720),
    [anon_sym_GT_GT] = ACTIONS(1722),
    [anon_sym_GT_GT_GT] = ACTIONS(1720),
    [anon_sym_LT_LT] = ACTIONS(1720),
    [anon_sym_AMP] = ACTIONS(1722),
    [anon_sym_CARET] = ACTIONS(1720),
    [anon_sym_PIPE] = ACTIONS(1722),
    [anon_sym_PLUS] = ACTIONS(1722),
    [anon_sym_DASH] = ACTIONS(1722),
    [anon_sym_SLASH] = ACTIONS(1722),
    [anon_sym_PERCENT] = ACTIONS(1720),
    [anon_sym_STAR_STAR] = ACTIONS(1720),
    [anon_sym_LT] = ACTIONS(1722),
    [anon_sym_LT_EQ] = ACTIONS(1720),
    [anon_sym_EQ_EQ] = ACTIONS(1722),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(1720),
    [anon_sym_BANG_EQ] = ACTIONS(1722),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(1720),
    [anon_sym_GT_EQ] = ACTIONS(1720),
    [anon_sym_GT] = ACTIONS(1722),
    [anon_sym_QMARK_QMARK] = ACTIONS(1720),
    [anon_sym_instanceof] = ACTIONS(1722),
    [anon_sym_TILDE] = ACTIONS(1720),
    [anon_sym_void] = ACTIONS(1722),
    [anon_sym_delete] = ACTIONS(1722),
    [anon_sym_PLUS_PLUS] = ACTIONS(1720),
    [anon_sym_DASH_DASH] = ACTIONS(1720),
    [anon_sym_DQUOTE] = ACTIONS(1720),
    [anon_sym_SQUOTE] = ACTIONS(1720),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1720),
    [sym_number] = ACTIONS(1720),
    [sym_private_property_identifier] = ACTIONS(1720),
    [sym_this] = ACTIONS(1722),
    [sym_super] = ACTIONS(1722),
    [sym_true] = ACTIONS(1722),
    [sym_false] = ACTIONS(1722),
    [sym_null] = ACTIONS(1722),
    [sym_undefined] = ACTIONS(1722),
    [anon_sym_AT] = ACTIONS(1720),
    [anon_sym_static] = ACTIONS(1722),
    [anon_sym_readonly] = ACTIONS(1722),
    [anon_sym_get] = ACTIONS(1722),
    [anon_sym_set] = ACTIONS(1722),
    [anon_sym_declare] = ACTIONS(1722),
    [anon_sym_public] = ACTIONS(1722),
    [anon_sym_private] = ACTIONS(1722),
    [anon_sym_protected] = ACTIONS(1722),
    [anon_sym_override] = ACTIONS(1722),
    [anon_sym_module] = ACTIONS(1722),
    [anon_sym_any] = ACTIONS(1722),
    [anon_sym_number] = ACTIONS(1722),
    [anon_sym_boolean] = ACTIONS(1722),
    [anon_sym_string] = ACTIONS(1722),
    [anon_sym_symbol] = ACTIONS(1722),
    [anon_sym_object] = ACTIONS(1722),
    [anon_sym_abstract] = ACTIONS(1722),
    [anon_sym_satisfies] = ACTIONS(1722),
    [anon_sym_interface] = ACTIONS(1722),
    [anon_sym_enum] = ACTIONS(1722),
    [sym__automatic_semicolon] = ACTIONS(1720),
    [sym__ternary_qmark] = ACTIONS(1720),
    [sym_html_comment] = ACTIONS(5),
  },
  [212] = {
    [ts_builtin_sym_end] = ACTIONS(1690),
    [sym_identifier] = ACTIONS(1692),
    [anon_sym_export] = ACTIONS(1692),
    [anon_sym_STAR] = ACTIONS(1692),
    [anon_sym_default] = ACTIONS(1692),
    [anon_sym_type] = ACTIONS(1692),
    [anon_sym_as] = ACTIONS(1692),
    [anon_sym_namespace] = ACTIONS(1692),
    [anon_sym_LBRACE] = ACTIONS(1690),
    [anon_sym_COMMA] = ACTIONS(1690),
    [anon_sym_RBRACE] = ACTIONS(1690),
    [anon_sym_typeof] = ACTIONS(1692),
    [anon_sym_import] = ACTIONS(1692),
    [anon_sym_with] = ACTIONS(1692),
    [anon_sym_var] = ACTIONS(1692),
    [anon_sym_let] = ACTIONS(1692),
    [anon_sym_const] = ACTIONS(1692),
    [anon_sym_BANG] = ACTIONS(1692),
    [anon_sym_else] = ACTIONS(1692),
    [anon_sym_if] = ACTIONS(1692),
    [anon_sym_switch] = ACTIONS(1692),
    [anon_sym_for] = ACTIONS(1692),
    [anon_sym_LPAREN] = ACTIONS(1690),
    [anon_sym_SEMI] = ACTIONS(1690),
    [anon_sym_await] = ACTIONS(1692),
    [anon_sym_in] = ACTIONS(1692),
    [anon_sym_while] = ACTIONS(1692),
    [anon_sym_do] = ACTIONS(1692),
    [anon_sym_try] = ACTIONS(1692),
    [anon_sym_break] = ACTIONS(1692),
    [anon_sym_continue] = ACTIONS(1692),
    [anon_sym_debugger] = ACTIONS(1692),
    [anon_sym_return] = ACTIONS(1692),
    [anon_sym_throw] = ACTIONS(1692),
    [anon_sym_case] = ACTIONS(1692),
    [anon_sym_yield] = ACTIONS(1692),
    [anon_sym_LBRACK] = ACTIONS(1690),
    [anon_sym_DOT] = ACTIONS(1692),
    [anon_sym_class] = ACTIONS(1692),
    [anon_sym_async] = ACTIONS(1692),
    [anon_sym_function] = ACTIONS(1692),
    [anon_sym_QMARK_DOT] = ACTIONS(1690),
    [anon_sym_new] = ACTIONS(1692),
    [anon_sym_using] = ACTIONS(1692),
    [anon_sym_AMP_AMP] = ACTIONS(1690),
    [anon_sym_PIPE_PIPE] = ACTIONS(1690),
    [anon_sym_GT_GT] = ACTIONS(1692),
    [anon_sym_GT_GT_GT] = ACTIONS(1690),
    [anon_sym_LT_LT] = ACTIONS(1690),
    [anon_sym_AMP] = ACTIONS(1692),
    [anon_sym_CARET] = ACTIONS(1690),
    [anon_sym_PIPE] = ACTIONS(1692),
    [anon_sym_PLUS] = ACTIONS(1692),
    [anon_sym_DASH] = ACTIONS(1692),
    [anon_sym_SLASH] = ACTIONS(1692),
    [anon_sym_PERCENT] = ACTIONS(1690),
    [anon_sym_STAR_STAR] = ACTIONS(1690),
    [anon_sym_LT] = ACTIONS(1692),
    [anon_sym_LT_EQ] = ACTIONS(1690),
    [anon_sym_EQ_EQ] = ACTIONS(1692),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(1690),
    [anon_sym_BANG_EQ] = ACTIONS(1692),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(1690),
    [anon_sym_GT_EQ] = ACTIONS(1690),
    [anon_sym_GT] = ACTIONS(1692),
    [anon_sym_QMARK_QMARK] = ACTIONS(1690),
    [anon_sym_instanceof] = ACTIONS(1692),
    [anon_sym_TILDE] = ACTIONS(1690),
    [anon_sym_void] = ACTIONS(1692),
    [anon_sym_delete] = ACTIONS(1692),
    [anon_sym_PLUS_PLUS] = ACTIONS(1690),
    [anon_sym_DASH_DASH] = ACTIONS(1690),
    [anon_sym_DQUOTE] = ACTIONS(1690),
    [anon_sym_SQUOTE] = ACTIONS(1690),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1690),
    [sym_number] = ACTIONS(1690),
    [sym_private_property_identifier] = ACTIONS(1690),
    [sym_this] = ACTIONS(1692),
    [sym_super] = ACTIONS(1692),
    [sym_true] = ACTIONS(1692),
    [sym_false] = ACTIONS(1692),
    [sym_null] = ACTIONS(1692),
    [sym_undefined] = ACTIONS(1692),
    [anon_sym_AT] = ACTIONS(1690),
    [anon_sym_static] = ACTIONS(1692),
    [anon_sym_readonly] = ACTIONS(1692),
    [anon_sym_get] = ACTIONS(1692),
    [anon_sym_set] = ACTIONS(1692),
    [anon_sym_declare] = ACTIONS(1692),
    [anon_sym_public] = ACTIONS(1692),
    [anon_sym_private] = ACTIONS(1692),
    [anon_sym_protected] = ACTIONS(1692),
    [anon_sym_override] = ACTIONS(1692),
    [anon_sym_module] = ACTIONS(1692),
    [anon_sym_any] = ACTIONS(1692),
    [anon_sym_number] = ACTIONS(1692),
    [anon_sym_boolean] = ACTIONS(1692),
    [anon_sym_string] = ACTIONS(1692),
    [anon_sym_symbol] = ACTIONS(1692),
    [anon_sym_object] = ACTIONS(1692),
    [anon_sym_abstract] = ACTIONS(1692),
    [anon_sym_satisfies] = ACTIONS(1692),
    [anon_sym_interface] = ACTIONS(1692),
    [anon_sym_enum] = ACTIONS(1692),
    [sym__automatic_semicolon] = ACTIONS(1724),
    [sym__ternary_qmark] = ACTIONS(1690),
    [sym_html_comment] = ACTIONS(5),
  },
  [213] = {
    [ts_builtin_sym_end] = ACTIONS(1726),
    [sym_identifier] = ACTIONS(1728),
    [anon_sym_export] = ACTIONS(1728),
    [anon_sym_STAR] = ACTIONS(1728),
    [anon_sym_default] = ACTIONS(1728),
    [anon_sym_type] = ACTIONS(1728),
    [anon_sym_as] = ACTIONS(1728),
    [anon_sym_namespace] = ACTIONS(1728),
    [anon_sym_LBRACE] = ACTIONS(1726),
    [anon_sym_COMMA] = ACTIONS(1726),
    [anon_sym_RBRACE] = ACTIONS(1726),
    [anon_sym_typeof] = ACTIONS(1728),
    [anon_sym_import] = ACTIONS(1728),
    [anon_sym_with] = ACTIONS(1728),
    [anon_sym_var] = ACTIONS(1728),
    [anon_sym_let] = ACTIONS(1728),
    [anon_sym_const] = ACTIONS(1728),
    [anon_sym_BANG] = ACTIONS(1728),
    [anon_sym_else] = ACTIONS(1728),
    [anon_sym_if] = ACTIONS(1728),
    [anon_sym_switch] = ACTIONS(1728),
    [anon_sym_for] = ACTIONS(1728),
    [anon_sym_LPAREN] = ACTIONS(1726),
    [anon_sym_SEMI] = ACTIONS(1726),
    [anon_sym_await] = ACTIONS(1728),
    [anon_sym_in] = ACTIONS(1728),
    [anon_sym_while] = ACTIONS(1728),
    [anon_sym_do] = ACTIONS(1728),
    [anon_sym_try] = ACTIONS(1728),
    [anon_sym_break] = ACTIONS(1728),
    [anon_sym_continue] = ACTIONS(1728),
    [anon_sym_debugger] = ACTIONS(1728),
    [anon_sym_return] = ACTIONS(1728),
    [anon_sym_throw] = ACTIONS(1728),
    [anon_sym_case] = ACTIONS(1728),
    [anon_sym_yield] = ACTIONS(1728),
    [anon_sym_LBRACK] = ACTIONS(1726),
    [anon_sym_DOT] = ACTIONS(1728),
    [anon_sym_class] = ACTIONS(1728),
    [anon_sym_async] = ACTIONS(1728),
    [anon_sym_function] = ACTIONS(1728),
    [anon_sym_QMARK_DOT] = ACTIONS(1726),
    [anon_sym_new] = ACTIONS(1728),
    [anon_sym_using] = ACTIONS(1728),
    [anon_sym_AMP_AMP] = ACTIONS(1726),
    [anon_sym_PIPE_PIPE] = ACTIONS(1726),
    [anon_sym_GT_GT] = ACTIONS(1728),
    [anon_sym_GT_GT_GT] = ACTIONS(1726),
    [anon_sym_LT_LT] = ACTIONS(1726),
    [anon_sym_AMP] = ACTIONS(1728),
    [anon_sym_CARET] = ACTIONS(1726),
    [anon_sym_PIPE] = ACTIONS(1728),
    [anon_sym_PLUS] = ACTIONS(1728),
    [anon_sym_DASH] = ACTIONS(1728),
    [anon_sym_SLASH] = ACTIONS(1728),
    [anon_sym_PERCENT] = ACTIONS(1726),
    [anon_sym_STAR_STAR] = ACTIONS(1726),
    [anon_sym_LT] = ACTIONS(1728),
    [anon_sym_LT_EQ] = ACTIONS(1726),
    [anon_sym_EQ_EQ] = ACTIONS(1728),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(1726),
    [anon_sym_BANG_EQ] = ACTIONS(1728),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(1726),
    [anon_sym_GT_EQ] = ACTIONS(1726),
    [anon_sym_GT] = ACTIONS(1728),
    [anon_sym_QMARK_QMARK] = ACTIONS(1726),
    [anon_sym_instanceof] = ACTIONS(1728),
    [anon_sym_TILDE] = ACTIONS(1726),
    [anon_sym_void] = ACTIONS(1728),
    [anon_sym_delete] = ACTIONS(1728),
    [anon_sym_PLUS_PLUS] = ACTIONS(1726),
    [anon_sym_DASH_DASH] = ACTIONS(1726),
    [anon_sym_DQUOTE] = ACTIONS(1726),
    [anon_sym_SQUOTE] = ACTIONS(1726),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1726),
    [sym_number] = ACTIONS(1726),
    [sym_private_property_identifier] = ACTIONS(1726),
    [sym_this] = ACTIONS(1728),
    [sym_super] = ACTIONS(1728),
    [sym_true] = ACTIONS(1728),
    [sym_false] = ACTIONS(1728),
    [sym_null] = ACTIONS(1728),
    [sym_undefined] = ACTIONS(1728),
    [anon_sym_AT] = ACTIONS(1726),
    [anon_sym_static] = ACTIONS(1728),
    [anon_sym_readonly] = ACTIONS(1728),
    [anon_sym_get] = ACTIONS(1728),
    [anon_sym_set] = ACTIONS(1728),
    [anon_sym_declare] = ACTIONS(1728),
    [anon_sym_public] = ACTIONS(1728),
    [anon_sym_private] = ACTIONS(1728),
    [anon_sym_protected] = ACTIONS(1728),
    [anon_sym_override] = ACTIONS(1728),
    [anon_sym_module] = ACTIONS(1728),
    [anon_sym_any] = ACTIONS(1728),
    [anon_sym_number] = ACTIONS(1728),
    [anon_sym_boolean] = ACTIONS(1728),
    [anon_sym_string] = ACTIONS(1728),
    [anon_sym_symbol] = ACTIONS(1728),
    [anon_sym_object] = ACTIONS(1728),
    [anon_sym_abstract] = ACTIONS(1728),
    [anon_sym_satisfies] = ACTIONS(1728),
    [anon_sym_interface] = ACTIONS(1728),
    [anon_sym_enum] = ACTIONS(1728),
    [sym__automatic_semicolon] = ACTIONS(1726),
    [sym__ternary_qmark] = ACTIONS(1726),
    [sym_html_comment] = ACTIONS(5),
  },
  [214] = {
    [ts_builtin_sym_end] = ACTIONS(1730),
    [sym_identifier] = ACTIONS(1732),
    [anon_sym_export] = ACTIONS(1732),
    [anon_sym_STAR] = ACTIONS(1734),
    [anon_sym_default] = ACTIONS(1732),
    [anon_sym_type] = ACTIONS(1732),
    [anon_sym_as] = ACTIONS(1734),
    [anon_sym_namespace] = ACTIONS(1732),
    [anon_sym_LBRACE] = ACTIONS(1730),
    [anon_sym_COMMA] = ACTIONS(1736),
    [anon_sym_RBRACE] = ACTIONS(1730),
    [anon_sym_typeof] = ACTIONS(1732),
    [anon_sym_import] = ACTIONS(1732),
    [anon_sym_with] = ACTIONS(1732),
    [anon_sym_var] = ACTIONS(1732),
    [anon_sym_let] = ACTIONS(1732),
    [anon_sym_const] = ACTIONS(1732),
    [anon_sym_BANG] = ACTIONS(1732),
    [anon_sym_else] = ACTIONS(1732),
    [anon_sym_if] = ACTIONS(1732),
    [anon_sym_switch] = ACTIONS(1732),
    [anon_sym_for] = ACTIONS(1732),
    [anon_sym_LPAREN] = ACTIONS(1730),
    [anon_sym_SEMI] = ACTIONS(1730),
    [anon_sym_await] = ACTIONS(1732),
    [anon_sym_in] = ACTIONS(1734),
    [anon_sym_while] = ACTIONS(1732),
    [anon_sym_do] = ACTIONS(1732),
    [anon_sym_try] = ACTIONS(1732),
    [anon_sym_break] = ACTIONS(1732),
    [anon_sym_continue] = ACTIONS(1732),
    [anon_sym_debugger] = ACTIONS(1732),
    [anon_sym_return] = ACTIONS(1732),
    [anon_sym_throw] = ACTIONS(1732),
    [anon_sym_case] = ACTIONS(1732),
    [anon_sym_yield] = ACTIONS(1732),
    [anon_sym_LBRACK] = ACTIONS(1730),
    [anon_sym_DOT] = ACTIONS(1734),
    [anon_sym_class] = ACTIONS(1732),
    [anon_sym_async] = ACTIONS(1732),
    [anon_sym_function] = ACTIONS(1732),
    [anon_sym_QMARK_DOT] = ACTIONS(1736),
    [anon_sym_new] = ACTIONS(1732),
    [anon_sym_using] = ACTIONS(1732),
    [anon_sym_AMP_AMP] = ACTIONS(1736),
    [anon_sym_PIPE_PIPE] = ACTIONS(1736),
    [anon_sym_GT_GT] = ACTIONS(1734),
    [anon_sym_GT_GT_GT] = ACTIONS(1736),
    [anon_sym_LT_LT] = ACTIONS(1736),
    [anon_sym_AMP] = ACTIONS(1734),
    [anon_sym_CARET] = ACTIONS(1736),
    [anon_sym_PIPE] = ACTIONS(1734),
    [anon_sym_PLUS] = ACTIONS(1732),
    [anon_sym_DASH] = ACTIONS(1732),
    [anon_sym_SLASH] = ACTIONS(1732),
    [anon_sym_PERCENT] = ACTIONS(1736),
    [anon_sym_STAR_STAR] = ACTIONS(1736),
    [anon_sym_LT] = ACTIONS(1732),
    [anon_sym_LT_EQ] = ACTIONS(1736),
    [anon_sym_EQ_EQ] = ACTIONS(1734),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(1736),
    [anon_sym_BANG_EQ] = ACTIONS(1734),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(1736),
    [anon_sym_GT_EQ] = ACTIONS(1736),
    [anon_sym_GT] = ACTIONS(1734),
    [anon_sym_QMARK_QMARK] = ACTIONS(1736),
    [anon_sym_instanceof] = ACTIONS(1734),
    [anon_sym_TILDE] = ACTIONS(1730),
    [anon_sym_void] = ACTIONS(1732),
    [anon_sym_delete] = ACTIONS(1732),
    [anon_sym_PLUS_PLUS] = ACTIONS(1730),
    [anon_sym_DASH_DASH] = ACTIONS(1730),
    [anon_sym_DQUOTE] = ACTIONS(1730),
    [anon_sym_SQUOTE] = ACTIONS(1730),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1730),
    [sym_number] = ACTIONS(1730),
    [sym_private_property_identifier] = ACTIONS(1730),
    [sym_this] = ACTIONS(1732),
    [sym_super] = ACTIONS(1732),
    [sym_true] = ACTIONS(1732),
    [sym_false] = ACTIONS(1732),
    [sym_null] = ACTIONS(1732),
    [sym_undefined] = ACTIONS(1732),
    [anon_sym_AT] = ACTIONS(1730),
    [anon_sym_static] = ACTIONS(1732),
    [anon_sym_readonly] = ACTIONS(1732),
    [anon_sym_get] = ACTIONS(1732),
    [anon_sym_set] = ACTIONS(1732),
    [anon_sym_declare] = ACTIONS(1732),
    [anon_sym_public] = ACTIONS(1732),
    [anon_sym_private] = ACTIONS(1732),
    [anon_sym_protected] = ACTIONS(1732),
    [anon_sym_override] = ACTIONS(1732),
    [anon_sym_module] = ACTIONS(1732),
    [anon_sym_any] = ACTIONS(1732),
    [anon_sym_number] = ACTIONS(1732),
    [anon_sym_boolean] = ACTIONS(1732),
    [anon_sym_string] = ACTIONS(1732),
    [anon_sym_symbol] = ACTIONS(1732),
    [anon_sym_object] = ACTIONS(1732),
    [anon_sym_abstract] = ACTIONS(1732),
    [anon_sym_satisfies] = ACTIONS(1734),
    [anon_sym_interface] = ACTIONS(1732),
    [anon_sym_enum] = ACTIONS(1732),
    [sym__automatic_semicolon] = ACTIONS(1736),
    [sym__ternary_qmark] = ACTIONS(1736),
    [sym_html_comment] = ACTIONS(5),
  },
  [215] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1322),
    [sym_expression] = STATE(2126),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(4425),
    [sym_assignment_pattern] = STATE(4969),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(4425),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5508),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1396),
    [sym_subscript_expression] = STATE(1396),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3003),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(4425),
    [sym_spread_element] = STATE(4946),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_pattern] = STATE(4406),
    [sym_rest_pattern] = STATE(3684),
    [sym_non_null_expression] = STATE(1396),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(484),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [aux_sym_array_repeat1] = STATE(4955),
    [aux_sym_array_pattern_repeat1] = STATE(4977),
    [sym_identifier] = ACTIONS(1738),
    [anon_sym_export] = ACTIONS(541),
    [anon_sym_type] = ACTIONS(541),
    [anon_sym_namespace] = ACTIONS(545),
    [anon_sym_LBRACE] = ACTIONS(808),
    [anon_sym_COMMA] = ACTIONS(1740),
    [anon_sym_typeof] = ACTIONS(581),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(541),
    [anon_sym_BANG] = ACTIONS(553),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(555),
    [anon_sym_yield] = ACTIONS(557),
    [anon_sym_LBRACK] = ACTIONS(812),
    [anon_sym_RBRACK] = ACTIONS(1742),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(563),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1744),
    [anon_sym_using] = ACTIONS(567),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(249),
    [anon_sym_PLUS] = ACTIONS(581),
    [anon_sym_DASH] = ACTIONS(581),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(553),
    [anon_sym_void] = ACTIONS(581),
    [anon_sym_delete] = ACTIONS(581),
    [anon_sym_PLUS_PLUS] = ACTIONS(583),
    [anon_sym_DASH_DASH] = ACTIONS(583),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(585),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1746),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(541),
    [anon_sym_readonly] = ACTIONS(541),
    [anon_sym_get] = ACTIONS(541),
    [anon_sym_set] = ACTIONS(541),
    [anon_sym_declare] = ACTIONS(541),
    [anon_sym_public] = ACTIONS(541),
    [anon_sym_private] = ACTIONS(541),
    [anon_sym_protected] = ACTIONS(541),
    [anon_sym_override] = ACTIONS(541),
    [anon_sym_module] = ACTIONS(541),
    [anon_sym_any] = ACTIONS(541),
    [anon_sym_number] = ACTIONS(541),
    [anon_sym_boolean] = ACTIONS(541),
    [anon_sym_string] = ACTIONS(541),
    [anon_sym_symbol] = ACTIONS(541),
    [anon_sym_object] = ACTIONS(541),
    [sym_html_comment] = ACTIONS(5),
  },
  [216] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1322),
    [sym_expression] = STATE(2126),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(4425),
    [sym_assignment_pattern] = STATE(4969),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(4425),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5508),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1396),
    [sym_subscript_expression] = STATE(1396),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3003),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(4425),
    [sym_spread_element] = STATE(4946),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_pattern] = STATE(4406),
    [sym_rest_pattern] = STATE(3684),
    [sym_non_null_expression] = STATE(1396),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(484),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [aux_sym_array_repeat1] = STATE(4955),
    [aux_sym_array_pattern_repeat1] = STATE(4977),
    [sym_identifier] = ACTIONS(1738),
    [anon_sym_export] = ACTIONS(541),
    [anon_sym_type] = ACTIONS(541),
    [anon_sym_namespace] = ACTIONS(545),
    [anon_sym_LBRACE] = ACTIONS(808),
    [anon_sym_COMMA] = ACTIONS(1740),
    [anon_sym_typeof] = ACTIONS(581),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(541),
    [anon_sym_BANG] = ACTIONS(553),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(555),
    [anon_sym_yield] = ACTIONS(557),
    [anon_sym_LBRACK] = ACTIONS(812),
    [anon_sym_RBRACK] = ACTIONS(1748),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(563),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1744),
    [anon_sym_using] = ACTIONS(567),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(249),
    [anon_sym_PLUS] = ACTIONS(581),
    [anon_sym_DASH] = ACTIONS(581),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(553),
    [anon_sym_void] = ACTIONS(581),
    [anon_sym_delete] = ACTIONS(581),
    [anon_sym_PLUS_PLUS] = ACTIONS(583),
    [anon_sym_DASH_DASH] = ACTIONS(583),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(585),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1746),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(541),
    [anon_sym_readonly] = ACTIONS(541),
    [anon_sym_get] = ACTIONS(541),
    [anon_sym_set] = ACTIONS(541),
    [anon_sym_declare] = ACTIONS(541),
    [anon_sym_public] = ACTIONS(541),
    [anon_sym_private] = ACTIONS(541),
    [anon_sym_protected] = ACTIONS(541),
    [anon_sym_override] = ACTIONS(541),
    [anon_sym_module] = ACTIONS(541),
    [anon_sym_any] = ACTIONS(541),
    [anon_sym_number] = ACTIONS(541),
    [anon_sym_boolean] = ACTIONS(541),
    [anon_sym_string] = ACTIONS(541),
    [anon_sym_symbol] = ACTIONS(541),
    [anon_sym_object] = ACTIONS(541),
    [sym_html_comment] = ACTIONS(5),
  },
  [217] = {
    [ts_builtin_sym_end] = ACTIONS(1750),
    [sym_identifier] = ACTIONS(1752),
    [anon_sym_export] = ACTIONS(1752),
    [anon_sym_STAR] = ACTIONS(1752),
    [anon_sym_default] = ACTIONS(1752),
    [anon_sym_type] = ACTIONS(1752),
    [anon_sym_as] = ACTIONS(1752),
    [anon_sym_namespace] = ACTIONS(1752),
    [anon_sym_LBRACE] = ACTIONS(1750),
    [anon_sym_COMMA] = ACTIONS(1750),
    [anon_sym_RBRACE] = ACTIONS(1750),
    [anon_sym_typeof] = ACTIONS(1752),
    [anon_sym_import] = ACTIONS(1752),
    [anon_sym_with] = ACTIONS(1752),
    [anon_sym_var] = ACTIONS(1752),
    [anon_sym_let] = ACTIONS(1752),
    [anon_sym_const] = ACTIONS(1752),
    [anon_sym_BANG] = ACTIONS(1752),
    [anon_sym_else] = ACTIONS(1752),
    [anon_sym_if] = ACTIONS(1752),
    [anon_sym_switch] = ACTIONS(1752),
    [anon_sym_for] = ACTIONS(1752),
    [anon_sym_LPAREN] = ACTIONS(1750),
    [anon_sym_SEMI] = ACTIONS(1750),
    [anon_sym_await] = ACTIONS(1752),
    [anon_sym_in] = ACTIONS(1752),
    [anon_sym_while] = ACTIONS(1752),
    [anon_sym_do] = ACTIONS(1752),
    [anon_sym_try] = ACTIONS(1752),
    [anon_sym_break] = ACTIONS(1752),
    [anon_sym_continue] = ACTIONS(1752),
    [anon_sym_debugger] = ACTIONS(1752),
    [anon_sym_return] = ACTIONS(1752),
    [anon_sym_throw] = ACTIONS(1752),
    [anon_sym_case] = ACTIONS(1752),
    [anon_sym_yield] = ACTIONS(1752),
    [anon_sym_LBRACK] = ACTIONS(1750),
    [anon_sym_DOT] = ACTIONS(1752),
    [anon_sym_class] = ACTIONS(1752),
    [anon_sym_async] = ACTIONS(1752),
    [anon_sym_function] = ACTIONS(1752),
    [anon_sym_QMARK_DOT] = ACTIONS(1750),
    [anon_sym_new] = ACTIONS(1752),
    [anon_sym_using] = ACTIONS(1752),
    [anon_sym_AMP_AMP] = ACTIONS(1750),
    [anon_sym_PIPE_PIPE] = ACTIONS(1750),
    [anon_sym_GT_GT] = ACTIONS(1752),
    [anon_sym_GT_GT_GT] = ACTIONS(1750),
    [anon_sym_LT_LT] = ACTIONS(1750),
    [anon_sym_AMP] = ACTIONS(1752),
    [anon_sym_CARET] = ACTIONS(1750),
    [anon_sym_PIPE] = ACTIONS(1752),
    [anon_sym_PLUS] = ACTIONS(1752),
    [anon_sym_DASH] = ACTIONS(1752),
    [anon_sym_SLASH] = ACTIONS(1752),
    [anon_sym_PERCENT] = ACTIONS(1750),
    [anon_sym_STAR_STAR] = ACTIONS(1750),
    [anon_sym_LT] = ACTIONS(1752),
    [anon_sym_LT_EQ] = ACTIONS(1750),
    [anon_sym_EQ_EQ] = ACTIONS(1752),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(1750),
    [anon_sym_BANG_EQ] = ACTIONS(1752),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(1750),
    [anon_sym_GT_EQ] = ACTIONS(1750),
    [anon_sym_GT] = ACTIONS(1752),
    [anon_sym_QMARK_QMARK] = ACTIONS(1750),
    [anon_sym_instanceof] = ACTIONS(1752),
    [anon_sym_TILDE] = ACTIONS(1750),
    [anon_sym_void] = ACTIONS(1752),
    [anon_sym_delete] = ACTIONS(1752),
    [anon_sym_PLUS_PLUS] = ACTIONS(1750),
    [anon_sym_DASH_DASH] = ACTIONS(1750),
    [anon_sym_DQUOTE] = ACTIONS(1750),
    [anon_sym_SQUOTE] = ACTIONS(1750),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1750),
    [sym_number] = ACTIONS(1750),
    [sym_private_property_identifier] = ACTIONS(1750),
    [sym_this] = ACTIONS(1752),
    [sym_super] = ACTIONS(1752),
    [sym_true] = ACTIONS(1752),
    [sym_false] = ACTIONS(1752),
    [sym_null] = ACTIONS(1752),
    [sym_undefined] = ACTIONS(1752),
    [anon_sym_AT] = ACTIONS(1750),
    [anon_sym_static] = ACTIONS(1752),
    [anon_sym_readonly] = ACTIONS(1752),
    [anon_sym_get] = ACTIONS(1752),
    [anon_sym_set] = ACTIONS(1752),
    [anon_sym_declare] = ACTIONS(1752),
    [anon_sym_public] = ACTIONS(1752),
    [anon_sym_private] = ACTIONS(1752),
    [anon_sym_protected] = ACTIONS(1752),
    [anon_sym_override] = ACTIONS(1752),
    [anon_sym_module] = ACTIONS(1752),
    [anon_sym_any] = ACTIONS(1752),
    [anon_sym_number] = ACTIONS(1752),
    [anon_sym_boolean] = ACTIONS(1752),
    [anon_sym_string] = ACTIONS(1752),
    [anon_sym_symbol] = ACTIONS(1752),
    [anon_sym_object] = ACTIONS(1752),
    [anon_sym_abstract] = ACTIONS(1752),
    [anon_sym_satisfies] = ACTIONS(1752),
    [anon_sym_interface] = ACTIONS(1752),
    [anon_sym_enum] = ACTIONS(1752),
    [sym__automatic_semicolon] = ACTIONS(1750),
    [sym__ternary_qmark] = ACTIONS(1750),
    [sym_html_comment] = ACTIONS(5),
  },
  [218] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1213),
    [sym_expression] = STATE(2644),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(3722),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(3722),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5800),
    [sym__formal_parameter] = STATE(5169),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1295),
    [sym_subscript_expression] = STATE(1295),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3013),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(3722),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_pattern] = STATE(4339),
    [sym_rest_pattern] = STATE(3684),
    [sym_non_null_expression] = STATE(1295),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_accessibility_modifier] = STATE(288),
    [sym_override_modifier] = STATE(303),
    [sym_required_parameter] = STATE(5169),
    [sym_optional_parameter] = STATE(5169),
    [sym__parameter_name] = STATE(3624),
    [sym_type_arguments] = STATE(539),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(267),
    [sym_identifier] = ACTIONS(696),
    [anon_sym_export] = ACTIONS(113),
    [anon_sym_type] = ACTIONS(113),
    [anon_sym_namespace] = ACTIONS(122),
    [anon_sym_LBRACE] = ACTIONS(698),
    [anon_sym_typeof] = ACTIONS(179),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(113),
    [anon_sym_BANG] = ACTIONS(175),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(140),
    [anon_sym_yield] = ACTIONS(142),
    [anon_sym_LBRACK] = ACTIONS(1664),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(148),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(706),
    [anon_sym_using] = ACTIONS(158),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(162),
    [anon_sym_PLUS] = ACTIONS(179),
    [anon_sym_DASH] = ACTIONS(179),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(175),
    [anon_sym_void] = ACTIONS(179),
    [anon_sym_delete] = ACTIONS(179),
    [anon_sym_PLUS_PLUS] = ACTIONS(686),
    [anon_sym_DASH_DASH] = ACTIONS(686),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(192),
    [sym_this] = ACTIONS(1666),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(718),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(113),
    [anon_sym_readonly] = ACTIONS(1668),
    [anon_sym_get] = ACTIONS(113),
    [anon_sym_set] = ACTIONS(113),
    [anon_sym_declare] = ACTIONS(113),
    [anon_sym_public] = ACTIONS(798),
    [anon_sym_private] = ACTIONS(798),
    [anon_sym_protected] = ACTIONS(798),
    [anon_sym_override] = ACTIONS(800),
    [anon_sym_module] = ACTIONS(113),
    [anon_sym_any] = ACTIONS(113),
    [anon_sym_number] = ACTIONS(113),
    [anon_sym_boolean] = ACTIONS(113),
    [anon_sym_string] = ACTIONS(113),
    [anon_sym_symbol] = ACTIONS(113),
    [anon_sym_object] = ACTIONS(113),
    [sym_html_comment] = ACTIONS(5),
  },
  [219] = {
    [ts_builtin_sym_end] = ACTIONS(1754),
    [sym_identifier] = ACTIONS(1756),
    [anon_sym_export] = ACTIONS(1756),
    [anon_sym_STAR] = ACTIONS(1756),
    [anon_sym_default] = ACTIONS(1756),
    [anon_sym_type] = ACTIONS(1756),
    [anon_sym_as] = ACTIONS(1756),
    [anon_sym_namespace] = ACTIONS(1756),
    [anon_sym_LBRACE] = ACTIONS(1754),
    [anon_sym_COMMA] = ACTIONS(1754),
    [anon_sym_RBRACE] = ACTIONS(1754),
    [anon_sym_typeof] = ACTIONS(1756),
    [anon_sym_import] = ACTIONS(1756),
    [anon_sym_with] = ACTIONS(1756),
    [anon_sym_var] = ACTIONS(1756),
    [anon_sym_let] = ACTIONS(1756),
    [anon_sym_const] = ACTIONS(1756),
    [anon_sym_BANG] = ACTIONS(1756),
    [anon_sym_else] = ACTIONS(1756),
    [anon_sym_if] = ACTIONS(1756),
    [anon_sym_switch] = ACTIONS(1756),
    [anon_sym_for] = ACTIONS(1756),
    [anon_sym_LPAREN] = ACTIONS(1754),
    [anon_sym_SEMI] = ACTIONS(1754),
    [anon_sym_await] = ACTIONS(1756),
    [anon_sym_in] = ACTIONS(1756),
    [anon_sym_while] = ACTIONS(1756),
    [anon_sym_do] = ACTIONS(1756),
    [anon_sym_try] = ACTIONS(1756),
    [anon_sym_break] = ACTIONS(1756),
    [anon_sym_continue] = ACTIONS(1756),
    [anon_sym_debugger] = ACTIONS(1756),
    [anon_sym_return] = ACTIONS(1756),
    [anon_sym_throw] = ACTIONS(1756),
    [anon_sym_case] = ACTIONS(1756),
    [anon_sym_yield] = ACTIONS(1756),
    [anon_sym_LBRACK] = ACTIONS(1754),
    [anon_sym_DOT] = ACTIONS(1756),
    [anon_sym_class] = ACTIONS(1756),
    [anon_sym_async] = ACTIONS(1756),
    [anon_sym_function] = ACTIONS(1756),
    [anon_sym_QMARK_DOT] = ACTIONS(1754),
    [anon_sym_new] = ACTIONS(1756),
    [anon_sym_using] = ACTIONS(1756),
    [anon_sym_AMP_AMP] = ACTIONS(1754),
    [anon_sym_PIPE_PIPE] = ACTIONS(1754),
    [anon_sym_GT_GT] = ACTIONS(1756),
    [anon_sym_GT_GT_GT] = ACTIONS(1754),
    [anon_sym_LT_LT] = ACTIONS(1754),
    [anon_sym_AMP] = ACTIONS(1756),
    [anon_sym_CARET] = ACTIONS(1754),
    [anon_sym_PIPE] = ACTIONS(1756),
    [anon_sym_PLUS] = ACTIONS(1756),
    [anon_sym_DASH] = ACTIONS(1756),
    [anon_sym_SLASH] = ACTIONS(1756),
    [anon_sym_PERCENT] = ACTIONS(1754),
    [anon_sym_STAR_STAR] = ACTIONS(1754),
    [anon_sym_LT] = ACTIONS(1756),
    [anon_sym_LT_EQ] = ACTIONS(1754),
    [anon_sym_EQ_EQ] = ACTIONS(1756),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(1754),
    [anon_sym_BANG_EQ] = ACTIONS(1756),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(1754),
    [anon_sym_GT_EQ] = ACTIONS(1754),
    [anon_sym_GT] = ACTIONS(1756),
    [anon_sym_QMARK_QMARK] = ACTIONS(1754),
    [anon_sym_instanceof] = ACTIONS(1756),
    [anon_sym_TILDE] = ACTIONS(1754),
    [anon_sym_void] = ACTIONS(1756),
    [anon_sym_delete] = ACTIONS(1756),
    [anon_sym_PLUS_PLUS] = ACTIONS(1754),
    [anon_sym_DASH_DASH] = ACTIONS(1754),
    [anon_sym_DQUOTE] = ACTIONS(1754),
    [anon_sym_SQUOTE] = ACTIONS(1754),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1754),
    [sym_number] = ACTIONS(1754),
    [sym_private_property_identifier] = ACTIONS(1754),
    [sym_this] = ACTIONS(1756),
    [sym_super] = ACTIONS(1756),
    [sym_true] = ACTIONS(1756),
    [sym_false] = ACTIONS(1756),
    [sym_null] = ACTIONS(1756),
    [sym_undefined] = ACTIONS(1756),
    [anon_sym_AT] = ACTIONS(1754),
    [anon_sym_static] = ACTIONS(1756),
    [anon_sym_readonly] = ACTIONS(1756),
    [anon_sym_get] = ACTIONS(1756),
    [anon_sym_set] = ACTIONS(1756),
    [anon_sym_declare] = ACTIONS(1756),
    [anon_sym_public] = ACTIONS(1756),
    [anon_sym_private] = ACTIONS(1756),
    [anon_sym_protected] = ACTIONS(1756),
    [anon_sym_override] = ACTIONS(1756),
    [anon_sym_module] = ACTIONS(1756),
    [anon_sym_any] = ACTIONS(1756),
    [anon_sym_number] = ACTIONS(1756),
    [anon_sym_boolean] = ACTIONS(1756),
    [anon_sym_string] = ACTIONS(1756),
    [anon_sym_symbol] = ACTIONS(1756),
    [anon_sym_object] = ACTIONS(1756),
    [anon_sym_abstract] = ACTIONS(1756),
    [anon_sym_satisfies] = ACTIONS(1756),
    [anon_sym_interface] = ACTIONS(1756),
    [anon_sym_enum] = ACTIONS(1756),
    [sym__automatic_semicolon] = ACTIONS(1754),
    [sym__ternary_qmark] = ACTIONS(1754),
    [sym_html_comment] = ACTIONS(5),
  },
  [220] = {
    [ts_builtin_sym_end] = ACTIONS(1758),
    [sym_identifier] = ACTIONS(1760),
    [anon_sym_export] = ACTIONS(1760),
    [anon_sym_STAR] = ACTIONS(1762),
    [anon_sym_default] = ACTIONS(1760),
    [anon_sym_type] = ACTIONS(1760),
    [anon_sym_as] = ACTIONS(1762),
    [anon_sym_namespace] = ACTIONS(1760),
    [anon_sym_LBRACE] = ACTIONS(1758),
    [anon_sym_COMMA] = ACTIONS(1764),
    [anon_sym_RBRACE] = ACTIONS(1758),
    [anon_sym_typeof] = ACTIONS(1760),
    [anon_sym_import] = ACTIONS(1760),
    [anon_sym_with] = ACTIONS(1760),
    [anon_sym_var] = ACTIONS(1760),
    [anon_sym_let] = ACTIONS(1760),
    [anon_sym_const] = ACTIONS(1760),
    [anon_sym_BANG] = ACTIONS(1760),
    [anon_sym_else] = ACTIONS(1760),
    [anon_sym_if] = ACTIONS(1760),
    [anon_sym_switch] = ACTIONS(1760),
    [anon_sym_for] = ACTIONS(1760),
    [anon_sym_LPAREN] = ACTIONS(1758),
    [anon_sym_SEMI] = ACTIONS(1758),
    [anon_sym_await] = ACTIONS(1760),
    [anon_sym_in] = ACTIONS(1762),
    [anon_sym_while] = ACTIONS(1760),
    [anon_sym_do] = ACTIONS(1760),
    [anon_sym_try] = ACTIONS(1760),
    [anon_sym_break] = ACTIONS(1760),
    [anon_sym_continue] = ACTIONS(1760),
    [anon_sym_debugger] = ACTIONS(1760),
    [anon_sym_return] = ACTIONS(1760),
    [anon_sym_throw] = ACTIONS(1760),
    [anon_sym_case] = ACTIONS(1760),
    [anon_sym_yield] = ACTIONS(1760),
    [anon_sym_LBRACK] = ACTIONS(1758),
    [anon_sym_DOT] = ACTIONS(1762),
    [anon_sym_class] = ACTIONS(1760),
    [anon_sym_async] = ACTIONS(1760),
    [anon_sym_function] = ACTIONS(1760),
    [anon_sym_QMARK_DOT] = ACTIONS(1764),
    [anon_sym_new] = ACTIONS(1760),
    [anon_sym_using] = ACTIONS(1760),
    [anon_sym_AMP_AMP] = ACTIONS(1764),
    [anon_sym_PIPE_PIPE] = ACTIONS(1764),
    [anon_sym_GT_GT] = ACTIONS(1762),
    [anon_sym_GT_GT_GT] = ACTIONS(1764),
    [anon_sym_LT_LT] = ACTIONS(1764),
    [anon_sym_AMP] = ACTIONS(1762),
    [anon_sym_CARET] = ACTIONS(1764),
    [anon_sym_PIPE] = ACTIONS(1762),
    [anon_sym_PLUS] = ACTIONS(1760),
    [anon_sym_DASH] = ACTIONS(1760),
    [anon_sym_SLASH] = ACTIONS(1760),
    [anon_sym_PERCENT] = ACTIONS(1764),
    [anon_sym_STAR_STAR] = ACTIONS(1764),
    [anon_sym_LT] = ACTIONS(1760),
    [anon_sym_LT_EQ] = ACTIONS(1764),
    [anon_sym_EQ_EQ] = ACTIONS(1762),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(1764),
    [anon_sym_BANG_EQ] = ACTIONS(1762),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(1764),
    [anon_sym_GT_EQ] = ACTIONS(1764),
    [anon_sym_GT] = ACTIONS(1762),
    [anon_sym_QMARK_QMARK] = ACTIONS(1764),
    [anon_sym_instanceof] = ACTIONS(1762),
    [anon_sym_TILDE] = ACTIONS(1758),
    [anon_sym_void] = ACTIONS(1760),
    [anon_sym_delete] = ACTIONS(1760),
    [anon_sym_PLUS_PLUS] = ACTIONS(1758),
    [anon_sym_DASH_DASH] = ACTIONS(1758),
    [anon_sym_DQUOTE] = ACTIONS(1758),
    [anon_sym_SQUOTE] = ACTIONS(1758),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1758),
    [sym_number] = ACTIONS(1758),
    [sym_private_property_identifier] = ACTIONS(1758),
    [sym_this] = ACTIONS(1760),
    [sym_super] = ACTIONS(1760),
    [sym_true] = ACTIONS(1760),
    [sym_false] = ACTIONS(1760),
    [sym_null] = ACTIONS(1760),
    [sym_undefined] = ACTIONS(1760),
    [anon_sym_AT] = ACTIONS(1758),
    [anon_sym_static] = ACTIONS(1760),
    [anon_sym_readonly] = ACTIONS(1760),
    [anon_sym_get] = ACTIONS(1760),
    [anon_sym_set] = ACTIONS(1760),
    [anon_sym_declare] = ACTIONS(1760),
    [anon_sym_public] = ACTIONS(1760),
    [anon_sym_private] = ACTIONS(1760),
    [anon_sym_protected] = ACTIONS(1760),
    [anon_sym_override] = ACTIONS(1760),
    [anon_sym_module] = ACTIONS(1760),
    [anon_sym_any] = ACTIONS(1760),
    [anon_sym_number] = ACTIONS(1760),
    [anon_sym_boolean] = ACTIONS(1760),
    [anon_sym_string] = ACTIONS(1760),
    [anon_sym_symbol] = ACTIONS(1760),
    [anon_sym_object] = ACTIONS(1760),
    [anon_sym_abstract] = ACTIONS(1760),
    [anon_sym_satisfies] = ACTIONS(1762),
    [anon_sym_interface] = ACTIONS(1760),
    [anon_sym_enum] = ACTIONS(1760),
    [sym__automatic_semicolon] = ACTIONS(1766),
    [sym__ternary_qmark] = ACTIONS(1764),
    [sym_html_comment] = ACTIONS(5),
  },
  [221] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1322),
    [sym_expression] = STATE(2126),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(4425),
    [sym_assignment_pattern] = STATE(4969),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(4425),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5508),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1396),
    [sym_subscript_expression] = STATE(1396),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3003),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(4425),
    [sym_spread_element] = STATE(4946),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_pattern] = STATE(4406),
    [sym_rest_pattern] = STATE(3684),
    [sym_non_null_expression] = STATE(1396),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(484),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [aux_sym_array_repeat1] = STATE(4955),
    [aux_sym_array_pattern_repeat1] = STATE(4977),
    [sym_identifier] = ACTIONS(1738),
    [anon_sym_export] = ACTIONS(541),
    [anon_sym_type] = ACTIONS(541),
    [anon_sym_namespace] = ACTIONS(545),
    [anon_sym_LBRACE] = ACTIONS(808),
    [anon_sym_COMMA] = ACTIONS(1740),
    [anon_sym_typeof] = ACTIONS(581),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(541),
    [anon_sym_BANG] = ACTIONS(553),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(555),
    [anon_sym_yield] = ACTIONS(557),
    [anon_sym_LBRACK] = ACTIONS(812),
    [anon_sym_RBRACK] = ACTIONS(1768),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(563),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1744),
    [anon_sym_using] = ACTIONS(567),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(249),
    [anon_sym_PLUS] = ACTIONS(581),
    [anon_sym_DASH] = ACTIONS(581),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(553),
    [anon_sym_void] = ACTIONS(581),
    [anon_sym_delete] = ACTIONS(581),
    [anon_sym_PLUS_PLUS] = ACTIONS(583),
    [anon_sym_DASH_DASH] = ACTIONS(583),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(585),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1746),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(541),
    [anon_sym_readonly] = ACTIONS(541),
    [anon_sym_get] = ACTIONS(541),
    [anon_sym_set] = ACTIONS(541),
    [anon_sym_declare] = ACTIONS(541),
    [anon_sym_public] = ACTIONS(541),
    [anon_sym_private] = ACTIONS(541),
    [anon_sym_protected] = ACTIONS(541),
    [anon_sym_override] = ACTIONS(541),
    [anon_sym_module] = ACTIONS(541),
    [anon_sym_any] = ACTIONS(541),
    [anon_sym_number] = ACTIONS(541),
    [anon_sym_boolean] = ACTIONS(541),
    [anon_sym_string] = ACTIONS(541),
    [anon_sym_symbol] = ACTIONS(541),
    [anon_sym_object] = ACTIONS(541),
    [sym_html_comment] = ACTIONS(5),
  },
  [222] = {
    [ts_builtin_sym_end] = ACTIONS(1770),
    [sym_identifier] = ACTIONS(1772),
    [anon_sym_export] = ACTIONS(1772),
    [anon_sym_STAR] = ACTIONS(1774),
    [anon_sym_default] = ACTIONS(1772),
    [anon_sym_type] = ACTIONS(1772),
    [anon_sym_as] = ACTIONS(1774),
    [anon_sym_namespace] = ACTIONS(1772),
    [anon_sym_LBRACE] = ACTIONS(1770),
    [anon_sym_COMMA] = ACTIONS(1776),
    [anon_sym_RBRACE] = ACTIONS(1770),
    [anon_sym_typeof] = ACTIONS(1772),
    [anon_sym_import] = ACTIONS(1772),
    [anon_sym_with] = ACTIONS(1772),
    [anon_sym_var] = ACTIONS(1772),
    [anon_sym_let] = ACTIONS(1772),
    [anon_sym_const] = ACTIONS(1772),
    [anon_sym_BANG] = ACTIONS(1772),
    [anon_sym_else] = ACTIONS(1772),
    [anon_sym_if] = ACTIONS(1772),
    [anon_sym_switch] = ACTIONS(1772),
    [anon_sym_for] = ACTIONS(1772),
    [anon_sym_LPAREN] = ACTIONS(1770),
    [anon_sym_SEMI] = ACTIONS(1770),
    [anon_sym_await] = ACTIONS(1772),
    [anon_sym_in] = ACTIONS(1774),
    [anon_sym_while] = ACTIONS(1772),
    [anon_sym_do] = ACTIONS(1772),
    [anon_sym_try] = ACTIONS(1772),
    [anon_sym_break] = ACTIONS(1772),
    [anon_sym_continue] = ACTIONS(1772),
    [anon_sym_debugger] = ACTIONS(1772),
    [anon_sym_return] = ACTIONS(1772),
    [anon_sym_throw] = ACTIONS(1772),
    [anon_sym_case] = ACTIONS(1772),
    [anon_sym_yield] = ACTIONS(1772),
    [anon_sym_LBRACK] = ACTIONS(1770),
    [anon_sym_DOT] = ACTIONS(1774),
    [anon_sym_class] = ACTIONS(1772),
    [anon_sym_async] = ACTIONS(1772),
    [anon_sym_function] = ACTIONS(1772),
    [anon_sym_QMARK_DOT] = ACTIONS(1776),
    [anon_sym_new] = ACTIONS(1772),
    [anon_sym_using] = ACTIONS(1772),
    [anon_sym_AMP_AMP] = ACTIONS(1776),
    [anon_sym_PIPE_PIPE] = ACTIONS(1776),
    [anon_sym_GT_GT] = ACTIONS(1774),
    [anon_sym_GT_GT_GT] = ACTIONS(1776),
    [anon_sym_LT_LT] = ACTIONS(1776),
    [anon_sym_AMP] = ACTIONS(1774),
    [anon_sym_CARET] = ACTIONS(1776),
    [anon_sym_PIPE] = ACTIONS(1774),
    [anon_sym_PLUS] = ACTIONS(1772),
    [anon_sym_DASH] = ACTIONS(1772),
    [anon_sym_SLASH] = ACTIONS(1772),
    [anon_sym_PERCENT] = ACTIONS(1776),
    [anon_sym_STAR_STAR] = ACTIONS(1776),
    [anon_sym_LT] = ACTIONS(1772),
    [anon_sym_LT_EQ] = ACTIONS(1776),
    [anon_sym_EQ_EQ] = ACTIONS(1774),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(1776),
    [anon_sym_BANG_EQ] = ACTIONS(1774),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(1776),
    [anon_sym_GT_EQ] = ACTIONS(1776),
    [anon_sym_GT] = ACTIONS(1774),
    [anon_sym_QMARK_QMARK] = ACTIONS(1776),
    [anon_sym_instanceof] = ACTIONS(1774),
    [anon_sym_TILDE] = ACTIONS(1770),
    [anon_sym_void] = ACTIONS(1772),
    [anon_sym_delete] = ACTIONS(1772),
    [anon_sym_PLUS_PLUS] = ACTIONS(1770),
    [anon_sym_DASH_DASH] = ACTIONS(1770),
    [anon_sym_DQUOTE] = ACTIONS(1770),
    [anon_sym_SQUOTE] = ACTIONS(1770),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1770),
    [sym_number] = ACTIONS(1770),
    [sym_private_property_identifier] = ACTIONS(1770),
    [sym_this] = ACTIONS(1772),
    [sym_super] = ACTIONS(1772),
    [sym_true] = ACTIONS(1772),
    [sym_false] = ACTIONS(1772),
    [sym_null] = ACTIONS(1772),
    [sym_undefined] = ACTIONS(1772),
    [anon_sym_AT] = ACTIONS(1770),
    [anon_sym_static] = ACTIONS(1772),
    [anon_sym_readonly] = ACTIONS(1772),
    [anon_sym_get] = ACTIONS(1772),
    [anon_sym_set] = ACTIONS(1772),
    [anon_sym_declare] = ACTIONS(1772),
    [anon_sym_public] = ACTIONS(1772),
    [anon_sym_private] = ACTIONS(1772),
    [anon_sym_protected] = ACTIONS(1772),
    [anon_sym_override] = ACTIONS(1772),
    [anon_sym_module] = ACTIONS(1772),
    [anon_sym_any] = ACTIONS(1772),
    [anon_sym_number] = ACTIONS(1772),
    [anon_sym_boolean] = ACTIONS(1772),
    [anon_sym_string] = ACTIONS(1772),
    [anon_sym_symbol] = ACTIONS(1772),
    [anon_sym_object] = ACTIONS(1772),
    [anon_sym_abstract] = ACTIONS(1772),
    [anon_sym_satisfies] = ACTIONS(1774),
    [anon_sym_interface] = ACTIONS(1772),
    [anon_sym_enum] = ACTIONS(1772),
    [sym__automatic_semicolon] = ACTIONS(1778),
    [sym__ternary_qmark] = ACTIONS(1776),
    [sym_html_comment] = ACTIONS(5),
  },
  [223] = {
    [ts_builtin_sym_end] = ACTIONS(1780),
    [sym_identifier] = ACTIONS(1782),
    [anon_sym_export] = ACTIONS(1782),
    [anon_sym_STAR] = ACTIONS(1784),
    [anon_sym_default] = ACTIONS(1782),
    [anon_sym_type] = ACTIONS(1782),
    [anon_sym_as] = ACTIONS(1784),
    [anon_sym_namespace] = ACTIONS(1782),
    [anon_sym_LBRACE] = ACTIONS(1780),
    [anon_sym_COMMA] = ACTIONS(1786),
    [anon_sym_RBRACE] = ACTIONS(1780),
    [anon_sym_typeof] = ACTIONS(1782),
    [anon_sym_import] = ACTIONS(1782),
    [anon_sym_with] = ACTIONS(1782),
    [anon_sym_var] = ACTIONS(1782),
    [anon_sym_let] = ACTIONS(1782),
    [anon_sym_const] = ACTIONS(1782),
    [anon_sym_BANG] = ACTIONS(1782),
    [anon_sym_else] = ACTIONS(1782),
    [anon_sym_if] = ACTIONS(1782),
    [anon_sym_switch] = ACTIONS(1782),
    [anon_sym_for] = ACTIONS(1782),
    [anon_sym_LPAREN] = ACTIONS(1780),
    [anon_sym_SEMI] = ACTIONS(1780),
    [anon_sym_await] = ACTIONS(1782),
    [anon_sym_in] = ACTIONS(1784),
    [anon_sym_while] = ACTIONS(1782),
    [anon_sym_do] = ACTIONS(1782),
    [anon_sym_try] = ACTIONS(1782),
    [anon_sym_break] = ACTIONS(1782),
    [anon_sym_continue] = ACTIONS(1782),
    [anon_sym_debugger] = ACTIONS(1782),
    [anon_sym_return] = ACTIONS(1782),
    [anon_sym_throw] = ACTIONS(1782),
    [anon_sym_case] = ACTIONS(1782),
    [anon_sym_yield] = ACTIONS(1782),
    [anon_sym_LBRACK] = ACTIONS(1780),
    [anon_sym_DOT] = ACTIONS(1784),
    [anon_sym_class] = ACTIONS(1782),
    [anon_sym_async] = ACTIONS(1782),
    [anon_sym_function] = ACTIONS(1782),
    [anon_sym_QMARK_DOT] = ACTIONS(1786),
    [anon_sym_new] = ACTIONS(1782),
    [anon_sym_using] = ACTIONS(1782),
    [anon_sym_AMP_AMP] = ACTIONS(1786),
    [anon_sym_PIPE_PIPE] = ACTIONS(1786),
    [anon_sym_GT_GT] = ACTIONS(1784),
    [anon_sym_GT_GT_GT] = ACTIONS(1786),
    [anon_sym_LT_LT] = ACTIONS(1786),
    [anon_sym_AMP] = ACTIONS(1784),
    [anon_sym_CARET] = ACTIONS(1786),
    [anon_sym_PIPE] = ACTIONS(1784),
    [anon_sym_PLUS] = ACTIONS(1782),
    [anon_sym_DASH] = ACTIONS(1782),
    [anon_sym_SLASH] = ACTIONS(1782),
    [anon_sym_PERCENT] = ACTIONS(1786),
    [anon_sym_STAR_STAR] = ACTIONS(1786),
    [anon_sym_LT] = ACTIONS(1782),
    [anon_sym_LT_EQ] = ACTIONS(1786),
    [anon_sym_EQ_EQ] = ACTIONS(1784),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(1786),
    [anon_sym_BANG_EQ] = ACTIONS(1784),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(1786),
    [anon_sym_GT_EQ] = ACTIONS(1786),
    [anon_sym_GT] = ACTIONS(1784),
    [anon_sym_QMARK_QMARK] = ACTIONS(1786),
    [anon_sym_instanceof] = ACTIONS(1784),
    [anon_sym_TILDE] = ACTIONS(1780),
    [anon_sym_void] = ACTIONS(1782),
    [anon_sym_delete] = ACTIONS(1782),
    [anon_sym_PLUS_PLUS] = ACTIONS(1780),
    [anon_sym_DASH_DASH] = ACTIONS(1780),
    [anon_sym_DQUOTE] = ACTIONS(1780),
    [anon_sym_SQUOTE] = ACTIONS(1780),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1780),
    [sym_number] = ACTIONS(1780),
    [sym_private_property_identifier] = ACTIONS(1780),
    [sym_this] = ACTIONS(1782),
    [sym_super] = ACTIONS(1782),
    [sym_true] = ACTIONS(1782),
    [sym_false] = ACTIONS(1782),
    [sym_null] = ACTIONS(1782),
    [sym_undefined] = ACTIONS(1782),
    [anon_sym_AT] = ACTIONS(1780),
    [anon_sym_static] = ACTIONS(1782),
    [anon_sym_readonly] = ACTIONS(1782),
    [anon_sym_get] = ACTIONS(1782),
    [anon_sym_set] = ACTIONS(1782),
    [anon_sym_declare] = ACTIONS(1782),
    [anon_sym_public] = ACTIONS(1782),
    [anon_sym_private] = ACTIONS(1782),
    [anon_sym_protected] = ACTIONS(1782),
    [anon_sym_override] = ACTIONS(1782),
    [anon_sym_module] = ACTIONS(1782),
    [anon_sym_any] = ACTIONS(1782),
    [anon_sym_number] = ACTIONS(1782),
    [anon_sym_boolean] = ACTIONS(1782),
    [anon_sym_string] = ACTIONS(1782),
    [anon_sym_symbol] = ACTIONS(1782),
    [anon_sym_object] = ACTIONS(1782),
    [anon_sym_abstract] = ACTIONS(1782),
    [anon_sym_satisfies] = ACTIONS(1784),
    [anon_sym_interface] = ACTIONS(1782),
    [anon_sym_enum] = ACTIONS(1782),
    [sym__automatic_semicolon] = ACTIONS(1788),
    [sym__ternary_qmark] = ACTIONS(1786),
    [sym_html_comment] = ACTIONS(5),
  },
  [224] = {
    [ts_builtin_sym_end] = ACTIONS(1790),
    [sym_identifier] = ACTIONS(1792),
    [anon_sym_export] = ACTIONS(1792),
    [anon_sym_STAR] = ACTIONS(1794),
    [anon_sym_default] = ACTIONS(1792),
    [anon_sym_type] = ACTIONS(1792),
    [anon_sym_as] = ACTIONS(1794),
    [anon_sym_namespace] = ACTIONS(1792),
    [anon_sym_LBRACE] = ACTIONS(1790),
    [anon_sym_COMMA] = ACTIONS(1796),
    [anon_sym_RBRACE] = ACTIONS(1790),
    [anon_sym_typeof] = ACTIONS(1792),
    [anon_sym_import] = ACTIONS(1792),
    [anon_sym_with] = ACTIONS(1792),
    [anon_sym_var] = ACTIONS(1792),
    [anon_sym_let] = ACTIONS(1792),
    [anon_sym_const] = ACTIONS(1792),
    [anon_sym_BANG] = ACTIONS(1792),
    [anon_sym_else] = ACTIONS(1792),
    [anon_sym_if] = ACTIONS(1792),
    [anon_sym_switch] = ACTIONS(1792),
    [anon_sym_for] = ACTIONS(1792),
    [anon_sym_LPAREN] = ACTIONS(1790),
    [anon_sym_SEMI] = ACTIONS(1790),
    [anon_sym_await] = ACTIONS(1792),
    [anon_sym_in] = ACTIONS(1794),
    [anon_sym_while] = ACTIONS(1792),
    [anon_sym_do] = ACTIONS(1792),
    [anon_sym_try] = ACTIONS(1792),
    [anon_sym_break] = ACTIONS(1792),
    [anon_sym_continue] = ACTIONS(1792),
    [anon_sym_debugger] = ACTIONS(1792),
    [anon_sym_return] = ACTIONS(1792),
    [anon_sym_throw] = ACTIONS(1792),
    [anon_sym_case] = ACTIONS(1792),
    [anon_sym_yield] = ACTIONS(1792),
    [anon_sym_LBRACK] = ACTIONS(1790),
    [anon_sym_DOT] = ACTIONS(1794),
    [anon_sym_class] = ACTIONS(1792),
    [anon_sym_async] = ACTIONS(1792),
    [anon_sym_function] = ACTIONS(1792),
    [anon_sym_QMARK_DOT] = ACTIONS(1796),
    [anon_sym_new] = ACTIONS(1792),
    [anon_sym_using] = ACTIONS(1792),
    [anon_sym_AMP_AMP] = ACTIONS(1796),
    [anon_sym_PIPE_PIPE] = ACTIONS(1796),
    [anon_sym_GT_GT] = ACTIONS(1794),
    [anon_sym_GT_GT_GT] = ACTIONS(1796),
    [anon_sym_LT_LT] = ACTIONS(1796),
    [anon_sym_AMP] = ACTIONS(1794),
    [anon_sym_CARET] = ACTIONS(1796),
    [anon_sym_PIPE] = ACTIONS(1794),
    [anon_sym_PLUS] = ACTIONS(1792),
    [anon_sym_DASH] = ACTIONS(1792),
    [anon_sym_SLASH] = ACTIONS(1792),
    [anon_sym_PERCENT] = ACTIONS(1796),
    [anon_sym_STAR_STAR] = ACTIONS(1796),
    [anon_sym_LT] = ACTIONS(1792),
    [anon_sym_LT_EQ] = ACTIONS(1796),
    [anon_sym_EQ_EQ] = ACTIONS(1794),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(1796),
    [anon_sym_BANG_EQ] = ACTIONS(1794),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(1796),
    [anon_sym_GT_EQ] = ACTIONS(1796),
    [anon_sym_GT] = ACTIONS(1794),
    [anon_sym_QMARK_QMARK] = ACTIONS(1796),
    [anon_sym_instanceof] = ACTIONS(1794),
    [anon_sym_TILDE] = ACTIONS(1790),
    [anon_sym_void] = ACTIONS(1792),
    [anon_sym_delete] = ACTIONS(1792),
    [anon_sym_PLUS_PLUS] = ACTIONS(1790),
    [anon_sym_DASH_DASH] = ACTIONS(1790),
    [anon_sym_DQUOTE] = ACTIONS(1790),
    [anon_sym_SQUOTE] = ACTIONS(1790),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1790),
    [sym_number] = ACTIONS(1790),
    [sym_private_property_identifier] = ACTIONS(1790),
    [sym_this] = ACTIONS(1792),
    [sym_super] = ACTIONS(1792),
    [sym_true] = ACTIONS(1792),
    [sym_false] = ACTIONS(1792),
    [sym_null] = ACTIONS(1792),
    [sym_undefined] = ACTIONS(1792),
    [anon_sym_AT] = ACTIONS(1790),
    [anon_sym_static] = ACTIONS(1792),
    [anon_sym_readonly] = ACTIONS(1792),
    [anon_sym_get] = ACTIONS(1792),
    [anon_sym_set] = ACTIONS(1792),
    [anon_sym_declare] = ACTIONS(1792),
    [anon_sym_public] = ACTIONS(1792),
    [anon_sym_private] = ACTIONS(1792),
    [anon_sym_protected] = ACTIONS(1792),
    [anon_sym_override] = ACTIONS(1792),
    [anon_sym_module] = ACTIONS(1792),
    [anon_sym_any] = ACTIONS(1792),
    [anon_sym_number] = ACTIONS(1792),
    [anon_sym_boolean] = ACTIONS(1792),
    [anon_sym_string] = ACTIONS(1792),
    [anon_sym_symbol] = ACTIONS(1792),
    [anon_sym_object] = ACTIONS(1792),
    [anon_sym_abstract] = ACTIONS(1792),
    [anon_sym_satisfies] = ACTIONS(1794),
    [anon_sym_interface] = ACTIONS(1792),
    [anon_sym_enum] = ACTIONS(1792),
    [sym__automatic_semicolon] = ACTIONS(1798),
    [sym__ternary_qmark] = ACTIONS(1796),
    [sym_html_comment] = ACTIONS(5),
  },
  [225] = {
    [ts_builtin_sym_end] = ACTIONS(1800),
    [sym_identifier] = ACTIONS(1802),
    [anon_sym_export] = ACTIONS(1802),
    [anon_sym_STAR] = ACTIONS(1804),
    [anon_sym_default] = ACTIONS(1802),
    [anon_sym_type] = ACTIONS(1802),
    [anon_sym_as] = ACTIONS(1804),
    [anon_sym_namespace] = ACTIONS(1802),
    [anon_sym_LBRACE] = ACTIONS(1800),
    [anon_sym_COMMA] = ACTIONS(1806),
    [anon_sym_RBRACE] = ACTIONS(1800),
    [anon_sym_typeof] = ACTIONS(1802),
    [anon_sym_import] = ACTIONS(1802),
    [anon_sym_with] = ACTIONS(1802),
    [anon_sym_var] = ACTIONS(1802),
    [anon_sym_let] = ACTIONS(1802),
    [anon_sym_const] = ACTIONS(1802),
    [anon_sym_BANG] = ACTIONS(1802),
    [anon_sym_else] = ACTIONS(1802),
    [anon_sym_if] = ACTIONS(1802),
    [anon_sym_switch] = ACTIONS(1802),
    [anon_sym_for] = ACTIONS(1802),
    [anon_sym_LPAREN] = ACTIONS(1800),
    [anon_sym_SEMI] = ACTIONS(1800),
    [anon_sym_await] = ACTIONS(1802),
    [anon_sym_in] = ACTIONS(1804),
    [anon_sym_while] = ACTIONS(1802),
    [anon_sym_do] = ACTIONS(1802),
    [anon_sym_try] = ACTIONS(1802),
    [anon_sym_break] = ACTIONS(1802),
    [anon_sym_continue] = ACTIONS(1802),
    [anon_sym_debugger] = ACTIONS(1802),
    [anon_sym_return] = ACTIONS(1802),
    [anon_sym_throw] = ACTIONS(1802),
    [anon_sym_case] = ACTIONS(1802),
    [anon_sym_yield] = ACTIONS(1802),
    [anon_sym_LBRACK] = ACTIONS(1800),
    [anon_sym_DOT] = ACTIONS(1804),
    [anon_sym_class] = ACTIONS(1802),
    [anon_sym_async] = ACTIONS(1802),
    [anon_sym_function] = ACTIONS(1802),
    [anon_sym_QMARK_DOT] = ACTIONS(1806),
    [anon_sym_new] = ACTIONS(1802),
    [anon_sym_using] = ACTIONS(1802),
    [anon_sym_AMP_AMP] = ACTIONS(1806),
    [anon_sym_PIPE_PIPE] = ACTIONS(1806),
    [anon_sym_GT_GT] = ACTIONS(1804),
    [anon_sym_GT_GT_GT] = ACTIONS(1806),
    [anon_sym_LT_LT] = ACTIONS(1806),
    [anon_sym_AMP] = ACTIONS(1804),
    [anon_sym_CARET] = ACTIONS(1806),
    [anon_sym_PIPE] = ACTIONS(1804),
    [anon_sym_PLUS] = ACTIONS(1802),
    [anon_sym_DASH] = ACTIONS(1802),
    [anon_sym_SLASH] = ACTIONS(1802),
    [anon_sym_PERCENT] = ACTIONS(1806),
    [anon_sym_STAR_STAR] = ACTIONS(1806),
    [anon_sym_LT] = ACTIONS(1802),
    [anon_sym_LT_EQ] = ACTIONS(1806),
    [anon_sym_EQ_EQ] = ACTIONS(1804),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(1806),
    [anon_sym_BANG_EQ] = ACTIONS(1804),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(1806),
    [anon_sym_GT_EQ] = ACTIONS(1806),
    [anon_sym_GT] = ACTIONS(1804),
    [anon_sym_QMARK_QMARK] = ACTIONS(1806),
    [anon_sym_instanceof] = ACTIONS(1804),
    [anon_sym_TILDE] = ACTIONS(1800),
    [anon_sym_void] = ACTIONS(1802),
    [anon_sym_delete] = ACTIONS(1802),
    [anon_sym_PLUS_PLUS] = ACTIONS(1800),
    [anon_sym_DASH_DASH] = ACTIONS(1800),
    [anon_sym_DQUOTE] = ACTIONS(1800),
    [anon_sym_SQUOTE] = ACTIONS(1800),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1800),
    [sym_number] = ACTIONS(1800),
    [sym_private_property_identifier] = ACTIONS(1800),
    [sym_this] = ACTIONS(1802),
    [sym_super] = ACTIONS(1802),
    [sym_true] = ACTIONS(1802),
    [sym_false] = ACTIONS(1802),
    [sym_null] = ACTIONS(1802),
    [sym_undefined] = ACTIONS(1802),
    [anon_sym_AT] = ACTIONS(1800),
    [anon_sym_static] = ACTIONS(1802),
    [anon_sym_readonly] = ACTIONS(1802),
    [anon_sym_get] = ACTIONS(1802),
    [anon_sym_set] = ACTIONS(1802),
    [anon_sym_declare] = ACTIONS(1802),
    [anon_sym_public] = ACTIONS(1802),
    [anon_sym_private] = ACTIONS(1802),
    [anon_sym_protected] = ACTIONS(1802),
    [anon_sym_override] = ACTIONS(1802),
    [anon_sym_module] = ACTIONS(1802),
    [anon_sym_any] = ACTIONS(1802),
    [anon_sym_number] = ACTIONS(1802),
    [anon_sym_boolean] = ACTIONS(1802),
    [anon_sym_string] = ACTIONS(1802),
    [anon_sym_symbol] = ACTIONS(1802),
    [anon_sym_object] = ACTIONS(1802),
    [anon_sym_abstract] = ACTIONS(1802),
    [anon_sym_satisfies] = ACTIONS(1804),
    [anon_sym_interface] = ACTIONS(1802),
    [anon_sym_enum] = ACTIONS(1802),
    [sym__automatic_semicolon] = ACTIONS(1808),
    [sym__ternary_qmark] = ACTIONS(1806),
    [sym_html_comment] = ACTIONS(5),
  },
  [226] = {
    [ts_builtin_sym_end] = ACTIONS(1810),
    [sym_identifier] = ACTIONS(1812),
    [anon_sym_export] = ACTIONS(1812),
    [anon_sym_STAR] = ACTIONS(1814),
    [anon_sym_default] = ACTIONS(1812),
    [anon_sym_type] = ACTIONS(1812),
    [anon_sym_as] = ACTIONS(1814),
    [anon_sym_namespace] = ACTIONS(1812),
    [anon_sym_LBRACE] = ACTIONS(1810),
    [anon_sym_COMMA] = ACTIONS(1816),
    [anon_sym_RBRACE] = ACTIONS(1810),
    [anon_sym_typeof] = ACTIONS(1812),
    [anon_sym_import] = ACTIONS(1812),
    [anon_sym_with] = ACTIONS(1812),
    [anon_sym_var] = ACTIONS(1812),
    [anon_sym_let] = ACTIONS(1812),
    [anon_sym_const] = ACTIONS(1812),
    [anon_sym_BANG] = ACTIONS(1812),
    [anon_sym_else] = ACTIONS(1812),
    [anon_sym_if] = ACTIONS(1812),
    [anon_sym_switch] = ACTIONS(1812),
    [anon_sym_for] = ACTIONS(1812),
    [anon_sym_LPAREN] = ACTIONS(1810),
    [anon_sym_SEMI] = ACTIONS(1810),
    [anon_sym_await] = ACTIONS(1812),
    [anon_sym_in] = ACTIONS(1814),
    [anon_sym_while] = ACTIONS(1812),
    [anon_sym_do] = ACTIONS(1812),
    [anon_sym_try] = ACTIONS(1812),
    [anon_sym_break] = ACTIONS(1812),
    [anon_sym_continue] = ACTIONS(1812),
    [anon_sym_debugger] = ACTIONS(1812),
    [anon_sym_return] = ACTIONS(1812),
    [anon_sym_throw] = ACTIONS(1812),
    [anon_sym_case] = ACTIONS(1812),
    [anon_sym_yield] = ACTIONS(1812),
    [anon_sym_LBRACK] = ACTIONS(1810),
    [anon_sym_DOT] = ACTIONS(1814),
    [anon_sym_class] = ACTIONS(1812),
    [anon_sym_async] = ACTIONS(1812),
    [anon_sym_function] = ACTIONS(1812),
    [anon_sym_QMARK_DOT] = ACTIONS(1816),
    [anon_sym_new] = ACTIONS(1812),
    [anon_sym_using] = ACTIONS(1812),
    [anon_sym_AMP_AMP] = ACTIONS(1816),
    [anon_sym_PIPE_PIPE] = ACTIONS(1816),
    [anon_sym_GT_GT] = ACTIONS(1814),
    [anon_sym_GT_GT_GT] = ACTIONS(1816),
    [anon_sym_LT_LT] = ACTIONS(1816),
    [anon_sym_AMP] = ACTIONS(1814),
    [anon_sym_CARET] = ACTIONS(1816),
    [anon_sym_PIPE] = ACTIONS(1814),
    [anon_sym_PLUS] = ACTIONS(1812),
    [anon_sym_DASH] = ACTIONS(1812),
    [anon_sym_SLASH] = ACTIONS(1812),
    [anon_sym_PERCENT] = ACTIONS(1816),
    [anon_sym_STAR_STAR] = ACTIONS(1816),
    [anon_sym_LT] = ACTIONS(1812),
    [anon_sym_LT_EQ] = ACTIONS(1816),
    [anon_sym_EQ_EQ] = ACTIONS(1814),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(1816),
    [anon_sym_BANG_EQ] = ACTIONS(1814),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(1816),
    [anon_sym_GT_EQ] = ACTIONS(1816),
    [anon_sym_GT] = ACTIONS(1814),
    [anon_sym_QMARK_QMARK] = ACTIONS(1816),
    [anon_sym_instanceof] = ACTIONS(1814),
    [anon_sym_TILDE] = ACTIONS(1810),
    [anon_sym_void] = ACTIONS(1812),
    [anon_sym_delete] = ACTIONS(1812),
    [anon_sym_PLUS_PLUS] = ACTIONS(1810),
    [anon_sym_DASH_DASH] = ACTIONS(1810),
    [anon_sym_DQUOTE] = ACTIONS(1810),
    [anon_sym_SQUOTE] = ACTIONS(1810),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1810),
    [sym_number] = ACTIONS(1810),
    [sym_private_property_identifier] = ACTIONS(1810),
    [sym_this] = ACTIONS(1812),
    [sym_super] = ACTIONS(1812),
    [sym_true] = ACTIONS(1812),
    [sym_false] = ACTIONS(1812),
    [sym_null] = ACTIONS(1812),
    [sym_undefined] = ACTIONS(1812),
    [anon_sym_AT] = ACTIONS(1810),
    [anon_sym_static] = ACTIONS(1812),
    [anon_sym_readonly] = ACTIONS(1812),
    [anon_sym_get] = ACTIONS(1812),
    [anon_sym_set] = ACTIONS(1812),
    [anon_sym_declare] = ACTIONS(1812),
    [anon_sym_public] = ACTIONS(1812),
    [anon_sym_private] = ACTIONS(1812),
    [anon_sym_protected] = ACTIONS(1812),
    [anon_sym_override] = ACTIONS(1812),
    [anon_sym_module] = ACTIONS(1812),
    [anon_sym_any] = ACTIONS(1812),
    [anon_sym_number] = ACTIONS(1812),
    [anon_sym_boolean] = ACTIONS(1812),
    [anon_sym_string] = ACTIONS(1812),
    [anon_sym_symbol] = ACTIONS(1812),
    [anon_sym_object] = ACTIONS(1812),
    [anon_sym_abstract] = ACTIONS(1812),
    [anon_sym_satisfies] = ACTIONS(1814),
    [anon_sym_interface] = ACTIONS(1812),
    [anon_sym_enum] = ACTIONS(1812),
    [sym__automatic_semicolon] = ACTIONS(1818),
    [sym__ternary_qmark] = ACTIONS(1816),
    [sym_html_comment] = ACTIONS(5),
  },
  [227] = {
    [ts_builtin_sym_end] = ACTIONS(1820),
    [sym_identifier] = ACTIONS(1822),
    [anon_sym_export] = ACTIONS(1822),
    [anon_sym_STAR] = ACTIONS(1824),
    [anon_sym_default] = ACTIONS(1822),
    [anon_sym_type] = ACTIONS(1822),
    [anon_sym_as] = ACTIONS(1824),
    [anon_sym_namespace] = ACTIONS(1822),
    [anon_sym_LBRACE] = ACTIONS(1820),
    [anon_sym_COMMA] = ACTIONS(1826),
    [anon_sym_RBRACE] = ACTIONS(1820),
    [anon_sym_typeof] = ACTIONS(1822),
    [anon_sym_import] = ACTIONS(1822),
    [anon_sym_with] = ACTIONS(1822),
    [anon_sym_var] = ACTIONS(1822),
    [anon_sym_let] = ACTIONS(1822),
    [anon_sym_const] = ACTIONS(1822),
    [anon_sym_BANG] = ACTIONS(1822),
    [anon_sym_else] = ACTIONS(1822),
    [anon_sym_if] = ACTIONS(1822),
    [anon_sym_switch] = ACTIONS(1822),
    [anon_sym_for] = ACTIONS(1822),
    [anon_sym_LPAREN] = ACTIONS(1820),
    [anon_sym_SEMI] = ACTIONS(1820),
    [anon_sym_await] = ACTIONS(1822),
    [anon_sym_in] = ACTIONS(1824),
    [anon_sym_while] = ACTIONS(1822),
    [anon_sym_do] = ACTIONS(1822),
    [anon_sym_try] = ACTIONS(1822),
    [anon_sym_break] = ACTIONS(1822),
    [anon_sym_continue] = ACTIONS(1822),
    [anon_sym_debugger] = ACTIONS(1822),
    [anon_sym_return] = ACTIONS(1822),
    [anon_sym_throw] = ACTIONS(1822),
    [anon_sym_case] = ACTIONS(1822),
    [anon_sym_yield] = ACTIONS(1822),
    [anon_sym_LBRACK] = ACTIONS(1820),
    [anon_sym_DOT] = ACTIONS(1824),
    [anon_sym_class] = ACTIONS(1822),
    [anon_sym_async] = ACTIONS(1822),
    [anon_sym_function] = ACTIONS(1822),
    [anon_sym_QMARK_DOT] = ACTIONS(1826),
    [anon_sym_new] = ACTIONS(1822),
    [anon_sym_using] = ACTIONS(1822),
    [anon_sym_AMP_AMP] = ACTIONS(1826),
    [anon_sym_PIPE_PIPE] = ACTIONS(1826),
    [anon_sym_GT_GT] = ACTIONS(1824),
    [anon_sym_GT_GT_GT] = ACTIONS(1826),
    [anon_sym_LT_LT] = ACTIONS(1826),
    [anon_sym_AMP] = ACTIONS(1824),
    [anon_sym_CARET] = ACTIONS(1826),
    [anon_sym_PIPE] = ACTIONS(1824),
    [anon_sym_PLUS] = ACTIONS(1822),
    [anon_sym_DASH] = ACTIONS(1822),
    [anon_sym_SLASH] = ACTIONS(1822),
    [anon_sym_PERCENT] = ACTIONS(1826),
    [anon_sym_STAR_STAR] = ACTIONS(1826),
    [anon_sym_LT] = ACTIONS(1822),
    [anon_sym_LT_EQ] = ACTIONS(1826),
    [anon_sym_EQ_EQ] = ACTIONS(1824),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(1826),
    [anon_sym_BANG_EQ] = ACTIONS(1824),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(1826),
    [anon_sym_GT_EQ] = ACTIONS(1826),
    [anon_sym_GT] = ACTIONS(1824),
    [anon_sym_QMARK_QMARK] = ACTIONS(1826),
    [anon_sym_instanceof] = ACTIONS(1824),
    [anon_sym_TILDE] = ACTIONS(1820),
    [anon_sym_void] = ACTIONS(1822),
    [anon_sym_delete] = ACTIONS(1822),
    [anon_sym_PLUS_PLUS] = ACTIONS(1820),
    [anon_sym_DASH_DASH] = ACTIONS(1820),
    [anon_sym_DQUOTE] = ACTIONS(1820),
    [anon_sym_SQUOTE] = ACTIONS(1820),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1820),
    [sym_number] = ACTIONS(1820),
    [sym_private_property_identifier] = ACTIONS(1820),
    [sym_this] = ACTIONS(1822),
    [sym_super] = ACTIONS(1822),
    [sym_true] = ACTIONS(1822),
    [sym_false] = ACTIONS(1822),
    [sym_null] = ACTIONS(1822),
    [sym_undefined] = ACTIONS(1822),
    [anon_sym_AT] = ACTIONS(1820),
    [anon_sym_static] = ACTIONS(1822),
    [anon_sym_readonly] = ACTIONS(1822),
    [anon_sym_get] = ACTIONS(1822),
    [anon_sym_set] = ACTIONS(1822),
    [anon_sym_declare] = ACTIONS(1822),
    [anon_sym_public] = ACTIONS(1822),
    [anon_sym_private] = ACTIONS(1822),
    [anon_sym_protected] = ACTIONS(1822),
    [anon_sym_override] = ACTIONS(1822),
    [anon_sym_module] = ACTIONS(1822),
    [anon_sym_any] = ACTIONS(1822),
    [anon_sym_number] = ACTIONS(1822),
    [anon_sym_boolean] = ACTIONS(1822),
    [anon_sym_string] = ACTIONS(1822),
    [anon_sym_symbol] = ACTIONS(1822),
    [anon_sym_object] = ACTIONS(1822),
    [anon_sym_abstract] = ACTIONS(1822),
    [anon_sym_satisfies] = ACTIONS(1824),
    [anon_sym_interface] = ACTIONS(1822),
    [anon_sym_enum] = ACTIONS(1822),
    [sym__automatic_semicolon] = ACTIONS(1828),
    [sym__ternary_qmark] = ACTIONS(1826),
    [sym_html_comment] = ACTIONS(5),
  },
  [228] = {
    [ts_builtin_sym_end] = ACTIONS(1830),
    [sym_identifier] = ACTIONS(1832),
    [anon_sym_export] = ACTIONS(1832),
    [anon_sym_STAR] = ACTIONS(1834),
    [anon_sym_default] = ACTIONS(1832),
    [anon_sym_type] = ACTIONS(1832),
    [anon_sym_as] = ACTIONS(1834),
    [anon_sym_namespace] = ACTIONS(1832),
    [anon_sym_LBRACE] = ACTIONS(1830),
    [anon_sym_COMMA] = ACTIONS(1836),
    [anon_sym_RBRACE] = ACTIONS(1830),
    [anon_sym_typeof] = ACTIONS(1832),
    [anon_sym_import] = ACTIONS(1832),
    [anon_sym_with] = ACTIONS(1832),
    [anon_sym_var] = ACTIONS(1832),
    [anon_sym_let] = ACTIONS(1832),
    [anon_sym_const] = ACTIONS(1832),
    [anon_sym_BANG] = ACTIONS(1832),
    [anon_sym_else] = ACTIONS(1832),
    [anon_sym_if] = ACTIONS(1832),
    [anon_sym_switch] = ACTIONS(1832),
    [anon_sym_for] = ACTIONS(1832),
    [anon_sym_LPAREN] = ACTIONS(1830),
    [anon_sym_SEMI] = ACTIONS(1830),
    [anon_sym_await] = ACTIONS(1832),
    [anon_sym_in] = ACTIONS(1834),
    [anon_sym_while] = ACTIONS(1832),
    [anon_sym_do] = ACTIONS(1832),
    [anon_sym_try] = ACTIONS(1832),
    [anon_sym_break] = ACTIONS(1832),
    [anon_sym_continue] = ACTIONS(1832),
    [anon_sym_debugger] = ACTIONS(1832),
    [anon_sym_return] = ACTIONS(1832),
    [anon_sym_throw] = ACTIONS(1832),
    [anon_sym_case] = ACTIONS(1832),
    [anon_sym_yield] = ACTIONS(1832),
    [anon_sym_LBRACK] = ACTIONS(1830),
    [anon_sym_DOT] = ACTIONS(1834),
    [anon_sym_class] = ACTIONS(1832),
    [anon_sym_async] = ACTIONS(1832),
    [anon_sym_function] = ACTIONS(1832),
    [anon_sym_QMARK_DOT] = ACTIONS(1836),
    [anon_sym_new] = ACTIONS(1832),
    [anon_sym_using] = ACTIONS(1832),
    [anon_sym_AMP_AMP] = ACTIONS(1836),
    [anon_sym_PIPE_PIPE] = ACTIONS(1836),
    [anon_sym_GT_GT] = ACTIONS(1834),
    [anon_sym_GT_GT_GT] = ACTIONS(1836),
    [anon_sym_LT_LT] = ACTIONS(1836),
    [anon_sym_AMP] = ACTIONS(1834),
    [anon_sym_CARET] = ACTIONS(1836),
    [anon_sym_PIPE] = ACTIONS(1834),
    [anon_sym_PLUS] = ACTIONS(1832),
    [anon_sym_DASH] = ACTIONS(1832),
    [anon_sym_SLASH] = ACTIONS(1832),
    [anon_sym_PERCENT] = ACTIONS(1836),
    [anon_sym_STAR_STAR] = ACTIONS(1836),
    [anon_sym_LT] = ACTIONS(1832),
    [anon_sym_LT_EQ] = ACTIONS(1836),
    [anon_sym_EQ_EQ] = ACTIONS(1834),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(1836),
    [anon_sym_BANG_EQ] = ACTIONS(1834),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(1836),
    [anon_sym_GT_EQ] = ACTIONS(1836),
    [anon_sym_GT] = ACTIONS(1834),
    [anon_sym_QMARK_QMARK] = ACTIONS(1836),
    [anon_sym_instanceof] = ACTIONS(1834),
    [anon_sym_TILDE] = ACTIONS(1830),
    [anon_sym_void] = ACTIONS(1832),
    [anon_sym_delete] = ACTIONS(1832),
    [anon_sym_PLUS_PLUS] = ACTIONS(1830),
    [anon_sym_DASH_DASH] = ACTIONS(1830),
    [anon_sym_DQUOTE] = ACTIONS(1830),
    [anon_sym_SQUOTE] = ACTIONS(1830),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1830),
    [sym_number] = ACTIONS(1830),
    [sym_private_property_identifier] = ACTIONS(1830),
    [sym_this] = ACTIONS(1832),
    [sym_super] = ACTIONS(1832),
    [sym_true] = ACTIONS(1832),
    [sym_false] = ACTIONS(1832),
    [sym_null] = ACTIONS(1832),
    [sym_undefined] = ACTIONS(1832),
    [anon_sym_AT] = ACTIONS(1830),
    [anon_sym_static] = ACTIONS(1832),
    [anon_sym_readonly] = ACTIONS(1832),
    [anon_sym_get] = ACTIONS(1832),
    [anon_sym_set] = ACTIONS(1832),
    [anon_sym_declare] = ACTIONS(1832),
    [anon_sym_public] = ACTIONS(1832),
    [anon_sym_private] = ACTIONS(1832),
    [anon_sym_protected] = ACTIONS(1832),
    [anon_sym_override] = ACTIONS(1832),
    [anon_sym_module] = ACTIONS(1832),
    [anon_sym_any] = ACTIONS(1832),
    [anon_sym_number] = ACTIONS(1832),
    [anon_sym_boolean] = ACTIONS(1832),
    [anon_sym_string] = ACTIONS(1832),
    [anon_sym_symbol] = ACTIONS(1832),
    [anon_sym_object] = ACTIONS(1832),
    [anon_sym_abstract] = ACTIONS(1832),
    [anon_sym_satisfies] = ACTIONS(1834),
    [anon_sym_interface] = ACTIONS(1832),
    [anon_sym_enum] = ACTIONS(1832),
    [sym__automatic_semicolon] = ACTIONS(1838),
    [sym__ternary_qmark] = ACTIONS(1836),
    [sym_html_comment] = ACTIONS(5),
  },
  [229] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1322),
    [sym_expression] = STATE(2301),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(4425),
    [sym_assignment_pattern] = STATE(4969),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(4425),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5508),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1396),
    [sym_subscript_expression] = STATE(1396),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3003),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(4425),
    [sym_spread_element] = STATE(4971),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_pattern] = STATE(4406),
    [sym_rest_pattern] = STATE(3684),
    [sym_non_null_expression] = STATE(1396),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(484),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [aux_sym_array_repeat1] = STATE(4975),
    [aux_sym_array_pattern_repeat1] = STATE(4977),
    [sym_identifier] = ACTIONS(1738),
    [anon_sym_export] = ACTIONS(541),
    [anon_sym_type] = ACTIONS(541),
    [anon_sym_namespace] = ACTIONS(545),
    [anon_sym_LBRACE] = ACTIONS(808),
    [anon_sym_COMMA] = ACTIONS(1740),
    [anon_sym_typeof] = ACTIONS(581),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(541),
    [anon_sym_BANG] = ACTIONS(553),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(555),
    [anon_sym_yield] = ACTIONS(557),
    [anon_sym_LBRACK] = ACTIONS(812),
    [anon_sym_RBRACK] = ACTIONS(1840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(563),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1744),
    [anon_sym_using] = ACTIONS(567),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(249),
    [anon_sym_PLUS] = ACTIONS(581),
    [anon_sym_DASH] = ACTIONS(581),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(553),
    [anon_sym_void] = ACTIONS(581),
    [anon_sym_delete] = ACTIONS(581),
    [anon_sym_PLUS_PLUS] = ACTIONS(583),
    [anon_sym_DASH_DASH] = ACTIONS(583),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(585),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1746),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(541),
    [anon_sym_readonly] = ACTIONS(541),
    [anon_sym_get] = ACTIONS(541),
    [anon_sym_set] = ACTIONS(541),
    [anon_sym_declare] = ACTIONS(541),
    [anon_sym_public] = ACTIONS(541),
    [anon_sym_private] = ACTIONS(541),
    [anon_sym_protected] = ACTIONS(541),
    [anon_sym_override] = ACTIONS(541),
    [anon_sym_module] = ACTIONS(541),
    [anon_sym_any] = ACTIONS(541),
    [anon_sym_number] = ACTIONS(541),
    [anon_sym_boolean] = ACTIONS(541),
    [anon_sym_string] = ACTIONS(541),
    [anon_sym_symbol] = ACTIONS(541),
    [anon_sym_object] = ACTIONS(541),
    [sym_html_comment] = ACTIONS(5),
  },
  [230] = {
    [ts_builtin_sym_end] = ACTIONS(1842),
    [sym_identifier] = ACTIONS(1844),
    [anon_sym_export] = ACTIONS(1844),
    [anon_sym_STAR] = ACTIONS(1846),
    [anon_sym_default] = ACTIONS(1844),
    [anon_sym_type] = ACTIONS(1844),
    [anon_sym_as] = ACTIONS(1846),
    [anon_sym_namespace] = ACTIONS(1844),
    [anon_sym_LBRACE] = ACTIONS(1842),
    [anon_sym_COMMA] = ACTIONS(1848),
    [anon_sym_RBRACE] = ACTIONS(1842),
    [anon_sym_typeof] = ACTIONS(1844),
    [anon_sym_import] = ACTIONS(1844),
    [anon_sym_with] = ACTIONS(1844),
    [anon_sym_var] = ACTIONS(1844),
    [anon_sym_let] = ACTIONS(1844),
    [anon_sym_const] = ACTIONS(1844),
    [anon_sym_BANG] = ACTIONS(1844),
    [anon_sym_else] = ACTIONS(1844),
    [anon_sym_if] = ACTIONS(1844),
    [anon_sym_switch] = ACTIONS(1844),
    [anon_sym_for] = ACTIONS(1844),
    [anon_sym_LPAREN] = ACTIONS(1842),
    [anon_sym_SEMI] = ACTIONS(1842),
    [anon_sym_await] = ACTIONS(1844),
    [anon_sym_in] = ACTIONS(1846),
    [anon_sym_while] = ACTIONS(1844),
    [anon_sym_do] = ACTIONS(1844),
    [anon_sym_try] = ACTIONS(1844),
    [anon_sym_break] = ACTIONS(1844),
    [anon_sym_continue] = ACTIONS(1844),
    [anon_sym_debugger] = ACTIONS(1844),
    [anon_sym_return] = ACTIONS(1844),
    [anon_sym_throw] = ACTIONS(1844),
    [anon_sym_case] = ACTIONS(1844),
    [anon_sym_yield] = ACTIONS(1844),
    [anon_sym_LBRACK] = ACTIONS(1842),
    [anon_sym_DOT] = ACTIONS(1846),
    [anon_sym_class] = ACTIONS(1844),
    [anon_sym_async] = ACTIONS(1844),
    [anon_sym_function] = ACTIONS(1844),
    [anon_sym_QMARK_DOT] = ACTIONS(1848),
    [anon_sym_new] = ACTIONS(1844),
    [anon_sym_using] = ACTIONS(1844),
    [anon_sym_AMP_AMP] = ACTIONS(1848),
    [anon_sym_PIPE_PIPE] = ACTIONS(1848),
    [anon_sym_GT_GT] = ACTIONS(1846),
    [anon_sym_GT_GT_GT] = ACTIONS(1848),
    [anon_sym_LT_LT] = ACTIONS(1848),
    [anon_sym_AMP] = ACTIONS(1846),
    [anon_sym_CARET] = ACTIONS(1848),
    [anon_sym_PIPE] = ACTIONS(1846),
    [anon_sym_PLUS] = ACTIONS(1844),
    [anon_sym_DASH] = ACTIONS(1844),
    [anon_sym_SLASH] = ACTIONS(1844),
    [anon_sym_PERCENT] = ACTIONS(1848),
    [anon_sym_STAR_STAR] = ACTIONS(1848),
    [anon_sym_LT] = ACTIONS(1844),
    [anon_sym_LT_EQ] = ACTIONS(1848),
    [anon_sym_EQ_EQ] = ACTIONS(1846),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(1848),
    [anon_sym_BANG_EQ] = ACTIONS(1846),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(1848),
    [anon_sym_GT_EQ] = ACTIONS(1848),
    [anon_sym_GT] = ACTIONS(1846),
    [anon_sym_QMARK_QMARK] = ACTIONS(1848),
    [anon_sym_instanceof] = ACTIONS(1846),
    [anon_sym_TILDE] = ACTIONS(1842),
    [anon_sym_void] = ACTIONS(1844),
    [anon_sym_delete] = ACTIONS(1844),
    [anon_sym_PLUS_PLUS] = ACTIONS(1842),
    [anon_sym_DASH_DASH] = ACTIONS(1842),
    [anon_sym_DQUOTE] = ACTIONS(1842),
    [anon_sym_SQUOTE] = ACTIONS(1842),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1842),
    [sym_number] = ACTIONS(1842),
    [sym_private_property_identifier] = ACTIONS(1842),
    [sym_this] = ACTIONS(1844),
    [sym_super] = ACTIONS(1844),
    [sym_true] = ACTIONS(1844),
    [sym_false] = ACTIONS(1844),
    [sym_null] = ACTIONS(1844),
    [sym_undefined] = ACTIONS(1844),
    [anon_sym_AT] = ACTIONS(1842),
    [anon_sym_static] = ACTIONS(1844),
    [anon_sym_readonly] = ACTIONS(1844),
    [anon_sym_get] = ACTIONS(1844),
    [anon_sym_set] = ACTIONS(1844),
    [anon_sym_declare] = ACTIONS(1844),
    [anon_sym_public] = ACTIONS(1844),
    [anon_sym_private] = ACTIONS(1844),
    [anon_sym_protected] = ACTIONS(1844),
    [anon_sym_override] = ACTIONS(1844),
    [anon_sym_module] = ACTIONS(1844),
    [anon_sym_any] = ACTIONS(1844),
    [anon_sym_number] = ACTIONS(1844),
    [anon_sym_boolean] = ACTIONS(1844),
    [anon_sym_string] = ACTIONS(1844),
    [anon_sym_symbol] = ACTIONS(1844),
    [anon_sym_object] = ACTIONS(1844),
    [anon_sym_abstract] = ACTIONS(1844),
    [anon_sym_satisfies] = ACTIONS(1846),
    [anon_sym_interface] = ACTIONS(1844),
    [anon_sym_enum] = ACTIONS(1844),
    [sym__automatic_semicolon] = ACTIONS(1850),
    [sym__ternary_qmark] = ACTIONS(1848),
    [sym_html_comment] = ACTIONS(5),
  },
  [231] = {
    [ts_builtin_sym_end] = ACTIONS(1852),
    [sym_identifier] = ACTIONS(1854),
    [anon_sym_export] = ACTIONS(1854),
    [anon_sym_STAR] = ACTIONS(1854),
    [anon_sym_default] = ACTIONS(1854),
    [anon_sym_type] = ACTIONS(1854),
    [anon_sym_as] = ACTIONS(1854),
    [anon_sym_namespace] = ACTIONS(1854),
    [anon_sym_LBRACE] = ACTIONS(1852),
    [anon_sym_COMMA] = ACTIONS(1852),
    [anon_sym_RBRACE] = ACTIONS(1852),
    [anon_sym_typeof] = ACTIONS(1854),
    [anon_sym_import] = ACTIONS(1854),
    [anon_sym_with] = ACTIONS(1854),
    [anon_sym_var] = ACTIONS(1854),
    [anon_sym_let] = ACTIONS(1854),
    [anon_sym_const] = ACTIONS(1854),
    [anon_sym_BANG] = ACTIONS(1854),
    [anon_sym_else] = ACTIONS(1854),
    [anon_sym_if] = ACTIONS(1854),
    [anon_sym_switch] = ACTIONS(1854),
    [anon_sym_for] = ACTIONS(1854),
    [anon_sym_LPAREN] = ACTIONS(1852),
    [anon_sym_SEMI] = ACTIONS(1852),
    [anon_sym_await] = ACTIONS(1854),
    [anon_sym_in] = ACTIONS(1854),
    [anon_sym_while] = ACTIONS(1854),
    [anon_sym_do] = ACTIONS(1854),
    [anon_sym_try] = ACTIONS(1854),
    [anon_sym_break] = ACTIONS(1854),
    [anon_sym_continue] = ACTIONS(1854),
    [anon_sym_debugger] = ACTIONS(1854),
    [anon_sym_return] = ACTIONS(1854),
    [anon_sym_throw] = ACTIONS(1854),
    [anon_sym_case] = ACTIONS(1854),
    [anon_sym_yield] = ACTIONS(1854),
    [anon_sym_LBRACK] = ACTIONS(1852),
    [anon_sym_DOT] = ACTIONS(1854),
    [anon_sym_class] = ACTIONS(1854),
    [anon_sym_async] = ACTIONS(1854),
    [anon_sym_function] = ACTIONS(1854),
    [anon_sym_QMARK_DOT] = ACTIONS(1852),
    [anon_sym_new] = ACTIONS(1854),
    [anon_sym_using] = ACTIONS(1854),
    [anon_sym_AMP_AMP] = ACTIONS(1852),
    [anon_sym_PIPE_PIPE] = ACTIONS(1852),
    [anon_sym_GT_GT] = ACTIONS(1854),
    [anon_sym_GT_GT_GT] = ACTIONS(1852),
    [anon_sym_LT_LT] = ACTIONS(1852),
    [anon_sym_AMP] = ACTIONS(1854),
    [anon_sym_CARET] = ACTIONS(1852),
    [anon_sym_PIPE] = ACTIONS(1854),
    [anon_sym_PLUS] = ACTIONS(1854),
    [anon_sym_DASH] = ACTIONS(1854),
    [anon_sym_SLASH] = ACTIONS(1854),
    [anon_sym_PERCENT] = ACTIONS(1852),
    [anon_sym_STAR_STAR] = ACTIONS(1852),
    [anon_sym_LT] = ACTIONS(1854),
    [anon_sym_LT_EQ] = ACTIONS(1852),
    [anon_sym_EQ_EQ] = ACTIONS(1854),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(1852),
    [anon_sym_BANG_EQ] = ACTIONS(1854),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(1852),
    [anon_sym_GT_EQ] = ACTIONS(1852),
    [anon_sym_GT] = ACTIONS(1854),
    [anon_sym_QMARK_QMARK] = ACTIONS(1852),
    [anon_sym_instanceof] = ACTIONS(1854),
    [anon_sym_TILDE] = ACTIONS(1852),
    [anon_sym_void] = ACTIONS(1854),
    [anon_sym_delete] = ACTIONS(1854),
    [anon_sym_PLUS_PLUS] = ACTIONS(1852),
    [anon_sym_DASH_DASH] = ACTIONS(1852),
    [anon_sym_DQUOTE] = ACTIONS(1852),
    [anon_sym_SQUOTE] = ACTIONS(1852),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1852),
    [sym_number] = ACTIONS(1852),
    [sym_private_property_identifier] = ACTIONS(1852),
    [sym_this] = ACTIONS(1854),
    [sym_super] = ACTIONS(1854),
    [sym_true] = ACTIONS(1854),
    [sym_false] = ACTIONS(1854),
    [sym_null] = ACTIONS(1854),
    [sym_undefined] = ACTIONS(1854),
    [anon_sym_AT] = ACTIONS(1852),
    [anon_sym_static] = ACTIONS(1854),
    [anon_sym_readonly] = ACTIONS(1854),
    [anon_sym_get] = ACTIONS(1854),
    [anon_sym_set] = ACTIONS(1854),
    [anon_sym_declare] = ACTIONS(1854),
    [anon_sym_public] = ACTIONS(1854),
    [anon_sym_private] = ACTIONS(1854),
    [anon_sym_protected] = ACTIONS(1854),
    [anon_sym_override] = ACTIONS(1854),
    [anon_sym_module] = ACTIONS(1854),
    [anon_sym_any] = ACTIONS(1854),
    [anon_sym_number] = ACTIONS(1854),
    [anon_sym_boolean] = ACTIONS(1854),
    [anon_sym_string] = ACTIONS(1854),
    [anon_sym_symbol] = ACTIONS(1854),
    [anon_sym_object] = ACTIONS(1854),
    [anon_sym_abstract] = ACTIONS(1854),
    [anon_sym_satisfies] = ACTIONS(1854),
    [anon_sym_interface] = ACTIONS(1854),
    [anon_sym_enum] = ACTIONS(1854),
    [sym__automatic_semicolon] = ACTIONS(1852),
    [sym__ternary_qmark] = ACTIONS(1852),
    [sym_html_comment] = ACTIONS(5),
  },
  [232] = {
    [ts_builtin_sym_end] = ACTIONS(1856),
    [sym_identifier] = ACTIONS(1858),
    [anon_sym_export] = ACTIONS(1858),
    [anon_sym_STAR] = ACTIONS(1860),
    [anon_sym_default] = ACTIONS(1858),
    [anon_sym_type] = ACTIONS(1858),
    [anon_sym_as] = ACTIONS(1860),
    [anon_sym_namespace] = ACTIONS(1858),
    [anon_sym_LBRACE] = ACTIONS(1856),
    [anon_sym_COMMA] = ACTIONS(1862),
    [anon_sym_RBRACE] = ACTIONS(1856),
    [anon_sym_typeof] = ACTIONS(1858),
    [anon_sym_import] = ACTIONS(1858),
    [anon_sym_with] = ACTIONS(1858),
    [anon_sym_var] = ACTIONS(1858),
    [anon_sym_let] = ACTIONS(1858),
    [anon_sym_const] = ACTIONS(1858),
    [anon_sym_BANG] = ACTIONS(1858),
    [anon_sym_else] = ACTIONS(1858),
    [anon_sym_if] = ACTIONS(1858),
    [anon_sym_switch] = ACTIONS(1858),
    [anon_sym_for] = ACTIONS(1858),
    [anon_sym_LPAREN] = ACTIONS(1856),
    [anon_sym_SEMI] = ACTIONS(1856),
    [anon_sym_await] = ACTIONS(1858),
    [anon_sym_in] = ACTIONS(1860),
    [anon_sym_while] = ACTIONS(1858),
    [anon_sym_do] = ACTIONS(1858),
    [anon_sym_try] = ACTIONS(1858),
    [anon_sym_break] = ACTIONS(1858),
    [anon_sym_continue] = ACTIONS(1858),
    [anon_sym_debugger] = ACTIONS(1858),
    [anon_sym_return] = ACTIONS(1858),
    [anon_sym_throw] = ACTIONS(1858),
    [anon_sym_case] = ACTIONS(1858),
    [anon_sym_yield] = ACTIONS(1858),
    [anon_sym_LBRACK] = ACTIONS(1856),
    [anon_sym_DOT] = ACTIONS(1860),
    [anon_sym_class] = ACTIONS(1858),
    [anon_sym_async] = ACTIONS(1858),
    [anon_sym_function] = ACTIONS(1858),
    [anon_sym_QMARK_DOT] = ACTIONS(1862),
    [anon_sym_new] = ACTIONS(1858),
    [anon_sym_using] = ACTIONS(1858),
    [anon_sym_AMP_AMP] = ACTIONS(1862),
    [anon_sym_PIPE_PIPE] = ACTIONS(1862),
    [anon_sym_GT_GT] = ACTIONS(1860),
    [anon_sym_GT_GT_GT] = ACTIONS(1862),
    [anon_sym_LT_LT] = ACTIONS(1862),
    [anon_sym_AMP] = ACTIONS(1860),
    [anon_sym_CARET] = ACTIONS(1862),
    [anon_sym_PIPE] = ACTIONS(1860),
    [anon_sym_PLUS] = ACTIONS(1858),
    [anon_sym_DASH] = ACTIONS(1858),
    [anon_sym_SLASH] = ACTIONS(1858),
    [anon_sym_PERCENT] = ACTIONS(1862),
    [anon_sym_STAR_STAR] = ACTIONS(1862),
    [anon_sym_LT] = ACTIONS(1858),
    [anon_sym_LT_EQ] = ACTIONS(1862),
    [anon_sym_EQ_EQ] = ACTIONS(1860),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(1862),
    [anon_sym_BANG_EQ] = ACTIONS(1860),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(1862),
    [anon_sym_GT_EQ] = ACTIONS(1862),
    [anon_sym_GT] = ACTIONS(1860),
    [anon_sym_QMARK_QMARK] = ACTIONS(1862),
    [anon_sym_instanceof] = ACTIONS(1860),
    [anon_sym_TILDE] = ACTIONS(1856),
    [anon_sym_void] = ACTIONS(1858),
    [anon_sym_delete] = ACTIONS(1858),
    [anon_sym_PLUS_PLUS] = ACTIONS(1856),
    [anon_sym_DASH_DASH] = ACTIONS(1856),
    [anon_sym_DQUOTE] = ACTIONS(1856),
    [anon_sym_SQUOTE] = ACTIONS(1856),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1856),
    [sym_number] = ACTIONS(1856),
    [sym_private_property_identifier] = ACTIONS(1856),
    [sym_this] = ACTIONS(1858),
    [sym_super] = ACTIONS(1858),
    [sym_true] = ACTIONS(1858),
    [sym_false] = ACTIONS(1858),
    [sym_null] = ACTIONS(1858),
    [sym_undefined] = ACTIONS(1858),
    [anon_sym_AT] = ACTIONS(1856),
    [anon_sym_static] = ACTIONS(1858),
    [anon_sym_readonly] = ACTIONS(1858),
    [anon_sym_get] = ACTIONS(1858),
    [anon_sym_set] = ACTIONS(1858),
    [anon_sym_declare] = ACTIONS(1858),
    [anon_sym_public] = ACTIONS(1858),
    [anon_sym_private] = ACTIONS(1858),
    [anon_sym_protected] = ACTIONS(1858),
    [anon_sym_override] = ACTIONS(1858),
    [anon_sym_module] = ACTIONS(1858),
    [anon_sym_any] = ACTIONS(1858),
    [anon_sym_number] = ACTIONS(1858),
    [anon_sym_boolean] = ACTIONS(1858),
    [anon_sym_string] = ACTIONS(1858),
    [anon_sym_symbol] = ACTIONS(1858),
    [anon_sym_object] = ACTIONS(1858),
    [anon_sym_abstract] = ACTIONS(1858),
    [anon_sym_satisfies] = ACTIONS(1860),
    [anon_sym_interface] = ACTIONS(1858),
    [anon_sym_enum] = ACTIONS(1858),
    [sym__automatic_semicolon] = ACTIONS(1864),
    [sym__ternary_qmark] = ACTIONS(1862),
    [sym_html_comment] = ACTIONS(5),
  },
  [233] = {
    [ts_builtin_sym_end] = ACTIONS(1866),
    [sym_identifier] = ACTIONS(1868),
    [anon_sym_export] = ACTIONS(1868),
    [anon_sym_STAR] = ACTIONS(1870),
    [anon_sym_default] = ACTIONS(1868),
    [anon_sym_type] = ACTIONS(1868),
    [anon_sym_as] = ACTIONS(1870),
    [anon_sym_namespace] = ACTIONS(1868),
    [anon_sym_LBRACE] = ACTIONS(1866),
    [anon_sym_COMMA] = ACTIONS(1872),
    [anon_sym_RBRACE] = ACTIONS(1866),
    [anon_sym_typeof] = ACTIONS(1868),
    [anon_sym_import] = ACTIONS(1868),
    [anon_sym_with] = ACTIONS(1868),
    [anon_sym_var] = ACTIONS(1868),
    [anon_sym_let] = ACTIONS(1868),
    [anon_sym_const] = ACTIONS(1868),
    [anon_sym_BANG] = ACTIONS(1868),
    [anon_sym_else] = ACTIONS(1868),
    [anon_sym_if] = ACTIONS(1868),
    [anon_sym_switch] = ACTIONS(1868),
    [anon_sym_for] = ACTIONS(1868),
    [anon_sym_LPAREN] = ACTIONS(1866),
    [anon_sym_SEMI] = ACTIONS(1866),
    [anon_sym_await] = ACTIONS(1868),
    [anon_sym_in] = ACTIONS(1870),
    [anon_sym_while] = ACTIONS(1868),
    [anon_sym_do] = ACTIONS(1868),
    [anon_sym_try] = ACTIONS(1868),
    [anon_sym_break] = ACTIONS(1868),
    [anon_sym_continue] = ACTIONS(1868),
    [anon_sym_debugger] = ACTIONS(1868),
    [anon_sym_return] = ACTIONS(1868),
    [anon_sym_throw] = ACTIONS(1868),
    [anon_sym_case] = ACTIONS(1868),
    [anon_sym_yield] = ACTIONS(1868),
    [anon_sym_LBRACK] = ACTIONS(1866),
    [anon_sym_DOT] = ACTIONS(1870),
    [anon_sym_class] = ACTIONS(1868),
    [anon_sym_async] = ACTIONS(1868),
    [anon_sym_function] = ACTIONS(1868),
    [anon_sym_QMARK_DOT] = ACTIONS(1872),
    [anon_sym_new] = ACTIONS(1868),
    [anon_sym_using] = ACTIONS(1868),
    [anon_sym_AMP_AMP] = ACTIONS(1872),
    [anon_sym_PIPE_PIPE] = ACTIONS(1872),
    [anon_sym_GT_GT] = ACTIONS(1870),
    [anon_sym_GT_GT_GT] = ACTIONS(1872),
    [anon_sym_LT_LT] = ACTIONS(1872),
    [anon_sym_AMP] = ACTIONS(1870),
    [anon_sym_CARET] = ACTIONS(1872),
    [anon_sym_PIPE] = ACTIONS(1870),
    [anon_sym_PLUS] = ACTIONS(1868),
    [anon_sym_DASH] = ACTIONS(1868),
    [anon_sym_SLASH] = ACTIONS(1868),
    [anon_sym_PERCENT] = ACTIONS(1872),
    [anon_sym_STAR_STAR] = ACTIONS(1872),
    [anon_sym_LT] = ACTIONS(1868),
    [anon_sym_LT_EQ] = ACTIONS(1872),
    [anon_sym_EQ_EQ] = ACTIONS(1870),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(1872),
    [anon_sym_BANG_EQ] = ACTIONS(1870),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(1872),
    [anon_sym_GT_EQ] = ACTIONS(1872),
    [anon_sym_GT] = ACTIONS(1870),
    [anon_sym_QMARK_QMARK] = ACTIONS(1872),
    [anon_sym_instanceof] = ACTIONS(1870),
    [anon_sym_TILDE] = ACTIONS(1866),
    [anon_sym_void] = ACTIONS(1868),
    [anon_sym_delete] = ACTIONS(1868),
    [anon_sym_PLUS_PLUS] = ACTIONS(1866),
    [anon_sym_DASH_DASH] = ACTIONS(1866),
    [anon_sym_DQUOTE] = ACTIONS(1866),
    [anon_sym_SQUOTE] = ACTIONS(1866),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1866),
    [sym_number] = ACTIONS(1866),
    [sym_private_property_identifier] = ACTIONS(1866),
    [sym_this] = ACTIONS(1868),
    [sym_super] = ACTIONS(1868),
    [sym_true] = ACTIONS(1868),
    [sym_false] = ACTIONS(1868),
    [sym_null] = ACTIONS(1868),
    [sym_undefined] = ACTIONS(1868),
    [anon_sym_AT] = ACTIONS(1866),
    [anon_sym_static] = ACTIONS(1868),
    [anon_sym_readonly] = ACTIONS(1868),
    [anon_sym_get] = ACTIONS(1868),
    [anon_sym_set] = ACTIONS(1868),
    [anon_sym_declare] = ACTIONS(1868),
    [anon_sym_public] = ACTIONS(1868),
    [anon_sym_private] = ACTIONS(1868),
    [anon_sym_protected] = ACTIONS(1868),
    [anon_sym_override] = ACTIONS(1868),
    [anon_sym_module] = ACTIONS(1868),
    [anon_sym_any] = ACTIONS(1868),
    [anon_sym_number] = ACTIONS(1868),
    [anon_sym_boolean] = ACTIONS(1868),
    [anon_sym_string] = ACTIONS(1868),
    [anon_sym_symbol] = ACTIONS(1868),
    [anon_sym_object] = ACTIONS(1868),
    [anon_sym_abstract] = ACTIONS(1868),
    [anon_sym_satisfies] = ACTIONS(1870),
    [anon_sym_interface] = ACTIONS(1868),
    [anon_sym_enum] = ACTIONS(1868),
    [sym__automatic_semicolon] = ACTIONS(1874),
    [sym__ternary_qmark] = ACTIONS(1872),
    [sym_html_comment] = ACTIONS(5),
  },
  [234] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1322),
    [sym_expression] = STATE(2126),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(4425),
    [sym_assignment_pattern] = STATE(4969),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(4425),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5508),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1396),
    [sym_subscript_expression] = STATE(1396),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3003),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(4425),
    [sym_spread_element] = STATE(4946),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_pattern] = STATE(4406),
    [sym_rest_pattern] = STATE(3684),
    [sym_non_null_expression] = STATE(1396),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(484),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [aux_sym_array_repeat1] = STATE(4955),
    [aux_sym_array_pattern_repeat1] = STATE(4977),
    [sym_identifier] = ACTIONS(1738),
    [anon_sym_export] = ACTIONS(541),
    [anon_sym_type] = ACTIONS(541),
    [anon_sym_namespace] = ACTIONS(545),
    [anon_sym_LBRACE] = ACTIONS(808),
    [anon_sym_COMMA] = ACTIONS(1740),
    [anon_sym_typeof] = ACTIONS(581),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(541),
    [anon_sym_BANG] = ACTIONS(553),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(555),
    [anon_sym_yield] = ACTIONS(557),
    [anon_sym_LBRACK] = ACTIONS(812),
    [anon_sym_RBRACK] = ACTIONS(1876),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(563),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1744),
    [anon_sym_using] = ACTIONS(567),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(249),
    [anon_sym_PLUS] = ACTIONS(581),
    [anon_sym_DASH] = ACTIONS(581),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(553),
    [anon_sym_void] = ACTIONS(581),
    [anon_sym_delete] = ACTIONS(581),
    [anon_sym_PLUS_PLUS] = ACTIONS(583),
    [anon_sym_DASH_DASH] = ACTIONS(583),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(585),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1746),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(541),
    [anon_sym_readonly] = ACTIONS(541),
    [anon_sym_get] = ACTIONS(541),
    [anon_sym_set] = ACTIONS(541),
    [anon_sym_declare] = ACTIONS(541),
    [anon_sym_public] = ACTIONS(541),
    [anon_sym_private] = ACTIONS(541),
    [anon_sym_protected] = ACTIONS(541),
    [anon_sym_override] = ACTIONS(541),
    [anon_sym_module] = ACTIONS(541),
    [anon_sym_any] = ACTIONS(541),
    [anon_sym_number] = ACTIONS(541),
    [anon_sym_boolean] = ACTIONS(541),
    [anon_sym_string] = ACTIONS(541),
    [anon_sym_symbol] = ACTIONS(541),
    [anon_sym_object] = ACTIONS(541),
    [sym_html_comment] = ACTIONS(5),
  },
  [235] = {
    [ts_builtin_sym_end] = ACTIONS(1878),
    [sym_identifier] = ACTIONS(1880),
    [anon_sym_export] = ACTIONS(1880),
    [anon_sym_STAR] = ACTIONS(1880),
    [anon_sym_default] = ACTIONS(1880),
    [anon_sym_type] = ACTIONS(1880),
    [anon_sym_as] = ACTIONS(1880),
    [anon_sym_namespace] = ACTIONS(1880),
    [anon_sym_LBRACE] = ACTIONS(1878),
    [anon_sym_COMMA] = ACTIONS(1878),
    [anon_sym_RBRACE] = ACTIONS(1878),
    [anon_sym_typeof] = ACTIONS(1880),
    [anon_sym_import] = ACTIONS(1880),
    [anon_sym_with] = ACTIONS(1880),
    [anon_sym_var] = ACTIONS(1880),
    [anon_sym_let] = ACTIONS(1880),
    [anon_sym_const] = ACTIONS(1880),
    [anon_sym_BANG] = ACTIONS(1880),
    [anon_sym_else] = ACTIONS(1880),
    [anon_sym_if] = ACTIONS(1880),
    [anon_sym_switch] = ACTIONS(1880),
    [anon_sym_for] = ACTIONS(1880),
    [anon_sym_LPAREN] = ACTIONS(1878),
    [anon_sym_SEMI] = ACTIONS(1878),
    [anon_sym_await] = ACTIONS(1880),
    [anon_sym_in] = ACTIONS(1880),
    [anon_sym_while] = ACTIONS(1880),
    [anon_sym_do] = ACTIONS(1880),
    [anon_sym_try] = ACTIONS(1880),
    [anon_sym_break] = ACTIONS(1880),
    [anon_sym_continue] = ACTIONS(1880),
    [anon_sym_debugger] = ACTIONS(1880),
    [anon_sym_return] = ACTIONS(1880),
    [anon_sym_throw] = ACTIONS(1880),
    [anon_sym_case] = ACTIONS(1880),
    [anon_sym_yield] = ACTIONS(1880),
    [anon_sym_LBRACK] = ACTIONS(1878),
    [anon_sym_DOT] = ACTIONS(1880),
    [anon_sym_class] = ACTIONS(1880),
    [anon_sym_async] = ACTIONS(1880),
    [anon_sym_function] = ACTIONS(1880),
    [anon_sym_QMARK_DOT] = ACTIONS(1878),
    [anon_sym_new] = ACTIONS(1880),
    [anon_sym_using] = ACTIONS(1880),
    [anon_sym_AMP_AMP] = ACTIONS(1878),
    [anon_sym_PIPE_PIPE] = ACTIONS(1878),
    [anon_sym_GT_GT] = ACTIONS(1880),
    [anon_sym_GT_GT_GT] = ACTIONS(1878),
    [anon_sym_LT_LT] = ACTIONS(1878),
    [anon_sym_AMP] = ACTIONS(1880),
    [anon_sym_CARET] = ACTIONS(1878),
    [anon_sym_PIPE] = ACTIONS(1880),
    [anon_sym_PLUS] = ACTIONS(1880),
    [anon_sym_DASH] = ACTIONS(1880),
    [anon_sym_SLASH] = ACTIONS(1880),
    [anon_sym_PERCENT] = ACTIONS(1878),
    [anon_sym_STAR_STAR] = ACTIONS(1878),
    [anon_sym_LT] = ACTIONS(1880),
    [anon_sym_LT_EQ] = ACTIONS(1878),
    [anon_sym_EQ_EQ] = ACTIONS(1880),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(1878),
    [anon_sym_BANG_EQ] = ACTIONS(1880),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(1878),
    [anon_sym_GT_EQ] = ACTIONS(1878),
    [anon_sym_GT] = ACTIONS(1880),
    [anon_sym_QMARK_QMARK] = ACTIONS(1878),
    [anon_sym_instanceof] = ACTIONS(1880),
    [anon_sym_TILDE] = ACTIONS(1878),
    [anon_sym_void] = ACTIONS(1880),
    [anon_sym_delete] = ACTIONS(1880),
    [anon_sym_PLUS_PLUS] = ACTIONS(1878),
    [anon_sym_DASH_DASH] = ACTIONS(1878),
    [anon_sym_DQUOTE] = ACTIONS(1878),
    [anon_sym_SQUOTE] = ACTIONS(1878),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1878),
    [sym_number] = ACTIONS(1878),
    [sym_private_property_identifier] = ACTIONS(1878),
    [sym_this] = ACTIONS(1880),
    [sym_super] = ACTIONS(1880),
    [sym_true] = ACTIONS(1880),
    [sym_false] = ACTIONS(1880),
    [sym_null] = ACTIONS(1880),
    [sym_undefined] = ACTIONS(1880),
    [anon_sym_AT] = ACTIONS(1878),
    [anon_sym_static] = ACTIONS(1880),
    [anon_sym_readonly] = ACTIONS(1880),
    [anon_sym_get] = ACTIONS(1880),
    [anon_sym_set] = ACTIONS(1880),
    [anon_sym_declare] = ACTIONS(1880),
    [anon_sym_public] = ACTIONS(1880),
    [anon_sym_private] = ACTIONS(1880),
    [anon_sym_protected] = ACTIONS(1880),
    [anon_sym_override] = ACTIONS(1880),
    [anon_sym_module] = ACTIONS(1880),
    [anon_sym_any] = ACTIONS(1880),
    [anon_sym_number] = ACTIONS(1880),
    [anon_sym_boolean] = ACTIONS(1880),
    [anon_sym_string] = ACTIONS(1880),
    [anon_sym_symbol] = ACTIONS(1880),
    [anon_sym_object] = ACTIONS(1880),
    [anon_sym_abstract] = ACTIONS(1880),
    [anon_sym_satisfies] = ACTIONS(1880),
    [anon_sym_interface] = ACTIONS(1880),
    [anon_sym_enum] = ACTIONS(1880),
    [sym__automatic_semicolon] = ACTIONS(1878),
    [sym__ternary_qmark] = ACTIONS(1878),
    [sym_html_comment] = ACTIONS(5),
  },
  [236] = {
    [ts_builtin_sym_end] = ACTIONS(1878),
    [sym_identifier] = ACTIONS(1880),
    [anon_sym_export] = ACTIONS(1880),
    [anon_sym_STAR] = ACTIONS(1880),
    [anon_sym_default] = ACTIONS(1880),
    [anon_sym_type] = ACTIONS(1880),
    [anon_sym_as] = ACTIONS(1880),
    [anon_sym_namespace] = ACTIONS(1880),
    [anon_sym_LBRACE] = ACTIONS(1878),
    [anon_sym_COMMA] = ACTIONS(1878),
    [anon_sym_RBRACE] = ACTIONS(1878),
    [anon_sym_typeof] = ACTIONS(1880),
    [anon_sym_import] = ACTIONS(1880),
    [anon_sym_with] = ACTIONS(1880),
    [anon_sym_var] = ACTIONS(1880),
    [anon_sym_let] = ACTIONS(1880),
    [anon_sym_const] = ACTIONS(1880),
    [anon_sym_BANG] = ACTIONS(1880),
    [anon_sym_else] = ACTIONS(1880),
    [anon_sym_if] = ACTIONS(1880),
    [anon_sym_switch] = ACTIONS(1880),
    [anon_sym_for] = ACTIONS(1880),
    [anon_sym_LPAREN] = ACTIONS(1878),
    [anon_sym_SEMI] = ACTIONS(1878),
    [anon_sym_await] = ACTIONS(1880),
    [anon_sym_in] = ACTIONS(1880),
    [anon_sym_while] = ACTIONS(1880),
    [anon_sym_do] = ACTIONS(1880),
    [anon_sym_try] = ACTIONS(1880),
    [anon_sym_break] = ACTIONS(1880),
    [anon_sym_continue] = ACTIONS(1880),
    [anon_sym_debugger] = ACTIONS(1880),
    [anon_sym_return] = ACTIONS(1880),
    [anon_sym_throw] = ACTIONS(1880),
    [anon_sym_case] = ACTIONS(1880),
    [anon_sym_yield] = ACTIONS(1880),
    [anon_sym_LBRACK] = ACTIONS(1878),
    [anon_sym_DOT] = ACTIONS(1880),
    [anon_sym_class] = ACTIONS(1880),
    [anon_sym_async] = ACTIONS(1880),
    [anon_sym_function] = ACTIONS(1880),
    [anon_sym_QMARK_DOT] = ACTIONS(1878),
    [anon_sym_new] = ACTIONS(1880),
    [anon_sym_using] = ACTIONS(1880),
    [anon_sym_AMP_AMP] = ACTIONS(1878),
    [anon_sym_PIPE_PIPE] = ACTIONS(1878),
    [anon_sym_GT_GT] = ACTIONS(1880),
    [anon_sym_GT_GT_GT] = ACTIONS(1878),
    [anon_sym_LT_LT] = ACTIONS(1878),
    [anon_sym_AMP] = ACTIONS(1880),
    [anon_sym_CARET] = ACTIONS(1878),
    [anon_sym_PIPE] = ACTIONS(1880),
    [anon_sym_PLUS] = ACTIONS(1880),
    [anon_sym_DASH] = ACTIONS(1880),
    [anon_sym_SLASH] = ACTIONS(1880),
    [anon_sym_PERCENT] = ACTIONS(1878),
    [anon_sym_STAR_STAR] = ACTIONS(1878),
    [anon_sym_LT] = ACTIONS(1880),
    [anon_sym_LT_EQ] = ACTIONS(1878),
    [anon_sym_EQ_EQ] = ACTIONS(1880),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(1878),
    [anon_sym_BANG_EQ] = ACTIONS(1880),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(1878),
    [anon_sym_GT_EQ] = ACTIONS(1878),
    [anon_sym_GT] = ACTIONS(1880),
    [anon_sym_QMARK_QMARK] = ACTIONS(1878),
    [anon_sym_instanceof] = ACTIONS(1880),
    [anon_sym_TILDE] = ACTIONS(1878),
    [anon_sym_void] = ACTIONS(1880),
    [anon_sym_delete] = ACTIONS(1880),
    [anon_sym_PLUS_PLUS] = ACTIONS(1878),
    [anon_sym_DASH_DASH] = ACTIONS(1878),
    [anon_sym_DQUOTE] = ACTIONS(1878),
    [anon_sym_SQUOTE] = ACTIONS(1878),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1878),
    [sym_number] = ACTIONS(1878),
    [sym_private_property_identifier] = ACTIONS(1878),
    [sym_this] = ACTIONS(1880),
    [sym_super] = ACTIONS(1880),
    [sym_true] = ACTIONS(1880),
    [sym_false] = ACTIONS(1880),
    [sym_null] = ACTIONS(1880),
    [sym_undefined] = ACTIONS(1880),
    [anon_sym_AT] = ACTIONS(1878),
    [anon_sym_static] = ACTIONS(1880),
    [anon_sym_readonly] = ACTIONS(1880),
    [anon_sym_get] = ACTIONS(1880),
    [anon_sym_set] = ACTIONS(1880),
    [anon_sym_declare] = ACTIONS(1880),
    [anon_sym_public] = ACTIONS(1880),
    [anon_sym_private] = ACTIONS(1880),
    [anon_sym_protected] = ACTIONS(1880),
    [anon_sym_override] = ACTIONS(1880),
    [anon_sym_module] = ACTIONS(1880),
    [anon_sym_any] = ACTIONS(1880),
    [anon_sym_number] = ACTIONS(1880),
    [anon_sym_boolean] = ACTIONS(1880),
    [anon_sym_string] = ACTIONS(1880),
    [anon_sym_symbol] = ACTIONS(1880),
    [anon_sym_object] = ACTIONS(1880),
    [anon_sym_abstract] = ACTIONS(1880),
    [anon_sym_satisfies] = ACTIONS(1880),
    [anon_sym_interface] = ACTIONS(1880),
    [anon_sym_enum] = ACTIONS(1880),
    [sym__automatic_semicolon] = ACTIONS(1882),
    [sym__ternary_qmark] = ACTIONS(1878),
    [sym_html_comment] = ACTIONS(5),
  },
  [237] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1322),
    [sym_expression] = STATE(2305),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(4425),
    [sym_assignment_pattern] = STATE(4969),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(4425),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5508),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1396),
    [sym_subscript_expression] = STATE(1396),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3003),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(4425),
    [sym_spread_element] = STATE(4971),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_pattern] = STATE(4406),
    [sym_rest_pattern] = STATE(3684),
    [sym_non_null_expression] = STATE(1396),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(484),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [aux_sym_array_repeat1] = STATE(4975),
    [aux_sym_array_pattern_repeat1] = STATE(4977),
    [sym_identifier] = ACTIONS(1738),
    [anon_sym_export] = ACTIONS(541),
    [anon_sym_type] = ACTIONS(541),
    [anon_sym_namespace] = ACTIONS(545),
    [anon_sym_LBRACE] = ACTIONS(808),
    [anon_sym_COMMA] = ACTIONS(1740),
    [anon_sym_typeof] = ACTIONS(581),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(541),
    [anon_sym_BANG] = ACTIONS(553),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(555),
    [anon_sym_yield] = ACTIONS(557),
    [anon_sym_LBRACK] = ACTIONS(812),
    [anon_sym_RBRACK] = ACTIONS(1840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(563),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1744),
    [anon_sym_using] = ACTIONS(567),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(249),
    [anon_sym_PLUS] = ACTIONS(581),
    [anon_sym_DASH] = ACTIONS(581),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(553),
    [anon_sym_void] = ACTIONS(581),
    [anon_sym_delete] = ACTIONS(581),
    [anon_sym_PLUS_PLUS] = ACTIONS(583),
    [anon_sym_DASH_DASH] = ACTIONS(583),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(585),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1746),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(541),
    [anon_sym_readonly] = ACTIONS(541),
    [anon_sym_get] = ACTIONS(541),
    [anon_sym_set] = ACTIONS(541),
    [anon_sym_declare] = ACTIONS(541),
    [anon_sym_public] = ACTIONS(541),
    [anon_sym_private] = ACTIONS(541),
    [anon_sym_protected] = ACTIONS(541),
    [anon_sym_override] = ACTIONS(541),
    [anon_sym_module] = ACTIONS(541),
    [anon_sym_any] = ACTIONS(541),
    [anon_sym_number] = ACTIONS(541),
    [anon_sym_boolean] = ACTIONS(541),
    [anon_sym_string] = ACTIONS(541),
    [anon_sym_symbol] = ACTIONS(541),
    [anon_sym_object] = ACTIONS(541),
    [sym_html_comment] = ACTIONS(5),
  },
  [238] = {
    [ts_builtin_sym_end] = ACTIONS(1884),
    [sym_identifier] = ACTIONS(1886),
    [anon_sym_export] = ACTIONS(1886),
    [anon_sym_STAR] = ACTIONS(1886),
    [anon_sym_default] = ACTIONS(1886),
    [anon_sym_type] = ACTIONS(1886),
    [anon_sym_as] = ACTIONS(1886),
    [anon_sym_namespace] = ACTIONS(1886),
    [anon_sym_LBRACE] = ACTIONS(1884),
    [anon_sym_COMMA] = ACTIONS(1884),
    [anon_sym_RBRACE] = ACTIONS(1884),
    [anon_sym_typeof] = ACTIONS(1886),
    [anon_sym_import] = ACTIONS(1886),
    [anon_sym_with] = ACTIONS(1886),
    [anon_sym_var] = ACTIONS(1886),
    [anon_sym_let] = ACTIONS(1886),
    [anon_sym_const] = ACTIONS(1886),
    [anon_sym_BANG] = ACTIONS(1886),
    [anon_sym_else] = ACTIONS(1886),
    [anon_sym_if] = ACTIONS(1886),
    [anon_sym_switch] = ACTIONS(1886),
    [anon_sym_for] = ACTIONS(1886),
    [anon_sym_LPAREN] = ACTIONS(1884),
    [anon_sym_SEMI] = ACTIONS(1884),
    [anon_sym_await] = ACTIONS(1886),
    [anon_sym_in] = ACTIONS(1886),
    [anon_sym_while] = ACTIONS(1886),
    [anon_sym_do] = ACTIONS(1886),
    [anon_sym_try] = ACTIONS(1886),
    [anon_sym_break] = ACTIONS(1886),
    [anon_sym_continue] = ACTIONS(1886),
    [anon_sym_debugger] = ACTIONS(1886),
    [anon_sym_return] = ACTIONS(1886),
    [anon_sym_throw] = ACTIONS(1886),
    [anon_sym_case] = ACTIONS(1886),
    [anon_sym_yield] = ACTIONS(1886),
    [anon_sym_LBRACK] = ACTIONS(1884),
    [anon_sym_DOT] = ACTIONS(1886),
    [anon_sym_class] = ACTIONS(1886),
    [anon_sym_async] = ACTIONS(1886),
    [anon_sym_function] = ACTIONS(1886),
    [anon_sym_QMARK_DOT] = ACTIONS(1884),
    [anon_sym_new] = ACTIONS(1886),
    [anon_sym_using] = ACTIONS(1886),
    [anon_sym_AMP_AMP] = ACTIONS(1884),
    [anon_sym_PIPE_PIPE] = ACTIONS(1884),
    [anon_sym_GT_GT] = ACTIONS(1886),
    [anon_sym_GT_GT_GT] = ACTIONS(1884),
    [anon_sym_LT_LT] = ACTIONS(1884),
    [anon_sym_AMP] = ACTIONS(1886),
    [anon_sym_CARET] = ACTIONS(1884),
    [anon_sym_PIPE] = ACTIONS(1886),
    [anon_sym_PLUS] = ACTIONS(1886),
    [anon_sym_DASH] = ACTIONS(1886),
    [anon_sym_SLASH] = ACTIONS(1886),
    [anon_sym_PERCENT] = ACTIONS(1884),
    [anon_sym_STAR_STAR] = ACTIONS(1884),
    [anon_sym_LT] = ACTIONS(1886),
    [anon_sym_LT_EQ] = ACTIONS(1884),
    [anon_sym_EQ_EQ] = ACTIONS(1886),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(1884),
    [anon_sym_BANG_EQ] = ACTIONS(1886),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(1884),
    [anon_sym_GT_EQ] = ACTIONS(1884),
    [anon_sym_GT] = ACTIONS(1886),
    [anon_sym_QMARK_QMARK] = ACTIONS(1884),
    [anon_sym_instanceof] = ACTIONS(1886),
    [anon_sym_TILDE] = ACTIONS(1884),
    [anon_sym_void] = ACTIONS(1886),
    [anon_sym_delete] = ACTIONS(1886),
    [anon_sym_PLUS_PLUS] = ACTIONS(1884),
    [anon_sym_DASH_DASH] = ACTIONS(1884),
    [anon_sym_DQUOTE] = ACTIONS(1884),
    [anon_sym_SQUOTE] = ACTIONS(1884),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1884),
    [sym_number] = ACTIONS(1884),
    [sym_private_property_identifier] = ACTIONS(1884),
    [sym_this] = ACTIONS(1886),
    [sym_super] = ACTIONS(1886),
    [sym_true] = ACTIONS(1886),
    [sym_false] = ACTIONS(1886),
    [sym_null] = ACTIONS(1886),
    [sym_undefined] = ACTIONS(1886),
    [anon_sym_AT] = ACTIONS(1884),
    [anon_sym_static] = ACTIONS(1886),
    [anon_sym_readonly] = ACTIONS(1886),
    [anon_sym_get] = ACTIONS(1886),
    [anon_sym_set] = ACTIONS(1886),
    [anon_sym_declare] = ACTIONS(1886),
    [anon_sym_public] = ACTIONS(1886),
    [anon_sym_private] = ACTIONS(1886),
    [anon_sym_protected] = ACTIONS(1886),
    [anon_sym_override] = ACTIONS(1886),
    [anon_sym_module] = ACTIONS(1886),
    [anon_sym_any] = ACTIONS(1886),
    [anon_sym_number] = ACTIONS(1886),
    [anon_sym_boolean] = ACTIONS(1886),
    [anon_sym_string] = ACTIONS(1886),
    [anon_sym_symbol] = ACTIONS(1886),
    [anon_sym_object] = ACTIONS(1886),
    [anon_sym_abstract] = ACTIONS(1886),
    [anon_sym_satisfies] = ACTIONS(1886),
    [anon_sym_interface] = ACTIONS(1886),
    [anon_sym_enum] = ACTIONS(1886),
    [sym__automatic_semicolon] = ACTIONS(1884),
    [sym__ternary_qmark] = ACTIONS(1884),
    [sym_html_comment] = ACTIONS(5),
  },
  [239] = {
    [ts_builtin_sym_end] = ACTIONS(1888),
    [sym_identifier] = ACTIONS(1890),
    [anon_sym_export] = ACTIONS(1890),
    [anon_sym_STAR] = ACTIONS(1890),
    [anon_sym_default] = ACTIONS(1890),
    [anon_sym_type] = ACTIONS(1890),
    [anon_sym_as] = ACTIONS(1890),
    [anon_sym_namespace] = ACTIONS(1890),
    [anon_sym_LBRACE] = ACTIONS(1888),
    [anon_sym_COMMA] = ACTIONS(1888),
    [anon_sym_RBRACE] = ACTIONS(1888),
    [anon_sym_typeof] = ACTIONS(1890),
    [anon_sym_import] = ACTIONS(1890),
    [anon_sym_with] = ACTIONS(1890),
    [anon_sym_var] = ACTIONS(1890),
    [anon_sym_let] = ACTIONS(1890),
    [anon_sym_const] = ACTIONS(1890),
    [anon_sym_BANG] = ACTIONS(1890),
    [anon_sym_else] = ACTIONS(1890),
    [anon_sym_if] = ACTIONS(1890),
    [anon_sym_switch] = ACTIONS(1890),
    [anon_sym_for] = ACTIONS(1890),
    [anon_sym_LPAREN] = ACTIONS(1888),
    [anon_sym_SEMI] = ACTIONS(1888),
    [anon_sym_await] = ACTIONS(1890),
    [anon_sym_in] = ACTIONS(1890),
    [anon_sym_while] = ACTIONS(1890),
    [anon_sym_do] = ACTIONS(1890),
    [anon_sym_try] = ACTIONS(1890),
    [anon_sym_break] = ACTIONS(1890),
    [anon_sym_continue] = ACTIONS(1890),
    [anon_sym_debugger] = ACTIONS(1890),
    [anon_sym_return] = ACTIONS(1890),
    [anon_sym_throw] = ACTIONS(1890),
    [anon_sym_case] = ACTIONS(1890),
    [anon_sym_yield] = ACTIONS(1890),
    [anon_sym_LBRACK] = ACTIONS(1888),
    [anon_sym_DOT] = ACTIONS(1890),
    [anon_sym_class] = ACTIONS(1890),
    [anon_sym_async] = ACTIONS(1890),
    [anon_sym_function] = ACTIONS(1890),
    [anon_sym_QMARK_DOT] = ACTIONS(1888),
    [anon_sym_new] = ACTIONS(1890),
    [anon_sym_using] = ACTIONS(1890),
    [anon_sym_AMP_AMP] = ACTIONS(1888),
    [anon_sym_PIPE_PIPE] = ACTIONS(1888),
    [anon_sym_GT_GT] = ACTIONS(1890),
    [anon_sym_GT_GT_GT] = ACTIONS(1888),
    [anon_sym_LT_LT] = ACTIONS(1888),
    [anon_sym_AMP] = ACTIONS(1890),
    [anon_sym_CARET] = ACTIONS(1888),
    [anon_sym_PIPE] = ACTIONS(1890),
    [anon_sym_PLUS] = ACTIONS(1890),
    [anon_sym_DASH] = ACTIONS(1890),
    [anon_sym_SLASH] = ACTIONS(1890),
    [anon_sym_PERCENT] = ACTIONS(1888),
    [anon_sym_STAR_STAR] = ACTIONS(1888),
    [anon_sym_LT] = ACTIONS(1890),
    [anon_sym_LT_EQ] = ACTIONS(1888),
    [anon_sym_EQ_EQ] = ACTIONS(1890),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(1888),
    [anon_sym_BANG_EQ] = ACTIONS(1890),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(1888),
    [anon_sym_GT_EQ] = ACTIONS(1888),
    [anon_sym_GT] = ACTIONS(1890),
    [anon_sym_QMARK_QMARK] = ACTIONS(1888),
    [anon_sym_instanceof] = ACTIONS(1890),
    [anon_sym_TILDE] = ACTIONS(1888),
    [anon_sym_void] = ACTIONS(1890),
    [anon_sym_delete] = ACTIONS(1890),
    [anon_sym_PLUS_PLUS] = ACTIONS(1888),
    [anon_sym_DASH_DASH] = ACTIONS(1888),
    [anon_sym_DQUOTE] = ACTIONS(1888),
    [anon_sym_SQUOTE] = ACTIONS(1888),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1888),
    [sym_number] = ACTIONS(1888),
    [sym_private_property_identifier] = ACTIONS(1888),
    [sym_this] = ACTIONS(1890),
    [sym_super] = ACTIONS(1890),
    [sym_true] = ACTIONS(1890),
    [sym_false] = ACTIONS(1890),
    [sym_null] = ACTIONS(1890),
    [sym_undefined] = ACTIONS(1890),
    [anon_sym_AT] = ACTIONS(1888),
    [anon_sym_static] = ACTIONS(1890),
    [anon_sym_readonly] = ACTIONS(1890),
    [anon_sym_get] = ACTIONS(1890),
    [anon_sym_set] = ACTIONS(1890),
    [anon_sym_declare] = ACTIONS(1890),
    [anon_sym_public] = ACTIONS(1890),
    [anon_sym_private] = ACTIONS(1890),
    [anon_sym_protected] = ACTIONS(1890),
    [anon_sym_override] = ACTIONS(1890),
    [anon_sym_module] = ACTIONS(1890),
    [anon_sym_any] = ACTIONS(1890),
    [anon_sym_number] = ACTIONS(1890),
    [anon_sym_boolean] = ACTIONS(1890),
    [anon_sym_string] = ACTIONS(1890),
    [anon_sym_symbol] = ACTIONS(1890),
    [anon_sym_object] = ACTIONS(1890),
    [anon_sym_abstract] = ACTIONS(1890),
    [anon_sym_satisfies] = ACTIONS(1890),
    [anon_sym_interface] = ACTIONS(1890),
    [anon_sym_enum] = ACTIONS(1890),
    [sym__automatic_semicolon] = ACTIONS(1888),
    [sym__ternary_qmark] = ACTIONS(1888),
    [sym_html_comment] = ACTIONS(5),
  },
  [240] = {
    [ts_builtin_sym_end] = ACTIONS(1892),
    [sym_identifier] = ACTIONS(1894),
    [anon_sym_export] = ACTIONS(1894),
    [anon_sym_STAR] = ACTIONS(1894),
    [anon_sym_default] = ACTIONS(1894),
    [anon_sym_type] = ACTIONS(1894),
    [anon_sym_as] = ACTIONS(1894),
    [anon_sym_namespace] = ACTIONS(1894),
    [anon_sym_LBRACE] = ACTIONS(1892),
    [anon_sym_COMMA] = ACTIONS(1892),
    [anon_sym_RBRACE] = ACTIONS(1892),
    [anon_sym_typeof] = ACTIONS(1894),
    [anon_sym_import] = ACTIONS(1894),
    [anon_sym_with] = ACTIONS(1894),
    [anon_sym_var] = ACTIONS(1894),
    [anon_sym_let] = ACTIONS(1894),
    [anon_sym_const] = ACTIONS(1894),
    [anon_sym_BANG] = ACTIONS(1894),
    [anon_sym_else] = ACTIONS(1894),
    [anon_sym_if] = ACTIONS(1894),
    [anon_sym_switch] = ACTIONS(1894),
    [anon_sym_for] = ACTIONS(1894),
    [anon_sym_LPAREN] = ACTIONS(1892),
    [anon_sym_SEMI] = ACTIONS(1892),
    [anon_sym_await] = ACTIONS(1894),
    [anon_sym_in] = ACTIONS(1894),
    [anon_sym_while] = ACTIONS(1894),
    [anon_sym_do] = ACTIONS(1894),
    [anon_sym_try] = ACTIONS(1894),
    [anon_sym_break] = ACTIONS(1894),
    [anon_sym_continue] = ACTIONS(1894),
    [anon_sym_debugger] = ACTIONS(1894),
    [anon_sym_return] = ACTIONS(1894),
    [anon_sym_throw] = ACTIONS(1894),
    [anon_sym_case] = ACTIONS(1894),
    [anon_sym_yield] = ACTIONS(1894),
    [anon_sym_LBRACK] = ACTIONS(1892),
    [anon_sym_DOT] = ACTIONS(1894),
    [anon_sym_class] = ACTIONS(1894),
    [anon_sym_async] = ACTIONS(1894),
    [anon_sym_function] = ACTIONS(1894),
    [anon_sym_QMARK_DOT] = ACTIONS(1892),
    [anon_sym_new] = ACTIONS(1894),
    [anon_sym_using] = ACTIONS(1894),
    [anon_sym_AMP_AMP] = ACTIONS(1892),
    [anon_sym_PIPE_PIPE] = ACTIONS(1892),
    [anon_sym_GT_GT] = ACTIONS(1894),
    [anon_sym_GT_GT_GT] = ACTIONS(1892),
    [anon_sym_LT_LT] = ACTIONS(1892),
    [anon_sym_AMP] = ACTIONS(1894),
    [anon_sym_CARET] = ACTIONS(1892),
    [anon_sym_PIPE] = ACTIONS(1894),
    [anon_sym_PLUS] = ACTIONS(1894),
    [anon_sym_DASH] = ACTIONS(1894),
    [anon_sym_SLASH] = ACTIONS(1894),
    [anon_sym_PERCENT] = ACTIONS(1892),
    [anon_sym_STAR_STAR] = ACTIONS(1892),
    [anon_sym_LT] = ACTIONS(1894),
    [anon_sym_LT_EQ] = ACTIONS(1892),
    [anon_sym_EQ_EQ] = ACTIONS(1894),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(1892),
    [anon_sym_BANG_EQ] = ACTIONS(1894),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(1892),
    [anon_sym_GT_EQ] = ACTIONS(1892),
    [anon_sym_GT] = ACTIONS(1894),
    [anon_sym_QMARK_QMARK] = ACTIONS(1892),
    [anon_sym_instanceof] = ACTIONS(1894),
    [anon_sym_TILDE] = ACTIONS(1892),
    [anon_sym_void] = ACTIONS(1894),
    [anon_sym_delete] = ACTIONS(1894),
    [anon_sym_PLUS_PLUS] = ACTIONS(1892),
    [anon_sym_DASH_DASH] = ACTIONS(1892),
    [anon_sym_DQUOTE] = ACTIONS(1892),
    [anon_sym_SQUOTE] = ACTIONS(1892),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1892),
    [sym_number] = ACTIONS(1892),
    [sym_private_property_identifier] = ACTIONS(1892),
    [sym_this] = ACTIONS(1894),
    [sym_super] = ACTIONS(1894),
    [sym_true] = ACTIONS(1894),
    [sym_false] = ACTIONS(1894),
    [sym_null] = ACTIONS(1894),
    [sym_undefined] = ACTIONS(1894),
    [anon_sym_AT] = ACTIONS(1892),
    [anon_sym_static] = ACTIONS(1894),
    [anon_sym_readonly] = ACTIONS(1894),
    [anon_sym_get] = ACTIONS(1894),
    [anon_sym_set] = ACTIONS(1894),
    [anon_sym_declare] = ACTIONS(1894),
    [anon_sym_public] = ACTIONS(1894),
    [anon_sym_private] = ACTIONS(1894),
    [anon_sym_protected] = ACTIONS(1894),
    [anon_sym_override] = ACTIONS(1894),
    [anon_sym_module] = ACTIONS(1894),
    [anon_sym_any] = ACTIONS(1894),
    [anon_sym_number] = ACTIONS(1894),
    [anon_sym_boolean] = ACTIONS(1894),
    [anon_sym_string] = ACTIONS(1894),
    [anon_sym_symbol] = ACTIONS(1894),
    [anon_sym_object] = ACTIONS(1894),
    [anon_sym_abstract] = ACTIONS(1894),
    [anon_sym_satisfies] = ACTIONS(1894),
    [anon_sym_interface] = ACTIONS(1894),
    [anon_sym_enum] = ACTIONS(1894),
    [sym__automatic_semicolon] = ACTIONS(1892),
    [sym__ternary_qmark] = ACTIONS(1892),
    [sym_html_comment] = ACTIONS(5),
  },
  [241] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1322),
    [sym_expression] = STATE(2126),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(4425),
    [sym_assignment_pattern] = STATE(4969),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(4425),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5508),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1396),
    [sym_subscript_expression] = STATE(1396),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3003),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(4425),
    [sym_spread_element] = STATE(4946),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_pattern] = STATE(4406),
    [sym_rest_pattern] = STATE(3684),
    [sym_non_null_expression] = STATE(1396),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(484),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [aux_sym_array_repeat1] = STATE(4955),
    [aux_sym_array_pattern_repeat1] = STATE(4977),
    [sym_identifier] = ACTIONS(1738),
    [anon_sym_export] = ACTIONS(541),
    [anon_sym_type] = ACTIONS(541),
    [anon_sym_namespace] = ACTIONS(545),
    [anon_sym_LBRACE] = ACTIONS(808),
    [anon_sym_COMMA] = ACTIONS(1740),
    [anon_sym_typeof] = ACTIONS(581),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(541),
    [anon_sym_BANG] = ACTIONS(553),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(555),
    [anon_sym_yield] = ACTIONS(557),
    [anon_sym_LBRACK] = ACTIONS(812),
    [anon_sym_RBRACK] = ACTIONS(1896),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(563),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1744),
    [anon_sym_using] = ACTIONS(567),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(249),
    [anon_sym_PLUS] = ACTIONS(581),
    [anon_sym_DASH] = ACTIONS(581),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(553),
    [anon_sym_void] = ACTIONS(581),
    [anon_sym_delete] = ACTIONS(581),
    [anon_sym_PLUS_PLUS] = ACTIONS(583),
    [anon_sym_DASH_DASH] = ACTIONS(583),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(585),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1746),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(541),
    [anon_sym_readonly] = ACTIONS(541),
    [anon_sym_get] = ACTIONS(541),
    [anon_sym_set] = ACTIONS(541),
    [anon_sym_declare] = ACTIONS(541),
    [anon_sym_public] = ACTIONS(541),
    [anon_sym_private] = ACTIONS(541),
    [anon_sym_protected] = ACTIONS(541),
    [anon_sym_override] = ACTIONS(541),
    [anon_sym_module] = ACTIONS(541),
    [anon_sym_any] = ACTIONS(541),
    [anon_sym_number] = ACTIONS(541),
    [anon_sym_boolean] = ACTIONS(541),
    [anon_sym_string] = ACTIONS(541),
    [anon_sym_symbol] = ACTIONS(541),
    [anon_sym_object] = ACTIONS(541),
    [sym_html_comment] = ACTIONS(5),
  },
  [242] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1322),
    [sym_expression] = STATE(1776),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5698),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5698),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5508),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1322),
    [sym_subscript_expression] = STATE(1322),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3003),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5698),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1322),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(484),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1456),
    [anon_sym_export] = ACTIONS(1048),
    [anon_sym_type] = ACTIONS(1048),
    [anon_sym_namespace] = ACTIONS(1050),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_COMMA] = ACTIONS(1898),
    [anon_sym_RBRACE] = ACTIONS(1898),
    [anon_sym_typeof] = ACTIONS(581),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1048),
    [anon_sym_BANG] = ACTIONS(553),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_SEMI] = ACTIONS(1898),
    [anon_sym_await] = ACTIONS(555),
    [anon_sym_yield] = ACTIONS(557),
    [anon_sym_LBRACK] = ACTIONS(1898),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1058),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1464),
    [anon_sym_using] = ACTIONS(567),
    [anon_sym_AMP] = ACTIONS(1898),
    [anon_sym_PIPE] = ACTIONS(1900),
    [anon_sym_PLUS] = ACTIONS(581),
    [anon_sym_DASH] = ACTIONS(581),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(553),
    [anon_sym_void] = ACTIONS(581),
    [anon_sym_delete] = ACTIONS(581),
    [anon_sym_PLUS_PLUS] = ACTIONS(583),
    [anon_sym_DASH_DASH] = ACTIONS(583),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(585),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1466),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1048),
    [anon_sym_readonly] = ACTIONS(1048),
    [anon_sym_get] = ACTIONS(1048),
    [anon_sym_set] = ACTIONS(1048),
    [anon_sym_declare] = ACTIONS(1048),
    [anon_sym_public] = ACTIONS(1048),
    [anon_sym_private] = ACTIONS(1048),
    [anon_sym_protected] = ACTIONS(1048),
    [anon_sym_override] = ACTIONS(1048),
    [anon_sym_module] = ACTIONS(1048),
    [anon_sym_any] = ACTIONS(1048),
    [anon_sym_number] = ACTIONS(1048),
    [anon_sym_boolean] = ACTIONS(1048),
    [anon_sym_string] = ACTIONS(1048),
    [anon_sym_symbol] = ACTIONS(1048),
    [anon_sym_object] = ACTIONS(1048),
    [anon_sym_extends] = ACTIONS(1900),
    [anon_sym_PIPE_RBRACE] = ACTIONS(1898),
    [sym__automatic_semicolon] = ACTIONS(1898),
    [sym_html_comment] = ACTIONS(5),
  },
  [243] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1457),
    [sym_expression] = STATE(2591),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5096),
    [sym_assignment_pattern] = STATE(4969),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5096),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5477),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1414),
    [sym_subscript_expression] = STATE(1414),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(2986),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5096),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_pattern] = STATE(4406),
    [sym_rest_pattern] = STATE(3684),
    [sym_non_null_expression] = STATE(1414),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_mapped_type_clause] = STATE(5820),
    [sym_type_arguments] = STATE(620),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [aux_sym_array_pattern_repeat1] = STATE(4977),
    [sym_identifier] = ACTIONS(1902),
    [anon_sym_export] = ACTIONS(1904),
    [anon_sym_type] = ACTIONS(1904),
    [anon_sym_namespace] = ACTIONS(1906),
    [anon_sym_LBRACE] = ACTIONS(1908),
    [anon_sym_COMMA] = ACTIONS(1910),
    [anon_sym_typeof] = ACTIONS(1202),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1904),
    [anon_sym_BANG] = ACTIONS(1186),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(1188),
    [anon_sym_yield] = ACTIONS(1190),
    [anon_sym_LBRACK] = ACTIONS(1912),
    [anon_sym_RBRACK] = ACTIONS(1914),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1916),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1918),
    [anon_sym_using] = ACTIONS(1196),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(162),
    [anon_sym_PLUS] = ACTIONS(1202),
    [anon_sym_DASH] = ACTIONS(1202),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(1186),
    [anon_sym_void] = ACTIONS(1202),
    [anon_sym_delete] = ACTIONS(1202),
    [anon_sym_PLUS_PLUS] = ACTIONS(1204),
    [anon_sym_DASH_DASH] = ACTIONS(1204),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(1206),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1920),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1904),
    [anon_sym_readonly] = ACTIONS(1904),
    [anon_sym_get] = ACTIONS(1904),
    [anon_sym_set] = ACTIONS(1904),
    [anon_sym_declare] = ACTIONS(1904),
    [anon_sym_public] = ACTIONS(1904),
    [anon_sym_private] = ACTIONS(1904),
    [anon_sym_protected] = ACTIONS(1904),
    [anon_sym_override] = ACTIONS(1904),
    [anon_sym_module] = ACTIONS(1904),
    [anon_sym_any] = ACTIONS(1904),
    [anon_sym_number] = ACTIONS(1904),
    [anon_sym_boolean] = ACTIONS(1904),
    [anon_sym_string] = ACTIONS(1904),
    [anon_sym_symbol] = ACTIONS(1904),
    [anon_sym_object] = ACTIONS(1904),
    [sym_html_comment] = ACTIONS(5),
  },
  [244] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1322),
    [sym_expression] = STATE(1776),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5698),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5698),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5508),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1322),
    [sym_subscript_expression] = STATE(1322),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3003),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5698),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1322),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(484),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1456),
    [anon_sym_export] = ACTIONS(1048),
    [anon_sym_type] = ACTIONS(1048),
    [anon_sym_namespace] = ACTIONS(1050),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_COMMA] = ACTIONS(1898),
    [anon_sym_RBRACE] = ACTIONS(1898),
    [anon_sym_typeof] = ACTIONS(581),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1048),
    [anon_sym_BANG] = ACTIONS(553),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(555),
    [anon_sym_yield] = ACTIONS(557),
    [anon_sym_LBRACK] = ACTIONS(1898),
    [anon_sym_RBRACK] = ACTIONS(1898),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1058),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1464),
    [anon_sym_using] = ACTIONS(567),
    [anon_sym_AMP] = ACTIONS(1898),
    [anon_sym_PIPE] = ACTIONS(1898),
    [anon_sym_PLUS] = ACTIONS(581),
    [anon_sym_DASH] = ACTIONS(581),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_GT] = ACTIONS(1898),
    [anon_sym_TILDE] = ACTIONS(553),
    [anon_sym_void] = ACTIONS(581),
    [anon_sym_delete] = ACTIONS(581),
    [anon_sym_PLUS_PLUS] = ACTIONS(583),
    [anon_sym_DASH_DASH] = ACTIONS(583),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(585),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1466),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1048),
    [anon_sym_readonly] = ACTIONS(1048),
    [anon_sym_get] = ACTIONS(1048),
    [anon_sym_set] = ACTIONS(1048),
    [anon_sym_QMARK] = ACTIONS(1898),
    [anon_sym_declare] = ACTIONS(1048),
    [anon_sym_public] = ACTIONS(1048),
    [anon_sym_private] = ACTIONS(1048),
    [anon_sym_protected] = ACTIONS(1048),
    [anon_sym_override] = ACTIONS(1048),
    [anon_sym_module] = ACTIONS(1048),
    [anon_sym_any] = ACTIONS(1048),
    [anon_sym_number] = ACTIONS(1048),
    [anon_sym_boolean] = ACTIONS(1048),
    [anon_sym_string] = ACTIONS(1048),
    [anon_sym_symbol] = ACTIONS(1048),
    [anon_sym_object] = ACTIONS(1048),
    [anon_sym_extends] = ACTIONS(1900),
    [sym_html_comment] = ACTIONS(5),
  },
  [245] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1213),
    [sym_expression] = STATE(2644),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(3722),
    [sym_assignment_pattern] = STATE(4927),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(3722),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5800),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1295),
    [sym_subscript_expression] = STATE(1295),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3013),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(3722),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_pattern] = STATE(4479),
    [sym_rest_pattern] = STATE(3684),
    [sym_non_null_expression] = STATE(1295),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(539),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [aux_sym_array_pattern_repeat1] = STATE(5023),
    [sym_identifier] = ACTIONS(696),
    [anon_sym_export] = ACTIONS(113),
    [anon_sym_type] = ACTIONS(113),
    [anon_sym_namespace] = ACTIONS(122),
    [anon_sym_LBRACE] = ACTIONS(698),
    [anon_sym_COMMA] = ACTIONS(1910),
    [anon_sym_typeof] = ACTIONS(179),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(113),
    [anon_sym_BANG] = ACTIONS(175),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(140),
    [anon_sym_yield] = ACTIONS(142),
    [anon_sym_LBRACK] = ACTIONS(1664),
    [anon_sym_RBRACK] = ACTIONS(1922),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(148),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(706),
    [anon_sym_using] = ACTIONS(158),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(162),
    [anon_sym_PLUS] = ACTIONS(179),
    [anon_sym_DASH] = ACTIONS(179),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(175),
    [anon_sym_void] = ACTIONS(179),
    [anon_sym_delete] = ACTIONS(179),
    [anon_sym_PLUS_PLUS] = ACTIONS(686),
    [anon_sym_DASH_DASH] = ACTIONS(686),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(192),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(718),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(113),
    [anon_sym_readonly] = ACTIONS(113),
    [anon_sym_get] = ACTIONS(113),
    [anon_sym_set] = ACTIONS(113),
    [anon_sym_declare] = ACTIONS(113),
    [anon_sym_public] = ACTIONS(113),
    [anon_sym_private] = ACTIONS(113),
    [anon_sym_protected] = ACTIONS(113),
    [anon_sym_override] = ACTIONS(113),
    [anon_sym_module] = ACTIONS(113),
    [anon_sym_any] = ACTIONS(113),
    [anon_sym_number] = ACTIONS(113),
    [anon_sym_boolean] = ACTIONS(113),
    [anon_sym_string] = ACTIONS(113),
    [anon_sym_symbol] = ACTIONS(113),
    [anon_sym_object] = ACTIONS(113),
    [sym_html_comment] = ACTIONS(5),
  },
  [246] = {
    [sym_import] = STATE(3639),
    [sym_variable_declaration] = STATE(299),
    [sym_lexical_declaration] = STATE(299),
    [sym_empty_statement] = STATE(299),
    [sym_parenthesized_expression] = STATE(1381),
    [sym_expression] = STATE(2227),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5003),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5003),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5508),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1381),
    [sym_subscript_expression] = STATE(1381),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3003),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5003),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_sequence_expression] = STATE(5597),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1381),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(484),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1924),
    [anon_sym_export] = ACTIONS(1926),
    [anon_sym_type] = ACTIONS(1926),
    [anon_sym_namespace] = ACTIONS(1928),
    [anon_sym_LBRACE] = ACTIONS(1930),
    [anon_sym_typeof] = ACTIONS(581),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_var] = ACTIONS(1932),
    [anon_sym_let] = ACTIONS(1934),
    [anon_sym_const] = ACTIONS(1936),
    [anon_sym_BANG] = ACTIONS(553),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_SEMI] = ACTIONS(43),
    [anon_sym_await] = ACTIONS(555),
    [anon_sym_yield] = ACTIONS(557),
    [anon_sym_LBRACK] = ACTIONS(1938),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1940),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1942),
    [anon_sym_using] = ACTIONS(567),
    [anon_sym_PLUS] = ACTIONS(581),
    [anon_sym_DASH] = ACTIONS(581),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(553),
    [anon_sym_void] = ACTIONS(581),
    [anon_sym_delete] = ACTIONS(581),
    [anon_sym_PLUS_PLUS] = ACTIONS(583),
    [anon_sym_DASH_DASH] = ACTIONS(583),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(585),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1944),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1926),
    [anon_sym_readonly] = ACTIONS(1926),
    [anon_sym_get] = ACTIONS(1926),
    [anon_sym_set] = ACTIONS(1926),
    [anon_sym_declare] = ACTIONS(1926),
    [anon_sym_public] = ACTIONS(1926),
    [anon_sym_private] = ACTIONS(1926),
    [anon_sym_protected] = ACTIONS(1926),
    [anon_sym_override] = ACTIONS(1926),
    [anon_sym_module] = ACTIONS(1926),
    [anon_sym_any] = ACTIONS(1926),
    [anon_sym_number] = ACTIONS(1926),
    [anon_sym_boolean] = ACTIONS(1926),
    [anon_sym_string] = ACTIONS(1926),
    [anon_sym_symbol] = ACTIONS(1926),
    [anon_sym_object] = ACTIONS(1926),
    [sym_html_comment] = ACTIONS(5),
  },
  [247] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1457),
    [sym_expression] = STATE(2553),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5096),
    [sym_assignment_pattern] = STATE(4969),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5096),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5477),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1414),
    [sym_subscript_expression] = STATE(1414),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(2986),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5096),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_pattern] = STATE(4406),
    [sym_rest_pattern] = STATE(3684),
    [sym_non_null_expression] = STATE(1414),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(620),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [aux_sym_array_pattern_repeat1] = STATE(4977),
    [sym_identifier] = ACTIONS(1946),
    [anon_sym_export] = ACTIONS(1948),
    [anon_sym_type] = ACTIONS(1948),
    [anon_sym_namespace] = ACTIONS(1950),
    [anon_sym_LBRACE] = ACTIONS(1908),
    [anon_sym_COMMA] = ACTIONS(1910),
    [anon_sym_typeof] = ACTIONS(1202),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1948),
    [anon_sym_BANG] = ACTIONS(1186),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(1188),
    [anon_sym_yield] = ACTIONS(1190),
    [anon_sym_LBRACK] = ACTIONS(1912),
    [anon_sym_RBRACK] = ACTIONS(1914),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1952),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1954),
    [anon_sym_using] = ACTIONS(1196),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(162),
    [anon_sym_PLUS] = ACTIONS(1202),
    [anon_sym_DASH] = ACTIONS(1202),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(1186),
    [anon_sym_void] = ACTIONS(1202),
    [anon_sym_delete] = ACTIONS(1202),
    [anon_sym_PLUS_PLUS] = ACTIONS(1204),
    [anon_sym_DASH_DASH] = ACTIONS(1204),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(1206),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1920),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1948),
    [anon_sym_readonly] = ACTIONS(1948),
    [anon_sym_get] = ACTIONS(1948),
    [anon_sym_set] = ACTIONS(1948),
    [anon_sym_declare] = ACTIONS(1948),
    [anon_sym_public] = ACTIONS(1948),
    [anon_sym_private] = ACTIONS(1948),
    [anon_sym_protected] = ACTIONS(1948),
    [anon_sym_override] = ACTIONS(1948),
    [anon_sym_module] = ACTIONS(1948),
    [anon_sym_any] = ACTIONS(1948),
    [anon_sym_number] = ACTIONS(1948),
    [anon_sym_boolean] = ACTIONS(1948),
    [anon_sym_string] = ACTIONS(1948),
    [anon_sym_symbol] = ACTIONS(1948),
    [anon_sym_object] = ACTIONS(1948),
    [sym_html_comment] = ACTIONS(5),
  },
  [248] = {
    [sym_import] = STATE(3639),
    [sym_variable_declaration] = STATE(304),
    [sym_lexical_declaration] = STATE(304),
    [sym_empty_statement] = STATE(304),
    [sym_parenthesized_expression] = STATE(1381),
    [sym_expression] = STATE(2311),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5003),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5003),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5508),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1381),
    [sym_subscript_expression] = STATE(1381),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3003),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5003),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_sequence_expression] = STATE(5849),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1381),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(484),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1924),
    [anon_sym_export] = ACTIONS(1926),
    [anon_sym_type] = ACTIONS(1926),
    [anon_sym_namespace] = ACTIONS(1928),
    [anon_sym_LBRACE] = ACTIONS(1930),
    [anon_sym_typeof] = ACTIONS(581),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_var] = ACTIONS(1932),
    [anon_sym_let] = ACTIONS(1934),
    [anon_sym_const] = ACTIONS(1936),
    [anon_sym_BANG] = ACTIONS(553),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_SEMI] = ACTIONS(43),
    [anon_sym_await] = ACTIONS(555),
    [anon_sym_yield] = ACTIONS(557),
    [anon_sym_LBRACK] = ACTIONS(1938),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1940),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1942),
    [anon_sym_using] = ACTIONS(567),
    [anon_sym_PLUS] = ACTIONS(581),
    [anon_sym_DASH] = ACTIONS(581),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(553),
    [anon_sym_void] = ACTIONS(581),
    [anon_sym_delete] = ACTIONS(581),
    [anon_sym_PLUS_PLUS] = ACTIONS(583),
    [anon_sym_DASH_DASH] = ACTIONS(583),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(585),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1944),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1926),
    [anon_sym_readonly] = ACTIONS(1926),
    [anon_sym_get] = ACTIONS(1926),
    [anon_sym_set] = ACTIONS(1926),
    [anon_sym_declare] = ACTIONS(1926),
    [anon_sym_public] = ACTIONS(1926),
    [anon_sym_private] = ACTIONS(1926),
    [anon_sym_protected] = ACTIONS(1926),
    [anon_sym_override] = ACTIONS(1926),
    [anon_sym_module] = ACTIONS(1926),
    [anon_sym_any] = ACTIONS(1926),
    [anon_sym_number] = ACTIONS(1926),
    [anon_sym_boolean] = ACTIONS(1926),
    [anon_sym_string] = ACTIONS(1926),
    [anon_sym_symbol] = ACTIONS(1926),
    [anon_sym_object] = ACTIONS(1926),
    [sym_html_comment] = ACTIONS(5),
  },
  [249] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1322),
    [sym_expression] = STATE(2439),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(4425),
    [sym_assignment_pattern] = STATE(5126),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(4425),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5508),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1396),
    [sym_subscript_expression] = STATE(1396),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3003),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(4425),
    [sym_spread_element] = STATE(4980),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_pattern] = STATE(4982),
    [sym_rest_pattern] = STATE(3684),
    [sym_non_null_expression] = STATE(1396),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(484),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1738),
    [anon_sym_export] = ACTIONS(541),
    [anon_sym_type] = ACTIONS(541),
    [anon_sym_namespace] = ACTIONS(545),
    [anon_sym_LBRACE] = ACTIONS(808),
    [anon_sym_COMMA] = ACTIONS(1956),
    [anon_sym_typeof] = ACTIONS(581),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(541),
    [anon_sym_BANG] = ACTIONS(553),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(555),
    [anon_sym_yield] = ACTIONS(557),
    [anon_sym_LBRACK] = ACTIONS(812),
    [anon_sym_RBRACK] = ACTIONS(1959),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(563),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1744),
    [anon_sym_using] = ACTIONS(567),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(249),
    [anon_sym_PLUS] = ACTIONS(581),
    [anon_sym_DASH] = ACTIONS(581),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(553),
    [anon_sym_void] = ACTIONS(581),
    [anon_sym_delete] = ACTIONS(581),
    [anon_sym_PLUS_PLUS] = ACTIONS(583),
    [anon_sym_DASH_DASH] = ACTIONS(583),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(585),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1746),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(541),
    [anon_sym_readonly] = ACTIONS(541),
    [anon_sym_get] = ACTIONS(541),
    [anon_sym_set] = ACTIONS(541),
    [anon_sym_declare] = ACTIONS(541),
    [anon_sym_public] = ACTIONS(541),
    [anon_sym_private] = ACTIONS(541),
    [anon_sym_protected] = ACTIONS(541),
    [anon_sym_override] = ACTIONS(541),
    [anon_sym_module] = ACTIONS(541),
    [anon_sym_any] = ACTIONS(541),
    [anon_sym_number] = ACTIONS(541),
    [anon_sym_boolean] = ACTIONS(541),
    [anon_sym_string] = ACTIONS(541),
    [anon_sym_symbol] = ACTIONS(541),
    [anon_sym_object] = ACTIONS(541),
    [sym_html_comment] = ACTIONS(5),
  },
  [250] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1322),
    [sym_expression] = STATE(2439),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(4425),
    [sym_assignment_pattern] = STATE(5126),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(4425),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5508),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1396),
    [sym_subscript_expression] = STATE(1396),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3003),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(4425),
    [sym_spread_element] = STATE(4980),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_pattern] = STATE(4982),
    [sym_rest_pattern] = STATE(3684),
    [sym_non_null_expression] = STATE(1396),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(484),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1738),
    [anon_sym_export] = ACTIONS(541),
    [anon_sym_type] = ACTIONS(541),
    [anon_sym_namespace] = ACTIONS(545),
    [anon_sym_LBRACE] = ACTIONS(808),
    [anon_sym_COMMA] = ACTIONS(1956),
    [anon_sym_typeof] = ACTIONS(581),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(541),
    [anon_sym_BANG] = ACTIONS(553),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(555),
    [anon_sym_yield] = ACTIONS(557),
    [anon_sym_LBRACK] = ACTIONS(812),
    [anon_sym_RBRACK] = ACTIONS(1956),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(563),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1744),
    [anon_sym_using] = ACTIONS(567),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(249),
    [anon_sym_PLUS] = ACTIONS(581),
    [anon_sym_DASH] = ACTIONS(581),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(553),
    [anon_sym_void] = ACTIONS(581),
    [anon_sym_delete] = ACTIONS(581),
    [anon_sym_PLUS_PLUS] = ACTIONS(583),
    [anon_sym_DASH_DASH] = ACTIONS(583),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(585),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1746),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(541),
    [anon_sym_readonly] = ACTIONS(541),
    [anon_sym_get] = ACTIONS(541),
    [anon_sym_set] = ACTIONS(541),
    [anon_sym_declare] = ACTIONS(541),
    [anon_sym_public] = ACTIONS(541),
    [anon_sym_private] = ACTIONS(541),
    [anon_sym_protected] = ACTIONS(541),
    [anon_sym_override] = ACTIONS(541),
    [anon_sym_module] = ACTIONS(541),
    [anon_sym_any] = ACTIONS(541),
    [anon_sym_number] = ACTIONS(541),
    [anon_sym_boolean] = ACTIONS(541),
    [anon_sym_string] = ACTIONS(541),
    [anon_sym_symbol] = ACTIONS(541),
    [anon_sym_object] = ACTIONS(541),
    [sym_html_comment] = ACTIONS(5),
  },
  [251] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1213),
    [sym_expression] = STATE(2577),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5522),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5522),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5800),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1213),
    [sym_subscript_expression] = STATE(1213),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3013),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5522),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1213),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(539),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(802),
    [anon_sym_export] = ACTIONS(804),
    [anon_sym_type] = ACTIONS(804),
    [anon_sym_namespace] = ACTIONS(806),
    [anon_sym_LBRACE] = ACTIONS(808),
    [anon_sym_COMMA] = ACTIONS(1898),
    [anon_sym_typeof] = ACTIONS(179),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(804),
    [anon_sym_BANG] = ACTIONS(175),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_RPAREN] = ACTIONS(1898),
    [anon_sym_await] = ACTIONS(140),
    [anon_sym_yield] = ACTIONS(142),
    [anon_sym_LBRACK] = ACTIONS(1898),
    [anon_sym_RBRACK] = ACTIONS(1898),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(816),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(818),
    [anon_sym_using] = ACTIONS(158),
    [anon_sym_AMP] = ACTIONS(1898),
    [anon_sym_PIPE] = ACTIONS(1898),
    [anon_sym_PLUS] = ACTIONS(179),
    [anon_sym_DASH] = ACTIONS(179),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_GT] = ACTIONS(1898),
    [anon_sym_TILDE] = ACTIONS(175),
    [anon_sym_void] = ACTIONS(179),
    [anon_sym_delete] = ACTIONS(179),
    [anon_sym_PLUS_PLUS] = ACTIONS(686),
    [anon_sym_DASH_DASH] = ACTIONS(686),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(192),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(822),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(804),
    [anon_sym_readonly] = ACTIONS(804),
    [anon_sym_get] = ACTIONS(804),
    [anon_sym_set] = ACTIONS(804),
    [anon_sym_declare] = ACTIONS(804),
    [anon_sym_public] = ACTIONS(804),
    [anon_sym_private] = ACTIONS(804),
    [anon_sym_protected] = ACTIONS(804),
    [anon_sym_override] = ACTIONS(804),
    [anon_sym_module] = ACTIONS(804),
    [anon_sym_any] = ACTIONS(804),
    [anon_sym_number] = ACTIONS(804),
    [anon_sym_boolean] = ACTIONS(804),
    [anon_sym_string] = ACTIONS(804),
    [anon_sym_symbol] = ACTIONS(804),
    [anon_sym_object] = ACTIONS(804),
    [anon_sym_extends] = ACTIONS(1900),
    [sym_html_comment] = ACTIONS(5),
  },
  [252] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1213),
    [sym_expression] = STATE(2644),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(3722),
    [sym_assignment_pattern] = STATE(4969),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(3722),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5800),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1295),
    [sym_subscript_expression] = STATE(1295),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3013),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(3722),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_pattern] = STATE(4406),
    [sym_rest_pattern] = STATE(3684),
    [sym_non_null_expression] = STATE(1295),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(539),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [aux_sym_array_pattern_repeat1] = STATE(4977),
    [sym_identifier] = ACTIONS(696),
    [anon_sym_export] = ACTIONS(113),
    [anon_sym_type] = ACTIONS(113),
    [anon_sym_namespace] = ACTIONS(122),
    [anon_sym_LBRACE] = ACTIONS(698),
    [anon_sym_COMMA] = ACTIONS(1910),
    [anon_sym_typeof] = ACTIONS(179),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(113),
    [anon_sym_BANG] = ACTIONS(175),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(140),
    [anon_sym_yield] = ACTIONS(142),
    [anon_sym_LBRACK] = ACTIONS(1664),
    [anon_sym_RBRACK] = ACTIONS(1914),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(148),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(706),
    [anon_sym_using] = ACTIONS(158),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(162),
    [anon_sym_PLUS] = ACTIONS(179),
    [anon_sym_DASH] = ACTIONS(179),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(175),
    [anon_sym_void] = ACTIONS(179),
    [anon_sym_delete] = ACTIONS(179),
    [anon_sym_PLUS_PLUS] = ACTIONS(686),
    [anon_sym_DASH_DASH] = ACTIONS(686),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(192),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(718),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(113),
    [anon_sym_readonly] = ACTIONS(113),
    [anon_sym_get] = ACTIONS(113),
    [anon_sym_set] = ACTIONS(113),
    [anon_sym_declare] = ACTIONS(113),
    [anon_sym_public] = ACTIONS(113),
    [anon_sym_private] = ACTIONS(113),
    [anon_sym_protected] = ACTIONS(113),
    [anon_sym_override] = ACTIONS(113),
    [anon_sym_module] = ACTIONS(113),
    [anon_sym_any] = ACTIONS(113),
    [anon_sym_number] = ACTIONS(113),
    [anon_sym_boolean] = ACTIONS(113),
    [anon_sym_string] = ACTIONS(113),
    [anon_sym_symbol] = ACTIONS(113),
    [anon_sym_object] = ACTIONS(113),
    [sym_html_comment] = ACTIONS(5),
  },
  [253] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1322),
    [sym_expression] = STATE(2439),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(4425),
    [sym_assignment_pattern] = STATE(5126),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(4425),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5508),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1396),
    [sym_subscript_expression] = STATE(1396),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3003),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(4425),
    [sym_spread_element] = STATE(4980),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_pattern] = STATE(4982),
    [sym_rest_pattern] = STATE(3684),
    [sym_non_null_expression] = STATE(1396),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(484),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1738),
    [anon_sym_export] = ACTIONS(541),
    [anon_sym_type] = ACTIONS(541),
    [anon_sym_namespace] = ACTIONS(545),
    [anon_sym_LBRACE] = ACTIONS(808),
    [anon_sym_COMMA] = ACTIONS(1956),
    [anon_sym_typeof] = ACTIONS(581),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(541),
    [anon_sym_BANG] = ACTIONS(553),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(555),
    [anon_sym_yield] = ACTIONS(557),
    [anon_sym_LBRACK] = ACTIONS(812),
    [anon_sym_RBRACK] = ACTIONS(1963),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(563),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1744),
    [anon_sym_using] = ACTIONS(567),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(249),
    [anon_sym_PLUS] = ACTIONS(581),
    [anon_sym_DASH] = ACTIONS(581),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(553),
    [anon_sym_void] = ACTIONS(581),
    [anon_sym_delete] = ACTIONS(581),
    [anon_sym_PLUS_PLUS] = ACTIONS(583),
    [anon_sym_DASH_DASH] = ACTIONS(583),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(585),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1746),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(541),
    [anon_sym_readonly] = ACTIONS(541),
    [anon_sym_get] = ACTIONS(541),
    [anon_sym_set] = ACTIONS(541),
    [anon_sym_declare] = ACTIONS(541),
    [anon_sym_public] = ACTIONS(541),
    [anon_sym_private] = ACTIONS(541),
    [anon_sym_protected] = ACTIONS(541),
    [anon_sym_override] = ACTIONS(541),
    [anon_sym_module] = ACTIONS(541),
    [anon_sym_any] = ACTIONS(541),
    [anon_sym_number] = ACTIONS(541),
    [anon_sym_boolean] = ACTIONS(541),
    [anon_sym_string] = ACTIONS(541),
    [anon_sym_symbol] = ACTIONS(541),
    [anon_sym_object] = ACTIONS(541),
    [sym_html_comment] = ACTIONS(5),
  },
  [254] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1213),
    [sym_expression] = STATE(2644),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(3722),
    [sym_assignment_pattern] = STATE(5126),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(3722),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5800),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1295),
    [sym_subscript_expression] = STATE(1295),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3013),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(3722),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_pattern] = STATE(4982),
    [sym_rest_pattern] = STATE(3684),
    [sym_non_null_expression] = STATE(1295),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(539),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(696),
    [anon_sym_export] = ACTIONS(113),
    [anon_sym_type] = ACTIONS(113),
    [anon_sym_namespace] = ACTIONS(122),
    [anon_sym_LBRACE] = ACTIONS(698),
    [anon_sym_COMMA] = ACTIONS(1967),
    [anon_sym_typeof] = ACTIONS(179),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(113),
    [anon_sym_BANG] = ACTIONS(175),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(140),
    [anon_sym_yield] = ACTIONS(142),
    [anon_sym_LBRACK] = ACTIONS(1664),
    [anon_sym_RBRACK] = ACTIONS(1967),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(148),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(706),
    [anon_sym_using] = ACTIONS(158),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(162),
    [anon_sym_PLUS] = ACTIONS(179),
    [anon_sym_DASH] = ACTIONS(179),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(175),
    [anon_sym_void] = ACTIONS(179),
    [anon_sym_delete] = ACTIONS(179),
    [anon_sym_PLUS_PLUS] = ACTIONS(686),
    [anon_sym_DASH_DASH] = ACTIONS(686),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(192),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(718),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(113),
    [anon_sym_readonly] = ACTIONS(113),
    [anon_sym_get] = ACTIONS(113),
    [anon_sym_set] = ACTIONS(113),
    [anon_sym_declare] = ACTIONS(113),
    [anon_sym_public] = ACTIONS(113),
    [anon_sym_private] = ACTIONS(113),
    [anon_sym_protected] = ACTIONS(113),
    [anon_sym_override] = ACTIONS(113),
    [anon_sym_module] = ACTIONS(113),
    [anon_sym_any] = ACTIONS(113),
    [anon_sym_number] = ACTIONS(113),
    [anon_sym_boolean] = ACTIONS(113),
    [anon_sym_string] = ACTIONS(113),
    [anon_sym_symbol] = ACTIONS(113),
    [anon_sym_object] = ACTIONS(113),
    [sym_html_comment] = ACTIONS(5),
  },
  [255] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1398),
    [sym_expression] = STATE(1960),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5544),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5544),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5558),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1398),
    [sym_subscript_expression] = STATE(1398),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(2980),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5544),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1398),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(638),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1482),
    [anon_sym_export] = ACTIONS(1158),
    [anon_sym_type] = ACTIONS(1158),
    [anon_sym_namespace] = ACTIONS(1160),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_COMMA] = ACTIONS(1898),
    [anon_sym_typeof] = ACTIONS(756),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1158),
    [anon_sym_BANG] = ACTIONS(732),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_RPAREN] = ACTIONS(1898),
    [anon_sym_await] = ACTIONS(736),
    [anon_sym_yield] = ACTIONS(738),
    [anon_sym_LBRACK] = ACTIONS(1898),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1164),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1486),
    [anon_sym_using] = ACTIONS(746),
    [anon_sym_AMP] = ACTIONS(1898),
    [anon_sym_PIPE] = ACTIONS(1898),
    [anon_sym_PLUS] = ACTIONS(756),
    [anon_sym_DASH] = ACTIONS(756),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_GT] = ACTIONS(1898),
    [anon_sym_TILDE] = ACTIONS(732),
    [anon_sym_void] = ACTIONS(756),
    [anon_sym_delete] = ACTIONS(756),
    [anon_sym_PLUS_PLUS] = ACTIONS(758),
    [anon_sym_DASH_DASH] = ACTIONS(758),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(764),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1488),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1158),
    [anon_sym_readonly] = ACTIONS(1158),
    [anon_sym_get] = ACTIONS(1158),
    [anon_sym_set] = ACTIONS(1158),
    [anon_sym_declare] = ACTIONS(1158),
    [anon_sym_public] = ACTIONS(1158),
    [anon_sym_private] = ACTIONS(1158),
    [anon_sym_protected] = ACTIONS(1158),
    [anon_sym_override] = ACTIONS(1158),
    [anon_sym_module] = ACTIONS(1158),
    [anon_sym_any] = ACTIONS(1158),
    [anon_sym_number] = ACTIONS(1158),
    [anon_sym_boolean] = ACTIONS(1158),
    [anon_sym_string] = ACTIONS(1158),
    [anon_sym_symbol] = ACTIONS(1158),
    [anon_sym_object] = ACTIONS(1158),
    [anon_sym_extends] = ACTIONS(1900),
    [sym_html_comment] = ACTIONS(5),
  },
  [256] = {
    [sym_identifier] = ACTIONS(1969),
    [anon_sym_export] = ACTIONS(1969),
    [anon_sym_STAR] = ACTIONS(120),
    [anon_sym_type] = ACTIONS(1969),
    [anon_sym_EQ] = ACTIONS(117),
    [anon_sym_as] = ACTIONS(120),
    [anon_sym_namespace] = ACTIONS(1969),
    [anon_sym_LBRACE] = ACTIONS(1971),
    [anon_sym_COMMA] = ACTIONS(126),
    [anon_sym_typeof] = ACTIONS(1969),
    [anon_sym_import] = ACTIONS(1969),
    [anon_sym_let] = ACTIONS(1969),
    [anon_sym_BANG] = ACTIONS(1969),
    [anon_sym_LPAREN] = ACTIONS(1971),
    [anon_sym_RPAREN] = ACTIONS(126),
    [anon_sym_await] = ACTIONS(1969),
    [anon_sym_in] = ACTIONS(120),
    [anon_sym_COLON] = ACTIONS(126),
    [anon_sym_yield] = ACTIONS(1969),
    [anon_sym_LBRACK] = ACTIONS(1971),
    [anon_sym_DOT] = ACTIONS(120),
    [anon_sym_class] = ACTIONS(1969),
    [anon_sym_async] = ACTIONS(1969),
    [anon_sym_function] = ACTIONS(1969),
    [anon_sym_EQ_GT] = ACTIONS(152),
    [anon_sym_QMARK_DOT] = ACTIONS(154),
    [anon_sym_new] = ACTIONS(1969),
    [anon_sym_using] = ACTIONS(1969),
    [anon_sym_PLUS_EQ] = ACTIONS(160),
    [anon_sym_DASH_EQ] = ACTIONS(160),
    [anon_sym_STAR_EQ] = ACTIONS(160),
    [anon_sym_SLASH_EQ] = ACTIONS(160),
    [anon_sym_PERCENT_EQ] = ACTIONS(160),
    [anon_sym_CARET_EQ] = ACTIONS(160),
    [anon_sym_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_LT_LT_EQ] = ACTIONS(160),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(160),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(160),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1971),
    [anon_sym_AMP_AMP] = ACTIONS(120),
    [anon_sym_PIPE_PIPE] = ACTIONS(120),
    [anon_sym_GT_GT] = ACTIONS(120),
    [anon_sym_GT_GT_GT] = ACTIONS(120),
    [anon_sym_LT_LT] = ACTIONS(120),
    [anon_sym_AMP] = ACTIONS(120),
    [anon_sym_CARET] = ACTIONS(120),
    [anon_sym_PIPE] = ACTIONS(120),
    [anon_sym_PLUS] = ACTIONS(1969),
    [anon_sym_DASH] = ACTIONS(1969),
    [anon_sym_SLASH] = ACTIONS(1969),
    [anon_sym_PERCENT] = ACTIONS(120),
    [anon_sym_STAR_STAR] = ACTIONS(120),
    [anon_sym_LT] = ACTIONS(1969),
    [anon_sym_LT_EQ] = ACTIONS(154),
    [anon_sym_EQ_EQ] = ACTIONS(120),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(154),
    [anon_sym_BANG_EQ] = ACTIONS(120),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(154),
    [anon_sym_GT_EQ] = ACTIONS(154),
    [anon_sym_GT] = ACTIONS(120),
    [anon_sym_QMARK_QMARK] = ACTIONS(120),
    [anon_sym_instanceof] = ACTIONS(120),
    [anon_sym_TILDE] = ACTIONS(1971),
    [anon_sym_void] = ACTIONS(1969),
    [anon_sym_delete] = ACTIONS(1969),
    [anon_sym_PLUS_PLUS] = ACTIONS(1971),
    [anon_sym_DASH_DASH] = ACTIONS(1971),
    [anon_sym_DQUOTE] = ACTIONS(1971),
    [anon_sym_SQUOTE] = ACTIONS(1971),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1971),
    [sym_number] = ACTIONS(1971),
    [sym_private_property_identifier] = ACTIONS(1971),
    [sym_this] = ACTIONS(1969),
    [sym_super] = ACTIONS(1969),
    [sym_true] = ACTIONS(1969),
    [sym_false] = ACTIONS(1969),
    [sym_null] = ACTIONS(1969),
    [sym_undefined] = ACTIONS(1969),
    [anon_sym_AT] = ACTIONS(1971),
    [anon_sym_static] = ACTIONS(1969),
    [anon_sym_readonly] = ACTIONS(1969),
    [anon_sym_get] = ACTIONS(1969),
    [anon_sym_set] = ACTIONS(1969),
    [anon_sym_QMARK] = ACTIONS(720),
    [anon_sym_declare] = ACTIONS(1969),
    [anon_sym_public] = ACTIONS(1969),
    [anon_sym_private] = ACTIONS(1969),
    [anon_sym_protected] = ACTIONS(1969),
    [anon_sym_override] = ACTIONS(1969),
    [anon_sym_module] = ACTIONS(1969),
    [anon_sym_any] = ACTIONS(1969),
    [anon_sym_number] = ACTIONS(1969),
    [anon_sym_boolean] = ACTIONS(1969),
    [anon_sym_string] = ACTIONS(1969),
    [anon_sym_symbol] = ACTIONS(1969),
    [anon_sym_object] = ACTIONS(1969),
    [anon_sym_satisfies] = ACTIONS(120),
    [sym__ternary_qmark] = ACTIONS(154),
    [sym_html_comment] = ACTIONS(5),
  },
  [257] = {
    [sym_identifier] = ACTIONS(1973),
    [anon_sym_export] = ACTIONS(1973),
    [anon_sym_STAR] = ACTIONS(120),
    [anon_sym_type] = ACTIONS(1973),
    [anon_sym_EQ] = ACTIONS(117),
    [anon_sym_as] = ACTIONS(120),
    [anon_sym_namespace] = ACTIONS(1973),
    [anon_sym_LBRACE] = ACTIONS(1975),
    [anon_sym_COMMA] = ACTIONS(126),
    [anon_sym_typeof] = ACTIONS(1973),
    [anon_sym_import] = ACTIONS(1973),
    [anon_sym_let] = ACTIONS(1973),
    [anon_sym_BANG] = ACTIONS(1973),
    [anon_sym_LPAREN] = ACTIONS(1975),
    [anon_sym_RPAREN] = ACTIONS(126),
    [anon_sym_await] = ACTIONS(1973),
    [anon_sym_in] = ACTIONS(120),
    [anon_sym_COLON] = ACTIONS(126),
    [anon_sym_yield] = ACTIONS(1973),
    [anon_sym_LBRACK] = ACTIONS(1975),
    [anon_sym_DOT] = ACTIONS(120),
    [anon_sym_class] = ACTIONS(1973),
    [anon_sym_async] = ACTIONS(1973),
    [anon_sym_function] = ACTIONS(1973),
    [anon_sym_EQ_GT] = ACTIONS(152),
    [anon_sym_QMARK_DOT] = ACTIONS(154),
    [anon_sym_new] = ACTIONS(1973),
    [anon_sym_using] = ACTIONS(1973),
    [anon_sym_PLUS_EQ] = ACTIONS(160),
    [anon_sym_DASH_EQ] = ACTIONS(160),
    [anon_sym_STAR_EQ] = ACTIONS(160),
    [anon_sym_SLASH_EQ] = ACTIONS(160),
    [anon_sym_PERCENT_EQ] = ACTIONS(160),
    [anon_sym_CARET_EQ] = ACTIONS(160),
    [anon_sym_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_LT_LT_EQ] = ACTIONS(160),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(160),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(160),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1975),
    [anon_sym_AMP_AMP] = ACTIONS(120),
    [anon_sym_PIPE_PIPE] = ACTIONS(120),
    [anon_sym_GT_GT] = ACTIONS(120),
    [anon_sym_GT_GT_GT] = ACTIONS(120),
    [anon_sym_LT_LT] = ACTIONS(120),
    [anon_sym_AMP] = ACTIONS(120),
    [anon_sym_CARET] = ACTIONS(120),
    [anon_sym_PIPE] = ACTIONS(120),
    [anon_sym_PLUS] = ACTIONS(1973),
    [anon_sym_DASH] = ACTIONS(1973),
    [anon_sym_SLASH] = ACTIONS(1973),
    [anon_sym_PERCENT] = ACTIONS(120),
    [anon_sym_STAR_STAR] = ACTIONS(120),
    [anon_sym_LT] = ACTIONS(1973),
    [anon_sym_LT_EQ] = ACTIONS(154),
    [anon_sym_EQ_EQ] = ACTIONS(120),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(154),
    [anon_sym_BANG_EQ] = ACTIONS(120),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(154),
    [anon_sym_GT_EQ] = ACTIONS(154),
    [anon_sym_GT] = ACTIONS(120),
    [anon_sym_QMARK_QMARK] = ACTIONS(120),
    [anon_sym_instanceof] = ACTIONS(120),
    [anon_sym_TILDE] = ACTIONS(1975),
    [anon_sym_void] = ACTIONS(1973),
    [anon_sym_delete] = ACTIONS(1973),
    [anon_sym_PLUS_PLUS] = ACTIONS(1975),
    [anon_sym_DASH_DASH] = ACTIONS(1975),
    [anon_sym_DQUOTE] = ACTIONS(1975),
    [anon_sym_SQUOTE] = ACTIONS(1975),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1975),
    [sym_number] = ACTIONS(1975),
    [sym_private_property_identifier] = ACTIONS(1975),
    [sym_this] = ACTIONS(1973),
    [sym_super] = ACTIONS(1973),
    [sym_true] = ACTIONS(1973),
    [sym_false] = ACTIONS(1973),
    [sym_null] = ACTIONS(1973),
    [sym_undefined] = ACTIONS(1973),
    [anon_sym_AT] = ACTIONS(1975),
    [anon_sym_static] = ACTIONS(1973),
    [anon_sym_readonly] = ACTIONS(1973),
    [anon_sym_get] = ACTIONS(1973),
    [anon_sym_set] = ACTIONS(1973),
    [anon_sym_QMARK] = ACTIONS(720),
    [anon_sym_declare] = ACTIONS(1973),
    [anon_sym_public] = ACTIONS(1973),
    [anon_sym_private] = ACTIONS(1973),
    [anon_sym_protected] = ACTIONS(1973),
    [anon_sym_override] = ACTIONS(1973),
    [anon_sym_module] = ACTIONS(1973),
    [anon_sym_any] = ACTIONS(1973),
    [anon_sym_number] = ACTIONS(1973),
    [anon_sym_boolean] = ACTIONS(1973),
    [anon_sym_string] = ACTIONS(1973),
    [anon_sym_symbol] = ACTIONS(1973),
    [anon_sym_object] = ACTIONS(1973),
    [anon_sym_satisfies] = ACTIONS(120),
    [sym__ternary_qmark] = ACTIONS(154),
    [sym_html_comment] = ACTIONS(5),
  },
  [258] = {
    [sym_identifier] = ACTIONS(1969),
    [anon_sym_export] = ACTIONS(1969),
    [anon_sym_STAR] = ACTIONS(120),
    [anon_sym_type] = ACTIONS(1969),
    [anon_sym_EQ] = ACTIONS(220),
    [anon_sym_as] = ACTIONS(120),
    [anon_sym_namespace] = ACTIONS(1969),
    [anon_sym_LBRACE] = ACTIONS(1971),
    [anon_sym_COMMA] = ACTIONS(223),
    [anon_sym_typeof] = ACTIONS(1969),
    [anon_sym_import] = ACTIONS(1969),
    [anon_sym_let] = ACTIONS(1969),
    [anon_sym_BANG] = ACTIONS(1969),
    [anon_sym_LPAREN] = ACTIONS(1971),
    [anon_sym_RPAREN] = ACTIONS(223),
    [anon_sym_await] = ACTIONS(1969),
    [anon_sym_in] = ACTIONS(120),
    [anon_sym_COLON] = ACTIONS(223),
    [anon_sym_yield] = ACTIONS(1969),
    [anon_sym_LBRACK] = ACTIONS(1971),
    [anon_sym_DOT] = ACTIONS(120),
    [anon_sym_class] = ACTIONS(1969),
    [anon_sym_async] = ACTIONS(1969),
    [anon_sym_function] = ACTIONS(1969),
    [anon_sym_EQ_GT] = ACTIONS(225),
    [anon_sym_QMARK_DOT] = ACTIONS(154),
    [anon_sym_new] = ACTIONS(1969),
    [anon_sym_using] = ACTIONS(1969),
    [anon_sym_PLUS_EQ] = ACTIONS(160),
    [anon_sym_DASH_EQ] = ACTIONS(160),
    [anon_sym_STAR_EQ] = ACTIONS(160),
    [anon_sym_SLASH_EQ] = ACTIONS(160),
    [anon_sym_PERCENT_EQ] = ACTIONS(160),
    [anon_sym_CARET_EQ] = ACTIONS(160),
    [anon_sym_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_LT_LT_EQ] = ACTIONS(160),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(160),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(160),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1971),
    [anon_sym_AMP_AMP] = ACTIONS(120),
    [anon_sym_PIPE_PIPE] = ACTIONS(120),
    [anon_sym_GT_GT] = ACTIONS(120),
    [anon_sym_GT_GT_GT] = ACTIONS(120),
    [anon_sym_LT_LT] = ACTIONS(120),
    [anon_sym_AMP] = ACTIONS(120),
    [anon_sym_CARET] = ACTIONS(120),
    [anon_sym_PIPE] = ACTIONS(120),
    [anon_sym_PLUS] = ACTIONS(1969),
    [anon_sym_DASH] = ACTIONS(1969),
    [anon_sym_SLASH] = ACTIONS(1969),
    [anon_sym_PERCENT] = ACTIONS(120),
    [anon_sym_STAR_STAR] = ACTIONS(120),
    [anon_sym_LT] = ACTIONS(1969),
    [anon_sym_LT_EQ] = ACTIONS(154),
    [anon_sym_EQ_EQ] = ACTIONS(120),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(154),
    [anon_sym_BANG_EQ] = ACTIONS(120),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(154),
    [anon_sym_GT_EQ] = ACTIONS(154),
    [anon_sym_GT] = ACTIONS(120),
    [anon_sym_QMARK_QMARK] = ACTIONS(120),
    [anon_sym_instanceof] = ACTIONS(120),
    [anon_sym_TILDE] = ACTIONS(1971),
    [anon_sym_void] = ACTIONS(1969),
    [anon_sym_delete] = ACTIONS(1969),
    [anon_sym_PLUS_PLUS] = ACTIONS(1971),
    [anon_sym_DASH_DASH] = ACTIONS(1971),
    [anon_sym_DQUOTE] = ACTIONS(1971),
    [anon_sym_SQUOTE] = ACTIONS(1971),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1971),
    [sym_number] = ACTIONS(1971),
    [sym_private_property_identifier] = ACTIONS(1971),
    [sym_this] = ACTIONS(1969),
    [sym_super] = ACTIONS(1969),
    [sym_true] = ACTIONS(1969),
    [sym_false] = ACTIONS(1969),
    [sym_null] = ACTIONS(1969),
    [sym_undefined] = ACTIONS(1969),
    [anon_sym_AT] = ACTIONS(1971),
    [anon_sym_static] = ACTIONS(1969),
    [anon_sym_readonly] = ACTIONS(1969),
    [anon_sym_get] = ACTIONS(1969),
    [anon_sym_set] = ACTIONS(1969),
    [anon_sym_QMARK] = ACTIONS(720),
    [anon_sym_declare] = ACTIONS(1969),
    [anon_sym_public] = ACTIONS(1969),
    [anon_sym_private] = ACTIONS(1969),
    [anon_sym_protected] = ACTIONS(1969),
    [anon_sym_override] = ACTIONS(1969),
    [anon_sym_module] = ACTIONS(1969),
    [anon_sym_any] = ACTIONS(1969),
    [anon_sym_number] = ACTIONS(1969),
    [anon_sym_boolean] = ACTIONS(1969),
    [anon_sym_string] = ACTIONS(1969),
    [anon_sym_symbol] = ACTIONS(1969),
    [anon_sym_object] = ACTIONS(1969),
    [anon_sym_satisfies] = ACTIONS(120),
    [sym__ternary_qmark] = ACTIONS(154),
    [sym_html_comment] = ACTIONS(5),
  },
  [259] = {
    [sym_identifier] = ACTIONS(1973),
    [anon_sym_export] = ACTIONS(1973),
    [anon_sym_STAR] = ACTIONS(120),
    [anon_sym_type] = ACTIONS(1973),
    [anon_sym_EQ] = ACTIONS(220),
    [anon_sym_as] = ACTIONS(120),
    [anon_sym_namespace] = ACTIONS(1973),
    [anon_sym_LBRACE] = ACTIONS(1975),
    [anon_sym_COMMA] = ACTIONS(223),
    [anon_sym_typeof] = ACTIONS(1973),
    [anon_sym_import] = ACTIONS(1973),
    [anon_sym_let] = ACTIONS(1973),
    [anon_sym_BANG] = ACTIONS(1973),
    [anon_sym_LPAREN] = ACTIONS(1975),
    [anon_sym_RPAREN] = ACTIONS(223),
    [anon_sym_await] = ACTIONS(1973),
    [anon_sym_in] = ACTIONS(120),
    [anon_sym_COLON] = ACTIONS(223),
    [anon_sym_yield] = ACTIONS(1973),
    [anon_sym_LBRACK] = ACTIONS(1975),
    [anon_sym_DOT] = ACTIONS(120),
    [anon_sym_class] = ACTIONS(1973),
    [anon_sym_async] = ACTIONS(1973),
    [anon_sym_function] = ACTIONS(1973),
    [anon_sym_EQ_GT] = ACTIONS(225),
    [anon_sym_QMARK_DOT] = ACTIONS(154),
    [anon_sym_new] = ACTIONS(1973),
    [anon_sym_using] = ACTIONS(1973),
    [anon_sym_PLUS_EQ] = ACTIONS(160),
    [anon_sym_DASH_EQ] = ACTIONS(160),
    [anon_sym_STAR_EQ] = ACTIONS(160),
    [anon_sym_SLASH_EQ] = ACTIONS(160),
    [anon_sym_PERCENT_EQ] = ACTIONS(160),
    [anon_sym_CARET_EQ] = ACTIONS(160),
    [anon_sym_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_LT_LT_EQ] = ACTIONS(160),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(160),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(160),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1975),
    [anon_sym_AMP_AMP] = ACTIONS(120),
    [anon_sym_PIPE_PIPE] = ACTIONS(120),
    [anon_sym_GT_GT] = ACTIONS(120),
    [anon_sym_GT_GT_GT] = ACTIONS(120),
    [anon_sym_LT_LT] = ACTIONS(120),
    [anon_sym_AMP] = ACTIONS(120),
    [anon_sym_CARET] = ACTIONS(120),
    [anon_sym_PIPE] = ACTIONS(120),
    [anon_sym_PLUS] = ACTIONS(1973),
    [anon_sym_DASH] = ACTIONS(1973),
    [anon_sym_SLASH] = ACTIONS(1973),
    [anon_sym_PERCENT] = ACTIONS(120),
    [anon_sym_STAR_STAR] = ACTIONS(120),
    [anon_sym_LT] = ACTIONS(1973),
    [anon_sym_LT_EQ] = ACTIONS(154),
    [anon_sym_EQ_EQ] = ACTIONS(120),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(154),
    [anon_sym_BANG_EQ] = ACTIONS(120),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(154),
    [anon_sym_GT_EQ] = ACTIONS(154),
    [anon_sym_GT] = ACTIONS(120),
    [anon_sym_QMARK_QMARK] = ACTIONS(120),
    [anon_sym_instanceof] = ACTIONS(120),
    [anon_sym_TILDE] = ACTIONS(1975),
    [anon_sym_void] = ACTIONS(1973),
    [anon_sym_delete] = ACTIONS(1973),
    [anon_sym_PLUS_PLUS] = ACTIONS(1975),
    [anon_sym_DASH_DASH] = ACTIONS(1975),
    [anon_sym_DQUOTE] = ACTIONS(1975),
    [anon_sym_SQUOTE] = ACTIONS(1975),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1975),
    [sym_number] = ACTIONS(1975),
    [sym_private_property_identifier] = ACTIONS(1975),
    [sym_this] = ACTIONS(1973),
    [sym_super] = ACTIONS(1973),
    [sym_true] = ACTIONS(1973),
    [sym_false] = ACTIONS(1973),
    [sym_null] = ACTIONS(1973),
    [sym_undefined] = ACTIONS(1973),
    [anon_sym_AT] = ACTIONS(1975),
    [anon_sym_static] = ACTIONS(1973),
    [anon_sym_readonly] = ACTIONS(1973),
    [anon_sym_get] = ACTIONS(1973),
    [anon_sym_set] = ACTIONS(1973),
    [anon_sym_QMARK] = ACTIONS(720),
    [anon_sym_declare] = ACTIONS(1973),
    [anon_sym_public] = ACTIONS(1973),
    [anon_sym_private] = ACTIONS(1973),
    [anon_sym_protected] = ACTIONS(1973),
    [anon_sym_override] = ACTIONS(1973),
    [anon_sym_module] = ACTIONS(1973),
    [anon_sym_any] = ACTIONS(1973),
    [anon_sym_number] = ACTIONS(1973),
    [anon_sym_boolean] = ACTIONS(1973),
    [anon_sym_string] = ACTIONS(1973),
    [anon_sym_symbol] = ACTIONS(1973),
    [anon_sym_object] = ACTIONS(1973),
    [anon_sym_satisfies] = ACTIONS(120),
    [sym__ternary_qmark] = ACTIONS(154),
    [sym_html_comment] = ACTIONS(5),
  },
  [260] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1457),
    [sym_expression] = STATE(2414),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5823),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5823),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5477),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1457),
    [sym_subscript_expression] = STATE(1457),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(2986),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5823),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1457),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(620),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1522),
    [anon_sym_export] = ACTIONS(1178),
    [anon_sym_type] = ACTIONS(1178),
    [anon_sym_namespace] = ACTIONS(1180),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_COMMA] = ACTIONS(1898),
    [anon_sym_typeof] = ACTIONS(1202),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1178),
    [anon_sym_BANG] = ACTIONS(1186),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(1188),
    [anon_sym_yield] = ACTIONS(1190),
    [anon_sym_LBRACK] = ACTIONS(1898),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1192),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1526),
    [anon_sym_using] = ACTIONS(1196),
    [anon_sym_AMP] = ACTIONS(1898),
    [anon_sym_PIPE] = ACTIONS(1898),
    [anon_sym_PLUS] = ACTIONS(1202),
    [anon_sym_DASH] = ACTIONS(1202),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_GT] = ACTIONS(1898),
    [anon_sym_TILDE] = ACTIONS(1186),
    [anon_sym_void] = ACTIONS(1202),
    [anon_sym_delete] = ACTIONS(1202),
    [anon_sym_PLUS_PLUS] = ACTIONS(1204),
    [anon_sym_DASH_DASH] = ACTIONS(1204),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(1206),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1528),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1178),
    [anon_sym_readonly] = ACTIONS(1178),
    [anon_sym_get] = ACTIONS(1178),
    [anon_sym_set] = ACTIONS(1178),
    [anon_sym_declare] = ACTIONS(1178),
    [anon_sym_public] = ACTIONS(1178),
    [anon_sym_private] = ACTIONS(1178),
    [anon_sym_protected] = ACTIONS(1178),
    [anon_sym_override] = ACTIONS(1178),
    [anon_sym_module] = ACTIONS(1178),
    [anon_sym_any] = ACTIONS(1178),
    [anon_sym_number] = ACTIONS(1178),
    [anon_sym_boolean] = ACTIONS(1178),
    [anon_sym_string] = ACTIONS(1178),
    [anon_sym_symbol] = ACTIONS(1178),
    [anon_sym_object] = ACTIONS(1178),
    [anon_sym_extends] = ACTIONS(1900),
    [sym_html_comment] = ACTIONS(5),
  },
  [261] = {
    [sym_import] = STATE(3636),
    [sym_parenthesized_expression] = STATE(1362),
    [sym_expression] = STATE(1814),
    [sym_primary_expression] = STATE(1810),
    [sym_yield_expression] = STATE(2358),
    [sym_object] = STATE(2222),
    [sym_object_pattern] = STATE(5492),
    [sym_array] = STATE(2222),
    [sym_array_pattern] = STATE(5492),
    [sym_class] = STATE(2222),
    [sym_function_expression] = STATE(2222),
    [sym_generator_function] = STATE(2222),
    [sym_arrow_function] = STATE(2222),
    [sym__call_signature] = STATE(5821),
    [sym_call_expression] = STATE(2222),
    [sym_new_expression] = STATE(1948),
    [sym_await_expression] = STATE(2358),
    [sym_member_expression] = STATE(1362),
    [sym_subscript_expression] = STATE(1362),
    [sym_assignment_expression] = STATE(2358),
    [sym__augmented_assignment_lhs] = STATE(3025),
    [sym_augmented_assignment_expression] = STATE(2358),
    [sym__destructuring_pattern] = STATE(5492),
    [sym_ternary_expression] = STATE(2358),
    [sym_binary_expression] = STATE(2358),
    [sym_unary_expression] = STATE(2358),
    [sym_update_expression] = STATE(2358),
    [sym_string] = STATE(2222),
    [sym_template_string] = STATE(2222),
    [sym_regex] = STATE(2222),
    [sym_meta_property] = STATE(2222),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1362),
    [sym_type_assertion] = STATE(2358),
    [sym_as_expression] = STATE(2358),
    [sym_satisfies_expression] = STATE(2358),
    [sym_instantiation_expression] = STATE(2358),
    [sym_internal_module] = STATE(2358),
    [sym_type_arguments] = STATE(428),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4408),
    [sym_identifier] = ACTIONS(1468),
    [anon_sym_export] = ACTIONS(1352),
    [anon_sym_type] = ACTIONS(1352),
    [anon_sym_namespace] = ACTIONS(1354),
    [anon_sym_LBRACE] = ACTIONS(665),
    [anon_sym_COMMA] = ACTIONS(1898),
    [anon_sym_typeof] = ACTIONS(21),
    [anon_sym_import] = ACTIONS(669),
    [anon_sym_let] = ACTIONS(1352),
    [anon_sym_BANG] = ACTIONS(33),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_await] = ACTIONS(45),
    [anon_sym_yield] = ACTIONS(63),
    [anon_sym_LBRACK] = ACTIONS(1898),
    [anon_sym_class] = ACTIONS(676),
    [anon_sym_async] = ACTIONS(1362),
    [anon_sym_function] = ACTIONS(680),
    [anon_sym_new] = ACTIONS(1472),
    [anon_sym_using] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(1898),
    [anon_sym_PIPE] = ACTIONS(1898),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_SLASH] = ACTIONS(77),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_GT] = ACTIONS(1898),
    [anon_sym_TILDE] = ACTIONS(33),
    [anon_sym_void] = ACTIONS(21),
    [anon_sym_delete] = ACTIONS(21),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_DQUOTE] = ACTIONS(83),
    [anon_sym_SQUOTE] = ACTIONS(85),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(87),
    [sym_number] = ACTIONS(89),
    [sym_private_property_identifier] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(93),
    [sym_true] = ACTIONS(93),
    [sym_false] = ACTIONS(93),
    [sym_null] = ACTIONS(93),
    [sym_undefined] = ACTIONS(95),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1352),
    [anon_sym_readonly] = ACTIONS(1352),
    [anon_sym_get] = ACTIONS(1352),
    [anon_sym_set] = ACTIONS(1352),
    [anon_sym_declare] = ACTIONS(1352),
    [anon_sym_public] = ACTIONS(1352),
    [anon_sym_private] = ACTIONS(1352),
    [anon_sym_protected] = ACTIONS(1352),
    [anon_sym_override] = ACTIONS(1352),
    [anon_sym_module] = ACTIONS(1352),
    [anon_sym_any] = ACTIONS(1352),
    [anon_sym_number] = ACTIONS(1352),
    [anon_sym_boolean] = ACTIONS(1352),
    [anon_sym_string] = ACTIONS(1352),
    [anon_sym_symbol] = ACTIONS(1352),
    [anon_sym_object] = ACTIONS(1352),
    [anon_sym_extends] = ACTIONS(1900),
    [sym_html_comment] = ACTIONS(5),
  },
  [262] = {
    [sym_import] = STATE(3636),
    [sym_parenthesized_expression] = STATE(1364),
    [sym_expression] = STATE(1873),
    [sym_primary_expression] = STATE(1810),
    [sym_yield_expression] = STATE(2358),
    [sym_object] = STATE(2222),
    [sym_object_pattern] = STATE(5773),
    [sym_array] = STATE(2222),
    [sym_array_pattern] = STATE(5773),
    [sym_class] = STATE(2222),
    [sym_function_expression] = STATE(2222),
    [sym_generator_function] = STATE(2222),
    [sym_arrow_function] = STATE(2222),
    [sym__call_signature] = STATE(5771),
    [sym_call_expression] = STATE(2222),
    [sym_new_expression] = STATE(1948),
    [sym_await_expression] = STATE(2358),
    [sym_member_expression] = STATE(1364),
    [sym_subscript_expression] = STATE(1364),
    [sym_assignment_expression] = STATE(2358),
    [sym__augmented_assignment_lhs] = STATE(3020),
    [sym_augmented_assignment_expression] = STATE(2358),
    [sym__destructuring_pattern] = STATE(5773),
    [sym_ternary_expression] = STATE(2358),
    [sym_binary_expression] = STATE(2358),
    [sym_unary_expression] = STATE(2358),
    [sym_update_expression] = STATE(2358),
    [sym_string] = STATE(2222),
    [sym_template_string] = STATE(2222),
    [sym_regex] = STATE(2222),
    [sym_meta_property] = STATE(2222),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1364),
    [sym_type_assertion] = STATE(2358),
    [sym_as_expression] = STATE(2358),
    [sym_satisfies_expression] = STATE(2358),
    [sym_instantiation_expression] = STATE(2358),
    [sym_internal_module] = STATE(2358),
    [sym_type_arguments] = STATE(513),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4408),
    [sym_identifier] = ACTIONS(1474),
    [anon_sym_export] = ACTIONS(1386),
    [anon_sym_type] = ACTIONS(1386),
    [anon_sym_namespace] = ACTIONS(1388),
    [anon_sym_LBRACE] = ACTIONS(665),
    [anon_sym_COMMA] = ACTIONS(1898),
    [anon_sym_typeof] = ACTIONS(1408),
    [anon_sym_import] = ACTIONS(669),
    [anon_sym_let] = ACTIONS(1386),
    [anon_sym_BANG] = ACTIONS(1392),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_await] = ACTIONS(1394),
    [anon_sym_yield] = ACTIONS(1396),
    [anon_sym_LBRACK] = ACTIONS(1898),
    [anon_sym_class] = ACTIONS(676),
    [anon_sym_async] = ACTIONS(1398),
    [anon_sym_function] = ACTIONS(680),
    [anon_sym_new] = ACTIONS(1478),
    [anon_sym_using] = ACTIONS(1402),
    [anon_sym_AMP] = ACTIONS(1898),
    [anon_sym_PIPE] = ACTIONS(1898),
    [anon_sym_PLUS] = ACTIONS(1408),
    [anon_sym_DASH] = ACTIONS(1408),
    [anon_sym_SLASH] = ACTIONS(876),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_GT] = ACTIONS(1898),
    [anon_sym_TILDE] = ACTIONS(1392),
    [anon_sym_void] = ACTIONS(1408),
    [anon_sym_delete] = ACTIONS(1408),
    [anon_sym_PLUS_PLUS] = ACTIONS(1410),
    [anon_sym_DASH_DASH] = ACTIONS(1410),
    [anon_sym_DQUOTE] = ACTIONS(83),
    [anon_sym_SQUOTE] = ACTIONS(85),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(87),
    [sym_number] = ACTIONS(89),
    [sym_private_property_identifier] = ACTIONS(1412),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(93),
    [sym_true] = ACTIONS(93),
    [sym_false] = ACTIONS(93),
    [sym_null] = ACTIONS(93),
    [sym_undefined] = ACTIONS(1480),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1386),
    [anon_sym_readonly] = ACTIONS(1386),
    [anon_sym_get] = ACTIONS(1386),
    [anon_sym_set] = ACTIONS(1386),
    [anon_sym_declare] = ACTIONS(1386),
    [anon_sym_public] = ACTIONS(1386),
    [anon_sym_private] = ACTIONS(1386),
    [anon_sym_protected] = ACTIONS(1386),
    [anon_sym_override] = ACTIONS(1386),
    [anon_sym_module] = ACTIONS(1386),
    [anon_sym_any] = ACTIONS(1386),
    [anon_sym_number] = ACTIONS(1386),
    [anon_sym_boolean] = ACTIONS(1386),
    [anon_sym_string] = ACTIONS(1386),
    [anon_sym_symbol] = ACTIONS(1386),
    [anon_sym_object] = ACTIONS(1386),
    [anon_sym_extends] = ACTIONS(1900),
    [sym_html_comment] = ACTIONS(5),
  },
  [263] = {
    [sym_import] = STATE(3636),
    [sym_parenthesized_expression] = STATE(1410),
    [sym_expression] = STATE(2239),
    [sym_primary_expression] = STATE(1810),
    [sym_yield_expression] = STATE(2358),
    [sym_object] = STATE(2222),
    [sym_object_pattern] = STATE(5580),
    [sym_array] = STATE(2222),
    [sym_array_pattern] = STATE(5580),
    [sym_class] = STATE(2222),
    [sym_function_expression] = STATE(2222),
    [sym_generator_function] = STATE(2222),
    [sym_arrow_function] = STATE(2222),
    [sym__call_signature] = STATE(5466),
    [sym_call_expression] = STATE(2222),
    [sym_new_expression] = STATE(1948),
    [sym_await_expression] = STATE(2358),
    [sym_member_expression] = STATE(1410),
    [sym_subscript_expression] = STATE(1410),
    [sym_assignment_expression] = STATE(2358),
    [sym__augmented_assignment_lhs] = STATE(3004),
    [sym_augmented_assignment_expression] = STATE(2358),
    [sym__destructuring_pattern] = STATE(5580),
    [sym_ternary_expression] = STATE(2358),
    [sym_binary_expression] = STATE(2358),
    [sym_unary_expression] = STATE(2358),
    [sym_update_expression] = STATE(2358),
    [sym_string] = STATE(2222),
    [sym_template_string] = STATE(2222),
    [sym_regex] = STATE(2222),
    [sym_meta_property] = STATE(2222),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1410),
    [sym_type_assertion] = STATE(2358),
    [sym_as_expression] = STATE(2358),
    [sym_satisfies_expression] = STATE(2358),
    [sym_instantiation_expression] = STATE(2358),
    [sym_internal_module] = STATE(2358),
    [sym_type_arguments] = STATE(452),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4408),
    [sym_identifier] = ACTIONS(1498),
    [anon_sym_export] = ACTIONS(1270),
    [anon_sym_type] = ACTIONS(1270),
    [anon_sym_namespace] = ACTIONS(1272),
    [anon_sym_LBRACE] = ACTIONS(665),
    [anon_sym_COMMA] = ACTIONS(1898),
    [anon_sym_typeof] = ACTIONS(1298),
    [anon_sym_import] = ACTIONS(669),
    [anon_sym_let] = ACTIONS(1270),
    [anon_sym_BANG] = ACTIONS(1278),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_await] = ACTIONS(1282),
    [anon_sym_yield] = ACTIONS(1284),
    [anon_sym_LBRACK] = ACTIONS(1898),
    [anon_sym_class] = ACTIONS(676),
    [anon_sym_async] = ACTIONS(1288),
    [anon_sym_function] = ACTIONS(680),
    [anon_sym_new] = ACTIONS(1502),
    [anon_sym_using] = ACTIONS(1292),
    [anon_sym_AMP] = ACTIONS(1898),
    [anon_sym_PIPE] = ACTIONS(1898),
    [anon_sym_PLUS] = ACTIONS(1298),
    [anon_sym_DASH] = ACTIONS(1298),
    [anon_sym_SLASH] = ACTIONS(77),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_GT] = ACTIONS(1898),
    [anon_sym_TILDE] = ACTIONS(1278),
    [anon_sym_void] = ACTIONS(1298),
    [anon_sym_delete] = ACTIONS(1298),
    [anon_sym_PLUS_PLUS] = ACTIONS(1300),
    [anon_sym_DASH_DASH] = ACTIONS(1300),
    [anon_sym_DQUOTE] = ACTIONS(83),
    [anon_sym_SQUOTE] = ACTIONS(85),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(87),
    [sym_number] = ACTIONS(89),
    [sym_private_property_identifier] = ACTIONS(1306),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(93),
    [sym_true] = ACTIONS(93),
    [sym_false] = ACTIONS(93),
    [sym_null] = ACTIONS(93),
    [sym_undefined] = ACTIONS(1504),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1270),
    [anon_sym_readonly] = ACTIONS(1270),
    [anon_sym_get] = ACTIONS(1270),
    [anon_sym_set] = ACTIONS(1270),
    [anon_sym_declare] = ACTIONS(1270),
    [anon_sym_public] = ACTIONS(1270),
    [anon_sym_private] = ACTIONS(1270),
    [anon_sym_protected] = ACTIONS(1270),
    [anon_sym_override] = ACTIONS(1270),
    [anon_sym_module] = ACTIONS(1270),
    [anon_sym_any] = ACTIONS(1270),
    [anon_sym_number] = ACTIONS(1270),
    [anon_sym_boolean] = ACTIONS(1270),
    [anon_sym_string] = ACTIONS(1270),
    [anon_sym_symbol] = ACTIONS(1270),
    [anon_sym_object] = ACTIONS(1270),
    [anon_sym_extends] = ACTIONS(1900),
    [sym_html_comment] = ACTIONS(5),
  },
  [264] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1398),
    [sym_expression] = STATE(2231),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5544),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5544),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5558),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1398),
    [sym_subscript_expression] = STATE(1398),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(2980),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5544),
    [sym_spread_element] = STATE(4590),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1398),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(638),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [aux_sym_array_repeat1] = STATE(4591),
    [sym_identifier] = ACTIONS(1482),
    [anon_sym_export] = ACTIONS(1158),
    [anon_sym_type] = ACTIONS(1158),
    [anon_sym_namespace] = ACTIONS(1160),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_COMMA] = ACTIONS(1977),
    [anon_sym_typeof] = ACTIONS(756),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1158),
    [anon_sym_BANG] = ACTIONS(732),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_RPAREN] = ACTIONS(1979),
    [anon_sym_await] = ACTIONS(736),
    [anon_sym_yield] = ACTIONS(738),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1164),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1486),
    [anon_sym_using] = ACTIONS(746),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1981),
    [anon_sym_PLUS] = ACTIONS(756),
    [anon_sym_DASH] = ACTIONS(756),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(732),
    [anon_sym_void] = ACTIONS(756),
    [anon_sym_delete] = ACTIONS(756),
    [anon_sym_PLUS_PLUS] = ACTIONS(758),
    [anon_sym_DASH_DASH] = ACTIONS(758),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(764),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1488),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1158),
    [anon_sym_readonly] = ACTIONS(1158),
    [anon_sym_get] = ACTIONS(1158),
    [anon_sym_set] = ACTIONS(1158),
    [anon_sym_declare] = ACTIONS(1158),
    [anon_sym_public] = ACTIONS(1158),
    [anon_sym_private] = ACTIONS(1158),
    [anon_sym_protected] = ACTIONS(1158),
    [anon_sym_override] = ACTIONS(1158),
    [anon_sym_module] = ACTIONS(1158),
    [anon_sym_any] = ACTIONS(1158),
    [anon_sym_number] = ACTIONS(1158),
    [anon_sym_boolean] = ACTIONS(1158),
    [anon_sym_string] = ACTIONS(1158),
    [anon_sym_symbol] = ACTIONS(1158),
    [anon_sym_object] = ACTIONS(1158),
    [sym_html_comment] = ACTIONS(5),
  },
  [265] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1398),
    [sym_expression] = STATE(2142),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5544),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5544),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5558),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1398),
    [sym_subscript_expression] = STATE(1398),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(2980),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5544),
    [sym_spread_element] = STATE(5115),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1398),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(638),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [aux_sym_array_repeat1] = STATE(5116),
    [sym_identifier] = ACTIONS(1482),
    [anon_sym_export] = ACTIONS(1158),
    [anon_sym_type] = ACTIONS(1158),
    [anon_sym_namespace] = ACTIONS(1160),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_COMMA] = ACTIONS(1977),
    [anon_sym_typeof] = ACTIONS(756),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1158),
    [anon_sym_BANG] = ACTIONS(732),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_RPAREN] = ACTIONS(1983),
    [anon_sym_await] = ACTIONS(736),
    [anon_sym_yield] = ACTIONS(738),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1164),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1486),
    [anon_sym_using] = ACTIONS(746),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1981),
    [anon_sym_PLUS] = ACTIONS(756),
    [anon_sym_DASH] = ACTIONS(756),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(732),
    [anon_sym_void] = ACTIONS(756),
    [anon_sym_delete] = ACTIONS(756),
    [anon_sym_PLUS_PLUS] = ACTIONS(758),
    [anon_sym_DASH_DASH] = ACTIONS(758),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(764),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1488),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1158),
    [anon_sym_readonly] = ACTIONS(1158),
    [anon_sym_get] = ACTIONS(1158),
    [anon_sym_set] = ACTIONS(1158),
    [anon_sym_declare] = ACTIONS(1158),
    [anon_sym_public] = ACTIONS(1158),
    [anon_sym_private] = ACTIONS(1158),
    [anon_sym_protected] = ACTIONS(1158),
    [anon_sym_override] = ACTIONS(1158),
    [anon_sym_module] = ACTIONS(1158),
    [anon_sym_any] = ACTIONS(1158),
    [anon_sym_number] = ACTIONS(1158),
    [anon_sym_boolean] = ACTIONS(1158),
    [anon_sym_string] = ACTIONS(1158),
    [anon_sym_symbol] = ACTIONS(1158),
    [anon_sym_object] = ACTIONS(1158),
    [sym_html_comment] = ACTIONS(5),
  },
  [266] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1398),
    [sym_expression] = STATE(2237),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5544),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5544),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5558),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1398),
    [sym_subscript_expression] = STATE(1398),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(2980),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5544),
    [sym_spread_element] = STATE(4638),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1398),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(638),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [aux_sym_array_repeat1] = STATE(4639),
    [sym_identifier] = ACTIONS(1482),
    [anon_sym_export] = ACTIONS(1158),
    [anon_sym_type] = ACTIONS(1158),
    [anon_sym_namespace] = ACTIONS(1160),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_COMMA] = ACTIONS(1977),
    [anon_sym_typeof] = ACTIONS(756),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1158),
    [anon_sym_BANG] = ACTIONS(732),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_RPAREN] = ACTIONS(1985),
    [anon_sym_await] = ACTIONS(736),
    [anon_sym_yield] = ACTIONS(738),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1164),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1486),
    [anon_sym_using] = ACTIONS(746),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1981),
    [anon_sym_PLUS] = ACTIONS(756),
    [anon_sym_DASH] = ACTIONS(756),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(732),
    [anon_sym_void] = ACTIONS(756),
    [anon_sym_delete] = ACTIONS(756),
    [anon_sym_PLUS_PLUS] = ACTIONS(758),
    [anon_sym_DASH_DASH] = ACTIONS(758),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(764),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1488),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1158),
    [anon_sym_readonly] = ACTIONS(1158),
    [anon_sym_get] = ACTIONS(1158),
    [anon_sym_set] = ACTIONS(1158),
    [anon_sym_declare] = ACTIONS(1158),
    [anon_sym_public] = ACTIONS(1158),
    [anon_sym_private] = ACTIONS(1158),
    [anon_sym_protected] = ACTIONS(1158),
    [anon_sym_override] = ACTIONS(1158),
    [anon_sym_module] = ACTIONS(1158),
    [anon_sym_any] = ACTIONS(1158),
    [anon_sym_number] = ACTIONS(1158),
    [anon_sym_boolean] = ACTIONS(1158),
    [anon_sym_string] = ACTIONS(1158),
    [anon_sym_symbol] = ACTIONS(1158),
    [anon_sym_object] = ACTIONS(1158),
    [sym_html_comment] = ACTIONS(5),
  },
  [267] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1213),
    [sym_expression] = STATE(2644),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(3722),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(3722),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5800),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1295),
    [sym_subscript_expression] = STATE(1295),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3013),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(3722),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_pattern] = STATE(4285),
    [sym_rest_pattern] = STATE(3684),
    [sym_non_null_expression] = STATE(1295),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_accessibility_modifier] = STATE(279),
    [sym_override_modifier] = STATE(298),
    [sym_type_arguments] = STATE(539),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(1297),
    [sym_identifier] = ACTIONS(696),
    [anon_sym_export] = ACTIONS(113),
    [anon_sym_type] = ACTIONS(113),
    [anon_sym_namespace] = ACTIONS(122),
    [anon_sym_LBRACE] = ACTIONS(698),
    [anon_sym_typeof] = ACTIONS(179),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(113),
    [anon_sym_BANG] = ACTIONS(175),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(140),
    [anon_sym_yield] = ACTIONS(142),
    [anon_sym_LBRACK] = ACTIONS(1664),
    [anon_sym_class] = ACTIONS(1987),
    [anon_sym_async] = ACTIONS(148),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(706),
    [anon_sym_using] = ACTIONS(158),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(162),
    [anon_sym_PLUS] = ACTIONS(179),
    [anon_sym_DASH] = ACTIONS(179),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(175),
    [anon_sym_void] = ACTIONS(179),
    [anon_sym_delete] = ACTIONS(179),
    [anon_sym_PLUS_PLUS] = ACTIONS(686),
    [anon_sym_DASH_DASH] = ACTIONS(686),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(192),
    [sym_this] = ACTIONS(1989),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(718),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(113),
    [anon_sym_readonly] = ACTIONS(1991),
    [anon_sym_get] = ACTIONS(113),
    [anon_sym_set] = ACTIONS(113),
    [anon_sym_declare] = ACTIONS(113),
    [anon_sym_public] = ACTIONS(798),
    [anon_sym_private] = ACTIONS(798),
    [anon_sym_protected] = ACTIONS(798),
    [anon_sym_override] = ACTIONS(800),
    [anon_sym_module] = ACTIONS(113),
    [anon_sym_any] = ACTIONS(113),
    [anon_sym_number] = ACTIONS(113),
    [anon_sym_boolean] = ACTIONS(113),
    [anon_sym_string] = ACTIONS(113),
    [anon_sym_symbol] = ACTIONS(113),
    [anon_sym_object] = ACTIONS(113),
    [sym_html_comment] = ACTIONS(5),
  },
  [268] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1398),
    [sym_expression] = STATE(2238),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5544),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5544),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5558),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1398),
    [sym_subscript_expression] = STATE(1398),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(2980),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5544),
    [sym_spread_element] = STATE(4653),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1398),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(638),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [aux_sym_array_repeat1] = STATE(4654),
    [sym_identifier] = ACTIONS(1482),
    [anon_sym_export] = ACTIONS(1158),
    [anon_sym_type] = ACTIONS(1158),
    [anon_sym_namespace] = ACTIONS(1160),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_COMMA] = ACTIONS(1977),
    [anon_sym_typeof] = ACTIONS(756),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1158),
    [anon_sym_BANG] = ACTIONS(732),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_RPAREN] = ACTIONS(1993),
    [anon_sym_await] = ACTIONS(736),
    [anon_sym_yield] = ACTIONS(738),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1164),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1486),
    [anon_sym_using] = ACTIONS(746),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1981),
    [anon_sym_PLUS] = ACTIONS(756),
    [anon_sym_DASH] = ACTIONS(756),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(732),
    [anon_sym_void] = ACTIONS(756),
    [anon_sym_delete] = ACTIONS(756),
    [anon_sym_PLUS_PLUS] = ACTIONS(758),
    [anon_sym_DASH_DASH] = ACTIONS(758),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(764),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1488),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1158),
    [anon_sym_readonly] = ACTIONS(1158),
    [anon_sym_get] = ACTIONS(1158),
    [anon_sym_set] = ACTIONS(1158),
    [anon_sym_declare] = ACTIONS(1158),
    [anon_sym_public] = ACTIONS(1158),
    [anon_sym_private] = ACTIONS(1158),
    [anon_sym_protected] = ACTIONS(1158),
    [anon_sym_override] = ACTIONS(1158),
    [anon_sym_module] = ACTIONS(1158),
    [anon_sym_any] = ACTIONS(1158),
    [anon_sym_number] = ACTIONS(1158),
    [anon_sym_boolean] = ACTIONS(1158),
    [anon_sym_string] = ACTIONS(1158),
    [anon_sym_symbol] = ACTIONS(1158),
    [anon_sym_object] = ACTIONS(1158),
    [sym_html_comment] = ACTIONS(5),
  },
  [269] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1398),
    [sym_expression] = STATE(2212),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5544),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5544),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5558),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1398),
    [sym_subscript_expression] = STATE(1398),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(2980),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5544),
    [sym_spread_element] = STATE(5008),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1398),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(638),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [aux_sym_array_repeat1] = STATE(5011),
    [sym_identifier] = ACTIONS(1482),
    [anon_sym_export] = ACTIONS(1158),
    [anon_sym_type] = ACTIONS(1158),
    [anon_sym_namespace] = ACTIONS(1160),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_COMMA] = ACTIONS(1977),
    [anon_sym_typeof] = ACTIONS(756),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1158),
    [anon_sym_BANG] = ACTIONS(732),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_RPAREN] = ACTIONS(1995),
    [anon_sym_await] = ACTIONS(736),
    [anon_sym_yield] = ACTIONS(738),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1164),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1486),
    [anon_sym_using] = ACTIONS(746),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1981),
    [anon_sym_PLUS] = ACTIONS(756),
    [anon_sym_DASH] = ACTIONS(756),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(732),
    [anon_sym_void] = ACTIONS(756),
    [anon_sym_delete] = ACTIONS(756),
    [anon_sym_PLUS_PLUS] = ACTIONS(758),
    [anon_sym_DASH_DASH] = ACTIONS(758),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(764),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1488),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1158),
    [anon_sym_readonly] = ACTIONS(1158),
    [anon_sym_get] = ACTIONS(1158),
    [anon_sym_set] = ACTIONS(1158),
    [anon_sym_declare] = ACTIONS(1158),
    [anon_sym_public] = ACTIONS(1158),
    [anon_sym_private] = ACTIONS(1158),
    [anon_sym_protected] = ACTIONS(1158),
    [anon_sym_override] = ACTIONS(1158),
    [anon_sym_module] = ACTIONS(1158),
    [anon_sym_any] = ACTIONS(1158),
    [anon_sym_number] = ACTIONS(1158),
    [anon_sym_boolean] = ACTIONS(1158),
    [anon_sym_string] = ACTIONS(1158),
    [anon_sym_symbol] = ACTIONS(1158),
    [anon_sym_object] = ACTIONS(1158),
    [sym_html_comment] = ACTIONS(5),
  },
  [270] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1387),
    [sym_expression] = STATE(2106),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5803),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5803),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5585),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1387),
    [sym_subscript_expression] = STATE(1387),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3009),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5803),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1387),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(566),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1490),
    [anon_sym_export] = ACTIONS(1422),
    [anon_sym_type] = ACTIONS(1422),
    [anon_sym_namespace] = ACTIONS(1424),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_COMMA] = ACTIONS(1898),
    [anon_sym_typeof] = ACTIONS(1444),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1422),
    [anon_sym_BANG] = ACTIONS(1428),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(1430),
    [anon_sym_yield] = ACTIONS(1432),
    [anon_sym_LBRACK] = ACTIONS(1898),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1434),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1494),
    [anon_sym_using] = ACTIONS(1438),
    [anon_sym_AMP] = ACTIONS(1898),
    [anon_sym_PIPE] = ACTIONS(1898),
    [anon_sym_PLUS] = ACTIONS(1444),
    [anon_sym_DASH] = ACTIONS(1444),
    [anon_sym_SLASH] = ACTIONS(942),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_GT] = ACTIONS(1898),
    [anon_sym_TILDE] = ACTIONS(1428),
    [anon_sym_void] = ACTIONS(1444),
    [anon_sym_delete] = ACTIONS(1444),
    [anon_sym_PLUS_PLUS] = ACTIONS(1446),
    [anon_sym_DASH_DASH] = ACTIONS(1446),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(1448),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1496),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1422),
    [anon_sym_readonly] = ACTIONS(1422),
    [anon_sym_get] = ACTIONS(1422),
    [anon_sym_set] = ACTIONS(1422),
    [anon_sym_declare] = ACTIONS(1422),
    [anon_sym_public] = ACTIONS(1422),
    [anon_sym_private] = ACTIONS(1422),
    [anon_sym_protected] = ACTIONS(1422),
    [anon_sym_override] = ACTIONS(1422),
    [anon_sym_module] = ACTIONS(1422),
    [anon_sym_any] = ACTIONS(1422),
    [anon_sym_number] = ACTIONS(1422),
    [anon_sym_boolean] = ACTIONS(1422),
    [anon_sym_string] = ACTIONS(1422),
    [anon_sym_symbol] = ACTIONS(1422),
    [anon_sym_object] = ACTIONS(1422),
    [anon_sym_extends] = ACTIONS(1900),
    [sym_html_comment] = ACTIONS(5),
  },
  [271] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1398),
    [sym_expression] = STATE(2208),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5544),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5544),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5558),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1398),
    [sym_subscript_expression] = STATE(1398),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(2980),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5544),
    [sym_spread_element] = STATE(4789),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1398),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(638),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [aux_sym_array_repeat1] = STATE(4790),
    [sym_identifier] = ACTIONS(1482),
    [anon_sym_export] = ACTIONS(1158),
    [anon_sym_type] = ACTIONS(1158),
    [anon_sym_namespace] = ACTIONS(1160),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_COMMA] = ACTIONS(1977),
    [anon_sym_typeof] = ACTIONS(756),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1158),
    [anon_sym_BANG] = ACTIONS(732),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_RPAREN] = ACTIONS(1997),
    [anon_sym_await] = ACTIONS(736),
    [anon_sym_yield] = ACTIONS(738),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1164),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1486),
    [anon_sym_using] = ACTIONS(746),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1981),
    [anon_sym_PLUS] = ACTIONS(756),
    [anon_sym_DASH] = ACTIONS(756),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(732),
    [anon_sym_void] = ACTIONS(756),
    [anon_sym_delete] = ACTIONS(756),
    [anon_sym_PLUS_PLUS] = ACTIONS(758),
    [anon_sym_DASH_DASH] = ACTIONS(758),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(764),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1488),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1158),
    [anon_sym_readonly] = ACTIONS(1158),
    [anon_sym_get] = ACTIONS(1158),
    [anon_sym_set] = ACTIONS(1158),
    [anon_sym_declare] = ACTIONS(1158),
    [anon_sym_public] = ACTIONS(1158),
    [anon_sym_private] = ACTIONS(1158),
    [anon_sym_protected] = ACTIONS(1158),
    [anon_sym_override] = ACTIONS(1158),
    [anon_sym_module] = ACTIONS(1158),
    [anon_sym_any] = ACTIONS(1158),
    [anon_sym_number] = ACTIONS(1158),
    [anon_sym_boolean] = ACTIONS(1158),
    [anon_sym_string] = ACTIONS(1158),
    [anon_sym_symbol] = ACTIONS(1158),
    [anon_sym_object] = ACTIONS(1158),
    [sym_html_comment] = ACTIONS(5),
  },
  [272] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1459),
    [sym_expression] = STATE(2514),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5827),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5827),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5529),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1459),
    [sym_subscript_expression] = STATE(1459),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(2979),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5827),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1459),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(647),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1514),
    [anon_sym_export] = ACTIONS(1074),
    [anon_sym_type] = ACTIONS(1074),
    [anon_sym_namespace] = ACTIONS(1076),
    [anon_sym_LBRACE] = ACTIONS(808),
    [anon_sym_COMMA] = ACTIONS(1898),
    [anon_sym_typeof] = ACTIONS(1100),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1074),
    [anon_sym_BANG] = ACTIONS(1082),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(1084),
    [anon_sym_yield] = ACTIONS(1086),
    [anon_sym_LBRACK] = ACTIONS(1898),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1090),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1518),
    [anon_sym_using] = ACTIONS(1094),
    [anon_sym_AMP] = ACTIONS(1898),
    [anon_sym_PIPE] = ACTIONS(1898),
    [anon_sym_PLUS] = ACTIONS(1100),
    [anon_sym_DASH] = ACTIONS(1100),
    [anon_sym_SLASH] = ACTIONS(958),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_GT] = ACTIONS(1898),
    [anon_sym_TILDE] = ACTIONS(1082),
    [anon_sym_void] = ACTIONS(1100),
    [anon_sym_delete] = ACTIONS(1100),
    [anon_sym_PLUS_PLUS] = ACTIONS(1102),
    [anon_sym_DASH_DASH] = ACTIONS(1102),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(1108),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1520),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1074),
    [anon_sym_readonly] = ACTIONS(1074),
    [anon_sym_get] = ACTIONS(1074),
    [anon_sym_set] = ACTIONS(1074),
    [anon_sym_declare] = ACTIONS(1074),
    [anon_sym_public] = ACTIONS(1074),
    [anon_sym_private] = ACTIONS(1074),
    [anon_sym_protected] = ACTIONS(1074),
    [anon_sym_override] = ACTIONS(1074),
    [anon_sym_module] = ACTIONS(1074),
    [anon_sym_any] = ACTIONS(1074),
    [anon_sym_number] = ACTIONS(1074),
    [anon_sym_boolean] = ACTIONS(1074),
    [anon_sym_string] = ACTIONS(1074),
    [anon_sym_symbol] = ACTIONS(1074),
    [anon_sym_object] = ACTIONS(1074),
    [anon_sym_extends] = ACTIONS(1900),
    [sym_html_comment] = ACTIONS(5),
  },
  [273] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1398),
    [sym_expression] = STATE(2219),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5544),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5544),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5558),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1398),
    [sym_subscript_expression] = STATE(1398),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(2980),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5544),
    [sym_spread_element] = STATE(4544),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1398),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(638),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [aux_sym_array_repeat1] = STATE(4545),
    [sym_identifier] = ACTIONS(1482),
    [anon_sym_export] = ACTIONS(1158),
    [anon_sym_type] = ACTIONS(1158),
    [anon_sym_namespace] = ACTIONS(1160),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_COMMA] = ACTIONS(1977),
    [anon_sym_typeof] = ACTIONS(756),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1158),
    [anon_sym_BANG] = ACTIONS(732),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_RPAREN] = ACTIONS(1999),
    [anon_sym_await] = ACTIONS(736),
    [anon_sym_yield] = ACTIONS(738),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1164),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1486),
    [anon_sym_using] = ACTIONS(746),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1981),
    [anon_sym_PLUS] = ACTIONS(756),
    [anon_sym_DASH] = ACTIONS(756),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(732),
    [anon_sym_void] = ACTIONS(756),
    [anon_sym_delete] = ACTIONS(756),
    [anon_sym_PLUS_PLUS] = ACTIONS(758),
    [anon_sym_DASH_DASH] = ACTIONS(758),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(764),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1488),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1158),
    [anon_sym_readonly] = ACTIONS(1158),
    [anon_sym_get] = ACTIONS(1158),
    [anon_sym_set] = ACTIONS(1158),
    [anon_sym_declare] = ACTIONS(1158),
    [anon_sym_public] = ACTIONS(1158),
    [anon_sym_private] = ACTIONS(1158),
    [anon_sym_protected] = ACTIONS(1158),
    [anon_sym_override] = ACTIONS(1158),
    [anon_sym_module] = ACTIONS(1158),
    [anon_sym_any] = ACTIONS(1158),
    [anon_sym_number] = ACTIONS(1158),
    [anon_sym_boolean] = ACTIONS(1158),
    [anon_sym_string] = ACTIONS(1158),
    [anon_sym_symbol] = ACTIONS(1158),
    [anon_sym_object] = ACTIONS(1158),
    [sym_html_comment] = ACTIONS(5),
  },
  [274] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1456),
    [sym_expression] = STATE(2404),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5815),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5815),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5755),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1456),
    [sym_subscript_expression] = STATE(1456),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3029),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5815),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1456),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(594),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1506),
    [anon_sym_export] = ACTIONS(1234),
    [anon_sym_type] = ACTIONS(1234),
    [anon_sym_namespace] = ACTIONS(1236),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_COMMA] = ACTIONS(1898),
    [anon_sym_typeof] = ACTIONS(1256),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1234),
    [anon_sym_BANG] = ACTIONS(1240),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(1242),
    [anon_sym_yield] = ACTIONS(1244),
    [anon_sym_LBRACK] = ACTIONS(1898),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1246),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1510),
    [anon_sym_using] = ACTIONS(1250),
    [anon_sym_AMP] = ACTIONS(1898),
    [anon_sym_PIPE] = ACTIONS(1898),
    [anon_sym_PLUS] = ACTIONS(1256),
    [anon_sym_DASH] = ACTIONS(1256),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_GT] = ACTIONS(1898),
    [anon_sym_TILDE] = ACTIONS(1240),
    [anon_sym_void] = ACTIONS(1256),
    [anon_sym_delete] = ACTIONS(1256),
    [anon_sym_PLUS_PLUS] = ACTIONS(1258),
    [anon_sym_DASH_DASH] = ACTIONS(1258),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(1260),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1512),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1234),
    [anon_sym_readonly] = ACTIONS(1234),
    [anon_sym_get] = ACTIONS(1234),
    [anon_sym_set] = ACTIONS(1234),
    [anon_sym_declare] = ACTIONS(1234),
    [anon_sym_public] = ACTIONS(1234),
    [anon_sym_private] = ACTIONS(1234),
    [anon_sym_protected] = ACTIONS(1234),
    [anon_sym_override] = ACTIONS(1234),
    [anon_sym_module] = ACTIONS(1234),
    [anon_sym_any] = ACTIONS(1234),
    [anon_sym_number] = ACTIONS(1234),
    [anon_sym_boolean] = ACTIONS(1234),
    [anon_sym_string] = ACTIONS(1234),
    [anon_sym_symbol] = ACTIONS(1234),
    [anon_sym_object] = ACTIONS(1234),
    [anon_sym_extends] = ACTIONS(1900),
    [sym_html_comment] = ACTIONS(5),
  },
  [275] = {
    [sym_import] = STATE(3575),
    [sym_parenthesized_expression] = STATE(1322),
    [sym_expression] = STATE(1776),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5698),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5698),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5508),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1322),
    [sym_subscript_expression] = STATE(1322),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3003),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5698),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1322),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym__type_query_member_expression] = STATE(2931),
    [sym__type_query_subscript_expression] = STATE(2933),
    [sym__type_query_call_expression] = STATE(3124),
    [sym__type_query_instantiation_expression] = STATE(3280),
    [sym_type_arguments] = STATE(484),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(2001),
    [anon_sym_export] = ACTIONS(1048),
    [anon_sym_type] = ACTIONS(1048),
    [anon_sym_namespace] = ACTIONS(1050),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_typeof] = ACTIONS(581),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1048),
    [anon_sym_BANG] = ACTIONS(553),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(555),
    [anon_sym_yield] = ACTIONS(557),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1058),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1464),
    [anon_sym_using] = ACTIONS(567),
    [anon_sym_PLUS] = ACTIONS(581),
    [anon_sym_DASH] = ACTIONS(581),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(553),
    [anon_sym_void] = ACTIONS(581),
    [anon_sym_delete] = ACTIONS(581),
    [anon_sym_PLUS_PLUS] = ACTIONS(583),
    [anon_sym_DASH_DASH] = ACTIONS(583),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(585),
    [sym_this] = ACTIONS(2003),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1466),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1048),
    [anon_sym_readonly] = ACTIONS(1048),
    [anon_sym_get] = ACTIONS(1048),
    [anon_sym_set] = ACTIONS(1048),
    [anon_sym_declare] = ACTIONS(1048),
    [anon_sym_public] = ACTIONS(1048),
    [anon_sym_private] = ACTIONS(1048),
    [anon_sym_protected] = ACTIONS(1048),
    [anon_sym_override] = ACTIONS(1048),
    [anon_sym_module] = ACTIONS(1048),
    [anon_sym_any] = ACTIONS(1048),
    [anon_sym_number] = ACTIONS(1048),
    [anon_sym_boolean] = ACTIONS(1048),
    [anon_sym_string] = ACTIONS(1048),
    [anon_sym_symbol] = ACTIONS(1048),
    [anon_sym_object] = ACTIONS(1048),
    [sym_html_comment] = ACTIONS(5),
  },
  [276] = {
    [sym_import] = STATE(3609),
    [sym_parenthesized_expression] = STATE(1459),
    [sym_expression] = STATE(2514),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5827),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5827),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5529),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1459),
    [sym_subscript_expression] = STATE(1459),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(2979),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5827),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1459),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym__type_query_member_expression] = STATE(2876),
    [sym__type_query_subscript_expression] = STATE(2877),
    [sym__type_query_call_expression] = STATE(2922),
    [sym__type_query_instantiation_expression] = STATE(3010),
    [sym_type_arguments] = STATE(647),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(2005),
    [anon_sym_export] = ACTIONS(1074),
    [anon_sym_type] = ACTIONS(1074),
    [anon_sym_namespace] = ACTIONS(1076),
    [anon_sym_LBRACE] = ACTIONS(808),
    [anon_sym_typeof] = ACTIONS(1100),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1074),
    [anon_sym_BANG] = ACTIONS(1082),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(1084),
    [anon_sym_yield] = ACTIONS(1086),
    [anon_sym_LBRACK] = ACTIONS(812),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1090),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1518),
    [anon_sym_using] = ACTIONS(1094),
    [anon_sym_PLUS] = ACTIONS(1100),
    [anon_sym_DASH] = ACTIONS(1100),
    [anon_sym_SLASH] = ACTIONS(958),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(1082),
    [anon_sym_void] = ACTIONS(1100),
    [anon_sym_delete] = ACTIONS(1100),
    [anon_sym_PLUS_PLUS] = ACTIONS(1102),
    [anon_sym_DASH_DASH] = ACTIONS(1102),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(1108),
    [sym_this] = ACTIONS(2007),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1520),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1074),
    [anon_sym_readonly] = ACTIONS(1074),
    [anon_sym_get] = ACTIONS(1074),
    [anon_sym_set] = ACTIONS(1074),
    [anon_sym_declare] = ACTIONS(1074),
    [anon_sym_public] = ACTIONS(1074),
    [anon_sym_private] = ACTIONS(1074),
    [anon_sym_protected] = ACTIONS(1074),
    [anon_sym_override] = ACTIONS(1074),
    [anon_sym_module] = ACTIONS(1074),
    [anon_sym_any] = ACTIONS(1074),
    [anon_sym_number] = ACTIONS(1074),
    [anon_sym_boolean] = ACTIONS(1074),
    [anon_sym_string] = ACTIONS(1074),
    [anon_sym_symbol] = ACTIONS(1074),
    [anon_sym_object] = ACTIONS(1074),
    [sym_html_comment] = ACTIONS(5),
  },
  [277] = {
    [sym_import] = STATE(3739),
    [sym_parenthesized_expression] = STATE(1362),
    [sym_expression] = STATE(1814),
    [sym_primary_expression] = STATE(1810),
    [sym_yield_expression] = STATE(2358),
    [sym_object] = STATE(2222),
    [sym_object_pattern] = STATE(5492),
    [sym_array] = STATE(2222),
    [sym_array_pattern] = STATE(5492),
    [sym_class] = STATE(2222),
    [sym_function_expression] = STATE(2222),
    [sym_generator_function] = STATE(2222),
    [sym_arrow_function] = STATE(2222),
    [sym__call_signature] = STATE(5821),
    [sym_call_expression] = STATE(2222),
    [sym_new_expression] = STATE(1948),
    [sym_await_expression] = STATE(2358),
    [sym_member_expression] = STATE(1362),
    [sym_subscript_expression] = STATE(1362),
    [sym_assignment_expression] = STATE(2358),
    [sym__augmented_assignment_lhs] = STATE(3025),
    [sym_augmented_assignment_expression] = STATE(2358),
    [sym__destructuring_pattern] = STATE(5492),
    [sym_ternary_expression] = STATE(2358),
    [sym_binary_expression] = STATE(2358),
    [sym_unary_expression] = STATE(2358),
    [sym_update_expression] = STATE(2358),
    [sym_string] = STATE(2222),
    [sym_template_string] = STATE(2222),
    [sym_regex] = STATE(2222),
    [sym_meta_property] = STATE(2222),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1362),
    [sym_type_assertion] = STATE(2358),
    [sym_as_expression] = STATE(2358),
    [sym_satisfies_expression] = STATE(2358),
    [sym_instantiation_expression] = STATE(2358),
    [sym_internal_module] = STATE(2358),
    [sym__type_query_member_expression] = STATE(2876),
    [sym__type_query_subscript_expression] = STATE(2877),
    [sym__type_query_call_expression] = STATE(2922),
    [sym__type_query_instantiation_expression] = STATE(3010),
    [sym_type_arguments] = STATE(428),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4408),
    [sym_identifier] = ACTIONS(2009),
    [anon_sym_export] = ACTIONS(1352),
    [anon_sym_type] = ACTIONS(1352),
    [anon_sym_namespace] = ACTIONS(1354),
    [anon_sym_LBRACE] = ACTIONS(665),
    [anon_sym_typeof] = ACTIONS(21),
    [anon_sym_import] = ACTIONS(669),
    [anon_sym_let] = ACTIONS(1352),
    [anon_sym_BANG] = ACTIONS(33),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_await] = ACTIONS(45),
    [anon_sym_yield] = ACTIONS(63),
    [anon_sym_LBRACK] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(676),
    [anon_sym_async] = ACTIONS(1362),
    [anon_sym_function] = ACTIONS(680),
    [anon_sym_new] = ACTIONS(1472),
    [anon_sym_using] = ACTIONS(75),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_SLASH] = ACTIONS(77),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(33),
    [anon_sym_void] = ACTIONS(21),
    [anon_sym_delete] = ACTIONS(21),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_DQUOTE] = ACTIONS(83),
    [anon_sym_SQUOTE] = ACTIONS(85),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(87),
    [sym_number] = ACTIONS(89),
    [sym_private_property_identifier] = ACTIONS(91),
    [sym_this] = ACTIONS(2011),
    [sym_super] = ACTIONS(93),
    [sym_true] = ACTIONS(93),
    [sym_false] = ACTIONS(93),
    [sym_null] = ACTIONS(93),
    [sym_undefined] = ACTIONS(95),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1352),
    [anon_sym_readonly] = ACTIONS(1352),
    [anon_sym_get] = ACTIONS(1352),
    [anon_sym_set] = ACTIONS(1352),
    [anon_sym_declare] = ACTIONS(1352),
    [anon_sym_public] = ACTIONS(1352),
    [anon_sym_private] = ACTIONS(1352),
    [anon_sym_protected] = ACTIONS(1352),
    [anon_sym_override] = ACTIONS(1352),
    [anon_sym_module] = ACTIONS(1352),
    [anon_sym_any] = ACTIONS(1352),
    [anon_sym_number] = ACTIONS(1352),
    [anon_sym_boolean] = ACTIONS(1352),
    [anon_sym_string] = ACTIONS(1352),
    [anon_sym_symbol] = ACTIONS(1352),
    [anon_sym_object] = ACTIONS(1352),
    [sym_html_comment] = ACTIONS(5),
  },
  [278] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1322),
    [sym_expression] = STATE(2425),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(4425),
    [sym_assignment_pattern] = STATE(5260),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(4425),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5508),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1396),
    [sym_subscript_expression] = STATE(1396),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3003),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(4425),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_pattern] = STATE(4930),
    [sym_rest_pattern] = STATE(3684),
    [sym_non_null_expression] = STATE(1396),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(484),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1738),
    [anon_sym_export] = ACTIONS(541),
    [anon_sym_type] = ACTIONS(541),
    [anon_sym_namespace] = ACTIONS(545),
    [anon_sym_LBRACE] = ACTIONS(808),
    [anon_sym_typeof] = ACTIONS(581),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(541),
    [anon_sym_BANG] = ACTIONS(553),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(555),
    [anon_sym_yield] = ACTIONS(557),
    [anon_sym_LBRACK] = ACTIONS(812),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(563),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1744),
    [anon_sym_using] = ACTIONS(567),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(162),
    [anon_sym_PLUS] = ACTIONS(581),
    [anon_sym_DASH] = ACTIONS(581),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(553),
    [anon_sym_void] = ACTIONS(581),
    [anon_sym_delete] = ACTIONS(581),
    [anon_sym_PLUS_PLUS] = ACTIONS(583),
    [anon_sym_DASH_DASH] = ACTIONS(583),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(585),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1746),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(541),
    [anon_sym_readonly] = ACTIONS(541),
    [anon_sym_get] = ACTIONS(541),
    [anon_sym_set] = ACTIONS(541),
    [anon_sym_declare] = ACTIONS(541),
    [anon_sym_public] = ACTIONS(541),
    [anon_sym_private] = ACTIONS(541),
    [anon_sym_protected] = ACTIONS(541),
    [anon_sym_override] = ACTIONS(541),
    [anon_sym_module] = ACTIONS(541),
    [anon_sym_any] = ACTIONS(541),
    [anon_sym_number] = ACTIONS(541),
    [anon_sym_boolean] = ACTIONS(541),
    [anon_sym_string] = ACTIONS(541),
    [anon_sym_symbol] = ACTIONS(541),
    [anon_sym_object] = ACTIONS(541),
    [sym_html_comment] = ACTIONS(5),
  },
  [279] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1213),
    [sym_expression] = STATE(2644),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(3722),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(3722),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5800),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1295),
    [sym_subscript_expression] = STATE(1295),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3013),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(3722),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_pattern] = STATE(3924),
    [sym_rest_pattern] = STATE(3684),
    [sym_non_null_expression] = STATE(1295),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_override_modifier] = STATE(302),
    [sym_type_arguments] = STATE(539),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(696),
    [anon_sym_export] = ACTIONS(113),
    [anon_sym_type] = ACTIONS(113),
    [anon_sym_namespace] = ACTIONS(122),
    [anon_sym_LBRACE] = ACTIONS(698),
    [anon_sym_typeof] = ACTIONS(179),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(113),
    [anon_sym_BANG] = ACTIONS(175),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(140),
    [anon_sym_yield] = ACTIONS(142),
    [anon_sym_LBRACK] = ACTIONS(1664),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(148),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(706),
    [anon_sym_using] = ACTIONS(158),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(162),
    [anon_sym_PLUS] = ACTIONS(179),
    [anon_sym_DASH] = ACTIONS(179),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(175),
    [anon_sym_void] = ACTIONS(179),
    [anon_sym_delete] = ACTIONS(179),
    [anon_sym_PLUS_PLUS] = ACTIONS(686),
    [anon_sym_DASH_DASH] = ACTIONS(686),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(192),
    [sym_this] = ACTIONS(2013),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(718),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(113),
    [anon_sym_readonly] = ACTIONS(2015),
    [anon_sym_get] = ACTIONS(113),
    [anon_sym_set] = ACTIONS(113),
    [anon_sym_declare] = ACTIONS(113),
    [anon_sym_public] = ACTIONS(113),
    [anon_sym_private] = ACTIONS(113),
    [anon_sym_protected] = ACTIONS(113),
    [anon_sym_override] = ACTIONS(800),
    [anon_sym_module] = ACTIONS(113),
    [anon_sym_any] = ACTIONS(113),
    [anon_sym_number] = ACTIONS(113),
    [anon_sym_boolean] = ACTIONS(113),
    [anon_sym_string] = ACTIONS(113),
    [anon_sym_symbol] = ACTIONS(113),
    [anon_sym_object] = ACTIONS(113),
    [sym_html_comment] = ACTIONS(5),
  },
  [280] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1322),
    [sym_expression] = STATE(2439),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5698),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5698),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5508),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1322),
    [sym_subscript_expression] = STATE(1322),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3003),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5698),
    [sym_spread_element] = STATE(4980),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1322),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(484),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1456),
    [anon_sym_export] = ACTIONS(1048),
    [anon_sym_type] = ACTIONS(1048),
    [anon_sym_namespace] = ACTIONS(1050),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_COMMA] = ACTIONS(2017),
    [anon_sym_typeof] = ACTIONS(581),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1048),
    [anon_sym_BANG] = ACTIONS(553),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(555),
    [anon_sym_yield] = ACTIONS(557),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_RBRACK] = ACTIONS(2017),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1058),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1464),
    [anon_sym_using] = ACTIONS(567),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(2019),
    [anon_sym_PLUS] = ACTIONS(581),
    [anon_sym_DASH] = ACTIONS(581),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(553),
    [anon_sym_void] = ACTIONS(581),
    [anon_sym_delete] = ACTIONS(581),
    [anon_sym_PLUS_PLUS] = ACTIONS(583),
    [anon_sym_DASH_DASH] = ACTIONS(583),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(585),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1466),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1048),
    [anon_sym_readonly] = ACTIONS(1048),
    [anon_sym_get] = ACTIONS(1048),
    [anon_sym_set] = ACTIONS(1048),
    [anon_sym_declare] = ACTIONS(1048),
    [anon_sym_public] = ACTIONS(1048),
    [anon_sym_private] = ACTIONS(1048),
    [anon_sym_protected] = ACTIONS(1048),
    [anon_sym_override] = ACTIONS(1048),
    [anon_sym_module] = ACTIONS(1048),
    [anon_sym_any] = ACTIONS(1048),
    [anon_sym_number] = ACTIONS(1048),
    [anon_sym_boolean] = ACTIONS(1048),
    [anon_sym_string] = ACTIONS(1048),
    [anon_sym_symbol] = ACTIONS(1048),
    [anon_sym_object] = ACTIONS(1048),
    [sym_html_comment] = ACTIONS(5),
  },
  [281] = {
    [sym_import] = STATE(3540),
    [sym_parenthesized_expression] = STATE(1322),
    [sym_expression] = STATE(1776),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5698),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5698),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5508),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1322),
    [sym_subscript_expression] = STATE(1322),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3003),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5698),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1322),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym__type_query_member_expression] = STATE(2876),
    [sym__type_query_subscript_expression] = STATE(2877),
    [sym__type_query_call_expression] = STATE(2922),
    [sym__type_query_instantiation_expression] = STATE(3010),
    [sym_type_arguments] = STATE(484),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(2021),
    [anon_sym_export] = ACTIONS(1048),
    [anon_sym_type] = ACTIONS(1048),
    [anon_sym_namespace] = ACTIONS(1050),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_typeof] = ACTIONS(581),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1048),
    [anon_sym_BANG] = ACTIONS(553),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(555),
    [anon_sym_yield] = ACTIONS(557),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1058),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1464),
    [anon_sym_using] = ACTIONS(567),
    [anon_sym_PLUS] = ACTIONS(581),
    [anon_sym_DASH] = ACTIONS(581),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(553),
    [anon_sym_void] = ACTIONS(581),
    [anon_sym_delete] = ACTIONS(581),
    [anon_sym_PLUS_PLUS] = ACTIONS(583),
    [anon_sym_DASH_DASH] = ACTIONS(583),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(585),
    [sym_this] = ACTIONS(2007),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1466),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1048),
    [anon_sym_readonly] = ACTIONS(1048),
    [anon_sym_get] = ACTIONS(1048),
    [anon_sym_set] = ACTIONS(1048),
    [anon_sym_declare] = ACTIONS(1048),
    [anon_sym_public] = ACTIONS(1048),
    [anon_sym_private] = ACTIONS(1048),
    [anon_sym_protected] = ACTIONS(1048),
    [anon_sym_override] = ACTIONS(1048),
    [anon_sym_module] = ACTIONS(1048),
    [anon_sym_any] = ACTIONS(1048),
    [anon_sym_number] = ACTIONS(1048),
    [anon_sym_boolean] = ACTIONS(1048),
    [anon_sym_string] = ACTIONS(1048),
    [anon_sym_symbol] = ACTIONS(1048),
    [anon_sym_object] = ACTIONS(1048),
    [sym_html_comment] = ACTIONS(5),
  },
  [282] = {
    [sym_import] = STATE(3609),
    [sym_parenthesized_expression] = STATE(1213),
    [sym_expression] = STATE(2577),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5522),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5522),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5800),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1213),
    [sym_subscript_expression] = STATE(1213),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3013),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5522),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1213),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym__type_query_member_expression] = STATE(2876),
    [sym__type_query_subscript_expression] = STATE(2877),
    [sym__type_query_call_expression] = STATE(2922),
    [sym__type_query_instantiation_expression] = STATE(3010),
    [sym_type_arguments] = STATE(539),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(2023),
    [anon_sym_export] = ACTIONS(804),
    [anon_sym_type] = ACTIONS(804),
    [anon_sym_namespace] = ACTIONS(806),
    [anon_sym_LBRACE] = ACTIONS(808),
    [anon_sym_typeof] = ACTIONS(179),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(804),
    [anon_sym_BANG] = ACTIONS(175),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(140),
    [anon_sym_yield] = ACTIONS(142),
    [anon_sym_LBRACK] = ACTIONS(812),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(816),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(818),
    [anon_sym_using] = ACTIONS(158),
    [anon_sym_PLUS] = ACTIONS(179),
    [anon_sym_DASH] = ACTIONS(179),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(175),
    [anon_sym_void] = ACTIONS(179),
    [anon_sym_delete] = ACTIONS(179),
    [anon_sym_PLUS_PLUS] = ACTIONS(686),
    [anon_sym_DASH_DASH] = ACTIONS(686),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(192),
    [sym_this] = ACTIONS(2007),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(822),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(804),
    [anon_sym_readonly] = ACTIONS(804),
    [anon_sym_get] = ACTIONS(804),
    [anon_sym_set] = ACTIONS(804),
    [anon_sym_declare] = ACTIONS(804),
    [anon_sym_public] = ACTIONS(804),
    [anon_sym_private] = ACTIONS(804),
    [anon_sym_protected] = ACTIONS(804),
    [anon_sym_override] = ACTIONS(804),
    [anon_sym_module] = ACTIONS(804),
    [anon_sym_any] = ACTIONS(804),
    [anon_sym_number] = ACTIONS(804),
    [anon_sym_boolean] = ACTIONS(804),
    [anon_sym_string] = ACTIONS(804),
    [anon_sym_symbol] = ACTIONS(804),
    [anon_sym_object] = ACTIONS(804),
    [sym_html_comment] = ACTIONS(5),
  },
  [283] = {
    [sym_import] = STATE(3599),
    [sym_parenthesized_expression] = STATE(1398),
    [sym_expression] = STATE(1960),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5544),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5544),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5558),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1398),
    [sym_subscript_expression] = STATE(1398),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(2980),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5544),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1398),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym__type_query_member_expression] = STATE(2876),
    [sym__type_query_subscript_expression] = STATE(2877),
    [sym__type_query_call_expression] = STATE(2922),
    [sym__type_query_instantiation_expression] = STATE(3010),
    [sym_type_arguments] = STATE(638),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(2025),
    [anon_sym_export] = ACTIONS(1158),
    [anon_sym_type] = ACTIONS(1158),
    [anon_sym_namespace] = ACTIONS(1160),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_typeof] = ACTIONS(756),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1158),
    [anon_sym_BANG] = ACTIONS(732),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(736),
    [anon_sym_yield] = ACTIONS(738),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1164),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1486),
    [anon_sym_using] = ACTIONS(746),
    [anon_sym_PLUS] = ACTIONS(756),
    [anon_sym_DASH] = ACTIONS(756),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(732),
    [anon_sym_void] = ACTIONS(756),
    [anon_sym_delete] = ACTIONS(756),
    [anon_sym_PLUS_PLUS] = ACTIONS(758),
    [anon_sym_DASH_DASH] = ACTIONS(758),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(764),
    [sym_this] = ACTIONS(2007),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1488),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1158),
    [anon_sym_readonly] = ACTIONS(1158),
    [anon_sym_get] = ACTIONS(1158),
    [anon_sym_set] = ACTIONS(1158),
    [anon_sym_declare] = ACTIONS(1158),
    [anon_sym_public] = ACTIONS(1158),
    [anon_sym_private] = ACTIONS(1158),
    [anon_sym_protected] = ACTIONS(1158),
    [anon_sym_override] = ACTIONS(1158),
    [anon_sym_module] = ACTIONS(1158),
    [anon_sym_any] = ACTIONS(1158),
    [anon_sym_number] = ACTIONS(1158),
    [anon_sym_boolean] = ACTIONS(1158),
    [anon_sym_string] = ACTIONS(1158),
    [anon_sym_symbol] = ACTIONS(1158),
    [anon_sym_object] = ACTIONS(1158),
    [sym_html_comment] = ACTIONS(5),
  },
  [284] = {
    [sym_import] = STATE(3540),
    [sym_parenthesized_expression] = STATE(1213),
    [sym_expression] = STATE(2577),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5522),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5522),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5800),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1213),
    [sym_subscript_expression] = STATE(1213),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3013),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5522),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1213),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym__type_query_member_expression] = STATE(2876),
    [sym__type_query_subscript_expression] = STATE(2877),
    [sym__type_query_call_expression] = STATE(2922),
    [sym__type_query_instantiation_expression] = STATE(3010),
    [sym_type_arguments] = STATE(539),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(2027),
    [anon_sym_export] = ACTIONS(804),
    [anon_sym_type] = ACTIONS(804),
    [anon_sym_namespace] = ACTIONS(806),
    [anon_sym_LBRACE] = ACTIONS(808),
    [anon_sym_typeof] = ACTIONS(179),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(804),
    [anon_sym_BANG] = ACTIONS(175),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(140),
    [anon_sym_yield] = ACTIONS(142),
    [anon_sym_LBRACK] = ACTIONS(812),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(816),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(818),
    [anon_sym_using] = ACTIONS(158),
    [anon_sym_PLUS] = ACTIONS(179),
    [anon_sym_DASH] = ACTIONS(179),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(175),
    [anon_sym_void] = ACTIONS(179),
    [anon_sym_delete] = ACTIONS(179),
    [anon_sym_PLUS_PLUS] = ACTIONS(686),
    [anon_sym_DASH_DASH] = ACTIONS(686),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(192),
    [sym_this] = ACTIONS(2029),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(822),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(804),
    [anon_sym_readonly] = ACTIONS(804),
    [anon_sym_get] = ACTIONS(804),
    [anon_sym_set] = ACTIONS(804),
    [anon_sym_declare] = ACTIONS(804),
    [anon_sym_public] = ACTIONS(804),
    [anon_sym_private] = ACTIONS(804),
    [anon_sym_protected] = ACTIONS(804),
    [anon_sym_override] = ACTIONS(804),
    [anon_sym_module] = ACTIONS(804),
    [anon_sym_any] = ACTIONS(804),
    [anon_sym_number] = ACTIONS(804),
    [anon_sym_boolean] = ACTIONS(804),
    [anon_sym_string] = ACTIONS(804),
    [anon_sym_symbol] = ACTIONS(804),
    [anon_sym_object] = ACTIONS(804),
    [sym_html_comment] = ACTIONS(5),
  },
  [285] = {
    [sym_import] = STATE(3540),
    [sym_parenthesized_expression] = STATE(1322),
    [sym_expression] = STATE(1776),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5698),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5698),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5508),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1322),
    [sym_subscript_expression] = STATE(1322),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3003),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5698),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1322),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym__type_query_member_expression] = STATE(2876),
    [sym__type_query_subscript_expression] = STATE(2877),
    [sym__type_query_call_expression] = STATE(2922),
    [sym__type_query_instantiation_expression] = STATE(3010),
    [sym_type_arguments] = STATE(484),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(2031),
    [anon_sym_export] = ACTIONS(1048),
    [anon_sym_type] = ACTIONS(1048),
    [anon_sym_namespace] = ACTIONS(1050),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_typeof] = ACTIONS(581),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1048),
    [anon_sym_BANG] = ACTIONS(553),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(555),
    [anon_sym_yield] = ACTIONS(557),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1058),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1464),
    [anon_sym_using] = ACTIONS(567),
    [anon_sym_PLUS] = ACTIONS(581),
    [anon_sym_DASH] = ACTIONS(581),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(553),
    [anon_sym_void] = ACTIONS(581),
    [anon_sym_delete] = ACTIONS(581),
    [anon_sym_PLUS_PLUS] = ACTIONS(583),
    [anon_sym_DASH_DASH] = ACTIONS(583),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(585),
    [sym_this] = ACTIONS(2033),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1466),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1048),
    [anon_sym_readonly] = ACTIONS(1048),
    [anon_sym_get] = ACTIONS(1048),
    [anon_sym_set] = ACTIONS(1048),
    [anon_sym_declare] = ACTIONS(1048),
    [anon_sym_public] = ACTIONS(1048),
    [anon_sym_private] = ACTIONS(1048),
    [anon_sym_protected] = ACTIONS(1048),
    [anon_sym_override] = ACTIONS(1048),
    [anon_sym_module] = ACTIONS(1048),
    [anon_sym_any] = ACTIONS(1048),
    [anon_sym_number] = ACTIONS(1048),
    [anon_sym_boolean] = ACTIONS(1048),
    [anon_sym_string] = ACTIONS(1048),
    [anon_sym_symbol] = ACTIONS(1048),
    [anon_sym_object] = ACTIONS(1048),
    [sym_html_comment] = ACTIONS(5),
  },
  [286] = {
    [sym_import] = STATE(3609),
    [sym_parenthesized_expression] = STATE(1213),
    [sym_expression] = STATE(2577),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5522),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5522),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5800),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1213),
    [sym_subscript_expression] = STATE(1213),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3013),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5522),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1213),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym__type_query_member_expression] = STATE(2876),
    [sym__type_query_subscript_expression] = STATE(2877),
    [sym__type_query_call_expression] = STATE(2922),
    [sym__type_query_instantiation_expression] = STATE(3010),
    [sym_type_arguments] = STATE(539),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(2035),
    [anon_sym_export] = ACTIONS(804),
    [anon_sym_type] = ACTIONS(804),
    [anon_sym_namespace] = ACTIONS(806),
    [anon_sym_LBRACE] = ACTIONS(808),
    [anon_sym_typeof] = ACTIONS(179),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(804),
    [anon_sym_BANG] = ACTIONS(175),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(140),
    [anon_sym_yield] = ACTIONS(142),
    [anon_sym_LBRACK] = ACTIONS(812),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(816),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(818),
    [anon_sym_using] = ACTIONS(158),
    [anon_sym_PLUS] = ACTIONS(179),
    [anon_sym_DASH] = ACTIONS(179),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(175),
    [anon_sym_void] = ACTIONS(179),
    [anon_sym_delete] = ACTIONS(179),
    [anon_sym_PLUS_PLUS] = ACTIONS(686),
    [anon_sym_DASH_DASH] = ACTIONS(686),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(192),
    [sym_this] = ACTIONS(2033),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(822),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(804),
    [anon_sym_readonly] = ACTIONS(804),
    [anon_sym_get] = ACTIONS(804),
    [anon_sym_set] = ACTIONS(804),
    [anon_sym_declare] = ACTIONS(804),
    [anon_sym_public] = ACTIONS(804),
    [anon_sym_private] = ACTIONS(804),
    [anon_sym_protected] = ACTIONS(804),
    [anon_sym_override] = ACTIONS(804),
    [anon_sym_module] = ACTIONS(804),
    [anon_sym_any] = ACTIONS(804),
    [anon_sym_number] = ACTIONS(804),
    [anon_sym_boolean] = ACTIONS(804),
    [anon_sym_string] = ACTIONS(804),
    [anon_sym_symbol] = ACTIONS(804),
    [anon_sym_object] = ACTIONS(804),
    [sym_html_comment] = ACTIONS(5),
  },
  [287] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1213),
    [sym_expression] = STATE(2644),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(3722),
    [sym_assignment_pattern] = STATE(5260),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(3722),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5800),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1295),
    [sym_subscript_expression] = STATE(1295),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3013),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(3722),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_pattern] = STATE(4930),
    [sym_rest_pattern] = STATE(3684),
    [sym_non_null_expression] = STATE(1295),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(539),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(696),
    [anon_sym_export] = ACTIONS(113),
    [anon_sym_type] = ACTIONS(113),
    [anon_sym_namespace] = ACTIONS(122),
    [anon_sym_LBRACE] = ACTIONS(698),
    [anon_sym_typeof] = ACTIONS(179),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(113),
    [anon_sym_BANG] = ACTIONS(175),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(140),
    [anon_sym_yield] = ACTIONS(142),
    [anon_sym_LBRACK] = ACTIONS(1664),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(148),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(706),
    [anon_sym_using] = ACTIONS(158),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(162),
    [anon_sym_PLUS] = ACTIONS(179),
    [anon_sym_DASH] = ACTIONS(179),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(175),
    [anon_sym_void] = ACTIONS(179),
    [anon_sym_delete] = ACTIONS(179),
    [anon_sym_PLUS_PLUS] = ACTIONS(686),
    [anon_sym_DASH_DASH] = ACTIONS(686),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(192),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(718),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(113),
    [anon_sym_readonly] = ACTIONS(113),
    [anon_sym_get] = ACTIONS(113),
    [anon_sym_set] = ACTIONS(113),
    [anon_sym_declare] = ACTIONS(113),
    [anon_sym_public] = ACTIONS(113),
    [anon_sym_private] = ACTIONS(113),
    [anon_sym_protected] = ACTIONS(113),
    [anon_sym_override] = ACTIONS(113),
    [anon_sym_module] = ACTIONS(113),
    [anon_sym_any] = ACTIONS(113),
    [anon_sym_number] = ACTIONS(113),
    [anon_sym_boolean] = ACTIONS(113),
    [anon_sym_string] = ACTIONS(113),
    [anon_sym_symbol] = ACTIONS(113),
    [anon_sym_object] = ACTIONS(113),
    [sym_html_comment] = ACTIONS(5),
  },
  [288] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1213),
    [sym_expression] = STATE(2644),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(3722),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(3722),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5800),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1295),
    [sym_subscript_expression] = STATE(1295),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3013),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(3722),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_pattern] = STATE(4312),
    [sym_rest_pattern] = STATE(3684),
    [sym_non_null_expression] = STATE(1295),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_override_modifier] = STATE(300),
    [sym_type_arguments] = STATE(539),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(696),
    [anon_sym_export] = ACTIONS(113),
    [anon_sym_type] = ACTIONS(113),
    [anon_sym_namespace] = ACTIONS(122),
    [anon_sym_LBRACE] = ACTIONS(698),
    [anon_sym_typeof] = ACTIONS(179),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(113),
    [anon_sym_BANG] = ACTIONS(175),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(140),
    [anon_sym_yield] = ACTIONS(142),
    [anon_sym_LBRACK] = ACTIONS(1664),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(148),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(706),
    [anon_sym_using] = ACTIONS(158),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(162),
    [anon_sym_PLUS] = ACTIONS(179),
    [anon_sym_DASH] = ACTIONS(179),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(175),
    [anon_sym_void] = ACTIONS(179),
    [anon_sym_delete] = ACTIONS(179),
    [anon_sym_PLUS_PLUS] = ACTIONS(686),
    [anon_sym_DASH_DASH] = ACTIONS(686),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(192),
    [sym_this] = ACTIONS(716),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(718),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(113),
    [anon_sym_readonly] = ACTIONS(2037),
    [anon_sym_get] = ACTIONS(113),
    [anon_sym_set] = ACTIONS(113),
    [anon_sym_declare] = ACTIONS(113),
    [anon_sym_public] = ACTIONS(113),
    [anon_sym_private] = ACTIONS(113),
    [anon_sym_protected] = ACTIONS(113),
    [anon_sym_override] = ACTIONS(800),
    [anon_sym_module] = ACTIONS(113),
    [anon_sym_any] = ACTIONS(113),
    [anon_sym_number] = ACTIONS(113),
    [anon_sym_boolean] = ACTIONS(113),
    [anon_sym_string] = ACTIONS(113),
    [anon_sym_symbol] = ACTIONS(113),
    [anon_sym_object] = ACTIONS(113),
    [sym_html_comment] = ACTIONS(5),
  },
  [289] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1398),
    [sym_expression] = STATE(2450),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5544),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5544),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5558),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1398),
    [sym_subscript_expression] = STATE(1398),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(2980),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5544),
    [sym_spread_element] = STATE(4980),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1398),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(638),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1482),
    [anon_sym_export] = ACTIONS(1158),
    [anon_sym_type] = ACTIONS(1158),
    [anon_sym_namespace] = ACTIONS(1160),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_COMMA] = ACTIONS(2017),
    [anon_sym_typeof] = ACTIONS(756),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1158),
    [anon_sym_BANG] = ACTIONS(732),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_RPAREN] = ACTIONS(2017),
    [anon_sym_await] = ACTIONS(736),
    [anon_sym_yield] = ACTIONS(738),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1164),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1486),
    [anon_sym_using] = ACTIONS(746),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1981),
    [anon_sym_PLUS] = ACTIONS(756),
    [anon_sym_DASH] = ACTIONS(756),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(732),
    [anon_sym_void] = ACTIONS(756),
    [anon_sym_delete] = ACTIONS(756),
    [anon_sym_PLUS_PLUS] = ACTIONS(758),
    [anon_sym_DASH_DASH] = ACTIONS(758),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(764),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1488),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1158),
    [anon_sym_readonly] = ACTIONS(1158),
    [anon_sym_get] = ACTIONS(1158),
    [anon_sym_set] = ACTIONS(1158),
    [anon_sym_declare] = ACTIONS(1158),
    [anon_sym_public] = ACTIONS(1158),
    [anon_sym_private] = ACTIONS(1158),
    [anon_sym_protected] = ACTIONS(1158),
    [anon_sym_override] = ACTIONS(1158),
    [anon_sym_module] = ACTIONS(1158),
    [anon_sym_any] = ACTIONS(1158),
    [anon_sym_number] = ACTIONS(1158),
    [anon_sym_boolean] = ACTIONS(1158),
    [anon_sym_string] = ACTIONS(1158),
    [anon_sym_symbol] = ACTIONS(1158),
    [anon_sym_object] = ACTIONS(1158),
    [sym_html_comment] = ACTIONS(5),
  },
  [290] = {
    [sym_import] = STATE(3599),
    [sym_parenthesized_expression] = STATE(1398),
    [sym_expression] = STATE(1960),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5544),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5544),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5558),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1398),
    [sym_subscript_expression] = STATE(1398),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(2980),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5544),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1398),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym__type_query_member_expression] = STATE(2876),
    [sym__type_query_subscript_expression] = STATE(2877),
    [sym__type_query_call_expression] = STATE(2922),
    [sym__type_query_instantiation_expression] = STATE(3010),
    [sym_type_arguments] = STATE(638),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(2039),
    [anon_sym_export] = ACTIONS(1158),
    [anon_sym_type] = ACTIONS(1158),
    [anon_sym_namespace] = ACTIONS(1160),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_typeof] = ACTIONS(756),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1158),
    [anon_sym_BANG] = ACTIONS(732),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(736),
    [anon_sym_yield] = ACTIONS(738),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1164),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1486),
    [anon_sym_using] = ACTIONS(746),
    [anon_sym_PLUS] = ACTIONS(756),
    [anon_sym_DASH] = ACTIONS(756),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(732),
    [anon_sym_void] = ACTIONS(756),
    [anon_sym_delete] = ACTIONS(756),
    [anon_sym_PLUS_PLUS] = ACTIONS(758),
    [anon_sym_DASH_DASH] = ACTIONS(758),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(764),
    [sym_this] = ACTIONS(2029),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1488),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1158),
    [anon_sym_readonly] = ACTIONS(1158),
    [anon_sym_get] = ACTIONS(1158),
    [anon_sym_set] = ACTIONS(1158),
    [anon_sym_declare] = ACTIONS(1158),
    [anon_sym_public] = ACTIONS(1158),
    [anon_sym_private] = ACTIONS(1158),
    [anon_sym_protected] = ACTIONS(1158),
    [anon_sym_override] = ACTIONS(1158),
    [anon_sym_module] = ACTIONS(1158),
    [anon_sym_any] = ACTIONS(1158),
    [anon_sym_number] = ACTIONS(1158),
    [anon_sym_boolean] = ACTIONS(1158),
    [anon_sym_string] = ACTIONS(1158),
    [anon_sym_symbol] = ACTIONS(1158),
    [anon_sym_object] = ACTIONS(1158),
    [sym_html_comment] = ACTIONS(5),
  },
  [291] = {
    [sym_import] = STATE(3546),
    [sym_parenthesized_expression] = STATE(1410),
    [sym_expression] = STATE(2239),
    [sym_primary_expression] = STATE(1810),
    [sym_yield_expression] = STATE(2358),
    [sym_object] = STATE(2222),
    [sym_object_pattern] = STATE(5580),
    [sym_array] = STATE(2222),
    [sym_array_pattern] = STATE(5580),
    [sym_class] = STATE(2222),
    [sym_function_expression] = STATE(2222),
    [sym_generator_function] = STATE(2222),
    [sym_arrow_function] = STATE(2222),
    [sym__call_signature] = STATE(5466),
    [sym_call_expression] = STATE(2222),
    [sym_new_expression] = STATE(1948),
    [sym_await_expression] = STATE(2358),
    [sym_member_expression] = STATE(1410),
    [sym_subscript_expression] = STATE(1410),
    [sym_assignment_expression] = STATE(2358),
    [sym__augmented_assignment_lhs] = STATE(3004),
    [sym_augmented_assignment_expression] = STATE(2358),
    [sym__destructuring_pattern] = STATE(5580),
    [sym_ternary_expression] = STATE(2358),
    [sym_binary_expression] = STATE(2358),
    [sym_unary_expression] = STATE(2358),
    [sym_update_expression] = STATE(2358),
    [sym_string] = STATE(2222),
    [sym_template_string] = STATE(2222),
    [sym_regex] = STATE(2222),
    [sym_meta_property] = STATE(2222),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1410),
    [sym_type_assertion] = STATE(2358),
    [sym_as_expression] = STATE(2358),
    [sym_satisfies_expression] = STATE(2358),
    [sym_instantiation_expression] = STATE(2358),
    [sym_internal_module] = STATE(2358),
    [sym__type_query_member_expression] = STATE(2876),
    [sym__type_query_subscript_expression] = STATE(2877),
    [sym__type_query_call_expression] = STATE(2922),
    [sym__type_query_instantiation_expression] = STATE(3010),
    [sym_type_arguments] = STATE(452),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4408),
    [sym_identifier] = ACTIONS(2041),
    [anon_sym_export] = ACTIONS(1270),
    [anon_sym_type] = ACTIONS(1270),
    [anon_sym_namespace] = ACTIONS(1272),
    [anon_sym_LBRACE] = ACTIONS(665),
    [anon_sym_typeof] = ACTIONS(1298),
    [anon_sym_import] = ACTIONS(669),
    [anon_sym_let] = ACTIONS(1270),
    [anon_sym_BANG] = ACTIONS(1278),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_await] = ACTIONS(1282),
    [anon_sym_yield] = ACTIONS(1284),
    [anon_sym_LBRACK] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(676),
    [anon_sym_async] = ACTIONS(1288),
    [anon_sym_function] = ACTIONS(680),
    [anon_sym_new] = ACTIONS(1502),
    [anon_sym_using] = ACTIONS(1292),
    [anon_sym_PLUS] = ACTIONS(1298),
    [anon_sym_DASH] = ACTIONS(1298),
    [anon_sym_SLASH] = ACTIONS(77),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(1278),
    [anon_sym_void] = ACTIONS(1298),
    [anon_sym_delete] = ACTIONS(1298),
    [anon_sym_PLUS_PLUS] = ACTIONS(1300),
    [anon_sym_DASH_DASH] = ACTIONS(1300),
    [anon_sym_DQUOTE] = ACTIONS(83),
    [anon_sym_SQUOTE] = ACTIONS(85),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(87),
    [sym_number] = ACTIONS(89),
    [sym_private_property_identifier] = ACTIONS(1306),
    [sym_this] = ACTIONS(2011),
    [sym_super] = ACTIONS(93),
    [sym_true] = ACTIONS(93),
    [sym_false] = ACTIONS(93),
    [sym_null] = ACTIONS(93),
    [sym_undefined] = ACTIONS(1504),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1270),
    [anon_sym_readonly] = ACTIONS(1270),
    [anon_sym_get] = ACTIONS(1270),
    [anon_sym_set] = ACTIONS(1270),
    [anon_sym_declare] = ACTIONS(1270),
    [anon_sym_public] = ACTIONS(1270),
    [anon_sym_private] = ACTIONS(1270),
    [anon_sym_protected] = ACTIONS(1270),
    [anon_sym_override] = ACTIONS(1270),
    [anon_sym_module] = ACTIONS(1270),
    [anon_sym_any] = ACTIONS(1270),
    [anon_sym_number] = ACTIONS(1270),
    [anon_sym_boolean] = ACTIONS(1270),
    [anon_sym_string] = ACTIONS(1270),
    [anon_sym_symbol] = ACTIONS(1270),
    [anon_sym_object] = ACTIONS(1270),
    [sym_html_comment] = ACTIONS(5),
  },
  [292] = {
    [sym_import] = STATE(3572),
    [sym_parenthesized_expression] = STATE(1457),
    [sym_expression] = STATE(2414),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5823),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5823),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5477),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1457),
    [sym_subscript_expression] = STATE(1457),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(2986),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5823),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1457),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym__type_query_member_expression] = STATE(2876),
    [sym__type_query_subscript_expression] = STATE(2877),
    [sym__type_query_call_expression] = STATE(2922),
    [sym__type_query_instantiation_expression] = STATE(3010),
    [sym_type_arguments] = STATE(620),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(2043),
    [anon_sym_export] = ACTIONS(1178),
    [anon_sym_type] = ACTIONS(1178),
    [anon_sym_namespace] = ACTIONS(1180),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_typeof] = ACTIONS(1202),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1178),
    [anon_sym_BANG] = ACTIONS(1186),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(1188),
    [anon_sym_yield] = ACTIONS(1190),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1192),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1526),
    [anon_sym_using] = ACTIONS(1196),
    [anon_sym_PLUS] = ACTIONS(1202),
    [anon_sym_DASH] = ACTIONS(1202),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(1186),
    [anon_sym_void] = ACTIONS(1202),
    [anon_sym_delete] = ACTIONS(1202),
    [anon_sym_PLUS_PLUS] = ACTIONS(1204),
    [anon_sym_DASH_DASH] = ACTIONS(1204),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(1206),
    [sym_this] = ACTIONS(2007),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1528),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1178),
    [anon_sym_readonly] = ACTIONS(1178),
    [anon_sym_get] = ACTIONS(1178),
    [anon_sym_set] = ACTIONS(1178),
    [anon_sym_declare] = ACTIONS(1178),
    [anon_sym_public] = ACTIONS(1178),
    [anon_sym_private] = ACTIONS(1178),
    [anon_sym_protected] = ACTIONS(1178),
    [anon_sym_override] = ACTIONS(1178),
    [anon_sym_module] = ACTIONS(1178),
    [anon_sym_any] = ACTIONS(1178),
    [anon_sym_number] = ACTIONS(1178),
    [anon_sym_boolean] = ACTIONS(1178),
    [anon_sym_string] = ACTIONS(1178),
    [anon_sym_symbol] = ACTIONS(1178),
    [anon_sym_object] = ACTIONS(1178),
    [sym_html_comment] = ACTIONS(5),
  },
  [293] = {
    [sym_import] = STATE(3739),
    [sym_parenthesized_expression] = STATE(1364),
    [sym_expression] = STATE(1873),
    [sym_primary_expression] = STATE(1810),
    [sym_yield_expression] = STATE(2358),
    [sym_object] = STATE(2222),
    [sym_object_pattern] = STATE(5773),
    [sym_array] = STATE(2222),
    [sym_array_pattern] = STATE(5773),
    [sym_class] = STATE(2222),
    [sym_function_expression] = STATE(2222),
    [sym_generator_function] = STATE(2222),
    [sym_arrow_function] = STATE(2222),
    [sym__call_signature] = STATE(5771),
    [sym_call_expression] = STATE(2222),
    [sym_new_expression] = STATE(1948),
    [sym_await_expression] = STATE(2358),
    [sym_member_expression] = STATE(1364),
    [sym_subscript_expression] = STATE(1364),
    [sym_assignment_expression] = STATE(2358),
    [sym__augmented_assignment_lhs] = STATE(3020),
    [sym_augmented_assignment_expression] = STATE(2358),
    [sym__destructuring_pattern] = STATE(5773),
    [sym_ternary_expression] = STATE(2358),
    [sym_binary_expression] = STATE(2358),
    [sym_unary_expression] = STATE(2358),
    [sym_update_expression] = STATE(2358),
    [sym_string] = STATE(2222),
    [sym_template_string] = STATE(2222),
    [sym_regex] = STATE(2222),
    [sym_meta_property] = STATE(2222),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1364),
    [sym_type_assertion] = STATE(2358),
    [sym_as_expression] = STATE(2358),
    [sym_satisfies_expression] = STATE(2358),
    [sym_instantiation_expression] = STATE(2358),
    [sym_internal_module] = STATE(2358),
    [sym__type_query_member_expression] = STATE(2876),
    [sym__type_query_subscript_expression] = STATE(2877),
    [sym__type_query_call_expression] = STATE(2922),
    [sym__type_query_instantiation_expression] = STATE(3010),
    [sym_type_arguments] = STATE(513),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4408),
    [sym_identifier] = ACTIONS(2045),
    [anon_sym_export] = ACTIONS(1386),
    [anon_sym_type] = ACTIONS(1386),
    [anon_sym_namespace] = ACTIONS(1388),
    [anon_sym_LBRACE] = ACTIONS(665),
    [anon_sym_typeof] = ACTIONS(1408),
    [anon_sym_import] = ACTIONS(669),
    [anon_sym_let] = ACTIONS(1386),
    [anon_sym_BANG] = ACTIONS(1392),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_await] = ACTIONS(1394),
    [anon_sym_yield] = ACTIONS(1396),
    [anon_sym_LBRACK] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(676),
    [anon_sym_async] = ACTIONS(1398),
    [anon_sym_function] = ACTIONS(680),
    [anon_sym_new] = ACTIONS(1478),
    [anon_sym_using] = ACTIONS(1402),
    [anon_sym_PLUS] = ACTIONS(1408),
    [anon_sym_DASH] = ACTIONS(1408),
    [anon_sym_SLASH] = ACTIONS(876),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(1392),
    [anon_sym_void] = ACTIONS(1408),
    [anon_sym_delete] = ACTIONS(1408),
    [anon_sym_PLUS_PLUS] = ACTIONS(1410),
    [anon_sym_DASH_DASH] = ACTIONS(1410),
    [anon_sym_DQUOTE] = ACTIONS(83),
    [anon_sym_SQUOTE] = ACTIONS(85),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(87),
    [sym_number] = ACTIONS(89),
    [sym_private_property_identifier] = ACTIONS(1412),
    [sym_this] = ACTIONS(2011),
    [sym_super] = ACTIONS(93),
    [sym_true] = ACTIONS(93),
    [sym_false] = ACTIONS(93),
    [sym_null] = ACTIONS(93),
    [sym_undefined] = ACTIONS(1480),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1386),
    [anon_sym_readonly] = ACTIONS(1386),
    [anon_sym_get] = ACTIONS(1386),
    [anon_sym_set] = ACTIONS(1386),
    [anon_sym_declare] = ACTIONS(1386),
    [anon_sym_public] = ACTIONS(1386),
    [anon_sym_private] = ACTIONS(1386),
    [anon_sym_protected] = ACTIONS(1386),
    [anon_sym_override] = ACTIONS(1386),
    [anon_sym_module] = ACTIONS(1386),
    [anon_sym_any] = ACTIONS(1386),
    [anon_sym_number] = ACTIONS(1386),
    [anon_sym_boolean] = ACTIONS(1386),
    [anon_sym_string] = ACTIONS(1386),
    [anon_sym_symbol] = ACTIONS(1386),
    [anon_sym_object] = ACTIONS(1386),
    [sym_html_comment] = ACTIONS(5),
  },
  [294] = {
    [sym_import] = STATE(3540),
    [sym_parenthesized_expression] = STATE(1322),
    [sym_expression] = STATE(1776),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5698),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5698),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5508),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1322),
    [sym_subscript_expression] = STATE(1322),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3003),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5698),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1322),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym__type_query_member_expression] = STATE(2876),
    [sym__type_query_subscript_expression] = STATE(2877),
    [sym__type_query_call_expression] = STATE(2922),
    [sym__type_query_instantiation_expression] = STATE(3010),
    [sym_type_arguments] = STATE(484),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(2047),
    [anon_sym_export] = ACTIONS(1048),
    [anon_sym_type] = ACTIONS(1048),
    [anon_sym_namespace] = ACTIONS(1050),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_typeof] = ACTIONS(581),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1048),
    [anon_sym_BANG] = ACTIONS(553),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(555),
    [anon_sym_yield] = ACTIONS(557),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1058),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1464),
    [anon_sym_using] = ACTIONS(567),
    [anon_sym_PLUS] = ACTIONS(581),
    [anon_sym_DASH] = ACTIONS(581),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(553),
    [anon_sym_void] = ACTIONS(581),
    [anon_sym_delete] = ACTIONS(581),
    [anon_sym_PLUS_PLUS] = ACTIONS(583),
    [anon_sym_DASH_DASH] = ACTIONS(583),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(585),
    [sym_this] = ACTIONS(2029),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1466),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1048),
    [anon_sym_readonly] = ACTIONS(1048),
    [anon_sym_get] = ACTIONS(1048),
    [anon_sym_set] = ACTIONS(1048),
    [anon_sym_declare] = ACTIONS(1048),
    [anon_sym_public] = ACTIONS(1048),
    [anon_sym_private] = ACTIONS(1048),
    [anon_sym_protected] = ACTIONS(1048),
    [anon_sym_override] = ACTIONS(1048),
    [anon_sym_module] = ACTIONS(1048),
    [anon_sym_any] = ACTIONS(1048),
    [anon_sym_number] = ACTIONS(1048),
    [anon_sym_boolean] = ACTIONS(1048),
    [anon_sym_string] = ACTIONS(1048),
    [anon_sym_symbol] = ACTIONS(1048),
    [anon_sym_object] = ACTIONS(1048),
    [sym_html_comment] = ACTIONS(5),
  },
  [295] = {
    [sym_import] = STATE(3609),
    [sym_parenthesized_expression] = STATE(1456),
    [sym_expression] = STATE(2404),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5815),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5815),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5755),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1456),
    [sym_subscript_expression] = STATE(1456),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3029),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5815),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1456),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym__type_query_member_expression] = STATE(2876),
    [sym__type_query_subscript_expression] = STATE(2877),
    [sym__type_query_call_expression] = STATE(2922),
    [sym__type_query_instantiation_expression] = STATE(3010),
    [sym_type_arguments] = STATE(594),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(2049),
    [anon_sym_export] = ACTIONS(1234),
    [anon_sym_type] = ACTIONS(1234),
    [anon_sym_namespace] = ACTIONS(1236),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_typeof] = ACTIONS(1256),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1234),
    [anon_sym_BANG] = ACTIONS(1240),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(1242),
    [anon_sym_yield] = ACTIONS(1244),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1246),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1510),
    [anon_sym_using] = ACTIONS(1250),
    [anon_sym_PLUS] = ACTIONS(1256),
    [anon_sym_DASH] = ACTIONS(1256),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(1240),
    [anon_sym_void] = ACTIONS(1256),
    [anon_sym_delete] = ACTIONS(1256),
    [anon_sym_PLUS_PLUS] = ACTIONS(1258),
    [anon_sym_DASH_DASH] = ACTIONS(1258),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(1260),
    [sym_this] = ACTIONS(2007),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1512),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1234),
    [anon_sym_readonly] = ACTIONS(1234),
    [anon_sym_get] = ACTIONS(1234),
    [anon_sym_set] = ACTIONS(1234),
    [anon_sym_declare] = ACTIONS(1234),
    [anon_sym_public] = ACTIONS(1234),
    [anon_sym_private] = ACTIONS(1234),
    [anon_sym_protected] = ACTIONS(1234),
    [anon_sym_override] = ACTIONS(1234),
    [anon_sym_module] = ACTIONS(1234),
    [anon_sym_any] = ACTIONS(1234),
    [anon_sym_number] = ACTIONS(1234),
    [anon_sym_boolean] = ACTIONS(1234),
    [anon_sym_string] = ACTIONS(1234),
    [anon_sym_symbol] = ACTIONS(1234),
    [anon_sym_object] = ACTIONS(1234),
    [sym_html_comment] = ACTIONS(5),
  },
  [296] = {
    [sym_import] = STATE(3540),
    [sym_parenthesized_expression] = STATE(1387),
    [sym_expression] = STATE(2106),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5803),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5803),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5585),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1387),
    [sym_subscript_expression] = STATE(1387),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3009),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5803),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1387),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym__type_query_member_expression] = STATE(2876),
    [sym__type_query_subscript_expression] = STATE(2877),
    [sym__type_query_call_expression] = STATE(2922),
    [sym__type_query_instantiation_expression] = STATE(3010),
    [sym_type_arguments] = STATE(566),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(2051),
    [anon_sym_export] = ACTIONS(1422),
    [anon_sym_type] = ACTIONS(1422),
    [anon_sym_namespace] = ACTIONS(1424),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_typeof] = ACTIONS(1444),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1422),
    [anon_sym_BANG] = ACTIONS(1428),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(1430),
    [anon_sym_yield] = ACTIONS(1432),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1434),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1494),
    [anon_sym_using] = ACTIONS(1438),
    [anon_sym_PLUS] = ACTIONS(1444),
    [anon_sym_DASH] = ACTIONS(1444),
    [anon_sym_SLASH] = ACTIONS(942),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(1428),
    [anon_sym_void] = ACTIONS(1444),
    [anon_sym_delete] = ACTIONS(1444),
    [anon_sym_PLUS_PLUS] = ACTIONS(1446),
    [anon_sym_DASH_DASH] = ACTIONS(1446),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(1448),
    [sym_this] = ACTIONS(2007),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1496),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1422),
    [anon_sym_readonly] = ACTIONS(1422),
    [anon_sym_get] = ACTIONS(1422),
    [anon_sym_set] = ACTIONS(1422),
    [anon_sym_declare] = ACTIONS(1422),
    [anon_sym_public] = ACTIONS(1422),
    [anon_sym_private] = ACTIONS(1422),
    [anon_sym_protected] = ACTIONS(1422),
    [anon_sym_override] = ACTIONS(1422),
    [anon_sym_module] = ACTIONS(1422),
    [anon_sym_any] = ACTIONS(1422),
    [anon_sym_number] = ACTIONS(1422),
    [anon_sym_boolean] = ACTIONS(1422),
    [anon_sym_string] = ACTIONS(1422),
    [anon_sym_symbol] = ACTIONS(1422),
    [anon_sym_object] = ACTIONS(1422),
    [sym_html_comment] = ACTIONS(5),
  },
  [297] = {
    [sym_import] = STATE(3636),
    [sym_parenthesized_expression] = STATE(1362),
    [sym_expression] = STATE(1905),
    [sym_primary_expression] = STATE(1810),
    [sym_yield_expression] = STATE(2358),
    [sym_object] = STATE(2222),
    [sym_object_pattern] = STATE(5492),
    [sym_array] = STATE(2222),
    [sym_array_pattern] = STATE(5492),
    [sym_class] = STATE(2222),
    [sym_function_expression] = STATE(2222),
    [sym_generator_function] = STATE(2222),
    [sym_arrow_function] = STATE(2222),
    [sym__call_signature] = STATE(5821),
    [sym_call_expression] = STATE(2222),
    [sym_new_expression] = STATE(1948),
    [sym_await_expression] = STATE(2358),
    [sym_member_expression] = STATE(1362),
    [sym_subscript_expression] = STATE(1362),
    [sym_assignment_expression] = STATE(2358),
    [sym__augmented_assignment_lhs] = STATE(3025),
    [sym_augmented_assignment_expression] = STATE(2358),
    [sym__destructuring_pattern] = STATE(5492),
    [sym_ternary_expression] = STATE(2358),
    [sym_binary_expression] = STATE(2358),
    [sym_unary_expression] = STATE(2358),
    [sym_update_expression] = STATE(2358),
    [sym_sequence_expression] = STATE(5245),
    [sym_string] = STATE(2222),
    [sym_template_string] = STATE(2222),
    [sym_regex] = STATE(2222),
    [sym_meta_property] = STATE(2222),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1362),
    [sym_type_assertion] = STATE(2358),
    [sym_as_expression] = STATE(2358),
    [sym_satisfies_expression] = STATE(2358),
    [sym_instantiation_expression] = STATE(2358),
    [sym_internal_module] = STATE(2358),
    [sym_type_arguments] = STATE(428),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4408),
    [sym_identifier] = ACTIONS(1468),
    [anon_sym_export] = ACTIONS(1352),
    [anon_sym_type] = ACTIONS(1352),
    [anon_sym_namespace] = ACTIONS(1354),
    [anon_sym_LBRACE] = ACTIONS(665),
    [anon_sym_typeof] = ACTIONS(21),
    [anon_sym_import] = ACTIONS(669),
    [anon_sym_let] = ACTIONS(1352),
    [anon_sym_BANG] = ACTIONS(33),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_SEMI] = ACTIONS(2053),
    [anon_sym_await] = ACTIONS(45),
    [anon_sym_yield] = ACTIONS(63),
    [anon_sym_LBRACK] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(676),
    [anon_sym_async] = ACTIONS(1362),
    [anon_sym_function] = ACTIONS(680),
    [anon_sym_new] = ACTIONS(1472),
    [anon_sym_using] = ACTIONS(75),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_SLASH] = ACTIONS(77),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(33),
    [anon_sym_void] = ACTIONS(21),
    [anon_sym_delete] = ACTIONS(21),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_DQUOTE] = ACTIONS(83),
    [anon_sym_SQUOTE] = ACTIONS(85),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(87),
    [sym_number] = ACTIONS(89),
    [sym_private_property_identifier] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(93),
    [sym_true] = ACTIONS(93),
    [sym_false] = ACTIONS(93),
    [sym_null] = ACTIONS(93),
    [sym_undefined] = ACTIONS(95),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1352),
    [anon_sym_readonly] = ACTIONS(1352),
    [anon_sym_get] = ACTIONS(1352),
    [anon_sym_set] = ACTIONS(1352),
    [anon_sym_declare] = ACTIONS(1352),
    [anon_sym_public] = ACTIONS(1352),
    [anon_sym_private] = ACTIONS(1352),
    [anon_sym_protected] = ACTIONS(1352),
    [anon_sym_override] = ACTIONS(1352),
    [anon_sym_module] = ACTIONS(1352),
    [anon_sym_any] = ACTIONS(1352),
    [anon_sym_number] = ACTIONS(1352),
    [anon_sym_boolean] = ACTIONS(1352),
    [anon_sym_string] = ACTIONS(1352),
    [anon_sym_symbol] = ACTIONS(1352),
    [anon_sym_object] = ACTIONS(1352),
    [sym__automatic_semicolon] = ACTIONS(2053),
    [sym_html_comment] = ACTIONS(5),
  },
  [298] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1213),
    [sym_expression] = STATE(2644),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(3722),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(3722),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5800),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1295),
    [sym_subscript_expression] = STATE(1295),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3013),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(3722),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_pattern] = STATE(3930),
    [sym_rest_pattern] = STATE(3684),
    [sym_non_null_expression] = STATE(1295),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(539),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(696),
    [anon_sym_export] = ACTIONS(113),
    [anon_sym_type] = ACTIONS(113),
    [anon_sym_namespace] = ACTIONS(122),
    [anon_sym_LBRACE] = ACTIONS(698),
    [anon_sym_typeof] = ACTIONS(179),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(113),
    [anon_sym_BANG] = ACTIONS(175),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(140),
    [anon_sym_yield] = ACTIONS(142),
    [anon_sym_LBRACK] = ACTIONS(1664),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(148),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(706),
    [anon_sym_using] = ACTIONS(158),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(162),
    [anon_sym_PLUS] = ACTIONS(179),
    [anon_sym_DASH] = ACTIONS(179),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(175),
    [anon_sym_void] = ACTIONS(179),
    [anon_sym_delete] = ACTIONS(179),
    [anon_sym_PLUS_PLUS] = ACTIONS(686),
    [anon_sym_DASH_DASH] = ACTIONS(686),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(192),
    [sym_this] = ACTIONS(2055),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(718),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(113),
    [anon_sym_readonly] = ACTIONS(2057),
    [anon_sym_get] = ACTIONS(113),
    [anon_sym_set] = ACTIONS(113),
    [anon_sym_declare] = ACTIONS(113),
    [anon_sym_public] = ACTIONS(113),
    [anon_sym_private] = ACTIONS(113),
    [anon_sym_protected] = ACTIONS(113),
    [anon_sym_override] = ACTIONS(113),
    [anon_sym_module] = ACTIONS(113),
    [anon_sym_any] = ACTIONS(113),
    [anon_sym_number] = ACTIONS(113),
    [anon_sym_boolean] = ACTIONS(113),
    [anon_sym_string] = ACTIONS(113),
    [anon_sym_symbol] = ACTIONS(113),
    [anon_sym_object] = ACTIONS(113),
    [sym_html_comment] = ACTIONS(5),
  },
  [299] = {
    [sym_import] = STATE(3639),
    [sym_empty_statement] = STATE(314),
    [sym_parenthesized_expression] = STATE(1322),
    [sym_expression] = STATE(2124),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5698),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5698),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5508),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1322),
    [sym_subscript_expression] = STATE(1322),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3003),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5698),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_sequence_expression] = STATE(5500),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1322),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(484),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1456),
    [anon_sym_export] = ACTIONS(1048),
    [anon_sym_type] = ACTIONS(1048),
    [anon_sym_namespace] = ACTIONS(1050),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_typeof] = ACTIONS(581),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1048),
    [anon_sym_BANG] = ACTIONS(553),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_SEMI] = ACTIONS(43),
    [anon_sym_await] = ACTIONS(555),
    [anon_sym_yield] = ACTIONS(557),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1058),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1464),
    [anon_sym_using] = ACTIONS(567),
    [anon_sym_PLUS] = ACTIONS(581),
    [anon_sym_DASH] = ACTIONS(581),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(553),
    [anon_sym_void] = ACTIONS(581),
    [anon_sym_delete] = ACTIONS(581),
    [anon_sym_PLUS_PLUS] = ACTIONS(583),
    [anon_sym_DASH_DASH] = ACTIONS(583),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(585),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1466),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1048),
    [anon_sym_readonly] = ACTIONS(1048),
    [anon_sym_get] = ACTIONS(1048),
    [anon_sym_set] = ACTIONS(1048),
    [anon_sym_declare] = ACTIONS(1048),
    [anon_sym_public] = ACTIONS(1048),
    [anon_sym_private] = ACTIONS(1048),
    [anon_sym_protected] = ACTIONS(1048),
    [anon_sym_override] = ACTIONS(1048),
    [anon_sym_module] = ACTIONS(1048),
    [anon_sym_any] = ACTIONS(1048),
    [anon_sym_number] = ACTIONS(1048),
    [anon_sym_boolean] = ACTIONS(1048),
    [anon_sym_string] = ACTIONS(1048),
    [anon_sym_symbol] = ACTIONS(1048),
    [anon_sym_object] = ACTIONS(1048),
    [sym_html_comment] = ACTIONS(5),
  },
  [300] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1213),
    [sym_expression] = STATE(2644),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(3722),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(3722),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5800),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1295),
    [sym_subscript_expression] = STATE(1295),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3013),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(3722),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_pattern] = STATE(3914),
    [sym_rest_pattern] = STATE(3684),
    [sym_non_null_expression] = STATE(1295),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(539),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(696),
    [anon_sym_export] = ACTIONS(113),
    [anon_sym_type] = ACTIONS(113),
    [anon_sym_namespace] = ACTIONS(122),
    [anon_sym_LBRACE] = ACTIONS(698),
    [anon_sym_typeof] = ACTIONS(179),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(113),
    [anon_sym_BANG] = ACTIONS(175),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(140),
    [anon_sym_yield] = ACTIONS(142),
    [anon_sym_LBRACK] = ACTIONS(1664),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(148),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(706),
    [anon_sym_using] = ACTIONS(158),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(162),
    [anon_sym_PLUS] = ACTIONS(179),
    [anon_sym_DASH] = ACTIONS(179),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(175),
    [anon_sym_void] = ACTIONS(179),
    [anon_sym_delete] = ACTIONS(179),
    [anon_sym_PLUS_PLUS] = ACTIONS(686),
    [anon_sym_DASH_DASH] = ACTIONS(686),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(192),
    [sym_this] = ACTIONS(784),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(718),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(113),
    [anon_sym_readonly] = ACTIONS(2059),
    [anon_sym_get] = ACTIONS(113),
    [anon_sym_set] = ACTIONS(113),
    [anon_sym_declare] = ACTIONS(113),
    [anon_sym_public] = ACTIONS(113),
    [anon_sym_private] = ACTIONS(113),
    [anon_sym_protected] = ACTIONS(113),
    [anon_sym_override] = ACTIONS(113),
    [anon_sym_module] = ACTIONS(113),
    [anon_sym_any] = ACTIONS(113),
    [anon_sym_number] = ACTIONS(113),
    [anon_sym_boolean] = ACTIONS(113),
    [anon_sym_string] = ACTIONS(113),
    [anon_sym_symbol] = ACTIONS(113),
    [anon_sym_object] = ACTIONS(113),
    [sym_html_comment] = ACTIONS(5),
  },
  [301] = {
    [sym_import] = STATE(3639),
    [sym_empty_statement] = STATE(306),
    [sym_parenthesized_expression] = STATE(1322),
    [sym_expression] = STATE(2292),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5698),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5698),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5508),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1322),
    [sym_subscript_expression] = STATE(1322),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3003),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5698),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_sequence_expression] = STATE(5561),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1322),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(484),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1456),
    [anon_sym_export] = ACTIONS(1048),
    [anon_sym_type] = ACTIONS(1048),
    [anon_sym_namespace] = ACTIONS(1050),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_typeof] = ACTIONS(581),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1048),
    [anon_sym_BANG] = ACTIONS(553),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_SEMI] = ACTIONS(43),
    [anon_sym_await] = ACTIONS(555),
    [anon_sym_yield] = ACTIONS(557),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1058),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1464),
    [anon_sym_using] = ACTIONS(567),
    [anon_sym_PLUS] = ACTIONS(581),
    [anon_sym_DASH] = ACTIONS(581),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(553),
    [anon_sym_void] = ACTIONS(581),
    [anon_sym_delete] = ACTIONS(581),
    [anon_sym_PLUS_PLUS] = ACTIONS(583),
    [anon_sym_DASH_DASH] = ACTIONS(583),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(585),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1466),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1048),
    [anon_sym_readonly] = ACTIONS(1048),
    [anon_sym_get] = ACTIONS(1048),
    [anon_sym_set] = ACTIONS(1048),
    [anon_sym_declare] = ACTIONS(1048),
    [anon_sym_public] = ACTIONS(1048),
    [anon_sym_private] = ACTIONS(1048),
    [anon_sym_protected] = ACTIONS(1048),
    [anon_sym_override] = ACTIONS(1048),
    [anon_sym_module] = ACTIONS(1048),
    [anon_sym_any] = ACTIONS(1048),
    [anon_sym_number] = ACTIONS(1048),
    [anon_sym_boolean] = ACTIONS(1048),
    [anon_sym_string] = ACTIONS(1048),
    [anon_sym_symbol] = ACTIONS(1048),
    [anon_sym_object] = ACTIONS(1048),
    [sym_html_comment] = ACTIONS(5),
  },
  [302] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1213),
    [sym_expression] = STATE(2644),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(3722),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(3722),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5800),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1295),
    [sym_subscript_expression] = STATE(1295),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3013),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(3722),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_pattern] = STATE(4226),
    [sym_rest_pattern] = STATE(3684),
    [sym_non_null_expression] = STATE(1295),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(539),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(696),
    [anon_sym_export] = ACTIONS(113),
    [anon_sym_type] = ACTIONS(113),
    [anon_sym_namespace] = ACTIONS(122),
    [anon_sym_LBRACE] = ACTIONS(698),
    [anon_sym_typeof] = ACTIONS(179),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(113),
    [anon_sym_BANG] = ACTIONS(175),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(140),
    [anon_sym_yield] = ACTIONS(142),
    [anon_sym_LBRACK] = ACTIONS(1664),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(148),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(706),
    [anon_sym_using] = ACTIONS(158),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(162),
    [anon_sym_PLUS] = ACTIONS(179),
    [anon_sym_DASH] = ACTIONS(179),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(175),
    [anon_sym_void] = ACTIONS(179),
    [anon_sym_delete] = ACTIONS(179),
    [anon_sym_PLUS_PLUS] = ACTIONS(686),
    [anon_sym_DASH_DASH] = ACTIONS(686),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(192),
    [sym_this] = ACTIONS(2061),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(718),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(113),
    [anon_sym_readonly] = ACTIONS(2063),
    [anon_sym_get] = ACTIONS(113),
    [anon_sym_set] = ACTIONS(113),
    [anon_sym_declare] = ACTIONS(113),
    [anon_sym_public] = ACTIONS(113),
    [anon_sym_private] = ACTIONS(113),
    [anon_sym_protected] = ACTIONS(113),
    [anon_sym_override] = ACTIONS(113),
    [anon_sym_module] = ACTIONS(113),
    [anon_sym_any] = ACTIONS(113),
    [anon_sym_number] = ACTIONS(113),
    [anon_sym_boolean] = ACTIONS(113),
    [anon_sym_string] = ACTIONS(113),
    [anon_sym_symbol] = ACTIONS(113),
    [anon_sym_object] = ACTIONS(113),
    [sym_html_comment] = ACTIONS(5),
  },
  [303] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1213),
    [sym_expression] = STATE(2644),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(3722),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(3722),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5800),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1295),
    [sym_subscript_expression] = STATE(1295),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3013),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(3722),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_pattern] = STATE(4312),
    [sym_rest_pattern] = STATE(3684),
    [sym_non_null_expression] = STATE(1295),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(539),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(696),
    [anon_sym_export] = ACTIONS(113),
    [anon_sym_type] = ACTIONS(113),
    [anon_sym_namespace] = ACTIONS(122),
    [anon_sym_LBRACE] = ACTIONS(698),
    [anon_sym_typeof] = ACTIONS(179),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(113),
    [anon_sym_BANG] = ACTIONS(175),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(140),
    [anon_sym_yield] = ACTIONS(142),
    [anon_sym_LBRACK] = ACTIONS(1664),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(148),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(706),
    [anon_sym_using] = ACTIONS(158),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(162),
    [anon_sym_PLUS] = ACTIONS(179),
    [anon_sym_DASH] = ACTIONS(179),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(175),
    [anon_sym_void] = ACTIONS(179),
    [anon_sym_delete] = ACTIONS(179),
    [anon_sym_PLUS_PLUS] = ACTIONS(686),
    [anon_sym_DASH_DASH] = ACTIONS(686),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(192),
    [sym_this] = ACTIONS(716),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(718),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(113),
    [anon_sym_readonly] = ACTIONS(2037),
    [anon_sym_get] = ACTIONS(113),
    [anon_sym_set] = ACTIONS(113),
    [anon_sym_declare] = ACTIONS(113),
    [anon_sym_public] = ACTIONS(113),
    [anon_sym_private] = ACTIONS(113),
    [anon_sym_protected] = ACTIONS(113),
    [anon_sym_override] = ACTIONS(113),
    [anon_sym_module] = ACTIONS(113),
    [anon_sym_any] = ACTIONS(113),
    [anon_sym_number] = ACTIONS(113),
    [anon_sym_boolean] = ACTIONS(113),
    [anon_sym_string] = ACTIONS(113),
    [anon_sym_symbol] = ACTIONS(113),
    [anon_sym_object] = ACTIONS(113),
    [sym_html_comment] = ACTIONS(5),
  },
  [304] = {
    [sym_import] = STATE(3639),
    [sym_empty_statement] = STATE(313),
    [sym_parenthesized_expression] = STATE(1322),
    [sym_expression] = STATE(2336),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5698),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5698),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5508),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1322),
    [sym_subscript_expression] = STATE(1322),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3003),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5698),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_sequence_expression] = STATE(5664),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1322),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(484),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1456),
    [anon_sym_export] = ACTIONS(1048),
    [anon_sym_type] = ACTIONS(1048),
    [anon_sym_namespace] = ACTIONS(1050),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_typeof] = ACTIONS(581),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1048),
    [anon_sym_BANG] = ACTIONS(553),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_SEMI] = ACTIONS(43),
    [anon_sym_await] = ACTIONS(555),
    [anon_sym_yield] = ACTIONS(557),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1058),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1464),
    [anon_sym_using] = ACTIONS(567),
    [anon_sym_PLUS] = ACTIONS(581),
    [anon_sym_DASH] = ACTIONS(581),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(553),
    [anon_sym_void] = ACTIONS(581),
    [anon_sym_delete] = ACTIONS(581),
    [anon_sym_PLUS_PLUS] = ACTIONS(583),
    [anon_sym_DASH_DASH] = ACTIONS(583),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(585),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1466),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1048),
    [anon_sym_readonly] = ACTIONS(1048),
    [anon_sym_get] = ACTIONS(1048),
    [anon_sym_set] = ACTIONS(1048),
    [anon_sym_declare] = ACTIONS(1048),
    [anon_sym_public] = ACTIONS(1048),
    [anon_sym_private] = ACTIONS(1048),
    [anon_sym_protected] = ACTIONS(1048),
    [anon_sym_override] = ACTIONS(1048),
    [anon_sym_module] = ACTIONS(1048),
    [anon_sym_any] = ACTIONS(1048),
    [anon_sym_number] = ACTIONS(1048),
    [anon_sym_boolean] = ACTIONS(1048),
    [anon_sym_string] = ACTIONS(1048),
    [anon_sym_symbol] = ACTIONS(1048),
    [anon_sym_object] = ACTIONS(1048),
    [sym_html_comment] = ACTIONS(5),
  },
  [305] = {
    [sym_import] = STATE(3639),
    [sym_empty_statement] = STATE(309),
    [sym_parenthesized_expression] = STATE(1322),
    [sym_expression] = STATE(2337),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5698),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5698),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5508),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1322),
    [sym_subscript_expression] = STATE(1322),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3003),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5698),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_sequence_expression] = STATE(5680),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1322),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(484),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1456),
    [anon_sym_export] = ACTIONS(1048),
    [anon_sym_type] = ACTIONS(1048),
    [anon_sym_namespace] = ACTIONS(1050),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_typeof] = ACTIONS(581),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1048),
    [anon_sym_BANG] = ACTIONS(553),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_SEMI] = ACTIONS(43),
    [anon_sym_await] = ACTIONS(555),
    [anon_sym_yield] = ACTIONS(557),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1058),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1464),
    [anon_sym_using] = ACTIONS(567),
    [anon_sym_PLUS] = ACTIONS(581),
    [anon_sym_DASH] = ACTIONS(581),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(553),
    [anon_sym_void] = ACTIONS(581),
    [anon_sym_delete] = ACTIONS(581),
    [anon_sym_PLUS_PLUS] = ACTIONS(583),
    [anon_sym_DASH_DASH] = ACTIONS(583),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(585),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1466),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1048),
    [anon_sym_readonly] = ACTIONS(1048),
    [anon_sym_get] = ACTIONS(1048),
    [anon_sym_set] = ACTIONS(1048),
    [anon_sym_declare] = ACTIONS(1048),
    [anon_sym_public] = ACTIONS(1048),
    [anon_sym_private] = ACTIONS(1048),
    [anon_sym_protected] = ACTIONS(1048),
    [anon_sym_override] = ACTIONS(1048),
    [anon_sym_module] = ACTIONS(1048),
    [anon_sym_any] = ACTIONS(1048),
    [anon_sym_number] = ACTIONS(1048),
    [anon_sym_boolean] = ACTIONS(1048),
    [anon_sym_string] = ACTIONS(1048),
    [anon_sym_symbol] = ACTIONS(1048),
    [anon_sym_object] = ACTIONS(1048),
    [sym_html_comment] = ACTIONS(5),
  },
  [306] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1398),
    [sym_expression] = STATE(2330),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5544),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5544),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5558),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1398),
    [sym_subscript_expression] = STATE(1398),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(2980),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5544),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_sequence_expression] = STATE(5565),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1398),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(638),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1482),
    [anon_sym_export] = ACTIONS(1158),
    [anon_sym_type] = ACTIONS(1158),
    [anon_sym_namespace] = ACTIONS(1160),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_typeof] = ACTIONS(756),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1158),
    [anon_sym_BANG] = ACTIONS(732),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_RPAREN] = ACTIONS(2065),
    [anon_sym_await] = ACTIONS(736),
    [anon_sym_yield] = ACTIONS(738),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1164),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1486),
    [anon_sym_using] = ACTIONS(746),
    [anon_sym_PLUS] = ACTIONS(756),
    [anon_sym_DASH] = ACTIONS(756),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(732),
    [anon_sym_void] = ACTIONS(756),
    [anon_sym_delete] = ACTIONS(756),
    [anon_sym_PLUS_PLUS] = ACTIONS(758),
    [anon_sym_DASH_DASH] = ACTIONS(758),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(764),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1488),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1158),
    [anon_sym_readonly] = ACTIONS(1158),
    [anon_sym_get] = ACTIONS(1158),
    [anon_sym_set] = ACTIONS(1158),
    [anon_sym_declare] = ACTIONS(1158),
    [anon_sym_public] = ACTIONS(1158),
    [anon_sym_private] = ACTIONS(1158),
    [anon_sym_protected] = ACTIONS(1158),
    [anon_sym_override] = ACTIONS(1158),
    [anon_sym_module] = ACTIONS(1158),
    [anon_sym_any] = ACTIONS(1158),
    [anon_sym_number] = ACTIONS(1158),
    [anon_sym_boolean] = ACTIONS(1158),
    [anon_sym_string] = ACTIONS(1158),
    [anon_sym_symbol] = ACTIONS(1158),
    [anon_sym_object] = ACTIONS(1158),
    [sym_html_comment] = ACTIONS(5),
  },
  [307] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1398),
    [sym_expression] = STATE(2174),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5544),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5544),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5558),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1398),
    [sym_subscript_expression] = STATE(1398),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(2980),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5544),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_sequence_expression] = STATE(5542),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1398),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(638),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1482),
    [anon_sym_export] = ACTIONS(1158),
    [anon_sym_type] = ACTIONS(1158),
    [anon_sym_namespace] = ACTIONS(1160),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_typeof] = ACTIONS(756),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1158),
    [anon_sym_BANG] = ACTIONS(732),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_RPAREN] = ACTIONS(2067),
    [anon_sym_await] = ACTIONS(736),
    [anon_sym_yield] = ACTIONS(738),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1164),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1486),
    [anon_sym_using] = ACTIONS(746),
    [anon_sym_PLUS] = ACTIONS(756),
    [anon_sym_DASH] = ACTIONS(756),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(732),
    [anon_sym_void] = ACTIONS(756),
    [anon_sym_delete] = ACTIONS(756),
    [anon_sym_PLUS_PLUS] = ACTIONS(758),
    [anon_sym_DASH_DASH] = ACTIONS(758),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(764),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1488),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1158),
    [anon_sym_readonly] = ACTIONS(1158),
    [anon_sym_get] = ACTIONS(1158),
    [anon_sym_set] = ACTIONS(1158),
    [anon_sym_declare] = ACTIONS(1158),
    [anon_sym_public] = ACTIONS(1158),
    [anon_sym_private] = ACTIONS(1158),
    [anon_sym_protected] = ACTIONS(1158),
    [anon_sym_override] = ACTIONS(1158),
    [anon_sym_module] = ACTIONS(1158),
    [anon_sym_any] = ACTIONS(1158),
    [anon_sym_number] = ACTIONS(1158),
    [anon_sym_boolean] = ACTIONS(1158),
    [anon_sym_string] = ACTIONS(1158),
    [anon_sym_symbol] = ACTIONS(1158),
    [anon_sym_object] = ACTIONS(1158),
    [sym_html_comment] = ACTIONS(5),
  },
  [308] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1398),
    [sym_expression] = STATE(2272),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5544),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5544),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5558),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1398),
    [sym_subscript_expression] = STATE(1398),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(2980),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5544),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_sequence_expression] = STATE(5723),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1398),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(638),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1482),
    [anon_sym_export] = ACTIONS(1158),
    [anon_sym_type] = ACTIONS(1158),
    [anon_sym_namespace] = ACTIONS(1160),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_typeof] = ACTIONS(756),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1158),
    [anon_sym_BANG] = ACTIONS(732),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_RPAREN] = ACTIONS(2069),
    [anon_sym_await] = ACTIONS(736),
    [anon_sym_yield] = ACTIONS(738),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1164),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1486),
    [anon_sym_using] = ACTIONS(746),
    [anon_sym_PLUS] = ACTIONS(756),
    [anon_sym_DASH] = ACTIONS(756),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(732),
    [anon_sym_void] = ACTIONS(756),
    [anon_sym_delete] = ACTIONS(756),
    [anon_sym_PLUS_PLUS] = ACTIONS(758),
    [anon_sym_DASH_DASH] = ACTIONS(758),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(764),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1488),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1158),
    [anon_sym_readonly] = ACTIONS(1158),
    [anon_sym_get] = ACTIONS(1158),
    [anon_sym_set] = ACTIONS(1158),
    [anon_sym_declare] = ACTIONS(1158),
    [anon_sym_public] = ACTIONS(1158),
    [anon_sym_private] = ACTIONS(1158),
    [anon_sym_protected] = ACTIONS(1158),
    [anon_sym_override] = ACTIONS(1158),
    [anon_sym_module] = ACTIONS(1158),
    [anon_sym_any] = ACTIONS(1158),
    [anon_sym_number] = ACTIONS(1158),
    [anon_sym_boolean] = ACTIONS(1158),
    [anon_sym_string] = ACTIONS(1158),
    [anon_sym_symbol] = ACTIONS(1158),
    [anon_sym_object] = ACTIONS(1158),
    [sym_html_comment] = ACTIONS(5),
  },
  [309] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1398),
    [sym_expression] = STATE(2273),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5544),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5544),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5558),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1398),
    [sym_subscript_expression] = STATE(1398),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(2980),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5544),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_sequence_expression] = STATE(5726),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1398),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(638),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1482),
    [anon_sym_export] = ACTIONS(1158),
    [anon_sym_type] = ACTIONS(1158),
    [anon_sym_namespace] = ACTIONS(1160),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_typeof] = ACTIONS(756),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1158),
    [anon_sym_BANG] = ACTIONS(732),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_RPAREN] = ACTIONS(2071),
    [anon_sym_await] = ACTIONS(736),
    [anon_sym_yield] = ACTIONS(738),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1164),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1486),
    [anon_sym_using] = ACTIONS(746),
    [anon_sym_PLUS] = ACTIONS(756),
    [anon_sym_DASH] = ACTIONS(756),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(732),
    [anon_sym_void] = ACTIONS(756),
    [anon_sym_delete] = ACTIONS(756),
    [anon_sym_PLUS_PLUS] = ACTIONS(758),
    [anon_sym_DASH_DASH] = ACTIONS(758),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(764),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1488),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1158),
    [anon_sym_readonly] = ACTIONS(1158),
    [anon_sym_get] = ACTIONS(1158),
    [anon_sym_set] = ACTIONS(1158),
    [anon_sym_declare] = ACTIONS(1158),
    [anon_sym_public] = ACTIONS(1158),
    [anon_sym_private] = ACTIONS(1158),
    [anon_sym_protected] = ACTIONS(1158),
    [anon_sym_override] = ACTIONS(1158),
    [anon_sym_module] = ACTIONS(1158),
    [anon_sym_any] = ACTIONS(1158),
    [anon_sym_number] = ACTIONS(1158),
    [anon_sym_boolean] = ACTIONS(1158),
    [anon_sym_string] = ACTIONS(1158),
    [anon_sym_symbol] = ACTIONS(1158),
    [anon_sym_object] = ACTIONS(1158),
    [sym_html_comment] = ACTIONS(5),
  },
  [310] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1398),
    [sym_expression] = STATE(2275),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5544),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5544),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5558),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1398),
    [sym_subscript_expression] = STATE(1398),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(2980),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5544),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_sequence_expression] = STATE(5751),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1398),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(638),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1482),
    [anon_sym_export] = ACTIONS(1158),
    [anon_sym_type] = ACTIONS(1158),
    [anon_sym_namespace] = ACTIONS(1160),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_typeof] = ACTIONS(756),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1158),
    [anon_sym_BANG] = ACTIONS(732),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_RPAREN] = ACTIONS(2073),
    [anon_sym_await] = ACTIONS(736),
    [anon_sym_yield] = ACTIONS(738),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1164),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1486),
    [anon_sym_using] = ACTIONS(746),
    [anon_sym_PLUS] = ACTIONS(756),
    [anon_sym_DASH] = ACTIONS(756),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(732),
    [anon_sym_void] = ACTIONS(756),
    [anon_sym_delete] = ACTIONS(756),
    [anon_sym_PLUS_PLUS] = ACTIONS(758),
    [anon_sym_DASH_DASH] = ACTIONS(758),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(764),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1488),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1158),
    [anon_sym_readonly] = ACTIONS(1158),
    [anon_sym_get] = ACTIONS(1158),
    [anon_sym_set] = ACTIONS(1158),
    [anon_sym_declare] = ACTIONS(1158),
    [anon_sym_public] = ACTIONS(1158),
    [anon_sym_private] = ACTIONS(1158),
    [anon_sym_protected] = ACTIONS(1158),
    [anon_sym_override] = ACTIONS(1158),
    [anon_sym_module] = ACTIONS(1158),
    [anon_sym_any] = ACTIONS(1158),
    [anon_sym_number] = ACTIONS(1158),
    [anon_sym_boolean] = ACTIONS(1158),
    [anon_sym_string] = ACTIONS(1158),
    [anon_sym_symbol] = ACTIONS(1158),
    [anon_sym_object] = ACTIONS(1158),
    [sym_html_comment] = ACTIONS(5),
  },
  [311] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1398),
    [sym_expression] = STATE(2329),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5544),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5544),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5558),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1398),
    [sym_subscript_expression] = STATE(1398),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(2980),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5544),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_sequence_expression] = STATE(5562),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1398),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(638),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1482),
    [anon_sym_export] = ACTIONS(1158),
    [anon_sym_type] = ACTIONS(1158),
    [anon_sym_namespace] = ACTIONS(1160),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_typeof] = ACTIONS(756),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1158),
    [anon_sym_BANG] = ACTIONS(732),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_RPAREN] = ACTIONS(2075),
    [anon_sym_await] = ACTIONS(736),
    [anon_sym_yield] = ACTIONS(738),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1164),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1486),
    [anon_sym_using] = ACTIONS(746),
    [anon_sym_PLUS] = ACTIONS(756),
    [anon_sym_DASH] = ACTIONS(756),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(732),
    [anon_sym_void] = ACTIONS(756),
    [anon_sym_delete] = ACTIONS(756),
    [anon_sym_PLUS_PLUS] = ACTIONS(758),
    [anon_sym_DASH_DASH] = ACTIONS(758),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(764),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1488),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1158),
    [anon_sym_readonly] = ACTIONS(1158),
    [anon_sym_get] = ACTIONS(1158),
    [anon_sym_set] = ACTIONS(1158),
    [anon_sym_declare] = ACTIONS(1158),
    [anon_sym_public] = ACTIONS(1158),
    [anon_sym_private] = ACTIONS(1158),
    [anon_sym_protected] = ACTIONS(1158),
    [anon_sym_override] = ACTIONS(1158),
    [anon_sym_module] = ACTIONS(1158),
    [anon_sym_any] = ACTIONS(1158),
    [anon_sym_number] = ACTIONS(1158),
    [anon_sym_boolean] = ACTIONS(1158),
    [anon_sym_string] = ACTIONS(1158),
    [anon_sym_symbol] = ACTIONS(1158),
    [anon_sym_object] = ACTIONS(1158),
    [sym_html_comment] = ACTIONS(5),
  },
  [312] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1447),
    [sym_expression] = STATE(2644),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5019),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5019),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5800),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1447),
    [sym_subscript_expression] = STATE(1447),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3013),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5019),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1447),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(539),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(2077),
    [anon_sym_export] = ACTIONS(2079),
    [anon_sym_type] = ACTIONS(2079),
    [anon_sym_namespace] = ACTIONS(2081),
    [anon_sym_LBRACE] = ACTIONS(1930),
    [anon_sym_typeof] = ACTIONS(179),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_var] = ACTIONS(2083),
    [anon_sym_let] = ACTIONS(2085),
    [anon_sym_const] = ACTIONS(2087),
    [anon_sym_BANG] = ACTIONS(175),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(140),
    [anon_sym_yield] = ACTIONS(142),
    [anon_sym_LBRACK] = ACTIONS(1938),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(2089),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(2091),
    [anon_sym_using] = ACTIONS(158),
    [anon_sym_PLUS] = ACTIONS(179),
    [anon_sym_DASH] = ACTIONS(179),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(175),
    [anon_sym_void] = ACTIONS(179),
    [anon_sym_delete] = ACTIONS(179),
    [anon_sym_PLUS_PLUS] = ACTIONS(686),
    [anon_sym_DASH_DASH] = ACTIONS(686),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(192),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(2093),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(2079),
    [anon_sym_readonly] = ACTIONS(2079),
    [anon_sym_get] = ACTIONS(2079),
    [anon_sym_set] = ACTIONS(2079),
    [anon_sym_declare] = ACTIONS(2079),
    [anon_sym_public] = ACTIONS(2079),
    [anon_sym_private] = ACTIONS(2079),
    [anon_sym_protected] = ACTIONS(2079),
    [anon_sym_override] = ACTIONS(2079),
    [anon_sym_module] = ACTIONS(2079),
    [anon_sym_any] = ACTIONS(2079),
    [anon_sym_number] = ACTIONS(2079),
    [anon_sym_boolean] = ACTIONS(2079),
    [anon_sym_string] = ACTIONS(2079),
    [anon_sym_symbol] = ACTIONS(2079),
    [anon_sym_object] = ACTIONS(2079),
    [sym_html_comment] = ACTIONS(5),
  },
  [313] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1398),
    [sym_expression] = STATE(2269),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5544),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5544),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5558),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1398),
    [sym_subscript_expression] = STATE(1398),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(2980),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5544),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_sequence_expression] = STATE(5687),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1398),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(638),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1482),
    [anon_sym_export] = ACTIONS(1158),
    [anon_sym_type] = ACTIONS(1158),
    [anon_sym_namespace] = ACTIONS(1160),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_typeof] = ACTIONS(756),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1158),
    [anon_sym_BANG] = ACTIONS(732),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_RPAREN] = ACTIONS(2095),
    [anon_sym_await] = ACTIONS(736),
    [anon_sym_yield] = ACTIONS(738),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1164),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1486),
    [anon_sym_using] = ACTIONS(746),
    [anon_sym_PLUS] = ACTIONS(756),
    [anon_sym_DASH] = ACTIONS(756),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(732),
    [anon_sym_void] = ACTIONS(756),
    [anon_sym_delete] = ACTIONS(756),
    [anon_sym_PLUS_PLUS] = ACTIONS(758),
    [anon_sym_DASH_DASH] = ACTIONS(758),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(764),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1488),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1158),
    [anon_sym_readonly] = ACTIONS(1158),
    [anon_sym_get] = ACTIONS(1158),
    [anon_sym_set] = ACTIONS(1158),
    [anon_sym_declare] = ACTIONS(1158),
    [anon_sym_public] = ACTIONS(1158),
    [anon_sym_private] = ACTIONS(1158),
    [anon_sym_protected] = ACTIONS(1158),
    [anon_sym_override] = ACTIONS(1158),
    [anon_sym_module] = ACTIONS(1158),
    [anon_sym_any] = ACTIONS(1158),
    [anon_sym_number] = ACTIONS(1158),
    [anon_sym_boolean] = ACTIONS(1158),
    [anon_sym_string] = ACTIONS(1158),
    [anon_sym_symbol] = ACTIONS(1158),
    [anon_sym_object] = ACTIONS(1158),
    [sym_html_comment] = ACTIONS(5),
  },
  [314] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1398),
    [sym_expression] = STATE(2290),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5544),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5544),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5558),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1398),
    [sym_subscript_expression] = STATE(1398),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(2980),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5544),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_sequence_expression] = STATE(5511),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1398),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(638),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1482),
    [anon_sym_export] = ACTIONS(1158),
    [anon_sym_type] = ACTIONS(1158),
    [anon_sym_namespace] = ACTIONS(1160),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_typeof] = ACTIONS(756),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1158),
    [anon_sym_BANG] = ACTIONS(732),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_RPAREN] = ACTIONS(2097),
    [anon_sym_await] = ACTIONS(736),
    [anon_sym_yield] = ACTIONS(738),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1164),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1486),
    [anon_sym_using] = ACTIONS(746),
    [anon_sym_PLUS] = ACTIONS(756),
    [anon_sym_DASH] = ACTIONS(756),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(732),
    [anon_sym_void] = ACTIONS(756),
    [anon_sym_delete] = ACTIONS(756),
    [anon_sym_PLUS_PLUS] = ACTIONS(758),
    [anon_sym_DASH_DASH] = ACTIONS(758),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(764),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1488),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1158),
    [anon_sym_readonly] = ACTIONS(1158),
    [anon_sym_get] = ACTIONS(1158),
    [anon_sym_set] = ACTIONS(1158),
    [anon_sym_declare] = ACTIONS(1158),
    [anon_sym_public] = ACTIONS(1158),
    [anon_sym_private] = ACTIONS(1158),
    [anon_sym_protected] = ACTIONS(1158),
    [anon_sym_override] = ACTIONS(1158),
    [anon_sym_module] = ACTIONS(1158),
    [anon_sym_any] = ACTIONS(1158),
    [anon_sym_number] = ACTIONS(1158),
    [anon_sym_boolean] = ACTIONS(1158),
    [anon_sym_string] = ACTIONS(1158),
    [anon_sym_symbol] = ACTIONS(1158),
    [anon_sym_object] = ACTIONS(1158),
    [sym_html_comment] = ACTIONS(5),
  },
  [315] = {
    [sym_import] = STATE(3639),
    [sym_statement_block] = STATE(1683),
    [sym_parenthesized_expression] = STATE(1322),
    [sym_expression] = STATE(1762),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5698),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5698),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5508),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1322),
    [sym_subscript_expression] = STATE(1322),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3003),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5698),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1322),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(484),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1456),
    [anon_sym_export] = ACTIONS(1048),
    [anon_sym_type] = ACTIONS(1048),
    [anon_sym_namespace] = ACTIONS(1050),
    [anon_sym_LBRACE] = ACTIONS(2099),
    [anon_sym_typeof] = ACTIONS(581),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1048),
    [anon_sym_BANG] = ACTIONS(553),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(555),
    [anon_sym_yield] = ACTIONS(557),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1058),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1464),
    [anon_sym_using] = ACTIONS(567),
    [anon_sym_PLUS] = ACTIONS(581),
    [anon_sym_DASH] = ACTIONS(581),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(553),
    [anon_sym_void] = ACTIONS(581),
    [anon_sym_delete] = ACTIONS(581),
    [anon_sym_PLUS_PLUS] = ACTIONS(583),
    [anon_sym_DASH_DASH] = ACTIONS(583),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(585),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1466),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1048),
    [anon_sym_readonly] = ACTIONS(1048),
    [anon_sym_get] = ACTIONS(1048),
    [anon_sym_set] = ACTIONS(1048),
    [anon_sym_declare] = ACTIONS(1048),
    [anon_sym_public] = ACTIONS(1048),
    [anon_sym_private] = ACTIONS(1048),
    [anon_sym_protected] = ACTIONS(1048),
    [anon_sym_override] = ACTIONS(1048),
    [anon_sym_module] = ACTIONS(1048),
    [anon_sym_any] = ACTIONS(1048),
    [anon_sym_number] = ACTIONS(1048),
    [anon_sym_boolean] = ACTIONS(1048),
    [anon_sym_string] = ACTIONS(1048),
    [anon_sym_symbol] = ACTIONS(1048),
    [anon_sym_object] = ACTIONS(1048),
    [sym_html_comment] = ACTIONS(5),
  },
  [316] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1398),
    [sym_expression] = STATE(2341),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5544),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5544),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5558),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1398),
    [sym_subscript_expression] = STATE(1398),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(2980),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5544),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_sequence_expression] = STATE(5620),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1398),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(638),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1482),
    [anon_sym_export] = ACTIONS(1158),
    [anon_sym_type] = ACTIONS(1158),
    [anon_sym_namespace] = ACTIONS(1160),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_typeof] = ACTIONS(756),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1158),
    [anon_sym_BANG] = ACTIONS(732),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(736),
    [anon_sym_yield] = ACTIONS(738),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1164),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1486),
    [anon_sym_using] = ACTIONS(746),
    [anon_sym_PLUS] = ACTIONS(756),
    [anon_sym_DASH] = ACTIONS(756),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(732),
    [anon_sym_void] = ACTIONS(756),
    [anon_sym_delete] = ACTIONS(756),
    [anon_sym_PLUS_PLUS] = ACTIONS(758),
    [anon_sym_DASH_DASH] = ACTIONS(758),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(764),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1488),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1158),
    [anon_sym_readonly] = ACTIONS(1158),
    [anon_sym_get] = ACTIONS(1158),
    [anon_sym_set] = ACTIONS(1158),
    [anon_sym_declare] = ACTIONS(1158),
    [anon_sym_public] = ACTIONS(1158),
    [anon_sym_private] = ACTIONS(1158),
    [anon_sym_protected] = ACTIONS(1158),
    [anon_sym_override] = ACTIONS(1158),
    [anon_sym_module] = ACTIONS(1158),
    [anon_sym_any] = ACTIONS(1158),
    [anon_sym_number] = ACTIONS(1158),
    [anon_sym_boolean] = ACTIONS(1158),
    [anon_sym_string] = ACTIONS(1158),
    [anon_sym_symbol] = ACTIONS(1158),
    [anon_sym_object] = ACTIONS(1158),
    [sym_html_comment] = ACTIONS(5),
  },
  [317] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1398),
    [sym_expression] = STATE(1825),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5544),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5544),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5558),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1398),
    [sym_subscript_expression] = STATE(1398),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(2980),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5544),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_sequence_expression] = STATE(5513),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1398),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(638),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1482),
    [anon_sym_export] = ACTIONS(1158),
    [anon_sym_type] = ACTIONS(1158),
    [anon_sym_namespace] = ACTIONS(1160),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_typeof] = ACTIONS(756),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1158),
    [anon_sym_BANG] = ACTIONS(732),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(736),
    [anon_sym_yield] = ACTIONS(738),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1164),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1486),
    [anon_sym_using] = ACTIONS(746),
    [anon_sym_PLUS] = ACTIONS(756),
    [anon_sym_DASH] = ACTIONS(756),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(732),
    [anon_sym_void] = ACTIONS(756),
    [anon_sym_delete] = ACTIONS(756),
    [anon_sym_PLUS_PLUS] = ACTIONS(758),
    [anon_sym_DASH_DASH] = ACTIONS(758),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(764),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1488),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1158),
    [anon_sym_readonly] = ACTIONS(1158),
    [anon_sym_get] = ACTIONS(1158),
    [anon_sym_set] = ACTIONS(1158),
    [anon_sym_declare] = ACTIONS(1158),
    [anon_sym_public] = ACTIONS(1158),
    [anon_sym_private] = ACTIONS(1158),
    [anon_sym_protected] = ACTIONS(1158),
    [anon_sym_override] = ACTIONS(1158),
    [anon_sym_module] = ACTIONS(1158),
    [anon_sym_any] = ACTIONS(1158),
    [anon_sym_number] = ACTIONS(1158),
    [anon_sym_boolean] = ACTIONS(1158),
    [anon_sym_string] = ACTIONS(1158),
    [anon_sym_symbol] = ACTIONS(1158),
    [anon_sym_object] = ACTIONS(1158),
    [sym_html_comment] = ACTIONS(5),
  },
  [318] = {
    [sym_import] = STATE(3636),
    [sym_statement_block] = STATE(2195),
    [sym_parenthesized_expression] = STATE(1410),
    [sym_expression] = STATE(2140),
    [sym_primary_expression] = STATE(1810),
    [sym_yield_expression] = STATE(2358),
    [sym_object] = STATE(2222),
    [sym_object_pattern] = STATE(5580),
    [sym_array] = STATE(2222),
    [sym_array_pattern] = STATE(5580),
    [sym_class] = STATE(2222),
    [sym_function_expression] = STATE(2222),
    [sym_generator_function] = STATE(2222),
    [sym_arrow_function] = STATE(2222),
    [sym__call_signature] = STATE(5466),
    [sym_call_expression] = STATE(2222),
    [sym_new_expression] = STATE(1948),
    [sym_await_expression] = STATE(2358),
    [sym_member_expression] = STATE(1410),
    [sym_subscript_expression] = STATE(1410),
    [sym_assignment_expression] = STATE(2358),
    [sym__augmented_assignment_lhs] = STATE(3004),
    [sym_augmented_assignment_expression] = STATE(2358),
    [sym__destructuring_pattern] = STATE(5580),
    [sym_ternary_expression] = STATE(2358),
    [sym_binary_expression] = STATE(2358),
    [sym_unary_expression] = STATE(2358),
    [sym_update_expression] = STATE(2358),
    [sym_string] = STATE(2222),
    [sym_template_string] = STATE(2222),
    [sym_regex] = STATE(2222),
    [sym_meta_property] = STATE(2222),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1410),
    [sym_type_assertion] = STATE(2358),
    [sym_as_expression] = STATE(2358),
    [sym_satisfies_expression] = STATE(2358),
    [sym_instantiation_expression] = STATE(2358),
    [sym_internal_module] = STATE(2358),
    [sym_type_arguments] = STATE(452),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4408),
    [sym_identifier] = ACTIONS(1498),
    [anon_sym_export] = ACTIONS(1270),
    [anon_sym_type] = ACTIONS(1270),
    [anon_sym_namespace] = ACTIONS(1272),
    [anon_sym_LBRACE] = ACTIONS(2101),
    [anon_sym_typeof] = ACTIONS(1298),
    [anon_sym_import] = ACTIONS(669),
    [anon_sym_let] = ACTIONS(1270),
    [anon_sym_BANG] = ACTIONS(1278),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_await] = ACTIONS(1282),
    [anon_sym_yield] = ACTIONS(1284),
    [anon_sym_LBRACK] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(676),
    [anon_sym_async] = ACTIONS(1288),
    [anon_sym_function] = ACTIONS(680),
    [anon_sym_new] = ACTIONS(1502),
    [anon_sym_using] = ACTIONS(1292),
    [anon_sym_PLUS] = ACTIONS(1298),
    [anon_sym_DASH] = ACTIONS(1298),
    [anon_sym_SLASH] = ACTIONS(77),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(1278),
    [anon_sym_void] = ACTIONS(1298),
    [anon_sym_delete] = ACTIONS(1298),
    [anon_sym_PLUS_PLUS] = ACTIONS(1300),
    [anon_sym_DASH_DASH] = ACTIONS(1300),
    [anon_sym_DQUOTE] = ACTIONS(83),
    [anon_sym_SQUOTE] = ACTIONS(85),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(87),
    [sym_number] = ACTIONS(89),
    [sym_private_property_identifier] = ACTIONS(1306),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(93),
    [sym_true] = ACTIONS(93),
    [sym_false] = ACTIONS(93),
    [sym_null] = ACTIONS(93),
    [sym_undefined] = ACTIONS(1504),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1270),
    [anon_sym_readonly] = ACTIONS(1270),
    [anon_sym_get] = ACTIONS(1270),
    [anon_sym_set] = ACTIONS(1270),
    [anon_sym_declare] = ACTIONS(1270),
    [anon_sym_public] = ACTIONS(1270),
    [anon_sym_private] = ACTIONS(1270),
    [anon_sym_protected] = ACTIONS(1270),
    [anon_sym_override] = ACTIONS(1270),
    [anon_sym_module] = ACTIONS(1270),
    [anon_sym_any] = ACTIONS(1270),
    [anon_sym_number] = ACTIONS(1270),
    [anon_sym_boolean] = ACTIONS(1270),
    [anon_sym_string] = ACTIONS(1270),
    [anon_sym_symbol] = ACTIONS(1270),
    [anon_sym_object] = ACTIONS(1270),
    [sym_html_comment] = ACTIONS(5),
  },
  [319] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1322),
    [sym_expression] = STATE(2144),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5698),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5698),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5508),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1322),
    [sym_subscript_expression] = STATE(1322),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3003),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5698),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_sequence_expression] = STATE(5498),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1322),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(484),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1456),
    [anon_sym_export] = ACTIONS(1048),
    [anon_sym_type] = ACTIONS(1048),
    [anon_sym_namespace] = ACTIONS(1050),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_typeof] = ACTIONS(581),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1048),
    [anon_sym_BANG] = ACTIONS(553),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(555),
    [anon_sym_yield] = ACTIONS(557),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1058),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1464),
    [anon_sym_using] = ACTIONS(567),
    [anon_sym_PLUS] = ACTIONS(581),
    [anon_sym_DASH] = ACTIONS(581),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(553),
    [anon_sym_void] = ACTIONS(581),
    [anon_sym_delete] = ACTIONS(581),
    [anon_sym_PLUS_PLUS] = ACTIONS(583),
    [anon_sym_DASH_DASH] = ACTIONS(583),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(585),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1466),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1048),
    [anon_sym_readonly] = ACTIONS(1048),
    [anon_sym_get] = ACTIONS(1048),
    [anon_sym_set] = ACTIONS(1048),
    [anon_sym_declare] = ACTIONS(1048),
    [anon_sym_public] = ACTIONS(1048),
    [anon_sym_private] = ACTIONS(1048),
    [anon_sym_protected] = ACTIONS(1048),
    [anon_sym_override] = ACTIONS(1048),
    [anon_sym_module] = ACTIONS(1048),
    [anon_sym_any] = ACTIONS(1048),
    [anon_sym_number] = ACTIONS(1048),
    [anon_sym_boolean] = ACTIONS(1048),
    [anon_sym_string] = ACTIONS(1048),
    [anon_sym_symbol] = ACTIONS(1048),
    [anon_sym_object] = ACTIONS(1048),
    [sym_html_comment] = ACTIONS(5),
  },
  [320] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1322),
    [sym_expression] = STATE(2287),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5698),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5698),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5508),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1322),
    [sym_subscript_expression] = STATE(1322),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3003),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5698),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_sequence_expression] = STATE(5643),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1322),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(484),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1456),
    [anon_sym_export] = ACTIONS(1048),
    [anon_sym_type] = ACTIONS(1048),
    [anon_sym_namespace] = ACTIONS(1050),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_typeof] = ACTIONS(581),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1048),
    [anon_sym_BANG] = ACTIONS(553),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(555),
    [anon_sym_yield] = ACTIONS(557),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1058),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1464),
    [anon_sym_using] = ACTIONS(567),
    [anon_sym_PLUS] = ACTIONS(581),
    [anon_sym_DASH] = ACTIONS(581),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(553),
    [anon_sym_void] = ACTIONS(581),
    [anon_sym_delete] = ACTIONS(581),
    [anon_sym_PLUS_PLUS] = ACTIONS(583),
    [anon_sym_DASH_DASH] = ACTIONS(583),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(585),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1466),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1048),
    [anon_sym_readonly] = ACTIONS(1048),
    [anon_sym_get] = ACTIONS(1048),
    [anon_sym_set] = ACTIONS(1048),
    [anon_sym_declare] = ACTIONS(1048),
    [anon_sym_public] = ACTIONS(1048),
    [anon_sym_private] = ACTIONS(1048),
    [anon_sym_protected] = ACTIONS(1048),
    [anon_sym_override] = ACTIONS(1048),
    [anon_sym_module] = ACTIONS(1048),
    [anon_sym_any] = ACTIONS(1048),
    [anon_sym_number] = ACTIONS(1048),
    [anon_sym_boolean] = ACTIONS(1048),
    [anon_sym_string] = ACTIONS(1048),
    [anon_sym_symbol] = ACTIONS(1048),
    [anon_sym_object] = ACTIONS(1048),
    [sym_html_comment] = ACTIONS(5),
  },
  [321] = {
    [sym_import] = STATE(3636),
    [sym_statement_block] = STATE(2262),
    [sym_parenthesized_expression] = STATE(1410),
    [sym_expression] = STATE(2155),
    [sym_primary_expression] = STATE(1810),
    [sym_yield_expression] = STATE(2358),
    [sym_object] = STATE(2222),
    [sym_object_pattern] = STATE(5580),
    [sym_array] = STATE(2222),
    [sym_array_pattern] = STATE(5580),
    [sym_class] = STATE(2222),
    [sym_function_expression] = STATE(2222),
    [sym_generator_function] = STATE(2222),
    [sym_arrow_function] = STATE(2222),
    [sym__call_signature] = STATE(5466),
    [sym_call_expression] = STATE(2222),
    [sym_new_expression] = STATE(1948),
    [sym_await_expression] = STATE(2358),
    [sym_member_expression] = STATE(1410),
    [sym_subscript_expression] = STATE(1410),
    [sym_assignment_expression] = STATE(2358),
    [sym__augmented_assignment_lhs] = STATE(3004),
    [sym_augmented_assignment_expression] = STATE(2358),
    [sym__destructuring_pattern] = STATE(5580),
    [sym_ternary_expression] = STATE(2358),
    [sym_binary_expression] = STATE(2358),
    [sym_unary_expression] = STATE(2358),
    [sym_update_expression] = STATE(2358),
    [sym_string] = STATE(2222),
    [sym_template_string] = STATE(2222),
    [sym_regex] = STATE(2222),
    [sym_meta_property] = STATE(2222),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1410),
    [sym_type_assertion] = STATE(2358),
    [sym_as_expression] = STATE(2358),
    [sym_satisfies_expression] = STATE(2358),
    [sym_instantiation_expression] = STATE(2358),
    [sym_internal_module] = STATE(2358),
    [sym_type_arguments] = STATE(452),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4408),
    [sym_identifier] = ACTIONS(1498),
    [anon_sym_export] = ACTIONS(1270),
    [anon_sym_type] = ACTIONS(1270),
    [anon_sym_namespace] = ACTIONS(1272),
    [anon_sym_LBRACE] = ACTIONS(2101),
    [anon_sym_typeof] = ACTIONS(1298),
    [anon_sym_import] = ACTIONS(669),
    [anon_sym_let] = ACTIONS(1270),
    [anon_sym_BANG] = ACTIONS(1278),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_await] = ACTIONS(1282),
    [anon_sym_yield] = ACTIONS(1284),
    [anon_sym_LBRACK] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(676),
    [anon_sym_async] = ACTIONS(1288),
    [anon_sym_function] = ACTIONS(680),
    [anon_sym_new] = ACTIONS(1502),
    [anon_sym_using] = ACTIONS(1292),
    [anon_sym_PLUS] = ACTIONS(1298),
    [anon_sym_DASH] = ACTIONS(1298),
    [anon_sym_SLASH] = ACTIONS(77),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(1278),
    [anon_sym_void] = ACTIONS(1298),
    [anon_sym_delete] = ACTIONS(1298),
    [anon_sym_PLUS_PLUS] = ACTIONS(1300),
    [anon_sym_DASH_DASH] = ACTIONS(1300),
    [anon_sym_DQUOTE] = ACTIONS(83),
    [anon_sym_SQUOTE] = ACTIONS(85),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(87),
    [sym_number] = ACTIONS(89),
    [sym_private_property_identifier] = ACTIONS(1306),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(93),
    [sym_true] = ACTIONS(93),
    [sym_false] = ACTIONS(93),
    [sym_null] = ACTIONS(93),
    [sym_undefined] = ACTIONS(1504),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1270),
    [anon_sym_readonly] = ACTIONS(1270),
    [anon_sym_get] = ACTIONS(1270),
    [anon_sym_set] = ACTIONS(1270),
    [anon_sym_declare] = ACTIONS(1270),
    [anon_sym_public] = ACTIONS(1270),
    [anon_sym_private] = ACTIONS(1270),
    [anon_sym_protected] = ACTIONS(1270),
    [anon_sym_override] = ACTIONS(1270),
    [anon_sym_module] = ACTIONS(1270),
    [anon_sym_any] = ACTIONS(1270),
    [anon_sym_number] = ACTIONS(1270),
    [anon_sym_boolean] = ACTIONS(1270),
    [anon_sym_string] = ACTIONS(1270),
    [anon_sym_symbol] = ACTIONS(1270),
    [anon_sym_object] = ACTIONS(1270),
    [sym_html_comment] = ACTIONS(5),
  },
  [322] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1398),
    [sym_expression] = STATE(2288),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5544),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5544),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5558),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1398),
    [sym_subscript_expression] = STATE(1398),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(2980),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5544),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_sequence_expression] = STATE(5722),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1398),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(638),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1482),
    [anon_sym_export] = ACTIONS(1158),
    [anon_sym_type] = ACTIONS(1158),
    [anon_sym_namespace] = ACTIONS(1160),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_typeof] = ACTIONS(756),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1158),
    [anon_sym_BANG] = ACTIONS(732),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(736),
    [anon_sym_yield] = ACTIONS(738),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1164),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1486),
    [anon_sym_using] = ACTIONS(746),
    [anon_sym_PLUS] = ACTIONS(756),
    [anon_sym_DASH] = ACTIONS(756),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(732),
    [anon_sym_void] = ACTIONS(756),
    [anon_sym_delete] = ACTIONS(756),
    [anon_sym_PLUS_PLUS] = ACTIONS(758),
    [anon_sym_DASH_DASH] = ACTIONS(758),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(764),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1488),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1158),
    [anon_sym_readonly] = ACTIONS(1158),
    [anon_sym_get] = ACTIONS(1158),
    [anon_sym_set] = ACTIONS(1158),
    [anon_sym_declare] = ACTIONS(1158),
    [anon_sym_public] = ACTIONS(1158),
    [anon_sym_private] = ACTIONS(1158),
    [anon_sym_protected] = ACTIONS(1158),
    [anon_sym_override] = ACTIONS(1158),
    [anon_sym_module] = ACTIONS(1158),
    [anon_sym_any] = ACTIONS(1158),
    [anon_sym_number] = ACTIONS(1158),
    [anon_sym_boolean] = ACTIONS(1158),
    [anon_sym_string] = ACTIONS(1158),
    [anon_sym_symbol] = ACTIONS(1158),
    [anon_sym_object] = ACTIONS(1158),
    [sym_html_comment] = ACTIONS(5),
  },
  [323] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1398),
    [sym_expression] = STATE(2121),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5544),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5544),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5558),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1398),
    [sym_subscript_expression] = STATE(1398),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(2980),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5544),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_sequence_expression] = STATE(5736),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1398),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(638),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1482),
    [anon_sym_export] = ACTIONS(1158),
    [anon_sym_type] = ACTIONS(1158),
    [anon_sym_namespace] = ACTIONS(1160),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_typeof] = ACTIONS(756),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1158),
    [anon_sym_BANG] = ACTIONS(732),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(736),
    [anon_sym_yield] = ACTIONS(738),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1164),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1486),
    [anon_sym_using] = ACTIONS(746),
    [anon_sym_PLUS] = ACTIONS(756),
    [anon_sym_DASH] = ACTIONS(756),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(732),
    [anon_sym_void] = ACTIONS(756),
    [anon_sym_delete] = ACTIONS(756),
    [anon_sym_PLUS_PLUS] = ACTIONS(758),
    [anon_sym_DASH_DASH] = ACTIONS(758),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(764),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1488),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1158),
    [anon_sym_readonly] = ACTIONS(1158),
    [anon_sym_get] = ACTIONS(1158),
    [anon_sym_set] = ACTIONS(1158),
    [anon_sym_declare] = ACTIONS(1158),
    [anon_sym_public] = ACTIONS(1158),
    [anon_sym_private] = ACTIONS(1158),
    [anon_sym_protected] = ACTIONS(1158),
    [anon_sym_override] = ACTIONS(1158),
    [anon_sym_module] = ACTIONS(1158),
    [anon_sym_any] = ACTIONS(1158),
    [anon_sym_number] = ACTIONS(1158),
    [anon_sym_boolean] = ACTIONS(1158),
    [anon_sym_string] = ACTIONS(1158),
    [anon_sym_symbol] = ACTIONS(1158),
    [anon_sym_object] = ACTIONS(1158),
    [sym_html_comment] = ACTIONS(5),
  },
  [324] = {
    [sym_import] = STATE(3636),
    [sym_statement_block] = STATE(2198),
    [sym_parenthesized_expression] = STATE(1410),
    [sym_expression] = STATE(2158),
    [sym_primary_expression] = STATE(1810),
    [sym_yield_expression] = STATE(2358),
    [sym_object] = STATE(2222),
    [sym_object_pattern] = STATE(5580),
    [sym_array] = STATE(2222),
    [sym_array_pattern] = STATE(5580),
    [sym_class] = STATE(2222),
    [sym_function_expression] = STATE(2222),
    [sym_generator_function] = STATE(2222),
    [sym_arrow_function] = STATE(2222),
    [sym__call_signature] = STATE(5466),
    [sym_call_expression] = STATE(2222),
    [sym_new_expression] = STATE(1948),
    [sym_await_expression] = STATE(2358),
    [sym_member_expression] = STATE(1410),
    [sym_subscript_expression] = STATE(1410),
    [sym_assignment_expression] = STATE(2358),
    [sym__augmented_assignment_lhs] = STATE(3004),
    [sym_augmented_assignment_expression] = STATE(2358),
    [sym__destructuring_pattern] = STATE(5580),
    [sym_ternary_expression] = STATE(2358),
    [sym_binary_expression] = STATE(2358),
    [sym_unary_expression] = STATE(2358),
    [sym_update_expression] = STATE(2358),
    [sym_string] = STATE(2222),
    [sym_template_string] = STATE(2222),
    [sym_regex] = STATE(2222),
    [sym_meta_property] = STATE(2222),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1410),
    [sym_type_assertion] = STATE(2358),
    [sym_as_expression] = STATE(2358),
    [sym_satisfies_expression] = STATE(2358),
    [sym_instantiation_expression] = STATE(2358),
    [sym_internal_module] = STATE(2358),
    [sym_type_arguments] = STATE(452),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4408),
    [sym_identifier] = ACTIONS(1498),
    [anon_sym_export] = ACTIONS(1270),
    [anon_sym_type] = ACTIONS(1270),
    [anon_sym_namespace] = ACTIONS(1272),
    [anon_sym_LBRACE] = ACTIONS(2101),
    [anon_sym_typeof] = ACTIONS(1298),
    [anon_sym_import] = ACTIONS(669),
    [anon_sym_let] = ACTIONS(1270),
    [anon_sym_BANG] = ACTIONS(1278),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_await] = ACTIONS(1282),
    [anon_sym_yield] = ACTIONS(1284),
    [anon_sym_LBRACK] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(676),
    [anon_sym_async] = ACTIONS(1288),
    [anon_sym_function] = ACTIONS(680),
    [anon_sym_new] = ACTIONS(1502),
    [anon_sym_using] = ACTIONS(1292),
    [anon_sym_PLUS] = ACTIONS(1298),
    [anon_sym_DASH] = ACTIONS(1298),
    [anon_sym_SLASH] = ACTIONS(77),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(1278),
    [anon_sym_void] = ACTIONS(1298),
    [anon_sym_delete] = ACTIONS(1298),
    [anon_sym_PLUS_PLUS] = ACTIONS(1300),
    [anon_sym_DASH_DASH] = ACTIONS(1300),
    [anon_sym_DQUOTE] = ACTIONS(83),
    [anon_sym_SQUOTE] = ACTIONS(85),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(87),
    [sym_number] = ACTIONS(89),
    [sym_private_property_identifier] = ACTIONS(1306),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(93),
    [sym_true] = ACTIONS(93),
    [sym_false] = ACTIONS(93),
    [sym_null] = ACTIONS(93),
    [sym_undefined] = ACTIONS(1504),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1270),
    [anon_sym_readonly] = ACTIONS(1270),
    [anon_sym_get] = ACTIONS(1270),
    [anon_sym_set] = ACTIONS(1270),
    [anon_sym_declare] = ACTIONS(1270),
    [anon_sym_public] = ACTIONS(1270),
    [anon_sym_private] = ACTIONS(1270),
    [anon_sym_protected] = ACTIONS(1270),
    [anon_sym_override] = ACTIONS(1270),
    [anon_sym_module] = ACTIONS(1270),
    [anon_sym_any] = ACTIONS(1270),
    [anon_sym_number] = ACTIONS(1270),
    [anon_sym_boolean] = ACTIONS(1270),
    [anon_sym_string] = ACTIONS(1270),
    [anon_sym_symbol] = ACTIONS(1270),
    [anon_sym_object] = ACTIONS(1270),
    [sym_html_comment] = ACTIONS(5),
  },
  [325] = {
    [sym_import] = STATE(3636),
    [sym_statement_block] = STATE(2201),
    [sym_parenthesized_expression] = STATE(1410),
    [sym_expression] = STATE(2159),
    [sym_primary_expression] = STATE(1810),
    [sym_yield_expression] = STATE(2358),
    [sym_object] = STATE(2222),
    [sym_object_pattern] = STATE(5580),
    [sym_array] = STATE(2222),
    [sym_array_pattern] = STATE(5580),
    [sym_class] = STATE(2222),
    [sym_function_expression] = STATE(2222),
    [sym_generator_function] = STATE(2222),
    [sym_arrow_function] = STATE(2222),
    [sym__call_signature] = STATE(5466),
    [sym_call_expression] = STATE(2222),
    [sym_new_expression] = STATE(1948),
    [sym_await_expression] = STATE(2358),
    [sym_member_expression] = STATE(1410),
    [sym_subscript_expression] = STATE(1410),
    [sym_assignment_expression] = STATE(2358),
    [sym__augmented_assignment_lhs] = STATE(3004),
    [sym_augmented_assignment_expression] = STATE(2358),
    [sym__destructuring_pattern] = STATE(5580),
    [sym_ternary_expression] = STATE(2358),
    [sym_binary_expression] = STATE(2358),
    [sym_unary_expression] = STATE(2358),
    [sym_update_expression] = STATE(2358),
    [sym_string] = STATE(2222),
    [sym_template_string] = STATE(2222),
    [sym_regex] = STATE(2222),
    [sym_meta_property] = STATE(2222),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1410),
    [sym_type_assertion] = STATE(2358),
    [sym_as_expression] = STATE(2358),
    [sym_satisfies_expression] = STATE(2358),
    [sym_instantiation_expression] = STATE(2358),
    [sym_internal_module] = STATE(2358),
    [sym_type_arguments] = STATE(452),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4408),
    [sym_identifier] = ACTIONS(1498),
    [anon_sym_export] = ACTIONS(1270),
    [anon_sym_type] = ACTIONS(1270),
    [anon_sym_namespace] = ACTIONS(1272),
    [anon_sym_LBRACE] = ACTIONS(2101),
    [anon_sym_typeof] = ACTIONS(1298),
    [anon_sym_import] = ACTIONS(669),
    [anon_sym_let] = ACTIONS(1270),
    [anon_sym_BANG] = ACTIONS(1278),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_await] = ACTIONS(1282),
    [anon_sym_yield] = ACTIONS(1284),
    [anon_sym_LBRACK] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(676),
    [anon_sym_async] = ACTIONS(1288),
    [anon_sym_function] = ACTIONS(680),
    [anon_sym_new] = ACTIONS(1502),
    [anon_sym_using] = ACTIONS(1292),
    [anon_sym_PLUS] = ACTIONS(1298),
    [anon_sym_DASH] = ACTIONS(1298),
    [anon_sym_SLASH] = ACTIONS(77),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(1278),
    [anon_sym_void] = ACTIONS(1298),
    [anon_sym_delete] = ACTIONS(1298),
    [anon_sym_PLUS_PLUS] = ACTIONS(1300),
    [anon_sym_DASH_DASH] = ACTIONS(1300),
    [anon_sym_DQUOTE] = ACTIONS(83),
    [anon_sym_SQUOTE] = ACTIONS(85),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(87),
    [sym_number] = ACTIONS(89),
    [sym_private_property_identifier] = ACTIONS(1306),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(93),
    [sym_true] = ACTIONS(93),
    [sym_false] = ACTIONS(93),
    [sym_null] = ACTIONS(93),
    [sym_undefined] = ACTIONS(1504),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1270),
    [anon_sym_readonly] = ACTIONS(1270),
    [anon_sym_get] = ACTIONS(1270),
    [anon_sym_set] = ACTIONS(1270),
    [anon_sym_declare] = ACTIONS(1270),
    [anon_sym_public] = ACTIONS(1270),
    [anon_sym_private] = ACTIONS(1270),
    [anon_sym_protected] = ACTIONS(1270),
    [anon_sym_override] = ACTIONS(1270),
    [anon_sym_module] = ACTIONS(1270),
    [anon_sym_any] = ACTIONS(1270),
    [anon_sym_number] = ACTIONS(1270),
    [anon_sym_boolean] = ACTIONS(1270),
    [anon_sym_string] = ACTIONS(1270),
    [anon_sym_symbol] = ACTIONS(1270),
    [anon_sym_object] = ACTIONS(1270),
    [sym_html_comment] = ACTIONS(5),
  },
  [326] = {
    [sym_import] = STATE(3636),
    [sym_statement_block] = STATE(2204),
    [sym_parenthesized_expression] = STATE(1410),
    [sym_expression] = STATE(2160),
    [sym_primary_expression] = STATE(1810),
    [sym_yield_expression] = STATE(2358),
    [sym_object] = STATE(2222),
    [sym_object_pattern] = STATE(5580),
    [sym_array] = STATE(2222),
    [sym_array_pattern] = STATE(5580),
    [sym_class] = STATE(2222),
    [sym_function_expression] = STATE(2222),
    [sym_generator_function] = STATE(2222),
    [sym_arrow_function] = STATE(2222),
    [sym__call_signature] = STATE(5466),
    [sym_call_expression] = STATE(2222),
    [sym_new_expression] = STATE(1948),
    [sym_await_expression] = STATE(2358),
    [sym_member_expression] = STATE(1410),
    [sym_subscript_expression] = STATE(1410),
    [sym_assignment_expression] = STATE(2358),
    [sym__augmented_assignment_lhs] = STATE(3004),
    [sym_augmented_assignment_expression] = STATE(2358),
    [sym__destructuring_pattern] = STATE(5580),
    [sym_ternary_expression] = STATE(2358),
    [sym_binary_expression] = STATE(2358),
    [sym_unary_expression] = STATE(2358),
    [sym_update_expression] = STATE(2358),
    [sym_string] = STATE(2222),
    [sym_template_string] = STATE(2222),
    [sym_regex] = STATE(2222),
    [sym_meta_property] = STATE(2222),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1410),
    [sym_type_assertion] = STATE(2358),
    [sym_as_expression] = STATE(2358),
    [sym_satisfies_expression] = STATE(2358),
    [sym_instantiation_expression] = STATE(2358),
    [sym_internal_module] = STATE(2358),
    [sym_type_arguments] = STATE(452),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4408),
    [sym_identifier] = ACTIONS(1498),
    [anon_sym_export] = ACTIONS(1270),
    [anon_sym_type] = ACTIONS(1270),
    [anon_sym_namespace] = ACTIONS(1272),
    [anon_sym_LBRACE] = ACTIONS(2101),
    [anon_sym_typeof] = ACTIONS(1298),
    [anon_sym_import] = ACTIONS(669),
    [anon_sym_let] = ACTIONS(1270),
    [anon_sym_BANG] = ACTIONS(1278),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_await] = ACTIONS(1282),
    [anon_sym_yield] = ACTIONS(1284),
    [anon_sym_LBRACK] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(676),
    [anon_sym_async] = ACTIONS(1288),
    [anon_sym_function] = ACTIONS(680),
    [anon_sym_new] = ACTIONS(1502),
    [anon_sym_using] = ACTIONS(1292),
    [anon_sym_PLUS] = ACTIONS(1298),
    [anon_sym_DASH] = ACTIONS(1298),
    [anon_sym_SLASH] = ACTIONS(77),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(1278),
    [anon_sym_void] = ACTIONS(1298),
    [anon_sym_delete] = ACTIONS(1298),
    [anon_sym_PLUS_PLUS] = ACTIONS(1300),
    [anon_sym_DASH_DASH] = ACTIONS(1300),
    [anon_sym_DQUOTE] = ACTIONS(83),
    [anon_sym_SQUOTE] = ACTIONS(85),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(87),
    [sym_number] = ACTIONS(89),
    [sym_private_property_identifier] = ACTIONS(1306),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(93),
    [sym_true] = ACTIONS(93),
    [sym_false] = ACTIONS(93),
    [sym_null] = ACTIONS(93),
    [sym_undefined] = ACTIONS(1504),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1270),
    [anon_sym_readonly] = ACTIONS(1270),
    [anon_sym_get] = ACTIONS(1270),
    [anon_sym_set] = ACTIONS(1270),
    [anon_sym_declare] = ACTIONS(1270),
    [anon_sym_public] = ACTIONS(1270),
    [anon_sym_private] = ACTIONS(1270),
    [anon_sym_protected] = ACTIONS(1270),
    [anon_sym_override] = ACTIONS(1270),
    [anon_sym_module] = ACTIONS(1270),
    [anon_sym_any] = ACTIONS(1270),
    [anon_sym_number] = ACTIONS(1270),
    [anon_sym_boolean] = ACTIONS(1270),
    [anon_sym_string] = ACTIONS(1270),
    [anon_sym_symbol] = ACTIONS(1270),
    [anon_sym_object] = ACTIONS(1270),
    [sym_html_comment] = ACTIONS(5),
  },
  [327] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1322),
    [sym_expression] = STATE(2225),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5698),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5698),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5508),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1322),
    [sym_subscript_expression] = STATE(1322),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3003),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5698),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_sequence_expression] = STATE(5835),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1322),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(484),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1456),
    [anon_sym_export] = ACTIONS(1048),
    [anon_sym_type] = ACTIONS(1048),
    [anon_sym_namespace] = ACTIONS(1050),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_typeof] = ACTIONS(581),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1048),
    [anon_sym_BANG] = ACTIONS(553),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(555),
    [anon_sym_yield] = ACTIONS(557),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1058),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1464),
    [anon_sym_using] = ACTIONS(567),
    [anon_sym_PLUS] = ACTIONS(581),
    [anon_sym_DASH] = ACTIONS(581),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(553),
    [anon_sym_void] = ACTIONS(581),
    [anon_sym_delete] = ACTIONS(581),
    [anon_sym_PLUS_PLUS] = ACTIONS(583),
    [anon_sym_DASH_DASH] = ACTIONS(583),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(585),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1466),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1048),
    [anon_sym_readonly] = ACTIONS(1048),
    [anon_sym_get] = ACTIONS(1048),
    [anon_sym_set] = ACTIONS(1048),
    [anon_sym_declare] = ACTIONS(1048),
    [anon_sym_public] = ACTIONS(1048),
    [anon_sym_private] = ACTIONS(1048),
    [anon_sym_protected] = ACTIONS(1048),
    [anon_sym_override] = ACTIONS(1048),
    [anon_sym_module] = ACTIONS(1048),
    [anon_sym_any] = ACTIONS(1048),
    [anon_sym_number] = ACTIONS(1048),
    [anon_sym_boolean] = ACTIONS(1048),
    [anon_sym_string] = ACTIONS(1048),
    [anon_sym_symbol] = ACTIONS(1048),
    [anon_sym_object] = ACTIONS(1048),
    [sym_html_comment] = ACTIONS(5),
  },
  [328] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1398),
    [sym_expression] = STATE(2289),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5544),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5544),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5558),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1398),
    [sym_subscript_expression] = STATE(1398),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(2980),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5544),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_sequence_expression] = STATE(5506),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1398),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(638),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1482),
    [anon_sym_export] = ACTIONS(1158),
    [anon_sym_type] = ACTIONS(1158),
    [anon_sym_namespace] = ACTIONS(1160),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_typeof] = ACTIONS(756),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1158),
    [anon_sym_BANG] = ACTIONS(732),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(736),
    [anon_sym_yield] = ACTIONS(738),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1164),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1486),
    [anon_sym_using] = ACTIONS(746),
    [anon_sym_PLUS] = ACTIONS(756),
    [anon_sym_DASH] = ACTIONS(756),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(732),
    [anon_sym_void] = ACTIONS(756),
    [anon_sym_delete] = ACTIONS(756),
    [anon_sym_PLUS_PLUS] = ACTIONS(758),
    [anon_sym_DASH_DASH] = ACTIONS(758),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(764),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1488),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1158),
    [anon_sym_readonly] = ACTIONS(1158),
    [anon_sym_get] = ACTIONS(1158),
    [anon_sym_set] = ACTIONS(1158),
    [anon_sym_declare] = ACTIONS(1158),
    [anon_sym_public] = ACTIONS(1158),
    [anon_sym_private] = ACTIONS(1158),
    [anon_sym_protected] = ACTIONS(1158),
    [anon_sym_override] = ACTIONS(1158),
    [anon_sym_module] = ACTIONS(1158),
    [anon_sym_any] = ACTIONS(1158),
    [anon_sym_number] = ACTIONS(1158),
    [anon_sym_boolean] = ACTIONS(1158),
    [anon_sym_string] = ACTIONS(1158),
    [anon_sym_symbol] = ACTIONS(1158),
    [anon_sym_object] = ACTIONS(1158),
    [sym_html_comment] = ACTIONS(5),
  },
  [329] = {
    [sym_import] = STATE(3636),
    [sym_statement_block] = STATE(2262),
    [sym_parenthesized_expression] = STATE(1362),
    [sym_expression] = STATE(1828),
    [sym_primary_expression] = STATE(1810),
    [sym_yield_expression] = STATE(2358),
    [sym_object] = STATE(2222),
    [sym_object_pattern] = STATE(5492),
    [sym_array] = STATE(2222),
    [sym_array_pattern] = STATE(5492),
    [sym_class] = STATE(2222),
    [sym_function_expression] = STATE(2222),
    [sym_generator_function] = STATE(2222),
    [sym_arrow_function] = STATE(2222),
    [sym__call_signature] = STATE(5821),
    [sym_call_expression] = STATE(2222),
    [sym_new_expression] = STATE(1948),
    [sym_await_expression] = STATE(2358),
    [sym_member_expression] = STATE(1362),
    [sym_subscript_expression] = STATE(1362),
    [sym_assignment_expression] = STATE(2358),
    [sym__augmented_assignment_lhs] = STATE(3025),
    [sym_augmented_assignment_expression] = STATE(2358),
    [sym__destructuring_pattern] = STATE(5492),
    [sym_ternary_expression] = STATE(2358),
    [sym_binary_expression] = STATE(2358),
    [sym_unary_expression] = STATE(2358),
    [sym_update_expression] = STATE(2358),
    [sym_string] = STATE(2222),
    [sym_template_string] = STATE(2222),
    [sym_regex] = STATE(2222),
    [sym_meta_property] = STATE(2222),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1362),
    [sym_type_assertion] = STATE(2358),
    [sym_as_expression] = STATE(2358),
    [sym_satisfies_expression] = STATE(2358),
    [sym_instantiation_expression] = STATE(2358),
    [sym_internal_module] = STATE(2358),
    [sym_type_arguments] = STATE(428),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4408),
    [sym_identifier] = ACTIONS(1468),
    [anon_sym_export] = ACTIONS(1352),
    [anon_sym_type] = ACTIONS(1352),
    [anon_sym_namespace] = ACTIONS(1354),
    [anon_sym_LBRACE] = ACTIONS(2101),
    [anon_sym_typeof] = ACTIONS(21),
    [anon_sym_import] = ACTIONS(669),
    [anon_sym_let] = ACTIONS(1352),
    [anon_sym_BANG] = ACTIONS(33),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_await] = ACTIONS(45),
    [anon_sym_yield] = ACTIONS(63),
    [anon_sym_LBRACK] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(676),
    [anon_sym_async] = ACTIONS(1362),
    [anon_sym_function] = ACTIONS(680),
    [anon_sym_new] = ACTIONS(1472),
    [anon_sym_using] = ACTIONS(75),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_SLASH] = ACTIONS(77),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(33),
    [anon_sym_void] = ACTIONS(21),
    [anon_sym_delete] = ACTIONS(21),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_DQUOTE] = ACTIONS(83),
    [anon_sym_SQUOTE] = ACTIONS(85),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(87),
    [sym_number] = ACTIONS(89),
    [sym_private_property_identifier] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(93),
    [sym_true] = ACTIONS(93),
    [sym_false] = ACTIONS(93),
    [sym_null] = ACTIONS(93),
    [sym_undefined] = ACTIONS(95),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1352),
    [anon_sym_readonly] = ACTIONS(1352),
    [anon_sym_get] = ACTIONS(1352),
    [anon_sym_set] = ACTIONS(1352),
    [anon_sym_declare] = ACTIONS(1352),
    [anon_sym_public] = ACTIONS(1352),
    [anon_sym_private] = ACTIONS(1352),
    [anon_sym_protected] = ACTIONS(1352),
    [anon_sym_override] = ACTIONS(1352),
    [anon_sym_module] = ACTIONS(1352),
    [anon_sym_any] = ACTIONS(1352),
    [anon_sym_number] = ACTIONS(1352),
    [anon_sym_boolean] = ACTIONS(1352),
    [anon_sym_string] = ACTIONS(1352),
    [anon_sym_symbol] = ACTIONS(1352),
    [anon_sym_object] = ACTIONS(1352),
    [sym_html_comment] = ACTIONS(5),
  },
  [330] = {
    [sym_import] = STATE(3639),
    [sym_statement_block] = STATE(1658),
    [sym_parenthesized_expression] = STATE(1398),
    [sym_expression] = STATE(1886),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5544),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5544),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5558),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1398),
    [sym_subscript_expression] = STATE(1398),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(2980),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5544),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1398),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(638),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1482),
    [anon_sym_export] = ACTIONS(1158),
    [anon_sym_type] = ACTIONS(1158),
    [anon_sym_namespace] = ACTIONS(1160),
    [anon_sym_LBRACE] = ACTIONS(2099),
    [anon_sym_typeof] = ACTIONS(756),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1158),
    [anon_sym_BANG] = ACTIONS(732),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(736),
    [anon_sym_yield] = ACTIONS(738),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1164),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1486),
    [anon_sym_using] = ACTIONS(746),
    [anon_sym_PLUS] = ACTIONS(756),
    [anon_sym_DASH] = ACTIONS(756),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(732),
    [anon_sym_void] = ACTIONS(756),
    [anon_sym_delete] = ACTIONS(756),
    [anon_sym_PLUS_PLUS] = ACTIONS(758),
    [anon_sym_DASH_DASH] = ACTIONS(758),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(764),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1488),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1158),
    [anon_sym_readonly] = ACTIONS(1158),
    [anon_sym_get] = ACTIONS(1158),
    [anon_sym_set] = ACTIONS(1158),
    [anon_sym_declare] = ACTIONS(1158),
    [anon_sym_public] = ACTIONS(1158),
    [anon_sym_private] = ACTIONS(1158),
    [anon_sym_protected] = ACTIONS(1158),
    [anon_sym_override] = ACTIONS(1158),
    [anon_sym_module] = ACTIONS(1158),
    [anon_sym_any] = ACTIONS(1158),
    [anon_sym_number] = ACTIONS(1158),
    [anon_sym_boolean] = ACTIONS(1158),
    [anon_sym_string] = ACTIONS(1158),
    [anon_sym_symbol] = ACTIONS(1158),
    [anon_sym_object] = ACTIONS(1158),
    [sym_html_comment] = ACTIONS(5),
  },
  [331] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1322),
    [sym_expression] = STATE(2166),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5698),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5698),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5508),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1322),
    [sym_subscript_expression] = STATE(1322),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3003),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5698),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_sequence_expression] = STATE(5487),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1322),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(484),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1456),
    [anon_sym_export] = ACTIONS(1048),
    [anon_sym_type] = ACTIONS(1048),
    [anon_sym_namespace] = ACTIONS(1050),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_typeof] = ACTIONS(581),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1048),
    [anon_sym_BANG] = ACTIONS(553),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(555),
    [anon_sym_yield] = ACTIONS(557),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1058),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1464),
    [anon_sym_using] = ACTIONS(567),
    [anon_sym_PLUS] = ACTIONS(581),
    [anon_sym_DASH] = ACTIONS(581),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(553),
    [anon_sym_void] = ACTIONS(581),
    [anon_sym_delete] = ACTIONS(581),
    [anon_sym_PLUS_PLUS] = ACTIONS(583),
    [anon_sym_DASH_DASH] = ACTIONS(583),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(585),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1466),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1048),
    [anon_sym_readonly] = ACTIONS(1048),
    [anon_sym_get] = ACTIONS(1048),
    [anon_sym_set] = ACTIONS(1048),
    [anon_sym_declare] = ACTIONS(1048),
    [anon_sym_public] = ACTIONS(1048),
    [anon_sym_private] = ACTIONS(1048),
    [anon_sym_protected] = ACTIONS(1048),
    [anon_sym_override] = ACTIONS(1048),
    [anon_sym_module] = ACTIONS(1048),
    [anon_sym_any] = ACTIONS(1048),
    [anon_sym_number] = ACTIONS(1048),
    [anon_sym_boolean] = ACTIONS(1048),
    [anon_sym_string] = ACTIONS(1048),
    [anon_sym_symbol] = ACTIONS(1048),
    [anon_sym_object] = ACTIONS(1048),
    [sym_html_comment] = ACTIONS(5),
  },
  [332] = {
    [sym_import] = STATE(3639),
    [sym_statement_block] = STATE(1668),
    [sym_parenthesized_expression] = STATE(1398),
    [sym_expression] = STATE(1890),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5544),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5544),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5558),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1398),
    [sym_subscript_expression] = STATE(1398),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(2980),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5544),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1398),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(638),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1482),
    [anon_sym_export] = ACTIONS(1158),
    [anon_sym_type] = ACTIONS(1158),
    [anon_sym_namespace] = ACTIONS(1160),
    [anon_sym_LBRACE] = ACTIONS(2099),
    [anon_sym_typeof] = ACTIONS(756),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1158),
    [anon_sym_BANG] = ACTIONS(732),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(736),
    [anon_sym_yield] = ACTIONS(738),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1164),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1486),
    [anon_sym_using] = ACTIONS(746),
    [anon_sym_PLUS] = ACTIONS(756),
    [anon_sym_DASH] = ACTIONS(756),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(732),
    [anon_sym_void] = ACTIONS(756),
    [anon_sym_delete] = ACTIONS(756),
    [anon_sym_PLUS_PLUS] = ACTIONS(758),
    [anon_sym_DASH_DASH] = ACTIONS(758),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(764),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1488),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1158),
    [anon_sym_readonly] = ACTIONS(1158),
    [anon_sym_get] = ACTIONS(1158),
    [anon_sym_set] = ACTIONS(1158),
    [anon_sym_declare] = ACTIONS(1158),
    [anon_sym_public] = ACTIONS(1158),
    [anon_sym_private] = ACTIONS(1158),
    [anon_sym_protected] = ACTIONS(1158),
    [anon_sym_override] = ACTIONS(1158),
    [anon_sym_module] = ACTIONS(1158),
    [anon_sym_any] = ACTIONS(1158),
    [anon_sym_number] = ACTIONS(1158),
    [anon_sym_boolean] = ACTIONS(1158),
    [anon_sym_string] = ACTIONS(1158),
    [anon_sym_symbol] = ACTIONS(1158),
    [anon_sym_object] = ACTIONS(1158),
    [sym_html_comment] = ACTIONS(5),
  },
  [333] = {
    [sym_import] = STATE(3639),
    [sym_statement_block] = STATE(1672),
    [sym_parenthesized_expression] = STATE(1398),
    [sym_expression] = STATE(1913),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5544),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5544),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5558),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1398),
    [sym_subscript_expression] = STATE(1398),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(2980),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5544),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1398),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(638),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1482),
    [anon_sym_export] = ACTIONS(1158),
    [anon_sym_type] = ACTIONS(1158),
    [anon_sym_namespace] = ACTIONS(1160),
    [anon_sym_LBRACE] = ACTIONS(2099),
    [anon_sym_typeof] = ACTIONS(756),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1158),
    [anon_sym_BANG] = ACTIONS(732),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(736),
    [anon_sym_yield] = ACTIONS(738),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1164),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1486),
    [anon_sym_using] = ACTIONS(746),
    [anon_sym_PLUS] = ACTIONS(756),
    [anon_sym_DASH] = ACTIONS(756),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(732),
    [anon_sym_void] = ACTIONS(756),
    [anon_sym_delete] = ACTIONS(756),
    [anon_sym_PLUS_PLUS] = ACTIONS(758),
    [anon_sym_DASH_DASH] = ACTIONS(758),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(764),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1488),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1158),
    [anon_sym_readonly] = ACTIONS(1158),
    [anon_sym_get] = ACTIONS(1158),
    [anon_sym_set] = ACTIONS(1158),
    [anon_sym_declare] = ACTIONS(1158),
    [anon_sym_public] = ACTIONS(1158),
    [anon_sym_private] = ACTIONS(1158),
    [anon_sym_protected] = ACTIONS(1158),
    [anon_sym_override] = ACTIONS(1158),
    [anon_sym_module] = ACTIONS(1158),
    [anon_sym_any] = ACTIONS(1158),
    [anon_sym_number] = ACTIONS(1158),
    [anon_sym_boolean] = ACTIONS(1158),
    [anon_sym_string] = ACTIONS(1158),
    [anon_sym_symbol] = ACTIONS(1158),
    [anon_sym_object] = ACTIONS(1158),
    [sym_html_comment] = ACTIONS(5),
  },
  [334] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1457),
    [sym_expression] = STATE(2591),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5823),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5823),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5477),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1457),
    [sym_subscript_expression] = STATE(1457),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(2986),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5823),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1457),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_mapped_type_clause] = STATE(5820),
    [sym_type_arguments] = STATE(620),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(2103),
    [anon_sym_export] = ACTIONS(2105),
    [anon_sym_type] = ACTIONS(2105),
    [anon_sym_namespace] = ACTIONS(2107),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_typeof] = ACTIONS(1202),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(2105),
    [anon_sym_BANG] = ACTIONS(1186),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(1188),
    [anon_sym_yield] = ACTIONS(1190),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(2109),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(2111),
    [anon_sym_using] = ACTIONS(1196),
    [anon_sym_PLUS] = ACTIONS(1202),
    [anon_sym_DASH] = ACTIONS(1202),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(1186),
    [anon_sym_void] = ACTIONS(1202),
    [anon_sym_delete] = ACTIONS(1202),
    [anon_sym_PLUS_PLUS] = ACTIONS(1204),
    [anon_sym_DASH_DASH] = ACTIONS(1204),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(1206),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1528),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(2105),
    [anon_sym_readonly] = ACTIONS(2105),
    [anon_sym_get] = ACTIONS(2105),
    [anon_sym_set] = ACTIONS(2105),
    [anon_sym_declare] = ACTIONS(2105),
    [anon_sym_public] = ACTIONS(2105),
    [anon_sym_private] = ACTIONS(2105),
    [anon_sym_protected] = ACTIONS(2105),
    [anon_sym_override] = ACTIONS(2105),
    [anon_sym_module] = ACTIONS(2105),
    [anon_sym_any] = ACTIONS(2105),
    [anon_sym_number] = ACTIONS(2105),
    [anon_sym_boolean] = ACTIONS(2105),
    [anon_sym_string] = ACTIONS(2105),
    [anon_sym_symbol] = ACTIONS(2105),
    [anon_sym_object] = ACTIONS(2105),
    [sym_html_comment] = ACTIONS(5),
  },
  [335] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1398),
    [sym_expression] = STATE(1864),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5544),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5544),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5558),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1398),
    [sym_subscript_expression] = STATE(1398),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(2980),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5544),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_sequence_expression] = STATE(5575),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1398),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(638),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1482),
    [anon_sym_export] = ACTIONS(1158),
    [anon_sym_type] = ACTIONS(1158),
    [anon_sym_namespace] = ACTIONS(1160),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_typeof] = ACTIONS(756),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1158),
    [anon_sym_BANG] = ACTIONS(732),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(736),
    [anon_sym_yield] = ACTIONS(738),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1164),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1486),
    [anon_sym_using] = ACTIONS(746),
    [anon_sym_PLUS] = ACTIONS(756),
    [anon_sym_DASH] = ACTIONS(756),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(732),
    [anon_sym_void] = ACTIONS(756),
    [anon_sym_delete] = ACTIONS(756),
    [anon_sym_PLUS_PLUS] = ACTIONS(758),
    [anon_sym_DASH_DASH] = ACTIONS(758),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(764),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1488),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1158),
    [anon_sym_readonly] = ACTIONS(1158),
    [anon_sym_get] = ACTIONS(1158),
    [anon_sym_set] = ACTIONS(1158),
    [anon_sym_declare] = ACTIONS(1158),
    [anon_sym_public] = ACTIONS(1158),
    [anon_sym_private] = ACTIONS(1158),
    [anon_sym_protected] = ACTIONS(1158),
    [anon_sym_override] = ACTIONS(1158),
    [anon_sym_module] = ACTIONS(1158),
    [anon_sym_any] = ACTIONS(1158),
    [anon_sym_number] = ACTIONS(1158),
    [anon_sym_boolean] = ACTIONS(1158),
    [anon_sym_string] = ACTIONS(1158),
    [anon_sym_symbol] = ACTIONS(1158),
    [anon_sym_object] = ACTIONS(1158),
    [sym_html_comment] = ACTIONS(5),
  },
  [336] = {
    [sym_import] = STATE(3636),
    [sym_statement_block] = STATE(2198),
    [sym_parenthesized_expression] = STATE(1362),
    [sym_expression] = STATE(1815),
    [sym_primary_expression] = STATE(1810),
    [sym_yield_expression] = STATE(2358),
    [sym_object] = STATE(2222),
    [sym_object_pattern] = STATE(5492),
    [sym_array] = STATE(2222),
    [sym_array_pattern] = STATE(5492),
    [sym_class] = STATE(2222),
    [sym_function_expression] = STATE(2222),
    [sym_generator_function] = STATE(2222),
    [sym_arrow_function] = STATE(2222),
    [sym__call_signature] = STATE(5821),
    [sym_call_expression] = STATE(2222),
    [sym_new_expression] = STATE(1948),
    [sym_await_expression] = STATE(2358),
    [sym_member_expression] = STATE(1362),
    [sym_subscript_expression] = STATE(1362),
    [sym_assignment_expression] = STATE(2358),
    [sym__augmented_assignment_lhs] = STATE(3025),
    [sym_augmented_assignment_expression] = STATE(2358),
    [sym__destructuring_pattern] = STATE(5492),
    [sym_ternary_expression] = STATE(2358),
    [sym_binary_expression] = STATE(2358),
    [sym_unary_expression] = STATE(2358),
    [sym_update_expression] = STATE(2358),
    [sym_string] = STATE(2222),
    [sym_template_string] = STATE(2222),
    [sym_regex] = STATE(2222),
    [sym_meta_property] = STATE(2222),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1362),
    [sym_type_assertion] = STATE(2358),
    [sym_as_expression] = STATE(2358),
    [sym_satisfies_expression] = STATE(2358),
    [sym_instantiation_expression] = STATE(2358),
    [sym_internal_module] = STATE(2358),
    [sym_type_arguments] = STATE(428),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4408),
    [sym_identifier] = ACTIONS(1468),
    [anon_sym_export] = ACTIONS(1352),
    [anon_sym_type] = ACTIONS(1352),
    [anon_sym_namespace] = ACTIONS(1354),
    [anon_sym_LBRACE] = ACTIONS(2101),
    [anon_sym_typeof] = ACTIONS(21),
    [anon_sym_import] = ACTIONS(669),
    [anon_sym_let] = ACTIONS(1352),
    [anon_sym_BANG] = ACTIONS(33),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_await] = ACTIONS(45),
    [anon_sym_yield] = ACTIONS(63),
    [anon_sym_LBRACK] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(676),
    [anon_sym_async] = ACTIONS(1362),
    [anon_sym_function] = ACTIONS(680),
    [anon_sym_new] = ACTIONS(1472),
    [anon_sym_using] = ACTIONS(75),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_SLASH] = ACTIONS(77),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(33),
    [anon_sym_void] = ACTIONS(21),
    [anon_sym_delete] = ACTIONS(21),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_DQUOTE] = ACTIONS(83),
    [anon_sym_SQUOTE] = ACTIONS(85),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(87),
    [sym_number] = ACTIONS(89),
    [sym_private_property_identifier] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(93),
    [sym_true] = ACTIONS(93),
    [sym_false] = ACTIONS(93),
    [sym_null] = ACTIONS(93),
    [sym_undefined] = ACTIONS(95),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1352),
    [anon_sym_readonly] = ACTIONS(1352),
    [anon_sym_get] = ACTIONS(1352),
    [anon_sym_set] = ACTIONS(1352),
    [anon_sym_declare] = ACTIONS(1352),
    [anon_sym_public] = ACTIONS(1352),
    [anon_sym_private] = ACTIONS(1352),
    [anon_sym_protected] = ACTIONS(1352),
    [anon_sym_override] = ACTIONS(1352),
    [anon_sym_module] = ACTIONS(1352),
    [anon_sym_any] = ACTIONS(1352),
    [anon_sym_number] = ACTIONS(1352),
    [anon_sym_boolean] = ACTIONS(1352),
    [anon_sym_string] = ACTIONS(1352),
    [anon_sym_symbol] = ACTIONS(1352),
    [anon_sym_object] = ACTIONS(1352),
    [sym_html_comment] = ACTIONS(5),
  },
  [337] = {
    [sym_import] = STATE(3639),
    [sym_statement_block] = STATE(1658),
    [sym_parenthesized_expression] = STATE(1322),
    [sym_expression] = STATE(1740),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5698),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5698),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5508),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1322),
    [sym_subscript_expression] = STATE(1322),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3003),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5698),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1322),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(484),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1456),
    [anon_sym_export] = ACTIONS(1048),
    [anon_sym_type] = ACTIONS(1048),
    [anon_sym_namespace] = ACTIONS(1050),
    [anon_sym_LBRACE] = ACTIONS(2099),
    [anon_sym_typeof] = ACTIONS(581),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1048),
    [anon_sym_BANG] = ACTIONS(553),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(555),
    [anon_sym_yield] = ACTIONS(557),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1058),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1464),
    [anon_sym_using] = ACTIONS(567),
    [anon_sym_PLUS] = ACTIONS(581),
    [anon_sym_DASH] = ACTIONS(581),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(553),
    [anon_sym_void] = ACTIONS(581),
    [anon_sym_delete] = ACTIONS(581),
    [anon_sym_PLUS_PLUS] = ACTIONS(583),
    [anon_sym_DASH_DASH] = ACTIONS(583),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(585),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1466),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1048),
    [anon_sym_readonly] = ACTIONS(1048),
    [anon_sym_get] = ACTIONS(1048),
    [anon_sym_set] = ACTIONS(1048),
    [anon_sym_declare] = ACTIONS(1048),
    [anon_sym_public] = ACTIONS(1048),
    [anon_sym_private] = ACTIONS(1048),
    [anon_sym_protected] = ACTIONS(1048),
    [anon_sym_override] = ACTIONS(1048),
    [anon_sym_module] = ACTIONS(1048),
    [anon_sym_any] = ACTIONS(1048),
    [anon_sym_number] = ACTIONS(1048),
    [anon_sym_boolean] = ACTIONS(1048),
    [anon_sym_string] = ACTIONS(1048),
    [anon_sym_symbol] = ACTIONS(1048),
    [anon_sym_object] = ACTIONS(1048),
    [sym_html_comment] = ACTIONS(5),
  },
  [338] = {
    [sym_import] = STATE(3639),
    [sym_statement_block] = STATE(1668),
    [sym_parenthesized_expression] = STATE(1322),
    [sym_expression] = STATE(1745),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5698),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5698),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5508),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1322),
    [sym_subscript_expression] = STATE(1322),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3003),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5698),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1322),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(484),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1456),
    [anon_sym_export] = ACTIONS(1048),
    [anon_sym_type] = ACTIONS(1048),
    [anon_sym_namespace] = ACTIONS(1050),
    [anon_sym_LBRACE] = ACTIONS(2099),
    [anon_sym_typeof] = ACTIONS(581),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1048),
    [anon_sym_BANG] = ACTIONS(553),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(555),
    [anon_sym_yield] = ACTIONS(557),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1058),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1464),
    [anon_sym_using] = ACTIONS(567),
    [anon_sym_PLUS] = ACTIONS(581),
    [anon_sym_DASH] = ACTIONS(581),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(553),
    [anon_sym_void] = ACTIONS(581),
    [anon_sym_delete] = ACTIONS(581),
    [anon_sym_PLUS_PLUS] = ACTIONS(583),
    [anon_sym_DASH_DASH] = ACTIONS(583),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(585),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1466),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1048),
    [anon_sym_readonly] = ACTIONS(1048),
    [anon_sym_get] = ACTIONS(1048),
    [anon_sym_set] = ACTIONS(1048),
    [anon_sym_declare] = ACTIONS(1048),
    [anon_sym_public] = ACTIONS(1048),
    [anon_sym_private] = ACTIONS(1048),
    [anon_sym_protected] = ACTIONS(1048),
    [anon_sym_override] = ACTIONS(1048),
    [anon_sym_module] = ACTIONS(1048),
    [anon_sym_any] = ACTIONS(1048),
    [anon_sym_number] = ACTIONS(1048),
    [anon_sym_boolean] = ACTIONS(1048),
    [anon_sym_string] = ACTIONS(1048),
    [anon_sym_symbol] = ACTIONS(1048),
    [anon_sym_object] = ACTIONS(1048),
    [sym_html_comment] = ACTIONS(5),
  },
  [339] = {
    [sym_import] = STATE(3639),
    [sym_statement_block] = STATE(1672),
    [sym_parenthesized_expression] = STATE(1322),
    [sym_expression] = STATE(1758),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5698),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5698),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5508),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1322),
    [sym_subscript_expression] = STATE(1322),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3003),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5698),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1322),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(484),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1456),
    [anon_sym_export] = ACTIONS(1048),
    [anon_sym_type] = ACTIONS(1048),
    [anon_sym_namespace] = ACTIONS(1050),
    [anon_sym_LBRACE] = ACTIONS(2099),
    [anon_sym_typeof] = ACTIONS(581),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1048),
    [anon_sym_BANG] = ACTIONS(553),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(555),
    [anon_sym_yield] = ACTIONS(557),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1058),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1464),
    [anon_sym_using] = ACTIONS(567),
    [anon_sym_PLUS] = ACTIONS(581),
    [anon_sym_DASH] = ACTIONS(581),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(553),
    [anon_sym_void] = ACTIONS(581),
    [anon_sym_delete] = ACTIONS(581),
    [anon_sym_PLUS_PLUS] = ACTIONS(583),
    [anon_sym_DASH_DASH] = ACTIONS(583),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(585),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1466),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1048),
    [anon_sym_readonly] = ACTIONS(1048),
    [anon_sym_get] = ACTIONS(1048),
    [anon_sym_set] = ACTIONS(1048),
    [anon_sym_declare] = ACTIONS(1048),
    [anon_sym_public] = ACTIONS(1048),
    [anon_sym_private] = ACTIONS(1048),
    [anon_sym_protected] = ACTIONS(1048),
    [anon_sym_override] = ACTIONS(1048),
    [anon_sym_module] = ACTIONS(1048),
    [anon_sym_any] = ACTIONS(1048),
    [anon_sym_number] = ACTIONS(1048),
    [anon_sym_boolean] = ACTIONS(1048),
    [anon_sym_string] = ACTIONS(1048),
    [anon_sym_symbol] = ACTIONS(1048),
    [anon_sym_object] = ACTIONS(1048),
    [sym_html_comment] = ACTIONS(5),
  },
  [340] = {
    [sym_import] = STATE(3639),
    [sym_statement_block] = STATE(1680),
    [sym_parenthesized_expression] = STATE(1322),
    [sym_expression] = STATE(1760),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5698),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5698),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5508),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1322),
    [sym_subscript_expression] = STATE(1322),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3003),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5698),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1322),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(484),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1456),
    [anon_sym_export] = ACTIONS(1048),
    [anon_sym_type] = ACTIONS(1048),
    [anon_sym_namespace] = ACTIONS(1050),
    [anon_sym_LBRACE] = ACTIONS(2099),
    [anon_sym_typeof] = ACTIONS(581),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1048),
    [anon_sym_BANG] = ACTIONS(553),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(555),
    [anon_sym_yield] = ACTIONS(557),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1058),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1464),
    [anon_sym_using] = ACTIONS(567),
    [anon_sym_PLUS] = ACTIONS(581),
    [anon_sym_DASH] = ACTIONS(581),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(553),
    [anon_sym_void] = ACTIONS(581),
    [anon_sym_delete] = ACTIONS(581),
    [anon_sym_PLUS_PLUS] = ACTIONS(583),
    [anon_sym_DASH_DASH] = ACTIONS(583),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(585),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1466),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1048),
    [anon_sym_readonly] = ACTIONS(1048),
    [anon_sym_get] = ACTIONS(1048),
    [anon_sym_set] = ACTIONS(1048),
    [anon_sym_declare] = ACTIONS(1048),
    [anon_sym_public] = ACTIONS(1048),
    [anon_sym_private] = ACTIONS(1048),
    [anon_sym_protected] = ACTIONS(1048),
    [anon_sym_override] = ACTIONS(1048),
    [anon_sym_module] = ACTIONS(1048),
    [anon_sym_any] = ACTIONS(1048),
    [anon_sym_number] = ACTIONS(1048),
    [anon_sym_boolean] = ACTIONS(1048),
    [anon_sym_string] = ACTIONS(1048),
    [anon_sym_symbol] = ACTIONS(1048),
    [anon_sym_object] = ACTIONS(1048),
    [sym_html_comment] = ACTIONS(5),
  },
  [341] = {
    [sym_import] = STATE(3639),
    [sym_statement_block] = STATE(1682),
    [sym_parenthesized_expression] = STATE(1322),
    [sym_expression] = STATE(1761),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5698),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5698),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5508),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1322),
    [sym_subscript_expression] = STATE(1322),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3003),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5698),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1322),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(484),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1456),
    [anon_sym_export] = ACTIONS(1048),
    [anon_sym_type] = ACTIONS(1048),
    [anon_sym_namespace] = ACTIONS(1050),
    [anon_sym_LBRACE] = ACTIONS(2099),
    [anon_sym_typeof] = ACTIONS(581),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1048),
    [anon_sym_BANG] = ACTIONS(553),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(555),
    [anon_sym_yield] = ACTIONS(557),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1058),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1464),
    [anon_sym_using] = ACTIONS(567),
    [anon_sym_PLUS] = ACTIONS(581),
    [anon_sym_DASH] = ACTIONS(581),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(553),
    [anon_sym_void] = ACTIONS(581),
    [anon_sym_delete] = ACTIONS(581),
    [anon_sym_PLUS_PLUS] = ACTIONS(583),
    [anon_sym_DASH_DASH] = ACTIONS(583),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(585),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1466),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1048),
    [anon_sym_readonly] = ACTIONS(1048),
    [anon_sym_get] = ACTIONS(1048),
    [anon_sym_set] = ACTIONS(1048),
    [anon_sym_declare] = ACTIONS(1048),
    [anon_sym_public] = ACTIONS(1048),
    [anon_sym_private] = ACTIONS(1048),
    [anon_sym_protected] = ACTIONS(1048),
    [anon_sym_override] = ACTIONS(1048),
    [anon_sym_module] = ACTIONS(1048),
    [anon_sym_any] = ACTIONS(1048),
    [anon_sym_number] = ACTIONS(1048),
    [anon_sym_boolean] = ACTIONS(1048),
    [anon_sym_string] = ACTIONS(1048),
    [anon_sym_symbol] = ACTIONS(1048),
    [anon_sym_object] = ACTIONS(1048),
    [sym_html_comment] = ACTIONS(5),
  },
  [342] = {
    [sym_import] = STATE(3636),
    [sym_statement_block] = STATE(2201),
    [sym_parenthesized_expression] = STATE(1362),
    [sym_expression] = STATE(1817),
    [sym_primary_expression] = STATE(1810),
    [sym_yield_expression] = STATE(2358),
    [sym_object] = STATE(2222),
    [sym_object_pattern] = STATE(5492),
    [sym_array] = STATE(2222),
    [sym_array_pattern] = STATE(5492),
    [sym_class] = STATE(2222),
    [sym_function_expression] = STATE(2222),
    [sym_generator_function] = STATE(2222),
    [sym_arrow_function] = STATE(2222),
    [sym__call_signature] = STATE(5821),
    [sym_call_expression] = STATE(2222),
    [sym_new_expression] = STATE(1948),
    [sym_await_expression] = STATE(2358),
    [sym_member_expression] = STATE(1362),
    [sym_subscript_expression] = STATE(1362),
    [sym_assignment_expression] = STATE(2358),
    [sym__augmented_assignment_lhs] = STATE(3025),
    [sym_augmented_assignment_expression] = STATE(2358),
    [sym__destructuring_pattern] = STATE(5492),
    [sym_ternary_expression] = STATE(2358),
    [sym_binary_expression] = STATE(2358),
    [sym_unary_expression] = STATE(2358),
    [sym_update_expression] = STATE(2358),
    [sym_string] = STATE(2222),
    [sym_template_string] = STATE(2222),
    [sym_regex] = STATE(2222),
    [sym_meta_property] = STATE(2222),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1362),
    [sym_type_assertion] = STATE(2358),
    [sym_as_expression] = STATE(2358),
    [sym_satisfies_expression] = STATE(2358),
    [sym_instantiation_expression] = STATE(2358),
    [sym_internal_module] = STATE(2358),
    [sym_type_arguments] = STATE(428),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4408),
    [sym_identifier] = ACTIONS(1468),
    [anon_sym_export] = ACTIONS(1352),
    [anon_sym_type] = ACTIONS(1352),
    [anon_sym_namespace] = ACTIONS(1354),
    [anon_sym_LBRACE] = ACTIONS(2101),
    [anon_sym_typeof] = ACTIONS(21),
    [anon_sym_import] = ACTIONS(669),
    [anon_sym_let] = ACTIONS(1352),
    [anon_sym_BANG] = ACTIONS(33),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_await] = ACTIONS(45),
    [anon_sym_yield] = ACTIONS(63),
    [anon_sym_LBRACK] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(676),
    [anon_sym_async] = ACTIONS(1362),
    [anon_sym_function] = ACTIONS(680),
    [anon_sym_new] = ACTIONS(1472),
    [anon_sym_using] = ACTIONS(75),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_SLASH] = ACTIONS(77),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(33),
    [anon_sym_void] = ACTIONS(21),
    [anon_sym_delete] = ACTIONS(21),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_DQUOTE] = ACTIONS(83),
    [anon_sym_SQUOTE] = ACTIONS(85),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(87),
    [sym_number] = ACTIONS(89),
    [sym_private_property_identifier] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(93),
    [sym_true] = ACTIONS(93),
    [sym_false] = ACTIONS(93),
    [sym_null] = ACTIONS(93),
    [sym_undefined] = ACTIONS(95),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1352),
    [anon_sym_readonly] = ACTIONS(1352),
    [anon_sym_get] = ACTIONS(1352),
    [anon_sym_set] = ACTIONS(1352),
    [anon_sym_declare] = ACTIONS(1352),
    [anon_sym_public] = ACTIONS(1352),
    [anon_sym_private] = ACTIONS(1352),
    [anon_sym_protected] = ACTIONS(1352),
    [anon_sym_override] = ACTIONS(1352),
    [anon_sym_module] = ACTIONS(1352),
    [anon_sym_any] = ACTIONS(1352),
    [anon_sym_number] = ACTIONS(1352),
    [anon_sym_boolean] = ACTIONS(1352),
    [anon_sym_string] = ACTIONS(1352),
    [anon_sym_symbol] = ACTIONS(1352),
    [anon_sym_object] = ACTIONS(1352),
    [sym_html_comment] = ACTIONS(5),
  },
  [343] = {
    [sym_import] = STATE(3636),
    [sym_statement_block] = STATE(2204),
    [sym_parenthesized_expression] = STATE(1362),
    [sym_expression] = STATE(1818),
    [sym_primary_expression] = STATE(1810),
    [sym_yield_expression] = STATE(2358),
    [sym_object] = STATE(2222),
    [sym_object_pattern] = STATE(5492),
    [sym_array] = STATE(2222),
    [sym_array_pattern] = STATE(5492),
    [sym_class] = STATE(2222),
    [sym_function_expression] = STATE(2222),
    [sym_generator_function] = STATE(2222),
    [sym_arrow_function] = STATE(2222),
    [sym__call_signature] = STATE(5821),
    [sym_call_expression] = STATE(2222),
    [sym_new_expression] = STATE(1948),
    [sym_await_expression] = STATE(2358),
    [sym_member_expression] = STATE(1362),
    [sym_subscript_expression] = STATE(1362),
    [sym_assignment_expression] = STATE(2358),
    [sym__augmented_assignment_lhs] = STATE(3025),
    [sym_augmented_assignment_expression] = STATE(2358),
    [sym__destructuring_pattern] = STATE(5492),
    [sym_ternary_expression] = STATE(2358),
    [sym_binary_expression] = STATE(2358),
    [sym_unary_expression] = STATE(2358),
    [sym_update_expression] = STATE(2358),
    [sym_string] = STATE(2222),
    [sym_template_string] = STATE(2222),
    [sym_regex] = STATE(2222),
    [sym_meta_property] = STATE(2222),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1362),
    [sym_type_assertion] = STATE(2358),
    [sym_as_expression] = STATE(2358),
    [sym_satisfies_expression] = STATE(2358),
    [sym_instantiation_expression] = STATE(2358),
    [sym_internal_module] = STATE(2358),
    [sym_type_arguments] = STATE(428),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4408),
    [sym_identifier] = ACTIONS(1468),
    [anon_sym_export] = ACTIONS(1352),
    [anon_sym_type] = ACTIONS(1352),
    [anon_sym_namespace] = ACTIONS(1354),
    [anon_sym_LBRACE] = ACTIONS(2101),
    [anon_sym_typeof] = ACTIONS(21),
    [anon_sym_import] = ACTIONS(669),
    [anon_sym_let] = ACTIONS(1352),
    [anon_sym_BANG] = ACTIONS(33),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_await] = ACTIONS(45),
    [anon_sym_yield] = ACTIONS(63),
    [anon_sym_LBRACK] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(676),
    [anon_sym_async] = ACTIONS(1362),
    [anon_sym_function] = ACTIONS(680),
    [anon_sym_new] = ACTIONS(1472),
    [anon_sym_using] = ACTIONS(75),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_SLASH] = ACTIONS(77),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(33),
    [anon_sym_void] = ACTIONS(21),
    [anon_sym_delete] = ACTIONS(21),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_DQUOTE] = ACTIONS(83),
    [anon_sym_SQUOTE] = ACTIONS(85),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(87),
    [sym_number] = ACTIONS(89),
    [sym_private_property_identifier] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(93),
    [sym_true] = ACTIONS(93),
    [sym_false] = ACTIONS(93),
    [sym_null] = ACTIONS(93),
    [sym_undefined] = ACTIONS(95),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1352),
    [anon_sym_readonly] = ACTIONS(1352),
    [anon_sym_get] = ACTIONS(1352),
    [anon_sym_set] = ACTIONS(1352),
    [anon_sym_declare] = ACTIONS(1352),
    [anon_sym_public] = ACTIONS(1352),
    [anon_sym_private] = ACTIONS(1352),
    [anon_sym_protected] = ACTIONS(1352),
    [anon_sym_override] = ACTIONS(1352),
    [anon_sym_module] = ACTIONS(1352),
    [anon_sym_any] = ACTIONS(1352),
    [anon_sym_number] = ACTIONS(1352),
    [anon_sym_boolean] = ACTIONS(1352),
    [anon_sym_string] = ACTIONS(1352),
    [anon_sym_symbol] = ACTIONS(1352),
    [anon_sym_object] = ACTIONS(1352),
    [sym_html_comment] = ACTIONS(5),
  },
  [344] = {
    [sym_import] = STATE(3639),
    [sym_statement_block] = STATE(1680),
    [sym_parenthesized_expression] = STATE(1398),
    [sym_expression] = STATE(1927),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5544),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5544),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5558),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1398),
    [sym_subscript_expression] = STATE(1398),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(2980),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5544),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1398),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(638),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1482),
    [anon_sym_export] = ACTIONS(1158),
    [anon_sym_type] = ACTIONS(1158),
    [anon_sym_namespace] = ACTIONS(1160),
    [anon_sym_LBRACE] = ACTIONS(2099),
    [anon_sym_typeof] = ACTIONS(756),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1158),
    [anon_sym_BANG] = ACTIONS(732),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(736),
    [anon_sym_yield] = ACTIONS(738),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1164),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1486),
    [anon_sym_using] = ACTIONS(746),
    [anon_sym_PLUS] = ACTIONS(756),
    [anon_sym_DASH] = ACTIONS(756),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(732),
    [anon_sym_void] = ACTIONS(756),
    [anon_sym_delete] = ACTIONS(756),
    [anon_sym_PLUS_PLUS] = ACTIONS(758),
    [anon_sym_DASH_DASH] = ACTIONS(758),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(764),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1488),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1158),
    [anon_sym_readonly] = ACTIONS(1158),
    [anon_sym_get] = ACTIONS(1158),
    [anon_sym_set] = ACTIONS(1158),
    [anon_sym_declare] = ACTIONS(1158),
    [anon_sym_public] = ACTIONS(1158),
    [anon_sym_private] = ACTIONS(1158),
    [anon_sym_protected] = ACTIONS(1158),
    [anon_sym_override] = ACTIONS(1158),
    [anon_sym_module] = ACTIONS(1158),
    [anon_sym_any] = ACTIONS(1158),
    [anon_sym_number] = ACTIONS(1158),
    [anon_sym_boolean] = ACTIONS(1158),
    [anon_sym_string] = ACTIONS(1158),
    [anon_sym_symbol] = ACTIONS(1158),
    [anon_sym_object] = ACTIONS(1158),
    [sym_html_comment] = ACTIONS(5),
  },
  [345] = {
    [sym_import] = STATE(3636),
    [sym_parenthesized_expression] = STATE(1362),
    [sym_expression] = STATE(1893),
    [sym_primary_expression] = STATE(1810),
    [sym_yield_expression] = STATE(2358),
    [sym_object] = STATE(2222),
    [sym_object_pattern] = STATE(5492),
    [sym_array] = STATE(2222),
    [sym_array_pattern] = STATE(5492),
    [sym_class] = STATE(2222),
    [sym_function_expression] = STATE(2222),
    [sym_generator_function] = STATE(2222),
    [sym_arrow_function] = STATE(2222),
    [sym__call_signature] = STATE(5821),
    [sym_call_expression] = STATE(2222),
    [sym_new_expression] = STATE(1948),
    [sym_await_expression] = STATE(2358),
    [sym_member_expression] = STATE(1362),
    [sym_subscript_expression] = STATE(1362),
    [sym_assignment_expression] = STATE(2358),
    [sym__augmented_assignment_lhs] = STATE(3025),
    [sym_augmented_assignment_expression] = STATE(2358),
    [sym__destructuring_pattern] = STATE(5492),
    [sym_ternary_expression] = STATE(2358),
    [sym_binary_expression] = STATE(2358),
    [sym_unary_expression] = STATE(2358),
    [sym_update_expression] = STATE(2358),
    [sym_sequence_expression] = STATE(5284),
    [sym_string] = STATE(2222),
    [sym_template_string] = STATE(2222),
    [sym_regex] = STATE(2222),
    [sym_meta_property] = STATE(2222),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1362),
    [sym_type_assertion] = STATE(2358),
    [sym_as_expression] = STATE(2358),
    [sym_satisfies_expression] = STATE(2358),
    [sym_instantiation_expression] = STATE(2358),
    [sym_internal_module] = STATE(2358),
    [sym_type_arguments] = STATE(428),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4408),
    [sym_identifier] = ACTIONS(1468),
    [anon_sym_export] = ACTIONS(1352),
    [anon_sym_type] = ACTIONS(1352),
    [anon_sym_namespace] = ACTIONS(1354),
    [anon_sym_LBRACE] = ACTIONS(665),
    [anon_sym_typeof] = ACTIONS(21),
    [anon_sym_import] = ACTIONS(669),
    [anon_sym_let] = ACTIONS(1352),
    [anon_sym_BANG] = ACTIONS(33),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_await] = ACTIONS(45),
    [anon_sym_yield] = ACTIONS(63),
    [anon_sym_LBRACK] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(676),
    [anon_sym_async] = ACTIONS(1362),
    [anon_sym_function] = ACTIONS(680),
    [anon_sym_new] = ACTIONS(1472),
    [anon_sym_using] = ACTIONS(75),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_SLASH] = ACTIONS(77),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(33),
    [anon_sym_void] = ACTIONS(21),
    [anon_sym_delete] = ACTIONS(21),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_DQUOTE] = ACTIONS(83),
    [anon_sym_SQUOTE] = ACTIONS(85),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(87),
    [sym_number] = ACTIONS(89),
    [sym_private_property_identifier] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(93),
    [sym_true] = ACTIONS(93),
    [sym_false] = ACTIONS(93),
    [sym_null] = ACTIONS(93),
    [sym_undefined] = ACTIONS(95),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1352),
    [anon_sym_readonly] = ACTIONS(1352),
    [anon_sym_get] = ACTIONS(1352),
    [anon_sym_set] = ACTIONS(1352),
    [anon_sym_declare] = ACTIONS(1352),
    [anon_sym_public] = ACTIONS(1352),
    [anon_sym_private] = ACTIONS(1352),
    [anon_sym_protected] = ACTIONS(1352),
    [anon_sym_override] = ACTIONS(1352),
    [anon_sym_module] = ACTIONS(1352),
    [anon_sym_any] = ACTIONS(1352),
    [anon_sym_number] = ACTIONS(1352),
    [anon_sym_boolean] = ACTIONS(1352),
    [anon_sym_string] = ACTIONS(1352),
    [anon_sym_symbol] = ACTIONS(1352),
    [anon_sym_object] = ACTIONS(1352),
    [sym_html_comment] = ACTIONS(5),
  },
  [346] = {
    [sym_import] = STATE(3636),
    [sym_statement_block] = STATE(2280),
    [sym_parenthesized_expression] = STATE(1364),
    [sym_expression] = STATE(1836),
    [sym_primary_expression] = STATE(1810),
    [sym_yield_expression] = STATE(2358),
    [sym_object] = STATE(2222),
    [sym_object_pattern] = STATE(5773),
    [sym_array] = STATE(2222),
    [sym_array_pattern] = STATE(5773),
    [sym_class] = STATE(2222),
    [sym_function_expression] = STATE(2222),
    [sym_generator_function] = STATE(2222),
    [sym_arrow_function] = STATE(2222),
    [sym__call_signature] = STATE(5771),
    [sym_call_expression] = STATE(2222),
    [sym_new_expression] = STATE(1948),
    [sym_await_expression] = STATE(2358),
    [sym_member_expression] = STATE(1364),
    [sym_subscript_expression] = STATE(1364),
    [sym_assignment_expression] = STATE(2358),
    [sym__augmented_assignment_lhs] = STATE(3020),
    [sym_augmented_assignment_expression] = STATE(2358),
    [sym__destructuring_pattern] = STATE(5773),
    [sym_ternary_expression] = STATE(2358),
    [sym_binary_expression] = STATE(2358),
    [sym_unary_expression] = STATE(2358),
    [sym_update_expression] = STATE(2358),
    [sym_string] = STATE(2222),
    [sym_template_string] = STATE(2222),
    [sym_regex] = STATE(2222),
    [sym_meta_property] = STATE(2222),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1364),
    [sym_type_assertion] = STATE(2358),
    [sym_as_expression] = STATE(2358),
    [sym_satisfies_expression] = STATE(2358),
    [sym_instantiation_expression] = STATE(2358),
    [sym_internal_module] = STATE(2358),
    [sym_type_arguments] = STATE(513),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4408),
    [sym_identifier] = ACTIONS(1474),
    [anon_sym_export] = ACTIONS(1386),
    [anon_sym_type] = ACTIONS(1386),
    [anon_sym_namespace] = ACTIONS(1388),
    [anon_sym_LBRACE] = ACTIONS(2101),
    [anon_sym_typeof] = ACTIONS(1408),
    [anon_sym_import] = ACTIONS(669),
    [anon_sym_let] = ACTIONS(1386),
    [anon_sym_BANG] = ACTIONS(1392),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_await] = ACTIONS(1394),
    [anon_sym_yield] = ACTIONS(1396),
    [anon_sym_LBRACK] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(676),
    [anon_sym_async] = ACTIONS(1398),
    [anon_sym_function] = ACTIONS(680),
    [anon_sym_new] = ACTIONS(1478),
    [anon_sym_using] = ACTIONS(1402),
    [anon_sym_PLUS] = ACTIONS(1408),
    [anon_sym_DASH] = ACTIONS(1408),
    [anon_sym_SLASH] = ACTIONS(876),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(1392),
    [anon_sym_void] = ACTIONS(1408),
    [anon_sym_delete] = ACTIONS(1408),
    [anon_sym_PLUS_PLUS] = ACTIONS(1410),
    [anon_sym_DASH_DASH] = ACTIONS(1410),
    [anon_sym_DQUOTE] = ACTIONS(83),
    [anon_sym_SQUOTE] = ACTIONS(85),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(87),
    [sym_number] = ACTIONS(89),
    [sym_private_property_identifier] = ACTIONS(1412),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(93),
    [sym_true] = ACTIONS(93),
    [sym_false] = ACTIONS(93),
    [sym_null] = ACTIONS(93),
    [sym_undefined] = ACTIONS(1480),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1386),
    [anon_sym_readonly] = ACTIONS(1386),
    [anon_sym_get] = ACTIONS(1386),
    [anon_sym_set] = ACTIONS(1386),
    [anon_sym_declare] = ACTIONS(1386),
    [anon_sym_public] = ACTIONS(1386),
    [anon_sym_private] = ACTIONS(1386),
    [anon_sym_protected] = ACTIONS(1386),
    [anon_sym_override] = ACTIONS(1386),
    [anon_sym_module] = ACTIONS(1386),
    [anon_sym_any] = ACTIONS(1386),
    [anon_sym_number] = ACTIONS(1386),
    [anon_sym_boolean] = ACTIONS(1386),
    [anon_sym_string] = ACTIONS(1386),
    [anon_sym_symbol] = ACTIONS(1386),
    [anon_sym_object] = ACTIONS(1386),
    [sym_html_comment] = ACTIONS(5),
  },
  [347] = {
    [sym_import] = STATE(3636),
    [sym_statement_block] = STATE(2195),
    [sym_parenthesized_expression] = STATE(1364),
    [sym_expression] = STATE(1841),
    [sym_primary_expression] = STATE(1810),
    [sym_yield_expression] = STATE(2358),
    [sym_object] = STATE(2222),
    [sym_object_pattern] = STATE(5773),
    [sym_array] = STATE(2222),
    [sym_array_pattern] = STATE(5773),
    [sym_class] = STATE(2222),
    [sym_function_expression] = STATE(2222),
    [sym_generator_function] = STATE(2222),
    [sym_arrow_function] = STATE(2222),
    [sym__call_signature] = STATE(5771),
    [sym_call_expression] = STATE(2222),
    [sym_new_expression] = STATE(1948),
    [sym_await_expression] = STATE(2358),
    [sym_member_expression] = STATE(1364),
    [sym_subscript_expression] = STATE(1364),
    [sym_assignment_expression] = STATE(2358),
    [sym__augmented_assignment_lhs] = STATE(3020),
    [sym_augmented_assignment_expression] = STATE(2358),
    [sym__destructuring_pattern] = STATE(5773),
    [sym_ternary_expression] = STATE(2358),
    [sym_binary_expression] = STATE(2358),
    [sym_unary_expression] = STATE(2358),
    [sym_update_expression] = STATE(2358),
    [sym_string] = STATE(2222),
    [sym_template_string] = STATE(2222),
    [sym_regex] = STATE(2222),
    [sym_meta_property] = STATE(2222),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1364),
    [sym_type_assertion] = STATE(2358),
    [sym_as_expression] = STATE(2358),
    [sym_satisfies_expression] = STATE(2358),
    [sym_instantiation_expression] = STATE(2358),
    [sym_internal_module] = STATE(2358),
    [sym_type_arguments] = STATE(513),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4408),
    [sym_identifier] = ACTIONS(1474),
    [anon_sym_export] = ACTIONS(1386),
    [anon_sym_type] = ACTIONS(1386),
    [anon_sym_namespace] = ACTIONS(1388),
    [anon_sym_LBRACE] = ACTIONS(2101),
    [anon_sym_typeof] = ACTIONS(1408),
    [anon_sym_import] = ACTIONS(669),
    [anon_sym_let] = ACTIONS(1386),
    [anon_sym_BANG] = ACTIONS(1392),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_await] = ACTIONS(1394),
    [anon_sym_yield] = ACTIONS(1396),
    [anon_sym_LBRACK] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(676),
    [anon_sym_async] = ACTIONS(1398),
    [anon_sym_function] = ACTIONS(680),
    [anon_sym_new] = ACTIONS(1478),
    [anon_sym_using] = ACTIONS(1402),
    [anon_sym_PLUS] = ACTIONS(1408),
    [anon_sym_DASH] = ACTIONS(1408),
    [anon_sym_SLASH] = ACTIONS(876),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(1392),
    [anon_sym_void] = ACTIONS(1408),
    [anon_sym_delete] = ACTIONS(1408),
    [anon_sym_PLUS_PLUS] = ACTIONS(1410),
    [anon_sym_DASH_DASH] = ACTIONS(1410),
    [anon_sym_DQUOTE] = ACTIONS(83),
    [anon_sym_SQUOTE] = ACTIONS(85),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(87),
    [sym_number] = ACTIONS(89),
    [sym_private_property_identifier] = ACTIONS(1412),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(93),
    [sym_true] = ACTIONS(93),
    [sym_false] = ACTIONS(93),
    [sym_null] = ACTIONS(93),
    [sym_undefined] = ACTIONS(1480),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1386),
    [anon_sym_readonly] = ACTIONS(1386),
    [anon_sym_get] = ACTIONS(1386),
    [anon_sym_set] = ACTIONS(1386),
    [anon_sym_declare] = ACTIONS(1386),
    [anon_sym_public] = ACTIONS(1386),
    [anon_sym_private] = ACTIONS(1386),
    [anon_sym_protected] = ACTIONS(1386),
    [anon_sym_override] = ACTIONS(1386),
    [anon_sym_module] = ACTIONS(1386),
    [anon_sym_any] = ACTIONS(1386),
    [anon_sym_number] = ACTIONS(1386),
    [anon_sym_boolean] = ACTIONS(1386),
    [anon_sym_string] = ACTIONS(1386),
    [anon_sym_symbol] = ACTIONS(1386),
    [anon_sym_object] = ACTIONS(1386),
    [sym_html_comment] = ACTIONS(5),
  },
  [348] = {
    [sym_import] = STATE(3636),
    [sym_statement_block] = STATE(2262),
    [sym_parenthesized_expression] = STATE(1364),
    [sym_expression] = STATE(1854),
    [sym_primary_expression] = STATE(1810),
    [sym_yield_expression] = STATE(2358),
    [sym_object] = STATE(2222),
    [sym_object_pattern] = STATE(5773),
    [sym_array] = STATE(2222),
    [sym_array_pattern] = STATE(5773),
    [sym_class] = STATE(2222),
    [sym_function_expression] = STATE(2222),
    [sym_generator_function] = STATE(2222),
    [sym_arrow_function] = STATE(2222),
    [sym__call_signature] = STATE(5771),
    [sym_call_expression] = STATE(2222),
    [sym_new_expression] = STATE(1948),
    [sym_await_expression] = STATE(2358),
    [sym_member_expression] = STATE(1364),
    [sym_subscript_expression] = STATE(1364),
    [sym_assignment_expression] = STATE(2358),
    [sym__augmented_assignment_lhs] = STATE(3020),
    [sym_augmented_assignment_expression] = STATE(2358),
    [sym__destructuring_pattern] = STATE(5773),
    [sym_ternary_expression] = STATE(2358),
    [sym_binary_expression] = STATE(2358),
    [sym_unary_expression] = STATE(2358),
    [sym_update_expression] = STATE(2358),
    [sym_string] = STATE(2222),
    [sym_template_string] = STATE(2222),
    [sym_regex] = STATE(2222),
    [sym_meta_property] = STATE(2222),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1364),
    [sym_type_assertion] = STATE(2358),
    [sym_as_expression] = STATE(2358),
    [sym_satisfies_expression] = STATE(2358),
    [sym_instantiation_expression] = STATE(2358),
    [sym_internal_module] = STATE(2358),
    [sym_type_arguments] = STATE(513),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4408),
    [sym_identifier] = ACTIONS(1474),
    [anon_sym_export] = ACTIONS(1386),
    [anon_sym_type] = ACTIONS(1386),
    [anon_sym_namespace] = ACTIONS(1388),
    [anon_sym_LBRACE] = ACTIONS(2101),
    [anon_sym_typeof] = ACTIONS(1408),
    [anon_sym_import] = ACTIONS(669),
    [anon_sym_let] = ACTIONS(1386),
    [anon_sym_BANG] = ACTIONS(1392),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_await] = ACTIONS(1394),
    [anon_sym_yield] = ACTIONS(1396),
    [anon_sym_LBRACK] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(676),
    [anon_sym_async] = ACTIONS(1398),
    [anon_sym_function] = ACTIONS(680),
    [anon_sym_new] = ACTIONS(1478),
    [anon_sym_using] = ACTIONS(1402),
    [anon_sym_PLUS] = ACTIONS(1408),
    [anon_sym_DASH] = ACTIONS(1408),
    [anon_sym_SLASH] = ACTIONS(876),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(1392),
    [anon_sym_void] = ACTIONS(1408),
    [anon_sym_delete] = ACTIONS(1408),
    [anon_sym_PLUS_PLUS] = ACTIONS(1410),
    [anon_sym_DASH_DASH] = ACTIONS(1410),
    [anon_sym_DQUOTE] = ACTIONS(83),
    [anon_sym_SQUOTE] = ACTIONS(85),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(87),
    [sym_number] = ACTIONS(89),
    [sym_private_property_identifier] = ACTIONS(1412),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(93),
    [sym_true] = ACTIONS(93),
    [sym_false] = ACTIONS(93),
    [sym_null] = ACTIONS(93),
    [sym_undefined] = ACTIONS(1480),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1386),
    [anon_sym_readonly] = ACTIONS(1386),
    [anon_sym_get] = ACTIONS(1386),
    [anon_sym_set] = ACTIONS(1386),
    [anon_sym_declare] = ACTIONS(1386),
    [anon_sym_public] = ACTIONS(1386),
    [anon_sym_private] = ACTIONS(1386),
    [anon_sym_protected] = ACTIONS(1386),
    [anon_sym_override] = ACTIONS(1386),
    [anon_sym_module] = ACTIONS(1386),
    [anon_sym_any] = ACTIONS(1386),
    [anon_sym_number] = ACTIONS(1386),
    [anon_sym_boolean] = ACTIONS(1386),
    [anon_sym_string] = ACTIONS(1386),
    [anon_sym_symbol] = ACTIONS(1386),
    [anon_sym_object] = ACTIONS(1386),
    [sym_html_comment] = ACTIONS(5),
  },
  [349] = {
    [sym_import] = STATE(3636),
    [sym_statement_block] = STATE(2198),
    [sym_parenthesized_expression] = STATE(1364),
    [sym_expression] = STATE(1856),
    [sym_primary_expression] = STATE(1810),
    [sym_yield_expression] = STATE(2358),
    [sym_object] = STATE(2222),
    [sym_object_pattern] = STATE(5773),
    [sym_array] = STATE(2222),
    [sym_array_pattern] = STATE(5773),
    [sym_class] = STATE(2222),
    [sym_function_expression] = STATE(2222),
    [sym_generator_function] = STATE(2222),
    [sym_arrow_function] = STATE(2222),
    [sym__call_signature] = STATE(5771),
    [sym_call_expression] = STATE(2222),
    [sym_new_expression] = STATE(1948),
    [sym_await_expression] = STATE(2358),
    [sym_member_expression] = STATE(1364),
    [sym_subscript_expression] = STATE(1364),
    [sym_assignment_expression] = STATE(2358),
    [sym__augmented_assignment_lhs] = STATE(3020),
    [sym_augmented_assignment_expression] = STATE(2358),
    [sym__destructuring_pattern] = STATE(5773),
    [sym_ternary_expression] = STATE(2358),
    [sym_binary_expression] = STATE(2358),
    [sym_unary_expression] = STATE(2358),
    [sym_update_expression] = STATE(2358),
    [sym_string] = STATE(2222),
    [sym_template_string] = STATE(2222),
    [sym_regex] = STATE(2222),
    [sym_meta_property] = STATE(2222),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1364),
    [sym_type_assertion] = STATE(2358),
    [sym_as_expression] = STATE(2358),
    [sym_satisfies_expression] = STATE(2358),
    [sym_instantiation_expression] = STATE(2358),
    [sym_internal_module] = STATE(2358),
    [sym_type_arguments] = STATE(513),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4408),
    [sym_identifier] = ACTIONS(1474),
    [anon_sym_export] = ACTIONS(1386),
    [anon_sym_type] = ACTIONS(1386),
    [anon_sym_namespace] = ACTIONS(1388),
    [anon_sym_LBRACE] = ACTIONS(2101),
    [anon_sym_typeof] = ACTIONS(1408),
    [anon_sym_import] = ACTIONS(669),
    [anon_sym_let] = ACTIONS(1386),
    [anon_sym_BANG] = ACTIONS(1392),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_await] = ACTIONS(1394),
    [anon_sym_yield] = ACTIONS(1396),
    [anon_sym_LBRACK] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(676),
    [anon_sym_async] = ACTIONS(1398),
    [anon_sym_function] = ACTIONS(680),
    [anon_sym_new] = ACTIONS(1478),
    [anon_sym_using] = ACTIONS(1402),
    [anon_sym_PLUS] = ACTIONS(1408),
    [anon_sym_DASH] = ACTIONS(1408),
    [anon_sym_SLASH] = ACTIONS(876),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(1392),
    [anon_sym_void] = ACTIONS(1408),
    [anon_sym_delete] = ACTIONS(1408),
    [anon_sym_PLUS_PLUS] = ACTIONS(1410),
    [anon_sym_DASH_DASH] = ACTIONS(1410),
    [anon_sym_DQUOTE] = ACTIONS(83),
    [anon_sym_SQUOTE] = ACTIONS(85),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(87),
    [sym_number] = ACTIONS(89),
    [sym_private_property_identifier] = ACTIONS(1412),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(93),
    [sym_true] = ACTIONS(93),
    [sym_false] = ACTIONS(93),
    [sym_null] = ACTIONS(93),
    [sym_undefined] = ACTIONS(1480),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1386),
    [anon_sym_readonly] = ACTIONS(1386),
    [anon_sym_get] = ACTIONS(1386),
    [anon_sym_set] = ACTIONS(1386),
    [anon_sym_declare] = ACTIONS(1386),
    [anon_sym_public] = ACTIONS(1386),
    [anon_sym_private] = ACTIONS(1386),
    [anon_sym_protected] = ACTIONS(1386),
    [anon_sym_override] = ACTIONS(1386),
    [anon_sym_module] = ACTIONS(1386),
    [anon_sym_any] = ACTIONS(1386),
    [anon_sym_number] = ACTIONS(1386),
    [anon_sym_boolean] = ACTIONS(1386),
    [anon_sym_string] = ACTIONS(1386),
    [anon_sym_symbol] = ACTIONS(1386),
    [anon_sym_object] = ACTIONS(1386),
    [sym_html_comment] = ACTIONS(5),
  },
  [350] = {
    [sym_import] = STATE(3636),
    [sym_statement_block] = STATE(2201),
    [sym_parenthesized_expression] = STATE(1364),
    [sym_expression] = STATE(1857),
    [sym_primary_expression] = STATE(1810),
    [sym_yield_expression] = STATE(2358),
    [sym_object] = STATE(2222),
    [sym_object_pattern] = STATE(5773),
    [sym_array] = STATE(2222),
    [sym_array_pattern] = STATE(5773),
    [sym_class] = STATE(2222),
    [sym_function_expression] = STATE(2222),
    [sym_generator_function] = STATE(2222),
    [sym_arrow_function] = STATE(2222),
    [sym__call_signature] = STATE(5771),
    [sym_call_expression] = STATE(2222),
    [sym_new_expression] = STATE(1948),
    [sym_await_expression] = STATE(2358),
    [sym_member_expression] = STATE(1364),
    [sym_subscript_expression] = STATE(1364),
    [sym_assignment_expression] = STATE(2358),
    [sym__augmented_assignment_lhs] = STATE(3020),
    [sym_augmented_assignment_expression] = STATE(2358),
    [sym__destructuring_pattern] = STATE(5773),
    [sym_ternary_expression] = STATE(2358),
    [sym_binary_expression] = STATE(2358),
    [sym_unary_expression] = STATE(2358),
    [sym_update_expression] = STATE(2358),
    [sym_string] = STATE(2222),
    [sym_template_string] = STATE(2222),
    [sym_regex] = STATE(2222),
    [sym_meta_property] = STATE(2222),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1364),
    [sym_type_assertion] = STATE(2358),
    [sym_as_expression] = STATE(2358),
    [sym_satisfies_expression] = STATE(2358),
    [sym_instantiation_expression] = STATE(2358),
    [sym_internal_module] = STATE(2358),
    [sym_type_arguments] = STATE(513),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4408),
    [sym_identifier] = ACTIONS(1474),
    [anon_sym_export] = ACTIONS(1386),
    [anon_sym_type] = ACTIONS(1386),
    [anon_sym_namespace] = ACTIONS(1388),
    [anon_sym_LBRACE] = ACTIONS(2101),
    [anon_sym_typeof] = ACTIONS(1408),
    [anon_sym_import] = ACTIONS(669),
    [anon_sym_let] = ACTIONS(1386),
    [anon_sym_BANG] = ACTIONS(1392),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_await] = ACTIONS(1394),
    [anon_sym_yield] = ACTIONS(1396),
    [anon_sym_LBRACK] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(676),
    [anon_sym_async] = ACTIONS(1398),
    [anon_sym_function] = ACTIONS(680),
    [anon_sym_new] = ACTIONS(1478),
    [anon_sym_using] = ACTIONS(1402),
    [anon_sym_PLUS] = ACTIONS(1408),
    [anon_sym_DASH] = ACTIONS(1408),
    [anon_sym_SLASH] = ACTIONS(876),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(1392),
    [anon_sym_void] = ACTIONS(1408),
    [anon_sym_delete] = ACTIONS(1408),
    [anon_sym_PLUS_PLUS] = ACTIONS(1410),
    [anon_sym_DASH_DASH] = ACTIONS(1410),
    [anon_sym_DQUOTE] = ACTIONS(83),
    [anon_sym_SQUOTE] = ACTIONS(85),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(87),
    [sym_number] = ACTIONS(89),
    [sym_private_property_identifier] = ACTIONS(1412),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(93),
    [sym_true] = ACTIONS(93),
    [sym_false] = ACTIONS(93),
    [sym_null] = ACTIONS(93),
    [sym_undefined] = ACTIONS(1480),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1386),
    [anon_sym_readonly] = ACTIONS(1386),
    [anon_sym_get] = ACTIONS(1386),
    [anon_sym_set] = ACTIONS(1386),
    [anon_sym_declare] = ACTIONS(1386),
    [anon_sym_public] = ACTIONS(1386),
    [anon_sym_private] = ACTIONS(1386),
    [anon_sym_protected] = ACTIONS(1386),
    [anon_sym_override] = ACTIONS(1386),
    [anon_sym_module] = ACTIONS(1386),
    [anon_sym_any] = ACTIONS(1386),
    [anon_sym_number] = ACTIONS(1386),
    [anon_sym_boolean] = ACTIONS(1386),
    [anon_sym_string] = ACTIONS(1386),
    [anon_sym_symbol] = ACTIONS(1386),
    [anon_sym_object] = ACTIONS(1386),
    [sym_html_comment] = ACTIONS(5),
  },
  [351] = {
    [sym_import] = STATE(3636),
    [sym_statement_block] = STATE(2204),
    [sym_parenthesized_expression] = STATE(1364),
    [sym_expression] = STATE(1858),
    [sym_primary_expression] = STATE(1810),
    [sym_yield_expression] = STATE(2358),
    [sym_object] = STATE(2222),
    [sym_object_pattern] = STATE(5773),
    [sym_array] = STATE(2222),
    [sym_array_pattern] = STATE(5773),
    [sym_class] = STATE(2222),
    [sym_function_expression] = STATE(2222),
    [sym_generator_function] = STATE(2222),
    [sym_arrow_function] = STATE(2222),
    [sym__call_signature] = STATE(5771),
    [sym_call_expression] = STATE(2222),
    [sym_new_expression] = STATE(1948),
    [sym_await_expression] = STATE(2358),
    [sym_member_expression] = STATE(1364),
    [sym_subscript_expression] = STATE(1364),
    [sym_assignment_expression] = STATE(2358),
    [sym__augmented_assignment_lhs] = STATE(3020),
    [sym_augmented_assignment_expression] = STATE(2358),
    [sym__destructuring_pattern] = STATE(5773),
    [sym_ternary_expression] = STATE(2358),
    [sym_binary_expression] = STATE(2358),
    [sym_unary_expression] = STATE(2358),
    [sym_update_expression] = STATE(2358),
    [sym_string] = STATE(2222),
    [sym_template_string] = STATE(2222),
    [sym_regex] = STATE(2222),
    [sym_meta_property] = STATE(2222),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1364),
    [sym_type_assertion] = STATE(2358),
    [sym_as_expression] = STATE(2358),
    [sym_satisfies_expression] = STATE(2358),
    [sym_instantiation_expression] = STATE(2358),
    [sym_internal_module] = STATE(2358),
    [sym_type_arguments] = STATE(513),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4408),
    [sym_identifier] = ACTIONS(1474),
    [anon_sym_export] = ACTIONS(1386),
    [anon_sym_type] = ACTIONS(1386),
    [anon_sym_namespace] = ACTIONS(1388),
    [anon_sym_LBRACE] = ACTIONS(2101),
    [anon_sym_typeof] = ACTIONS(1408),
    [anon_sym_import] = ACTIONS(669),
    [anon_sym_let] = ACTIONS(1386),
    [anon_sym_BANG] = ACTIONS(1392),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_await] = ACTIONS(1394),
    [anon_sym_yield] = ACTIONS(1396),
    [anon_sym_LBRACK] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(676),
    [anon_sym_async] = ACTIONS(1398),
    [anon_sym_function] = ACTIONS(680),
    [anon_sym_new] = ACTIONS(1478),
    [anon_sym_using] = ACTIONS(1402),
    [anon_sym_PLUS] = ACTIONS(1408),
    [anon_sym_DASH] = ACTIONS(1408),
    [anon_sym_SLASH] = ACTIONS(876),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(1392),
    [anon_sym_void] = ACTIONS(1408),
    [anon_sym_delete] = ACTIONS(1408),
    [anon_sym_PLUS_PLUS] = ACTIONS(1410),
    [anon_sym_DASH_DASH] = ACTIONS(1410),
    [anon_sym_DQUOTE] = ACTIONS(83),
    [anon_sym_SQUOTE] = ACTIONS(85),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(87),
    [sym_number] = ACTIONS(89),
    [sym_private_property_identifier] = ACTIONS(1412),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(93),
    [sym_true] = ACTIONS(93),
    [sym_false] = ACTIONS(93),
    [sym_null] = ACTIONS(93),
    [sym_undefined] = ACTIONS(1480),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1386),
    [anon_sym_readonly] = ACTIONS(1386),
    [anon_sym_get] = ACTIONS(1386),
    [anon_sym_set] = ACTIONS(1386),
    [anon_sym_declare] = ACTIONS(1386),
    [anon_sym_public] = ACTIONS(1386),
    [anon_sym_private] = ACTIONS(1386),
    [anon_sym_protected] = ACTIONS(1386),
    [anon_sym_override] = ACTIONS(1386),
    [anon_sym_module] = ACTIONS(1386),
    [anon_sym_any] = ACTIONS(1386),
    [anon_sym_number] = ACTIONS(1386),
    [anon_sym_boolean] = ACTIONS(1386),
    [anon_sym_string] = ACTIONS(1386),
    [anon_sym_symbol] = ACTIONS(1386),
    [anon_sym_object] = ACTIONS(1386),
    [sym_html_comment] = ACTIONS(5),
  },
  [352] = {
    [sym_import] = STATE(3639),
    [sym_statement_block] = STATE(1682),
    [sym_parenthesized_expression] = STATE(1398),
    [sym_expression] = STATE(1930),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5544),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5544),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5558),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1398),
    [sym_subscript_expression] = STATE(1398),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(2980),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5544),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1398),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(638),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1482),
    [anon_sym_export] = ACTIONS(1158),
    [anon_sym_type] = ACTIONS(1158),
    [anon_sym_namespace] = ACTIONS(1160),
    [anon_sym_LBRACE] = ACTIONS(2099),
    [anon_sym_typeof] = ACTIONS(756),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1158),
    [anon_sym_BANG] = ACTIONS(732),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(736),
    [anon_sym_yield] = ACTIONS(738),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1164),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1486),
    [anon_sym_using] = ACTIONS(746),
    [anon_sym_PLUS] = ACTIONS(756),
    [anon_sym_DASH] = ACTIONS(756),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(732),
    [anon_sym_void] = ACTIONS(756),
    [anon_sym_delete] = ACTIONS(756),
    [anon_sym_PLUS_PLUS] = ACTIONS(758),
    [anon_sym_DASH_DASH] = ACTIONS(758),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(764),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1488),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1158),
    [anon_sym_readonly] = ACTIONS(1158),
    [anon_sym_get] = ACTIONS(1158),
    [anon_sym_set] = ACTIONS(1158),
    [anon_sym_declare] = ACTIONS(1158),
    [anon_sym_public] = ACTIONS(1158),
    [anon_sym_private] = ACTIONS(1158),
    [anon_sym_protected] = ACTIONS(1158),
    [anon_sym_override] = ACTIONS(1158),
    [anon_sym_module] = ACTIONS(1158),
    [anon_sym_any] = ACTIONS(1158),
    [anon_sym_number] = ACTIONS(1158),
    [anon_sym_boolean] = ACTIONS(1158),
    [anon_sym_string] = ACTIONS(1158),
    [anon_sym_symbol] = ACTIONS(1158),
    [anon_sym_object] = ACTIONS(1158),
    [sym_html_comment] = ACTIONS(5),
  },
  [353] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1457),
    [sym_expression] = STATE(2591),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5823),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5823),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5477),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1457),
    [sym_subscript_expression] = STATE(1457),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(2986),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5823),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1457),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_mapped_type_clause] = STATE(5605),
    [sym_type_arguments] = STATE(620),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(2113),
    [anon_sym_export] = ACTIONS(2115),
    [anon_sym_type] = ACTIONS(2115),
    [anon_sym_namespace] = ACTIONS(2117),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_typeof] = ACTIONS(1202),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(2115),
    [anon_sym_BANG] = ACTIONS(1186),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(1188),
    [anon_sym_yield] = ACTIONS(1190),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(2119),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(2121),
    [anon_sym_using] = ACTIONS(1196),
    [anon_sym_PLUS] = ACTIONS(1202),
    [anon_sym_DASH] = ACTIONS(1202),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(1186),
    [anon_sym_void] = ACTIONS(1202),
    [anon_sym_delete] = ACTIONS(1202),
    [anon_sym_PLUS_PLUS] = ACTIONS(1204),
    [anon_sym_DASH_DASH] = ACTIONS(1204),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(1206),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1528),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(2115),
    [anon_sym_readonly] = ACTIONS(2115),
    [anon_sym_get] = ACTIONS(2115),
    [anon_sym_set] = ACTIONS(2115),
    [anon_sym_declare] = ACTIONS(2115),
    [anon_sym_public] = ACTIONS(2115),
    [anon_sym_private] = ACTIONS(2115),
    [anon_sym_protected] = ACTIONS(2115),
    [anon_sym_override] = ACTIONS(2115),
    [anon_sym_module] = ACTIONS(2115),
    [anon_sym_any] = ACTIONS(2115),
    [anon_sym_number] = ACTIONS(2115),
    [anon_sym_boolean] = ACTIONS(2115),
    [anon_sym_string] = ACTIONS(2115),
    [anon_sym_symbol] = ACTIONS(2115),
    [anon_sym_object] = ACTIONS(2115),
    [sym_html_comment] = ACTIONS(5),
  },
  [354] = {
    [sym_import] = STATE(3639),
    [sym_statement_block] = STATE(1658),
    [sym_parenthesized_expression] = STATE(1213),
    [sym_expression] = STATE(2528),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5522),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5522),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5800),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1213),
    [sym_subscript_expression] = STATE(1213),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3013),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5522),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1213),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(539),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(802),
    [anon_sym_export] = ACTIONS(804),
    [anon_sym_type] = ACTIONS(804),
    [anon_sym_namespace] = ACTIONS(806),
    [anon_sym_LBRACE] = ACTIONS(2123),
    [anon_sym_typeof] = ACTIONS(179),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(804),
    [anon_sym_BANG] = ACTIONS(175),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(140),
    [anon_sym_yield] = ACTIONS(142),
    [anon_sym_LBRACK] = ACTIONS(812),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(816),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(818),
    [anon_sym_using] = ACTIONS(158),
    [anon_sym_PLUS] = ACTIONS(179),
    [anon_sym_DASH] = ACTIONS(179),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(175),
    [anon_sym_void] = ACTIONS(179),
    [anon_sym_delete] = ACTIONS(179),
    [anon_sym_PLUS_PLUS] = ACTIONS(686),
    [anon_sym_DASH_DASH] = ACTIONS(686),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(192),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(822),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(804),
    [anon_sym_readonly] = ACTIONS(804),
    [anon_sym_get] = ACTIONS(804),
    [anon_sym_set] = ACTIONS(804),
    [anon_sym_declare] = ACTIONS(804),
    [anon_sym_public] = ACTIONS(804),
    [anon_sym_private] = ACTIONS(804),
    [anon_sym_protected] = ACTIONS(804),
    [anon_sym_override] = ACTIONS(804),
    [anon_sym_module] = ACTIONS(804),
    [anon_sym_any] = ACTIONS(804),
    [anon_sym_number] = ACTIONS(804),
    [anon_sym_boolean] = ACTIONS(804),
    [anon_sym_string] = ACTIONS(804),
    [anon_sym_symbol] = ACTIONS(804),
    [anon_sym_object] = ACTIONS(804),
    [sym_html_comment] = ACTIONS(5),
  },
  [355] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1387),
    [sym_expression] = STATE(2183),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5803),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5803),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5585),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1387),
    [sym_subscript_expression] = STATE(1387),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3009),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5803),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1387),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym__extends_clause_single] = STATE(4894),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(566),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1490),
    [anon_sym_export] = ACTIONS(1422),
    [anon_sym_type] = ACTIONS(1422),
    [anon_sym_namespace] = ACTIONS(1424),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_typeof] = ACTIONS(1444),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1422),
    [anon_sym_BANG] = ACTIONS(1428),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(1430),
    [anon_sym_yield] = ACTIONS(1432),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1434),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1494),
    [anon_sym_using] = ACTIONS(1438),
    [anon_sym_PLUS] = ACTIONS(1444),
    [anon_sym_DASH] = ACTIONS(1444),
    [anon_sym_SLASH] = ACTIONS(942),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(1428),
    [anon_sym_void] = ACTIONS(1444),
    [anon_sym_delete] = ACTIONS(1444),
    [anon_sym_PLUS_PLUS] = ACTIONS(1446),
    [anon_sym_DASH_DASH] = ACTIONS(1446),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(1448),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1496),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1422),
    [anon_sym_readonly] = ACTIONS(1422),
    [anon_sym_get] = ACTIONS(1422),
    [anon_sym_set] = ACTIONS(1422),
    [anon_sym_declare] = ACTIONS(1422),
    [anon_sym_public] = ACTIONS(1422),
    [anon_sym_private] = ACTIONS(1422),
    [anon_sym_protected] = ACTIONS(1422),
    [anon_sym_override] = ACTIONS(1422),
    [anon_sym_module] = ACTIONS(1422),
    [anon_sym_any] = ACTIONS(1422),
    [anon_sym_number] = ACTIONS(1422),
    [anon_sym_boolean] = ACTIONS(1422),
    [anon_sym_string] = ACTIONS(1422),
    [anon_sym_symbol] = ACTIONS(1422),
    [anon_sym_object] = ACTIONS(1422),
    [sym_html_comment] = ACTIONS(5),
  },
  [356] = {
    [sym_import] = STATE(3639),
    [sym_statement_block] = STATE(1668),
    [sym_parenthesized_expression] = STATE(1213),
    [sym_expression] = STATE(2531),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5522),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5522),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5800),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1213),
    [sym_subscript_expression] = STATE(1213),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3013),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5522),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1213),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(539),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(802),
    [anon_sym_export] = ACTIONS(804),
    [anon_sym_type] = ACTIONS(804),
    [anon_sym_namespace] = ACTIONS(806),
    [anon_sym_LBRACE] = ACTIONS(2123),
    [anon_sym_typeof] = ACTIONS(179),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(804),
    [anon_sym_BANG] = ACTIONS(175),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(140),
    [anon_sym_yield] = ACTIONS(142),
    [anon_sym_LBRACK] = ACTIONS(812),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(816),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(818),
    [anon_sym_using] = ACTIONS(158),
    [anon_sym_PLUS] = ACTIONS(179),
    [anon_sym_DASH] = ACTIONS(179),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(175),
    [anon_sym_void] = ACTIONS(179),
    [anon_sym_delete] = ACTIONS(179),
    [anon_sym_PLUS_PLUS] = ACTIONS(686),
    [anon_sym_DASH_DASH] = ACTIONS(686),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(192),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(822),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(804),
    [anon_sym_readonly] = ACTIONS(804),
    [anon_sym_get] = ACTIONS(804),
    [anon_sym_set] = ACTIONS(804),
    [anon_sym_declare] = ACTIONS(804),
    [anon_sym_public] = ACTIONS(804),
    [anon_sym_private] = ACTIONS(804),
    [anon_sym_protected] = ACTIONS(804),
    [anon_sym_override] = ACTIONS(804),
    [anon_sym_module] = ACTIONS(804),
    [anon_sym_any] = ACTIONS(804),
    [anon_sym_number] = ACTIONS(804),
    [anon_sym_boolean] = ACTIONS(804),
    [anon_sym_string] = ACTIONS(804),
    [anon_sym_symbol] = ACTIONS(804),
    [anon_sym_object] = ACTIONS(804),
    [sym_html_comment] = ACTIONS(5),
  },
  [357] = {
    [sym_import] = STATE(3639),
    [sym_statement_block] = STATE(1672),
    [sym_parenthesized_expression] = STATE(1213),
    [sym_expression] = STATE(2544),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5522),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5522),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5800),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1213),
    [sym_subscript_expression] = STATE(1213),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3013),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5522),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1213),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(539),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(802),
    [anon_sym_export] = ACTIONS(804),
    [anon_sym_type] = ACTIONS(804),
    [anon_sym_namespace] = ACTIONS(806),
    [anon_sym_LBRACE] = ACTIONS(2123),
    [anon_sym_typeof] = ACTIONS(179),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(804),
    [anon_sym_BANG] = ACTIONS(175),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(140),
    [anon_sym_yield] = ACTIONS(142),
    [anon_sym_LBRACK] = ACTIONS(812),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(816),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(818),
    [anon_sym_using] = ACTIONS(158),
    [anon_sym_PLUS] = ACTIONS(179),
    [anon_sym_DASH] = ACTIONS(179),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(175),
    [anon_sym_void] = ACTIONS(179),
    [anon_sym_delete] = ACTIONS(179),
    [anon_sym_PLUS_PLUS] = ACTIONS(686),
    [anon_sym_DASH_DASH] = ACTIONS(686),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(192),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(822),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(804),
    [anon_sym_readonly] = ACTIONS(804),
    [anon_sym_get] = ACTIONS(804),
    [anon_sym_set] = ACTIONS(804),
    [anon_sym_declare] = ACTIONS(804),
    [anon_sym_public] = ACTIONS(804),
    [anon_sym_private] = ACTIONS(804),
    [anon_sym_protected] = ACTIONS(804),
    [anon_sym_override] = ACTIONS(804),
    [anon_sym_module] = ACTIONS(804),
    [anon_sym_any] = ACTIONS(804),
    [anon_sym_number] = ACTIONS(804),
    [anon_sym_boolean] = ACTIONS(804),
    [anon_sym_string] = ACTIONS(804),
    [anon_sym_symbol] = ACTIONS(804),
    [anon_sym_object] = ACTIONS(804),
    [sym_html_comment] = ACTIONS(5),
  },
  [358] = {
    [sym_import] = STATE(3639),
    [sym_statement_block] = STATE(1680),
    [sym_parenthesized_expression] = STATE(1213),
    [sym_expression] = STATE(2546),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5522),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5522),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5800),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1213),
    [sym_subscript_expression] = STATE(1213),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3013),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5522),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1213),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(539),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(802),
    [anon_sym_export] = ACTIONS(804),
    [anon_sym_type] = ACTIONS(804),
    [anon_sym_namespace] = ACTIONS(806),
    [anon_sym_LBRACE] = ACTIONS(2123),
    [anon_sym_typeof] = ACTIONS(179),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(804),
    [anon_sym_BANG] = ACTIONS(175),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(140),
    [anon_sym_yield] = ACTIONS(142),
    [anon_sym_LBRACK] = ACTIONS(812),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(816),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(818),
    [anon_sym_using] = ACTIONS(158),
    [anon_sym_PLUS] = ACTIONS(179),
    [anon_sym_DASH] = ACTIONS(179),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(175),
    [anon_sym_void] = ACTIONS(179),
    [anon_sym_delete] = ACTIONS(179),
    [anon_sym_PLUS_PLUS] = ACTIONS(686),
    [anon_sym_DASH_DASH] = ACTIONS(686),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(192),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(822),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(804),
    [anon_sym_readonly] = ACTIONS(804),
    [anon_sym_get] = ACTIONS(804),
    [anon_sym_set] = ACTIONS(804),
    [anon_sym_declare] = ACTIONS(804),
    [anon_sym_public] = ACTIONS(804),
    [anon_sym_private] = ACTIONS(804),
    [anon_sym_protected] = ACTIONS(804),
    [anon_sym_override] = ACTIONS(804),
    [anon_sym_module] = ACTIONS(804),
    [anon_sym_any] = ACTIONS(804),
    [anon_sym_number] = ACTIONS(804),
    [anon_sym_boolean] = ACTIONS(804),
    [anon_sym_string] = ACTIONS(804),
    [anon_sym_symbol] = ACTIONS(804),
    [anon_sym_object] = ACTIONS(804),
    [sym_html_comment] = ACTIONS(5),
  },
  [359] = {
    [sym_import] = STATE(3636),
    [sym_statement_block] = STATE(2195),
    [sym_parenthesized_expression] = STATE(1362),
    [sym_expression] = STATE(1790),
    [sym_primary_expression] = STATE(1810),
    [sym_yield_expression] = STATE(2358),
    [sym_object] = STATE(2222),
    [sym_object_pattern] = STATE(5492),
    [sym_array] = STATE(2222),
    [sym_array_pattern] = STATE(5492),
    [sym_class] = STATE(2222),
    [sym_function_expression] = STATE(2222),
    [sym_generator_function] = STATE(2222),
    [sym_arrow_function] = STATE(2222),
    [sym__call_signature] = STATE(5821),
    [sym_call_expression] = STATE(2222),
    [sym_new_expression] = STATE(1948),
    [sym_await_expression] = STATE(2358),
    [sym_member_expression] = STATE(1362),
    [sym_subscript_expression] = STATE(1362),
    [sym_assignment_expression] = STATE(2358),
    [sym__augmented_assignment_lhs] = STATE(3025),
    [sym_augmented_assignment_expression] = STATE(2358),
    [sym__destructuring_pattern] = STATE(5492),
    [sym_ternary_expression] = STATE(2358),
    [sym_binary_expression] = STATE(2358),
    [sym_unary_expression] = STATE(2358),
    [sym_update_expression] = STATE(2358),
    [sym_string] = STATE(2222),
    [sym_template_string] = STATE(2222),
    [sym_regex] = STATE(2222),
    [sym_meta_property] = STATE(2222),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1362),
    [sym_type_assertion] = STATE(2358),
    [sym_as_expression] = STATE(2358),
    [sym_satisfies_expression] = STATE(2358),
    [sym_instantiation_expression] = STATE(2358),
    [sym_internal_module] = STATE(2358),
    [sym_type_arguments] = STATE(428),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4408),
    [sym_identifier] = ACTIONS(1468),
    [anon_sym_export] = ACTIONS(1352),
    [anon_sym_type] = ACTIONS(1352),
    [anon_sym_namespace] = ACTIONS(1354),
    [anon_sym_LBRACE] = ACTIONS(2101),
    [anon_sym_typeof] = ACTIONS(21),
    [anon_sym_import] = ACTIONS(669),
    [anon_sym_let] = ACTIONS(1352),
    [anon_sym_BANG] = ACTIONS(33),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_await] = ACTIONS(45),
    [anon_sym_yield] = ACTIONS(63),
    [anon_sym_LBRACK] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(676),
    [anon_sym_async] = ACTIONS(1362),
    [anon_sym_function] = ACTIONS(680),
    [anon_sym_new] = ACTIONS(1472),
    [anon_sym_using] = ACTIONS(75),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_SLASH] = ACTIONS(77),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(33),
    [anon_sym_void] = ACTIONS(21),
    [anon_sym_delete] = ACTIONS(21),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_DQUOTE] = ACTIONS(83),
    [anon_sym_SQUOTE] = ACTIONS(85),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(87),
    [sym_number] = ACTIONS(89),
    [sym_private_property_identifier] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(93),
    [sym_true] = ACTIONS(93),
    [sym_false] = ACTIONS(93),
    [sym_null] = ACTIONS(93),
    [sym_undefined] = ACTIONS(95),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1352),
    [anon_sym_readonly] = ACTIONS(1352),
    [anon_sym_get] = ACTIONS(1352),
    [anon_sym_set] = ACTIONS(1352),
    [anon_sym_declare] = ACTIONS(1352),
    [anon_sym_public] = ACTIONS(1352),
    [anon_sym_private] = ACTIONS(1352),
    [anon_sym_protected] = ACTIONS(1352),
    [anon_sym_override] = ACTIONS(1352),
    [anon_sym_module] = ACTIONS(1352),
    [anon_sym_any] = ACTIONS(1352),
    [anon_sym_number] = ACTIONS(1352),
    [anon_sym_boolean] = ACTIONS(1352),
    [anon_sym_string] = ACTIONS(1352),
    [anon_sym_symbol] = ACTIONS(1352),
    [anon_sym_object] = ACTIONS(1352),
    [sym_html_comment] = ACTIONS(5),
  },
  [360] = {
    [sym_import] = STATE(3639),
    [sym_statement_block] = STATE(1683),
    [sym_parenthesized_expression] = STATE(1213),
    [sym_expression] = STATE(2548),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5522),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5522),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5800),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1213),
    [sym_subscript_expression] = STATE(1213),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3013),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5522),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1213),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(539),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(802),
    [anon_sym_export] = ACTIONS(804),
    [anon_sym_type] = ACTIONS(804),
    [anon_sym_namespace] = ACTIONS(806),
    [anon_sym_LBRACE] = ACTIONS(2123),
    [anon_sym_typeof] = ACTIONS(179),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(804),
    [anon_sym_BANG] = ACTIONS(175),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(140),
    [anon_sym_yield] = ACTIONS(142),
    [anon_sym_LBRACK] = ACTIONS(812),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(816),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(818),
    [anon_sym_using] = ACTIONS(158),
    [anon_sym_PLUS] = ACTIONS(179),
    [anon_sym_DASH] = ACTIONS(179),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(175),
    [anon_sym_void] = ACTIONS(179),
    [anon_sym_delete] = ACTIONS(179),
    [anon_sym_PLUS_PLUS] = ACTIONS(686),
    [anon_sym_DASH_DASH] = ACTIONS(686),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(192),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(822),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(804),
    [anon_sym_readonly] = ACTIONS(804),
    [anon_sym_get] = ACTIONS(804),
    [anon_sym_set] = ACTIONS(804),
    [anon_sym_declare] = ACTIONS(804),
    [anon_sym_public] = ACTIONS(804),
    [anon_sym_private] = ACTIONS(804),
    [anon_sym_protected] = ACTIONS(804),
    [anon_sym_override] = ACTIONS(804),
    [anon_sym_module] = ACTIONS(804),
    [anon_sym_any] = ACTIONS(804),
    [anon_sym_number] = ACTIONS(804),
    [anon_sym_boolean] = ACTIONS(804),
    [anon_sym_string] = ACTIONS(804),
    [anon_sym_symbol] = ACTIONS(804),
    [anon_sym_object] = ACTIONS(804),
    [sym_html_comment] = ACTIONS(5),
  },
  [361] = {
    [sym_import] = STATE(3636),
    [sym_statement_block] = STATE(2280),
    [sym_parenthesized_expression] = STATE(1362),
    [sym_expression] = STATE(1866),
    [sym_primary_expression] = STATE(1810),
    [sym_yield_expression] = STATE(2358),
    [sym_object] = STATE(2222),
    [sym_object_pattern] = STATE(5492),
    [sym_array] = STATE(2222),
    [sym_array_pattern] = STATE(5492),
    [sym_class] = STATE(2222),
    [sym_function_expression] = STATE(2222),
    [sym_generator_function] = STATE(2222),
    [sym_arrow_function] = STATE(2222),
    [sym__call_signature] = STATE(5821),
    [sym_call_expression] = STATE(2222),
    [sym_new_expression] = STATE(1948),
    [sym_await_expression] = STATE(2358),
    [sym_member_expression] = STATE(1362),
    [sym_subscript_expression] = STATE(1362),
    [sym_assignment_expression] = STATE(2358),
    [sym__augmented_assignment_lhs] = STATE(3025),
    [sym_augmented_assignment_expression] = STATE(2358),
    [sym__destructuring_pattern] = STATE(5492),
    [sym_ternary_expression] = STATE(2358),
    [sym_binary_expression] = STATE(2358),
    [sym_unary_expression] = STATE(2358),
    [sym_update_expression] = STATE(2358),
    [sym_string] = STATE(2222),
    [sym_template_string] = STATE(2222),
    [sym_regex] = STATE(2222),
    [sym_meta_property] = STATE(2222),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1362),
    [sym_type_assertion] = STATE(2358),
    [sym_as_expression] = STATE(2358),
    [sym_satisfies_expression] = STATE(2358),
    [sym_instantiation_expression] = STATE(2358),
    [sym_internal_module] = STATE(2358),
    [sym_type_arguments] = STATE(428),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4408),
    [sym_identifier] = ACTIONS(1468),
    [anon_sym_export] = ACTIONS(1352),
    [anon_sym_type] = ACTIONS(1352),
    [anon_sym_namespace] = ACTIONS(1354),
    [anon_sym_LBRACE] = ACTIONS(2101),
    [anon_sym_typeof] = ACTIONS(21),
    [anon_sym_import] = ACTIONS(669),
    [anon_sym_let] = ACTIONS(1352),
    [anon_sym_BANG] = ACTIONS(33),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_await] = ACTIONS(45),
    [anon_sym_yield] = ACTIONS(63),
    [anon_sym_LBRACK] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(676),
    [anon_sym_async] = ACTIONS(1362),
    [anon_sym_function] = ACTIONS(680),
    [anon_sym_new] = ACTIONS(1472),
    [anon_sym_using] = ACTIONS(75),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_SLASH] = ACTIONS(77),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(33),
    [anon_sym_void] = ACTIONS(21),
    [anon_sym_delete] = ACTIONS(21),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_DQUOTE] = ACTIONS(83),
    [anon_sym_SQUOTE] = ACTIONS(85),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(87),
    [sym_number] = ACTIONS(89),
    [sym_private_property_identifier] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(93),
    [sym_true] = ACTIONS(93),
    [sym_false] = ACTIONS(93),
    [sym_null] = ACTIONS(93),
    [sym_undefined] = ACTIONS(95),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1352),
    [anon_sym_readonly] = ACTIONS(1352),
    [anon_sym_get] = ACTIONS(1352),
    [anon_sym_set] = ACTIONS(1352),
    [anon_sym_declare] = ACTIONS(1352),
    [anon_sym_public] = ACTIONS(1352),
    [anon_sym_private] = ACTIONS(1352),
    [anon_sym_protected] = ACTIONS(1352),
    [anon_sym_override] = ACTIONS(1352),
    [anon_sym_module] = ACTIONS(1352),
    [anon_sym_any] = ACTIONS(1352),
    [anon_sym_number] = ACTIONS(1352),
    [anon_sym_boolean] = ACTIONS(1352),
    [anon_sym_string] = ACTIONS(1352),
    [anon_sym_symbol] = ACTIONS(1352),
    [anon_sym_object] = ACTIONS(1352),
    [sym_html_comment] = ACTIONS(5),
  },
  [362] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1322),
    [sym_expression] = STATE(2250),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5698),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5698),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5508),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1322),
    [sym_subscript_expression] = STATE(1322),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3003),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5698),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_sequence_expression] = STATE(5837),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1322),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(484),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1456),
    [anon_sym_export] = ACTIONS(1048),
    [anon_sym_type] = ACTIONS(1048),
    [anon_sym_namespace] = ACTIONS(1050),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_typeof] = ACTIONS(581),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1048),
    [anon_sym_BANG] = ACTIONS(553),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(555),
    [anon_sym_yield] = ACTIONS(557),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1058),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1464),
    [anon_sym_using] = ACTIONS(567),
    [anon_sym_PLUS] = ACTIONS(581),
    [anon_sym_DASH] = ACTIONS(581),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(553),
    [anon_sym_void] = ACTIONS(581),
    [anon_sym_delete] = ACTIONS(581),
    [anon_sym_PLUS_PLUS] = ACTIONS(583),
    [anon_sym_DASH_DASH] = ACTIONS(583),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(585),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1466),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1048),
    [anon_sym_readonly] = ACTIONS(1048),
    [anon_sym_get] = ACTIONS(1048),
    [anon_sym_set] = ACTIONS(1048),
    [anon_sym_declare] = ACTIONS(1048),
    [anon_sym_public] = ACTIONS(1048),
    [anon_sym_private] = ACTIONS(1048),
    [anon_sym_protected] = ACTIONS(1048),
    [anon_sym_override] = ACTIONS(1048),
    [anon_sym_module] = ACTIONS(1048),
    [anon_sym_any] = ACTIONS(1048),
    [anon_sym_number] = ACTIONS(1048),
    [anon_sym_boolean] = ACTIONS(1048),
    [anon_sym_string] = ACTIONS(1048),
    [anon_sym_symbol] = ACTIONS(1048),
    [anon_sym_object] = ACTIONS(1048),
    [sym_html_comment] = ACTIONS(5),
  },
  [363] = {
    [sym_import] = STATE(3639),
    [sym_statement_block] = STATE(1658),
    [sym_parenthesized_expression] = STATE(1387),
    [sym_expression] = STATE(2081),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5803),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5803),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5585),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1387),
    [sym_subscript_expression] = STATE(1387),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3009),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5803),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1387),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(566),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1490),
    [anon_sym_export] = ACTIONS(1422),
    [anon_sym_type] = ACTIONS(1422),
    [anon_sym_namespace] = ACTIONS(1424),
    [anon_sym_LBRACE] = ACTIONS(2099),
    [anon_sym_typeof] = ACTIONS(1444),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1422),
    [anon_sym_BANG] = ACTIONS(1428),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(1430),
    [anon_sym_yield] = ACTIONS(1432),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1434),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1494),
    [anon_sym_using] = ACTIONS(1438),
    [anon_sym_PLUS] = ACTIONS(1444),
    [anon_sym_DASH] = ACTIONS(1444),
    [anon_sym_SLASH] = ACTIONS(942),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(1428),
    [anon_sym_void] = ACTIONS(1444),
    [anon_sym_delete] = ACTIONS(1444),
    [anon_sym_PLUS_PLUS] = ACTIONS(1446),
    [anon_sym_DASH_DASH] = ACTIONS(1446),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(1448),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1496),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1422),
    [anon_sym_readonly] = ACTIONS(1422),
    [anon_sym_get] = ACTIONS(1422),
    [anon_sym_set] = ACTIONS(1422),
    [anon_sym_declare] = ACTIONS(1422),
    [anon_sym_public] = ACTIONS(1422),
    [anon_sym_private] = ACTIONS(1422),
    [anon_sym_protected] = ACTIONS(1422),
    [anon_sym_override] = ACTIONS(1422),
    [anon_sym_module] = ACTIONS(1422),
    [anon_sym_any] = ACTIONS(1422),
    [anon_sym_number] = ACTIONS(1422),
    [anon_sym_boolean] = ACTIONS(1422),
    [anon_sym_string] = ACTIONS(1422),
    [anon_sym_symbol] = ACTIONS(1422),
    [anon_sym_object] = ACTIONS(1422),
    [sym_html_comment] = ACTIONS(5),
  },
  [364] = {
    [sym_import] = STATE(3639),
    [sym_statement_block] = STATE(1668),
    [sym_parenthesized_expression] = STATE(1387),
    [sym_expression] = STATE(2085),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5803),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5803),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5585),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1387),
    [sym_subscript_expression] = STATE(1387),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3009),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5803),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1387),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(566),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1490),
    [anon_sym_export] = ACTIONS(1422),
    [anon_sym_type] = ACTIONS(1422),
    [anon_sym_namespace] = ACTIONS(1424),
    [anon_sym_LBRACE] = ACTIONS(2099),
    [anon_sym_typeof] = ACTIONS(1444),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1422),
    [anon_sym_BANG] = ACTIONS(1428),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(1430),
    [anon_sym_yield] = ACTIONS(1432),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1434),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1494),
    [anon_sym_using] = ACTIONS(1438),
    [anon_sym_PLUS] = ACTIONS(1444),
    [anon_sym_DASH] = ACTIONS(1444),
    [anon_sym_SLASH] = ACTIONS(942),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(1428),
    [anon_sym_void] = ACTIONS(1444),
    [anon_sym_delete] = ACTIONS(1444),
    [anon_sym_PLUS_PLUS] = ACTIONS(1446),
    [anon_sym_DASH_DASH] = ACTIONS(1446),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(1448),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1496),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1422),
    [anon_sym_readonly] = ACTIONS(1422),
    [anon_sym_get] = ACTIONS(1422),
    [anon_sym_set] = ACTIONS(1422),
    [anon_sym_declare] = ACTIONS(1422),
    [anon_sym_public] = ACTIONS(1422),
    [anon_sym_private] = ACTIONS(1422),
    [anon_sym_protected] = ACTIONS(1422),
    [anon_sym_override] = ACTIONS(1422),
    [anon_sym_module] = ACTIONS(1422),
    [anon_sym_any] = ACTIONS(1422),
    [anon_sym_number] = ACTIONS(1422),
    [anon_sym_boolean] = ACTIONS(1422),
    [anon_sym_string] = ACTIONS(1422),
    [anon_sym_symbol] = ACTIONS(1422),
    [anon_sym_object] = ACTIONS(1422),
    [sym_html_comment] = ACTIONS(5),
  },
  [365] = {
    [sym_import] = STATE(3639),
    [sym_statement_block] = STATE(1672),
    [sym_parenthesized_expression] = STATE(1387),
    [sym_expression] = STATE(2098),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5803),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5803),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5585),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1387),
    [sym_subscript_expression] = STATE(1387),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3009),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5803),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1387),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(566),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1490),
    [anon_sym_export] = ACTIONS(1422),
    [anon_sym_type] = ACTIONS(1422),
    [anon_sym_namespace] = ACTIONS(1424),
    [anon_sym_LBRACE] = ACTIONS(2099),
    [anon_sym_typeof] = ACTIONS(1444),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1422),
    [anon_sym_BANG] = ACTIONS(1428),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(1430),
    [anon_sym_yield] = ACTIONS(1432),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1434),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1494),
    [anon_sym_using] = ACTIONS(1438),
    [anon_sym_PLUS] = ACTIONS(1444),
    [anon_sym_DASH] = ACTIONS(1444),
    [anon_sym_SLASH] = ACTIONS(942),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(1428),
    [anon_sym_void] = ACTIONS(1444),
    [anon_sym_delete] = ACTIONS(1444),
    [anon_sym_PLUS_PLUS] = ACTIONS(1446),
    [anon_sym_DASH_DASH] = ACTIONS(1446),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(1448),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1496),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1422),
    [anon_sym_readonly] = ACTIONS(1422),
    [anon_sym_get] = ACTIONS(1422),
    [anon_sym_set] = ACTIONS(1422),
    [anon_sym_declare] = ACTIONS(1422),
    [anon_sym_public] = ACTIONS(1422),
    [anon_sym_private] = ACTIONS(1422),
    [anon_sym_protected] = ACTIONS(1422),
    [anon_sym_override] = ACTIONS(1422),
    [anon_sym_module] = ACTIONS(1422),
    [anon_sym_any] = ACTIONS(1422),
    [anon_sym_number] = ACTIONS(1422),
    [anon_sym_boolean] = ACTIONS(1422),
    [anon_sym_string] = ACTIONS(1422),
    [anon_sym_symbol] = ACTIONS(1422),
    [anon_sym_object] = ACTIONS(1422),
    [sym_html_comment] = ACTIONS(5),
  },
  [366] = {
    [sym_import] = STATE(3639),
    [sym_statement_block] = STATE(1680),
    [sym_parenthesized_expression] = STATE(1387),
    [sym_expression] = STATE(2100),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5803),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5803),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5585),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1387),
    [sym_subscript_expression] = STATE(1387),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3009),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5803),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1387),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(566),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1490),
    [anon_sym_export] = ACTIONS(1422),
    [anon_sym_type] = ACTIONS(1422),
    [anon_sym_namespace] = ACTIONS(1424),
    [anon_sym_LBRACE] = ACTIONS(2099),
    [anon_sym_typeof] = ACTIONS(1444),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1422),
    [anon_sym_BANG] = ACTIONS(1428),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(1430),
    [anon_sym_yield] = ACTIONS(1432),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1434),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1494),
    [anon_sym_using] = ACTIONS(1438),
    [anon_sym_PLUS] = ACTIONS(1444),
    [anon_sym_DASH] = ACTIONS(1444),
    [anon_sym_SLASH] = ACTIONS(942),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(1428),
    [anon_sym_void] = ACTIONS(1444),
    [anon_sym_delete] = ACTIONS(1444),
    [anon_sym_PLUS_PLUS] = ACTIONS(1446),
    [anon_sym_DASH_DASH] = ACTIONS(1446),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(1448),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1496),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1422),
    [anon_sym_readonly] = ACTIONS(1422),
    [anon_sym_get] = ACTIONS(1422),
    [anon_sym_set] = ACTIONS(1422),
    [anon_sym_declare] = ACTIONS(1422),
    [anon_sym_public] = ACTIONS(1422),
    [anon_sym_private] = ACTIONS(1422),
    [anon_sym_protected] = ACTIONS(1422),
    [anon_sym_override] = ACTIONS(1422),
    [anon_sym_module] = ACTIONS(1422),
    [anon_sym_any] = ACTIONS(1422),
    [anon_sym_number] = ACTIONS(1422),
    [anon_sym_boolean] = ACTIONS(1422),
    [anon_sym_string] = ACTIONS(1422),
    [anon_sym_symbol] = ACTIONS(1422),
    [anon_sym_object] = ACTIONS(1422),
    [sym_html_comment] = ACTIONS(5),
  },
  [367] = {
    [sym_import] = STATE(3639),
    [sym_statement_block] = STATE(1682),
    [sym_parenthesized_expression] = STATE(1387),
    [sym_expression] = STATE(2101),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5803),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5803),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5585),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1387),
    [sym_subscript_expression] = STATE(1387),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3009),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5803),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1387),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(566),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1490),
    [anon_sym_export] = ACTIONS(1422),
    [anon_sym_type] = ACTIONS(1422),
    [anon_sym_namespace] = ACTIONS(1424),
    [anon_sym_LBRACE] = ACTIONS(2099),
    [anon_sym_typeof] = ACTIONS(1444),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1422),
    [anon_sym_BANG] = ACTIONS(1428),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(1430),
    [anon_sym_yield] = ACTIONS(1432),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1434),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1494),
    [anon_sym_using] = ACTIONS(1438),
    [anon_sym_PLUS] = ACTIONS(1444),
    [anon_sym_DASH] = ACTIONS(1444),
    [anon_sym_SLASH] = ACTIONS(942),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(1428),
    [anon_sym_void] = ACTIONS(1444),
    [anon_sym_delete] = ACTIONS(1444),
    [anon_sym_PLUS_PLUS] = ACTIONS(1446),
    [anon_sym_DASH_DASH] = ACTIONS(1446),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(1448),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1496),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1422),
    [anon_sym_readonly] = ACTIONS(1422),
    [anon_sym_get] = ACTIONS(1422),
    [anon_sym_set] = ACTIONS(1422),
    [anon_sym_declare] = ACTIONS(1422),
    [anon_sym_public] = ACTIONS(1422),
    [anon_sym_private] = ACTIONS(1422),
    [anon_sym_protected] = ACTIONS(1422),
    [anon_sym_override] = ACTIONS(1422),
    [anon_sym_module] = ACTIONS(1422),
    [anon_sym_any] = ACTIONS(1422),
    [anon_sym_number] = ACTIONS(1422),
    [anon_sym_boolean] = ACTIONS(1422),
    [anon_sym_string] = ACTIONS(1422),
    [anon_sym_symbol] = ACTIONS(1422),
    [anon_sym_object] = ACTIONS(1422),
    [sym_html_comment] = ACTIONS(5),
  },
  [368] = {
    [sym_import] = STATE(3639),
    [sym_statement_block] = STATE(1683),
    [sym_parenthesized_expression] = STATE(1387),
    [sym_expression] = STATE(2102),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5803),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5803),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5585),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1387),
    [sym_subscript_expression] = STATE(1387),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3009),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5803),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1387),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(566),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1490),
    [anon_sym_export] = ACTIONS(1422),
    [anon_sym_type] = ACTIONS(1422),
    [anon_sym_namespace] = ACTIONS(1424),
    [anon_sym_LBRACE] = ACTIONS(2099),
    [anon_sym_typeof] = ACTIONS(1444),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1422),
    [anon_sym_BANG] = ACTIONS(1428),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(1430),
    [anon_sym_yield] = ACTIONS(1432),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1434),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1494),
    [anon_sym_using] = ACTIONS(1438),
    [anon_sym_PLUS] = ACTIONS(1444),
    [anon_sym_DASH] = ACTIONS(1444),
    [anon_sym_SLASH] = ACTIONS(942),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(1428),
    [anon_sym_void] = ACTIONS(1444),
    [anon_sym_delete] = ACTIONS(1444),
    [anon_sym_PLUS_PLUS] = ACTIONS(1446),
    [anon_sym_DASH_DASH] = ACTIONS(1446),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(1448),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1496),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1422),
    [anon_sym_readonly] = ACTIONS(1422),
    [anon_sym_get] = ACTIONS(1422),
    [anon_sym_set] = ACTIONS(1422),
    [anon_sym_declare] = ACTIONS(1422),
    [anon_sym_public] = ACTIONS(1422),
    [anon_sym_private] = ACTIONS(1422),
    [anon_sym_protected] = ACTIONS(1422),
    [anon_sym_override] = ACTIONS(1422),
    [anon_sym_module] = ACTIONS(1422),
    [anon_sym_any] = ACTIONS(1422),
    [anon_sym_number] = ACTIONS(1422),
    [anon_sym_boolean] = ACTIONS(1422),
    [anon_sym_string] = ACTIONS(1422),
    [anon_sym_symbol] = ACTIONS(1422),
    [anon_sym_object] = ACTIONS(1422),
    [sym_html_comment] = ACTIONS(5),
  },
  [369] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1387),
    [sym_expression] = STATE(2183),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5803),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5803),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5585),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1387),
    [sym_subscript_expression] = STATE(1387),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3009),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5803),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1387),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym__extends_clause_single] = STATE(4462),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(566),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1490),
    [anon_sym_export] = ACTIONS(1422),
    [anon_sym_type] = ACTIONS(1422),
    [anon_sym_namespace] = ACTIONS(1424),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_typeof] = ACTIONS(1444),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1422),
    [anon_sym_BANG] = ACTIONS(1428),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(1430),
    [anon_sym_yield] = ACTIONS(1432),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1434),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1494),
    [anon_sym_using] = ACTIONS(1438),
    [anon_sym_PLUS] = ACTIONS(1444),
    [anon_sym_DASH] = ACTIONS(1444),
    [anon_sym_SLASH] = ACTIONS(942),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(1428),
    [anon_sym_void] = ACTIONS(1444),
    [anon_sym_delete] = ACTIONS(1444),
    [anon_sym_PLUS_PLUS] = ACTIONS(1446),
    [anon_sym_DASH_DASH] = ACTIONS(1446),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(1448),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1496),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1422),
    [anon_sym_readonly] = ACTIONS(1422),
    [anon_sym_get] = ACTIONS(1422),
    [anon_sym_set] = ACTIONS(1422),
    [anon_sym_declare] = ACTIONS(1422),
    [anon_sym_public] = ACTIONS(1422),
    [anon_sym_private] = ACTIONS(1422),
    [anon_sym_protected] = ACTIONS(1422),
    [anon_sym_override] = ACTIONS(1422),
    [anon_sym_module] = ACTIONS(1422),
    [anon_sym_any] = ACTIONS(1422),
    [anon_sym_number] = ACTIONS(1422),
    [anon_sym_boolean] = ACTIONS(1422),
    [anon_sym_string] = ACTIONS(1422),
    [anon_sym_symbol] = ACTIONS(1422),
    [anon_sym_object] = ACTIONS(1422),
    [sym_html_comment] = ACTIONS(5),
  },
  [370] = {
    [sym_import] = STATE(3639),
    [sym_statement_block] = STATE(1658),
    [sym_parenthesized_expression] = STATE(1456),
    [sym_expression] = STATE(2465),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5815),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5815),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5755),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1456),
    [sym_subscript_expression] = STATE(1456),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3029),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5815),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1456),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(594),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1506),
    [anon_sym_export] = ACTIONS(1234),
    [anon_sym_type] = ACTIONS(1234),
    [anon_sym_namespace] = ACTIONS(1236),
    [anon_sym_LBRACE] = ACTIONS(2099),
    [anon_sym_typeof] = ACTIONS(1256),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1234),
    [anon_sym_BANG] = ACTIONS(1240),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(1242),
    [anon_sym_yield] = ACTIONS(1244),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1246),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1510),
    [anon_sym_using] = ACTIONS(1250),
    [anon_sym_PLUS] = ACTIONS(1256),
    [anon_sym_DASH] = ACTIONS(1256),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(1240),
    [anon_sym_void] = ACTIONS(1256),
    [anon_sym_delete] = ACTIONS(1256),
    [anon_sym_PLUS_PLUS] = ACTIONS(1258),
    [anon_sym_DASH_DASH] = ACTIONS(1258),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(1260),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1512),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1234),
    [anon_sym_readonly] = ACTIONS(1234),
    [anon_sym_get] = ACTIONS(1234),
    [anon_sym_set] = ACTIONS(1234),
    [anon_sym_declare] = ACTIONS(1234),
    [anon_sym_public] = ACTIONS(1234),
    [anon_sym_private] = ACTIONS(1234),
    [anon_sym_protected] = ACTIONS(1234),
    [anon_sym_override] = ACTIONS(1234),
    [anon_sym_module] = ACTIONS(1234),
    [anon_sym_any] = ACTIONS(1234),
    [anon_sym_number] = ACTIONS(1234),
    [anon_sym_boolean] = ACTIONS(1234),
    [anon_sym_string] = ACTIONS(1234),
    [anon_sym_symbol] = ACTIONS(1234),
    [anon_sym_object] = ACTIONS(1234),
    [sym_html_comment] = ACTIONS(5),
  },
  [371] = {
    [sym_import] = STATE(3639),
    [sym_statement_block] = STATE(1668),
    [sym_parenthesized_expression] = STATE(1456),
    [sym_expression] = STATE(2474),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5815),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5815),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5755),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1456),
    [sym_subscript_expression] = STATE(1456),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3029),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5815),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1456),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(594),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1506),
    [anon_sym_export] = ACTIONS(1234),
    [anon_sym_type] = ACTIONS(1234),
    [anon_sym_namespace] = ACTIONS(1236),
    [anon_sym_LBRACE] = ACTIONS(2099),
    [anon_sym_typeof] = ACTIONS(1256),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1234),
    [anon_sym_BANG] = ACTIONS(1240),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(1242),
    [anon_sym_yield] = ACTIONS(1244),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1246),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1510),
    [anon_sym_using] = ACTIONS(1250),
    [anon_sym_PLUS] = ACTIONS(1256),
    [anon_sym_DASH] = ACTIONS(1256),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(1240),
    [anon_sym_void] = ACTIONS(1256),
    [anon_sym_delete] = ACTIONS(1256),
    [anon_sym_PLUS_PLUS] = ACTIONS(1258),
    [anon_sym_DASH_DASH] = ACTIONS(1258),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(1260),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1512),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1234),
    [anon_sym_readonly] = ACTIONS(1234),
    [anon_sym_get] = ACTIONS(1234),
    [anon_sym_set] = ACTIONS(1234),
    [anon_sym_declare] = ACTIONS(1234),
    [anon_sym_public] = ACTIONS(1234),
    [anon_sym_private] = ACTIONS(1234),
    [anon_sym_protected] = ACTIONS(1234),
    [anon_sym_override] = ACTIONS(1234),
    [anon_sym_module] = ACTIONS(1234),
    [anon_sym_any] = ACTIONS(1234),
    [anon_sym_number] = ACTIONS(1234),
    [anon_sym_boolean] = ACTIONS(1234),
    [anon_sym_string] = ACTIONS(1234),
    [anon_sym_symbol] = ACTIONS(1234),
    [anon_sym_object] = ACTIONS(1234),
    [sym_html_comment] = ACTIONS(5),
  },
  [372] = {
    [sym_import] = STATE(3639),
    [sym_statement_block] = STATE(1672),
    [sym_parenthesized_expression] = STATE(1456),
    [sym_expression] = STATE(2363),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5815),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5815),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5755),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1456),
    [sym_subscript_expression] = STATE(1456),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3029),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5815),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1456),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(594),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1506),
    [anon_sym_export] = ACTIONS(1234),
    [anon_sym_type] = ACTIONS(1234),
    [anon_sym_namespace] = ACTIONS(1236),
    [anon_sym_LBRACE] = ACTIONS(2099),
    [anon_sym_typeof] = ACTIONS(1256),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1234),
    [anon_sym_BANG] = ACTIONS(1240),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(1242),
    [anon_sym_yield] = ACTIONS(1244),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1246),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1510),
    [anon_sym_using] = ACTIONS(1250),
    [anon_sym_PLUS] = ACTIONS(1256),
    [anon_sym_DASH] = ACTIONS(1256),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(1240),
    [anon_sym_void] = ACTIONS(1256),
    [anon_sym_delete] = ACTIONS(1256),
    [anon_sym_PLUS_PLUS] = ACTIONS(1258),
    [anon_sym_DASH_DASH] = ACTIONS(1258),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(1260),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1512),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1234),
    [anon_sym_readonly] = ACTIONS(1234),
    [anon_sym_get] = ACTIONS(1234),
    [anon_sym_set] = ACTIONS(1234),
    [anon_sym_declare] = ACTIONS(1234),
    [anon_sym_public] = ACTIONS(1234),
    [anon_sym_private] = ACTIONS(1234),
    [anon_sym_protected] = ACTIONS(1234),
    [anon_sym_override] = ACTIONS(1234),
    [anon_sym_module] = ACTIONS(1234),
    [anon_sym_any] = ACTIONS(1234),
    [anon_sym_number] = ACTIONS(1234),
    [anon_sym_boolean] = ACTIONS(1234),
    [anon_sym_string] = ACTIONS(1234),
    [anon_sym_symbol] = ACTIONS(1234),
    [anon_sym_object] = ACTIONS(1234),
    [sym_html_comment] = ACTIONS(5),
  },
  [373] = {
    [sym_import] = STATE(3639),
    [sym_statement_block] = STATE(1680),
    [sym_parenthesized_expression] = STATE(1456),
    [sym_expression] = STATE(2365),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5815),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5815),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5755),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1456),
    [sym_subscript_expression] = STATE(1456),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3029),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5815),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1456),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(594),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1506),
    [anon_sym_export] = ACTIONS(1234),
    [anon_sym_type] = ACTIONS(1234),
    [anon_sym_namespace] = ACTIONS(1236),
    [anon_sym_LBRACE] = ACTIONS(2099),
    [anon_sym_typeof] = ACTIONS(1256),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1234),
    [anon_sym_BANG] = ACTIONS(1240),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(1242),
    [anon_sym_yield] = ACTIONS(1244),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1246),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1510),
    [anon_sym_using] = ACTIONS(1250),
    [anon_sym_PLUS] = ACTIONS(1256),
    [anon_sym_DASH] = ACTIONS(1256),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(1240),
    [anon_sym_void] = ACTIONS(1256),
    [anon_sym_delete] = ACTIONS(1256),
    [anon_sym_PLUS_PLUS] = ACTIONS(1258),
    [anon_sym_DASH_DASH] = ACTIONS(1258),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(1260),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1512),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1234),
    [anon_sym_readonly] = ACTIONS(1234),
    [anon_sym_get] = ACTIONS(1234),
    [anon_sym_set] = ACTIONS(1234),
    [anon_sym_declare] = ACTIONS(1234),
    [anon_sym_public] = ACTIONS(1234),
    [anon_sym_private] = ACTIONS(1234),
    [anon_sym_protected] = ACTIONS(1234),
    [anon_sym_override] = ACTIONS(1234),
    [anon_sym_module] = ACTIONS(1234),
    [anon_sym_any] = ACTIONS(1234),
    [anon_sym_number] = ACTIONS(1234),
    [anon_sym_boolean] = ACTIONS(1234),
    [anon_sym_string] = ACTIONS(1234),
    [anon_sym_symbol] = ACTIONS(1234),
    [anon_sym_object] = ACTIONS(1234),
    [sym_html_comment] = ACTIONS(5),
  },
  [374] = {
    [sym_import] = STATE(3639),
    [sym_statement_block] = STATE(1682),
    [sym_parenthesized_expression] = STATE(1456),
    [sym_expression] = STATE(2366),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5815),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5815),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5755),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1456),
    [sym_subscript_expression] = STATE(1456),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3029),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5815),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1456),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(594),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1506),
    [anon_sym_export] = ACTIONS(1234),
    [anon_sym_type] = ACTIONS(1234),
    [anon_sym_namespace] = ACTIONS(1236),
    [anon_sym_LBRACE] = ACTIONS(2099),
    [anon_sym_typeof] = ACTIONS(1256),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1234),
    [anon_sym_BANG] = ACTIONS(1240),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(1242),
    [anon_sym_yield] = ACTIONS(1244),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1246),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1510),
    [anon_sym_using] = ACTIONS(1250),
    [anon_sym_PLUS] = ACTIONS(1256),
    [anon_sym_DASH] = ACTIONS(1256),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(1240),
    [anon_sym_void] = ACTIONS(1256),
    [anon_sym_delete] = ACTIONS(1256),
    [anon_sym_PLUS_PLUS] = ACTIONS(1258),
    [anon_sym_DASH_DASH] = ACTIONS(1258),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(1260),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1512),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1234),
    [anon_sym_readonly] = ACTIONS(1234),
    [anon_sym_get] = ACTIONS(1234),
    [anon_sym_set] = ACTIONS(1234),
    [anon_sym_declare] = ACTIONS(1234),
    [anon_sym_public] = ACTIONS(1234),
    [anon_sym_private] = ACTIONS(1234),
    [anon_sym_protected] = ACTIONS(1234),
    [anon_sym_override] = ACTIONS(1234),
    [anon_sym_module] = ACTIONS(1234),
    [anon_sym_any] = ACTIONS(1234),
    [anon_sym_number] = ACTIONS(1234),
    [anon_sym_boolean] = ACTIONS(1234),
    [anon_sym_string] = ACTIONS(1234),
    [anon_sym_symbol] = ACTIONS(1234),
    [anon_sym_object] = ACTIONS(1234),
    [sym_html_comment] = ACTIONS(5),
  },
  [375] = {
    [sym_import] = STATE(3639),
    [sym_statement_block] = STATE(1683),
    [sym_parenthesized_expression] = STATE(1456),
    [sym_expression] = STATE(2367),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5815),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5815),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5755),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1456),
    [sym_subscript_expression] = STATE(1456),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3029),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5815),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1456),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(594),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1506),
    [anon_sym_export] = ACTIONS(1234),
    [anon_sym_type] = ACTIONS(1234),
    [anon_sym_namespace] = ACTIONS(1236),
    [anon_sym_LBRACE] = ACTIONS(2099),
    [anon_sym_typeof] = ACTIONS(1256),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1234),
    [anon_sym_BANG] = ACTIONS(1240),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(1242),
    [anon_sym_yield] = ACTIONS(1244),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1246),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1510),
    [anon_sym_using] = ACTIONS(1250),
    [anon_sym_PLUS] = ACTIONS(1256),
    [anon_sym_DASH] = ACTIONS(1256),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(1240),
    [anon_sym_void] = ACTIONS(1256),
    [anon_sym_delete] = ACTIONS(1256),
    [anon_sym_PLUS_PLUS] = ACTIONS(1258),
    [anon_sym_DASH_DASH] = ACTIONS(1258),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(1260),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1512),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1234),
    [anon_sym_readonly] = ACTIONS(1234),
    [anon_sym_get] = ACTIONS(1234),
    [anon_sym_set] = ACTIONS(1234),
    [anon_sym_declare] = ACTIONS(1234),
    [anon_sym_public] = ACTIONS(1234),
    [anon_sym_private] = ACTIONS(1234),
    [anon_sym_protected] = ACTIONS(1234),
    [anon_sym_override] = ACTIONS(1234),
    [anon_sym_module] = ACTIONS(1234),
    [anon_sym_any] = ACTIONS(1234),
    [anon_sym_number] = ACTIONS(1234),
    [anon_sym_boolean] = ACTIONS(1234),
    [anon_sym_string] = ACTIONS(1234),
    [anon_sym_symbol] = ACTIONS(1234),
    [anon_sym_object] = ACTIONS(1234),
    [sym_html_comment] = ACTIONS(5),
  },
  [376] = {
    [sym_import] = STATE(3639),
    [sym_statement_block] = STATE(1658),
    [sym_parenthesized_expression] = STATE(1457),
    [sym_expression] = STATE(2388),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5823),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5823),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5477),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1457),
    [sym_subscript_expression] = STATE(1457),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(2986),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5823),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1457),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(620),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1522),
    [anon_sym_export] = ACTIONS(1178),
    [anon_sym_type] = ACTIONS(1178),
    [anon_sym_namespace] = ACTIONS(1180),
    [anon_sym_LBRACE] = ACTIONS(2099),
    [anon_sym_typeof] = ACTIONS(1202),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1178),
    [anon_sym_BANG] = ACTIONS(1186),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(1188),
    [anon_sym_yield] = ACTIONS(1190),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1192),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1526),
    [anon_sym_using] = ACTIONS(1196),
    [anon_sym_PLUS] = ACTIONS(1202),
    [anon_sym_DASH] = ACTIONS(1202),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(1186),
    [anon_sym_void] = ACTIONS(1202),
    [anon_sym_delete] = ACTIONS(1202),
    [anon_sym_PLUS_PLUS] = ACTIONS(1204),
    [anon_sym_DASH_DASH] = ACTIONS(1204),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(1206),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1528),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1178),
    [anon_sym_readonly] = ACTIONS(1178),
    [anon_sym_get] = ACTIONS(1178),
    [anon_sym_set] = ACTIONS(1178),
    [anon_sym_declare] = ACTIONS(1178),
    [anon_sym_public] = ACTIONS(1178),
    [anon_sym_private] = ACTIONS(1178),
    [anon_sym_protected] = ACTIONS(1178),
    [anon_sym_override] = ACTIONS(1178),
    [anon_sym_module] = ACTIONS(1178),
    [anon_sym_any] = ACTIONS(1178),
    [anon_sym_number] = ACTIONS(1178),
    [anon_sym_boolean] = ACTIONS(1178),
    [anon_sym_string] = ACTIONS(1178),
    [anon_sym_symbol] = ACTIONS(1178),
    [anon_sym_object] = ACTIONS(1178),
    [sym_html_comment] = ACTIONS(5),
  },
  [377] = {
    [sym_import] = STATE(3639),
    [sym_statement_block] = STATE(1668),
    [sym_parenthesized_expression] = STATE(1457),
    [sym_expression] = STATE(2392),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5823),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5823),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5477),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1457),
    [sym_subscript_expression] = STATE(1457),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(2986),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5823),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1457),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(620),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1522),
    [anon_sym_export] = ACTIONS(1178),
    [anon_sym_type] = ACTIONS(1178),
    [anon_sym_namespace] = ACTIONS(1180),
    [anon_sym_LBRACE] = ACTIONS(2099),
    [anon_sym_typeof] = ACTIONS(1202),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1178),
    [anon_sym_BANG] = ACTIONS(1186),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(1188),
    [anon_sym_yield] = ACTIONS(1190),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1192),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1526),
    [anon_sym_using] = ACTIONS(1196),
    [anon_sym_PLUS] = ACTIONS(1202),
    [anon_sym_DASH] = ACTIONS(1202),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(1186),
    [anon_sym_void] = ACTIONS(1202),
    [anon_sym_delete] = ACTIONS(1202),
    [anon_sym_PLUS_PLUS] = ACTIONS(1204),
    [anon_sym_DASH_DASH] = ACTIONS(1204),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(1206),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1528),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1178),
    [anon_sym_readonly] = ACTIONS(1178),
    [anon_sym_get] = ACTIONS(1178),
    [anon_sym_set] = ACTIONS(1178),
    [anon_sym_declare] = ACTIONS(1178),
    [anon_sym_public] = ACTIONS(1178),
    [anon_sym_private] = ACTIONS(1178),
    [anon_sym_protected] = ACTIONS(1178),
    [anon_sym_override] = ACTIONS(1178),
    [anon_sym_module] = ACTIONS(1178),
    [anon_sym_any] = ACTIONS(1178),
    [anon_sym_number] = ACTIONS(1178),
    [anon_sym_boolean] = ACTIONS(1178),
    [anon_sym_string] = ACTIONS(1178),
    [anon_sym_symbol] = ACTIONS(1178),
    [anon_sym_object] = ACTIONS(1178),
    [sym_html_comment] = ACTIONS(5),
  },
  [378] = {
    [sym_import] = STATE(3639),
    [sym_statement_block] = STATE(1672),
    [sym_parenthesized_expression] = STATE(1457),
    [sym_expression] = STATE(2413),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5823),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5823),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5477),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1457),
    [sym_subscript_expression] = STATE(1457),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(2986),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5823),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1457),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(620),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1522),
    [anon_sym_export] = ACTIONS(1178),
    [anon_sym_type] = ACTIONS(1178),
    [anon_sym_namespace] = ACTIONS(1180),
    [anon_sym_LBRACE] = ACTIONS(2099),
    [anon_sym_typeof] = ACTIONS(1202),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1178),
    [anon_sym_BANG] = ACTIONS(1186),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(1188),
    [anon_sym_yield] = ACTIONS(1190),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1192),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1526),
    [anon_sym_using] = ACTIONS(1196),
    [anon_sym_PLUS] = ACTIONS(1202),
    [anon_sym_DASH] = ACTIONS(1202),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(1186),
    [anon_sym_void] = ACTIONS(1202),
    [anon_sym_delete] = ACTIONS(1202),
    [anon_sym_PLUS_PLUS] = ACTIONS(1204),
    [anon_sym_DASH_DASH] = ACTIONS(1204),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(1206),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1528),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1178),
    [anon_sym_readonly] = ACTIONS(1178),
    [anon_sym_get] = ACTIONS(1178),
    [anon_sym_set] = ACTIONS(1178),
    [anon_sym_declare] = ACTIONS(1178),
    [anon_sym_public] = ACTIONS(1178),
    [anon_sym_private] = ACTIONS(1178),
    [anon_sym_protected] = ACTIONS(1178),
    [anon_sym_override] = ACTIONS(1178),
    [anon_sym_module] = ACTIONS(1178),
    [anon_sym_any] = ACTIONS(1178),
    [anon_sym_number] = ACTIONS(1178),
    [anon_sym_boolean] = ACTIONS(1178),
    [anon_sym_string] = ACTIONS(1178),
    [anon_sym_symbol] = ACTIONS(1178),
    [anon_sym_object] = ACTIONS(1178),
    [sym_html_comment] = ACTIONS(5),
  },
  [379] = {
    [sym_import] = STATE(3639),
    [sym_statement_block] = STATE(1680),
    [sym_parenthesized_expression] = STATE(1457),
    [sym_expression] = STATE(2419),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5823),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5823),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5477),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1457),
    [sym_subscript_expression] = STATE(1457),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(2986),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5823),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1457),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(620),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1522),
    [anon_sym_export] = ACTIONS(1178),
    [anon_sym_type] = ACTIONS(1178),
    [anon_sym_namespace] = ACTIONS(1180),
    [anon_sym_LBRACE] = ACTIONS(2099),
    [anon_sym_typeof] = ACTIONS(1202),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1178),
    [anon_sym_BANG] = ACTIONS(1186),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(1188),
    [anon_sym_yield] = ACTIONS(1190),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1192),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1526),
    [anon_sym_using] = ACTIONS(1196),
    [anon_sym_PLUS] = ACTIONS(1202),
    [anon_sym_DASH] = ACTIONS(1202),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(1186),
    [anon_sym_void] = ACTIONS(1202),
    [anon_sym_delete] = ACTIONS(1202),
    [anon_sym_PLUS_PLUS] = ACTIONS(1204),
    [anon_sym_DASH_DASH] = ACTIONS(1204),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(1206),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1528),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1178),
    [anon_sym_readonly] = ACTIONS(1178),
    [anon_sym_get] = ACTIONS(1178),
    [anon_sym_set] = ACTIONS(1178),
    [anon_sym_declare] = ACTIONS(1178),
    [anon_sym_public] = ACTIONS(1178),
    [anon_sym_private] = ACTIONS(1178),
    [anon_sym_protected] = ACTIONS(1178),
    [anon_sym_override] = ACTIONS(1178),
    [anon_sym_module] = ACTIONS(1178),
    [anon_sym_any] = ACTIONS(1178),
    [anon_sym_number] = ACTIONS(1178),
    [anon_sym_boolean] = ACTIONS(1178),
    [anon_sym_string] = ACTIONS(1178),
    [anon_sym_symbol] = ACTIONS(1178),
    [anon_sym_object] = ACTIONS(1178),
    [sym_html_comment] = ACTIONS(5),
  },
  [380] = {
    [sym_import] = STATE(3639),
    [sym_statement_block] = STATE(1682),
    [sym_parenthesized_expression] = STATE(1457),
    [sym_expression] = STATE(2420),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5823),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5823),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5477),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1457),
    [sym_subscript_expression] = STATE(1457),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(2986),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5823),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1457),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(620),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1522),
    [anon_sym_export] = ACTIONS(1178),
    [anon_sym_type] = ACTIONS(1178),
    [anon_sym_namespace] = ACTIONS(1180),
    [anon_sym_LBRACE] = ACTIONS(2099),
    [anon_sym_typeof] = ACTIONS(1202),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1178),
    [anon_sym_BANG] = ACTIONS(1186),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(1188),
    [anon_sym_yield] = ACTIONS(1190),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1192),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1526),
    [anon_sym_using] = ACTIONS(1196),
    [anon_sym_PLUS] = ACTIONS(1202),
    [anon_sym_DASH] = ACTIONS(1202),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(1186),
    [anon_sym_void] = ACTIONS(1202),
    [anon_sym_delete] = ACTIONS(1202),
    [anon_sym_PLUS_PLUS] = ACTIONS(1204),
    [anon_sym_DASH_DASH] = ACTIONS(1204),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(1206),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1528),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1178),
    [anon_sym_readonly] = ACTIONS(1178),
    [anon_sym_get] = ACTIONS(1178),
    [anon_sym_set] = ACTIONS(1178),
    [anon_sym_declare] = ACTIONS(1178),
    [anon_sym_public] = ACTIONS(1178),
    [anon_sym_private] = ACTIONS(1178),
    [anon_sym_protected] = ACTIONS(1178),
    [anon_sym_override] = ACTIONS(1178),
    [anon_sym_module] = ACTIONS(1178),
    [anon_sym_any] = ACTIONS(1178),
    [anon_sym_number] = ACTIONS(1178),
    [anon_sym_boolean] = ACTIONS(1178),
    [anon_sym_string] = ACTIONS(1178),
    [anon_sym_symbol] = ACTIONS(1178),
    [anon_sym_object] = ACTIONS(1178),
    [sym_html_comment] = ACTIONS(5),
  },
  [381] = {
    [sym_import] = STATE(3639),
    [sym_statement_block] = STATE(1683),
    [sym_parenthesized_expression] = STATE(1457),
    [sym_expression] = STATE(2421),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5823),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5823),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5477),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1457),
    [sym_subscript_expression] = STATE(1457),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(2986),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5823),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1457),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(620),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1522),
    [anon_sym_export] = ACTIONS(1178),
    [anon_sym_type] = ACTIONS(1178),
    [anon_sym_namespace] = ACTIONS(1180),
    [anon_sym_LBRACE] = ACTIONS(2099),
    [anon_sym_typeof] = ACTIONS(1202),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1178),
    [anon_sym_BANG] = ACTIONS(1186),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(1188),
    [anon_sym_yield] = ACTIONS(1190),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1192),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1526),
    [anon_sym_using] = ACTIONS(1196),
    [anon_sym_PLUS] = ACTIONS(1202),
    [anon_sym_DASH] = ACTIONS(1202),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(1186),
    [anon_sym_void] = ACTIONS(1202),
    [anon_sym_delete] = ACTIONS(1202),
    [anon_sym_PLUS_PLUS] = ACTIONS(1204),
    [anon_sym_DASH_DASH] = ACTIONS(1204),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(1206),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1528),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1178),
    [anon_sym_readonly] = ACTIONS(1178),
    [anon_sym_get] = ACTIONS(1178),
    [anon_sym_set] = ACTIONS(1178),
    [anon_sym_declare] = ACTIONS(1178),
    [anon_sym_public] = ACTIONS(1178),
    [anon_sym_private] = ACTIONS(1178),
    [anon_sym_protected] = ACTIONS(1178),
    [anon_sym_override] = ACTIONS(1178),
    [anon_sym_module] = ACTIONS(1178),
    [anon_sym_any] = ACTIONS(1178),
    [anon_sym_number] = ACTIONS(1178),
    [anon_sym_boolean] = ACTIONS(1178),
    [anon_sym_string] = ACTIONS(1178),
    [anon_sym_symbol] = ACTIONS(1178),
    [anon_sym_object] = ACTIONS(1178),
    [sym_html_comment] = ACTIONS(5),
  },
  [382] = {
    [sym_import] = STATE(3639),
    [sym_statement_block] = STATE(1658),
    [sym_parenthesized_expression] = STATE(1459),
    [sym_expression] = STATE(2485),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5827),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5827),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5529),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1459),
    [sym_subscript_expression] = STATE(1459),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(2979),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5827),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1459),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(647),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1514),
    [anon_sym_export] = ACTIONS(1074),
    [anon_sym_type] = ACTIONS(1074),
    [anon_sym_namespace] = ACTIONS(1076),
    [anon_sym_LBRACE] = ACTIONS(2123),
    [anon_sym_typeof] = ACTIONS(1100),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1074),
    [anon_sym_BANG] = ACTIONS(1082),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(1084),
    [anon_sym_yield] = ACTIONS(1086),
    [anon_sym_LBRACK] = ACTIONS(812),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1090),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1518),
    [anon_sym_using] = ACTIONS(1094),
    [anon_sym_PLUS] = ACTIONS(1100),
    [anon_sym_DASH] = ACTIONS(1100),
    [anon_sym_SLASH] = ACTIONS(958),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(1082),
    [anon_sym_void] = ACTIONS(1100),
    [anon_sym_delete] = ACTIONS(1100),
    [anon_sym_PLUS_PLUS] = ACTIONS(1102),
    [anon_sym_DASH_DASH] = ACTIONS(1102),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(1108),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1520),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1074),
    [anon_sym_readonly] = ACTIONS(1074),
    [anon_sym_get] = ACTIONS(1074),
    [anon_sym_set] = ACTIONS(1074),
    [anon_sym_declare] = ACTIONS(1074),
    [anon_sym_public] = ACTIONS(1074),
    [anon_sym_private] = ACTIONS(1074),
    [anon_sym_protected] = ACTIONS(1074),
    [anon_sym_override] = ACTIONS(1074),
    [anon_sym_module] = ACTIONS(1074),
    [anon_sym_any] = ACTIONS(1074),
    [anon_sym_number] = ACTIONS(1074),
    [anon_sym_boolean] = ACTIONS(1074),
    [anon_sym_string] = ACTIONS(1074),
    [anon_sym_symbol] = ACTIONS(1074),
    [anon_sym_object] = ACTIONS(1074),
    [sym_html_comment] = ACTIONS(5),
  },
  [383] = {
    [sym_import] = STATE(3639),
    [sym_statement_block] = STATE(1668),
    [sym_parenthesized_expression] = STATE(1459),
    [sym_expression] = STATE(2489),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5827),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5827),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5529),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1459),
    [sym_subscript_expression] = STATE(1459),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(2979),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5827),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1459),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(647),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1514),
    [anon_sym_export] = ACTIONS(1074),
    [anon_sym_type] = ACTIONS(1074),
    [anon_sym_namespace] = ACTIONS(1076),
    [anon_sym_LBRACE] = ACTIONS(2123),
    [anon_sym_typeof] = ACTIONS(1100),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1074),
    [anon_sym_BANG] = ACTIONS(1082),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(1084),
    [anon_sym_yield] = ACTIONS(1086),
    [anon_sym_LBRACK] = ACTIONS(812),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1090),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1518),
    [anon_sym_using] = ACTIONS(1094),
    [anon_sym_PLUS] = ACTIONS(1100),
    [anon_sym_DASH] = ACTIONS(1100),
    [anon_sym_SLASH] = ACTIONS(958),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(1082),
    [anon_sym_void] = ACTIONS(1100),
    [anon_sym_delete] = ACTIONS(1100),
    [anon_sym_PLUS_PLUS] = ACTIONS(1102),
    [anon_sym_DASH_DASH] = ACTIONS(1102),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(1108),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1520),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1074),
    [anon_sym_readonly] = ACTIONS(1074),
    [anon_sym_get] = ACTIONS(1074),
    [anon_sym_set] = ACTIONS(1074),
    [anon_sym_declare] = ACTIONS(1074),
    [anon_sym_public] = ACTIONS(1074),
    [anon_sym_private] = ACTIONS(1074),
    [anon_sym_protected] = ACTIONS(1074),
    [anon_sym_override] = ACTIONS(1074),
    [anon_sym_module] = ACTIONS(1074),
    [anon_sym_any] = ACTIONS(1074),
    [anon_sym_number] = ACTIONS(1074),
    [anon_sym_boolean] = ACTIONS(1074),
    [anon_sym_string] = ACTIONS(1074),
    [anon_sym_symbol] = ACTIONS(1074),
    [anon_sym_object] = ACTIONS(1074),
    [sym_html_comment] = ACTIONS(5),
  },
  [384] = {
    [sym_import] = STATE(3639),
    [sym_statement_block] = STATE(1672),
    [sym_parenthesized_expression] = STATE(1459),
    [sym_expression] = STATE(2502),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5827),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5827),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5529),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1459),
    [sym_subscript_expression] = STATE(1459),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(2979),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5827),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1459),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(647),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1514),
    [anon_sym_export] = ACTIONS(1074),
    [anon_sym_type] = ACTIONS(1074),
    [anon_sym_namespace] = ACTIONS(1076),
    [anon_sym_LBRACE] = ACTIONS(2123),
    [anon_sym_typeof] = ACTIONS(1100),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1074),
    [anon_sym_BANG] = ACTIONS(1082),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(1084),
    [anon_sym_yield] = ACTIONS(1086),
    [anon_sym_LBRACK] = ACTIONS(812),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1090),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1518),
    [anon_sym_using] = ACTIONS(1094),
    [anon_sym_PLUS] = ACTIONS(1100),
    [anon_sym_DASH] = ACTIONS(1100),
    [anon_sym_SLASH] = ACTIONS(958),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(1082),
    [anon_sym_void] = ACTIONS(1100),
    [anon_sym_delete] = ACTIONS(1100),
    [anon_sym_PLUS_PLUS] = ACTIONS(1102),
    [anon_sym_DASH_DASH] = ACTIONS(1102),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(1108),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1520),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1074),
    [anon_sym_readonly] = ACTIONS(1074),
    [anon_sym_get] = ACTIONS(1074),
    [anon_sym_set] = ACTIONS(1074),
    [anon_sym_declare] = ACTIONS(1074),
    [anon_sym_public] = ACTIONS(1074),
    [anon_sym_private] = ACTIONS(1074),
    [anon_sym_protected] = ACTIONS(1074),
    [anon_sym_override] = ACTIONS(1074),
    [anon_sym_module] = ACTIONS(1074),
    [anon_sym_any] = ACTIONS(1074),
    [anon_sym_number] = ACTIONS(1074),
    [anon_sym_boolean] = ACTIONS(1074),
    [anon_sym_string] = ACTIONS(1074),
    [anon_sym_symbol] = ACTIONS(1074),
    [anon_sym_object] = ACTIONS(1074),
    [sym_html_comment] = ACTIONS(5),
  },
  [385] = {
    [sym_import] = STATE(3639),
    [sym_statement_block] = STATE(1680),
    [sym_parenthesized_expression] = STATE(1459),
    [sym_expression] = STATE(2504),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5827),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5827),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5529),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1459),
    [sym_subscript_expression] = STATE(1459),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(2979),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5827),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1459),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(647),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1514),
    [anon_sym_export] = ACTIONS(1074),
    [anon_sym_type] = ACTIONS(1074),
    [anon_sym_namespace] = ACTIONS(1076),
    [anon_sym_LBRACE] = ACTIONS(2123),
    [anon_sym_typeof] = ACTIONS(1100),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1074),
    [anon_sym_BANG] = ACTIONS(1082),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(1084),
    [anon_sym_yield] = ACTIONS(1086),
    [anon_sym_LBRACK] = ACTIONS(812),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1090),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1518),
    [anon_sym_using] = ACTIONS(1094),
    [anon_sym_PLUS] = ACTIONS(1100),
    [anon_sym_DASH] = ACTIONS(1100),
    [anon_sym_SLASH] = ACTIONS(958),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(1082),
    [anon_sym_void] = ACTIONS(1100),
    [anon_sym_delete] = ACTIONS(1100),
    [anon_sym_PLUS_PLUS] = ACTIONS(1102),
    [anon_sym_DASH_DASH] = ACTIONS(1102),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(1108),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1520),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1074),
    [anon_sym_readonly] = ACTIONS(1074),
    [anon_sym_get] = ACTIONS(1074),
    [anon_sym_set] = ACTIONS(1074),
    [anon_sym_declare] = ACTIONS(1074),
    [anon_sym_public] = ACTIONS(1074),
    [anon_sym_private] = ACTIONS(1074),
    [anon_sym_protected] = ACTIONS(1074),
    [anon_sym_override] = ACTIONS(1074),
    [anon_sym_module] = ACTIONS(1074),
    [anon_sym_any] = ACTIONS(1074),
    [anon_sym_number] = ACTIONS(1074),
    [anon_sym_boolean] = ACTIONS(1074),
    [anon_sym_string] = ACTIONS(1074),
    [anon_sym_symbol] = ACTIONS(1074),
    [anon_sym_object] = ACTIONS(1074),
    [sym_html_comment] = ACTIONS(5),
  },
  [386] = {
    [sym_import] = STATE(3639),
    [sym_statement_block] = STATE(1682),
    [sym_parenthesized_expression] = STATE(1459),
    [sym_expression] = STATE(2505),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5827),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5827),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5529),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1459),
    [sym_subscript_expression] = STATE(1459),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(2979),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5827),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1459),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(647),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1514),
    [anon_sym_export] = ACTIONS(1074),
    [anon_sym_type] = ACTIONS(1074),
    [anon_sym_namespace] = ACTIONS(1076),
    [anon_sym_LBRACE] = ACTIONS(2123),
    [anon_sym_typeof] = ACTIONS(1100),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1074),
    [anon_sym_BANG] = ACTIONS(1082),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(1084),
    [anon_sym_yield] = ACTIONS(1086),
    [anon_sym_LBRACK] = ACTIONS(812),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1090),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1518),
    [anon_sym_using] = ACTIONS(1094),
    [anon_sym_PLUS] = ACTIONS(1100),
    [anon_sym_DASH] = ACTIONS(1100),
    [anon_sym_SLASH] = ACTIONS(958),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(1082),
    [anon_sym_void] = ACTIONS(1100),
    [anon_sym_delete] = ACTIONS(1100),
    [anon_sym_PLUS_PLUS] = ACTIONS(1102),
    [anon_sym_DASH_DASH] = ACTIONS(1102),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(1108),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1520),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1074),
    [anon_sym_readonly] = ACTIONS(1074),
    [anon_sym_get] = ACTIONS(1074),
    [anon_sym_set] = ACTIONS(1074),
    [anon_sym_declare] = ACTIONS(1074),
    [anon_sym_public] = ACTIONS(1074),
    [anon_sym_private] = ACTIONS(1074),
    [anon_sym_protected] = ACTIONS(1074),
    [anon_sym_override] = ACTIONS(1074),
    [anon_sym_module] = ACTIONS(1074),
    [anon_sym_any] = ACTIONS(1074),
    [anon_sym_number] = ACTIONS(1074),
    [anon_sym_boolean] = ACTIONS(1074),
    [anon_sym_string] = ACTIONS(1074),
    [anon_sym_symbol] = ACTIONS(1074),
    [anon_sym_object] = ACTIONS(1074),
    [sym_html_comment] = ACTIONS(5),
  },
  [387] = {
    [sym_import] = STATE(3639),
    [sym_statement_block] = STATE(1683),
    [sym_parenthesized_expression] = STATE(1459),
    [sym_expression] = STATE(2506),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5827),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5827),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5529),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1459),
    [sym_subscript_expression] = STATE(1459),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(2979),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5827),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1459),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(647),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1514),
    [anon_sym_export] = ACTIONS(1074),
    [anon_sym_type] = ACTIONS(1074),
    [anon_sym_namespace] = ACTIONS(1076),
    [anon_sym_LBRACE] = ACTIONS(2123),
    [anon_sym_typeof] = ACTIONS(1100),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1074),
    [anon_sym_BANG] = ACTIONS(1082),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(1084),
    [anon_sym_yield] = ACTIONS(1086),
    [anon_sym_LBRACK] = ACTIONS(812),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1090),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1518),
    [anon_sym_using] = ACTIONS(1094),
    [anon_sym_PLUS] = ACTIONS(1100),
    [anon_sym_DASH] = ACTIONS(1100),
    [anon_sym_SLASH] = ACTIONS(958),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(1082),
    [anon_sym_void] = ACTIONS(1100),
    [anon_sym_delete] = ACTIONS(1100),
    [anon_sym_PLUS_PLUS] = ACTIONS(1102),
    [anon_sym_DASH_DASH] = ACTIONS(1102),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(1108),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1520),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1074),
    [anon_sym_readonly] = ACTIONS(1074),
    [anon_sym_get] = ACTIONS(1074),
    [anon_sym_set] = ACTIONS(1074),
    [anon_sym_declare] = ACTIONS(1074),
    [anon_sym_public] = ACTIONS(1074),
    [anon_sym_private] = ACTIONS(1074),
    [anon_sym_protected] = ACTIONS(1074),
    [anon_sym_override] = ACTIONS(1074),
    [anon_sym_module] = ACTIONS(1074),
    [anon_sym_any] = ACTIONS(1074),
    [anon_sym_number] = ACTIONS(1074),
    [anon_sym_boolean] = ACTIONS(1074),
    [anon_sym_string] = ACTIONS(1074),
    [anon_sym_symbol] = ACTIONS(1074),
    [anon_sym_object] = ACTIONS(1074),
    [sym_html_comment] = ACTIONS(5),
  },
  [388] = {
    [sym_import] = STATE(3639),
    [sym_statement_block] = STATE(1683),
    [sym_parenthesized_expression] = STATE(1398),
    [sym_expression] = STATE(1932),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5544),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5544),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5558),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1398),
    [sym_subscript_expression] = STATE(1398),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(2980),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5544),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1398),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(638),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1482),
    [anon_sym_export] = ACTIONS(1158),
    [anon_sym_type] = ACTIONS(1158),
    [anon_sym_namespace] = ACTIONS(1160),
    [anon_sym_LBRACE] = ACTIONS(2099),
    [anon_sym_typeof] = ACTIONS(756),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1158),
    [anon_sym_BANG] = ACTIONS(732),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(736),
    [anon_sym_yield] = ACTIONS(738),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1164),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1486),
    [anon_sym_using] = ACTIONS(746),
    [anon_sym_PLUS] = ACTIONS(756),
    [anon_sym_DASH] = ACTIONS(756),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(732),
    [anon_sym_void] = ACTIONS(756),
    [anon_sym_delete] = ACTIONS(756),
    [anon_sym_PLUS_PLUS] = ACTIONS(758),
    [anon_sym_DASH_DASH] = ACTIONS(758),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(764),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1488),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1158),
    [anon_sym_readonly] = ACTIONS(1158),
    [anon_sym_get] = ACTIONS(1158),
    [anon_sym_set] = ACTIONS(1158),
    [anon_sym_declare] = ACTIONS(1158),
    [anon_sym_public] = ACTIONS(1158),
    [anon_sym_private] = ACTIONS(1158),
    [anon_sym_protected] = ACTIONS(1158),
    [anon_sym_override] = ACTIONS(1158),
    [anon_sym_module] = ACTIONS(1158),
    [anon_sym_any] = ACTIONS(1158),
    [anon_sym_number] = ACTIONS(1158),
    [anon_sym_boolean] = ACTIONS(1158),
    [anon_sym_string] = ACTIONS(1158),
    [anon_sym_symbol] = ACTIONS(1158),
    [anon_sym_object] = ACTIONS(1158),
    [sym_html_comment] = ACTIONS(5),
  },
  [389] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1398),
    [sym_expression] = STATE(2285),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5544),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5544),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5558),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1398),
    [sym_subscript_expression] = STATE(1398),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(2980),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5544),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_sequence_expression] = STATE(5730),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1398),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(638),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1482),
    [anon_sym_export] = ACTIONS(1158),
    [anon_sym_type] = ACTIONS(1158),
    [anon_sym_namespace] = ACTIONS(1160),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_typeof] = ACTIONS(756),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1158),
    [anon_sym_BANG] = ACTIONS(732),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(736),
    [anon_sym_yield] = ACTIONS(738),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1164),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1486),
    [anon_sym_using] = ACTIONS(746),
    [anon_sym_PLUS] = ACTIONS(756),
    [anon_sym_DASH] = ACTIONS(756),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(732),
    [anon_sym_void] = ACTIONS(756),
    [anon_sym_delete] = ACTIONS(756),
    [anon_sym_PLUS_PLUS] = ACTIONS(758),
    [anon_sym_DASH_DASH] = ACTIONS(758),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(764),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1488),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1158),
    [anon_sym_readonly] = ACTIONS(1158),
    [anon_sym_get] = ACTIONS(1158),
    [anon_sym_set] = ACTIONS(1158),
    [anon_sym_declare] = ACTIONS(1158),
    [anon_sym_public] = ACTIONS(1158),
    [anon_sym_private] = ACTIONS(1158),
    [anon_sym_protected] = ACTIONS(1158),
    [anon_sym_override] = ACTIONS(1158),
    [anon_sym_module] = ACTIONS(1158),
    [anon_sym_any] = ACTIONS(1158),
    [anon_sym_number] = ACTIONS(1158),
    [anon_sym_boolean] = ACTIONS(1158),
    [anon_sym_string] = ACTIONS(1158),
    [anon_sym_symbol] = ACTIONS(1158),
    [anon_sym_object] = ACTIONS(1158),
    [sym_html_comment] = ACTIONS(5),
  },
  [390] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1398),
    [sym_expression] = STATE(2291),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5544),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5544),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5558),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1398),
    [sym_subscript_expression] = STATE(1398),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(2980),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5544),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_sequence_expression] = STATE(5550),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1398),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(638),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1482),
    [anon_sym_export] = ACTIONS(1158),
    [anon_sym_type] = ACTIONS(1158),
    [anon_sym_namespace] = ACTIONS(1160),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_typeof] = ACTIONS(756),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1158),
    [anon_sym_BANG] = ACTIONS(732),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(736),
    [anon_sym_yield] = ACTIONS(738),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1164),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1486),
    [anon_sym_using] = ACTIONS(746),
    [anon_sym_PLUS] = ACTIONS(756),
    [anon_sym_DASH] = ACTIONS(756),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(732),
    [anon_sym_void] = ACTIONS(756),
    [anon_sym_delete] = ACTIONS(756),
    [anon_sym_PLUS_PLUS] = ACTIONS(758),
    [anon_sym_DASH_DASH] = ACTIONS(758),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(764),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1488),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1158),
    [anon_sym_readonly] = ACTIONS(1158),
    [anon_sym_get] = ACTIONS(1158),
    [anon_sym_set] = ACTIONS(1158),
    [anon_sym_declare] = ACTIONS(1158),
    [anon_sym_public] = ACTIONS(1158),
    [anon_sym_private] = ACTIONS(1158),
    [anon_sym_protected] = ACTIONS(1158),
    [anon_sym_override] = ACTIONS(1158),
    [anon_sym_module] = ACTIONS(1158),
    [anon_sym_any] = ACTIONS(1158),
    [anon_sym_number] = ACTIONS(1158),
    [anon_sym_boolean] = ACTIONS(1158),
    [anon_sym_string] = ACTIONS(1158),
    [anon_sym_symbol] = ACTIONS(1158),
    [anon_sym_object] = ACTIONS(1158),
    [sym_html_comment] = ACTIONS(5),
  },
  [391] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1398),
    [sym_expression] = STATE(2308),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5544),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5544),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5558),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1398),
    [sym_subscript_expression] = STATE(1398),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(2980),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5544),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_sequence_expression] = STATE(5631),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1398),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(638),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1482),
    [anon_sym_export] = ACTIONS(1158),
    [anon_sym_type] = ACTIONS(1158),
    [anon_sym_namespace] = ACTIONS(1160),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_typeof] = ACTIONS(756),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1158),
    [anon_sym_BANG] = ACTIONS(732),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(736),
    [anon_sym_yield] = ACTIONS(738),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1164),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1486),
    [anon_sym_using] = ACTIONS(746),
    [anon_sym_PLUS] = ACTIONS(756),
    [anon_sym_DASH] = ACTIONS(756),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(732),
    [anon_sym_void] = ACTIONS(756),
    [anon_sym_delete] = ACTIONS(756),
    [anon_sym_PLUS_PLUS] = ACTIONS(758),
    [anon_sym_DASH_DASH] = ACTIONS(758),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(764),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1488),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1158),
    [anon_sym_readonly] = ACTIONS(1158),
    [anon_sym_get] = ACTIONS(1158),
    [anon_sym_set] = ACTIONS(1158),
    [anon_sym_declare] = ACTIONS(1158),
    [anon_sym_public] = ACTIONS(1158),
    [anon_sym_private] = ACTIONS(1158),
    [anon_sym_protected] = ACTIONS(1158),
    [anon_sym_override] = ACTIONS(1158),
    [anon_sym_module] = ACTIONS(1158),
    [anon_sym_any] = ACTIONS(1158),
    [anon_sym_number] = ACTIONS(1158),
    [anon_sym_boolean] = ACTIONS(1158),
    [anon_sym_string] = ACTIONS(1158),
    [anon_sym_symbol] = ACTIONS(1158),
    [anon_sym_object] = ACTIONS(1158),
    [sym_html_comment] = ACTIONS(5),
  },
  [392] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1398),
    [sym_expression] = STATE(2328),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5544),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5544),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5558),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1398),
    [sym_subscript_expression] = STATE(1398),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(2980),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5544),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_sequence_expression] = STATE(5551),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1398),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(638),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1482),
    [anon_sym_export] = ACTIONS(1158),
    [anon_sym_type] = ACTIONS(1158),
    [anon_sym_namespace] = ACTIONS(1160),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_typeof] = ACTIONS(756),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1158),
    [anon_sym_BANG] = ACTIONS(732),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(736),
    [anon_sym_yield] = ACTIONS(738),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1164),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1486),
    [anon_sym_using] = ACTIONS(746),
    [anon_sym_PLUS] = ACTIONS(756),
    [anon_sym_DASH] = ACTIONS(756),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(732),
    [anon_sym_void] = ACTIONS(756),
    [anon_sym_delete] = ACTIONS(756),
    [anon_sym_PLUS_PLUS] = ACTIONS(758),
    [anon_sym_DASH_DASH] = ACTIONS(758),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(764),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1488),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1158),
    [anon_sym_readonly] = ACTIONS(1158),
    [anon_sym_get] = ACTIONS(1158),
    [anon_sym_set] = ACTIONS(1158),
    [anon_sym_declare] = ACTIONS(1158),
    [anon_sym_public] = ACTIONS(1158),
    [anon_sym_private] = ACTIONS(1158),
    [anon_sym_protected] = ACTIONS(1158),
    [anon_sym_override] = ACTIONS(1158),
    [anon_sym_module] = ACTIONS(1158),
    [anon_sym_any] = ACTIONS(1158),
    [anon_sym_number] = ACTIONS(1158),
    [anon_sym_boolean] = ACTIONS(1158),
    [anon_sym_string] = ACTIONS(1158),
    [anon_sym_symbol] = ACTIONS(1158),
    [anon_sym_object] = ACTIONS(1158),
    [sym_html_comment] = ACTIONS(5),
  },
  [393] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1322),
    [sym_expression] = STATE(2188),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5698),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5698),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5508),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1322),
    [sym_subscript_expression] = STATE(1322),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3003),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5698),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_sequence_expression] = STATE(5640),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1322),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(484),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1456),
    [anon_sym_export] = ACTIONS(1048),
    [anon_sym_type] = ACTIONS(1048),
    [anon_sym_namespace] = ACTIONS(1050),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_typeof] = ACTIONS(581),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1048),
    [anon_sym_BANG] = ACTIONS(553),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(555),
    [anon_sym_yield] = ACTIONS(557),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1058),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1464),
    [anon_sym_using] = ACTIONS(567),
    [anon_sym_PLUS] = ACTIONS(581),
    [anon_sym_DASH] = ACTIONS(581),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(553),
    [anon_sym_void] = ACTIONS(581),
    [anon_sym_delete] = ACTIONS(581),
    [anon_sym_PLUS_PLUS] = ACTIONS(583),
    [anon_sym_DASH_DASH] = ACTIONS(583),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(585),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1466),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1048),
    [anon_sym_readonly] = ACTIONS(1048),
    [anon_sym_get] = ACTIONS(1048),
    [anon_sym_set] = ACTIONS(1048),
    [anon_sym_declare] = ACTIONS(1048),
    [anon_sym_public] = ACTIONS(1048),
    [anon_sym_private] = ACTIONS(1048),
    [anon_sym_protected] = ACTIONS(1048),
    [anon_sym_override] = ACTIONS(1048),
    [anon_sym_module] = ACTIONS(1048),
    [anon_sym_any] = ACTIONS(1048),
    [anon_sym_number] = ACTIONS(1048),
    [anon_sym_boolean] = ACTIONS(1048),
    [anon_sym_string] = ACTIONS(1048),
    [anon_sym_symbol] = ACTIONS(1048),
    [anon_sym_object] = ACTIONS(1048),
    [sym_html_comment] = ACTIONS(5),
  },
  [394] = {
    [sym_import] = STATE(3636),
    [sym_statement_block] = STATE(2280),
    [sym_parenthesized_expression] = STATE(1410),
    [sym_expression] = STATE(2132),
    [sym_primary_expression] = STATE(1810),
    [sym_yield_expression] = STATE(2358),
    [sym_object] = STATE(2222),
    [sym_object_pattern] = STATE(5580),
    [sym_array] = STATE(2222),
    [sym_array_pattern] = STATE(5580),
    [sym_class] = STATE(2222),
    [sym_function_expression] = STATE(2222),
    [sym_generator_function] = STATE(2222),
    [sym_arrow_function] = STATE(2222),
    [sym__call_signature] = STATE(5466),
    [sym_call_expression] = STATE(2222),
    [sym_new_expression] = STATE(1948),
    [sym_await_expression] = STATE(2358),
    [sym_member_expression] = STATE(1410),
    [sym_subscript_expression] = STATE(1410),
    [sym_assignment_expression] = STATE(2358),
    [sym__augmented_assignment_lhs] = STATE(3004),
    [sym_augmented_assignment_expression] = STATE(2358),
    [sym__destructuring_pattern] = STATE(5580),
    [sym_ternary_expression] = STATE(2358),
    [sym_binary_expression] = STATE(2358),
    [sym_unary_expression] = STATE(2358),
    [sym_update_expression] = STATE(2358),
    [sym_string] = STATE(2222),
    [sym_template_string] = STATE(2222),
    [sym_regex] = STATE(2222),
    [sym_meta_property] = STATE(2222),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1410),
    [sym_type_assertion] = STATE(2358),
    [sym_as_expression] = STATE(2358),
    [sym_satisfies_expression] = STATE(2358),
    [sym_instantiation_expression] = STATE(2358),
    [sym_internal_module] = STATE(2358),
    [sym_type_arguments] = STATE(452),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4408),
    [sym_identifier] = ACTIONS(1498),
    [anon_sym_export] = ACTIONS(1270),
    [anon_sym_type] = ACTIONS(1270),
    [anon_sym_namespace] = ACTIONS(1272),
    [anon_sym_LBRACE] = ACTIONS(2101),
    [anon_sym_typeof] = ACTIONS(1298),
    [anon_sym_import] = ACTIONS(669),
    [anon_sym_let] = ACTIONS(1270),
    [anon_sym_BANG] = ACTIONS(1278),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_await] = ACTIONS(1282),
    [anon_sym_yield] = ACTIONS(1284),
    [anon_sym_LBRACK] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(676),
    [anon_sym_async] = ACTIONS(1288),
    [anon_sym_function] = ACTIONS(680),
    [anon_sym_new] = ACTIONS(1502),
    [anon_sym_using] = ACTIONS(1292),
    [anon_sym_PLUS] = ACTIONS(1298),
    [anon_sym_DASH] = ACTIONS(1298),
    [anon_sym_SLASH] = ACTIONS(77),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(1278),
    [anon_sym_void] = ACTIONS(1298),
    [anon_sym_delete] = ACTIONS(1298),
    [anon_sym_PLUS_PLUS] = ACTIONS(1300),
    [anon_sym_DASH_DASH] = ACTIONS(1300),
    [anon_sym_DQUOTE] = ACTIONS(83),
    [anon_sym_SQUOTE] = ACTIONS(85),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(87),
    [sym_number] = ACTIONS(89),
    [sym_private_property_identifier] = ACTIONS(1306),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(93),
    [sym_true] = ACTIONS(93),
    [sym_false] = ACTIONS(93),
    [sym_null] = ACTIONS(93),
    [sym_undefined] = ACTIONS(1504),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1270),
    [anon_sym_readonly] = ACTIONS(1270),
    [anon_sym_get] = ACTIONS(1270),
    [anon_sym_set] = ACTIONS(1270),
    [anon_sym_declare] = ACTIONS(1270),
    [anon_sym_public] = ACTIONS(1270),
    [anon_sym_private] = ACTIONS(1270),
    [anon_sym_protected] = ACTIONS(1270),
    [anon_sym_override] = ACTIONS(1270),
    [anon_sym_module] = ACTIONS(1270),
    [anon_sym_any] = ACTIONS(1270),
    [anon_sym_number] = ACTIONS(1270),
    [anon_sym_boolean] = ACTIONS(1270),
    [anon_sym_string] = ACTIONS(1270),
    [anon_sym_symbol] = ACTIONS(1270),
    [anon_sym_object] = ACTIONS(1270),
    [sym_html_comment] = ACTIONS(5),
  },
  [395] = {
    [sym_import] = STATE(3639),
    [sym_statement_block] = STATE(1682),
    [sym_parenthesized_expression] = STATE(1213),
    [sym_expression] = STATE(2547),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5522),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5522),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5800),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1213),
    [sym_subscript_expression] = STATE(1213),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3013),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5522),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1213),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(539),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(802),
    [anon_sym_export] = ACTIONS(804),
    [anon_sym_type] = ACTIONS(804),
    [anon_sym_namespace] = ACTIONS(806),
    [anon_sym_LBRACE] = ACTIONS(2123),
    [anon_sym_typeof] = ACTIONS(179),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(804),
    [anon_sym_BANG] = ACTIONS(175),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(140),
    [anon_sym_yield] = ACTIONS(142),
    [anon_sym_LBRACK] = ACTIONS(812),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(816),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(818),
    [anon_sym_using] = ACTIONS(158),
    [anon_sym_PLUS] = ACTIONS(179),
    [anon_sym_DASH] = ACTIONS(179),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(175),
    [anon_sym_void] = ACTIONS(179),
    [anon_sym_delete] = ACTIONS(179),
    [anon_sym_PLUS_PLUS] = ACTIONS(686),
    [anon_sym_DASH_DASH] = ACTIONS(686),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(192),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(822),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(804),
    [anon_sym_readonly] = ACTIONS(804),
    [anon_sym_get] = ACTIONS(804),
    [anon_sym_set] = ACTIONS(804),
    [anon_sym_declare] = ACTIONS(804),
    [anon_sym_public] = ACTIONS(804),
    [anon_sym_private] = ACTIONS(804),
    [anon_sym_protected] = ACTIONS(804),
    [anon_sym_override] = ACTIONS(804),
    [anon_sym_module] = ACTIONS(804),
    [anon_sym_any] = ACTIONS(804),
    [anon_sym_number] = ACTIONS(804),
    [anon_sym_boolean] = ACTIONS(804),
    [anon_sym_string] = ACTIONS(804),
    [anon_sym_symbol] = ACTIONS(804),
    [anon_sym_object] = ACTIONS(804),
    [sym_html_comment] = ACTIONS(5),
  },
  [396] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1456),
    [sym_expression] = STATE(2592),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5815),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5815),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5755),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1456),
    [sym_subscript_expression] = STATE(1456),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3029),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5815),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1456),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(594),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1506),
    [anon_sym_export] = ACTIONS(1234),
    [anon_sym_type] = ACTIONS(1234),
    [anon_sym_namespace] = ACTIONS(1236),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_typeof] = ACTIONS(1256),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1234),
    [anon_sym_BANG] = ACTIONS(1240),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(1242),
    [anon_sym_yield] = ACTIONS(1244),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1246),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1510),
    [anon_sym_using] = ACTIONS(1250),
    [anon_sym_PLUS] = ACTIONS(1256),
    [anon_sym_DASH] = ACTIONS(1256),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(1240),
    [anon_sym_void] = ACTIONS(1256),
    [anon_sym_delete] = ACTIONS(1256),
    [anon_sym_PLUS_PLUS] = ACTIONS(1258),
    [anon_sym_DASH_DASH] = ACTIONS(1258),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(1260),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1512),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1234),
    [anon_sym_readonly] = ACTIONS(1234),
    [anon_sym_get] = ACTIONS(1234),
    [anon_sym_set] = ACTIONS(1234),
    [anon_sym_declare] = ACTIONS(1234),
    [anon_sym_public] = ACTIONS(1234),
    [anon_sym_private] = ACTIONS(1234),
    [anon_sym_protected] = ACTIONS(1234),
    [anon_sym_override] = ACTIONS(1234),
    [anon_sym_module] = ACTIONS(1234),
    [anon_sym_any] = ACTIONS(1234),
    [anon_sym_number] = ACTIONS(1234),
    [anon_sym_boolean] = ACTIONS(1234),
    [anon_sym_string] = ACTIONS(1234),
    [anon_sym_symbol] = ACTIONS(1234),
    [anon_sym_object] = ACTIONS(1234),
    [sym_html_comment] = ACTIONS(5),
  },
  [397] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1398),
    [sym_expression] = STATE(1887),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5544),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5544),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5558),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1398),
    [sym_subscript_expression] = STATE(1398),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(2980),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5544),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1398),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(638),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1482),
    [anon_sym_export] = ACTIONS(1158),
    [anon_sym_type] = ACTIONS(1158),
    [anon_sym_namespace] = ACTIONS(1160),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_typeof] = ACTIONS(756),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1158),
    [anon_sym_BANG] = ACTIONS(732),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(736),
    [anon_sym_yield] = ACTIONS(738),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1164),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1486),
    [anon_sym_using] = ACTIONS(746),
    [anon_sym_PLUS] = ACTIONS(756),
    [anon_sym_DASH] = ACTIONS(756),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(732),
    [anon_sym_void] = ACTIONS(756),
    [anon_sym_delete] = ACTIONS(756),
    [anon_sym_PLUS_PLUS] = ACTIONS(758),
    [anon_sym_DASH_DASH] = ACTIONS(758),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(764),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1488),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1158),
    [anon_sym_readonly] = ACTIONS(1158),
    [anon_sym_get] = ACTIONS(1158),
    [anon_sym_set] = ACTIONS(1158),
    [anon_sym_declare] = ACTIONS(1158),
    [anon_sym_public] = ACTIONS(1158),
    [anon_sym_private] = ACTIONS(1158),
    [anon_sym_protected] = ACTIONS(1158),
    [anon_sym_override] = ACTIONS(1158),
    [anon_sym_module] = ACTIONS(1158),
    [anon_sym_any] = ACTIONS(1158),
    [anon_sym_number] = ACTIONS(1158),
    [anon_sym_boolean] = ACTIONS(1158),
    [anon_sym_string] = ACTIONS(1158),
    [anon_sym_symbol] = ACTIONS(1158),
    [anon_sym_object] = ACTIONS(1158),
    [sym_html_comment] = ACTIONS(5),
  },
  [398] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1398),
    [sym_expression] = STATE(1891),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5544),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5544),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5558),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1398),
    [sym_subscript_expression] = STATE(1398),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(2980),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5544),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1398),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(638),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1482),
    [anon_sym_export] = ACTIONS(1158),
    [anon_sym_type] = ACTIONS(1158),
    [anon_sym_namespace] = ACTIONS(1160),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_typeof] = ACTIONS(756),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1158),
    [anon_sym_BANG] = ACTIONS(732),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(736),
    [anon_sym_yield] = ACTIONS(738),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1164),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1486),
    [anon_sym_using] = ACTIONS(746),
    [anon_sym_PLUS] = ACTIONS(756),
    [anon_sym_DASH] = ACTIONS(756),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(732),
    [anon_sym_void] = ACTIONS(756),
    [anon_sym_delete] = ACTIONS(756),
    [anon_sym_PLUS_PLUS] = ACTIONS(758),
    [anon_sym_DASH_DASH] = ACTIONS(758),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(764),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1488),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1158),
    [anon_sym_readonly] = ACTIONS(1158),
    [anon_sym_get] = ACTIONS(1158),
    [anon_sym_set] = ACTIONS(1158),
    [anon_sym_declare] = ACTIONS(1158),
    [anon_sym_public] = ACTIONS(1158),
    [anon_sym_private] = ACTIONS(1158),
    [anon_sym_protected] = ACTIONS(1158),
    [anon_sym_override] = ACTIONS(1158),
    [anon_sym_module] = ACTIONS(1158),
    [anon_sym_any] = ACTIONS(1158),
    [anon_sym_number] = ACTIONS(1158),
    [anon_sym_boolean] = ACTIONS(1158),
    [anon_sym_string] = ACTIONS(1158),
    [anon_sym_symbol] = ACTIONS(1158),
    [anon_sym_object] = ACTIONS(1158),
    [sym_html_comment] = ACTIONS(5),
  },
  [399] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1398),
    [sym_expression] = STATE(1895),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5544),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5544),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5558),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1398),
    [sym_subscript_expression] = STATE(1398),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(2980),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5544),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1398),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(638),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1482),
    [anon_sym_export] = ACTIONS(1158),
    [anon_sym_type] = ACTIONS(1158),
    [anon_sym_namespace] = ACTIONS(1160),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_typeof] = ACTIONS(756),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1158),
    [anon_sym_BANG] = ACTIONS(732),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(736),
    [anon_sym_yield] = ACTIONS(738),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1164),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1486),
    [anon_sym_using] = ACTIONS(746),
    [anon_sym_PLUS] = ACTIONS(756),
    [anon_sym_DASH] = ACTIONS(756),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(732),
    [anon_sym_void] = ACTIONS(756),
    [anon_sym_delete] = ACTIONS(756),
    [anon_sym_PLUS_PLUS] = ACTIONS(758),
    [anon_sym_DASH_DASH] = ACTIONS(758),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(764),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1488),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1158),
    [anon_sym_readonly] = ACTIONS(1158),
    [anon_sym_get] = ACTIONS(1158),
    [anon_sym_set] = ACTIONS(1158),
    [anon_sym_declare] = ACTIONS(1158),
    [anon_sym_public] = ACTIONS(1158),
    [anon_sym_private] = ACTIONS(1158),
    [anon_sym_protected] = ACTIONS(1158),
    [anon_sym_override] = ACTIONS(1158),
    [anon_sym_module] = ACTIONS(1158),
    [anon_sym_any] = ACTIONS(1158),
    [anon_sym_number] = ACTIONS(1158),
    [anon_sym_boolean] = ACTIONS(1158),
    [anon_sym_string] = ACTIONS(1158),
    [anon_sym_symbol] = ACTIONS(1158),
    [anon_sym_object] = ACTIONS(1158),
    [sym_html_comment] = ACTIONS(5),
  },
  [400] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1398),
    [sym_expression] = STATE(2467),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5544),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5544),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5558),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1398),
    [sym_subscript_expression] = STATE(1398),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(2980),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5544),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1398),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(638),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1482),
    [anon_sym_export] = ACTIONS(1158),
    [anon_sym_type] = ACTIONS(1158),
    [anon_sym_namespace] = ACTIONS(1160),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_typeof] = ACTIONS(756),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1158),
    [anon_sym_BANG] = ACTIONS(732),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(736),
    [anon_sym_yield] = ACTIONS(738),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1164),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1486),
    [anon_sym_using] = ACTIONS(746),
    [anon_sym_PLUS] = ACTIONS(756),
    [anon_sym_DASH] = ACTIONS(756),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(732),
    [anon_sym_void] = ACTIONS(756),
    [anon_sym_delete] = ACTIONS(756),
    [anon_sym_PLUS_PLUS] = ACTIONS(758),
    [anon_sym_DASH_DASH] = ACTIONS(758),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(764),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1488),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1158),
    [anon_sym_readonly] = ACTIONS(1158),
    [anon_sym_get] = ACTIONS(1158),
    [anon_sym_set] = ACTIONS(1158),
    [anon_sym_declare] = ACTIONS(1158),
    [anon_sym_public] = ACTIONS(1158),
    [anon_sym_private] = ACTIONS(1158),
    [anon_sym_protected] = ACTIONS(1158),
    [anon_sym_override] = ACTIONS(1158),
    [anon_sym_module] = ACTIONS(1158),
    [anon_sym_any] = ACTIONS(1158),
    [anon_sym_number] = ACTIONS(1158),
    [anon_sym_boolean] = ACTIONS(1158),
    [anon_sym_string] = ACTIONS(1158),
    [anon_sym_symbol] = ACTIONS(1158),
    [anon_sym_object] = ACTIONS(1158),
    [sym_html_comment] = ACTIONS(5),
  },
  [401] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1398),
    [sym_expression] = STATE(1896),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5544),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5544),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5558),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1398),
    [sym_subscript_expression] = STATE(1398),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(2980),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5544),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1398),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(638),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1482),
    [anon_sym_export] = ACTIONS(1158),
    [anon_sym_type] = ACTIONS(1158),
    [anon_sym_namespace] = ACTIONS(1160),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_typeof] = ACTIONS(756),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1158),
    [anon_sym_BANG] = ACTIONS(732),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(736),
    [anon_sym_yield] = ACTIONS(738),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1164),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1486),
    [anon_sym_using] = ACTIONS(746),
    [anon_sym_PLUS] = ACTIONS(756),
    [anon_sym_DASH] = ACTIONS(756),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(732),
    [anon_sym_void] = ACTIONS(756),
    [anon_sym_delete] = ACTIONS(756),
    [anon_sym_PLUS_PLUS] = ACTIONS(758),
    [anon_sym_DASH_DASH] = ACTIONS(758),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(764),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1488),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1158),
    [anon_sym_readonly] = ACTIONS(1158),
    [anon_sym_get] = ACTIONS(1158),
    [anon_sym_set] = ACTIONS(1158),
    [anon_sym_declare] = ACTIONS(1158),
    [anon_sym_public] = ACTIONS(1158),
    [anon_sym_private] = ACTIONS(1158),
    [anon_sym_protected] = ACTIONS(1158),
    [anon_sym_override] = ACTIONS(1158),
    [anon_sym_module] = ACTIONS(1158),
    [anon_sym_any] = ACTIONS(1158),
    [anon_sym_number] = ACTIONS(1158),
    [anon_sym_boolean] = ACTIONS(1158),
    [anon_sym_string] = ACTIONS(1158),
    [anon_sym_symbol] = ACTIONS(1158),
    [anon_sym_object] = ACTIONS(1158),
    [sym_html_comment] = ACTIONS(5),
  },
  [402] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1398),
    [sym_expression] = STATE(1897),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5544),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5544),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5558),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1398),
    [sym_subscript_expression] = STATE(1398),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(2980),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5544),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1398),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(638),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1482),
    [anon_sym_export] = ACTIONS(1158),
    [anon_sym_type] = ACTIONS(1158),
    [anon_sym_namespace] = ACTIONS(1160),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_typeof] = ACTIONS(756),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1158),
    [anon_sym_BANG] = ACTIONS(732),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(736),
    [anon_sym_yield] = ACTIONS(738),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1164),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1486),
    [anon_sym_using] = ACTIONS(746),
    [anon_sym_PLUS] = ACTIONS(756),
    [anon_sym_DASH] = ACTIONS(756),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(732),
    [anon_sym_void] = ACTIONS(756),
    [anon_sym_delete] = ACTIONS(756),
    [anon_sym_PLUS_PLUS] = ACTIONS(758),
    [anon_sym_DASH_DASH] = ACTIONS(758),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(764),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1488),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1158),
    [anon_sym_readonly] = ACTIONS(1158),
    [anon_sym_get] = ACTIONS(1158),
    [anon_sym_set] = ACTIONS(1158),
    [anon_sym_declare] = ACTIONS(1158),
    [anon_sym_public] = ACTIONS(1158),
    [anon_sym_private] = ACTIONS(1158),
    [anon_sym_protected] = ACTIONS(1158),
    [anon_sym_override] = ACTIONS(1158),
    [anon_sym_module] = ACTIONS(1158),
    [anon_sym_any] = ACTIONS(1158),
    [anon_sym_number] = ACTIONS(1158),
    [anon_sym_boolean] = ACTIONS(1158),
    [anon_sym_string] = ACTIONS(1158),
    [anon_sym_symbol] = ACTIONS(1158),
    [anon_sym_object] = ACTIONS(1158),
    [sym_html_comment] = ACTIONS(5),
  },
  [403] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1398),
    [sym_expression] = STATE(1898),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5544),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5544),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5558),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1398),
    [sym_subscript_expression] = STATE(1398),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(2980),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5544),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1398),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(638),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1482),
    [anon_sym_export] = ACTIONS(1158),
    [anon_sym_type] = ACTIONS(1158),
    [anon_sym_namespace] = ACTIONS(1160),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_typeof] = ACTIONS(756),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1158),
    [anon_sym_BANG] = ACTIONS(732),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(736),
    [anon_sym_yield] = ACTIONS(738),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1164),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1486),
    [anon_sym_using] = ACTIONS(746),
    [anon_sym_PLUS] = ACTIONS(756),
    [anon_sym_DASH] = ACTIONS(756),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(732),
    [anon_sym_void] = ACTIONS(756),
    [anon_sym_delete] = ACTIONS(756),
    [anon_sym_PLUS_PLUS] = ACTIONS(758),
    [anon_sym_DASH_DASH] = ACTIONS(758),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(764),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1488),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1158),
    [anon_sym_readonly] = ACTIONS(1158),
    [anon_sym_get] = ACTIONS(1158),
    [anon_sym_set] = ACTIONS(1158),
    [anon_sym_declare] = ACTIONS(1158),
    [anon_sym_public] = ACTIONS(1158),
    [anon_sym_private] = ACTIONS(1158),
    [anon_sym_protected] = ACTIONS(1158),
    [anon_sym_override] = ACTIONS(1158),
    [anon_sym_module] = ACTIONS(1158),
    [anon_sym_any] = ACTIONS(1158),
    [anon_sym_number] = ACTIONS(1158),
    [anon_sym_boolean] = ACTIONS(1158),
    [anon_sym_string] = ACTIONS(1158),
    [anon_sym_symbol] = ACTIONS(1158),
    [anon_sym_object] = ACTIONS(1158),
    [sym_html_comment] = ACTIONS(5),
  },
  [404] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1398),
    [sym_expression] = STATE(1899),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5544),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5544),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5558),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1398),
    [sym_subscript_expression] = STATE(1398),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(2980),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5544),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1398),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(638),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1482),
    [anon_sym_export] = ACTIONS(1158),
    [anon_sym_type] = ACTIONS(1158),
    [anon_sym_namespace] = ACTIONS(1160),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_typeof] = ACTIONS(756),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1158),
    [anon_sym_BANG] = ACTIONS(732),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(736),
    [anon_sym_yield] = ACTIONS(738),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1164),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1486),
    [anon_sym_using] = ACTIONS(746),
    [anon_sym_PLUS] = ACTIONS(756),
    [anon_sym_DASH] = ACTIONS(756),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(732),
    [anon_sym_void] = ACTIONS(756),
    [anon_sym_delete] = ACTIONS(756),
    [anon_sym_PLUS_PLUS] = ACTIONS(758),
    [anon_sym_DASH_DASH] = ACTIONS(758),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(764),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1488),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1158),
    [anon_sym_readonly] = ACTIONS(1158),
    [anon_sym_get] = ACTIONS(1158),
    [anon_sym_set] = ACTIONS(1158),
    [anon_sym_declare] = ACTIONS(1158),
    [anon_sym_public] = ACTIONS(1158),
    [anon_sym_private] = ACTIONS(1158),
    [anon_sym_protected] = ACTIONS(1158),
    [anon_sym_override] = ACTIONS(1158),
    [anon_sym_module] = ACTIONS(1158),
    [anon_sym_any] = ACTIONS(1158),
    [anon_sym_number] = ACTIONS(1158),
    [anon_sym_boolean] = ACTIONS(1158),
    [anon_sym_string] = ACTIONS(1158),
    [anon_sym_symbol] = ACTIONS(1158),
    [anon_sym_object] = ACTIONS(1158),
    [sym_html_comment] = ACTIONS(5),
  },
  [405] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1398),
    [sym_expression] = STATE(1900),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5544),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5544),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5558),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1398),
    [sym_subscript_expression] = STATE(1398),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(2980),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5544),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1398),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(638),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1482),
    [anon_sym_export] = ACTIONS(1158),
    [anon_sym_type] = ACTIONS(1158),
    [anon_sym_namespace] = ACTIONS(1160),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_typeof] = ACTIONS(756),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1158),
    [anon_sym_BANG] = ACTIONS(732),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(736),
    [anon_sym_yield] = ACTIONS(738),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1164),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1486),
    [anon_sym_using] = ACTIONS(746),
    [anon_sym_PLUS] = ACTIONS(756),
    [anon_sym_DASH] = ACTIONS(756),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(732),
    [anon_sym_void] = ACTIONS(756),
    [anon_sym_delete] = ACTIONS(756),
    [anon_sym_PLUS_PLUS] = ACTIONS(758),
    [anon_sym_DASH_DASH] = ACTIONS(758),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(764),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1488),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1158),
    [anon_sym_readonly] = ACTIONS(1158),
    [anon_sym_get] = ACTIONS(1158),
    [anon_sym_set] = ACTIONS(1158),
    [anon_sym_declare] = ACTIONS(1158),
    [anon_sym_public] = ACTIONS(1158),
    [anon_sym_private] = ACTIONS(1158),
    [anon_sym_protected] = ACTIONS(1158),
    [anon_sym_override] = ACTIONS(1158),
    [anon_sym_module] = ACTIONS(1158),
    [anon_sym_any] = ACTIONS(1158),
    [anon_sym_number] = ACTIONS(1158),
    [anon_sym_boolean] = ACTIONS(1158),
    [anon_sym_string] = ACTIONS(1158),
    [anon_sym_symbol] = ACTIONS(1158),
    [anon_sym_object] = ACTIONS(1158),
    [sym_html_comment] = ACTIONS(5),
  },
  [406] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1398),
    [sym_expression] = STATE(1901),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5544),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5544),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5558),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1398),
    [sym_subscript_expression] = STATE(1398),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(2980),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5544),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1398),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(638),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1482),
    [anon_sym_export] = ACTIONS(1158),
    [anon_sym_type] = ACTIONS(1158),
    [anon_sym_namespace] = ACTIONS(1160),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_typeof] = ACTIONS(756),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1158),
    [anon_sym_BANG] = ACTIONS(732),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(736),
    [anon_sym_yield] = ACTIONS(738),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1164),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1486),
    [anon_sym_using] = ACTIONS(746),
    [anon_sym_PLUS] = ACTIONS(756),
    [anon_sym_DASH] = ACTIONS(756),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(732),
    [anon_sym_void] = ACTIONS(756),
    [anon_sym_delete] = ACTIONS(756),
    [anon_sym_PLUS_PLUS] = ACTIONS(758),
    [anon_sym_DASH_DASH] = ACTIONS(758),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(764),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1488),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1158),
    [anon_sym_readonly] = ACTIONS(1158),
    [anon_sym_get] = ACTIONS(1158),
    [anon_sym_set] = ACTIONS(1158),
    [anon_sym_declare] = ACTIONS(1158),
    [anon_sym_public] = ACTIONS(1158),
    [anon_sym_private] = ACTIONS(1158),
    [anon_sym_protected] = ACTIONS(1158),
    [anon_sym_override] = ACTIONS(1158),
    [anon_sym_module] = ACTIONS(1158),
    [anon_sym_any] = ACTIONS(1158),
    [anon_sym_number] = ACTIONS(1158),
    [anon_sym_boolean] = ACTIONS(1158),
    [anon_sym_string] = ACTIONS(1158),
    [anon_sym_symbol] = ACTIONS(1158),
    [anon_sym_object] = ACTIONS(1158),
    [sym_html_comment] = ACTIONS(5),
  },
  [407] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1398),
    [sym_expression] = STATE(1903),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5544),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5544),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5558),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1398),
    [sym_subscript_expression] = STATE(1398),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(2980),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5544),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1398),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(638),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1482),
    [anon_sym_export] = ACTIONS(1158),
    [anon_sym_type] = ACTIONS(1158),
    [anon_sym_namespace] = ACTIONS(1160),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_typeof] = ACTIONS(756),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1158),
    [anon_sym_BANG] = ACTIONS(732),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(736),
    [anon_sym_yield] = ACTIONS(738),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1164),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1486),
    [anon_sym_using] = ACTIONS(746),
    [anon_sym_PLUS] = ACTIONS(756),
    [anon_sym_DASH] = ACTIONS(756),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(732),
    [anon_sym_void] = ACTIONS(756),
    [anon_sym_delete] = ACTIONS(756),
    [anon_sym_PLUS_PLUS] = ACTIONS(758),
    [anon_sym_DASH_DASH] = ACTIONS(758),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(764),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1488),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1158),
    [anon_sym_readonly] = ACTIONS(1158),
    [anon_sym_get] = ACTIONS(1158),
    [anon_sym_set] = ACTIONS(1158),
    [anon_sym_declare] = ACTIONS(1158),
    [anon_sym_public] = ACTIONS(1158),
    [anon_sym_private] = ACTIONS(1158),
    [anon_sym_protected] = ACTIONS(1158),
    [anon_sym_override] = ACTIONS(1158),
    [anon_sym_module] = ACTIONS(1158),
    [anon_sym_any] = ACTIONS(1158),
    [anon_sym_number] = ACTIONS(1158),
    [anon_sym_boolean] = ACTIONS(1158),
    [anon_sym_string] = ACTIONS(1158),
    [anon_sym_symbol] = ACTIONS(1158),
    [anon_sym_object] = ACTIONS(1158),
    [sym_html_comment] = ACTIONS(5),
  },
  [408] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1398),
    [sym_expression] = STATE(1904),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5544),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5544),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5558),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1398),
    [sym_subscript_expression] = STATE(1398),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(2980),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5544),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1398),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(638),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1482),
    [anon_sym_export] = ACTIONS(1158),
    [anon_sym_type] = ACTIONS(1158),
    [anon_sym_namespace] = ACTIONS(1160),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_typeof] = ACTIONS(756),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1158),
    [anon_sym_BANG] = ACTIONS(732),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(736),
    [anon_sym_yield] = ACTIONS(738),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1164),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1486),
    [anon_sym_using] = ACTIONS(746),
    [anon_sym_PLUS] = ACTIONS(756),
    [anon_sym_DASH] = ACTIONS(756),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(732),
    [anon_sym_void] = ACTIONS(756),
    [anon_sym_delete] = ACTIONS(756),
    [anon_sym_PLUS_PLUS] = ACTIONS(758),
    [anon_sym_DASH_DASH] = ACTIONS(758),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(764),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1488),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1158),
    [anon_sym_readonly] = ACTIONS(1158),
    [anon_sym_get] = ACTIONS(1158),
    [anon_sym_set] = ACTIONS(1158),
    [anon_sym_declare] = ACTIONS(1158),
    [anon_sym_public] = ACTIONS(1158),
    [anon_sym_private] = ACTIONS(1158),
    [anon_sym_protected] = ACTIONS(1158),
    [anon_sym_override] = ACTIONS(1158),
    [anon_sym_module] = ACTIONS(1158),
    [anon_sym_any] = ACTIONS(1158),
    [anon_sym_number] = ACTIONS(1158),
    [anon_sym_boolean] = ACTIONS(1158),
    [anon_sym_string] = ACTIONS(1158),
    [anon_sym_symbol] = ACTIONS(1158),
    [anon_sym_object] = ACTIONS(1158),
    [sym_html_comment] = ACTIONS(5),
  },
  [409] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1398),
    [sym_expression] = STATE(1906),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5544),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5544),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5558),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1398),
    [sym_subscript_expression] = STATE(1398),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(2980),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5544),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1398),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(638),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1482),
    [anon_sym_export] = ACTIONS(1158),
    [anon_sym_type] = ACTIONS(1158),
    [anon_sym_namespace] = ACTIONS(1160),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_typeof] = ACTIONS(756),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1158),
    [anon_sym_BANG] = ACTIONS(732),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(736),
    [anon_sym_yield] = ACTIONS(738),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1164),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1486),
    [anon_sym_using] = ACTIONS(746),
    [anon_sym_PLUS] = ACTIONS(756),
    [anon_sym_DASH] = ACTIONS(756),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(732),
    [anon_sym_void] = ACTIONS(756),
    [anon_sym_delete] = ACTIONS(756),
    [anon_sym_PLUS_PLUS] = ACTIONS(758),
    [anon_sym_DASH_DASH] = ACTIONS(758),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(764),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1488),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1158),
    [anon_sym_readonly] = ACTIONS(1158),
    [anon_sym_get] = ACTIONS(1158),
    [anon_sym_set] = ACTIONS(1158),
    [anon_sym_declare] = ACTIONS(1158),
    [anon_sym_public] = ACTIONS(1158),
    [anon_sym_private] = ACTIONS(1158),
    [anon_sym_protected] = ACTIONS(1158),
    [anon_sym_override] = ACTIONS(1158),
    [anon_sym_module] = ACTIONS(1158),
    [anon_sym_any] = ACTIONS(1158),
    [anon_sym_number] = ACTIONS(1158),
    [anon_sym_boolean] = ACTIONS(1158),
    [anon_sym_string] = ACTIONS(1158),
    [anon_sym_symbol] = ACTIONS(1158),
    [anon_sym_object] = ACTIONS(1158),
    [sym_html_comment] = ACTIONS(5),
  },
  [410] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1398),
    [sym_expression] = STATE(1908),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5544),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5544),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5558),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1398),
    [sym_subscript_expression] = STATE(1398),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(2980),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5544),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1398),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(638),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1482),
    [anon_sym_export] = ACTIONS(1158),
    [anon_sym_type] = ACTIONS(1158),
    [anon_sym_namespace] = ACTIONS(1160),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_typeof] = ACTIONS(756),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1158),
    [anon_sym_BANG] = ACTIONS(732),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(736),
    [anon_sym_yield] = ACTIONS(738),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1164),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1486),
    [anon_sym_using] = ACTIONS(746),
    [anon_sym_PLUS] = ACTIONS(756),
    [anon_sym_DASH] = ACTIONS(756),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(732),
    [anon_sym_void] = ACTIONS(756),
    [anon_sym_delete] = ACTIONS(756),
    [anon_sym_PLUS_PLUS] = ACTIONS(758),
    [anon_sym_DASH_DASH] = ACTIONS(758),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(764),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1488),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1158),
    [anon_sym_readonly] = ACTIONS(1158),
    [anon_sym_get] = ACTIONS(1158),
    [anon_sym_set] = ACTIONS(1158),
    [anon_sym_declare] = ACTIONS(1158),
    [anon_sym_public] = ACTIONS(1158),
    [anon_sym_private] = ACTIONS(1158),
    [anon_sym_protected] = ACTIONS(1158),
    [anon_sym_override] = ACTIONS(1158),
    [anon_sym_module] = ACTIONS(1158),
    [anon_sym_any] = ACTIONS(1158),
    [anon_sym_number] = ACTIONS(1158),
    [anon_sym_boolean] = ACTIONS(1158),
    [anon_sym_string] = ACTIONS(1158),
    [anon_sym_symbol] = ACTIONS(1158),
    [anon_sym_object] = ACTIONS(1158),
    [sym_html_comment] = ACTIONS(5),
  },
  [411] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1398),
    [sym_expression] = STATE(1914),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5544),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5544),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5558),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1398),
    [sym_subscript_expression] = STATE(1398),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(2980),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5544),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1398),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(638),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1482),
    [anon_sym_export] = ACTIONS(1158),
    [anon_sym_type] = ACTIONS(1158),
    [anon_sym_namespace] = ACTIONS(1160),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_typeof] = ACTIONS(756),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1158),
    [anon_sym_BANG] = ACTIONS(732),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(736),
    [anon_sym_yield] = ACTIONS(738),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1164),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1486),
    [anon_sym_using] = ACTIONS(746),
    [anon_sym_PLUS] = ACTIONS(756),
    [anon_sym_DASH] = ACTIONS(756),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(732),
    [anon_sym_void] = ACTIONS(756),
    [anon_sym_delete] = ACTIONS(756),
    [anon_sym_PLUS_PLUS] = ACTIONS(758),
    [anon_sym_DASH_DASH] = ACTIONS(758),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(764),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1488),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1158),
    [anon_sym_readonly] = ACTIONS(1158),
    [anon_sym_get] = ACTIONS(1158),
    [anon_sym_set] = ACTIONS(1158),
    [anon_sym_declare] = ACTIONS(1158),
    [anon_sym_public] = ACTIONS(1158),
    [anon_sym_private] = ACTIONS(1158),
    [anon_sym_protected] = ACTIONS(1158),
    [anon_sym_override] = ACTIONS(1158),
    [anon_sym_module] = ACTIONS(1158),
    [anon_sym_any] = ACTIONS(1158),
    [anon_sym_number] = ACTIONS(1158),
    [anon_sym_boolean] = ACTIONS(1158),
    [anon_sym_string] = ACTIONS(1158),
    [anon_sym_symbol] = ACTIONS(1158),
    [anon_sym_object] = ACTIONS(1158),
    [sym_html_comment] = ACTIONS(5),
  },
  [412] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1398),
    [sym_expression] = STATE(2386),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5544),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5544),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5558),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1398),
    [sym_subscript_expression] = STATE(1398),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(2980),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5544),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1398),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(638),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1482),
    [anon_sym_export] = ACTIONS(1158),
    [anon_sym_type] = ACTIONS(1158),
    [anon_sym_namespace] = ACTIONS(1160),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_typeof] = ACTIONS(756),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1158),
    [anon_sym_BANG] = ACTIONS(732),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(736),
    [anon_sym_yield] = ACTIONS(738),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1164),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1486),
    [anon_sym_using] = ACTIONS(746),
    [anon_sym_PLUS] = ACTIONS(756),
    [anon_sym_DASH] = ACTIONS(756),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(732),
    [anon_sym_void] = ACTIONS(756),
    [anon_sym_delete] = ACTIONS(756),
    [anon_sym_PLUS_PLUS] = ACTIONS(758),
    [anon_sym_DASH_DASH] = ACTIONS(758),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(764),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1488),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1158),
    [anon_sym_readonly] = ACTIONS(1158),
    [anon_sym_get] = ACTIONS(1158),
    [anon_sym_set] = ACTIONS(1158),
    [anon_sym_declare] = ACTIONS(1158),
    [anon_sym_public] = ACTIONS(1158),
    [anon_sym_private] = ACTIONS(1158),
    [anon_sym_protected] = ACTIONS(1158),
    [anon_sym_override] = ACTIONS(1158),
    [anon_sym_module] = ACTIONS(1158),
    [anon_sym_any] = ACTIONS(1158),
    [anon_sym_number] = ACTIONS(1158),
    [anon_sym_boolean] = ACTIONS(1158),
    [anon_sym_string] = ACTIONS(1158),
    [anon_sym_symbol] = ACTIONS(1158),
    [anon_sym_object] = ACTIONS(1158),
    [sym_html_comment] = ACTIONS(5),
  },
  [413] = {
    [sym_import] = STATE(3636),
    [sym_parenthesized_expression] = STATE(1362),
    [sym_expression] = STATE(1940),
    [sym_primary_expression] = STATE(1810),
    [sym_yield_expression] = STATE(2358),
    [sym_object] = STATE(2222),
    [sym_object_pattern] = STATE(5492),
    [sym_array] = STATE(2222),
    [sym_array_pattern] = STATE(5492),
    [sym_class] = STATE(2222),
    [sym_function_expression] = STATE(2222),
    [sym_generator_function] = STATE(2222),
    [sym_arrow_function] = STATE(2222),
    [sym__call_signature] = STATE(5821),
    [sym_call_expression] = STATE(2222),
    [sym_new_expression] = STATE(1948),
    [sym_await_expression] = STATE(2358),
    [sym_member_expression] = STATE(1362),
    [sym_subscript_expression] = STATE(1362),
    [sym_assignment_expression] = STATE(2358),
    [sym__augmented_assignment_lhs] = STATE(3025),
    [sym_augmented_assignment_expression] = STATE(2358),
    [sym__destructuring_pattern] = STATE(5492),
    [sym_ternary_expression] = STATE(2358),
    [sym_binary_expression] = STATE(2358),
    [sym_unary_expression] = STATE(2358),
    [sym_update_expression] = STATE(2358),
    [sym_string] = STATE(2222),
    [sym_template_string] = STATE(2222),
    [sym_regex] = STATE(2222),
    [sym_meta_property] = STATE(2222),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1362),
    [sym_type_assertion] = STATE(2358),
    [sym_as_expression] = STATE(2358),
    [sym_satisfies_expression] = STATE(2358),
    [sym_instantiation_expression] = STATE(2358),
    [sym_internal_module] = STATE(2358),
    [sym_type_arguments] = STATE(428),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4408),
    [sym_identifier] = ACTIONS(1468),
    [anon_sym_export] = ACTIONS(1352),
    [anon_sym_type] = ACTIONS(1352),
    [anon_sym_namespace] = ACTIONS(1354),
    [anon_sym_LBRACE] = ACTIONS(665),
    [anon_sym_typeof] = ACTIONS(21),
    [anon_sym_import] = ACTIONS(669),
    [anon_sym_let] = ACTIONS(1352),
    [anon_sym_BANG] = ACTIONS(33),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_await] = ACTIONS(45),
    [anon_sym_yield] = ACTIONS(63),
    [anon_sym_LBRACK] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(676),
    [anon_sym_async] = ACTIONS(1362),
    [anon_sym_function] = ACTIONS(680),
    [anon_sym_new] = ACTIONS(1472),
    [anon_sym_using] = ACTIONS(75),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_SLASH] = ACTIONS(77),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(33),
    [anon_sym_void] = ACTIONS(21),
    [anon_sym_delete] = ACTIONS(21),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_DQUOTE] = ACTIONS(83),
    [anon_sym_SQUOTE] = ACTIONS(85),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(87),
    [sym_number] = ACTIONS(89),
    [sym_private_property_identifier] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(93),
    [sym_true] = ACTIONS(93),
    [sym_false] = ACTIONS(93),
    [sym_null] = ACTIONS(93),
    [sym_undefined] = ACTIONS(95),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1352),
    [anon_sym_readonly] = ACTIONS(1352),
    [anon_sym_get] = ACTIONS(1352),
    [anon_sym_set] = ACTIONS(1352),
    [anon_sym_declare] = ACTIONS(1352),
    [anon_sym_public] = ACTIONS(1352),
    [anon_sym_private] = ACTIONS(1352),
    [anon_sym_protected] = ACTIONS(1352),
    [anon_sym_override] = ACTIONS(1352),
    [anon_sym_module] = ACTIONS(1352),
    [anon_sym_any] = ACTIONS(1352),
    [anon_sym_number] = ACTIONS(1352),
    [anon_sym_boolean] = ACTIONS(1352),
    [anon_sym_string] = ACTIONS(1352),
    [anon_sym_symbol] = ACTIONS(1352),
    [anon_sym_object] = ACTIONS(1352),
    [sym_html_comment] = ACTIONS(5),
  },
  [414] = {
    [sym_import] = STATE(3636),
    [sym_parenthesized_expression] = STATE(1362),
    [sym_expression] = STATE(2005),
    [sym_primary_expression] = STATE(1810),
    [sym_yield_expression] = STATE(2358),
    [sym_object] = STATE(2222),
    [sym_object_pattern] = STATE(5492),
    [sym_array] = STATE(2222),
    [sym_array_pattern] = STATE(5492),
    [sym_class] = STATE(2222),
    [sym_function_expression] = STATE(2222),
    [sym_generator_function] = STATE(2222),
    [sym_arrow_function] = STATE(2222),
    [sym__call_signature] = STATE(5821),
    [sym_call_expression] = STATE(2222),
    [sym_new_expression] = STATE(1948),
    [sym_await_expression] = STATE(2358),
    [sym_member_expression] = STATE(1362),
    [sym_subscript_expression] = STATE(1362),
    [sym_assignment_expression] = STATE(2358),
    [sym__augmented_assignment_lhs] = STATE(3025),
    [sym_augmented_assignment_expression] = STATE(2358),
    [sym__destructuring_pattern] = STATE(5492),
    [sym_ternary_expression] = STATE(2358),
    [sym_binary_expression] = STATE(2358),
    [sym_unary_expression] = STATE(2358),
    [sym_update_expression] = STATE(2358),
    [sym_string] = STATE(2222),
    [sym_template_string] = STATE(2222),
    [sym_regex] = STATE(2222),
    [sym_meta_property] = STATE(2222),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1362),
    [sym_type_assertion] = STATE(2358),
    [sym_as_expression] = STATE(2358),
    [sym_satisfies_expression] = STATE(2358),
    [sym_instantiation_expression] = STATE(2358),
    [sym_internal_module] = STATE(2358),
    [sym_type_arguments] = STATE(428),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4408),
    [sym_identifier] = ACTIONS(1468),
    [anon_sym_export] = ACTIONS(1352),
    [anon_sym_type] = ACTIONS(1352),
    [anon_sym_namespace] = ACTIONS(1354),
    [anon_sym_LBRACE] = ACTIONS(665),
    [anon_sym_typeof] = ACTIONS(21),
    [anon_sym_import] = ACTIONS(669),
    [anon_sym_let] = ACTIONS(1352),
    [anon_sym_BANG] = ACTIONS(33),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_await] = ACTIONS(45),
    [anon_sym_yield] = ACTIONS(63),
    [anon_sym_LBRACK] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(676),
    [anon_sym_async] = ACTIONS(1362),
    [anon_sym_function] = ACTIONS(680),
    [anon_sym_new] = ACTIONS(1472),
    [anon_sym_using] = ACTIONS(75),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_SLASH] = ACTIONS(77),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(33),
    [anon_sym_void] = ACTIONS(21),
    [anon_sym_delete] = ACTIONS(21),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_DQUOTE] = ACTIONS(83),
    [anon_sym_SQUOTE] = ACTIONS(85),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(87),
    [sym_number] = ACTIONS(89),
    [sym_private_property_identifier] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(93),
    [sym_true] = ACTIONS(93),
    [sym_false] = ACTIONS(93),
    [sym_null] = ACTIONS(93),
    [sym_undefined] = ACTIONS(95),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1352),
    [anon_sym_readonly] = ACTIONS(1352),
    [anon_sym_get] = ACTIONS(1352),
    [anon_sym_set] = ACTIONS(1352),
    [anon_sym_declare] = ACTIONS(1352),
    [anon_sym_public] = ACTIONS(1352),
    [anon_sym_private] = ACTIONS(1352),
    [anon_sym_protected] = ACTIONS(1352),
    [anon_sym_override] = ACTIONS(1352),
    [anon_sym_module] = ACTIONS(1352),
    [anon_sym_any] = ACTIONS(1352),
    [anon_sym_number] = ACTIONS(1352),
    [anon_sym_boolean] = ACTIONS(1352),
    [anon_sym_string] = ACTIONS(1352),
    [anon_sym_symbol] = ACTIONS(1352),
    [anon_sym_object] = ACTIONS(1352),
    [sym_html_comment] = ACTIONS(5),
  },
  [415] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1398),
    [sym_expression] = STATE(1946),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5544),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5544),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5558),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1398),
    [sym_subscript_expression] = STATE(1398),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(2980),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5544),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1398),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(638),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1482),
    [anon_sym_export] = ACTIONS(1158),
    [anon_sym_type] = ACTIONS(1158),
    [anon_sym_namespace] = ACTIONS(1160),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_typeof] = ACTIONS(756),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1158),
    [anon_sym_BANG] = ACTIONS(732),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(736),
    [anon_sym_yield] = ACTIONS(738),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1164),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1486),
    [anon_sym_using] = ACTIONS(746),
    [anon_sym_PLUS] = ACTIONS(756),
    [anon_sym_DASH] = ACTIONS(756),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(732),
    [anon_sym_void] = ACTIONS(756),
    [anon_sym_delete] = ACTIONS(756),
    [anon_sym_PLUS_PLUS] = ACTIONS(758),
    [anon_sym_DASH_DASH] = ACTIONS(758),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(764),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1488),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1158),
    [anon_sym_readonly] = ACTIONS(1158),
    [anon_sym_get] = ACTIONS(1158),
    [anon_sym_set] = ACTIONS(1158),
    [anon_sym_declare] = ACTIONS(1158),
    [anon_sym_public] = ACTIONS(1158),
    [anon_sym_private] = ACTIONS(1158),
    [anon_sym_protected] = ACTIONS(1158),
    [anon_sym_override] = ACTIONS(1158),
    [anon_sym_module] = ACTIONS(1158),
    [anon_sym_any] = ACTIONS(1158),
    [anon_sym_number] = ACTIONS(1158),
    [anon_sym_boolean] = ACTIONS(1158),
    [anon_sym_string] = ACTIONS(1158),
    [anon_sym_symbol] = ACTIONS(1158),
    [anon_sym_object] = ACTIONS(1158),
    [sym_html_comment] = ACTIONS(5),
  },
  [416] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1398),
    [sym_expression] = STATE(1959),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5544),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5544),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5558),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1398),
    [sym_subscript_expression] = STATE(1398),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(2980),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5544),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1398),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(638),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1482),
    [anon_sym_export] = ACTIONS(1158),
    [anon_sym_type] = ACTIONS(1158),
    [anon_sym_namespace] = ACTIONS(1160),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_typeof] = ACTIONS(756),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1158),
    [anon_sym_BANG] = ACTIONS(732),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(736),
    [anon_sym_yield] = ACTIONS(738),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1164),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1486),
    [anon_sym_using] = ACTIONS(746),
    [anon_sym_PLUS] = ACTIONS(756),
    [anon_sym_DASH] = ACTIONS(756),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(732),
    [anon_sym_void] = ACTIONS(756),
    [anon_sym_delete] = ACTIONS(756),
    [anon_sym_PLUS_PLUS] = ACTIONS(758),
    [anon_sym_DASH_DASH] = ACTIONS(758),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(764),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1488),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1158),
    [anon_sym_readonly] = ACTIONS(1158),
    [anon_sym_get] = ACTIONS(1158),
    [anon_sym_set] = ACTIONS(1158),
    [anon_sym_declare] = ACTIONS(1158),
    [anon_sym_public] = ACTIONS(1158),
    [anon_sym_private] = ACTIONS(1158),
    [anon_sym_protected] = ACTIONS(1158),
    [anon_sym_override] = ACTIONS(1158),
    [anon_sym_module] = ACTIONS(1158),
    [anon_sym_any] = ACTIONS(1158),
    [anon_sym_number] = ACTIONS(1158),
    [anon_sym_boolean] = ACTIONS(1158),
    [anon_sym_string] = ACTIONS(1158),
    [anon_sym_symbol] = ACTIONS(1158),
    [anon_sym_object] = ACTIONS(1158),
    [sym_html_comment] = ACTIONS(5),
  },
  [417] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1457),
    [sym_expression] = STATE(2553),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5823),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5823),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5477),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1457),
    [sym_subscript_expression] = STATE(1457),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(2986),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5823),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1457),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(620),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1522),
    [anon_sym_export] = ACTIONS(1178),
    [anon_sym_type] = ACTIONS(1178),
    [anon_sym_namespace] = ACTIONS(1180),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_typeof] = ACTIONS(1202),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1178),
    [anon_sym_BANG] = ACTIONS(1186),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(1188),
    [anon_sym_yield] = ACTIONS(1190),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1192),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1526),
    [anon_sym_using] = ACTIONS(1196),
    [anon_sym_PLUS] = ACTIONS(1202),
    [anon_sym_DASH] = ACTIONS(1202),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(1186),
    [anon_sym_void] = ACTIONS(1202),
    [anon_sym_delete] = ACTIONS(1202),
    [anon_sym_PLUS_PLUS] = ACTIONS(1204),
    [anon_sym_DASH_DASH] = ACTIONS(1204),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(1206),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1528),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1178),
    [anon_sym_readonly] = ACTIONS(1178),
    [anon_sym_get] = ACTIONS(1178),
    [anon_sym_set] = ACTIONS(1178),
    [anon_sym_declare] = ACTIONS(1178),
    [anon_sym_public] = ACTIONS(1178),
    [anon_sym_private] = ACTIONS(1178),
    [anon_sym_protected] = ACTIONS(1178),
    [anon_sym_override] = ACTIONS(1178),
    [anon_sym_module] = ACTIONS(1178),
    [anon_sym_any] = ACTIONS(1178),
    [anon_sym_number] = ACTIONS(1178),
    [anon_sym_boolean] = ACTIONS(1178),
    [anon_sym_string] = ACTIONS(1178),
    [anon_sym_symbol] = ACTIONS(1178),
    [anon_sym_object] = ACTIONS(1178),
    [sym_html_comment] = ACTIONS(5),
  },
  [418] = {
    [sym_import] = STATE(3636),
    [sym_parenthesized_expression] = STATE(1362),
    [sym_expression] = STATE(1814),
    [sym_primary_expression] = STATE(1810),
    [sym_yield_expression] = STATE(2358),
    [sym_object] = STATE(2222),
    [sym_object_pattern] = STATE(5492),
    [sym_array] = STATE(2222),
    [sym_array_pattern] = STATE(5492),
    [sym_class] = STATE(2222),
    [sym_function_expression] = STATE(2222),
    [sym_generator_function] = STATE(2222),
    [sym_arrow_function] = STATE(2222),
    [sym__call_signature] = STATE(5821),
    [sym_call_expression] = STATE(2222),
    [sym_new_expression] = STATE(1948),
    [sym_await_expression] = STATE(2358),
    [sym_member_expression] = STATE(1362),
    [sym_subscript_expression] = STATE(1362),
    [sym_assignment_expression] = STATE(2358),
    [sym__augmented_assignment_lhs] = STATE(3025),
    [sym_augmented_assignment_expression] = STATE(2358),
    [sym__destructuring_pattern] = STATE(5492),
    [sym_ternary_expression] = STATE(2358),
    [sym_binary_expression] = STATE(2358),
    [sym_unary_expression] = STATE(2358),
    [sym_update_expression] = STATE(2358),
    [sym_string] = STATE(2222),
    [sym_template_string] = STATE(2222),
    [sym_regex] = STATE(2222),
    [sym_meta_property] = STATE(2222),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1362),
    [sym_type_assertion] = STATE(2358),
    [sym_as_expression] = STATE(2358),
    [sym_satisfies_expression] = STATE(2358),
    [sym_instantiation_expression] = STATE(2358),
    [sym_internal_module] = STATE(2358),
    [sym_type_arguments] = STATE(428),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4408),
    [sym_identifier] = ACTIONS(1468),
    [anon_sym_export] = ACTIONS(1352),
    [anon_sym_type] = ACTIONS(1352),
    [anon_sym_namespace] = ACTIONS(1354),
    [anon_sym_LBRACE] = ACTIONS(665),
    [anon_sym_typeof] = ACTIONS(21),
    [anon_sym_import] = ACTIONS(669),
    [anon_sym_let] = ACTIONS(1352),
    [anon_sym_BANG] = ACTIONS(33),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_await] = ACTIONS(45),
    [anon_sym_yield] = ACTIONS(63),
    [anon_sym_LBRACK] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(676),
    [anon_sym_async] = ACTIONS(1362),
    [anon_sym_function] = ACTIONS(680),
    [anon_sym_new] = ACTIONS(1472),
    [anon_sym_using] = ACTIONS(75),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_SLASH] = ACTIONS(77),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(33),
    [anon_sym_void] = ACTIONS(21),
    [anon_sym_delete] = ACTIONS(21),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_DQUOTE] = ACTIONS(83),
    [anon_sym_SQUOTE] = ACTIONS(85),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(87),
    [sym_number] = ACTIONS(2125),
    [sym_private_property_identifier] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(93),
    [sym_true] = ACTIONS(93),
    [sym_false] = ACTIONS(93),
    [sym_null] = ACTIONS(93),
    [sym_undefined] = ACTIONS(95),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1352),
    [anon_sym_readonly] = ACTIONS(1352),
    [anon_sym_get] = ACTIONS(1352),
    [anon_sym_set] = ACTIONS(1352),
    [anon_sym_declare] = ACTIONS(1352),
    [anon_sym_public] = ACTIONS(1352),
    [anon_sym_private] = ACTIONS(1352),
    [anon_sym_protected] = ACTIONS(1352),
    [anon_sym_override] = ACTIONS(1352),
    [anon_sym_module] = ACTIONS(1352),
    [anon_sym_any] = ACTIONS(1352),
    [anon_sym_number] = ACTIONS(1352),
    [anon_sym_boolean] = ACTIONS(1352),
    [anon_sym_string] = ACTIONS(1352),
    [anon_sym_symbol] = ACTIONS(1352),
    [anon_sym_object] = ACTIONS(1352),
    [sym_html_comment] = ACTIONS(5),
  },
  [419] = {
    [sym_import] = STATE(3636),
    [sym_parenthesized_expression] = STATE(1362),
    [sym_expression] = STATE(1943),
    [sym_primary_expression] = STATE(1810),
    [sym_yield_expression] = STATE(2358),
    [sym_object] = STATE(2222),
    [sym_object_pattern] = STATE(5492),
    [sym_array] = STATE(2222),
    [sym_array_pattern] = STATE(5492),
    [sym_class] = STATE(2222),
    [sym_function_expression] = STATE(2222),
    [sym_generator_function] = STATE(2222),
    [sym_arrow_function] = STATE(2222),
    [sym__call_signature] = STATE(5821),
    [sym_call_expression] = STATE(2222),
    [sym_new_expression] = STATE(1948),
    [sym_await_expression] = STATE(2358),
    [sym_member_expression] = STATE(1362),
    [sym_subscript_expression] = STATE(1362),
    [sym_assignment_expression] = STATE(2358),
    [sym__augmented_assignment_lhs] = STATE(3025),
    [sym_augmented_assignment_expression] = STATE(2358),
    [sym__destructuring_pattern] = STATE(5492),
    [sym_ternary_expression] = STATE(2358),
    [sym_binary_expression] = STATE(2358),
    [sym_unary_expression] = STATE(2358),
    [sym_update_expression] = STATE(2358),
    [sym_string] = STATE(2222),
    [sym_template_string] = STATE(2222),
    [sym_regex] = STATE(2222),
    [sym_meta_property] = STATE(2222),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1362),
    [sym_type_assertion] = STATE(2358),
    [sym_as_expression] = STATE(2358),
    [sym_satisfies_expression] = STATE(2358),
    [sym_instantiation_expression] = STATE(2358),
    [sym_internal_module] = STATE(2358),
    [sym_type_arguments] = STATE(428),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4408),
    [sym_identifier] = ACTIONS(1468),
    [anon_sym_export] = ACTIONS(1352),
    [anon_sym_type] = ACTIONS(1352),
    [anon_sym_namespace] = ACTIONS(1354),
    [anon_sym_LBRACE] = ACTIONS(665),
    [anon_sym_typeof] = ACTIONS(21),
    [anon_sym_import] = ACTIONS(669),
    [anon_sym_let] = ACTIONS(1352),
    [anon_sym_BANG] = ACTIONS(33),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_await] = ACTIONS(45),
    [anon_sym_yield] = ACTIONS(63),
    [anon_sym_LBRACK] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(676),
    [anon_sym_async] = ACTIONS(1362),
    [anon_sym_function] = ACTIONS(680),
    [anon_sym_new] = ACTIONS(1472),
    [anon_sym_using] = ACTIONS(75),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_SLASH] = ACTIONS(77),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(33),
    [anon_sym_void] = ACTIONS(21),
    [anon_sym_delete] = ACTIONS(21),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_DQUOTE] = ACTIONS(83),
    [anon_sym_SQUOTE] = ACTIONS(85),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(87),
    [sym_number] = ACTIONS(89),
    [sym_private_property_identifier] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(93),
    [sym_true] = ACTIONS(93),
    [sym_false] = ACTIONS(93),
    [sym_null] = ACTIONS(93),
    [sym_undefined] = ACTIONS(95),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1352),
    [anon_sym_readonly] = ACTIONS(1352),
    [anon_sym_get] = ACTIONS(1352),
    [anon_sym_set] = ACTIONS(1352),
    [anon_sym_declare] = ACTIONS(1352),
    [anon_sym_public] = ACTIONS(1352),
    [anon_sym_private] = ACTIONS(1352),
    [anon_sym_protected] = ACTIONS(1352),
    [anon_sym_override] = ACTIONS(1352),
    [anon_sym_module] = ACTIONS(1352),
    [anon_sym_any] = ACTIONS(1352),
    [anon_sym_number] = ACTIONS(1352),
    [anon_sym_boolean] = ACTIONS(1352),
    [anon_sym_string] = ACTIONS(1352),
    [anon_sym_symbol] = ACTIONS(1352),
    [anon_sym_object] = ACTIONS(1352),
    [sym_html_comment] = ACTIONS(5),
  },
  [420] = {
    [sym_import] = STATE(3636),
    [sym_parenthesized_expression] = STATE(1362),
    [sym_expression] = STATE(1944),
    [sym_primary_expression] = STATE(1810),
    [sym_yield_expression] = STATE(2358),
    [sym_object] = STATE(2222),
    [sym_object_pattern] = STATE(5492),
    [sym_array] = STATE(2222),
    [sym_array_pattern] = STATE(5492),
    [sym_class] = STATE(2222),
    [sym_function_expression] = STATE(2222),
    [sym_generator_function] = STATE(2222),
    [sym_arrow_function] = STATE(2222),
    [sym__call_signature] = STATE(5821),
    [sym_call_expression] = STATE(2222),
    [sym_new_expression] = STATE(1948),
    [sym_await_expression] = STATE(2358),
    [sym_member_expression] = STATE(1362),
    [sym_subscript_expression] = STATE(1362),
    [sym_assignment_expression] = STATE(2358),
    [sym__augmented_assignment_lhs] = STATE(3025),
    [sym_augmented_assignment_expression] = STATE(2358),
    [sym__destructuring_pattern] = STATE(5492),
    [sym_ternary_expression] = STATE(2358),
    [sym_binary_expression] = STATE(2358),
    [sym_unary_expression] = STATE(2358),
    [sym_update_expression] = STATE(2358),
    [sym_string] = STATE(2222),
    [sym_template_string] = STATE(2222),
    [sym_regex] = STATE(2222),
    [sym_meta_property] = STATE(2222),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1362),
    [sym_type_assertion] = STATE(2358),
    [sym_as_expression] = STATE(2358),
    [sym_satisfies_expression] = STATE(2358),
    [sym_instantiation_expression] = STATE(2358),
    [sym_internal_module] = STATE(2358),
    [sym_type_arguments] = STATE(428),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4408),
    [sym_identifier] = ACTIONS(1468),
    [anon_sym_export] = ACTIONS(1352),
    [anon_sym_type] = ACTIONS(1352),
    [anon_sym_namespace] = ACTIONS(1354),
    [anon_sym_LBRACE] = ACTIONS(665),
    [anon_sym_typeof] = ACTIONS(21),
    [anon_sym_import] = ACTIONS(669),
    [anon_sym_let] = ACTIONS(1352),
    [anon_sym_BANG] = ACTIONS(33),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_await] = ACTIONS(45),
    [anon_sym_yield] = ACTIONS(63),
    [anon_sym_LBRACK] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(676),
    [anon_sym_async] = ACTIONS(1362),
    [anon_sym_function] = ACTIONS(680),
    [anon_sym_new] = ACTIONS(1472),
    [anon_sym_using] = ACTIONS(75),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_SLASH] = ACTIONS(77),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(33),
    [anon_sym_void] = ACTIONS(21),
    [anon_sym_delete] = ACTIONS(21),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_DQUOTE] = ACTIONS(83),
    [anon_sym_SQUOTE] = ACTIONS(85),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(87),
    [sym_number] = ACTIONS(89),
    [sym_private_property_identifier] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(93),
    [sym_true] = ACTIONS(93),
    [sym_false] = ACTIONS(93),
    [sym_null] = ACTIONS(93),
    [sym_undefined] = ACTIONS(95),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1352),
    [anon_sym_readonly] = ACTIONS(1352),
    [anon_sym_get] = ACTIONS(1352),
    [anon_sym_set] = ACTIONS(1352),
    [anon_sym_declare] = ACTIONS(1352),
    [anon_sym_public] = ACTIONS(1352),
    [anon_sym_private] = ACTIONS(1352),
    [anon_sym_protected] = ACTIONS(1352),
    [anon_sym_override] = ACTIONS(1352),
    [anon_sym_module] = ACTIONS(1352),
    [anon_sym_any] = ACTIONS(1352),
    [anon_sym_number] = ACTIONS(1352),
    [anon_sym_boolean] = ACTIONS(1352),
    [anon_sym_string] = ACTIONS(1352),
    [anon_sym_symbol] = ACTIONS(1352),
    [anon_sym_object] = ACTIONS(1352),
    [sym_html_comment] = ACTIONS(5),
  },
  [421] = {
    [sym_import] = STATE(3636),
    [sym_parenthesized_expression] = STATE(1362),
    [sym_expression] = STATE(1945),
    [sym_primary_expression] = STATE(1810),
    [sym_yield_expression] = STATE(2358),
    [sym_object] = STATE(2222),
    [sym_object_pattern] = STATE(5492),
    [sym_array] = STATE(2222),
    [sym_array_pattern] = STATE(5492),
    [sym_class] = STATE(2222),
    [sym_function_expression] = STATE(2222),
    [sym_generator_function] = STATE(2222),
    [sym_arrow_function] = STATE(2222),
    [sym__call_signature] = STATE(5821),
    [sym_call_expression] = STATE(2222),
    [sym_new_expression] = STATE(1948),
    [sym_await_expression] = STATE(2358),
    [sym_member_expression] = STATE(1362),
    [sym_subscript_expression] = STATE(1362),
    [sym_assignment_expression] = STATE(2358),
    [sym__augmented_assignment_lhs] = STATE(3025),
    [sym_augmented_assignment_expression] = STATE(2358),
    [sym__destructuring_pattern] = STATE(5492),
    [sym_ternary_expression] = STATE(2358),
    [sym_binary_expression] = STATE(2358),
    [sym_unary_expression] = STATE(2358),
    [sym_update_expression] = STATE(2358),
    [sym_string] = STATE(2222),
    [sym_template_string] = STATE(2222),
    [sym_regex] = STATE(2222),
    [sym_meta_property] = STATE(2222),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1362),
    [sym_type_assertion] = STATE(2358),
    [sym_as_expression] = STATE(2358),
    [sym_satisfies_expression] = STATE(2358),
    [sym_instantiation_expression] = STATE(2358),
    [sym_internal_module] = STATE(2358),
    [sym_type_arguments] = STATE(428),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4408),
    [sym_identifier] = ACTIONS(1468),
    [anon_sym_export] = ACTIONS(1352),
    [anon_sym_type] = ACTIONS(1352),
    [anon_sym_namespace] = ACTIONS(1354),
    [anon_sym_LBRACE] = ACTIONS(665),
    [anon_sym_typeof] = ACTIONS(21),
    [anon_sym_import] = ACTIONS(669),
    [anon_sym_let] = ACTIONS(1352),
    [anon_sym_BANG] = ACTIONS(33),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_await] = ACTIONS(45),
    [anon_sym_yield] = ACTIONS(63),
    [anon_sym_LBRACK] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(676),
    [anon_sym_async] = ACTIONS(1362),
    [anon_sym_function] = ACTIONS(680),
    [anon_sym_new] = ACTIONS(1472),
    [anon_sym_using] = ACTIONS(75),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_SLASH] = ACTIONS(77),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(33),
    [anon_sym_void] = ACTIONS(21),
    [anon_sym_delete] = ACTIONS(21),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_DQUOTE] = ACTIONS(83),
    [anon_sym_SQUOTE] = ACTIONS(85),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(87),
    [sym_number] = ACTIONS(89),
    [sym_private_property_identifier] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(93),
    [sym_true] = ACTIONS(93),
    [sym_false] = ACTIONS(93),
    [sym_null] = ACTIONS(93),
    [sym_undefined] = ACTIONS(95),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1352),
    [anon_sym_readonly] = ACTIONS(1352),
    [anon_sym_get] = ACTIONS(1352),
    [anon_sym_set] = ACTIONS(1352),
    [anon_sym_declare] = ACTIONS(1352),
    [anon_sym_public] = ACTIONS(1352),
    [anon_sym_private] = ACTIONS(1352),
    [anon_sym_protected] = ACTIONS(1352),
    [anon_sym_override] = ACTIONS(1352),
    [anon_sym_module] = ACTIONS(1352),
    [anon_sym_any] = ACTIONS(1352),
    [anon_sym_number] = ACTIONS(1352),
    [anon_sym_boolean] = ACTIONS(1352),
    [anon_sym_string] = ACTIONS(1352),
    [anon_sym_symbol] = ACTIONS(1352),
    [anon_sym_object] = ACTIONS(1352),
    [sym_html_comment] = ACTIONS(5),
  },
  [422] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1398),
    [sym_expression] = STATE(2041),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5544),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5544),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5558),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1398),
    [sym_subscript_expression] = STATE(1398),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(2980),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5544),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1398),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(638),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1482),
    [anon_sym_export] = ACTIONS(1158),
    [anon_sym_type] = ACTIONS(1158),
    [anon_sym_namespace] = ACTIONS(1160),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_typeof] = ACTIONS(756),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1158),
    [anon_sym_BANG] = ACTIONS(732),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(736),
    [anon_sym_yield] = ACTIONS(738),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1164),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1486),
    [anon_sym_using] = ACTIONS(746),
    [anon_sym_PLUS] = ACTIONS(756),
    [anon_sym_DASH] = ACTIONS(756),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(732),
    [anon_sym_void] = ACTIONS(756),
    [anon_sym_delete] = ACTIONS(756),
    [anon_sym_PLUS_PLUS] = ACTIONS(758),
    [anon_sym_DASH_DASH] = ACTIONS(758),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(764),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1488),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1158),
    [anon_sym_readonly] = ACTIONS(1158),
    [anon_sym_get] = ACTIONS(1158),
    [anon_sym_set] = ACTIONS(1158),
    [anon_sym_declare] = ACTIONS(1158),
    [anon_sym_public] = ACTIONS(1158),
    [anon_sym_private] = ACTIONS(1158),
    [anon_sym_protected] = ACTIONS(1158),
    [anon_sym_override] = ACTIONS(1158),
    [anon_sym_module] = ACTIONS(1158),
    [anon_sym_any] = ACTIONS(1158),
    [anon_sym_number] = ACTIONS(1158),
    [anon_sym_boolean] = ACTIONS(1158),
    [anon_sym_string] = ACTIONS(1158),
    [anon_sym_symbol] = ACTIONS(1158),
    [anon_sym_object] = ACTIONS(1158),
    [sym_html_comment] = ACTIONS(5),
  },
  [423] = {
    [sym_import] = STATE(3636),
    [sym_parenthesized_expression] = STATE(1362),
    [sym_expression] = STATE(2353),
    [sym_primary_expression] = STATE(1810),
    [sym_yield_expression] = STATE(2358),
    [sym_object] = STATE(2222),
    [sym_object_pattern] = STATE(5492),
    [sym_array] = STATE(2222),
    [sym_array_pattern] = STATE(5492),
    [sym_class] = STATE(2222),
    [sym_function_expression] = STATE(2222),
    [sym_generator_function] = STATE(2222),
    [sym_arrow_function] = STATE(2222),
    [sym__call_signature] = STATE(5821),
    [sym_call_expression] = STATE(2222),
    [sym_new_expression] = STATE(1948),
    [sym_await_expression] = STATE(2358),
    [sym_member_expression] = STATE(1362),
    [sym_subscript_expression] = STATE(1362),
    [sym_assignment_expression] = STATE(2358),
    [sym__augmented_assignment_lhs] = STATE(3025),
    [sym_augmented_assignment_expression] = STATE(2358),
    [sym__destructuring_pattern] = STATE(5492),
    [sym_ternary_expression] = STATE(2358),
    [sym_binary_expression] = STATE(2358),
    [sym_unary_expression] = STATE(2358),
    [sym_update_expression] = STATE(2358),
    [sym_string] = STATE(2222),
    [sym_template_string] = STATE(2222),
    [sym_regex] = STATE(2222),
    [sym_meta_property] = STATE(2222),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1362),
    [sym_type_assertion] = STATE(2358),
    [sym_as_expression] = STATE(2358),
    [sym_satisfies_expression] = STATE(2358),
    [sym_instantiation_expression] = STATE(2358),
    [sym_internal_module] = STATE(2358),
    [sym_type_arguments] = STATE(428),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4408),
    [sym_identifier] = ACTIONS(1468),
    [anon_sym_export] = ACTIONS(1352),
    [anon_sym_type] = ACTIONS(1352),
    [anon_sym_namespace] = ACTIONS(1354),
    [anon_sym_LBRACE] = ACTIONS(665),
    [anon_sym_typeof] = ACTIONS(21),
    [anon_sym_import] = ACTIONS(669),
    [anon_sym_let] = ACTIONS(1352),
    [anon_sym_BANG] = ACTIONS(33),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_await] = ACTIONS(45),
    [anon_sym_yield] = ACTIONS(63),
    [anon_sym_LBRACK] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(676),
    [anon_sym_async] = ACTIONS(1362),
    [anon_sym_function] = ACTIONS(680),
    [anon_sym_new] = ACTIONS(1472),
    [anon_sym_using] = ACTIONS(75),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_SLASH] = ACTIONS(77),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(33),
    [anon_sym_void] = ACTIONS(21),
    [anon_sym_delete] = ACTIONS(21),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_DQUOTE] = ACTIONS(83),
    [anon_sym_SQUOTE] = ACTIONS(85),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(87),
    [sym_number] = ACTIONS(89),
    [sym_private_property_identifier] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(93),
    [sym_true] = ACTIONS(93),
    [sym_false] = ACTIONS(93),
    [sym_null] = ACTIONS(93),
    [sym_undefined] = ACTIONS(95),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1352),
    [anon_sym_readonly] = ACTIONS(1352),
    [anon_sym_get] = ACTIONS(1352),
    [anon_sym_set] = ACTIONS(1352),
    [anon_sym_declare] = ACTIONS(1352),
    [anon_sym_public] = ACTIONS(1352),
    [anon_sym_private] = ACTIONS(1352),
    [anon_sym_protected] = ACTIONS(1352),
    [anon_sym_override] = ACTIONS(1352),
    [anon_sym_module] = ACTIONS(1352),
    [anon_sym_any] = ACTIONS(1352),
    [anon_sym_number] = ACTIONS(1352),
    [anon_sym_boolean] = ACTIONS(1352),
    [anon_sym_string] = ACTIONS(1352),
    [anon_sym_symbol] = ACTIONS(1352),
    [anon_sym_object] = ACTIONS(1352),
    [sym_html_comment] = ACTIONS(5),
  },
  [424] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1398),
    [sym_expression] = STATE(1960),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5544),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5544),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5558),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1398),
    [sym_subscript_expression] = STATE(1398),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(2980),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5544),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1398),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(638),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1482),
    [anon_sym_export] = ACTIONS(1158),
    [anon_sym_type] = ACTIONS(1158),
    [anon_sym_namespace] = ACTIONS(1160),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_typeof] = ACTIONS(756),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1158),
    [anon_sym_BANG] = ACTIONS(732),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(736),
    [anon_sym_yield] = ACTIONS(738),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1164),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1486),
    [anon_sym_using] = ACTIONS(746),
    [anon_sym_PLUS] = ACTIONS(756),
    [anon_sym_DASH] = ACTIONS(756),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(732),
    [anon_sym_void] = ACTIONS(756),
    [anon_sym_delete] = ACTIONS(756),
    [anon_sym_PLUS_PLUS] = ACTIONS(758),
    [anon_sym_DASH_DASH] = ACTIONS(758),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(764),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1488),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1158),
    [anon_sym_readonly] = ACTIONS(1158),
    [anon_sym_get] = ACTIONS(1158),
    [anon_sym_set] = ACTIONS(1158),
    [anon_sym_declare] = ACTIONS(1158),
    [anon_sym_public] = ACTIONS(1158),
    [anon_sym_private] = ACTIONS(1158),
    [anon_sym_protected] = ACTIONS(1158),
    [anon_sym_override] = ACTIONS(1158),
    [anon_sym_module] = ACTIONS(1158),
    [anon_sym_any] = ACTIONS(1158),
    [anon_sym_number] = ACTIONS(1158),
    [anon_sym_boolean] = ACTIONS(1158),
    [anon_sym_string] = ACTIONS(1158),
    [anon_sym_symbol] = ACTIONS(1158),
    [anon_sym_object] = ACTIONS(1158),
    [sym_html_comment] = ACTIONS(5),
  },
  [425] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1398),
    [sym_expression] = STATE(1923),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5544),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5544),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5558),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1398),
    [sym_subscript_expression] = STATE(1398),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(2980),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5544),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1398),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(638),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1482),
    [anon_sym_export] = ACTIONS(1158),
    [anon_sym_type] = ACTIONS(1158),
    [anon_sym_namespace] = ACTIONS(1160),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_typeof] = ACTIONS(756),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1158),
    [anon_sym_BANG] = ACTIONS(732),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(736),
    [anon_sym_yield] = ACTIONS(738),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1164),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1486),
    [anon_sym_using] = ACTIONS(746),
    [anon_sym_PLUS] = ACTIONS(756),
    [anon_sym_DASH] = ACTIONS(756),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(732),
    [anon_sym_void] = ACTIONS(756),
    [anon_sym_delete] = ACTIONS(756),
    [anon_sym_PLUS_PLUS] = ACTIONS(758),
    [anon_sym_DASH_DASH] = ACTIONS(758),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(764),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1488),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1158),
    [anon_sym_readonly] = ACTIONS(1158),
    [anon_sym_get] = ACTIONS(1158),
    [anon_sym_set] = ACTIONS(1158),
    [anon_sym_declare] = ACTIONS(1158),
    [anon_sym_public] = ACTIONS(1158),
    [anon_sym_private] = ACTIONS(1158),
    [anon_sym_protected] = ACTIONS(1158),
    [anon_sym_override] = ACTIONS(1158),
    [anon_sym_module] = ACTIONS(1158),
    [anon_sym_any] = ACTIONS(1158),
    [anon_sym_number] = ACTIONS(1158),
    [anon_sym_boolean] = ACTIONS(1158),
    [anon_sym_string] = ACTIONS(1158),
    [anon_sym_symbol] = ACTIONS(1158),
    [anon_sym_object] = ACTIONS(1158),
    [sym_html_comment] = ACTIONS(5),
  },
  [426] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1456),
    [sym_expression] = STATE(2604),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5815),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5815),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5755),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1456),
    [sym_subscript_expression] = STATE(1456),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3029),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5815),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1456),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(594),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1506),
    [anon_sym_export] = ACTIONS(1234),
    [anon_sym_type] = ACTIONS(1234),
    [anon_sym_namespace] = ACTIONS(1236),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_typeof] = ACTIONS(1256),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1234),
    [anon_sym_BANG] = ACTIONS(1240),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(1242),
    [anon_sym_yield] = ACTIONS(1244),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1246),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1510),
    [anon_sym_using] = ACTIONS(1250),
    [anon_sym_PLUS] = ACTIONS(1256),
    [anon_sym_DASH] = ACTIONS(1256),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(1240),
    [anon_sym_void] = ACTIONS(1256),
    [anon_sym_delete] = ACTIONS(1256),
    [anon_sym_PLUS_PLUS] = ACTIONS(1258),
    [anon_sym_DASH_DASH] = ACTIONS(1258),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(1260),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1512),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1234),
    [anon_sym_readonly] = ACTIONS(1234),
    [anon_sym_get] = ACTIONS(1234),
    [anon_sym_set] = ACTIONS(1234),
    [anon_sym_declare] = ACTIONS(1234),
    [anon_sym_public] = ACTIONS(1234),
    [anon_sym_private] = ACTIONS(1234),
    [anon_sym_protected] = ACTIONS(1234),
    [anon_sym_override] = ACTIONS(1234),
    [anon_sym_module] = ACTIONS(1234),
    [anon_sym_any] = ACTIONS(1234),
    [anon_sym_number] = ACTIONS(1234),
    [anon_sym_boolean] = ACTIONS(1234),
    [anon_sym_string] = ACTIONS(1234),
    [anon_sym_symbol] = ACTIONS(1234),
    [anon_sym_object] = ACTIONS(1234),
    [sym_html_comment] = ACTIONS(5),
  },
  [427] = {
    [sym_namespace_export] = STATE(5206),
    [sym_export_clause] = STATE(4427),
    [sym_declaration] = STATE(919),
    [sym_variable_declaration] = STATE(831),
    [sym_lexical_declaration] = STATE(831),
    [sym_class_declaration] = STATE(831),
    [sym_function_declaration] = STATE(831),
    [sym_generator_function_declaration] = STATE(831),
    [sym_decorator] = STATE(1344),
    [sym_function_signature] = STATE(831),
    [sym_ambient_declaration] = STATE(831),
    [sym_abstract_class_declaration] = STATE(831),
    [sym_module] = STATE(831),
    [sym_internal_module] = STATE(824),
    [sym_import_alias] = STATE(831),
    [sym_interface_declaration] = STATE(831),
    [sym_enum_declaration] = STATE(831),
    [sym_type_alias_declaration] = STATE(831),
    [aux_sym_export_statement_repeat1] = STATE(4301),
    [aux_sym_object_repeat1] = STATE(4792),
    [aux_sym_object_pattern_repeat1] = STATE(4815),
    [anon_sym_STAR] = ACTIONS(2127),
    [anon_sym_default] = ACTIONS(2129),
    [anon_sym_type] = ACTIONS(2131),
    [anon_sym_EQ] = ACTIONS(2133),
    [anon_sym_as] = ACTIONS(2135),
    [anon_sym_namespace] = ACTIONS(2137),
    [anon_sym_LBRACE] = ACTIONS(2139),
    [anon_sym_COMMA] = ACTIONS(154),
    [anon_sym_RBRACE] = ACTIONS(694),
    [anon_sym_import] = ACTIONS(2141),
    [anon_sym_var] = ACTIONS(2143),
    [anon_sym_let] = ACTIONS(2145),
    [anon_sym_const] = ACTIONS(2147),
    [anon_sym_BANG] = ACTIONS(120),
    [anon_sym_LPAREN] = ACTIONS(2149),
    [anon_sym_SEMI] = ACTIONS(154),
    [anon_sym_in] = ACTIONS(120),
    [anon_sym_COLON] = ACTIONS(671),
    [anon_sym_LBRACK] = ACTIONS(154),
    [anon_sym_DOT] = ACTIONS(154),
    [anon_sym_class] = ACTIONS(2152),
    [anon_sym_async] = ACTIONS(2154),
    [anon_sym_function] = ACTIONS(2156),
    [anon_sym_EQ_GT] = ACTIONS(682),
    [anon_sym_QMARK_DOT] = ACTIONS(154),
    [anon_sym_PLUS_EQ] = ACTIONS(160),
    [anon_sym_DASH_EQ] = ACTIONS(160),
    [anon_sym_STAR_EQ] = ACTIONS(160),
    [anon_sym_SLASH_EQ] = ACTIONS(160),
    [anon_sym_PERCENT_EQ] = ACTIONS(160),
    [anon_sym_CARET_EQ] = ACTIONS(160),
    [anon_sym_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_LT_LT_EQ] = ACTIONS(160),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(160),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP] = ACTIONS(120),
    [anon_sym_PIPE_PIPE] = ACTIONS(120),
    [anon_sym_GT_GT] = ACTIONS(120),
    [anon_sym_GT_GT_GT] = ACTIONS(120),
    [anon_sym_LT_LT] = ACTIONS(120),
    [anon_sym_AMP] = ACTIONS(120),
    [anon_sym_CARET] = ACTIONS(120),
    [anon_sym_PIPE] = ACTIONS(120),
    [anon_sym_PLUS] = ACTIONS(120),
    [anon_sym_DASH] = ACTIONS(120),
    [anon_sym_SLASH] = ACTIONS(120),
    [anon_sym_PERCENT] = ACTIONS(120),
    [anon_sym_STAR_STAR] = ACTIONS(120),
    [anon_sym_LT] = ACTIONS(2158),
    [anon_sym_LT_EQ] = ACTIONS(154),
    [anon_sym_EQ_EQ] = ACTIONS(120),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(154),
    [anon_sym_BANG_EQ] = ACTIONS(120),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(154),
    [anon_sym_GT_EQ] = ACTIONS(154),
    [anon_sym_GT] = ACTIONS(120),
    [anon_sym_QMARK_QMARK] = ACTIONS(120),
    [anon_sym_instanceof] = ACTIONS(154),
    [anon_sym_PLUS_PLUS] = ACTIONS(154),
    [anon_sym_DASH_DASH] = ACTIONS(154),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(154),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_QMARK] = ACTIONS(690),
    [anon_sym_declare] = ACTIONS(2161),
    [anon_sym_module] = ACTIONS(2163),
    [anon_sym_abstract] = ACTIONS(2165),
    [anon_sym_satisfies] = ACTIONS(154),
    [anon_sym_interface] = ACTIONS(2167),
    [anon_sym_enum] = ACTIONS(2169),
    [sym__automatic_semicolon] = ACTIONS(154),
    [sym__ternary_qmark] = ACTIONS(154),
    [sym_html_comment] = ACTIONS(5),
  },
  [428] = {
    [sym_import] = STATE(3636),
    [sym_parenthesized_expression] = STATE(1362),
    [sym_expression] = STATE(1834),
    [sym_primary_expression] = STATE(1810),
    [sym_yield_expression] = STATE(2358),
    [sym_object] = STATE(2222),
    [sym_object_pattern] = STATE(5492),
    [sym_array] = STATE(2222),
    [sym_array_pattern] = STATE(5492),
    [sym_class] = STATE(2222),
    [sym_function_expression] = STATE(2222),
    [sym_generator_function] = STATE(2222),
    [sym_arrow_function] = STATE(2222),
    [sym__call_signature] = STATE(5821),
    [sym_call_expression] = STATE(2222),
    [sym_new_expression] = STATE(1948),
    [sym_await_expression] = STATE(2358),
    [sym_member_expression] = STATE(1362),
    [sym_subscript_expression] = STATE(1362),
    [sym_assignment_expression] = STATE(2358),
    [sym__augmented_assignment_lhs] = STATE(3025),
    [sym_augmented_assignment_expression] = STATE(2358),
    [sym__destructuring_pattern] = STATE(5492),
    [sym_ternary_expression] = STATE(2358),
    [sym_binary_expression] = STATE(2358),
    [sym_unary_expression] = STATE(2358),
    [sym_update_expression] = STATE(2358),
    [sym_string] = STATE(2222),
    [sym_template_string] = STATE(2222),
    [sym_regex] = STATE(2222),
    [sym_meta_property] = STATE(2222),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1362),
    [sym_type_assertion] = STATE(2358),
    [sym_as_expression] = STATE(2358),
    [sym_satisfies_expression] = STATE(2358),
    [sym_instantiation_expression] = STATE(2358),
    [sym_internal_module] = STATE(2358),
    [sym_type_arguments] = STATE(428),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4408),
    [sym_identifier] = ACTIONS(1468),
    [anon_sym_export] = ACTIONS(1352),
    [anon_sym_type] = ACTIONS(1352),
    [anon_sym_namespace] = ACTIONS(1354),
    [anon_sym_LBRACE] = ACTIONS(665),
    [anon_sym_typeof] = ACTIONS(21),
    [anon_sym_import] = ACTIONS(669),
    [anon_sym_let] = ACTIONS(1352),
    [anon_sym_BANG] = ACTIONS(33),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_await] = ACTIONS(45),
    [anon_sym_yield] = ACTIONS(63),
    [anon_sym_LBRACK] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(676),
    [anon_sym_async] = ACTIONS(1362),
    [anon_sym_function] = ACTIONS(680),
    [anon_sym_new] = ACTIONS(1472),
    [anon_sym_using] = ACTIONS(75),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_SLASH] = ACTIONS(77),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(33),
    [anon_sym_void] = ACTIONS(21),
    [anon_sym_delete] = ACTIONS(21),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_DQUOTE] = ACTIONS(83),
    [anon_sym_SQUOTE] = ACTIONS(85),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(87),
    [sym_number] = ACTIONS(89),
    [sym_private_property_identifier] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(93),
    [sym_true] = ACTIONS(93),
    [sym_false] = ACTIONS(93),
    [sym_null] = ACTIONS(93),
    [sym_undefined] = ACTIONS(95),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1352),
    [anon_sym_readonly] = ACTIONS(1352),
    [anon_sym_get] = ACTIONS(1352),
    [anon_sym_set] = ACTIONS(1352),
    [anon_sym_declare] = ACTIONS(1352),
    [anon_sym_public] = ACTIONS(1352),
    [anon_sym_private] = ACTIONS(1352),
    [anon_sym_protected] = ACTIONS(1352),
    [anon_sym_override] = ACTIONS(1352),
    [anon_sym_module] = ACTIONS(1352),
    [anon_sym_any] = ACTIONS(1352),
    [anon_sym_number] = ACTIONS(1352),
    [anon_sym_boolean] = ACTIONS(1352),
    [anon_sym_string] = ACTIONS(1352),
    [anon_sym_symbol] = ACTIONS(1352),
    [anon_sym_object] = ACTIONS(1352),
    [sym_html_comment] = ACTIONS(5),
  },
  [429] = {
    [sym_import] = STATE(3636),
    [sym_parenthesized_expression] = STATE(1364),
    [sym_expression] = STATE(1894),
    [sym_primary_expression] = STATE(1810),
    [sym_yield_expression] = STATE(2358),
    [sym_object] = STATE(2222),
    [sym_object_pattern] = STATE(5773),
    [sym_array] = STATE(2222),
    [sym_array_pattern] = STATE(5773),
    [sym_class] = STATE(2222),
    [sym_function_expression] = STATE(2222),
    [sym_generator_function] = STATE(2222),
    [sym_arrow_function] = STATE(2222),
    [sym__call_signature] = STATE(5771),
    [sym_call_expression] = STATE(2222),
    [sym_new_expression] = STATE(1948),
    [sym_await_expression] = STATE(2358),
    [sym_member_expression] = STATE(1364),
    [sym_subscript_expression] = STATE(1364),
    [sym_assignment_expression] = STATE(2358),
    [sym__augmented_assignment_lhs] = STATE(3020),
    [sym_augmented_assignment_expression] = STATE(2358),
    [sym__destructuring_pattern] = STATE(5773),
    [sym_ternary_expression] = STATE(2358),
    [sym_binary_expression] = STATE(2358),
    [sym_unary_expression] = STATE(2358),
    [sym_update_expression] = STATE(2358),
    [sym_string] = STATE(2222),
    [sym_template_string] = STATE(2222),
    [sym_regex] = STATE(2222),
    [sym_meta_property] = STATE(2222),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1364),
    [sym_type_assertion] = STATE(2358),
    [sym_as_expression] = STATE(2358),
    [sym_satisfies_expression] = STATE(2358),
    [sym_instantiation_expression] = STATE(2358),
    [sym_internal_module] = STATE(2358),
    [sym_type_arguments] = STATE(513),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4408),
    [sym_identifier] = ACTIONS(1474),
    [anon_sym_export] = ACTIONS(1386),
    [anon_sym_type] = ACTIONS(1386),
    [anon_sym_namespace] = ACTIONS(1388),
    [anon_sym_LBRACE] = ACTIONS(665),
    [anon_sym_typeof] = ACTIONS(1408),
    [anon_sym_import] = ACTIONS(669),
    [anon_sym_let] = ACTIONS(1386),
    [anon_sym_BANG] = ACTIONS(1392),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_await] = ACTIONS(1394),
    [anon_sym_yield] = ACTIONS(1396),
    [anon_sym_LBRACK] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(676),
    [anon_sym_async] = ACTIONS(1398),
    [anon_sym_function] = ACTIONS(680),
    [anon_sym_new] = ACTIONS(1478),
    [anon_sym_using] = ACTIONS(1402),
    [anon_sym_PLUS] = ACTIONS(1408),
    [anon_sym_DASH] = ACTIONS(1408),
    [anon_sym_SLASH] = ACTIONS(876),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(1392),
    [anon_sym_void] = ACTIONS(1408),
    [anon_sym_delete] = ACTIONS(1408),
    [anon_sym_PLUS_PLUS] = ACTIONS(1410),
    [anon_sym_DASH_DASH] = ACTIONS(1410),
    [anon_sym_DQUOTE] = ACTIONS(83),
    [anon_sym_SQUOTE] = ACTIONS(85),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(87),
    [sym_number] = ACTIONS(89),
    [sym_private_property_identifier] = ACTIONS(1412),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(93),
    [sym_true] = ACTIONS(93),
    [sym_false] = ACTIONS(93),
    [sym_null] = ACTIONS(93),
    [sym_undefined] = ACTIONS(1480),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1386),
    [anon_sym_readonly] = ACTIONS(1386),
    [anon_sym_get] = ACTIONS(1386),
    [anon_sym_set] = ACTIONS(1386),
    [anon_sym_declare] = ACTIONS(1386),
    [anon_sym_public] = ACTIONS(1386),
    [anon_sym_private] = ACTIONS(1386),
    [anon_sym_protected] = ACTIONS(1386),
    [anon_sym_override] = ACTIONS(1386),
    [anon_sym_module] = ACTIONS(1386),
    [anon_sym_any] = ACTIONS(1386),
    [anon_sym_number] = ACTIONS(1386),
    [anon_sym_boolean] = ACTIONS(1386),
    [anon_sym_string] = ACTIONS(1386),
    [anon_sym_symbol] = ACTIONS(1386),
    [anon_sym_object] = ACTIONS(1386),
    [sym_html_comment] = ACTIONS(5),
  },
  [430] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1398),
    [sym_expression] = STATE(1960),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5544),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5544),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5558),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1398),
    [sym_subscript_expression] = STATE(1398),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(2980),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5544),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1398),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(638),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1482),
    [anon_sym_export] = ACTIONS(1158),
    [anon_sym_type] = ACTIONS(1158),
    [anon_sym_namespace] = ACTIONS(1160),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_typeof] = ACTIONS(756),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1158),
    [anon_sym_BANG] = ACTIONS(732),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(736),
    [anon_sym_yield] = ACTIONS(738),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1164),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1486),
    [anon_sym_using] = ACTIONS(746),
    [anon_sym_PLUS] = ACTIONS(756),
    [anon_sym_DASH] = ACTIONS(756),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(732),
    [anon_sym_void] = ACTIONS(756),
    [anon_sym_delete] = ACTIONS(756),
    [anon_sym_PLUS_PLUS] = ACTIONS(758),
    [anon_sym_DASH_DASH] = ACTIONS(758),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(2171),
    [sym_private_property_identifier] = ACTIONS(764),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1488),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1158),
    [anon_sym_readonly] = ACTIONS(1158),
    [anon_sym_get] = ACTIONS(1158),
    [anon_sym_set] = ACTIONS(1158),
    [anon_sym_declare] = ACTIONS(1158),
    [anon_sym_public] = ACTIONS(1158),
    [anon_sym_private] = ACTIONS(1158),
    [anon_sym_protected] = ACTIONS(1158),
    [anon_sym_override] = ACTIONS(1158),
    [anon_sym_module] = ACTIONS(1158),
    [anon_sym_any] = ACTIONS(1158),
    [anon_sym_number] = ACTIONS(1158),
    [anon_sym_boolean] = ACTIONS(1158),
    [anon_sym_string] = ACTIONS(1158),
    [anon_sym_symbol] = ACTIONS(1158),
    [anon_sym_object] = ACTIONS(1158),
    [sym_html_comment] = ACTIONS(5),
  },
  [431] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1322),
    [sym_expression] = STATE(2135),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5698),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5698),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5508),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1322),
    [sym_subscript_expression] = STATE(1322),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3003),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5698),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1322),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(484),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1456),
    [anon_sym_export] = ACTIONS(1048),
    [anon_sym_type] = ACTIONS(1048),
    [anon_sym_namespace] = ACTIONS(1050),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_typeof] = ACTIONS(581),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1048),
    [anon_sym_BANG] = ACTIONS(553),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(555),
    [anon_sym_yield] = ACTIONS(557),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1058),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1464),
    [anon_sym_using] = ACTIONS(567),
    [anon_sym_PLUS] = ACTIONS(581),
    [anon_sym_DASH] = ACTIONS(581),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(553),
    [anon_sym_void] = ACTIONS(581),
    [anon_sym_delete] = ACTIONS(581),
    [anon_sym_PLUS_PLUS] = ACTIONS(583),
    [anon_sym_DASH_DASH] = ACTIONS(583),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(585),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1466),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1048),
    [anon_sym_readonly] = ACTIONS(1048),
    [anon_sym_get] = ACTIONS(1048),
    [anon_sym_set] = ACTIONS(1048),
    [anon_sym_declare] = ACTIONS(1048),
    [anon_sym_public] = ACTIONS(1048),
    [anon_sym_private] = ACTIONS(1048),
    [anon_sym_protected] = ACTIONS(1048),
    [anon_sym_override] = ACTIONS(1048),
    [anon_sym_module] = ACTIONS(1048),
    [anon_sym_any] = ACTIONS(1048),
    [anon_sym_number] = ACTIONS(1048),
    [anon_sym_boolean] = ACTIONS(1048),
    [anon_sym_string] = ACTIONS(1048),
    [anon_sym_symbol] = ACTIONS(1048),
    [anon_sym_object] = ACTIONS(1048),
    [sym_html_comment] = ACTIONS(5),
  },
  [432] = {
    [sym_import] = STATE(3636),
    [sym_parenthesized_expression] = STATE(1362),
    [sym_expression] = STATE(1800),
    [sym_primary_expression] = STATE(1810),
    [sym_yield_expression] = STATE(2358),
    [sym_object] = STATE(2222),
    [sym_object_pattern] = STATE(5492),
    [sym_array] = STATE(2222),
    [sym_array_pattern] = STATE(5492),
    [sym_class] = STATE(2222),
    [sym_function_expression] = STATE(2222),
    [sym_generator_function] = STATE(2222),
    [sym_arrow_function] = STATE(2222),
    [sym__call_signature] = STATE(5821),
    [sym_call_expression] = STATE(2222),
    [sym_new_expression] = STATE(1948),
    [sym_await_expression] = STATE(2358),
    [sym_member_expression] = STATE(1362),
    [sym_subscript_expression] = STATE(1362),
    [sym_assignment_expression] = STATE(2358),
    [sym__augmented_assignment_lhs] = STATE(3025),
    [sym_augmented_assignment_expression] = STATE(2358),
    [sym__destructuring_pattern] = STATE(5492),
    [sym_ternary_expression] = STATE(2358),
    [sym_binary_expression] = STATE(2358),
    [sym_unary_expression] = STATE(2358),
    [sym_update_expression] = STATE(2358),
    [sym_string] = STATE(2222),
    [sym_template_string] = STATE(2222),
    [sym_regex] = STATE(2222),
    [sym_meta_property] = STATE(2222),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1362),
    [sym_type_assertion] = STATE(2358),
    [sym_as_expression] = STATE(2358),
    [sym_satisfies_expression] = STATE(2358),
    [sym_instantiation_expression] = STATE(2358),
    [sym_internal_module] = STATE(2358),
    [sym_type_arguments] = STATE(428),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4408),
    [sym_identifier] = ACTIONS(1468),
    [anon_sym_export] = ACTIONS(1352),
    [anon_sym_type] = ACTIONS(1352),
    [anon_sym_namespace] = ACTIONS(1354),
    [anon_sym_LBRACE] = ACTIONS(665),
    [anon_sym_typeof] = ACTIONS(21),
    [anon_sym_import] = ACTIONS(669),
    [anon_sym_let] = ACTIONS(1352),
    [anon_sym_BANG] = ACTIONS(33),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_await] = ACTIONS(45),
    [anon_sym_yield] = ACTIONS(63),
    [anon_sym_LBRACK] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(676),
    [anon_sym_async] = ACTIONS(1362),
    [anon_sym_function] = ACTIONS(680),
    [anon_sym_new] = ACTIONS(1472),
    [anon_sym_using] = ACTIONS(75),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_SLASH] = ACTIONS(77),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(33),
    [anon_sym_void] = ACTIONS(21),
    [anon_sym_delete] = ACTIONS(21),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_DQUOTE] = ACTIONS(83),
    [anon_sym_SQUOTE] = ACTIONS(85),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(87),
    [sym_number] = ACTIONS(89),
    [sym_private_property_identifier] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(93),
    [sym_true] = ACTIONS(93),
    [sym_false] = ACTIONS(93),
    [sym_null] = ACTIONS(93),
    [sym_undefined] = ACTIONS(95),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1352),
    [anon_sym_readonly] = ACTIONS(1352),
    [anon_sym_get] = ACTIONS(1352),
    [anon_sym_set] = ACTIONS(1352),
    [anon_sym_declare] = ACTIONS(1352),
    [anon_sym_public] = ACTIONS(1352),
    [anon_sym_private] = ACTIONS(1352),
    [anon_sym_protected] = ACTIONS(1352),
    [anon_sym_override] = ACTIONS(1352),
    [anon_sym_module] = ACTIONS(1352),
    [anon_sym_any] = ACTIONS(1352),
    [anon_sym_number] = ACTIONS(1352),
    [anon_sym_boolean] = ACTIONS(1352),
    [anon_sym_string] = ACTIONS(1352),
    [anon_sym_symbol] = ACTIONS(1352),
    [anon_sym_object] = ACTIONS(1352),
    [sym_html_comment] = ACTIONS(5),
  },
  [433] = {
    [sym_import] = STATE(3636),
    [sym_parenthesized_expression] = STATE(1362),
    [sym_expression] = STATE(2224),
    [sym_primary_expression] = STATE(1810),
    [sym_yield_expression] = STATE(2358),
    [sym_object] = STATE(2222),
    [sym_object_pattern] = STATE(5492),
    [sym_array] = STATE(2222),
    [sym_array_pattern] = STATE(5492),
    [sym_class] = STATE(2222),
    [sym_function_expression] = STATE(2222),
    [sym_generator_function] = STATE(2222),
    [sym_arrow_function] = STATE(2222),
    [sym__call_signature] = STATE(5821),
    [sym_call_expression] = STATE(2222),
    [sym_new_expression] = STATE(1948),
    [sym_await_expression] = STATE(2358),
    [sym_member_expression] = STATE(1362),
    [sym_subscript_expression] = STATE(1362),
    [sym_assignment_expression] = STATE(2358),
    [sym__augmented_assignment_lhs] = STATE(3025),
    [sym_augmented_assignment_expression] = STATE(2358),
    [sym__destructuring_pattern] = STATE(5492),
    [sym_ternary_expression] = STATE(2358),
    [sym_binary_expression] = STATE(2358),
    [sym_unary_expression] = STATE(2358),
    [sym_update_expression] = STATE(2358),
    [sym_string] = STATE(2222),
    [sym_template_string] = STATE(2222),
    [sym_regex] = STATE(2222),
    [sym_meta_property] = STATE(2222),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1362),
    [sym_type_assertion] = STATE(2358),
    [sym_as_expression] = STATE(2358),
    [sym_satisfies_expression] = STATE(2358),
    [sym_instantiation_expression] = STATE(2358),
    [sym_internal_module] = STATE(2358),
    [sym_type_arguments] = STATE(428),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4408),
    [sym_identifier] = ACTIONS(1468),
    [anon_sym_export] = ACTIONS(1352),
    [anon_sym_type] = ACTIONS(1352),
    [anon_sym_namespace] = ACTIONS(1354),
    [anon_sym_LBRACE] = ACTIONS(665),
    [anon_sym_typeof] = ACTIONS(21),
    [anon_sym_import] = ACTIONS(669),
    [anon_sym_let] = ACTIONS(1352),
    [anon_sym_BANG] = ACTIONS(33),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_await] = ACTIONS(45),
    [anon_sym_yield] = ACTIONS(63),
    [anon_sym_LBRACK] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(676),
    [anon_sym_async] = ACTIONS(1362),
    [anon_sym_function] = ACTIONS(680),
    [anon_sym_new] = ACTIONS(1472),
    [anon_sym_using] = ACTIONS(75),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_SLASH] = ACTIONS(77),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(33),
    [anon_sym_void] = ACTIONS(21),
    [anon_sym_delete] = ACTIONS(21),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_DQUOTE] = ACTIONS(83),
    [anon_sym_SQUOTE] = ACTIONS(85),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(87),
    [sym_number] = ACTIONS(89),
    [sym_private_property_identifier] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(93),
    [sym_true] = ACTIONS(93),
    [sym_false] = ACTIONS(93),
    [sym_null] = ACTIONS(93),
    [sym_undefined] = ACTIONS(95),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1352),
    [anon_sym_readonly] = ACTIONS(1352),
    [anon_sym_get] = ACTIONS(1352),
    [anon_sym_set] = ACTIONS(1352),
    [anon_sym_declare] = ACTIONS(1352),
    [anon_sym_public] = ACTIONS(1352),
    [anon_sym_private] = ACTIONS(1352),
    [anon_sym_protected] = ACTIONS(1352),
    [anon_sym_override] = ACTIONS(1352),
    [anon_sym_module] = ACTIONS(1352),
    [anon_sym_any] = ACTIONS(1352),
    [anon_sym_number] = ACTIONS(1352),
    [anon_sym_boolean] = ACTIONS(1352),
    [anon_sym_string] = ACTIONS(1352),
    [anon_sym_symbol] = ACTIONS(1352),
    [anon_sym_object] = ACTIONS(1352),
    [sym_html_comment] = ACTIONS(5),
  },
  [434] = {
    [sym_import] = STATE(3636),
    [sym_parenthesized_expression] = STATE(1362),
    [sym_expression] = STATE(1819),
    [sym_primary_expression] = STATE(1810),
    [sym_yield_expression] = STATE(2358),
    [sym_object] = STATE(2222),
    [sym_object_pattern] = STATE(5492),
    [sym_array] = STATE(2222),
    [sym_array_pattern] = STATE(5492),
    [sym_class] = STATE(2222),
    [sym_function_expression] = STATE(2222),
    [sym_generator_function] = STATE(2222),
    [sym_arrow_function] = STATE(2222),
    [sym__call_signature] = STATE(5821),
    [sym_call_expression] = STATE(2222),
    [sym_new_expression] = STATE(1948),
    [sym_await_expression] = STATE(2358),
    [sym_member_expression] = STATE(1362),
    [sym_subscript_expression] = STATE(1362),
    [sym_assignment_expression] = STATE(2358),
    [sym__augmented_assignment_lhs] = STATE(3025),
    [sym_augmented_assignment_expression] = STATE(2358),
    [sym__destructuring_pattern] = STATE(5492),
    [sym_ternary_expression] = STATE(2358),
    [sym_binary_expression] = STATE(2358),
    [sym_unary_expression] = STATE(2358),
    [sym_update_expression] = STATE(2358),
    [sym_string] = STATE(2222),
    [sym_template_string] = STATE(2222),
    [sym_regex] = STATE(2222),
    [sym_meta_property] = STATE(2222),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1362),
    [sym_type_assertion] = STATE(2358),
    [sym_as_expression] = STATE(2358),
    [sym_satisfies_expression] = STATE(2358),
    [sym_instantiation_expression] = STATE(2358),
    [sym_internal_module] = STATE(2358),
    [sym_type_arguments] = STATE(428),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4408),
    [sym_identifier] = ACTIONS(1468),
    [anon_sym_export] = ACTIONS(1352),
    [anon_sym_type] = ACTIONS(1352),
    [anon_sym_namespace] = ACTIONS(1354),
    [anon_sym_LBRACE] = ACTIONS(665),
    [anon_sym_typeof] = ACTIONS(21),
    [anon_sym_import] = ACTIONS(669),
    [anon_sym_let] = ACTIONS(1352),
    [anon_sym_BANG] = ACTIONS(33),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_await] = ACTIONS(45),
    [anon_sym_yield] = ACTIONS(63),
    [anon_sym_LBRACK] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(676),
    [anon_sym_async] = ACTIONS(1362),
    [anon_sym_function] = ACTIONS(680),
    [anon_sym_new] = ACTIONS(1472),
    [anon_sym_using] = ACTIONS(75),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_SLASH] = ACTIONS(77),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(33),
    [anon_sym_void] = ACTIONS(21),
    [anon_sym_delete] = ACTIONS(21),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_DQUOTE] = ACTIONS(83),
    [anon_sym_SQUOTE] = ACTIONS(85),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(87),
    [sym_number] = ACTIONS(89),
    [sym_private_property_identifier] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(93),
    [sym_true] = ACTIONS(93),
    [sym_false] = ACTIONS(93),
    [sym_null] = ACTIONS(93),
    [sym_undefined] = ACTIONS(95),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1352),
    [anon_sym_readonly] = ACTIONS(1352),
    [anon_sym_get] = ACTIONS(1352),
    [anon_sym_set] = ACTIONS(1352),
    [anon_sym_declare] = ACTIONS(1352),
    [anon_sym_public] = ACTIONS(1352),
    [anon_sym_private] = ACTIONS(1352),
    [anon_sym_protected] = ACTIONS(1352),
    [anon_sym_override] = ACTIONS(1352),
    [anon_sym_module] = ACTIONS(1352),
    [anon_sym_any] = ACTIONS(1352),
    [anon_sym_number] = ACTIONS(1352),
    [anon_sym_boolean] = ACTIONS(1352),
    [anon_sym_string] = ACTIONS(1352),
    [anon_sym_symbol] = ACTIONS(1352),
    [anon_sym_object] = ACTIONS(1352),
    [sym_html_comment] = ACTIONS(5),
  },
  [435] = {
    [sym_import] = STATE(3636),
    [sym_parenthesized_expression] = STATE(1362),
    [sym_expression] = STATE(1820),
    [sym_primary_expression] = STATE(1810),
    [sym_yield_expression] = STATE(2358),
    [sym_object] = STATE(2222),
    [sym_object_pattern] = STATE(5492),
    [sym_array] = STATE(2222),
    [sym_array_pattern] = STATE(5492),
    [sym_class] = STATE(2222),
    [sym_function_expression] = STATE(2222),
    [sym_generator_function] = STATE(2222),
    [sym_arrow_function] = STATE(2222),
    [sym__call_signature] = STATE(5821),
    [sym_call_expression] = STATE(2222),
    [sym_new_expression] = STATE(1948),
    [sym_await_expression] = STATE(2358),
    [sym_member_expression] = STATE(1362),
    [sym_subscript_expression] = STATE(1362),
    [sym_assignment_expression] = STATE(2358),
    [sym__augmented_assignment_lhs] = STATE(3025),
    [sym_augmented_assignment_expression] = STATE(2358),
    [sym__destructuring_pattern] = STATE(5492),
    [sym_ternary_expression] = STATE(2358),
    [sym_binary_expression] = STATE(2358),
    [sym_unary_expression] = STATE(2358),
    [sym_update_expression] = STATE(2358),
    [sym_string] = STATE(2222),
    [sym_template_string] = STATE(2222),
    [sym_regex] = STATE(2222),
    [sym_meta_property] = STATE(2222),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1362),
    [sym_type_assertion] = STATE(2358),
    [sym_as_expression] = STATE(2358),
    [sym_satisfies_expression] = STATE(2358),
    [sym_instantiation_expression] = STATE(2358),
    [sym_internal_module] = STATE(2358),
    [sym_type_arguments] = STATE(428),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4408),
    [sym_identifier] = ACTIONS(1468),
    [anon_sym_export] = ACTIONS(1352),
    [anon_sym_type] = ACTIONS(1352),
    [anon_sym_namespace] = ACTIONS(1354),
    [anon_sym_LBRACE] = ACTIONS(665),
    [anon_sym_typeof] = ACTIONS(21),
    [anon_sym_import] = ACTIONS(669),
    [anon_sym_let] = ACTIONS(1352),
    [anon_sym_BANG] = ACTIONS(33),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_await] = ACTIONS(45),
    [anon_sym_yield] = ACTIONS(63),
    [anon_sym_LBRACK] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(676),
    [anon_sym_async] = ACTIONS(1362),
    [anon_sym_function] = ACTIONS(680),
    [anon_sym_new] = ACTIONS(1472),
    [anon_sym_using] = ACTIONS(75),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_SLASH] = ACTIONS(77),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(33),
    [anon_sym_void] = ACTIONS(21),
    [anon_sym_delete] = ACTIONS(21),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_DQUOTE] = ACTIONS(83),
    [anon_sym_SQUOTE] = ACTIONS(85),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(87),
    [sym_number] = ACTIONS(89),
    [sym_private_property_identifier] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(93),
    [sym_true] = ACTIONS(93),
    [sym_false] = ACTIONS(93),
    [sym_null] = ACTIONS(93),
    [sym_undefined] = ACTIONS(95),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1352),
    [anon_sym_readonly] = ACTIONS(1352),
    [anon_sym_get] = ACTIONS(1352),
    [anon_sym_set] = ACTIONS(1352),
    [anon_sym_declare] = ACTIONS(1352),
    [anon_sym_public] = ACTIONS(1352),
    [anon_sym_private] = ACTIONS(1352),
    [anon_sym_protected] = ACTIONS(1352),
    [anon_sym_override] = ACTIONS(1352),
    [anon_sym_module] = ACTIONS(1352),
    [anon_sym_any] = ACTIONS(1352),
    [anon_sym_number] = ACTIONS(1352),
    [anon_sym_boolean] = ACTIONS(1352),
    [anon_sym_string] = ACTIONS(1352),
    [anon_sym_symbol] = ACTIONS(1352),
    [anon_sym_object] = ACTIONS(1352),
    [sym_html_comment] = ACTIONS(5),
  },
  [436] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1459),
    [sym_expression] = STATE(2552),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5827),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5827),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5529),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1459),
    [sym_subscript_expression] = STATE(1459),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(2979),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5827),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1459),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(647),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1514),
    [anon_sym_export] = ACTIONS(1074),
    [anon_sym_type] = ACTIONS(1074),
    [anon_sym_namespace] = ACTIONS(1076),
    [anon_sym_LBRACE] = ACTIONS(808),
    [anon_sym_typeof] = ACTIONS(1100),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1074),
    [anon_sym_BANG] = ACTIONS(1082),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(1084),
    [anon_sym_yield] = ACTIONS(1086),
    [anon_sym_LBRACK] = ACTIONS(812),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1090),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1518),
    [anon_sym_using] = ACTIONS(1094),
    [anon_sym_PLUS] = ACTIONS(1100),
    [anon_sym_DASH] = ACTIONS(1100),
    [anon_sym_SLASH] = ACTIONS(958),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(1082),
    [anon_sym_void] = ACTIONS(1100),
    [anon_sym_delete] = ACTIONS(1100),
    [anon_sym_PLUS_PLUS] = ACTIONS(1102),
    [anon_sym_DASH_DASH] = ACTIONS(1102),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(1108),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1520),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1074),
    [anon_sym_readonly] = ACTIONS(1074),
    [anon_sym_get] = ACTIONS(1074),
    [anon_sym_set] = ACTIONS(1074),
    [anon_sym_declare] = ACTIONS(1074),
    [anon_sym_public] = ACTIONS(1074),
    [anon_sym_private] = ACTIONS(1074),
    [anon_sym_protected] = ACTIONS(1074),
    [anon_sym_override] = ACTIONS(1074),
    [anon_sym_module] = ACTIONS(1074),
    [anon_sym_any] = ACTIONS(1074),
    [anon_sym_number] = ACTIONS(1074),
    [anon_sym_boolean] = ACTIONS(1074),
    [anon_sym_string] = ACTIONS(1074),
    [anon_sym_symbol] = ACTIONS(1074),
    [anon_sym_object] = ACTIONS(1074),
    [sym_html_comment] = ACTIONS(5),
  },
  [437] = {
    [sym_import] = STATE(3636),
    [sym_parenthesized_expression] = STATE(1362),
    [sym_expression] = STATE(1798),
    [sym_primary_expression] = STATE(1810),
    [sym_yield_expression] = STATE(2358),
    [sym_object] = STATE(2222),
    [sym_object_pattern] = STATE(5492),
    [sym_array] = STATE(2222),
    [sym_array_pattern] = STATE(5492),
    [sym_class] = STATE(2222),
    [sym_function_expression] = STATE(2222),
    [sym_generator_function] = STATE(2222),
    [sym_arrow_function] = STATE(2222),
    [sym__call_signature] = STATE(5821),
    [sym_call_expression] = STATE(2222),
    [sym_new_expression] = STATE(1948),
    [sym_await_expression] = STATE(2358),
    [sym_member_expression] = STATE(1362),
    [sym_subscript_expression] = STATE(1362),
    [sym_assignment_expression] = STATE(2358),
    [sym__augmented_assignment_lhs] = STATE(3025),
    [sym_augmented_assignment_expression] = STATE(2358),
    [sym__destructuring_pattern] = STATE(5492),
    [sym_ternary_expression] = STATE(2358),
    [sym_binary_expression] = STATE(2358),
    [sym_unary_expression] = STATE(2358),
    [sym_update_expression] = STATE(2358),
    [sym_string] = STATE(2222),
    [sym_template_string] = STATE(2222),
    [sym_regex] = STATE(2222),
    [sym_meta_property] = STATE(2222),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1362),
    [sym_type_assertion] = STATE(2358),
    [sym_as_expression] = STATE(2358),
    [sym_satisfies_expression] = STATE(2358),
    [sym_instantiation_expression] = STATE(2358),
    [sym_internal_module] = STATE(2358),
    [sym_type_arguments] = STATE(428),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4408),
    [sym_identifier] = ACTIONS(1468),
    [anon_sym_export] = ACTIONS(1352),
    [anon_sym_type] = ACTIONS(1352),
    [anon_sym_namespace] = ACTIONS(1354),
    [anon_sym_LBRACE] = ACTIONS(665),
    [anon_sym_typeof] = ACTIONS(21),
    [anon_sym_import] = ACTIONS(669),
    [anon_sym_let] = ACTIONS(1352),
    [anon_sym_BANG] = ACTIONS(33),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_await] = ACTIONS(45),
    [anon_sym_yield] = ACTIONS(63),
    [anon_sym_LBRACK] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(676),
    [anon_sym_async] = ACTIONS(1362),
    [anon_sym_function] = ACTIONS(680),
    [anon_sym_new] = ACTIONS(1472),
    [anon_sym_using] = ACTIONS(75),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_SLASH] = ACTIONS(77),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(33),
    [anon_sym_void] = ACTIONS(21),
    [anon_sym_delete] = ACTIONS(21),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_DQUOTE] = ACTIONS(83),
    [anon_sym_SQUOTE] = ACTIONS(85),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(87),
    [sym_number] = ACTIONS(89),
    [sym_private_property_identifier] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(93),
    [sym_true] = ACTIONS(93),
    [sym_false] = ACTIONS(93),
    [sym_null] = ACTIONS(93),
    [sym_undefined] = ACTIONS(95),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1352),
    [anon_sym_readonly] = ACTIONS(1352),
    [anon_sym_get] = ACTIONS(1352),
    [anon_sym_set] = ACTIONS(1352),
    [anon_sym_declare] = ACTIONS(1352),
    [anon_sym_public] = ACTIONS(1352),
    [anon_sym_private] = ACTIONS(1352),
    [anon_sym_protected] = ACTIONS(1352),
    [anon_sym_override] = ACTIONS(1352),
    [anon_sym_module] = ACTIONS(1352),
    [anon_sym_any] = ACTIONS(1352),
    [anon_sym_number] = ACTIONS(1352),
    [anon_sym_boolean] = ACTIONS(1352),
    [anon_sym_string] = ACTIONS(1352),
    [anon_sym_symbol] = ACTIONS(1352),
    [anon_sym_object] = ACTIONS(1352),
    [sym_html_comment] = ACTIONS(5),
  },
  [438] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1213),
    [sym_expression] = STATE(2577),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5522),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5522),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5800),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1213),
    [sym_subscript_expression] = STATE(1213),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3013),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5522),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1213),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(539),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(802),
    [anon_sym_export] = ACTIONS(804),
    [anon_sym_type] = ACTIONS(804),
    [anon_sym_namespace] = ACTIONS(806),
    [anon_sym_LBRACE] = ACTIONS(808),
    [anon_sym_typeof] = ACTIONS(179),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(804),
    [anon_sym_BANG] = ACTIONS(175),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(140),
    [anon_sym_yield] = ACTIONS(142),
    [anon_sym_LBRACK] = ACTIONS(812),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(816),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(818),
    [anon_sym_using] = ACTIONS(158),
    [anon_sym_PLUS] = ACTIONS(179),
    [anon_sym_DASH] = ACTIONS(179),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(175),
    [anon_sym_void] = ACTIONS(179),
    [anon_sym_delete] = ACTIONS(179),
    [anon_sym_PLUS_PLUS] = ACTIONS(686),
    [anon_sym_DASH_DASH] = ACTIONS(686),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(2173),
    [sym_private_property_identifier] = ACTIONS(192),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(822),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(804),
    [anon_sym_readonly] = ACTIONS(804),
    [anon_sym_get] = ACTIONS(804),
    [anon_sym_set] = ACTIONS(804),
    [anon_sym_declare] = ACTIONS(804),
    [anon_sym_public] = ACTIONS(804),
    [anon_sym_private] = ACTIONS(804),
    [anon_sym_protected] = ACTIONS(804),
    [anon_sym_override] = ACTIONS(804),
    [anon_sym_module] = ACTIONS(804),
    [anon_sym_any] = ACTIONS(804),
    [anon_sym_number] = ACTIONS(804),
    [anon_sym_boolean] = ACTIONS(804),
    [anon_sym_string] = ACTIONS(804),
    [anon_sym_symbol] = ACTIONS(804),
    [anon_sym_object] = ACTIONS(804),
    [sym_html_comment] = ACTIONS(5),
  },
  [439] = {
    [sym_import] = STATE(3636),
    [sym_parenthesized_expression] = STATE(1362),
    [sym_expression] = STATE(2249),
    [sym_primary_expression] = STATE(1810),
    [sym_yield_expression] = STATE(2358),
    [sym_object] = STATE(2222),
    [sym_object_pattern] = STATE(5492),
    [sym_array] = STATE(2222),
    [sym_array_pattern] = STATE(5492),
    [sym_class] = STATE(2222),
    [sym_function_expression] = STATE(2222),
    [sym_generator_function] = STATE(2222),
    [sym_arrow_function] = STATE(2222),
    [sym__call_signature] = STATE(5821),
    [sym_call_expression] = STATE(2222),
    [sym_new_expression] = STATE(1948),
    [sym_await_expression] = STATE(2358),
    [sym_member_expression] = STATE(1362),
    [sym_subscript_expression] = STATE(1362),
    [sym_assignment_expression] = STATE(2358),
    [sym__augmented_assignment_lhs] = STATE(3025),
    [sym_augmented_assignment_expression] = STATE(2358),
    [sym__destructuring_pattern] = STATE(5492),
    [sym_ternary_expression] = STATE(2358),
    [sym_binary_expression] = STATE(2358),
    [sym_unary_expression] = STATE(2358),
    [sym_update_expression] = STATE(2358),
    [sym_string] = STATE(2222),
    [sym_template_string] = STATE(2222),
    [sym_regex] = STATE(2222),
    [sym_meta_property] = STATE(2222),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1362),
    [sym_type_assertion] = STATE(2358),
    [sym_as_expression] = STATE(2358),
    [sym_satisfies_expression] = STATE(2358),
    [sym_instantiation_expression] = STATE(2358),
    [sym_internal_module] = STATE(2358),
    [sym_type_arguments] = STATE(428),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4408),
    [sym_identifier] = ACTIONS(1468),
    [anon_sym_export] = ACTIONS(1352),
    [anon_sym_type] = ACTIONS(1352),
    [anon_sym_namespace] = ACTIONS(1354),
    [anon_sym_LBRACE] = ACTIONS(665),
    [anon_sym_typeof] = ACTIONS(21),
    [anon_sym_import] = ACTIONS(669),
    [anon_sym_let] = ACTIONS(1352),
    [anon_sym_BANG] = ACTIONS(33),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_await] = ACTIONS(45),
    [anon_sym_yield] = ACTIONS(63),
    [anon_sym_LBRACK] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(676),
    [anon_sym_async] = ACTIONS(1362),
    [anon_sym_function] = ACTIONS(680),
    [anon_sym_new] = ACTIONS(1472),
    [anon_sym_using] = ACTIONS(75),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_SLASH] = ACTIONS(77),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(33),
    [anon_sym_void] = ACTIONS(21),
    [anon_sym_delete] = ACTIONS(21),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_DQUOTE] = ACTIONS(83),
    [anon_sym_SQUOTE] = ACTIONS(85),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(87),
    [sym_number] = ACTIONS(89),
    [sym_private_property_identifier] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(93),
    [sym_true] = ACTIONS(93),
    [sym_false] = ACTIONS(93),
    [sym_null] = ACTIONS(93),
    [sym_undefined] = ACTIONS(95),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1352),
    [anon_sym_readonly] = ACTIONS(1352),
    [anon_sym_get] = ACTIONS(1352),
    [anon_sym_set] = ACTIONS(1352),
    [anon_sym_declare] = ACTIONS(1352),
    [anon_sym_public] = ACTIONS(1352),
    [anon_sym_private] = ACTIONS(1352),
    [anon_sym_protected] = ACTIONS(1352),
    [anon_sym_override] = ACTIONS(1352),
    [anon_sym_module] = ACTIONS(1352),
    [anon_sym_any] = ACTIONS(1352),
    [anon_sym_number] = ACTIONS(1352),
    [anon_sym_boolean] = ACTIONS(1352),
    [anon_sym_string] = ACTIONS(1352),
    [anon_sym_symbol] = ACTIONS(1352),
    [anon_sym_object] = ACTIONS(1352),
    [sym_html_comment] = ACTIONS(5),
  },
  [440] = {
    [sym_namespace_export] = STATE(5206),
    [sym_export_clause] = STATE(4427),
    [sym_declaration] = STATE(919),
    [sym_variable_declaration] = STATE(831),
    [sym_lexical_declaration] = STATE(831),
    [sym_class_declaration] = STATE(831),
    [sym_function_declaration] = STATE(831),
    [sym_generator_function_declaration] = STATE(831),
    [sym_decorator] = STATE(1344),
    [sym_function_signature] = STATE(831),
    [sym_ambient_declaration] = STATE(831),
    [sym_abstract_class_declaration] = STATE(831),
    [sym_module] = STATE(831),
    [sym_internal_module] = STATE(824),
    [sym_import_alias] = STATE(831),
    [sym_interface_declaration] = STATE(831),
    [sym_enum_declaration] = STATE(831),
    [sym_type_alias_declaration] = STATE(831),
    [aux_sym_export_statement_repeat1] = STATE(4301),
    [aux_sym_object_repeat1] = STATE(4792),
    [aux_sym_object_pattern_repeat1] = STATE(4815),
    [anon_sym_STAR] = ACTIONS(2127),
    [anon_sym_default] = ACTIONS(2129),
    [anon_sym_type] = ACTIONS(2131),
    [anon_sym_EQ] = ACTIONS(2133),
    [anon_sym_as] = ACTIONS(2135),
    [anon_sym_namespace] = ACTIONS(2137),
    [anon_sym_LBRACE] = ACTIONS(2139),
    [anon_sym_COMMA] = ACTIONS(154),
    [anon_sym_RBRACE] = ACTIONS(667),
    [anon_sym_import] = ACTIONS(2141),
    [anon_sym_var] = ACTIONS(2143),
    [anon_sym_let] = ACTIONS(2145),
    [anon_sym_const] = ACTIONS(2147),
    [anon_sym_BANG] = ACTIONS(120),
    [anon_sym_LPAREN] = ACTIONS(2149),
    [anon_sym_SEMI] = ACTIONS(154),
    [anon_sym_in] = ACTIONS(120),
    [anon_sym_COLON] = ACTIONS(671),
    [anon_sym_LBRACK] = ACTIONS(154),
    [anon_sym_DOT] = ACTIONS(154),
    [anon_sym_class] = ACTIONS(2152),
    [anon_sym_async] = ACTIONS(2154),
    [anon_sym_function] = ACTIONS(2156),
    [anon_sym_EQ_GT] = ACTIONS(682),
    [anon_sym_QMARK_DOT] = ACTIONS(154),
    [anon_sym_PLUS_EQ] = ACTIONS(160),
    [anon_sym_DASH_EQ] = ACTIONS(160),
    [anon_sym_STAR_EQ] = ACTIONS(160),
    [anon_sym_SLASH_EQ] = ACTIONS(160),
    [anon_sym_PERCENT_EQ] = ACTIONS(160),
    [anon_sym_CARET_EQ] = ACTIONS(160),
    [anon_sym_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_LT_LT_EQ] = ACTIONS(160),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(160),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP] = ACTIONS(120),
    [anon_sym_PIPE_PIPE] = ACTIONS(120),
    [anon_sym_GT_GT] = ACTIONS(120),
    [anon_sym_GT_GT_GT] = ACTIONS(120),
    [anon_sym_LT_LT] = ACTIONS(120),
    [anon_sym_AMP] = ACTIONS(120),
    [anon_sym_CARET] = ACTIONS(120),
    [anon_sym_PIPE] = ACTIONS(120),
    [anon_sym_PLUS] = ACTIONS(120),
    [anon_sym_DASH] = ACTIONS(120),
    [anon_sym_SLASH] = ACTIONS(120),
    [anon_sym_PERCENT] = ACTIONS(120),
    [anon_sym_STAR_STAR] = ACTIONS(120),
    [anon_sym_LT] = ACTIONS(2158),
    [anon_sym_LT_EQ] = ACTIONS(154),
    [anon_sym_EQ_EQ] = ACTIONS(120),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(154),
    [anon_sym_BANG_EQ] = ACTIONS(120),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(154),
    [anon_sym_GT_EQ] = ACTIONS(154),
    [anon_sym_GT] = ACTIONS(120),
    [anon_sym_QMARK_QMARK] = ACTIONS(120),
    [anon_sym_instanceof] = ACTIONS(154),
    [anon_sym_PLUS_PLUS] = ACTIONS(154),
    [anon_sym_DASH_DASH] = ACTIONS(154),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(154),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_QMARK] = ACTIONS(690),
    [anon_sym_declare] = ACTIONS(2161),
    [anon_sym_module] = ACTIONS(2163),
    [anon_sym_abstract] = ACTIONS(2165),
    [anon_sym_satisfies] = ACTIONS(154),
    [anon_sym_interface] = ACTIONS(2167),
    [anon_sym_enum] = ACTIONS(2169),
    [sym__automatic_semicolon] = ACTIONS(154),
    [sym__ternary_qmark] = ACTIONS(154),
    [sym_html_comment] = ACTIONS(5),
  },
  [441] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1213),
    [sym_expression] = STATE(2577),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5522),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5522),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5800),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1213),
    [sym_subscript_expression] = STATE(1213),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3013),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5522),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1213),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(539),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(802),
    [anon_sym_export] = ACTIONS(804),
    [anon_sym_type] = ACTIONS(804),
    [anon_sym_namespace] = ACTIONS(806),
    [anon_sym_LBRACE] = ACTIONS(808),
    [anon_sym_typeof] = ACTIONS(179),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(804),
    [anon_sym_BANG] = ACTIONS(175),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(140),
    [anon_sym_yield] = ACTIONS(142),
    [anon_sym_LBRACK] = ACTIONS(812),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(816),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(818),
    [anon_sym_using] = ACTIONS(158),
    [anon_sym_PLUS] = ACTIONS(179),
    [anon_sym_DASH] = ACTIONS(179),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(175),
    [anon_sym_void] = ACTIONS(179),
    [anon_sym_delete] = ACTIONS(179),
    [anon_sym_PLUS_PLUS] = ACTIONS(686),
    [anon_sym_DASH_DASH] = ACTIONS(686),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(2171),
    [sym_private_property_identifier] = ACTIONS(192),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(822),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(804),
    [anon_sym_readonly] = ACTIONS(804),
    [anon_sym_get] = ACTIONS(804),
    [anon_sym_set] = ACTIONS(804),
    [anon_sym_declare] = ACTIONS(804),
    [anon_sym_public] = ACTIONS(804),
    [anon_sym_private] = ACTIONS(804),
    [anon_sym_protected] = ACTIONS(804),
    [anon_sym_override] = ACTIONS(804),
    [anon_sym_module] = ACTIONS(804),
    [anon_sym_any] = ACTIONS(804),
    [anon_sym_number] = ACTIONS(804),
    [anon_sym_boolean] = ACTIONS(804),
    [anon_sym_string] = ACTIONS(804),
    [anon_sym_symbol] = ACTIONS(804),
    [anon_sym_object] = ACTIONS(804),
    [sym_html_comment] = ACTIONS(5),
  },
  [442] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1398),
    [sym_expression] = STATE(2359),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5544),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5544),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5558),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1398),
    [sym_subscript_expression] = STATE(1398),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(2980),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5544),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1398),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(638),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1482),
    [anon_sym_export] = ACTIONS(1158),
    [anon_sym_type] = ACTIONS(1158),
    [anon_sym_namespace] = ACTIONS(1160),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_typeof] = ACTIONS(756),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1158),
    [anon_sym_BANG] = ACTIONS(732),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(736),
    [anon_sym_yield] = ACTIONS(738),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1164),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1486),
    [anon_sym_using] = ACTIONS(746),
    [anon_sym_PLUS] = ACTIONS(756),
    [anon_sym_DASH] = ACTIONS(756),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(732),
    [anon_sym_void] = ACTIONS(756),
    [anon_sym_delete] = ACTIONS(756),
    [anon_sym_PLUS_PLUS] = ACTIONS(758),
    [anon_sym_DASH_DASH] = ACTIONS(758),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(764),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1488),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1158),
    [anon_sym_readonly] = ACTIONS(1158),
    [anon_sym_get] = ACTIONS(1158),
    [anon_sym_set] = ACTIONS(1158),
    [anon_sym_declare] = ACTIONS(1158),
    [anon_sym_public] = ACTIONS(1158),
    [anon_sym_private] = ACTIONS(1158),
    [anon_sym_protected] = ACTIONS(1158),
    [anon_sym_override] = ACTIONS(1158),
    [anon_sym_module] = ACTIONS(1158),
    [anon_sym_any] = ACTIONS(1158),
    [anon_sym_number] = ACTIONS(1158),
    [anon_sym_boolean] = ACTIONS(1158),
    [anon_sym_string] = ACTIONS(1158),
    [anon_sym_symbol] = ACTIONS(1158),
    [anon_sym_object] = ACTIONS(1158),
    [sym_html_comment] = ACTIONS(5),
  },
  [443] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1213),
    [sym_expression] = STATE(2644),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(3654),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(3654),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5800),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1278),
    [sym_subscript_expression] = STATE(1278),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3013),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(3654),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1278),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(539),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(2175),
    [anon_sym_export] = ACTIONS(2177),
    [anon_sym_type] = ACTIONS(2177),
    [anon_sym_namespace] = ACTIONS(2179),
    [anon_sym_LBRACE] = ACTIONS(698),
    [anon_sym_typeof] = ACTIONS(179),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(2177),
    [anon_sym_BANG] = ACTIONS(175),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(140),
    [anon_sym_yield] = ACTIONS(142),
    [anon_sym_LBRACK] = ACTIONS(1664),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(2181),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(2183),
    [anon_sym_using] = ACTIONS(158),
    [anon_sym_PLUS] = ACTIONS(179),
    [anon_sym_DASH] = ACTIONS(179),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(175),
    [anon_sym_void] = ACTIONS(179),
    [anon_sym_delete] = ACTIONS(179),
    [anon_sym_PLUS_PLUS] = ACTIONS(686),
    [anon_sym_DASH_DASH] = ACTIONS(686),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(192),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(2185),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(2177),
    [anon_sym_readonly] = ACTIONS(2177),
    [anon_sym_get] = ACTIONS(2177),
    [anon_sym_set] = ACTIONS(2177),
    [anon_sym_declare] = ACTIONS(2177),
    [anon_sym_public] = ACTIONS(2177),
    [anon_sym_private] = ACTIONS(2177),
    [anon_sym_protected] = ACTIONS(2177),
    [anon_sym_override] = ACTIONS(2177),
    [anon_sym_module] = ACTIONS(2177),
    [anon_sym_any] = ACTIONS(2177),
    [anon_sym_number] = ACTIONS(2177),
    [anon_sym_boolean] = ACTIONS(2177),
    [anon_sym_string] = ACTIONS(2177),
    [anon_sym_symbol] = ACTIONS(2177),
    [anon_sym_object] = ACTIONS(2177),
    [sym_html_comment] = ACTIONS(5),
  },
  [444] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1322),
    [sym_expression] = STATE(1776),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5698),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5698),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5508),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1322),
    [sym_subscript_expression] = STATE(1322),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3003),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5698),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1322),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(484),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1456),
    [anon_sym_export] = ACTIONS(1048),
    [anon_sym_type] = ACTIONS(1048),
    [anon_sym_namespace] = ACTIONS(1050),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_typeof] = ACTIONS(581),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1048),
    [anon_sym_BANG] = ACTIONS(553),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(555),
    [anon_sym_yield] = ACTIONS(557),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1058),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1464),
    [anon_sym_using] = ACTIONS(567),
    [anon_sym_PLUS] = ACTIONS(581),
    [anon_sym_DASH] = ACTIONS(581),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(553),
    [anon_sym_void] = ACTIONS(581),
    [anon_sym_delete] = ACTIONS(581),
    [anon_sym_PLUS_PLUS] = ACTIONS(583),
    [anon_sym_DASH_DASH] = ACTIONS(583),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(2187),
    [sym_private_property_identifier] = ACTIONS(585),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1466),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1048),
    [anon_sym_readonly] = ACTIONS(1048),
    [anon_sym_get] = ACTIONS(1048),
    [anon_sym_set] = ACTIONS(1048),
    [anon_sym_declare] = ACTIONS(1048),
    [anon_sym_public] = ACTIONS(1048),
    [anon_sym_private] = ACTIONS(1048),
    [anon_sym_protected] = ACTIONS(1048),
    [anon_sym_override] = ACTIONS(1048),
    [anon_sym_module] = ACTIONS(1048),
    [anon_sym_any] = ACTIONS(1048),
    [anon_sym_number] = ACTIONS(1048),
    [anon_sym_boolean] = ACTIONS(1048),
    [anon_sym_string] = ACTIONS(1048),
    [anon_sym_symbol] = ACTIONS(1048),
    [anon_sym_object] = ACTIONS(1048),
    [sym_html_comment] = ACTIONS(5),
  },
  [445] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1213),
    [sym_expression] = STATE(2577),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5522),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5522),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5800),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1213),
    [sym_subscript_expression] = STATE(1213),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3013),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5522),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1213),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(539),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(802),
    [anon_sym_export] = ACTIONS(804),
    [anon_sym_type] = ACTIONS(804),
    [anon_sym_namespace] = ACTIONS(806),
    [anon_sym_LBRACE] = ACTIONS(808),
    [anon_sym_typeof] = ACTIONS(179),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(804),
    [anon_sym_BANG] = ACTIONS(175),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(140),
    [anon_sym_yield] = ACTIONS(142),
    [anon_sym_LBRACK] = ACTIONS(812),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(816),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(818),
    [anon_sym_using] = ACTIONS(158),
    [anon_sym_PLUS] = ACTIONS(179),
    [anon_sym_DASH] = ACTIONS(179),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(175),
    [anon_sym_void] = ACTIONS(179),
    [anon_sym_delete] = ACTIONS(179),
    [anon_sym_PLUS_PLUS] = ACTIONS(686),
    [anon_sym_DASH_DASH] = ACTIONS(686),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(2187),
    [sym_private_property_identifier] = ACTIONS(192),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(822),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(804),
    [anon_sym_readonly] = ACTIONS(804),
    [anon_sym_get] = ACTIONS(804),
    [anon_sym_set] = ACTIONS(804),
    [anon_sym_declare] = ACTIONS(804),
    [anon_sym_public] = ACTIONS(804),
    [anon_sym_private] = ACTIONS(804),
    [anon_sym_protected] = ACTIONS(804),
    [anon_sym_override] = ACTIONS(804),
    [anon_sym_module] = ACTIONS(804),
    [anon_sym_any] = ACTIONS(804),
    [anon_sym_number] = ACTIONS(804),
    [anon_sym_boolean] = ACTIONS(804),
    [anon_sym_string] = ACTIONS(804),
    [anon_sym_symbol] = ACTIONS(804),
    [anon_sym_object] = ACTIONS(804),
    [sym_html_comment] = ACTIONS(5),
  },
  [446] = {
    [sym_import] = STATE(3636),
    [sym_parenthesized_expression] = STATE(1362),
    [sym_expression] = STATE(1868),
    [sym_primary_expression] = STATE(1810),
    [sym_yield_expression] = STATE(2358),
    [sym_object] = STATE(2222),
    [sym_object_pattern] = STATE(5492),
    [sym_array] = STATE(2222),
    [sym_array_pattern] = STATE(5492),
    [sym_class] = STATE(2222),
    [sym_function_expression] = STATE(2222),
    [sym_generator_function] = STATE(2222),
    [sym_arrow_function] = STATE(2222),
    [sym__call_signature] = STATE(5821),
    [sym_call_expression] = STATE(2222),
    [sym_new_expression] = STATE(1948),
    [sym_await_expression] = STATE(2358),
    [sym_member_expression] = STATE(1362),
    [sym_subscript_expression] = STATE(1362),
    [sym_assignment_expression] = STATE(2358),
    [sym__augmented_assignment_lhs] = STATE(3025),
    [sym_augmented_assignment_expression] = STATE(2358),
    [sym__destructuring_pattern] = STATE(5492),
    [sym_ternary_expression] = STATE(2358),
    [sym_binary_expression] = STATE(2358),
    [sym_unary_expression] = STATE(2358),
    [sym_update_expression] = STATE(2358),
    [sym_string] = STATE(2222),
    [sym_template_string] = STATE(2222),
    [sym_regex] = STATE(2222),
    [sym_meta_property] = STATE(2222),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1362),
    [sym_type_assertion] = STATE(2358),
    [sym_as_expression] = STATE(2358),
    [sym_satisfies_expression] = STATE(2358),
    [sym_instantiation_expression] = STATE(2358),
    [sym_internal_module] = STATE(2358),
    [sym_type_arguments] = STATE(428),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4408),
    [sym_identifier] = ACTIONS(1468),
    [anon_sym_export] = ACTIONS(1352),
    [anon_sym_type] = ACTIONS(1352),
    [anon_sym_namespace] = ACTIONS(1354),
    [anon_sym_LBRACE] = ACTIONS(665),
    [anon_sym_typeof] = ACTIONS(21),
    [anon_sym_import] = ACTIONS(669),
    [anon_sym_let] = ACTIONS(1352),
    [anon_sym_BANG] = ACTIONS(33),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_await] = ACTIONS(45),
    [anon_sym_yield] = ACTIONS(63),
    [anon_sym_LBRACK] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(676),
    [anon_sym_async] = ACTIONS(1362),
    [anon_sym_function] = ACTIONS(680),
    [anon_sym_new] = ACTIONS(1472),
    [anon_sym_using] = ACTIONS(75),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_SLASH] = ACTIONS(77),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(33),
    [anon_sym_void] = ACTIONS(21),
    [anon_sym_delete] = ACTIONS(21),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_DQUOTE] = ACTIONS(83),
    [anon_sym_SQUOTE] = ACTIONS(85),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(87),
    [sym_number] = ACTIONS(89),
    [sym_private_property_identifier] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(93),
    [sym_true] = ACTIONS(93),
    [sym_false] = ACTIONS(93),
    [sym_null] = ACTIONS(93),
    [sym_undefined] = ACTIONS(95),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1352),
    [anon_sym_readonly] = ACTIONS(1352),
    [anon_sym_get] = ACTIONS(1352),
    [anon_sym_set] = ACTIONS(1352),
    [anon_sym_declare] = ACTIONS(1352),
    [anon_sym_public] = ACTIONS(1352),
    [anon_sym_private] = ACTIONS(1352),
    [anon_sym_protected] = ACTIONS(1352),
    [anon_sym_override] = ACTIONS(1352),
    [anon_sym_module] = ACTIONS(1352),
    [anon_sym_any] = ACTIONS(1352),
    [anon_sym_number] = ACTIONS(1352),
    [anon_sym_boolean] = ACTIONS(1352),
    [anon_sym_string] = ACTIONS(1352),
    [anon_sym_symbol] = ACTIONS(1352),
    [anon_sym_object] = ACTIONS(1352),
    [sym_html_comment] = ACTIONS(5),
  },
  [447] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1322),
    [sym_expression] = STATE(2370),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5698),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5698),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5508),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1322),
    [sym_subscript_expression] = STATE(1322),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3003),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5698),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1322),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(484),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1456),
    [anon_sym_export] = ACTIONS(1048),
    [anon_sym_type] = ACTIONS(1048),
    [anon_sym_namespace] = ACTIONS(1050),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_typeof] = ACTIONS(581),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1048),
    [anon_sym_BANG] = ACTIONS(553),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(555),
    [anon_sym_yield] = ACTIONS(557),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1058),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1464),
    [anon_sym_using] = ACTIONS(567),
    [anon_sym_PLUS] = ACTIONS(581),
    [anon_sym_DASH] = ACTIONS(581),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(553),
    [anon_sym_void] = ACTIONS(581),
    [anon_sym_delete] = ACTIONS(581),
    [anon_sym_PLUS_PLUS] = ACTIONS(583),
    [anon_sym_DASH_DASH] = ACTIONS(583),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(585),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1466),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1048),
    [anon_sym_readonly] = ACTIONS(1048),
    [anon_sym_get] = ACTIONS(1048),
    [anon_sym_set] = ACTIONS(1048),
    [anon_sym_declare] = ACTIONS(1048),
    [anon_sym_public] = ACTIONS(1048),
    [anon_sym_private] = ACTIONS(1048),
    [anon_sym_protected] = ACTIONS(1048),
    [anon_sym_override] = ACTIONS(1048),
    [anon_sym_module] = ACTIONS(1048),
    [anon_sym_any] = ACTIONS(1048),
    [anon_sym_number] = ACTIONS(1048),
    [anon_sym_boolean] = ACTIONS(1048),
    [anon_sym_string] = ACTIONS(1048),
    [anon_sym_symbol] = ACTIONS(1048),
    [anon_sym_object] = ACTIONS(1048),
    [sym_html_comment] = ACTIONS(5),
  },
  [448] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1322),
    [sym_expression] = STATE(2371),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5698),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5698),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5508),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1322),
    [sym_subscript_expression] = STATE(1322),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3003),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5698),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1322),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(484),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1456),
    [anon_sym_export] = ACTIONS(1048),
    [anon_sym_type] = ACTIONS(1048),
    [anon_sym_namespace] = ACTIONS(1050),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_typeof] = ACTIONS(581),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1048),
    [anon_sym_BANG] = ACTIONS(553),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(555),
    [anon_sym_yield] = ACTIONS(557),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1058),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1464),
    [anon_sym_using] = ACTIONS(567),
    [anon_sym_PLUS] = ACTIONS(581),
    [anon_sym_DASH] = ACTIONS(581),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(553),
    [anon_sym_void] = ACTIONS(581),
    [anon_sym_delete] = ACTIONS(581),
    [anon_sym_PLUS_PLUS] = ACTIONS(583),
    [anon_sym_DASH_DASH] = ACTIONS(583),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(585),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1466),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1048),
    [anon_sym_readonly] = ACTIONS(1048),
    [anon_sym_get] = ACTIONS(1048),
    [anon_sym_set] = ACTIONS(1048),
    [anon_sym_declare] = ACTIONS(1048),
    [anon_sym_public] = ACTIONS(1048),
    [anon_sym_private] = ACTIONS(1048),
    [anon_sym_protected] = ACTIONS(1048),
    [anon_sym_override] = ACTIONS(1048),
    [anon_sym_module] = ACTIONS(1048),
    [anon_sym_any] = ACTIONS(1048),
    [anon_sym_number] = ACTIONS(1048),
    [anon_sym_boolean] = ACTIONS(1048),
    [anon_sym_string] = ACTIONS(1048),
    [anon_sym_symbol] = ACTIONS(1048),
    [anon_sym_object] = ACTIONS(1048),
    [sym_html_comment] = ACTIONS(5),
  },
  [449] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1322),
    [sym_expression] = STATE(1776),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5698),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5698),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5508),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1322),
    [sym_subscript_expression] = STATE(1322),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3003),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5698),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1322),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(484),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1456),
    [anon_sym_export] = ACTIONS(1048),
    [anon_sym_type] = ACTIONS(1048),
    [anon_sym_namespace] = ACTIONS(1050),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_typeof] = ACTIONS(581),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1048),
    [anon_sym_BANG] = ACTIONS(553),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(555),
    [anon_sym_yield] = ACTIONS(557),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1058),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1464),
    [anon_sym_using] = ACTIONS(567),
    [anon_sym_PLUS] = ACTIONS(581),
    [anon_sym_DASH] = ACTIONS(581),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(553),
    [anon_sym_void] = ACTIONS(581),
    [anon_sym_delete] = ACTIONS(581),
    [anon_sym_PLUS_PLUS] = ACTIONS(583),
    [anon_sym_DASH_DASH] = ACTIONS(583),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(2189),
    [sym_private_property_identifier] = ACTIONS(585),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1466),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1048),
    [anon_sym_readonly] = ACTIONS(1048),
    [anon_sym_get] = ACTIONS(1048),
    [anon_sym_set] = ACTIONS(1048),
    [anon_sym_declare] = ACTIONS(1048),
    [anon_sym_public] = ACTIONS(1048),
    [anon_sym_private] = ACTIONS(1048),
    [anon_sym_protected] = ACTIONS(1048),
    [anon_sym_override] = ACTIONS(1048),
    [anon_sym_module] = ACTIONS(1048),
    [anon_sym_any] = ACTIONS(1048),
    [anon_sym_number] = ACTIONS(1048),
    [anon_sym_boolean] = ACTIONS(1048),
    [anon_sym_string] = ACTIONS(1048),
    [anon_sym_symbol] = ACTIONS(1048),
    [anon_sym_object] = ACTIONS(1048),
    [sym_html_comment] = ACTIONS(5),
  },
  [450] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1471),
    [sym_expression] = STATE(2644),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5758),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5758),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5800),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1471),
    [sym_subscript_expression] = STATE(1471),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3013),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5758),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1471),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(539),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(2191),
    [anon_sym_export] = ACTIONS(2193),
    [anon_sym_type] = ACTIONS(2193),
    [anon_sym_namespace] = ACTIONS(2195),
    [anon_sym_LBRACE] = ACTIONS(808),
    [anon_sym_typeof] = ACTIONS(179),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(2193),
    [anon_sym_BANG] = ACTIONS(175),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(140),
    [anon_sym_yield] = ACTIONS(142),
    [anon_sym_LBRACK] = ACTIONS(812),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(2197),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(2199),
    [anon_sym_using] = ACTIONS(158),
    [anon_sym_PLUS] = ACTIONS(179),
    [anon_sym_DASH] = ACTIONS(179),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(175),
    [anon_sym_void] = ACTIONS(179),
    [anon_sym_delete] = ACTIONS(179),
    [anon_sym_PLUS_PLUS] = ACTIONS(686),
    [anon_sym_DASH_DASH] = ACTIONS(686),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(192),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(2201),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(2193),
    [anon_sym_readonly] = ACTIONS(2193),
    [anon_sym_get] = ACTIONS(2193),
    [anon_sym_set] = ACTIONS(2193),
    [anon_sym_declare] = ACTIONS(2193),
    [anon_sym_public] = ACTIONS(2193),
    [anon_sym_private] = ACTIONS(2193),
    [anon_sym_protected] = ACTIONS(2193),
    [anon_sym_override] = ACTIONS(2193),
    [anon_sym_module] = ACTIONS(2193),
    [anon_sym_any] = ACTIONS(2193),
    [anon_sym_number] = ACTIONS(2193),
    [anon_sym_boolean] = ACTIONS(2193),
    [anon_sym_string] = ACTIONS(2193),
    [anon_sym_symbol] = ACTIONS(2193),
    [anon_sym_object] = ACTIONS(2193),
    [sym_html_comment] = ACTIONS(5),
  },
  [451] = {
    [sym_import] = STATE(3636),
    [sym_parenthesized_expression] = STATE(1364),
    [sym_expression] = STATE(1831),
    [sym_primary_expression] = STATE(1810),
    [sym_yield_expression] = STATE(2358),
    [sym_object] = STATE(2222),
    [sym_object_pattern] = STATE(5773),
    [sym_array] = STATE(2222),
    [sym_array_pattern] = STATE(5773),
    [sym_class] = STATE(2222),
    [sym_function_expression] = STATE(2222),
    [sym_generator_function] = STATE(2222),
    [sym_arrow_function] = STATE(2222),
    [sym__call_signature] = STATE(5771),
    [sym_call_expression] = STATE(2222),
    [sym_new_expression] = STATE(1948),
    [sym_await_expression] = STATE(2358),
    [sym_member_expression] = STATE(1364),
    [sym_subscript_expression] = STATE(1364),
    [sym_assignment_expression] = STATE(2358),
    [sym__augmented_assignment_lhs] = STATE(3020),
    [sym_augmented_assignment_expression] = STATE(2358),
    [sym__destructuring_pattern] = STATE(5773),
    [sym_ternary_expression] = STATE(2358),
    [sym_binary_expression] = STATE(2358),
    [sym_unary_expression] = STATE(2358),
    [sym_update_expression] = STATE(2358),
    [sym_string] = STATE(2222),
    [sym_template_string] = STATE(2222),
    [sym_regex] = STATE(2222),
    [sym_meta_property] = STATE(2222),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1364),
    [sym_type_assertion] = STATE(2358),
    [sym_as_expression] = STATE(2358),
    [sym_satisfies_expression] = STATE(2358),
    [sym_instantiation_expression] = STATE(2358),
    [sym_internal_module] = STATE(2358),
    [sym_type_arguments] = STATE(513),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4408),
    [sym_identifier] = ACTIONS(1474),
    [anon_sym_export] = ACTIONS(1386),
    [anon_sym_type] = ACTIONS(1386),
    [anon_sym_namespace] = ACTIONS(1388),
    [anon_sym_LBRACE] = ACTIONS(665),
    [anon_sym_typeof] = ACTIONS(1408),
    [anon_sym_import] = ACTIONS(669),
    [anon_sym_let] = ACTIONS(1386),
    [anon_sym_BANG] = ACTIONS(1392),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_await] = ACTIONS(1394),
    [anon_sym_yield] = ACTIONS(1396),
    [anon_sym_LBRACK] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(676),
    [anon_sym_async] = ACTIONS(1398),
    [anon_sym_function] = ACTIONS(680),
    [anon_sym_new] = ACTIONS(1478),
    [anon_sym_using] = ACTIONS(1402),
    [anon_sym_PLUS] = ACTIONS(1408),
    [anon_sym_DASH] = ACTIONS(1408),
    [anon_sym_SLASH] = ACTIONS(876),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(1392),
    [anon_sym_void] = ACTIONS(1408),
    [anon_sym_delete] = ACTIONS(1408),
    [anon_sym_PLUS_PLUS] = ACTIONS(1410),
    [anon_sym_DASH_DASH] = ACTIONS(1410),
    [anon_sym_DQUOTE] = ACTIONS(83),
    [anon_sym_SQUOTE] = ACTIONS(85),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(87),
    [sym_number] = ACTIONS(89),
    [sym_private_property_identifier] = ACTIONS(1412),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(93),
    [sym_true] = ACTIONS(93),
    [sym_false] = ACTIONS(93),
    [sym_null] = ACTIONS(93),
    [sym_undefined] = ACTIONS(1480),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1386),
    [anon_sym_readonly] = ACTIONS(1386),
    [anon_sym_get] = ACTIONS(1386),
    [anon_sym_set] = ACTIONS(1386),
    [anon_sym_declare] = ACTIONS(1386),
    [anon_sym_public] = ACTIONS(1386),
    [anon_sym_private] = ACTIONS(1386),
    [anon_sym_protected] = ACTIONS(1386),
    [anon_sym_override] = ACTIONS(1386),
    [anon_sym_module] = ACTIONS(1386),
    [anon_sym_any] = ACTIONS(1386),
    [anon_sym_number] = ACTIONS(1386),
    [anon_sym_boolean] = ACTIONS(1386),
    [anon_sym_string] = ACTIONS(1386),
    [anon_sym_symbol] = ACTIONS(1386),
    [anon_sym_object] = ACTIONS(1386),
    [sym_html_comment] = ACTIONS(5),
  },
  [452] = {
    [sym_import] = STATE(3636),
    [sym_parenthesized_expression] = STATE(1410),
    [sym_expression] = STATE(2131),
    [sym_primary_expression] = STATE(1810),
    [sym_yield_expression] = STATE(2358),
    [sym_object] = STATE(2222),
    [sym_object_pattern] = STATE(5580),
    [sym_array] = STATE(2222),
    [sym_array_pattern] = STATE(5580),
    [sym_class] = STATE(2222),
    [sym_function_expression] = STATE(2222),
    [sym_generator_function] = STATE(2222),
    [sym_arrow_function] = STATE(2222),
    [sym__call_signature] = STATE(5466),
    [sym_call_expression] = STATE(2222),
    [sym_new_expression] = STATE(1948),
    [sym_await_expression] = STATE(2358),
    [sym_member_expression] = STATE(1410),
    [sym_subscript_expression] = STATE(1410),
    [sym_assignment_expression] = STATE(2358),
    [sym__augmented_assignment_lhs] = STATE(3004),
    [sym_augmented_assignment_expression] = STATE(2358),
    [sym__destructuring_pattern] = STATE(5580),
    [sym_ternary_expression] = STATE(2358),
    [sym_binary_expression] = STATE(2358),
    [sym_unary_expression] = STATE(2358),
    [sym_update_expression] = STATE(2358),
    [sym_string] = STATE(2222),
    [sym_template_string] = STATE(2222),
    [sym_regex] = STATE(2222),
    [sym_meta_property] = STATE(2222),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1410),
    [sym_type_assertion] = STATE(2358),
    [sym_as_expression] = STATE(2358),
    [sym_satisfies_expression] = STATE(2358),
    [sym_instantiation_expression] = STATE(2358),
    [sym_internal_module] = STATE(2358),
    [sym_type_arguments] = STATE(452),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4408),
    [sym_identifier] = ACTIONS(1498),
    [anon_sym_export] = ACTIONS(1270),
    [anon_sym_type] = ACTIONS(1270),
    [anon_sym_namespace] = ACTIONS(1272),
    [anon_sym_LBRACE] = ACTIONS(665),
    [anon_sym_typeof] = ACTIONS(1298),
    [anon_sym_import] = ACTIONS(669),
    [anon_sym_let] = ACTIONS(1270),
    [anon_sym_BANG] = ACTIONS(1278),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_await] = ACTIONS(1282),
    [anon_sym_yield] = ACTIONS(1284),
    [anon_sym_LBRACK] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(676),
    [anon_sym_async] = ACTIONS(1288),
    [anon_sym_function] = ACTIONS(680),
    [anon_sym_new] = ACTIONS(1502),
    [anon_sym_using] = ACTIONS(1292),
    [anon_sym_PLUS] = ACTIONS(1298),
    [anon_sym_DASH] = ACTIONS(1298),
    [anon_sym_SLASH] = ACTIONS(77),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(1278),
    [anon_sym_void] = ACTIONS(1298),
    [anon_sym_delete] = ACTIONS(1298),
    [anon_sym_PLUS_PLUS] = ACTIONS(1300),
    [anon_sym_DASH_DASH] = ACTIONS(1300),
    [anon_sym_DQUOTE] = ACTIONS(83),
    [anon_sym_SQUOTE] = ACTIONS(85),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(87),
    [sym_number] = ACTIONS(89),
    [sym_private_property_identifier] = ACTIONS(1306),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(93),
    [sym_true] = ACTIONS(93),
    [sym_false] = ACTIONS(93),
    [sym_null] = ACTIONS(93),
    [sym_undefined] = ACTIONS(1504),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1270),
    [anon_sym_readonly] = ACTIONS(1270),
    [anon_sym_get] = ACTIONS(1270),
    [anon_sym_set] = ACTIONS(1270),
    [anon_sym_declare] = ACTIONS(1270),
    [anon_sym_public] = ACTIONS(1270),
    [anon_sym_private] = ACTIONS(1270),
    [anon_sym_protected] = ACTIONS(1270),
    [anon_sym_override] = ACTIONS(1270),
    [anon_sym_module] = ACTIONS(1270),
    [anon_sym_any] = ACTIONS(1270),
    [anon_sym_number] = ACTIONS(1270),
    [anon_sym_boolean] = ACTIONS(1270),
    [anon_sym_string] = ACTIONS(1270),
    [anon_sym_symbol] = ACTIONS(1270),
    [anon_sym_object] = ACTIONS(1270),
    [sym_html_comment] = ACTIONS(5),
  },
  [453] = {
    [sym_import] = STATE(3636),
    [sym_parenthesized_expression] = STATE(1362),
    [sym_expression] = STATE(1802),
    [sym_primary_expression] = STATE(1810),
    [sym_yield_expression] = STATE(2358),
    [sym_object] = STATE(2222),
    [sym_object_pattern] = STATE(5492),
    [sym_array] = STATE(2222),
    [sym_array_pattern] = STATE(5492),
    [sym_class] = STATE(2222),
    [sym_function_expression] = STATE(2222),
    [sym_generator_function] = STATE(2222),
    [sym_arrow_function] = STATE(2222),
    [sym__call_signature] = STATE(5821),
    [sym_call_expression] = STATE(2222),
    [sym_new_expression] = STATE(1948),
    [sym_await_expression] = STATE(2358),
    [sym_member_expression] = STATE(1362),
    [sym_subscript_expression] = STATE(1362),
    [sym_assignment_expression] = STATE(2358),
    [sym__augmented_assignment_lhs] = STATE(3025),
    [sym_augmented_assignment_expression] = STATE(2358),
    [sym__destructuring_pattern] = STATE(5492),
    [sym_ternary_expression] = STATE(2358),
    [sym_binary_expression] = STATE(2358),
    [sym_unary_expression] = STATE(2358),
    [sym_update_expression] = STATE(2358),
    [sym_string] = STATE(2222),
    [sym_template_string] = STATE(2222),
    [sym_regex] = STATE(2222),
    [sym_meta_property] = STATE(2222),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1362),
    [sym_type_assertion] = STATE(2358),
    [sym_as_expression] = STATE(2358),
    [sym_satisfies_expression] = STATE(2358),
    [sym_instantiation_expression] = STATE(2358),
    [sym_internal_module] = STATE(2358),
    [sym_type_arguments] = STATE(428),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4408),
    [sym_identifier] = ACTIONS(1468),
    [anon_sym_export] = ACTIONS(1352),
    [anon_sym_type] = ACTIONS(1352),
    [anon_sym_namespace] = ACTIONS(1354),
    [anon_sym_LBRACE] = ACTIONS(665),
    [anon_sym_typeof] = ACTIONS(21),
    [anon_sym_import] = ACTIONS(669),
    [anon_sym_let] = ACTIONS(1352),
    [anon_sym_BANG] = ACTIONS(33),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_await] = ACTIONS(45),
    [anon_sym_yield] = ACTIONS(63),
    [anon_sym_LBRACK] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(676),
    [anon_sym_async] = ACTIONS(1362),
    [anon_sym_function] = ACTIONS(680),
    [anon_sym_new] = ACTIONS(1472),
    [anon_sym_using] = ACTIONS(75),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_SLASH] = ACTIONS(77),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(33),
    [anon_sym_void] = ACTIONS(21),
    [anon_sym_delete] = ACTIONS(21),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_DQUOTE] = ACTIONS(83),
    [anon_sym_SQUOTE] = ACTIONS(85),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(87),
    [sym_number] = ACTIONS(89),
    [sym_private_property_identifier] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(93),
    [sym_true] = ACTIONS(93),
    [sym_false] = ACTIONS(93),
    [sym_null] = ACTIONS(93),
    [sym_undefined] = ACTIONS(95),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1352),
    [anon_sym_readonly] = ACTIONS(1352),
    [anon_sym_get] = ACTIONS(1352),
    [anon_sym_set] = ACTIONS(1352),
    [anon_sym_declare] = ACTIONS(1352),
    [anon_sym_public] = ACTIONS(1352),
    [anon_sym_private] = ACTIONS(1352),
    [anon_sym_protected] = ACTIONS(1352),
    [anon_sym_override] = ACTIONS(1352),
    [anon_sym_module] = ACTIONS(1352),
    [anon_sym_any] = ACTIONS(1352),
    [anon_sym_number] = ACTIONS(1352),
    [anon_sym_boolean] = ACTIONS(1352),
    [anon_sym_string] = ACTIONS(1352),
    [anon_sym_symbol] = ACTIONS(1352),
    [anon_sym_object] = ACTIONS(1352),
    [sym_html_comment] = ACTIONS(5),
  },
  [454] = {
    [sym_import] = STATE(3636),
    [sym_parenthesized_expression] = STATE(1410),
    [sym_expression] = STATE(2133),
    [sym_primary_expression] = STATE(1810),
    [sym_yield_expression] = STATE(2358),
    [sym_object] = STATE(2222),
    [sym_object_pattern] = STATE(5580),
    [sym_array] = STATE(2222),
    [sym_array_pattern] = STATE(5580),
    [sym_class] = STATE(2222),
    [sym_function_expression] = STATE(2222),
    [sym_generator_function] = STATE(2222),
    [sym_arrow_function] = STATE(2222),
    [sym__call_signature] = STATE(5466),
    [sym_call_expression] = STATE(2222),
    [sym_new_expression] = STATE(1948),
    [sym_await_expression] = STATE(2358),
    [sym_member_expression] = STATE(1410),
    [sym_subscript_expression] = STATE(1410),
    [sym_assignment_expression] = STATE(2358),
    [sym__augmented_assignment_lhs] = STATE(3004),
    [sym_augmented_assignment_expression] = STATE(2358),
    [sym__destructuring_pattern] = STATE(5580),
    [sym_ternary_expression] = STATE(2358),
    [sym_binary_expression] = STATE(2358),
    [sym_unary_expression] = STATE(2358),
    [sym_update_expression] = STATE(2358),
    [sym_string] = STATE(2222),
    [sym_template_string] = STATE(2222),
    [sym_regex] = STATE(2222),
    [sym_meta_property] = STATE(2222),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1410),
    [sym_type_assertion] = STATE(2358),
    [sym_as_expression] = STATE(2358),
    [sym_satisfies_expression] = STATE(2358),
    [sym_instantiation_expression] = STATE(2358),
    [sym_internal_module] = STATE(2358),
    [sym_type_arguments] = STATE(452),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4408),
    [sym_identifier] = ACTIONS(1498),
    [anon_sym_export] = ACTIONS(1270),
    [anon_sym_type] = ACTIONS(1270),
    [anon_sym_namespace] = ACTIONS(1272),
    [anon_sym_LBRACE] = ACTIONS(665),
    [anon_sym_typeof] = ACTIONS(1298),
    [anon_sym_import] = ACTIONS(669),
    [anon_sym_let] = ACTIONS(1270),
    [anon_sym_BANG] = ACTIONS(1278),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_await] = ACTIONS(1282),
    [anon_sym_yield] = ACTIONS(1284),
    [anon_sym_LBRACK] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(676),
    [anon_sym_async] = ACTIONS(1288),
    [anon_sym_function] = ACTIONS(680),
    [anon_sym_new] = ACTIONS(1502),
    [anon_sym_using] = ACTIONS(1292),
    [anon_sym_PLUS] = ACTIONS(1298),
    [anon_sym_DASH] = ACTIONS(1298),
    [anon_sym_SLASH] = ACTIONS(77),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(1278),
    [anon_sym_void] = ACTIONS(1298),
    [anon_sym_delete] = ACTIONS(1298),
    [anon_sym_PLUS_PLUS] = ACTIONS(1300),
    [anon_sym_DASH_DASH] = ACTIONS(1300),
    [anon_sym_DQUOTE] = ACTIONS(83),
    [anon_sym_SQUOTE] = ACTIONS(85),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(87),
    [sym_number] = ACTIONS(89),
    [sym_private_property_identifier] = ACTIONS(1306),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(93),
    [sym_true] = ACTIONS(93),
    [sym_false] = ACTIONS(93),
    [sym_null] = ACTIONS(93),
    [sym_undefined] = ACTIONS(1504),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1270),
    [anon_sym_readonly] = ACTIONS(1270),
    [anon_sym_get] = ACTIONS(1270),
    [anon_sym_set] = ACTIONS(1270),
    [anon_sym_declare] = ACTIONS(1270),
    [anon_sym_public] = ACTIONS(1270),
    [anon_sym_private] = ACTIONS(1270),
    [anon_sym_protected] = ACTIONS(1270),
    [anon_sym_override] = ACTIONS(1270),
    [anon_sym_module] = ACTIONS(1270),
    [anon_sym_any] = ACTIONS(1270),
    [anon_sym_number] = ACTIONS(1270),
    [anon_sym_boolean] = ACTIONS(1270),
    [anon_sym_string] = ACTIONS(1270),
    [anon_sym_symbol] = ACTIONS(1270),
    [anon_sym_object] = ACTIONS(1270),
    [sym_html_comment] = ACTIONS(5),
  },
  [455] = {
    [sym_import] = STATE(3636),
    [sym_parenthesized_expression] = STATE(1410),
    [sym_expression] = STATE(2136),
    [sym_primary_expression] = STATE(1810),
    [sym_yield_expression] = STATE(2358),
    [sym_object] = STATE(2222),
    [sym_object_pattern] = STATE(5580),
    [sym_array] = STATE(2222),
    [sym_array_pattern] = STATE(5580),
    [sym_class] = STATE(2222),
    [sym_function_expression] = STATE(2222),
    [sym_generator_function] = STATE(2222),
    [sym_arrow_function] = STATE(2222),
    [sym__call_signature] = STATE(5466),
    [sym_call_expression] = STATE(2222),
    [sym_new_expression] = STATE(1948),
    [sym_await_expression] = STATE(2358),
    [sym_member_expression] = STATE(1410),
    [sym_subscript_expression] = STATE(1410),
    [sym_assignment_expression] = STATE(2358),
    [sym__augmented_assignment_lhs] = STATE(3004),
    [sym_augmented_assignment_expression] = STATE(2358),
    [sym__destructuring_pattern] = STATE(5580),
    [sym_ternary_expression] = STATE(2358),
    [sym_binary_expression] = STATE(2358),
    [sym_unary_expression] = STATE(2358),
    [sym_update_expression] = STATE(2358),
    [sym_string] = STATE(2222),
    [sym_template_string] = STATE(2222),
    [sym_regex] = STATE(2222),
    [sym_meta_property] = STATE(2222),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1410),
    [sym_type_assertion] = STATE(2358),
    [sym_as_expression] = STATE(2358),
    [sym_satisfies_expression] = STATE(2358),
    [sym_instantiation_expression] = STATE(2358),
    [sym_internal_module] = STATE(2358),
    [sym_type_arguments] = STATE(452),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4408),
    [sym_identifier] = ACTIONS(1498),
    [anon_sym_export] = ACTIONS(1270),
    [anon_sym_type] = ACTIONS(1270),
    [anon_sym_namespace] = ACTIONS(1272),
    [anon_sym_LBRACE] = ACTIONS(665),
    [anon_sym_typeof] = ACTIONS(1298),
    [anon_sym_import] = ACTIONS(669),
    [anon_sym_let] = ACTIONS(1270),
    [anon_sym_BANG] = ACTIONS(1278),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_await] = ACTIONS(1282),
    [anon_sym_yield] = ACTIONS(1284),
    [anon_sym_LBRACK] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(676),
    [anon_sym_async] = ACTIONS(1288),
    [anon_sym_function] = ACTIONS(680),
    [anon_sym_new] = ACTIONS(1502),
    [anon_sym_using] = ACTIONS(1292),
    [anon_sym_PLUS] = ACTIONS(1298),
    [anon_sym_DASH] = ACTIONS(1298),
    [anon_sym_SLASH] = ACTIONS(77),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(1278),
    [anon_sym_void] = ACTIONS(1298),
    [anon_sym_delete] = ACTIONS(1298),
    [anon_sym_PLUS_PLUS] = ACTIONS(1300),
    [anon_sym_DASH_DASH] = ACTIONS(1300),
    [anon_sym_DQUOTE] = ACTIONS(83),
    [anon_sym_SQUOTE] = ACTIONS(85),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(87),
    [sym_number] = ACTIONS(89),
    [sym_private_property_identifier] = ACTIONS(1306),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(93),
    [sym_true] = ACTIONS(93),
    [sym_false] = ACTIONS(93),
    [sym_null] = ACTIONS(93),
    [sym_undefined] = ACTIONS(1504),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1270),
    [anon_sym_readonly] = ACTIONS(1270),
    [anon_sym_get] = ACTIONS(1270),
    [anon_sym_set] = ACTIONS(1270),
    [anon_sym_declare] = ACTIONS(1270),
    [anon_sym_public] = ACTIONS(1270),
    [anon_sym_private] = ACTIONS(1270),
    [anon_sym_protected] = ACTIONS(1270),
    [anon_sym_override] = ACTIONS(1270),
    [anon_sym_module] = ACTIONS(1270),
    [anon_sym_any] = ACTIONS(1270),
    [anon_sym_number] = ACTIONS(1270),
    [anon_sym_boolean] = ACTIONS(1270),
    [anon_sym_string] = ACTIONS(1270),
    [anon_sym_symbol] = ACTIONS(1270),
    [anon_sym_object] = ACTIONS(1270),
    [sym_html_comment] = ACTIONS(5),
  },
  [456] = {
    [sym_import] = STATE(3636),
    [sym_parenthesized_expression] = STATE(1410),
    [sym_expression] = STATE(2139),
    [sym_primary_expression] = STATE(1810),
    [sym_yield_expression] = STATE(2358),
    [sym_object] = STATE(2222),
    [sym_object_pattern] = STATE(5580),
    [sym_array] = STATE(2222),
    [sym_array_pattern] = STATE(5580),
    [sym_class] = STATE(2222),
    [sym_function_expression] = STATE(2222),
    [sym_generator_function] = STATE(2222),
    [sym_arrow_function] = STATE(2222),
    [sym__call_signature] = STATE(5466),
    [sym_call_expression] = STATE(2222),
    [sym_new_expression] = STATE(1948),
    [sym_await_expression] = STATE(2358),
    [sym_member_expression] = STATE(1410),
    [sym_subscript_expression] = STATE(1410),
    [sym_assignment_expression] = STATE(2358),
    [sym__augmented_assignment_lhs] = STATE(3004),
    [sym_augmented_assignment_expression] = STATE(2358),
    [sym__destructuring_pattern] = STATE(5580),
    [sym_ternary_expression] = STATE(2358),
    [sym_binary_expression] = STATE(2358),
    [sym_unary_expression] = STATE(2358),
    [sym_update_expression] = STATE(2358),
    [sym_string] = STATE(2222),
    [sym_template_string] = STATE(2222),
    [sym_regex] = STATE(2222),
    [sym_meta_property] = STATE(2222),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1410),
    [sym_type_assertion] = STATE(2358),
    [sym_as_expression] = STATE(2358),
    [sym_satisfies_expression] = STATE(2358),
    [sym_instantiation_expression] = STATE(2358),
    [sym_internal_module] = STATE(2358),
    [sym_type_arguments] = STATE(452),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4408),
    [sym_identifier] = ACTIONS(1498),
    [anon_sym_export] = ACTIONS(1270),
    [anon_sym_type] = ACTIONS(1270),
    [anon_sym_namespace] = ACTIONS(1272),
    [anon_sym_LBRACE] = ACTIONS(665),
    [anon_sym_typeof] = ACTIONS(1298),
    [anon_sym_import] = ACTIONS(669),
    [anon_sym_let] = ACTIONS(1270),
    [anon_sym_BANG] = ACTIONS(1278),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_await] = ACTIONS(1282),
    [anon_sym_yield] = ACTIONS(1284),
    [anon_sym_LBRACK] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(676),
    [anon_sym_async] = ACTIONS(1288),
    [anon_sym_function] = ACTIONS(680),
    [anon_sym_new] = ACTIONS(1502),
    [anon_sym_using] = ACTIONS(1292),
    [anon_sym_PLUS] = ACTIONS(1298),
    [anon_sym_DASH] = ACTIONS(1298),
    [anon_sym_SLASH] = ACTIONS(77),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(1278),
    [anon_sym_void] = ACTIONS(1298),
    [anon_sym_delete] = ACTIONS(1298),
    [anon_sym_PLUS_PLUS] = ACTIONS(1300),
    [anon_sym_DASH_DASH] = ACTIONS(1300),
    [anon_sym_DQUOTE] = ACTIONS(83),
    [anon_sym_SQUOTE] = ACTIONS(85),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(87),
    [sym_number] = ACTIONS(89),
    [sym_private_property_identifier] = ACTIONS(1306),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(93),
    [sym_true] = ACTIONS(93),
    [sym_false] = ACTIONS(93),
    [sym_null] = ACTIONS(93),
    [sym_undefined] = ACTIONS(1504),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1270),
    [anon_sym_readonly] = ACTIONS(1270),
    [anon_sym_get] = ACTIONS(1270),
    [anon_sym_set] = ACTIONS(1270),
    [anon_sym_declare] = ACTIONS(1270),
    [anon_sym_public] = ACTIONS(1270),
    [anon_sym_private] = ACTIONS(1270),
    [anon_sym_protected] = ACTIONS(1270),
    [anon_sym_override] = ACTIONS(1270),
    [anon_sym_module] = ACTIONS(1270),
    [anon_sym_any] = ACTIONS(1270),
    [anon_sym_number] = ACTIONS(1270),
    [anon_sym_boolean] = ACTIONS(1270),
    [anon_sym_string] = ACTIONS(1270),
    [anon_sym_symbol] = ACTIONS(1270),
    [anon_sym_object] = ACTIONS(1270),
    [sym_html_comment] = ACTIONS(5),
  },
  [457] = {
    [sym_import] = STATE(3636),
    [sym_parenthesized_expression] = STATE(1362),
    [sym_expression] = STATE(1791),
    [sym_primary_expression] = STATE(1810),
    [sym_yield_expression] = STATE(2358),
    [sym_object] = STATE(2222),
    [sym_object_pattern] = STATE(5492),
    [sym_array] = STATE(2222),
    [sym_array_pattern] = STATE(5492),
    [sym_class] = STATE(2222),
    [sym_function_expression] = STATE(2222),
    [sym_generator_function] = STATE(2222),
    [sym_arrow_function] = STATE(2222),
    [sym__call_signature] = STATE(5821),
    [sym_call_expression] = STATE(2222),
    [sym_new_expression] = STATE(1948),
    [sym_await_expression] = STATE(2358),
    [sym_member_expression] = STATE(1362),
    [sym_subscript_expression] = STATE(1362),
    [sym_assignment_expression] = STATE(2358),
    [sym__augmented_assignment_lhs] = STATE(3025),
    [sym_augmented_assignment_expression] = STATE(2358),
    [sym__destructuring_pattern] = STATE(5492),
    [sym_ternary_expression] = STATE(2358),
    [sym_binary_expression] = STATE(2358),
    [sym_unary_expression] = STATE(2358),
    [sym_update_expression] = STATE(2358),
    [sym_string] = STATE(2222),
    [sym_template_string] = STATE(2222),
    [sym_regex] = STATE(2222),
    [sym_meta_property] = STATE(2222),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1362),
    [sym_type_assertion] = STATE(2358),
    [sym_as_expression] = STATE(2358),
    [sym_satisfies_expression] = STATE(2358),
    [sym_instantiation_expression] = STATE(2358),
    [sym_internal_module] = STATE(2358),
    [sym_type_arguments] = STATE(428),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4408),
    [sym_identifier] = ACTIONS(1468),
    [anon_sym_export] = ACTIONS(1352),
    [anon_sym_type] = ACTIONS(1352),
    [anon_sym_namespace] = ACTIONS(1354),
    [anon_sym_LBRACE] = ACTIONS(665),
    [anon_sym_typeof] = ACTIONS(21),
    [anon_sym_import] = ACTIONS(669),
    [anon_sym_let] = ACTIONS(1352),
    [anon_sym_BANG] = ACTIONS(33),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_await] = ACTIONS(45),
    [anon_sym_yield] = ACTIONS(63),
    [anon_sym_LBRACK] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(676),
    [anon_sym_async] = ACTIONS(1362),
    [anon_sym_function] = ACTIONS(680),
    [anon_sym_new] = ACTIONS(1472),
    [anon_sym_using] = ACTIONS(75),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_SLASH] = ACTIONS(77),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(33),
    [anon_sym_void] = ACTIONS(21),
    [anon_sym_delete] = ACTIONS(21),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_DQUOTE] = ACTIONS(83),
    [anon_sym_SQUOTE] = ACTIONS(85),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(87),
    [sym_number] = ACTIONS(89),
    [sym_private_property_identifier] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(93),
    [sym_true] = ACTIONS(93),
    [sym_false] = ACTIONS(93),
    [sym_null] = ACTIONS(93),
    [sym_undefined] = ACTIONS(95),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1352),
    [anon_sym_readonly] = ACTIONS(1352),
    [anon_sym_get] = ACTIONS(1352),
    [anon_sym_set] = ACTIONS(1352),
    [anon_sym_declare] = ACTIONS(1352),
    [anon_sym_public] = ACTIONS(1352),
    [anon_sym_private] = ACTIONS(1352),
    [anon_sym_protected] = ACTIONS(1352),
    [anon_sym_override] = ACTIONS(1352),
    [anon_sym_module] = ACTIONS(1352),
    [anon_sym_any] = ACTIONS(1352),
    [anon_sym_number] = ACTIONS(1352),
    [anon_sym_boolean] = ACTIONS(1352),
    [anon_sym_string] = ACTIONS(1352),
    [anon_sym_symbol] = ACTIONS(1352),
    [anon_sym_object] = ACTIONS(1352),
    [sym_html_comment] = ACTIONS(5),
  },
  [458] = {
    [sym_import] = STATE(3636),
    [sym_parenthesized_expression] = STATE(1410),
    [sym_expression] = STATE(2141),
    [sym_primary_expression] = STATE(1810),
    [sym_yield_expression] = STATE(2358),
    [sym_object] = STATE(2222),
    [sym_object_pattern] = STATE(5580),
    [sym_array] = STATE(2222),
    [sym_array_pattern] = STATE(5580),
    [sym_class] = STATE(2222),
    [sym_function_expression] = STATE(2222),
    [sym_generator_function] = STATE(2222),
    [sym_arrow_function] = STATE(2222),
    [sym__call_signature] = STATE(5466),
    [sym_call_expression] = STATE(2222),
    [sym_new_expression] = STATE(1948),
    [sym_await_expression] = STATE(2358),
    [sym_member_expression] = STATE(1410),
    [sym_subscript_expression] = STATE(1410),
    [sym_assignment_expression] = STATE(2358),
    [sym__augmented_assignment_lhs] = STATE(3004),
    [sym_augmented_assignment_expression] = STATE(2358),
    [sym__destructuring_pattern] = STATE(5580),
    [sym_ternary_expression] = STATE(2358),
    [sym_binary_expression] = STATE(2358),
    [sym_unary_expression] = STATE(2358),
    [sym_update_expression] = STATE(2358),
    [sym_string] = STATE(2222),
    [sym_template_string] = STATE(2222),
    [sym_regex] = STATE(2222),
    [sym_meta_property] = STATE(2222),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1410),
    [sym_type_assertion] = STATE(2358),
    [sym_as_expression] = STATE(2358),
    [sym_satisfies_expression] = STATE(2358),
    [sym_instantiation_expression] = STATE(2358),
    [sym_internal_module] = STATE(2358),
    [sym_type_arguments] = STATE(452),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4408),
    [sym_identifier] = ACTIONS(1498),
    [anon_sym_export] = ACTIONS(1270),
    [anon_sym_type] = ACTIONS(1270),
    [anon_sym_namespace] = ACTIONS(1272),
    [anon_sym_LBRACE] = ACTIONS(665),
    [anon_sym_typeof] = ACTIONS(1298),
    [anon_sym_import] = ACTIONS(669),
    [anon_sym_let] = ACTIONS(1270),
    [anon_sym_BANG] = ACTIONS(1278),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_await] = ACTIONS(1282),
    [anon_sym_yield] = ACTIONS(1284),
    [anon_sym_LBRACK] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(676),
    [anon_sym_async] = ACTIONS(1288),
    [anon_sym_function] = ACTIONS(680),
    [anon_sym_new] = ACTIONS(1502),
    [anon_sym_using] = ACTIONS(1292),
    [anon_sym_PLUS] = ACTIONS(1298),
    [anon_sym_DASH] = ACTIONS(1298),
    [anon_sym_SLASH] = ACTIONS(77),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(1278),
    [anon_sym_void] = ACTIONS(1298),
    [anon_sym_delete] = ACTIONS(1298),
    [anon_sym_PLUS_PLUS] = ACTIONS(1300),
    [anon_sym_DASH_DASH] = ACTIONS(1300),
    [anon_sym_DQUOTE] = ACTIONS(83),
    [anon_sym_SQUOTE] = ACTIONS(85),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(87),
    [sym_number] = ACTIONS(89),
    [sym_private_property_identifier] = ACTIONS(1306),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(93),
    [sym_true] = ACTIONS(93),
    [sym_false] = ACTIONS(93),
    [sym_null] = ACTIONS(93),
    [sym_undefined] = ACTIONS(1504),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1270),
    [anon_sym_readonly] = ACTIONS(1270),
    [anon_sym_get] = ACTIONS(1270),
    [anon_sym_set] = ACTIONS(1270),
    [anon_sym_declare] = ACTIONS(1270),
    [anon_sym_public] = ACTIONS(1270),
    [anon_sym_private] = ACTIONS(1270),
    [anon_sym_protected] = ACTIONS(1270),
    [anon_sym_override] = ACTIONS(1270),
    [anon_sym_module] = ACTIONS(1270),
    [anon_sym_any] = ACTIONS(1270),
    [anon_sym_number] = ACTIONS(1270),
    [anon_sym_boolean] = ACTIONS(1270),
    [anon_sym_string] = ACTIONS(1270),
    [anon_sym_symbol] = ACTIONS(1270),
    [anon_sym_object] = ACTIONS(1270),
    [sym_html_comment] = ACTIONS(5),
  },
  [459] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1456),
    [sym_expression] = STATE(2588),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5815),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5815),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5755),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1456),
    [sym_subscript_expression] = STATE(1456),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3029),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5815),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1456),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(594),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1506),
    [anon_sym_export] = ACTIONS(1234),
    [anon_sym_type] = ACTIONS(1234),
    [anon_sym_namespace] = ACTIONS(1236),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_typeof] = ACTIONS(1256),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1234),
    [anon_sym_BANG] = ACTIONS(1240),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(1242),
    [anon_sym_yield] = ACTIONS(1244),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1246),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1510),
    [anon_sym_using] = ACTIONS(1250),
    [anon_sym_PLUS] = ACTIONS(1256),
    [anon_sym_DASH] = ACTIONS(1256),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(1240),
    [anon_sym_void] = ACTIONS(1256),
    [anon_sym_delete] = ACTIONS(1256),
    [anon_sym_PLUS_PLUS] = ACTIONS(1258),
    [anon_sym_DASH_DASH] = ACTIONS(1258),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(1260),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1512),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1234),
    [anon_sym_readonly] = ACTIONS(1234),
    [anon_sym_get] = ACTIONS(1234),
    [anon_sym_set] = ACTIONS(1234),
    [anon_sym_declare] = ACTIONS(1234),
    [anon_sym_public] = ACTIONS(1234),
    [anon_sym_private] = ACTIONS(1234),
    [anon_sym_protected] = ACTIONS(1234),
    [anon_sym_override] = ACTIONS(1234),
    [anon_sym_module] = ACTIONS(1234),
    [anon_sym_any] = ACTIONS(1234),
    [anon_sym_number] = ACTIONS(1234),
    [anon_sym_boolean] = ACTIONS(1234),
    [anon_sym_string] = ACTIONS(1234),
    [anon_sym_symbol] = ACTIONS(1234),
    [anon_sym_object] = ACTIONS(1234),
    [sym_html_comment] = ACTIONS(5),
  },
  [460] = {
    [sym_import] = STATE(3636),
    [sym_parenthesized_expression] = STATE(1410),
    [sym_expression] = STATE(2143),
    [sym_primary_expression] = STATE(1810),
    [sym_yield_expression] = STATE(2358),
    [sym_object] = STATE(2222),
    [sym_object_pattern] = STATE(5580),
    [sym_array] = STATE(2222),
    [sym_array_pattern] = STATE(5580),
    [sym_class] = STATE(2222),
    [sym_function_expression] = STATE(2222),
    [sym_generator_function] = STATE(2222),
    [sym_arrow_function] = STATE(2222),
    [sym__call_signature] = STATE(5466),
    [sym_call_expression] = STATE(2222),
    [sym_new_expression] = STATE(1948),
    [sym_await_expression] = STATE(2358),
    [sym_member_expression] = STATE(1410),
    [sym_subscript_expression] = STATE(1410),
    [sym_assignment_expression] = STATE(2358),
    [sym__augmented_assignment_lhs] = STATE(3004),
    [sym_augmented_assignment_expression] = STATE(2358),
    [sym__destructuring_pattern] = STATE(5580),
    [sym_ternary_expression] = STATE(2358),
    [sym_binary_expression] = STATE(2358),
    [sym_unary_expression] = STATE(2358),
    [sym_update_expression] = STATE(2358),
    [sym_string] = STATE(2222),
    [sym_template_string] = STATE(2222),
    [sym_regex] = STATE(2222),
    [sym_meta_property] = STATE(2222),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1410),
    [sym_type_assertion] = STATE(2358),
    [sym_as_expression] = STATE(2358),
    [sym_satisfies_expression] = STATE(2358),
    [sym_instantiation_expression] = STATE(2358),
    [sym_internal_module] = STATE(2358),
    [sym_type_arguments] = STATE(452),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4408),
    [sym_identifier] = ACTIONS(1498),
    [anon_sym_export] = ACTIONS(1270),
    [anon_sym_type] = ACTIONS(1270),
    [anon_sym_namespace] = ACTIONS(1272),
    [anon_sym_LBRACE] = ACTIONS(665),
    [anon_sym_typeof] = ACTIONS(1298),
    [anon_sym_import] = ACTIONS(669),
    [anon_sym_let] = ACTIONS(1270),
    [anon_sym_BANG] = ACTIONS(1278),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_await] = ACTIONS(1282),
    [anon_sym_yield] = ACTIONS(1284),
    [anon_sym_LBRACK] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(676),
    [anon_sym_async] = ACTIONS(1288),
    [anon_sym_function] = ACTIONS(680),
    [anon_sym_new] = ACTIONS(1502),
    [anon_sym_using] = ACTIONS(1292),
    [anon_sym_PLUS] = ACTIONS(1298),
    [anon_sym_DASH] = ACTIONS(1298),
    [anon_sym_SLASH] = ACTIONS(77),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(1278),
    [anon_sym_void] = ACTIONS(1298),
    [anon_sym_delete] = ACTIONS(1298),
    [anon_sym_PLUS_PLUS] = ACTIONS(1300),
    [anon_sym_DASH_DASH] = ACTIONS(1300),
    [anon_sym_DQUOTE] = ACTIONS(83),
    [anon_sym_SQUOTE] = ACTIONS(85),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(87),
    [sym_number] = ACTIONS(89),
    [sym_private_property_identifier] = ACTIONS(1306),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(93),
    [sym_true] = ACTIONS(93),
    [sym_false] = ACTIONS(93),
    [sym_null] = ACTIONS(93),
    [sym_undefined] = ACTIONS(1504),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1270),
    [anon_sym_readonly] = ACTIONS(1270),
    [anon_sym_get] = ACTIONS(1270),
    [anon_sym_set] = ACTIONS(1270),
    [anon_sym_declare] = ACTIONS(1270),
    [anon_sym_public] = ACTIONS(1270),
    [anon_sym_private] = ACTIONS(1270),
    [anon_sym_protected] = ACTIONS(1270),
    [anon_sym_override] = ACTIONS(1270),
    [anon_sym_module] = ACTIONS(1270),
    [anon_sym_any] = ACTIONS(1270),
    [anon_sym_number] = ACTIONS(1270),
    [anon_sym_boolean] = ACTIONS(1270),
    [anon_sym_string] = ACTIONS(1270),
    [anon_sym_symbol] = ACTIONS(1270),
    [anon_sym_object] = ACTIONS(1270),
    [sym_html_comment] = ACTIONS(5),
  },
  [461] = {
    [sym_import] = STATE(3636),
    [sym_parenthesized_expression] = STATE(1410),
    [sym_expression] = STATE(2145),
    [sym_primary_expression] = STATE(1810),
    [sym_yield_expression] = STATE(2358),
    [sym_object] = STATE(2222),
    [sym_object_pattern] = STATE(5580),
    [sym_array] = STATE(2222),
    [sym_array_pattern] = STATE(5580),
    [sym_class] = STATE(2222),
    [sym_function_expression] = STATE(2222),
    [sym_generator_function] = STATE(2222),
    [sym_arrow_function] = STATE(2222),
    [sym__call_signature] = STATE(5466),
    [sym_call_expression] = STATE(2222),
    [sym_new_expression] = STATE(1948),
    [sym_await_expression] = STATE(2358),
    [sym_member_expression] = STATE(1410),
    [sym_subscript_expression] = STATE(1410),
    [sym_assignment_expression] = STATE(2358),
    [sym__augmented_assignment_lhs] = STATE(3004),
    [sym_augmented_assignment_expression] = STATE(2358),
    [sym__destructuring_pattern] = STATE(5580),
    [sym_ternary_expression] = STATE(2358),
    [sym_binary_expression] = STATE(2358),
    [sym_unary_expression] = STATE(2358),
    [sym_update_expression] = STATE(2358),
    [sym_string] = STATE(2222),
    [sym_template_string] = STATE(2222),
    [sym_regex] = STATE(2222),
    [sym_meta_property] = STATE(2222),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1410),
    [sym_type_assertion] = STATE(2358),
    [sym_as_expression] = STATE(2358),
    [sym_satisfies_expression] = STATE(2358),
    [sym_instantiation_expression] = STATE(2358),
    [sym_internal_module] = STATE(2358),
    [sym_type_arguments] = STATE(452),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4408),
    [sym_identifier] = ACTIONS(1498),
    [anon_sym_export] = ACTIONS(1270),
    [anon_sym_type] = ACTIONS(1270),
    [anon_sym_namespace] = ACTIONS(1272),
    [anon_sym_LBRACE] = ACTIONS(665),
    [anon_sym_typeof] = ACTIONS(1298),
    [anon_sym_import] = ACTIONS(669),
    [anon_sym_let] = ACTIONS(1270),
    [anon_sym_BANG] = ACTIONS(1278),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_await] = ACTIONS(1282),
    [anon_sym_yield] = ACTIONS(1284),
    [anon_sym_LBRACK] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(676),
    [anon_sym_async] = ACTIONS(1288),
    [anon_sym_function] = ACTIONS(680),
    [anon_sym_new] = ACTIONS(1502),
    [anon_sym_using] = ACTIONS(1292),
    [anon_sym_PLUS] = ACTIONS(1298),
    [anon_sym_DASH] = ACTIONS(1298),
    [anon_sym_SLASH] = ACTIONS(77),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(1278),
    [anon_sym_void] = ACTIONS(1298),
    [anon_sym_delete] = ACTIONS(1298),
    [anon_sym_PLUS_PLUS] = ACTIONS(1300),
    [anon_sym_DASH_DASH] = ACTIONS(1300),
    [anon_sym_DQUOTE] = ACTIONS(83),
    [anon_sym_SQUOTE] = ACTIONS(85),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(87),
    [sym_number] = ACTIONS(89),
    [sym_private_property_identifier] = ACTIONS(1306),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(93),
    [sym_true] = ACTIONS(93),
    [sym_false] = ACTIONS(93),
    [sym_null] = ACTIONS(93),
    [sym_undefined] = ACTIONS(1504),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1270),
    [anon_sym_readonly] = ACTIONS(1270),
    [anon_sym_get] = ACTIONS(1270),
    [anon_sym_set] = ACTIONS(1270),
    [anon_sym_declare] = ACTIONS(1270),
    [anon_sym_public] = ACTIONS(1270),
    [anon_sym_private] = ACTIONS(1270),
    [anon_sym_protected] = ACTIONS(1270),
    [anon_sym_override] = ACTIONS(1270),
    [anon_sym_module] = ACTIONS(1270),
    [anon_sym_any] = ACTIONS(1270),
    [anon_sym_number] = ACTIONS(1270),
    [anon_sym_boolean] = ACTIONS(1270),
    [anon_sym_string] = ACTIONS(1270),
    [anon_sym_symbol] = ACTIONS(1270),
    [anon_sym_object] = ACTIONS(1270),
    [sym_html_comment] = ACTIONS(5),
  },
  [462] = {
    [sym_import] = STATE(3636),
    [sym_parenthesized_expression] = STATE(1410),
    [sym_expression] = STATE(2146),
    [sym_primary_expression] = STATE(1810),
    [sym_yield_expression] = STATE(2358),
    [sym_object] = STATE(2222),
    [sym_object_pattern] = STATE(5580),
    [sym_array] = STATE(2222),
    [sym_array_pattern] = STATE(5580),
    [sym_class] = STATE(2222),
    [sym_function_expression] = STATE(2222),
    [sym_generator_function] = STATE(2222),
    [sym_arrow_function] = STATE(2222),
    [sym__call_signature] = STATE(5466),
    [sym_call_expression] = STATE(2222),
    [sym_new_expression] = STATE(1948),
    [sym_await_expression] = STATE(2358),
    [sym_member_expression] = STATE(1410),
    [sym_subscript_expression] = STATE(1410),
    [sym_assignment_expression] = STATE(2358),
    [sym__augmented_assignment_lhs] = STATE(3004),
    [sym_augmented_assignment_expression] = STATE(2358),
    [sym__destructuring_pattern] = STATE(5580),
    [sym_ternary_expression] = STATE(2358),
    [sym_binary_expression] = STATE(2358),
    [sym_unary_expression] = STATE(2358),
    [sym_update_expression] = STATE(2358),
    [sym_string] = STATE(2222),
    [sym_template_string] = STATE(2222),
    [sym_regex] = STATE(2222),
    [sym_meta_property] = STATE(2222),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1410),
    [sym_type_assertion] = STATE(2358),
    [sym_as_expression] = STATE(2358),
    [sym_satisfies_expression] = STATE(2358),
    [sym_instantiation_expression] = STATE(2358),
    [sym_internal_module] = STATE(2358),
    [sym_type_arguments] = STATE(452),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4408),
    [sym_identifier] = ACTIONS(1498),
    [anon_sym_export] = ACTIONS(1270),
    [anon_sym_type] = ACTIONS(1270),
    [anon_sym_namespace] = ACTIONS(1272),
    [anon_sym_LBRACE] = ACTIONS(665),
    [anon_sym_typeof] = ACTIONS(1298),
    [anon_sym_import] = ACTIONS(669),
    [anon_sym_let] = ACTIONS(1270),
    [anon_sym_BANG] = ACTIONS(1278),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_await] = ACTIONS(1282),
    [anon_sym_yield] = ACTIONS(1284),
    [anon_sym_LBRACK] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(676),
    [anon_sym_async] = ACTIONS(1288),
    [anon_sym_function] = ACTIONS(680),
    [anon_sym_new] = ACTIONS(1502),
    [anon_sym_using] = ACTIONS(1292),
    [anon_sym_PLUS] = ACTIONS(1298),
    [anon_sym_DASH] = ACTIONS(1298),
    [anon_sym_SLASH] = ACTIONS(77),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(1278),
    [anon_sym_void] = ACTIONS(1298),
    [anon_sym_delete] = ACTIONS(1298),
    [anon_sym_PLUS_PLUS] = ACTIONS(1300),
    [anon_sym_DASH_DASH] = ACTIONS(1300),
    [anon_sym_DQUOTE] = ACTIONS(83),
    [anon_sym_SQUOTE] = ACTIONS(85),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(87),
    [sym_number] = ACTIONS(89),
    [sym_private_property_identifier] = ACTIONS(1306),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(93),
    [sym_true] = ACTIONS(93),
    [sym_false] = ACTIONS(93),
    [sym_null] = ACTIONS(93),
    [sym_undefined] = ACTIONS(1504),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1270),
    [anon_sym_readonly] = ACTIONS(1270),
    [anon_sym_get] = ACTIONS(1270),
    [anon_sym_set] = ACTIONS(1270),
    [anon_sym_declare] = ACTIONS(1270),
    [anon_sym_public] = ACTIONS(1270),
    [anon_sym_private] = ACTIONS(1270),
    [anon_sym_protected] = ACTIONS(1270),
    [anon_sym_override] = ACTIONS(1270),
    [anon_sym_module] = ACTIONS(1270),
    [anon_sym_any] = ACTIONS(1270),
    [anon_sym_number] = ACTIONS(1270),
    [anon_sym_boolean] = ACTIONS(1270),
    [anon_sym_string] = ACTIONS(1270),
    [anon_sym_symbol] = ACTIONS(1270),
    [anon_sym_object] = ACTIONS(1270),
    [sym_html_comment] = ACTIONS(5),
  },
  [463] = {
    [sym_import] = STATE(3636),
    [sym_parenthesized_expression] = STATE(1410),
    [sym_expression] = STATE(2147),
    [sym_primary_expression] = STATE(1810),
    [sym_yield_expression] = STATE(2358),
    [sym_object] = STATE(2222),
    [sym_object_pattern] = STATE(5580),
    [sym_array] = STATE(2222),
    [sym_array_pattern] = STATE(5580),
    [sym_class] = STATE(2222),
    [sym_function_expression] = STATE(2222),
    [sym_generator_function] = STATE(2222),
    [sym_arrow_function] = STATE(2222),
    [sym__call_signature] = STATE(5466),
    [sym_call_expression] = STATE(2222),
    [sym_new_expression] = STATE(1948),
    [sym_await_expression] = STATE(2358),
    [sym_member_expression] = STATE(1410),
    [sym_subscript_expression] = STATE(1410),
    [sym_assignment_expression] = STATE(2358),
    [sym__augmented_assignment_lhs] = STATE(3004),
    [sym_augmented_assignment_expression] = STATE(2358),
    [sym__destructuring_pattern] = STATE(5580),
    [sym_ternary_expression] = STATE(2358),
    [sym_binary_expression] = STATE(2358),
    [sym_unary_expression] = STATE(2358),
    [sym_update_expression] = STATE(2358),
    [sym_string] = STATE(2222),
    [sym_template_string] = STATE(2222),
    [sym_regex] = STATE(2222),
    [sym_meta_property] = STATE(2222),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1410),
    [sym_type_assertion] = STATE(2358),
    [sym_as_expression] = STATE(2358),
    [sym_satisfies_expression] = STATE(2358),
    [sym_instantiation_expression] = STATE(2358),
    [sym_internal_module] = STATE(2358),
    [sym_type_arguments] = STATE(452),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4408),
    [sym_identifier] = ACTIONS(1498),
    [anon_sym_export] = ACTIONS(1270),
    [anon_sym_type] = ACTIONS(1270),
    [anon_sym_namespace] = ACTIONS(1272),
    [anon_sym_LBRACE] = ACTIONS(665),
    [anon_sym_typeof] = ACTIONS(1298),
    [anon_sym_import] = ACTIONS(669),
    [anon_sym_let] = ACTIONS(1270),
    [anon_sym_BANG] = ACTIONS(1278),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_await] = ACTIONS(1282),
    [anon_sym_yield] = ACTIONS(1284),
    [anon_sym_LBRACK] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(676),
    [anon_sym_async] = ACTIONS(1288),
    [anon_sym_function] = ACTIONS(680),
    [anon_sym_new] = ACTIONS(1502),
    [anon_sym_using] = ACTIONS(1292),
    [anon_sym_PLUS] = ACTIONS(1298),
    [anon_sym_DASH] = ACTIONS(1298),
    [anon_sym_SLASH] = ACTIONS(77),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(1278),
    [anon_sym_void] = ACTIONS(1298),
    [anon_sym_delete] = ACTIONS(1298),
    [anon_sym_PLUS_PLUS] = ACTIONS(1300),
    [anon_sym_DASH_DASH] = ACTIONS(1300),
    [anon_sym_DQUOTE] = ACTIONS(83),
    [anon_sym_SQUOTE] = ACTIONS(85),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(87),
    [sym_number] = ACTIONS(89),
    [sym_private_property_identifier] = ACTIONS(1306),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(93),
    [sym_true] = ACTIONS(93),
    [sym_false] = ACTIONS(93),
    [sym_null] = ACTIONS(93),
    [sym_undefined] = ACTIONS(1504),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1270),
    [anon_sym_readonly] = ACTIONS(1270),
    [anon_sym_get] = ACTIONS(1270),
    [anon_sym_set] = ACTIONS(1270),
    [anon_sym_declare] = ACTIONS(1270),
    [anon_sym_public] = ACTIONS(1270),
    [anon_sym_private] = ACTIONS(1270),
    [anon_sym_protected] = ACTIONS(1270),
    [anon_sym_override] = ACTIONS(1270),
    [anon_sym_module] = ACTIONS(1270),
    [anon_sym_any] = ACTIONS(1270),
    [anon_sym_number] = ACTIONS(1270),
    [anon_sym_boolean] = ACTIONS(1270),
    [anon_sym_string] = ACTIONS(1270),
    [anon_sym_symbol] = ACTIONS(1270),
    [anon_sym_object] = ACTIONS(1270),
    [sym_html_comment] = ACTIONS(5),
  },
  [464] = {
    [sym_import] = STATE(3636),
    [sym_parenthesized_expression] = STATE(1410),
    [sym_expression] = STATE(2148),
    [sym_primary_expression] = STATE(1810),
    [sym_yield_expression] = STATE(2358),
    [sym_object] = STATE(2222),
    [sym_object_pattern] = STATE(5580),
    [sym_array] = STATE(2222),
    [sym_array_pattern] = STATE(5580),
    [sym_class] = STATE(2222),
    [sym_function_expression] = STATE(2222),
    [sym_generator_function] = STATE(2222),
    [sym_arrow_function] = STATE(2222),
    [sym__call_signature] = STATE(5466),
    [sym_call_expression] = STATE(2222),
    [sym_new_expression] = STATE(1948),
    [sym_await_expression] = STATE(2358),
    [sym_member_expression] = STATE(1410),
    [sym_subscript_expression] = STATE(1410),
    [sym_assignment_expression] = STATE(2358),
    [sym__augmented_assignment_lhs] = STATE(3004),
    [sym_augmented_assignment_expression] = STATE(2358),
    [sym__destructuring_pattern] = STATE(5580),
    [sym_ternary_expression] = STATE(2358),
    [sym_binary_expression] = STATE(2358),
    [sym_unary_expression] = STATE(2358),
    [sym_update_expression] = STATE(2358),
    [sym_string] = STATE(2222),
    [sym_template_string] = STATE(2222),
    [sym_regex] = STATE(2222),
    [sym_meta_property] = STATE(2222),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1410),
    [sym_type_assertion] = STATE(2358),
    [sym_as_expression] = STATE(2358),
    [sym_satisfies_expression] = STATE(2358),
    [sym_instantiation_expression] = STATE(2358),
    [sym_internal_module] = STATE(2358),
    [sym_type_arguments] = STATE(452),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4408),
    [sym_identifier] = ACTIONS(1498),
    [anon_sym_export] = ACTIONS(1270),
    [anon_sym_type] = ACTIONS(1270),
    [anon_sym_namespace] = ACTIONS(1272),
    [anon_sym_LBRACE] = ACTIONS(665),
    [anon_sym_typeof] = ACTIONS(1298),
    [anon_sym_import] = ACTIONS(669),
    [anon_sym_let] = ACTIONS(1270),
    [anon_sym_BANG] = ACTIONS(1278),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_await] = ACTIONS(1282),
    [anon_sym_yield] = ACTIONS(1284),
    [anon_sym_LBRACK] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(676),
    [anon_sym_async] = ACTIONS(1288),
    [anon_sym_function] = ACTIONS(680),
    [anon_sym_new] = ACTIONS(1502),
    [anon_sym_using] = ACTIONS(1292),
    [anon_sym_PLUS] = ACTIONS(1298),
    [anon_sym_DASH] = ACTIONS(1298),
    [anon_sym_SLASH] = ACTIONS(77),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(1278),
    [anon_sym_void] = ACTIONS(1298),
    [anon_sym_delete] = ACTIONS(1298),
    [anon_sym_PLUS_PLUS] = ACTIONS(1300),
    [anon_sym_DASH_DASH] = ACTIONS(1300),
    [anon_sym_DQUOTE] = ACTIONS(83),
    [anon_sym_SQUOTE] = ACTIONS(85),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(87),
    [sym_number] = ACTIONS(89),
    [sym_private_property_identifier] = ACTIONS(1306),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(93),
    [sym_true] = ACTIONS(93),
    [sym_false] = ACTIONS(93),
    [sym_null] = ACTIONS(93),
    [sym_undefined] = ACTIONS(1504),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1270),
    [anon_sym_readonly] = ACTIONS(1270),
    [anon_sym_get] = ACTIONS(1270),
    [anon_sym_set] = ACTIONS(1270),
    [anon_sym_declare] = ACTIONS(1270),
    [anon_sym_public] = ACTIONS(1270),
    [anon_sym_private] = ACTIONS(1270),
    [anon_sym_protected] = ACTIONS(1270),
    [anon_sym_override] = ACTIONS(1270),
    [anon_sym_module] = ACTIONS(1270),
    [anon_sym_any] = ACTIONS(1270),
    [anon_sym_number] = ACTIONS(1270),
    [anon_sym_boolean] = ACTIONS(1270),
    [anon_sym_string] = ACTIONS(1270),
    [anon_sym_symbol] = ACTIONS(1270),
    [anon_sym_object] = ACTIONS(1270),
    [sym_html_comment] = ACTIONS(5),
  },
  [465] = {
    [sym_import] = STATE(3636),
    [sym_parenthesized_expression] = STATE(1410),
    [sym_expression] = STATE(2149),
    [sym_primary_expression] = STATE(1810),
    [sym_yield_expression] = STATE(2358),
    [sym_object] = STATE(2222),
    [sym_object_pattern] = STATE(5580),
    [sym_array] = STATE(2222),
    [sym_array_pattern] = STATE(5580),
    [sym_class] = STATE(2222),
    [sym_function_expression] = STATE(2222),
    [sym_generator_function] = STATE(2222),
    [sym_arrow_function] = STATE(2222),
    [sym__call_signature] = STATE(5466),
    [sym_call_expression] = STATE(2222),
    [sym_new_expression] = STATE(1948),
    [sym_await_expression] = STATE(2358),
    [sym_member_expression] = STATE(1410),
    [sym_subscript_expression] = STATE(1410),
    [sym_assignment_expression] = STATE(2358),
    [sym__augmented_assignment_lhs] = STATE(3004),
    [sym_augmented_assignment_expression] = STATE(2358),
    [sym__destructuring_pattern] = STATE(5580),
    [sym_ternary_expression] = STATE(2358),
    [sym_binary_expression] = STATE(2358),
    [sym_unary_expression] = STATE(2358),
    [sym_update_expression] = STATE(2358),
    [sym_string] = STATE(2222),
    [sym_template_string] = STATE(2222),
    [sym_regex] = STATE(2222),
    [sym_meta_property] = STATE(2222),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1410),
    [sym_type_assertion] = STATE(2358),
    [sym_as_expression] = STATE(2358),
    [sym_satisfies_expression] = STATE(2358),
    [sym_instantiation_expression] = STATE(2358),
    [sym_internal_module] = STATE(2358),
    [sym_type_arguments] = STATE(452),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4408),
    [sym_identifier] = ACTIONS(1498),
    [anon_sym_export] = ACTIONS(1270),
    [anon_sym_type] = ACTIONS(1270),
    [anon_sym_namespace] = ACTIONS(1272),
    [anon_sym_LBRACE] = ACTIONS(665),
    [anon_sym_typeof] = ACTIONS(1298),
    [anon_sym_import] = ACTIONS(669),
    [anon_sym_let] = ACTIONS(1270),
    [anon_sym_BANG] = ACTIONS(1278),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_await] = ACTIONS(1282),
    [anon_sym_yield] = ACTIONS(1284),
    [anon_sym_LBRACK] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(676),
    [anon_sym_async] = ACTIONS(1288),
    [anon_sym_function] = ACTIONS(680),
    [anon_sym_new] = ACTIONS(1502),
    [anon_sym_using] = ACTIONS(1292),
    [anon_sym_PLUS] = ACTIONS(1298),
    [anon_sym_DASH] = ACTIONS(1298),
    [anon_sym_SLASH] = ACTIONS(77),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(1278),
    [anon_sym_void] = ACTIONS(1298),
    [anon_sym_delete] = ACTIONS(1298),
    [anon_sym_PLUS_PLUS] = ACTIONS(1300),
    [anon_sym_DASH_DASH] = ACTIONS(1300),
    [anon_sym_DQUOTE] = ACTIONS(83),
    [anon_sym_SQUOTE] = ACTIONS(85),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(87),
    [sym_number] = ACTIONS(89),
    [sym_private_property_identifier] = ACTIONS(1306),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(93),
    [sym_true] = ACTIONS(93),
    [sym_false] = ACTIONS(93),
    [sym_null] = ACTIONS(93),
    [sym_undefined] = ACTIONS(1504),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1270),
    [anon_sym_readonly] = ACTIONS(1270),
    [anon_sym_get] = ACTIONS(1270),
    [anon_sym_set] = ACTIONS(1270),
    [anon_sym_declare] = ACTIONS(1270),
    [anon_sym_public] = ACTIONS(1270),
    [anon_sym_private] = ACTIONS(1270),
    [anon_sym_protected] = ACTIONS(1270),
    [anon_sym_override] = ACTIONS(1270),
    [anon_sym_module] = ACTIONS(1270),
    [anon_sym_any] = ACTIONS(1270),
    [anon_sym_number] = ACTIONS(1270),
    [anon_sym_boolean] = ACTIONS(1270),
    [anon_sym_string] = ACTIONS(1270),
    [anon_sym_symbol] = ACTIONS(1270),
    [anon_sym_object] = ACTIONS(1270),
    [sym_html_comment] = ACTIONS(5),
  },
  [466] = {
    [sym_import] = STATE(3636),
    [sym_parenthesized_expression] = STATE(1410),
    [sym_expression] = STATE(2150),
    [sym_primary_expression] = STATE(1810),
    [sym_yield_expression] = STATE(2358),
    [sym_object] = STATE(2222),
    [sym_object_pattern] = STATE(5580),
    [sym_array] = STATE(2222),
    [sym_array_pattern] = STATE(5580),
    [sym_class] = STATE(2222),
    [sym_function_expression] = STATE(2222),
    [sym_generator_function] = STATE(2222),
    [sym_arrow_function] = STATE(2222),
    [sym__call_signature] = STATE(5466),
    [sym_call_expression] = STATE(2222),
    [sym_new_expression] = STATE(1948),
    [sym_await_expression] = STATE(2358),
    [sym_member_expression] = STATE(1410),
    [sym_subscript_expression] = STATE(1410),
    [sym_assignment_expression] = STATE(2358),
    [sym__augmented_assignment_lhs] = STATE(3004),
    [sym_augmented_assignment_expression] = STATE(2358),
    [sym__destructuring_pattern] = STATE(5580),
    [sym_ternary_expression] = STATE(2358),
    [sym_binary_expression] = STATE(2358),
    [sym_unary_expression] = STATE(2358),
    [sym_update_expression] = STATE(2358),
    [sym_string] = STATE(2222),
    [sym_template_string] = STATE(2222),
    [sym_regex] = STATE(2222),
    [sym_meta_property] = STATE(2222),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1410),
    [sym_type_assertion] = STATE(2358),
    [sym_as_expression] = STATE(2358),
    [sym_satisfies_expression] = STATE(2358),
    [sym_instantiation_expression] = STATE(2358),
    [sym_internal_module] = STATE(2358),
    [sym_type_arguments] = STATE(452),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4408),
    [sym_identifier] = ACTIONS(1498),
    [anon_sym_export] = ACTIONS(1270),
    [anon_sym_type] = ACTIONS(1270),
    [anon_sym_namespace] = ACTIONS(1272),
    [anon_sym_LBRACE] = ACTIONS(665),
    [anon_sym_typeof] = ACTIONS(1298),
    [anon_sym_import] = ACTIONS(669),
    [anon_sym_let] = ACTIONS(1270),
    [anon_sym_BANG] = ACTIONS(1278),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_await] = ACTIONS(1282),
    [anon_sym_yield] = ACTIONS(1284),
    [anon_sym_LBRACK] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(676),
    [anon_sym_async] = ACTIONS(1288),
    [anon_sym_function] = ACTIONS(680),
    [anon_sym_new] = ACTIONS(1502),
    [anon_sym_using] = ACTIONS(1292),
    [anon_sym_PLUS] = ACTIONS(1298),
    [anon_sym_DASH] = ACTIONS(1298),
    [anon_sym_SLASH] = ACTIONS(77),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(1278),
    [anon_sym_void] = ACTIONS(1298),
    [anon_sym_delete] = ACTIONS(1298),
    [anon_sym_PLUS_PLUS] = ACTIONS(1300),
    [anon_sym_DASH_DASH] = ACTIONS(1300),
    [anon_sym_DQUOTE] = ACTIONS(83),
    [anon_sym_SQUOTE] = ACTIONS(85),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(87),
    [sym_number] = ACTIONS(89),
    [sym_private_property_identifier] = ACTIONS(1306),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(93),
    [sym_true] = ACTIONS(93),
    [sym_false] = ACTIONS(93),
    [sym_null] = ACTIONS(93),
    [sym_undefined] = ACTIONS(1504),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1270),
    [anon_sym_readonly] = ACTIONS(1270),
    [anon_sym_get] = ACTIONS(1270),
    [anon_sym_set] = ACTIONS(1270),
    [anon_sym_declare] = ACTIONS(1270),
    [anon_sym_public] = ACTIONS(1270),
    [anon_sym_private] = ACTIONS(1270),
    [anon_sym_protected] = ACTIONS(1270),
    [anon_sym_override] = ACTIONS(1270),
    [anon_sym_module] = ACTIONS(1270),
    [anon_sym_any] = ACTIONS(1270),
    [anon_sym_number] = ACTIONS(1270),
    [anon_sym_boolean] = ACTIONS(1270),
    [anon_sym_string] = ACTIONS(1270),
    [anon_sym_symbol] = ACTIONS(1270),
    [anon_sym_object] = ACTIONS(1270),
    [sym_html_comment] = ACTIONS(5),
  },
  [467] = {
    [sym_import] = STATE(3636),
    [sym_parenthesized_expression] = STATE(1410),
    [sym_expression] = STATE(2151),
    [sym_primary_expression] = STATE(1810),
    [sym_yield_expression] = STATE(2358),
    [sym_object] = STATE(2222),
    [sym_object_pattern] = STATE(5580),
    [sym_array] = STATE(2222),
    [sym_array_pattern] = STATE(5580),
    [sym_class] = STATE(2222),
    [sym_function_expression] = STATE(2222),
    [sym_generator_function] = STATE(2222),
    [sym_arrow_function] = STATE(2222),
    [sym__call_signature] = STATE(5466),
    [sym_call_expression] = STATE(2222),
    [sym_new_expression] = STATE(1948),
    [sym_await_expression] = STATE(2358),
    [sym_member_expression] = STATE(1410),
    [sym_subscript_expression] = STATE(1410),
    [sym_assignment_expression] = STATE(2358),
    [sym__augmented_assignment_lhs] = STATE(3004),
    [sym_augmented_assignment_expression] = STATE(2358),
    [sym__destructuring_pattern] = STATE(5580),
    [sym_ternary_expression] = STATE(2358),
    [sym_binary_expression] = STATE(2358),
    [sym_unary_expression] = STATE(2358),
    [sym_update_expression] = STATE(2358),
    [sym_string] = STATE(2222),
    [sym_template_string] = STATE(2222),
    [sym_regex] = STATE(2222),
    [sym_meta_property] = STATE(2222),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1410),
    [sym_type_assertion] = STATE(2358),
    [sym_as_expression] = STATE(2358),
    [sym_satisfies_expression] = STATE(2358),
    [sym_instantiation_expression] = STATE(2358),
    [sym_internal_module] = STATE(2358),
    [sym_type_arguments] = STATE(452),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4408),
    [sym_identifier] = ACTIONS(1498),
    [anon_sym_export] = ACTIONS(1270),
    [anon_sym_type] = ACTIONS(1270),
    [anon_sym_namespace] = ACTIONS(1272),
    [anon_sym_LBRACE] = ACTIONS(665),
    [anon_sym_typeof] = ACTIONS(1298),
    [anon_sym_import] = ACTIONS(669),
    [anon_sym_let] = ACTIONS(1270),
    [anon_sym_BANG] = ACTIONS(1278),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_await] = ACTIONS(1282),
    [anon_sym_yield] = ACTIONS(1284),
    [anon_sym_LBRACK] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(676),
    [anon_sym_async] = ACTIONS(1288),
    [anon_sym_function] = ACTIONS(680),
    [anon_sym_new] = ACTIONS(1502),
    [anon_sym_using] = ACTIONS(1292),
    [anon_sym_PLUS] = ACTIONS(1298),
    [anon_sym_DASH] = ACTIONS(1298),
    [anon_sym_SLASH] = ACTIONS(77),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(1278),
    [anon_sym_void] = ACTIONS(1298),
    [anon_sym_delete] = ACTIONS(1298),
    [anon_sym_PLUS_PLUS] = ACTIONS(1300),
    [anon_sym_DASH_DASH] = ACTIONS(1300),
    [anon_sym_DQUOTE] = ACTIONS(83),
    [anon_sym_SQUOTE] = ACTIONS(85),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(87),
    [sym_number] = ACTIONS(89),
    [sym_private_property_identifier] = ACTIONS(1306),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(93),
    [sym_true] = ACTIONS(93),
    [sym_false] = ACTIONS(93),
    [sym_null] = ACTIONS(93),
    [sym_undefined] = ACTIONS(1504),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1270),
    [anon_sym_readonly] = ACTIONS(1270),
    [anon_sym_get] = ACTIONS(1270),
    [anon_sym_set] = ACTIONS(1270),
    [anon_sym_declare] = ACTIONS(1270),
    [anon_sym_public] = ACTIONS(1270),
    [anon_sym_private] = ACTIONS(1270),
    [anon_sym_protected] = ACTIONS(1270),
    [anon_sym_override] = ACTIONS(1270),
    [anon_sym_module] = ACTIONS(1270),
    [anon_sym_any] = ACTIONS(1270),
    [anon_sym_number] = ACTIONS(1270),
    [anon_sym_boolean] = ACTIONS(1270),
    [anon_sym_string] = ACTIONS(1270),
    [anon_sym_symbol] = ACTIONS(1270),
    [anon_sym_object] = ACTIONS(1270),
    [sym_html_comment] = ACTIONS(5),
  },
  [468] = {
    [sym_import] = STATE(3636),
    [sym_parenthesized_expression] = STATE(1410),
    [sym_expression] = STATE(2152),
    [sym_primary_expression] = STATE(1810),
    [sym_yield_expression] = STATE(2358),
    [sym_object] = STATE(2222),
    [sym_object_pattern] = STATE(5580),
    [sym_array] = STATE(2222),
    [sym_array_pattern] = STATE(5580),
    [sym_class] = STATE(2222),
    [sym_function_expression] = STATE(2222),
    [sym_generator_function] = STATE(2222),
    [sym_arrow_function] = STATE(2222),
    [sym__call_signature] = STATE(5466),
    [sym_call_expression] = STATE(2222),
    [sym_new_expression] = STATE(1948),
    [sym_await_expression] = STATE(2358),
    [sym_member_expression] = STATE(1410),
    [sym_subscript_expression] = STATE(1410),
    [sym_assignment_expression] = STATE(2358),
    [sym__augmented_assignment_lhs] = STATE(3004),
    [sym_augmented_assignment_expression] = STATE(2358),
    [sym__destructuring_pattern] = STATE(5580),
    [sym_ternary_expression] = STATE(2358),
    [sym_binary_expression] = STATE(2358),
    [sym_unary_expression] = STATE(2358),
    [sym_update_expression] = STATE(2358),
    [sym_string] = STATE(2222),
    [sym_template_string] = STATE(2222),
    [sym_regex] = STATE(2222),
    [sym_meta_property] = STATE(2222),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1410),
    [sym_type_assertion] = STATE(2358),
    [sym_as_expression] = STATE(2358),
    [sym_satisfies_expression] = STATE(2358),
    [sym_instantiation_expression] = STATE(2358),
    [sym_internal_module] = STATE(2358),
    [sym_type_arguments] = STATE(452),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4408),
    [sym_identifier] = ACTIONS(1498),
    [anon_sym_export] = ACTIONS(1270),
    [anon_sym_type] = ACTIONS(1270),
    [anon_sym_namespace] = ACTIONS(1272),
    [anon_sym_LBRACE] = ACTIONS(665),
    [anon_sym_typeof] = ACTIONS(1298),
    [anon_sym_import] = ACTIONS(669),
    [anon_sym_let] = ACTIONS(1270),
    [anon_sym_BANG] = ACTIONS(1278),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_await] = ACTIONS(1282),
    [anon_sym_yield] = ACTIONS(1284),
    [anon_sym_LBRACK] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(676),
    [anon_sym_async] = ACTIONS(1288),
    [anon_sym_function] = ACTIONS(680),
    [anon_sym_new] = ACTIONS(1502),
    [anon_sym_using] = ACTIONS(1292),
    [anon_sym_PLUS] = ACTIONS(1298),
    [anon_sym_DASH] = ACTIONS(1298),
    [anon_sym_SLASH] = ACTIONS(77),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(1278),
    [anon_sym_void] = ACTIONS(1298),
    [anon_sym_delete] = ACTIONS(1298),
    [anon_sym_PLUS_PLUS] = ACTIONS(1300),
    [anon_sym_DASH_DASH] = ACTIONS(1300),
    [anon_sym_DQUOTE] = ACTIONS(83),
    [anon_sym_SQUOTE] = ACTIONS(85),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(87),
    [sym_number] = ACTIONS(89),
    [sym_private_property_identifier] = ACTIONS(1306),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(93),
    [sym_true] = ACTIONS(93),
    [sym_false] = ACTIONS(93),
    [sym_null] = ACTIONS(93),
    [sym_undefined] = ACTIONS(1504),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1270),
    [anon_sym_readonly] = ACTIONS(1270),
    [anon_sym_get] = ACTIONS(1270),
    [anon_sym_set] = ACTIONS(1270),
    [anon_sym_declare] = ACTIONS(1270),
    [anon_sym_public] = ACTIONS(1270),
    [anon_sym_private] = ACTIONS(1270),
    [anon_sym_protected] = ACTIONS(1270),
    [anon_sym_override] = ACTIONS(1270),
    [anon_sym_module] = ACTIONS(1270),
    [anon_sym_any] = ACTIONS(1270),
    [anon_sym_number] = ACTIONS(1270),
    [anon_sym_boolean] = ACTIONS(1270),
    [anon_sym_string] = ACTIONS(1270),
    [anon_sym_symbol] = ACTIONS(1270),
    [anon_sym_object] = ACTIONS(1270),
    [sym_html_comment] = ACTIONS(5),
  },
  [469] = {
    [sym_import] = STATE(3636),
    [sym_parenthesized_expression] = STATE(1410),
    [sym_expression] = STATE(2153),
    [sym_primary_expression] = STATE(1810),
    [sym_yield_expression] = STATE(2358),
    [sym_object] = STATE(2222),
    [sym_object_pattern] = STATE(5580),
    [sym_array] = STATE(2222),
    [sym_array_pattern] = STATE(5580),
    [sym_class] = STATE(2222),
    [sym_function_expression] = STATE(2222),
    [sym_generator_function] = STATE(2222),
    [sym_arrow_function] = STATE(2222),
    [sym__call_signature] = STATE(5466),
    [sym_call_expression] = STATE(2222),
    [sym_new_expression] = STATE(1948),
    [sym_await_expression] = STATE(2358),
    [sym_member_expression] = STATE(1410),
    [sym_subscript_expression] = STATE(1410),
    [sym_assignment_expression] = STATE(2358),
    [sym__augmented_assignment_lhs] = STATE(3004),
    [sym_augmented_assignment_expression] = STATE(2358),
    [sym__destructuring_pattern] = STATE(5580),
    [sym_ternary_expression] = STATE(2358),
    [sym_binary_expression] = STATE(2358),
    [sym_unary_expression] = STATE(2358),
    [sym_update_expression] = STATE(2358),
    [sym_string] = STATE(2222),
    [sym_template_string] = STATE(2222),
    [sym_regex] = STATE(2222),
    [sym_meta_property] = STATE(2222),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1410),
    [sym_type_assertion] = STATE(2358),
    [sym_as_expression] = STATE(2358),
    [sym_satisfies_expression] = STATE(2358),
    [sym_instantiation_expression] = STATE(2358),
    [sym_internal_module] = STATE(2358),
    [sym_type_arguments] = STATE(452),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4408),
    [sym_identifier] = ACTIONS(1498),
    [anon_sym_export] = ACTIONS(1270),
    [anon_sym_type] = ACTIONS(1270),
    [anon_sym_namespace] = ACTIONS(1272),
    [anon_sym_LBRACE] = ACTIONS(665),
    [anon_sym_typeof] = ACTIONS(1298),
    [anon_sym_import] = ACTIONS(669),
    [anon_sym_let] = ACTIONS(1270),
    [anon_sym_BANG] = ACTIONS(1278),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_await] = ACTIONS(1282),
    [anon_sym_yield] = ACTIONS(1284),
    [anon_sym_LBRACK] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(676),
    [anon_sym_async] = ACTIONS(1288),
    [anon_sym_function] = ACTIONS(680),
    [anon_sym_new] = ACTIONS(1502),
    [anon_sym_using] = ACTIONS(1292),
    [anon_sym_PLUS] = ACTIONS(1298),
    [anon_sym_DASH] = ACTIONS(1298),
    [anon_sym_SLASH] = ACTIONS(77),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(1278),
    [anon_sym_void] = ACTIONS(1298),
    [anon_sym_delete] = ACTIONS(1298),
    [anon_sym_PLUS_PLUS] = ACTIONS(1300),
    [anon_sym_DASH_DASH] = ACTIONS(1300),
    [anon_sym_DQUOTE] = ACTIONS(83),
    [anon_sym_SQUOTE] = ACTIONS(85),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(87),
    [sym_number] = ACTIONS(89),
    [sym_private_property_identifier] = ACTIONS(1306),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(93),
    [sym_true] = ACTIONS(93),
    [sym_false] = ACTIONS(93),
    [sym_null] = ACTIONS(93),
    [sym_undefined] = ACTIONS(1504),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1270),
    [anon_sym_readonly] = ACTIONS(1270),
    [anon_sym_get] = ACTIONS(1270),
    [anon_sym_set] = ACTIONS(1270),
    [anon_sym_declare] = ACTIONS(1270),
    [anon_sym_public] = ACTIONS(1270),
    [anon_sym_private] = ACTIONS(1270),
    [anon_sym_protected] = ACTIONS(1270),
    [anon_sym_override] = ACTIONS(1270),
    [anon_sym_module] = ACTIONS(1270),
    [anon_sym_any] = ACTIONS(1270),
    [anon_sym_number] = ACTIONS(1270),
    [anon_sym_boolean] = ACTIONS(1270),
    [anon_sym_string] = ACTIONS(1270),
    [anon_sym_symbol] = ACTIONS(1270),
    [anon_sym_object] = ACTIONS(1270),
    [sym_html_comment] = ACTIONS(5),
  },
  [470] = {
    [sym_import] = STATE(3636),
    [sym_parenthesized_expression] = STATE(1410),
    [sym_expression] = STATE(2154),
    [sym_primary_expression] = STATE(1810),
    [sym_yield_expression] = STATE(2358),
    [sym_object] = STATE(2222),
    [sym_object_pattern] = STATE(5580),
    [sym_array] = STATE(2222),
    [sym_array_pattern] = STATE(5580),
    [sym_class] = STATE(2222),
    [sym_function_expression] = STATE(2222),
    [sym_generator_function] = STATE(2222),
    [sym_arrow_function] = STATE(2222),
    [sym__call_signature] = STATE(5466),
    [sym_call_expression] = STATE(2222),
    [sym_new_expression] = STATE(1948),
    [sym_await_expression] = STATE(2358),
    [sym_member_expression] = STATE(1410),
    [sym_subscript_expression] = STATE(1410),
    [sym_assignment_expression] = STATE(2358),
    [sym__augmented_assignment_lhs] = STATE(3004),
    [sym_augmented_assignment_expression] = STATE(2358),
    [sym__destructuring_pattern] = STATE(5580),
    [sym_ternary_expression] = STATE(2358),
    [sym_binary_expression] = STATE(2358),
    [sym_unary_expression] = STATE(2358),
    [sym_update_expression] = STATE(2358),
    [sym_string] = STATE(2222),
    [sym_template_string] = STATE(2222),
    [sym_regex] = STATE(2222),
    [sym_meta_property] = STATE(2222),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1410),
    [sym_type_assertion] = STATE(2358),
    [sym_as_expression] = STATE(2358),
    [sym_satisfies_expression] = STATE(2358),
    [sym_instantiation_expression] = STATE(2358),
    [sym_internal_module] = STATE(2358),
    [sym_type_arguments] = STATE(452),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4408),
    [sym_identifier] = ACTIONS(1498),
    [anon_sym_export] = ACTIONS(1270),
    [anon_sym_type] = ACTIONS(1270),
    [anon_sym_namespace] = ACTIONS(1272),
    [anon_sym_LBRACE] = ACTIONS(665),
    [anon_sym_typeof] = ACTIONS(1298),
    [anon_sym_import] = ACTIONS(669),
    [anon_sym_let] = ACTIONS(1270),
    [anon_sym_BANG] = ACTIONS(1278),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_await] = ACTIONS(1282),
    [anon_sym_yield] = ACTIONS(1284),
    [anon_sym_LBRACK] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(676),
    [anon_sym_async] = ACTIONS(1288),
    [anon_sym_function] = ACTIONS(680),
    [anon_sym_new] = ACTIONS(1502),
    [anon_sym_using] = ACTIONS(1292),
    [anon_sym_PLUS] = ACTIONS(1298),
    [anon_sym_DASH] = ACTIONS(1298),
    [anon_sym_SLASH] = ACTIONS(77),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(1278),
    [anon_sym_void] = ACTIONS(1298),
    [anon_sym_delete] = ACTIONS(1298),
    [anon_sym_PLUS_PLUS] = ACTIONS(1300),
    [anon_sym_DASH_DASH] = ACTIONS(1300),
    [anon_sym_DQUOTE] = ACTIONS(83),
    [anon_sym_SQUOTE] = ACTIONS(85),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(87),
    [sym_number] = ACTIONS(89),
    [sym_private_property_identifier] = ACTIONS(1306),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(93),
    [sym_true] = ACTIONS(93),
    [sym_false] = ACTIONS(93),
    [sym_null] = ACTIONS(93),
    [sym_undefined] = ACTIONS(1504),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1270),
    [anon_sym_readonly] = ACTIONS(1270),
    [anon_sym_get] = ACTIONS(1270),
    [anon_sym_set] = ACTIONS(1270),
    [anon_sym_declare] = ACTIONS(1270),
    [anon_sym_public] = ACTIONS(1270),
    [anon_sym_private] = ACTIONS(1270),
    [anon_sym_protected] = ACTIONS(1270),
    [anon_sym_override] = ACTIONS(1270),
    [anon_sym_module] = ACTIONS(1270),
    [anon_sym_any] = ACTIONS(1270),
    [anon_sym_number] = ACTIONS(1270),
    [anon_sym_boolean] = ACTIONS(1270),
    [anon_sym_string] = ACTIONS(1270),
    [anon_sym_symbol] = ACTIONS(1270),
    [anon_sym_object] = ACTIONS(1270),
    [sym_html_comment] = ACTIONS(5),
  },
  [471] = {
    [sym_import] = STATE(3636),
    [sym_parenthesized_expression] = STATE(1410),
    [sym_expression] = STATE(2156),
    [sym_primary_expression] = STATE(1810),
    [sym_yield_expression] = STATE(2358),
    [sym_object] = STATE(2222),
    [sym_object_pattern] = STATE(5580),
    [sym_array] = STATE(2222),
    [sym_array_pattern] = STATE(5580),
    [sym_class] = STATE(2222),
    [sym_function_expression] = STATE(2222),
    [sym_generator_function] = STATE(2222),
    [sym_arrow_function] = STATE(2222),
    [sym__call_signature] = STATE(5466),
    [sym_call_expression] = STATE(2222),
    [sym_new_expression] = STATE(1948),
    [sym_await_expression] = STATE(2358),
    [sym_member_expression] = STATE(1410),
    [sym_subscript_expression] = STATE(1410),
    [sym_assignment_expression] = STATE(2358),
    [sym__augmented_assignment_lhs] = STATE(3004),
    [sym_augmented_assignment_expression] = STATE(2358),
    [sym__destructuring_pattern] = STATE(5580),
    [sym_ternary_expression] = STATE(2358),
    [sym_binary_expression] = STATE(2358),
    [sym_unary_expression] = STATE(2358),
    [sym_update_expression] = STATE(2358),
    [sym_string] = STATE(2222),
    [sym_template_string] = STATE(2222),
    [sym_regex] = STATE(2222),
    [sym_meta_property] = STATE(2222),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1410),
    [sym_type_assertion] = STATE(2358),
    [sym_as_expression] = STATE(2358),
    [sym_satisfies_expression] = STATE(2358),
    [sym_instantiation_expression] = STATE(2358),
    [sym_internal_module] = STATE(2358),
    [sym_type_arguments] = STATE(452),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4408),
    [sym_identifier] = ACTIONS(1498),
    [anon_sym_export] = ACTIONS(1270),
    [anon_sym_type] = ACTIONS(1270),
    [anon_sym_namespace] = ACTIONS(1272),
    [anon_sym_LBRACE] = ACTIONS(665),
    [anon_sym_typeof] = ACTIONS(1298),
    [anon_sym_import] = ACTIONS(669),
    [anon_sym_let] = ACTIONS(1270),
    [anon_sym_BANG] = ACTIONS(1278),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_await] = ACTIONS(1282),
    [anon_sym_yield] = ACTIONS(1284),
    [anon_sym_LBRACK] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(676),
    [anon_sym_async] = ACTIONS(1288),
    [anon_sym_function] = ACTIONS(680),
    [anon_sym_new] = ACTIONS(1502),
    [anon_sym_using] = ACTIONS(1292),
    [anon_sym_PLUS] = ACTIONS(1298),
    [anon_sym_DASH] = ACTIONS(1298),
    [anon_sym_SLASH] = ACTIONS(77),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(1278),
    [anon_sym_void] = ACTIONS(1298),
    [anon_sym_delete] = ACTIONS(1298),
    [anon_sym_PLUS_PLUS] = ACTIONS(1300),
    [anon_sym_DASH_DASH] = ACTIONS(1300),
    [anon_sym_DQUOTE] = ACTIONS(83),
    [anon_sym_SQUOTE] = ACTIONS(85),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(87),
    [sym_number] = ACTIONS(89),
    [sym_private_property_identifier] = ACTIONS(1306),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(93),
    [sym_true] = ACTIONS(93),
    [sym_false] = ACTIONS(93),
    [sym_null] = ACTIONS(93),
    [sym_undefined] = ACTIONS(1504),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1270),
    [anon_sym_readonly] = ACTIONS(1270),
    [anon_sym_get] = ACTIONS(1270),
    [anon_sym_set] = ACTIONS(1270),
    [anon_sym_declare] = ACTIONS(1270),
    [anon_sym_public] = ACTIONS(1270),
    [anon_sym_private] = ACTIONS(1270),
    [anon_sym_protected] = ACTIONS(1270),
    [anon_sym_override] = ACTIONS(1270),
    [anon_sym_module] = ACTIONS(1270),
    [anon_sym_any] = ACTIONS(1270),
    [anon_sym_number] = ACTIONS(1270),
    [anon_sym_boolean] = ACTIONS(1270),
    [anon_sym_string] = ACTIONS(1270),
    [anon_sym_symbol] = ACTIONS(1270),
    [anon_sym_object] = ACTIONS(1270),
    [sym_html_comment] = ACTIONS(5),
  },
  [472] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1457),
    [sym_expression] = STATE(2591),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5823),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5823),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5477),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1457),
    [sym_subscript_expression] = STATE(1457),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(2986),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5823),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1457),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(620),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1522),
    [anon_sym_export] = ACTIONS(1178),
    [anon_sym_type] = ACTIONS(1178),
    [anon_sym_namespace] = ACTIONS(1180),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_typeof] = ACTIONS(1202),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1178),
    [anon_sym_BANG] = ACTIONS(1186),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(1188),
    [anon_sym_yield] = ACTIONS(1190),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1192),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1526),
    [anon_sym_using] = ACTIONS(1196),
    [anon_sym_PLUS] = ACTIONS(1202),
    [anon_sym_DASH] = ACTIONS(1202),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(1186),
    [anon_sym_void] = ACTIONS(1202),
    [anon_sym_delete] = ACTIONS(1202),
    [anon_sym_PLUS_PLUS] = ACTIONS(1204),
    [anon_sym_DASH_DASH] = ACTIONS(1204),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(1206),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1528),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1178),
    [anon_sym_readonly] = ACTIONS(1178),
    [anon_sym_get] = ACTIONS(1178),
    [anon_sym_set] = ACTIONS(1178),
    [anon_sym_declare] = ACTIONS(1178),
    [anon_sym_public] = ACTIONS(1178),
    [anon_sym_private] = ACTIONS(1178),
    [anon_sym_protected] = ACTIONS(1178),
    [anon_sym_override] = ACTIONS(1178),
    [anon_sym_module] = ACTIONS(1178),
    [anon_sym_any] = ACTIONS(1178),
    [anon_sym_number] = ACTIONS(1178),
    [anon_sym_boolean] = ACTIONS(1178),
    [anon_sym_string] = ACTIONS(1178),
    [anon_sym_symbol] = ACTIONS(1178),
    [anon_sym_object] = ACTIONS(1178),
    [sym_html_comment] = ACTIONS(5),
  },
  [473] = {
    [sym_import] = STATE(3636),
    [sym_parenthesized_expression] = STATE(1362),
    [sym_expression] = STATE(1803),
    [sym_primary_expression] = STATE(1810),
    [sym_yield_expression] = STATE(2358),
    [sym_object] = STATE(2222),
    [sym_object_pattern] = STATE(5492),
    [sym_array] = STATE(2222),
    [sym_array_pattern] = STATE(5492),
    [sym_class] = STATE(2222),
    [sym_function_expression] = STATE(2222),
    [sym_generator_function] = STATE(2222),
    [sym_arrow_function] = STATE(2222),
    [sym__call_signature] = STATE(5821),
    [sym_call_expression] = STATE(2222),
    [sym_new_expression] = STATE(1948),
    [sym_await_expression] = STATE(2358),
    [sym_member_expression] = STATE(1362),
    [sym_subscript_expression] = STATE(1362),
    [sym_assignment_expression] = STATE(2358),
    [sym__augmented_assignment_lhs] = STATE(3025),
    [sym_augmented_assignment_expression] = STATE(2358),
    [sym__destructuring_pattern] = STATE(5492),
    [sym_ternary_expression] = STATE(2358),
    [sym_binary_expression] = STATE(2358),
    [sym_unary_expression] = STATE(2358),
    [sym_update_expression] = STATE(2358),
    [sym_string] = STATE(2222),
    [sym_template_string] = STATE(2222),
    [sym_regex] = STATE(2222),
    [sym_meta_property] = STATE(2222),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1362),
    [sym_type_assertion] = STATE(2358),
    [sym_as_expression] = STATE(2358),
    [sym_satisfies_expression] = STATE(2358),
    [sym_instantiation_expression] = STATE(2358),
    [sym_internal_module] = STATE(2358),
    [sym_type_arguments] = STATE(428),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4408),
    [sym_identifier] = ACTIONS(1468),
    [anon_sym_export] = ACTIONS(1352),
    [anon_sym_type] = ACTIONS(1352),
    [anon_sym_namespace] = ACTIONS(1354),
    [anon_sym_LBRACE] = ACTIONS(665),
    [anon_sym_typeof] = ACTIONS(21),
    [anon_sym_import] = ACTIONS(669),
    [anon_sym_let] = ACTIONS(1352),
    [anon_sym_BANG] = ACTIONS(33),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_await] = ACTIONS(45),
    [anon_sym_yield] = ACTIONS(63),
    [anon_sym_LBRACK] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(676),
    [anon_sym_async] = ACTIONS(1362),
    [anon_sym_function] = ACTIONS(680),
    [anon_sym_new] = ACTIONS(1472),
    [anon_sym_using] = ACTIONS(75),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_SLASH] = ACTIONS(77),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(33),
    [anon_sym_void] = ACTIONS(21),
    [anon_sym_delete] = ACTIONS(21),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_DQUOTE] = ACTIONS(83),
    [anon_sym_SQUOTE] = ACTIONS(85),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(87),
    [sym_number] = ACTIONS(89),
    [sym_private_property_identifier] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(93),
    [sym_true] = ACTIONS(93),
    [sym_false] = ACTIONS(93),
    [sym_null] = ACTIONS(93),
    [sym_undefined] = ACTIONS(95),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1352),
    [anon_sym_readonly] = ACTIONS(1352),
    [anon_sym_get] = ACTIONS(1352),
    [anon_sym_set] = ACTIONS(1352),
    [anon_sym_declare] = ACTIONS(1352),
    [anon_sym_public] = ACTIONS(1352),
    [anon_sym_private] = ACTIONS(1352),
    [anon_sym_protected] = ACTIONS(1352),
    [anon_sym_override] = ACTIONS(1352),
    [anon_sym_module] = ACTIONS(1352),
    [anon_sym_any] = ACTIONS(1352),
    [anon_sym_number] = ACTIONS(1352),
    [anon_sym_boolean] = ACTIONS(1352),
    [anon_sym_string] = ACTIONS(1352),
    [anon_sym_symbol] = ACTIONS(1352),
    [anon_sym_object] = ACTIONS(1352),
    [sym_html_comment] = ACTIONS(5),
  },
  [474] = {
    [sym_import] = STATE(3636),
    [sym_parenthesized_expression] = STATE(1362),
    [sym_expression] = STATE(1804),
    [sym_primary_expression] = STATE(1810),
    [sym_yield_expression] = STATE(2358),
    [sym_object] = STATE(2222),
    [sym_object_pattern] = STATE(5492),
    [sym_array] = STATE(2222),
    [sym_array_pattern] = STATE(5492),
    [sym_class] = STATE(2222),
    [sym_function_expression] = STATE(2222),
    [sym_generator_function] = STATE(2222),
    [sym_arrow_function] = STATE(2222),
    [sym__call_signature] = STATE(5821),
    [sym_call_expression] = STATE(2222),
    [sym_new_expression] = STATE(1948),
    [sym_await_expression] = STATE(2358),
    [sym_member_expression] = STATE(1362),
    [sym_subscript_expression] = STATE(1362),
    [sym_assignment_expression] = STATE(2358),
    [sym__augmented_assignment_lhs] = STATE(3025),
    [sym_augmented_assignment_expression] = STATE(2358),
    [sym__destructuring_pattern] = STATE(5492),
    [sym_ternary_expression] = STATE(2358),
    [sym_binary_expression] = STATE(2358),
    [sym_unary_expression] = STATE(2358),
    [sym_update_expression] = STATE(2358),
    [sym_string] = STATE(2222),
    [sym_template_string] = STATE(2222),
    [sym_regex] = STATE(2222),
    [sym_meta_property] = STATE(2222),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1362),
    [sym_type_assertion] = STATE(2358),
    [sym_as_expression] = STATE(2358),
    [sym_satisfies_expression] = STATE(2358),
    [sym_instantiation_expression] = STATE(2358),
    [sym_internal_module] = STATE(2358),
    [sym_type_arguments] = STATE(428),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4408),
    [sym_identifier] = ACTIONS(1468),
    [anon_sym_export] = ACTIONS(1352),
    [anon_sym_type] = ACTIONS(1352),
    [anon_sym_namespace] = ACTIONS(1354),
    [anon_sym_LBRACE] = ACTIONS(665),
    [anon_sym_typeof] = ACTIONS(21),
    [anon_sym_import] = ACTIONS(669),
    [anon_sym_let] = ACTIONS(1352),
    [anon_sym_BANG] = ACTIONS(33),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_await] = ACTIONS(45),
    [anon_sym_yield] = ACTIONS(63),
    [anon_sym_LBRACK] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(676),
    [anon_sym_async] = ACTIONS(1362),
    [anon_sym_function] = ACTIONS(680),
    [anon_sym_new] = ACTIONS(1472),
    [anon_sym_using] = ACTIONS(75),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_SLASH] = ACTIONS(77),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(33),
    [anon_sym_void] = ACTIONS(21),
    [anon_sym_delete] = ACTIONS(21),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_DQUOTE] = ACTIONS(83),
    [anon_sym_SQUOTE] = ACTIONS(85),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(87),
    [sym_number] = ACTIONS(89),
    [sym_private_property_identifier] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(93),
    [sym_true] = ACTIONS(93),
    [sym_false] = ACTIONS(93),
    [sym_null] = ACTIONS(93),
    [sym_undefined] = ACTIONS(95),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1352),
    [anon_sym_readonly] = ACTIONS(1352),
    [anon_sym_get] = ACTIONS(1352),
    [anon_sym_set] = ACTIONS(1352),
    [anon_sym_declare] = ACTIONS(1352),
    [anon_sym_public] = ACTIONS(1352),
    [anon_sym_private] = ACTIONS(1352),
    [anon_sym_protected] = ACTIONS(1352),
    [anon_sym_override] = ACTIONS(1352),
    [anon_sym_module] = ACTIONS(1352),
    [anon_sym_any] = ACTIONS(1352),
    [anon_sym_number] = ACTIONS(1352),
    [anon_sym_boolean] = ACTIONS(1352),
    [anon_sym_string] = ACTIONS(1352),
    [anon_sym_symbol] = ACTIONS(1352),
    [anon_sym_object] = ACTIONS(1352),
    [sym_html_comment] = ACTIONS(5),
  },
  [475] = {
    [sym_import] = STATE(3636),
    [sym_parenthesized_expression] = STATE(1362),
    [sym_expression] = STATE(1805),
    [sym_primary_expression] = STATE(1810),
    [sym_yield_expression] = STATE(2358),
    [sym_object] = STATE(2222),
    [sym_object_pattern] = STATE(5492),
    [sym_array] = STATE(2222),
    [sym_array_pattern] = STATE(5492),
    [sym_class] = STATE(2222),
    [sym_function_expression] = STATE(2222),
    [sym_generator_function] = STATE(2222),
    [sym_arrow_function] = STATE(2222),
    [sym__call_signature] = STATE(5821),
    [sym_call_expression] = STATE(2222),
    [sym_new_expression] = STATE(1948),
    [sym_await_expression] = STATE(2358),
    [sym_member_expression] = STATE(1362),
    [sym_subscript_expression] = STATE(1362),
    [sym_assignment_expression] = STATE(2358),
    [sym__augmented_assignment_lhs] = STATE(3025),
    [sym_augmented_assignment_expression] = STATE(2358),
    [sym__destructuring_pattern] = STATE(5492),
    [sym_ternary_expression] = STATE(2358),
    [sym_binary_expression] = STATE(2358),
    [sym_unary_expression] = STATE(2358),
    [sym_update_expression] = STATE(2358),
    [sym_string] = STATE(2222),
    [sym_template_string] = STATE(2222),
    [sym_regex] = STATE(2222),
    [sym_meta_property] = STATE(2222),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1362),
    [sym_type_assertion] = STATE(2358),
    [sym_as_expression] = STATE(2358),
    [sym_satisfies_expression] = STATE(2358),
    [sym_instantiation_expression] = STATE(2358),
    [sym_internal_module] = STATE(2358),
    [sym_type_arguments] = STATE(428),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4408),
    [sym_identifier] = ACTIONS(1468),
    [anon_sym_export] = ACTIONS(1352),
    [anon_sym_type] = ACTIONS(1352),
    [anon_sym_namespace] = ACTIONS(1354),
    [anon_sym_LBRACE] = ACTIONS(665),
    [anon_sym_typeof] = ACTIONS(21),
    [anon_sym_import] = ACTIONS(669),
    [anon_sym_let] = ACTIONS(1352),
    [anon_sym_BANG] = ACTIONS(33),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_await] = ACTIONS(45),
    [anon_sym_yield] = ACTIONS(63),
    [anon_sym_LBRACK] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(676),
    [anon_sym_async] = ACTIONS(1362),
    [anon_sym_function] = ACTIONS(680),
    [anon_sym_new] = ACTIONS(1472),
    [anon_sym_using] = ACTIONS(75),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_SLASH] = ACTIONS(77),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(33),
    [anon_sym_void] = ACTIONS(21),
    [anon_sym_delete] = ACTIONS(21),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_DQUOTE] = ACTIONS(83),
    [anon_sym_SQUOTE] = ACTIONS(85),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(87),
    [sym_number] = ACTIONS(89),
    [sym_private_property_identifier] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(93),
    [sym_true] = ACTIONS(93),
    [sym_false] = ACTIONS(93),
    [sym_null] = ACTIONS(93),
    [sym_undefined] = ACTIONS(95),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1352),
    [anon_sym_readonly] = ACTIONS(1352),
    [anon_sym_get] = ACTIONS(1352),
    [anon_sym_set] = ACTIONS(1352),
    [anon_sym_declare] = ACTIONS(1352),
    [anon_sym_public] = ACTIONS(1352),
    [anon_sym_private] = ACTIONS(1352),
    [anon_sym_protected] = ACTIONS(1352),
    [anon_sym_override] = ACTIONS(1352),
    [anon_sym_module] = ACTIONS(1352),
    [anon_sym_any] = ACTIONS(1352),
    [anon_sym_number] = ACTIONS(1352),
    [anon_sym_boolean] = ACTIONS(1352),
    [anon_sym_string] = ACTIONS(1352),
    [anon_sym_symbol] = ACTIONS(1352),
    [anon_sym_object] = ACTIONS(1352),
    [sym_html_comment] = ACTIONS(5),
  },
  [476] = {
    [sym_import] = STATE(3636),
    [sym_parenthesized_expression] = STATE(1410),
    [sym_expression] = STATE(2161),
    [sym_primary_expression] = STATE(1810),
    [sym_yield_expression] = STATE(2358),
    [sym_object] = STATE(2222),
    [sym_object_pattern] = STATE(5580),
    [sym_array] = STATE(2222),
    [sym_array_pattern] = STATE(5580),
    [sym_class] = STATE(2222),
    [sym_function_expression] = STATE(2222),
    [sym_generator_function] = STATE(2222),
    [sym_arrow_function] = STATE(2222),
    [sym__call_signature] = STATE(5466),
    [sym_call_expression] = STATE(2222),
    [sym_new_expression] = STATE(1948),
    [sym_await_expression] = STATE(2358),
    [sym_member_expression] = STATE(1410),
    [sym_subscript_expression] = STATE(1410),
    [sym_assignment_expression] = STATE(2358),
    [sym__augmented_assignment_lhs] = STATE(3004),
    [sym_augmented_assignment_expression] = STATE(2358),
    [sym__destructuring_pattern] = STATE(5580),
    [sym_ternary_expression] = STATE(2358),
    [sym_binary_expression] = STATE(2358),
    [sym_unary_expression] = STATE(2358),
    [sym_update_expression] = STATE(2358),
    [sym_string] = STATE(2222),
    [sym_template_string] = STATE(2222),
    [sym_regex] = STATE(2222),
    [sym_meta_property] = STATE(2222),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1410),
    [sym_type_assertion] = STATE(2358),
    [sym_as_expression] = STATE(2358),
    [sym_satisfies_expression] = STATE(2358),
    [sym_instantiation_expression] = STATE(2358),
    [sym_internal_module] = STATE(2358),
    [sym_type_arguments] = STATE(452),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4408),
    [sym_identifier] = ACTIONS(1498),
    [anon_sym_export] = ACTIONS(1270),
    [anon_sym_type] = ACTIONS(1270),
    [anon_sym_namespace] = ACTIONS(1272),
    [anon_sym_LBRACE] = ACTIONS(665),
    [anon_sym_typeof] = ACTIONS(1298),
    [anon_sym_import] = ACTIONS(669),
    [anon_sym_let] = ACTIONS(1270),
    [anon_sym_BANG] = ACTIONS(1278),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_await] = ACTIONS(1282),
    [anon_sym_yield] = ACTIONS(1284),
    [anon_sym_LBRACK] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(676),
    [anon_sym_async] = ACTIONS(1288),
    [anon_sym_function] = ACTIONS(680),
    [anon_sym_new] = ACTIONS(1502),
    [anon_sym_using] = ACTIONS(1292),
    [anon_sym_PLUS] = ACTIONS(1298),
    [anon_sym_DASH] = ACTIONS(1298),
    [anon_sym_SLASH] = ACTIONS(77),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(1278),
    [anon_sym_void] = ACTIONS(1298),
    [anon_sym_delete] = ACTIONS(1298),
    [anon_sym_PLUS_PLUS] = ACTIONS(1300),
    [anon_sym_DASH_DASH] = ACTIONS(1300),
    [anon_sym_DQUOTE] = ACTIONS(83),
    [anon_sym_SQUOTE] = ACTIONS(85),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(87),
    [sym_number] = ACTIONS(89),
    [sym_private_property_identifier] = ACTIONS(1306),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(93),
    [sym_true] = ACTIONS(93),
    [sym_false] = ACTIONS(93),
    [sym_null] = ACTIONS(93),
    [sym_undefined] = ACTIONS(1504),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1270),
    [anon_sym_readonly] = ACTIONS(1270),
    [anon_sym_get] = ACTIONS(1270),
    [anon_sym_set] = ACTIONS(1270),
    [anon_sym_declare] = ACTIONS(1270),
    [anon_sym_public] = ACTIONS(1270),
    [anon_sym_private] = ACTIONS(1270),
    [anon_sym_protected] = ACTIONS(1270),
    [anon_sym_override] = ACTIONS(1270),
    [anon_sym_module] = ACTIONS(1270),
    [anon_sym_any] = ACTIONS(1270),
    [anon_sym_number] = ACTIONS(1270),
    [anon_sym_boolean] = ACTIONS(1270),
    [anon_sym_string] = ACTIONS(1270),
    [anon_sym_symbol] = ACTIONS(1270),
    [anon_sym_object] = ACTIONS(1270),
    [sym_html_comment] = ACTIONS(5),
  },
  [477] = {
    [sym_import] = STATE(3636),
    [sym_parenthesized_expression] = STATE(1410),
    [sym_expression] = STATE(2162),
    [sym_primary_expression] = STATE(1810),
    [sym_yield_expression] = STATE(2358),
    [sym_object] = STATE(2222),
    [sym_object_pattern] = STATE(5580),
    [sym_array] = STATE(2222),
    [sym_array_pattern] = STATE(5580),
    [sym_class] = STATE(2222),
    [sym_function_expression] = STATE(2222),
    [sym_generator_function] = STATE(2222),
    [sym_arrow_function] = STATE(2222),
    [sym__call_signature] = STATE(5466),
    [sym_call_expression] = STATE(2222),
    [sym_new_expression] = STATE(1948),
    [sym_await_expression] = STATE(2358),
    [sym_member_expression] = STATE(1410),
    [sym_subscript_expression] = STATE(1410),
    [sym_assignment_expression] = STATE(2358),
    [sym__augmented_assignment_lhs] = STATE(3004),
    [sym_augmented_assignment_expression] = STATE(2358),
    [sym__destructuring_pattern] = STATE(5580),
    [sym_ternary_expression] = STATE(2358),
    [sym_binary_expression] = STATE(2358),
    [sym_unary_expression] = STATE(2358),
    [sym_update_expression] = STATE(2358),
    [sym_string] = STATE(2222),
    [sym_template_string] = STATE(2222),
    [sym_regex] = STATE(2222),
    [sym_meta_property] = STATE(2222),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1410),
    [sym_type_assertion] = STATE(2358),
    [sym_as_expression] = STATE(2358),
    [sym_satisfies_expression] = STATE(2358),
    [sym_instantiation_expression] = STATE(2358),
    [sym_internal_module] = STATE(2358),
    [sym_type_arguments] = STATE(452),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4408),
    [sym_identifier] = ACTIONS(1498),
    [anon_sym_export] = ACTIONS(1270),
    [anon_sym_type] = ACTIONS(1270),
    [anon_sym_namespace] = ACTIONS(1272),
    [anon_sym_LBRACE] = ACTIONS(665),
    [anon_sym_typeof] = ACTIONS(1298),
    [anon_sym_import] = ACTIONS(669),
    [anon_sym_let] = ACTIONS(1270),
    [anon_sym_BANG] = ACTIONS(1278),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_await] = ACTIONS(1282),
    [anon_sym_yield] = ACTIONS(1284),
    [anon_sym_LBRACK] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(676),
    [anon_sym_async] = ACTIONS(1288),
    [anon_sym_function] = ACTIONS(680),
    [anon_sym_new] = ACTIONS(1502),
    [anon_sym_using] = ACTIONS(1292),
    [anon_sym_PLUS] = ACTIONS(1298),
    [anon_sym_DASH] = ACTIONS(1298),
    [anon_sym_SLASH] = ACTIONS(77),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(1278),
    [anon_sym_void] = ACTIONS(1298),
    [anon_sym_delete] = ACTIONS(1298),
    [anon_sym_PLUS_PLUS] = ACTIONS(1300),
    [anon_sym_DASH_DASH] = ACTIONS(1300),
    [anon_sym_DQUOTE] = ACTIONS(83),
    [anon_sym_SQUOTE] = ACTIONS(85),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(87),
    [sym_number] = ACTIONS(89),
    [sym_private_property_identifier] = ACTIONS(1306),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(93),
    [sym_true] = ACTIONS(93),
    [sym_false] = ACTIONS(93),
    [sym_null] = ACTIONS(93),
    [sym_undefined] = ACTIONS(1504),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1270),
    [anon_sym_readonly] = ACTIONS(1270),
    [anon_sym_get] = ACTIONS(1270),
    [anon_sym_set] = ACTIONS(1270),
    [anon_sym_declare] = ACTIONS(1270),
    [anon_sym_public] = ACTIONS(1270),
    [anon_sym_private] = ACTIONS(1270),
    [anon_sym_protected] = ACTIONS(1270),
    [anon_sym_override] = ACTIONS(1270),
    [anon_sym_module] = ACTIONS(1270),
    [anon_sym_any] = ACTIONS(1270),
    [anon_sym_number] = ACTIONS(1270),
    [anon_sym_boolean] = ACTIONS(1270),
    [anon_sym_string] = ACTIONS(1270),
    [anon_sym_symbol] = ACTIONS(1270),
    [anon_sym_object] = ACTIONS(1270),
    [sym_html_comment] = ACTIONS(5),
  },
  [478] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1398),
    [sym_expression] = STATE(1960),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5544),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5544),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5558),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1398),
    [sym_subscript_expression] = STATE(1398),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(2980),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5544),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1398),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(638),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1482),
    [anon_sym_export] = ACTIONS(1158),
    [anon_sym_type] = ACTIONS(1158),
    [anon_sym_namespace] = ACTIONS(1160),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_typeof] = ACTIONS(756),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1158),
    [anon_sym_BANG] = ACTIONS(732),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(736),
    [anon_sym_yield] = ACTIONS(738),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1164),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1486),
    [anon_sym_using] = ACTIONS(746),
    [anon_sym_PLUS] = ACTIONS(756),
    [anon_sym_DASH] = ACTIONS(756),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(732),
    [anon_sym_void] = ACTIONS(756),
    [anon_sym_delete] = ACTIONS(756),
    [anon_sym_PLUS_PLUS] = ACTIONS(758),
    [anon_sym_DASH_DASH] = ACTIONS(758),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(2173),
    [sym_private_property_identifier] = ACTIONS(764),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1488),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1158),
    [anon_sym_readonly] = ACTIONS(1158),
    [anon_sym_get] = ACTIONS(1158),
    [anon_sym_set] = ACTIONS(1158),
    [anon_sym_declare] = ACTIONS(1158),
    [anon_sym_public] = ACTIONS(1158),
    [anon_sym_private] = ACTIONS(1158),
    [anon_sym_protected] = ACTIONS(1158),
    [anon_sym_override] = ACTIONS(1158),
    [anon_sym_module] = ACTIONS(1158),
    [anon_sym_any] = ACTIONS(1158),
    [anon_sym_number] = ACTIONS(1158),
    [anon_sym_boolean] = ACTIONS(1158),
    [anon_sym_string] = ACTIONS(1158),
    [anon_sym_symbol] = ACTIONS(1158),
    [anon_sym_object] = ACTIONS(1158),
    [sym_html_comment] = ACTIONS(5),
  },
  [479] = {
    [sym_import] = STATE(3636),
    [sym_parenthesized_expression] = STATE(1362),
    [sym_expression] = STATE(1806),
    [sym_primary_expression] = STATE(1810),
    [sym_yield_expression] = STATE(2358),
    [sym_object] = STATE(2222),
    [sym_object_pattern] = STATE(5492),
    [sym_array] = STATE(2222),
    [sym_array_pattern] = STATE(5492),
    [sym_class] = STATE(2222),
    [sym_function_expression] = STATE(2222),
    [sym_generator_function] = STATE(2222),
    [sym_arrow_function] = STATE(2222),
    [sym__call_signature] = STATE(5821),
    [sym_call_expression] = STATE(2222),
    [sym_new_expression] = STATE(1948),
    [sym_await_expression] = STATE(2358),
    [sym_member_expression] = STATE(1362),
    [sym_subscript_expression] = STATE(1362),
    [sym_assignment_expression] = STATE(2358),
    [sym__augmented_assignment_lhs] = STATE(3025),
    [sym_augmented_assignment_expression] = STATE(2358),
    [sym__destructuring_pattern] = STATE(5492),
    [sym_ternary_expression] = STATE(2358),
    [sym_binary_expression] = STATE(2358),
    [sym_unary_expression] = STATE(2358),
    [sym_update_expression] = STATE(2358),
    [sym_string] = STATE(2222),
    [sym_template_string] = STATE(2222),
    [sym_regex] = STATE(2222),
    [sym_meta_property] = STATE(2222),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1362),
    [sym_type_assertion] = STATE(2358),
    [sym_as_expression] = STATE(2358),
    [sym_satisfies_expression] = STATE(2358),
    [sym_instantiation_expression] = STATE(2358),
    [sym_internal_module] = STATE(2358),
    [sym_type_arguments] = STATE(428),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4408),
    [sym_identifier] = ACTIONS(1468),
    [anon_sym_export] = ACTIONS(1352),
    [anon_sym_type] = ACTIONS(1352),
    [anon_sym_namespace] = ACTIONS(1354),
    [anon_sym_LBRACE] = ACTIONS(665),
    [anon_sym_typeof] = ACTIONS(21),
    [anon_sym_import] = ACTIONS(669),
    [anon_sym_let] = ACTIONS(1352),
    [anon_sym_BANG] = ACTIONS(33),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_await] = ACTIONS(45),
    [anon_sym_yield] = ACTIONS(63),
    [anon_sym_LBRACK] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(676),
    [anon_sym_async] = ACTIONS(1362),
    [anon_sym_function] = ACTIONS(680),
    [anon_sym_new] = ACTIONS(1472),
    [anon_sym_using] = ACTIONS(75),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_SLASH] = ACTIONS(77),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(33),
    [anon_sym_void] = ACTIONS(21),
    [anon_sym_delete] = ACTIONS(21),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_DQUOTE] = ACTIONS(83),
    [anon_sym_SQUOTE] = ACTIONS(85),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(87),
    [sym_number] = ACTIONS(89),
    [sym_private_property_identifier] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(93),
    [sym_true] = ACTIONS(93),
    [sym_false] = ACTIONS(93),
    [sym_null] = ACTIONS(93),
    [sym_undefined] = ACTIONS(95),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1352),
    [anon_sym_readonly] = ACTIONS(1352),
    [anon_sym_get] = ACTIONS(1352),
    [anon_sym_set] = ACTIONS(1352),
    [anon_sym_declare] = ACTIONS(1352),
    [anon_sym_public] = ACTIONS(1352),
    [anon_sym_private] = ACTIONS(1352),
    [anon_sym_protected] = ACTIONS(1352),
    [anon_sym_override] = ACTIONS(1352),
    [anon_sym_module] = ACTIONS(1352),
    [anon_sym_any] = ACTIONS(1352),
    [anon_sym_number] = ACTIONS(1352),
    [anon_sym_boolean] = ACTIONS(1352),
    [anon_sym_string] = ACTIONS(1352),
    [anon_sym_symbol] = ACTIONS(1352),
    [anon_sym_object] = ACTIONS(1352),
    [sym_html_comment] = ACTIONS(5),
  },
  [480] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1322),
    [sym_expression] = STATE(2312),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5698),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5698),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5508),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1322),
    [sym_subscript_expression] = STATE(1322),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3003),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5698),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1322),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(484),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1456),
    [anon_sym_export] = ACTIONS(1048),
    [anon_sym_type] = ACTIONS(1048),
    [anon_sym_namespace] = ACTIONS(1050),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_typeof] = ACTIONS(581),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1048),
    [anon_sym_BANG] = ACTIONS(553),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(555),
    [anon_sym_yield] = ACTIONS(557),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1058),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1464),
    [anon_sym_using] = ACTIONS(567),
    [anon_sym_PLUS] = ACTIONS(581),
    [anon_sym_DASH] = ACTIONS(581),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(553),
    [anon_sym_void] = ACTIONS(581),
    [anon_sym_delete] = ACTIONS(581),
    [anon_sym_PLUS_PLUS] = ACTIONS(583),
    [anon_sym_DASH_DASH] = ACTIONS(583),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(585),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1466),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1048),
    [anon_sym_readonly] = ACTIONS(1048),
    [anon_sym_get] = ACTIONS(1048),
    [anon_sym_set] = ACTIONS(1048),
    [anon_sym_declare] = ACTIONS(1048),
    [anon_sym_public] = ACTIONS(1048),
    [anon_sym_private] = ACTIONS(1048),
    [anon_sym_protected] = ACTIONS(1048),
    [anon_sym_override] = ACTIONS(1048),
    [anon_sym_module] = ACTIONS(1048),
    [anon_sym_any] = ACTIONS(1048),
    [anon_sym_number] = ACTIONS(1048),
    [anon_sym_boolean] = ACTIONS(1048),
    [anon_sym_string] = ACTIONS(1048),
    [anon_sym_symbol] = ACTIONS(1048),
    [anon_sym_object] = ACTIONS(1048),
    [sym_html_comment] = ACTIONS(5),
  },
  [481] = {
    [sym_import] = STATE(3636),
    [sym_parenthesized_expression] = STATE(1410),
    [sym_expression] = STATE(2167),
    [sym_primary_expression] = STATE(1810),
    [sym_yield_expression] = STATE(2358),
    [sym_object] = STATE(2222),
    [sym_object_pattern] = STATE(5580),
    [sym_array] = STATE(2222),
    [sym_array_pattern] = STATE(5580),
    [sym_class] = STATE(2222),
    [sym_function_expression] = STATE(2222),
    [sym_generator_function] = STATE(2222),
    [sym_arrow_function] = STATE(2222),
    [sym__call_signature] = STATE(5466),
    [sym_call_expression] = STATE(2222),
    [sym_new_expression] = STATE(1948),
    [sym_await_expression] = STATE(2358),
    [sym_member_expression] = STATE(1410),
    [sym_subscript_expression] = STATE(1410),
    [sym_assignment_expression] = STATE(2358),
    [sym__augmented_assignment_lhs] = STATE(3004),
    [sym_augmented_assignment_expression] = STATE(2358),
    [sym__destructuring_pattern] = STATE(5580),
    [sym_ternary_expression] = STATE(2358),
    [sym_binary_expression] = STATE(2358),
    [sym_unary_expression] = STATE(2358),
    [sym_update_expression] = STATE(2358),
    [sym_string] = STATE(2222),
    [sym_template_string] = STATE(2222),
    [sym_regex] = STATE(2222),
    [sym_meta_property] = STATE(2222),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1410),
    [sym_type_assertion] = STATE(2358),
    [sym_as_expression] = STATE(2358),
    [sym_satisfies_expression] = STATE(2358),
    [sym_instantiation_expression] = STATE(2358),
    [sym_internal_module] = STATE(2358),
    [sym_type_arguments] = STATE(452),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4408),
    [sym_identifier] = ACTIONS(1498),
    [anon_sym_export] = ACTIONS(1270),
    [anon_sym_type] = ACTIONS(1270),
    [anon_sym_namespace] = ACTIONS(1272),
    [anon_sym_LBRACE] = ACTIONS(665),
    [anon_sym_typeof] = ACTIONS(1298),
    [anon_sym_import] = ACTIONS(669),
    [anon_sym_let] = ACTIONS(1270),
    [anon_sym_BANG] = ACTIONS(1278),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_await] = ACTIONS(1282),
    [anon_sym_yield] = ACTIONS(1284),
    [anon_sym_LBRACK] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(676),
    [anon_sym_async] = ACTIONS(1288),
    [anon_sym_function] = ACTIONS(680),
    [anon_sym_new] = ACTIONS(1502),
    [anon_sym_using] = ACTIONS(1292),
    [anon_sym_PLUS] = ACTIONS(1298),
    [anon_sym_DASH] = ACTIONS(1298),
    [anon_sym_SLASH] = ACTIONS(77),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(1278),
    [anon_sym_void] = ACTIONS(1298),
    [anon_sym_delete] = ACTIONS(1298),
    [anon_sym_PLUS_PLUS] = ACTIONS(1300),
    [anon_sym_DASH_DASH] = ACTIONS(1300),
    [anon_sym_DQUOTE] = ACTIONS(83),
    [anon_sym_SQUOTE] = ACTIONS(85),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(87),
    [sym_number] = ACTIONS(89),
    [sym_private_property_identifier] = ACTIONS(1306),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(93),
    [sym_true] = ACTIONS(93),
    [sym_false] = ACTIONS(93),
    [sym_null] = ACTIONS(93),
    [sym_undefined] = ACTIONS(1504),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1270),
    [anon_sym_readonly] = ACTIONS(1270),
    [anon_sym_get] = ACTIONS(1270),
    [anon_sym_set] = ACTIONS(1270),
    [anon_sym_declare] = ACTIONS(1270),
    [anon_sym_public] = ACTIONS(1270),
    [anon_sym_private] = ACTIONS(1270),
    [anon_sym_protected] = ACTIONS(1270),
    [anon_sym_override] = ACTIONS(1270),
    [anon_sym_module] = ACTIONS(1270),
    [anon_sym_any] = ACTIONS(1270),
    [anon_sym_number] = ACTIONS(1270),
    [anon_sym_boolean] = ACTIONS(1270),
    [anon_sym_string] = ACTIONS(1270),
    [anon_sym_symbol] = ACTIONS(1270),
    [anon_sym_object] = ACTIONS(1270),
    [sym_html_comment] = ACTIONS(5),
  },
  [482] = {
    [sym_import] = STATE(3636),
    [sym_parenthesized_expression] = STATE(1362),
    [sym_expression] = STATE(1814),
    [sym_primary_expression] = STATE(1810),
    [sym_yield_expression] = STATE(2358),
    [sym_object] = STATE(2222),
    [sym_object_pattern] = STATE(5492),
    [sym_array] = STATE(2222),
    [sym_array_pattern] = STATE(5492),
    [sym_class] = STATE(2222),
    [sym_function_expression] = STATE(2222),
    [sym_generator_function] = STATE(2222),
    [sym_arrow_function] = STATE(2222),
    [sym__call_signature] = STATE(5821),
    [sym_call_expression] = STATE(2222),
    [sym_new_expression] = STATE(1948),
    [sym_await_expression] = STATE(2358),
    [sym_member_expression] = STATE(1362),
    [sym_subscript_expression] = STATE(1362),
    [sym_assignment_expression] = STATE(2358),
    [sym__augmented_assignment_lhs] = STATE(3025),
    [sym_augmented_assignment_expression] = STATE(2358),
    [sym__destructuring_pattern] = STATE(5492),
    [sym_ternary_expression] = STATE(2358),
    [sym_binary_expression] = STATE(2358),
    [sym_unary_expression] = STATE(2358),
    [sym_update_expression] = STATE(2358),
    [sym_string] = STATE(2222),
    [sym_template_string] = STATE(2222),
    [sym_regex] = STATE(2222),
    [sym_meta_property] = STATE(2222),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1362),
    [sym_type_assertion] = STATE(2358),
    [sym_as_expression] = STATE(2358),
    [sym_satisfies_expression] = STATE(2358),
    [sym_instantiation_expression] = STATE(2358),
    [sym_internal_module] = STATE(2358),
    [sym_type_arguments] = STATE(428),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4408),
    [sym_identifier] = ACTIONS(1468),
    [anon_sym_export] = ACTIONS(1352),
    [anon_sym_type] = ACTIONS(1352),
    [anon_sym_namespace] = ACTIONS(1354),
    [anon_sym_LBRACE] = ACTIONS(665),
    [anon_sym_typeof] = ACTIONS(21),
    [anon_sym_import] = ACTIONS(669),
    [anon_sym_let] = ACTIONS(1352),
    [anon_sym_BANG] = ACTIONS(33),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_await] = ACTIONS(45),
    [anon_sym_yield] = ACTIONS(63),
    [anon_sym_LBRACK] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(676),
    [anon_sym_async] = ACTIONS(1362),
    [anon_sym_function] = ACTIONS(680),
    [anon_sym_new] = ACTIONS(1472),
    [anon_sym_using] = ACTIONS(75),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_SLASH] = ACTIONS(77),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(33),
    [anon_sym_void] = ACTIONS(21),
    [anon_sym_delete] = ACTIONS(21),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_DQUOTE] = ACTIONS(83),
    [anon_sym_SQUOTE] = ACTIONS(85),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(87),
    [sym_number] = ACTIONS(89),
    [sym_private_property_identifier] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(93),
    [sym_true] = ACTIONS(93),
    [sym_false] = ACTIONS(93),
    [sym_null] = ACTIONS(93),
    [sym_undefined] = ACTIONS(95),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1352),
    [anon_sym_readonly] = ACTIONS(1352),
    [anon_sym_get] = ACTIONS(1352),
    [anon_sym_set] = ACTIONS(1352),
    [anon_sym_declare] = ACTIONS(1352),
    [anon_sym_public] = ACTIONS(1352),
    [anon_sym_private] = ACTIONS(1352),
    [anon_sym_protected] = ACTIONS(1352),
    [anon_sym_override] = ACTIONS(1352),
    [anon_sym_module] = ACTIONS(1352),
    [anon_sym_any] = ACTIONS(1352),
    [anon_sym_number] = ACTIONS(1352),
    [anon_sym_boolean] = ACTIONS(1352),
    [anon_sym_string] = ACTIONS(1352),
    [anon_sym_symbol] = ACTIONS(1352),
    [anon_sym_object] = ACTIONS(1352),
    [sym_html_comment] = ACTIONS(5),
  },
  [483] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1213),
    [sym_expression] = STATE(2580),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5522),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5522),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5800),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1213),
    [sym_subscript_expression] = STATE(1213),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3013),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5522),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1213),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(539),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(802),
    [anon_sym_export] = ACTIONS(804),
    [anon_sym_type] = ACTIONS(804),
    [anon_sym_namespace] = ACTIONS(806),
    [anon_sym_LBRACE] = ACTIONS(808),
    [anon_sym_typeof] = ACTIONS(179),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(804),
    [anon_sym_BANG] = ACTIONS(175),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(140),
    [anon_sym_yield] = ACTIONS(142),
    [anon_sym_LBRACK] = ACTIONS(812),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(816),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(818),
    [anon_sym_using] = ACTIONS(158),
    [anon_sym_PLUS] = ACTIONS(179),
    [anon_sym_DASH] = ACTIONS(179),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(175),
    [anon_sym_void] = ACTIONS(179),
    [anon_sym_delete] = ACTIONS(179),
    [anon_sym_PLUS_PLUS] = ACTIONS(686),
    [anon_sym_DASH_DASH] = ACTIONS(686),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(192),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(822),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(804),
    [anon_sym_readonly] = ACTIONS(804),
    [anon_sym_get] = ACTIONS(804),
    [anon_sym_set] = ACTIONS(804),
    [anon_sym_declare] = ACTIONS(804),
    [anon_sym_public] = ACTIONS(804),
    [anon_sym_private] = ACTIONS(804),
    [anon_sym_protected] = ACTIONS(804),
    [anon_sym_override] = ACTIONS(804),
    [anon_sym_module] = ACTIONS(804),
    [anon_sym_any] = ACTIONS(804),
    [anon_sym_number] = ACTIONS(804),
    [anon_sym_boolean] = ACTIONS(804),
    [anon_sym_string] = ACTIONS(804),
    [anon_sym_symbol] = ACTIONS(804),
    [anon_sym_object] = ACTIONS(804),
    [sym_html_comment] = ACTIONS(5),
  },
  [484] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1322),
    [sym_expression] = STATE(1739),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5698),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5698),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5508),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1322),
    [sym_subscript_expression] = STATE(1322),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3003),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5698),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1322),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(484),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1456),
    [anon_sym_export] = ACTIONS(1048),
    [anon_sym_type] = ACTIONS(1048),
    [anon_sym_namespace] = ACTIONS(1050),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_typeof] = ACTIONS(581),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1048),
    [anon_sym_BANG] = ACTIONS(553),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(555),
    [anon_sym_yield] = ACTIONS(557),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1058),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1464),
    [anon_sym_using] = ACTIONS(567),
    [anon_sym_PLUS] = ACTIONS(581),
    [anon_sym_DASH] = ACTIONS(581),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(553),
    [anon_sym_void] = ACTIONS(581),
    [anon_sym_delete] = ACTIONS(581),
    [anon_sym_PLUS_PLUS] = ACTIONS(583),
    [anon_sym_DASH_DASH] = ACTIONS(583),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(585),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1466),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1048),
    [anon_sym_readonly] = ACTIONS(1048),
    [anon_sym_get] = ACTIONS(1048),
    [anon_sym_set] = ACTIONS(1048),
    [anon_sym_declare] = ACTIONS(1048),
    [anon_sym_public] = ACTIONS(1048),
    [anon_sym_private] = ACTIONS(1048),
    [anon_sym_protected] = ACTIONS(1048),
    [anon_sym_override] = ACTIONS(1048),
    [anon_sym_module] = ACTIONS(1048),
    [anon_sym_any] = ACTIONS(1048),
    [anon_sym_number] = ACTIONS(1048),
    [anon_sym_boolean] = ACTIONS(1048),
    [anon_sym_string] = ACTIONS(1048),
    [anon_sym_symbol] = ACTIONS(1048),
    [anon_sym_object] = ACTIONS(1048),
    [sym_html_comment] = ACTIONS(5),
  },
  [485] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1322),
    [sym_expression] = STATE(1741),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5698),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5698),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5508),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1322),
    [sym_subscript_expression] = STATE(1322),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3003),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5698),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1322),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(484),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1456),
    [anon_sym_export] = ACTIONS(1048),
    [anon_sym_type] = ACTIONS(1048),
    [anon_sym_namespace] = ACTIONS(1050),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_typeof] = ACTIONS(581),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1048),
    [anon_sym_BANG] = ACTIONS(553),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(555),
    [anon_sym_yield] = ACTIONS(557),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1058),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1464),
    [anon_sym_using] = ACTIONS(567),
    [anon_sym_PLUS] = ACTIONS(581),
    [anon_sym_DASH] = ACTIONS(581),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(553),
    [anon_sym_void] = ACTIONS(581),
    [anon_sym_delete] = ACTIONS(581),
    [anon_sym_PLUS_PLUS] = ACTIONS(583),
    [anon_sym_DASH_DASH] = ACTIONS(583),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(585),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1466),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1048),
    [anon_sym_readonly] = ACTIONS(1048),
    [anon_sym_get] = ACTIONS(1048),
    [anon_sym_set] = ACTIONS(1048),
    [anon_sym_declare] = ACTIONS(1048),
    [anon_sym_public] = ACTIONS(1048),
    [anon_sym_private] = ACTIONS(1048),
    [anon_sym_protected] = ACTIONS(1048),
    [anon_sym_override] = ACTIONS(1048),
    [anon_sym_module] = ACTIONS(1048),
    [anon_sym_any] = ACTIONS(1048),
    [anon_sym_number] = ACTIONS(1048),
    [anon_sym_boolean] = ACTIONS(1048),
    [anon_sym_string] = ACTIONS(1048),
    [anon_sym_symbol] = ACTIONS(1048),
    [anon_sym_object] = ACTIONS(1048),
    [sym_html_comment] = ACTIONS(5),
  },
  [486] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1468),
    [sym_expression] = STATE(2644),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5658),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5658),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5800),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1468),
    [sym_subscript_expression] = STATE(1468),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3013),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5658),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1468),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(539),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(2203),
    [anon_sym_export] = ACTIONS(2205),
    [anon_sym_type] = ACTIONS(2205),
    [anon_sym_namespace] = ACTIONS(2207),
    [anon_sym_LBRACE] = ACTIONS(808),
    [anon_sym_typeof] = ACTIONS(179),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(2205),
    [anon_sym_BANG] = ACTIONS(175),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(140),
    [anon_sym_yield] = ACTIONS(142),
    [anon_sym_LBRACK] = ACTIONS(812),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(2209),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(2211),
    [anon_sym_using] = ACTIONS(158),
    [anon_sym_PLUS] = ACTIONS(179),
    [anon_sym_DASH] = ACTIONS(179),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(175),
    [anon_sym_void] = ACTIONS(179),
    [anon_sym_delete] = ACTIONS(179),
    [anon_sym_PLUS_PLUS] = ACTIONS(686),
    [anon_sym_DASH_DASH] = ACTIONS(686),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(192),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(2213),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(2205),
    [anon_sym_readonly] = ACTIONS(2205),
    [anon_sym_get] = ACTIONS(2205),
    [anon_sym_set] = ACTIONS(2205),
    [anon_sym_declare] = ACTIONS(2205),
    [anon_sym_public] = ACTIONS(2205),
    [anon_sym_private] = ACTIONS(2205),
    [anon_sym_protected] = ACTIONS(2205),
    [anon_sym_override] = ACTIONS(2205),
    [anon_sym_module] = ACTIONS(2205),
    [anon_sym_any] = ACTIONS(2205),
    [anon_sym_number] = ACTIONS(2205),
    [anon_sym_boolean] = ACTIONS(2205),
    [anon_sym_string] = ACTIONS(2205),
    [anon_sym_symbol] = ACTIONS(2205),
    [anon_sym_object] = ACTIONS(2205),
    [sym_html_comment] = ACTIONS(5),
  },
  [487] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1322),
    [sym_expression] = STATE(1743),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5698),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5698),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5508),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1322),
    [sym_subscript_expression] = STATE(1322),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3003),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5698),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1322),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(484),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1456),
    [anon_sym_export] = ACTIONS(1048),
    [anon_sym_type] = ACTIONS(1048),
    [anon_sym_namespace] = ACTIONS(1050),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_typeof] = ACTIONS(581),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1048),
    [anon_sym_BANG] = ACTIONS(553),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(555),
    [anon_sym_yield] = ACTIONS(557),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1058),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1464),
    [anon_sym_using] = ACTIONS(567),
    [anon_sym_PLUS] = ACTIONS(581),
    [anon_sym_DASH] = ACTIONS(581),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(553),
    [anon_sym_void] = ACTIONS(581),
    [anon_sym_delete] = ACTIONS(581),
    [anon_sym_PLUS_PLUS] = ACTIONS(583),
    [anon_sym_DASH_DASH] = ACTIONS(583),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(585),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1466),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1048),
    [anon_sym_readonly] = ACTIONS(1048),
    [anon_sym_get] = ACTIONS(1048),
    [anon_sym_set] = ACTIONS(1048),
    [anon_sym_declare] = ACTIONS(1048),
    [anon_sym_public] = ACTIONS(1048),
    [anon_sym_private] = ACTIONS(1048),
    [anon_sym_protected] = ACTIONS(1048),
    [anon_sym_override] = ACTIONS(1048),
    [anon_sym_module] = ACTIONS(1048),
    [anon_sym_any] = ACTIONS(1048),
    [anon_sym_number] = ACTIONS(1048),
    [anon_sym_boolean] = ACTIONS(1048),
    [anon_sym_string] = ACTIONS(1048),
    [anon_sym_symbol] = ACTIONS(1048),
    [anon_sym_object] = ACTIONS(1048),
    [sym_html_comment] = ACTIONS(5),
  },
  [488] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1322),
    [sym_expression] = STATE(1744),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5698),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5698),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5508),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1322),
    [sym_subscript_expression] = STATE(1322),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3003),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5698),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1322),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(484),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1456),
    [anon_sym_export] = ACTIONS(1048),
    [anon_sym_type] = ACTIONS(1048),
    [anon_sym_namespace] = ACTIONS(1050),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_typeof] = ACTIONS(581),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1048),
    [anon_sym_BANG] = ACTIONS(553),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(555),
    [anon_sym_yield] = ACTIONS(557),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1058),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1464),
    [anon_sym_using] = ACTIONS(567),
    [anon_sym_PLUS] = ACTIONS(581),
    [anon_sym_DASH] = ACTIONS(581),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(553),
    [anon_sym_void] = ACTIONS(581),
    [anon_sym_delete] = ACTIONS(581),
    [anon_sym_PLUS_PLUS] = ACTIONS(583),
    [anon_sym_DASH_DASH] = ACTIONS(583),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(585),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1466),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1048),
    [anon_sym_readonly] = ACTIONS(1048),
    [anon_sym_get] = ACTIONS(1048),
    [anon_sym_set] = ACTIONS(1048),
    [anon_sym_declare] = ACTIONS(1048),
    [anon_sym_public] = ACTIONS(1048),
    [anon_sym_private] = ACTIONS(1048),
    [anon_sym_protected] = ACTIONS(1048),
    [anon_sym_override] = ACTIONS(1048),
    [anon_sym_module] = ACTIONS(1048),
    [anon_sym_any] = ACTIONS(1048),
    [anon_sym_number] = ACTIONS(1048),
    [anon_sym_boolean] = ACTIONS(1048),
    [anon_sym_string] = ACTIONS(1048),
    [anon_sym_symbol] = ACTIONS(1048),
    [anon_sym_object] = ACTIONS(1048),
    [sym_html_comment] = ACTIONS(5),
  },
  [489] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1322),
    [sym_expression] = STATE(1746),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5698),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5698),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5508),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1322),
    [sym_subscript_expression] = STATE(1322),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3003),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5698),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1322),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(484),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1456),
    [anon_sym_export] = ACTIONS(1048),
    [anon_sym_type] = ACTIONS(1048),
    [anon_sym_namespace] = ACTIONS(1050),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_typeof] = ACTIONS(581),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1048),
    [anon_sym_BANG] = ACTIONS(553),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(555),
    [anon_sym_yield] = ACTIONS(557),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1058),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1464),
    [anon_sym_using] = ACTIONS(567),
    [anon_sym_PLUS] = ACTIONS(581),
    [anon_sym_DASH] = ACTIONS(581),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(553),
    [anon_sym_void] = ACTIONS(581),
    [anon_sym_delete] = ACTIONS(581),
    [anon_sym_PLUS_PLUS] = ACTIONS(583),
    [anon_sym_DASH_DASH] = ACTIONS(583),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(585),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1466),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1048),
    [anon_sym_readonly] = ACTIONS(1048),
    [anon_sym_get] = ACTIONS(1048),
    [anon_sym_set] = ACTIONS(1048),
    [anon_sym_declare] = ACTIONS(1048),
    [anon_sym_public] = ACTIONS(1048),
    [anon_sym_private] = ACTIONS(1048),
    [anon_sym_protected] = ACTIONS(1048),
    [anon_sym_override] = ACTIONS(1048),
    [anon_sym_module] = ACTIONS(1048),
    [anon_sym_any] = ACTIONS(1048),
    [anon_sym_number] = ACTIONS(1048),
    [anon_sym_boolean] = ACTIONS(1048),
    [anon_sym_string] = ACTIONS(1048),
    [anon_sym_symbol] = ACTIONS(1048),
    [anon_sym_object] = ACTIONS(1048),
    [sym_html_comment] = ACTIONS(5),
  },
  [490] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1322),
    [sym_expression] = STATE(1747),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5698),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5698),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5508),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1322),
    [sym_subscript_expression] = STATE(1322),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3003),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5698),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1322),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(484),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1456),
    [anon_sym_export] = ACTIONS(1048),
    [anon_sym_type] = ACTIONS(1048),
    [anon_sym_namespace] = ACTIONS(1050),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_typeof] = ACTIONS(581),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1048),
    [anon_sym_BANG] = ACTIONS(553),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(555),
    [anon_sym_yield] = ACTIONS(557),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1058),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1464),
    [anon_sym_using] = ACTIONS(567),
    [anon_sym_PLUS] = ACTIONS(581),
    [anon_sym_DASH] = ACTIONS(581),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(553),
    [anon_sym_void] = ACTIONS(581),
    [anon_sym_delete] = ACTIONS(581),
    [anon_sym_PLUS_PLUS] = ACTIONS(583),
    [anon_sym_DASH_DASH] = ACTIONS(583),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(585),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1466),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1048),
    [anon_sym_readonly] = ACTIONS(1048),
    [anon_sym_get] = ACTIONS(1048),
    [anon_sym_set] = ACTIONS(1048),
    [anon_sym_declare] = ACTIONS(1048),
    [anon_sym_public] = ACTIONS(1048),
    [anon_sym_private] = ACTIONS(1048),
    [anon_sym_protected] = ACTIONS(1048),
    [anon_sym_override] = ACTIONS(1048),
    [anon_sym_module] = ACTIONS(1048),
    [anon_sym_any] = ACTIONS(1048),
    [anon_sym_number] = ACTIONS(1048),
    [anon_sym_boolean] = ACTIONS(1048),
    [anon_sym_string] = ACTIONS(1048),
    [anon_sym_symbol] = ACTIONS(1048),
    [anon_sym_object] = ACTIONS(1048),
    [sym_html_comment] = ACTIONS(5),
  },
  [491] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1322),
    [sym_expression] = STATE(1794),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5698),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5698),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5508),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1322),
    [sym_subscript_expression] = STATE(1322),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3003),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5698),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1322),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(484),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1456),
    [anon_sym_export] = ACTIONS(1048),
    [anon_sym_type] = ACTIONS(1048),
    [anon_sym_namespace] = ACTIONS(1050),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_typeof] = ACTIONS(581),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1048),
    [anon_sym_BANG] = ACTIONS(553),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(555),
    [anon_sym_yield] = ACTIONS(557),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1058),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1464),
    [anon_sym_using] = ACTIONS(567),
    [anon_sym_PLUS] = ACTIONS(581),
    [anon_sym_DASH] = ACTIONS(581),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(553),
    [anon_sym_void] = ACTIONS(581),
    [anon_sym_delete] = ACTIONS(581),
    [anon_sym_PLUS_PLUS] = ACTIONS(583),
    [anon_sym_DASH_DASH] = ACTIONS(583),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(585),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1466),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1048),
    [anon_sym_readonly] = ACTIONS(1048),
    [anon_sym_get] = ACTIONS(1048),
    [anon_sym_set] = ACTIONS(1048),
    [anon_sym_declare] = ACTIONS(1048),
    [anon_sym_public] = ACTIONS(1048),
    [anon_sym_private] = ACTIONS(1048),
    [anon_sym_protected] = ACTIONS(1048),
    [anon_sym_override] = ACTIONS(1048),
    [anon_sym_module] = ACTIONS(1048),
    [anon_sym_any] = ACTIONS(1048),
    [anon_sym_number] = ACTIONS(1048),
    [anon_sym_boolean] = ACTIONS(1048),
    [anon_sym_string] = ACTIONS(1048),
    [anon_sym_symbol] = ACTIONS(1048),
    [anon_sym_object] = ACTIONS(1048),
    [sym_html_comment] = ACTIONS(5),
  },
  [492] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1322),
    [sym_expression] = STATE(1748),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5698),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5698),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5508),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1322),
    [sym_subscript_expression] = STATE(1322),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3003),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5698),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1322),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(484),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1456),
    [anon_sym_export] = ACTIONS(1048),
    [anon_sym_type] = ACTIONS(1048),
    [anon_sym_namespace] = ACTIONS(1050),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_typeof] = ACTIONS(581),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1048),
    [anon_sym_BANG] = ACTIONS(553),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(555),
    [anon_sym_yield] = ACTIONS(557),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1058),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1464),
    [anon_sym_using] = ACTIONS(567),
    [anon_sym_PLUS] = ACTIONS(581),
    [anon_sym_DASH] = ACTIONS(581),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(553),
    [anon_sym_void] = ACTIONS(581),
    [anon_sym_delete] = ACTIONS(581),
    [anon_sym_PLUS_PLUS] = ACTIONS(583),
    [anon_sym_DASH_DASH] = ACTIONS(583),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(585),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1466),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1048),
    [anon_sym_readonly] = ACTIONS(1048),
    [anon_sym_get] = ACTIONS(1048),
    [anon_sym_set] = ACTIONS(1048),
    [anon_sym_declare] = ACTIONS(1048),
    [anon_sym_public] = ACTIONS(1048),
    [anon_sym_private] = ACTIONS(1048),
    [anon_sym_protected] = ACTIONS(1048),
    [anon_sym_override] = ACTIONS(1048),
    [anon_sym_module] = ACTIONS(1048),
    [anon_sym_any] = ACTIONS(1048),
    [anon_sym_number] = ACTIONS(1048),
    [anon_sym_boolean] = ACTIONS(1048),
    [anon_sym_string] = ACTIONS(1048),
    [anon_sym_symbol] = ACTIONS(1048),
    [anon_sym_object] = ACTIONS(1048),
    [sym_html_comment] = ACTIONS(5),
  },
  [493] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1322),
    [sym_expression] = STATE(1749),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5698),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5698),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5508),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1322),
    [sym_subscript_expression] = STATE(1322),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3003),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5698),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1322),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(484),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1456),
    [anon_sym_export] = ACTIONS(1048),
    [anon_sym_type] = ACTIONS(1048),
    [anon_sym_namespace] = ACTIONS(1050),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_typeof] = ACTIONS(581),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1048),
    [anon_sym_BANG] = ACTIONS(553),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(555),
    [anon_sym_yield] = ACTIONS(557),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1058),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1464),
    [anon_sym_using] = ACTIONS(567),
    [anon_sym_PLUS] = ACTIONS(581),
    [anon_sym_DASH] = ACTIONS(581),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(553),
    [anon_sym_void] = ACTIONS(581),
    [anon_sym_delete] = ACTIONS(581),
    [anon_sym_PLUS_PLUS] = ACTIONS(583),
    [anon_sym_DASH_DASH] = ACTIONS(583),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(585),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1466),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1048),
    [anon_sym_readonly] = ACTIONS(1048),
    [anon_sym_get] = ACTIONS(1048),
    [anon_sym_set] = ACTIONS(1048),
    [anon_sym_declare] = ACTIONS(1048),
    [anon_sym_public] = ACTIONS(1048),
    [anon_sym_private] = ACTIONS(1048),
    [anon_sym_protected] = ACTIONS(1048),
    [anon_sym_override] = ACTIONS(1048),
    [anon_sym_module] = ACTIONS(1048),
    [anon_sym_any] = ACTIONS(1048),
    [anon_sym_number] = ACTIONS(1048),
    [anon_sym_boolean] = ACTIONS(1048),
    [anon_sym_string] = ACTIONS(1048),
    [anon_sym_symbol] = ACTIONS(1048),
    [anon_sym_object] = ACTIONS(1048),
    [sym_html_comment] = ACTIONS(5),
  },
  [494] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1322),
    [sym_expression] = STATE(1779),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5698),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5698),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5508),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1322),
    [sym_subscript_expression] = STATE(1322),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3003),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5698),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1322),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(484),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1456),
    [anon_sym_export] = ACTIONS(1048),
    [anon_sym_type] = ACTIONS(1048),
    [anon_sym_namespace] = ACTIONS(1050),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_typeof] = ACTIONS(581),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1048),
    [anon_sym_BANG] = ACTIONS(553),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(555),
    [anon_sym_yield] = ACTIONS(557),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1058),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1464),
    [anon_sym_using] = ACTIONS(567),
    [anon_sym_PLUS] = ACTIONS(581),
    [anon_sym_DASH] = ACTIONS(581),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(553),
    [anon_sym_void] = ACTIONS(581),
    [anon_sym_delete] = ACTIONS(581),
    [anon_sym_PLUS_PLUS] = ACTIONS(583),
    [anon_sym_DASH_DASH] = ACTIONS(583),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(585),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1466),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1048),
    [anon_sym_readonly] = ACTIONS(1048),
    [anon_sym_get] = ACTIONS(1048),
    [anon_sym_set] = ACTIONS(1048),
    [anon_sym_declare] = ACTIONS(1048),
    [anon_sym_public] = ACTIONS(1048),
    [anon_sym_private] = ACTIONS(1048),
    [anon_sym_protected] = ACTIONS(1048),
    [anon_sym_override] = ACTIONS(1048),
    [anon_sym_module] = ACTIONS(1048),
    [anon_sym_any] = ACTIONS(1048),
    [anon_sym_number] = ACTIONS(1048),
    [anon_sym_boolean] = ACTIONS(1048),
    [anon_sym_string] = ACTIONS(1048),
    [anon_sym_symbol] = ACTIONS(1048),
    [anon_sym_object] = ACTIONS(1048),
    [sym_html_comment] = ACTIONS(5),
  },
  [495] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1322),
    [sym_expression] = STATE(1751),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5698),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5698),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5508),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1322),
    [sym_subscript_expression] = STATE(1322),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3003),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5698),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1322),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(484),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1456),
    [anon_sym_export] = ACTIONS(1048),
    [anon_sym_type] = ACTIONS(1048),
    [anon_sym_namespace] = ACTIONS(1050),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_typeof] = ACTIONS(581),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1048),
    [anon_sym_BANG] = ACTIONS(553),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(555),
    [anon_sym_yield] = ACTIONS(557),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1058),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1464),
    [anon_sym_using] = ACTIONS(567),
    [anon_sym_PLUS] = ACTIONS(581),
    [anon_sym_DASH] = ACTIONS(581),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(553),
    [anon_sym_void] = ACTIONS(581),
    [anon_sym_delete] = ACTIONS(581),
    [anon_sym_PLUS_PLUS] = ACTIONS(583),
    [anon_sym_DASH_DASH] = ACTIONS(583),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(585),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1466),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1048),
    [anon_sym_readonly] = ACTIONS(1048),
    [anon_sym_get] = ACTIONS(1048),
    [anon_sym_set] = ACTIONS(1048),
    [anon_sym_declare] = ACTIONS(1048),
    [anon_sym_public] = ACTIONS(1048),
    [anon_sym_private] = ACTIONS(1048),
    [anon_sym_protected] = ACTIONS(1048),
    [anon_sym_override] = ACTIONS(1048),
    [anon_sym_module] = ACTIONS(1048),
    [anon_sym_any] = ACTIONS(1048),
    [anon_sym_number] = ACTIONS(1048),
    [anon_sym_boolean] = ACTIONS(1048),
    [anon_sym_string] = ACTIONS(1048),
    [anon_sym_symbol] = ACTIONS(1048),
    [anon_sym_object] = ACTIONS(1048),
    [sym_html_comment] = ACTIONS(5),
  },
  [496] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1322),
    [sym_expression] = STATE(1752),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5698),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5698),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5508),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1322),
    [sym_subscript_expression] = STATE(1322),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3003),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5698),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1322),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(484),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1456),
    [anon_sym_export] = ACTIONS(1048),
    [anon_sym_type] = ACTIONS(1048),
    [anon_sym_namespace] = ACTIONS(1050),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_typeof] = ACTIONS(581),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1048),
    [anon_sym_BANG] = ACTIONS(553),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(555),
    [anon_sym_yield] = ACTIONS(557),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1058),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1464),
    [anon_sym_using] = ACTIONS(567),
    [anon_sym_PLUS] = ACTIONS(581),
    [anon_sym_DASH] = ACTIONS(581),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(553),
    [anon_sym_void] = ACTIONS(581),
    [anon_sym_delete] = ACTIONS(581),
    [anon_sym_PLUS_PLUS] = ACTIONS(583),
    [anon_sym_DASH_DASH] = ACTIONS(583),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(585),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1466),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1048),
    [anon_sym_readonly] = ACTIONS(1048),
    [anon_sym_get] = ACTIONS(1048),
    [anon_sym_set] = ACTIONS(1048),
    [anon_sym_declare] = ACTIONS(1048),
    [anon_sym_public] = ACTIONS(1048),
    [anon_sym_private] = ACTIONS(1048),
    [anon_sym_protected] = ACTIONS(1048),
    [anon_sym_override] = ACTIONS(1048),
    [anon_sym_module] = ACTIONS(1048),
    [anon_sym_any] = ACTIONS(1048),
    [anon_sym_number] = ACTIONS(1048),
    [anon_sym_boolean] = ACTIONS(1048),
    [anon_sym_string] = ACTIONS(1048),
    [anon_sym_symbol] = ACTIONS(1048),
    [anon_sym_object] = ACTIONS(1048),
    [sym_html_comment] = ACTIONS(5),
  },
  [497] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1322),
    [sym_expression] = STATE(1753),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5698),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5698),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5508),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1322),
    [sym_subscript_expression] = STATE(1322),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3003),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5698),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1322),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(484),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1456),
    [anon_sym_export] = ACTIONS(1048),
    [anon_sym_type] = ACTIONS(1048),
    [anon_sym_namespace] = ACTIONS(1050),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_typeof] = ACTIONS(581),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1048),
    [anon_sym_BANG] = ACTIONS(553),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(555),
    [anon_sym_yield] = ACTIONS(557),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1058),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1464),
    [anon_sym_using] = ACTIONS(567),
    [anon_sym_PLUS] = ACTIONS(581),
    [anon_sym_DASH] = ACTIONS(581),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(553),
    [anon_sym_void] = ACTIONS(581),
    [anon_sym_delete] = ACTIONS(581),
    [anon_sym_PLUS_PLUS] = ACTIONS(583),
    [anon_sym_DASH_DASH] = ACTIONS(583),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(585),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1466),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1048),
    [anon_sym_readonly] = ACTIONS(1048),
    [anon_sym_get] = ACTIONS(1048),
    [anon_sym_set] = ACTIONS(1048),
    [anon_sym_declare] = ACTIONS(1048),
    [anon_sym_public] = ACTIONS(1048),
    [anon_sym_private] = ACTIONS(1048),
    [anon_sym_protected] = ACTIONS(1048),
    [anon_sym_override] = ACTIONS(1048),
    [anon_sym_module] = ACTIONS(1048),
    [anon_sym_any] = ACTIONS(1048),
    [anon_sym_number] = ACTIONS(1048),
    [anon_sym_boolean] = ACTIONS(1048),
    [anon_sym_string] = ACTIONS(1048),
    [anon_sym_symbol] = ACTIONS(1048),
    [anon_sym_object] = ACTIONS(1048),
    [sym_html_comment] = ACTIONS(5),
  },
  [498] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1322),
    [sym_expression] = STATE(1754),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5698),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5698),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5508),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1322),
    [sym_subscript_expression] = STATE(1322),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3003),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5698),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1322),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(484),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1456),
    [anon_sym_export] = ACTIONS(1048),
    [anon_sym_type] = ACTIONS(1048),
    [anon_sym_namespace] = ACTIONS(1050),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_typeof] = ACTIONS(581),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1048),
    [anon_sym_BANG] = ACTIONS(553),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(555),
    [anon_sym_yield] = ACTIONS(557),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1058),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1464),
    [anon_sym_using] = ACTIONS(567),
    [anon_sym_PLUS] = ACTIONS(581),
    [anon_sym_DASH] = ACTIONS(581),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(553),
    [anon_sym_void] = ACTIONS(581),
    [anon_sym_delete] = ACTIONS(581),
    [anon_sym_PLUS_PLUS] = ACTIONS(583),
    [anon_sym_DASH_DASH] = ACTIONS(583),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(585),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1466),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1048),
    [anon_sym_readonly] = ACTIONS(1048),
    [anon_sym_get] = ACTIONS(1048),
    [anon_sym_set] = ACTIONS(1048),
    [anon_sym_declare] = ACTIONS(1048),
    [anon_sym_public] = ACTIONS(1048),
    [anon_sym_private] = ACTIONS(1048),
    [anon_sym_protected] = ACTIONS(1048),
    [anon_sym_override] = ACTIONS(1048),
    [anon_sym_module] = ACTIONS(1048),
    [anon_sym_any] = ACTIONS(1048),
    [anon_sym_number] = ACTIONS(1048),
    [anon_sym_boolean] = ACTIONS(1048),
    [anon_sym_string] = ACTIONS(1048),
    [anon_sym_symbol] = ACTIONS(1048),
    [anon_sym_object] = ACTIONS(1048),
    [sym_html_comment] = ACTIONS(5),
  },
  [499] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1322),
    [sym_expression] = STATE(1755),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5698),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5698),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5508),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1322),
    [sym_subscript_expression] = STATE(1322),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3003),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5698),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1322),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(484),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1456),
    [anon_sym_export] = ACTIONS(1048),
    [anon_sym_type] = ACTIONS(1048),
    [anon_sym_namespace] = ACTIONS(1050),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_typeof] = ACTIONS(581),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1048),
    [anon_sym_BANG] = ACTIONS(553),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(555),
    [anon_sym_yield] = ACTIONS(557),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1058),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1464),
    [anon_sym_using] = ACTIONS(567),
    [anon_sym_PLUS] = ACTIONS(581),
    [anon_sym_DASH] = ACTIONS(581),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(553),
    [anon_sym_void] = ACTIONS(581),
    [anon_sym_delete] = ACTIONS(581),
    [anon_sym_PLUS_PLUS] = ACTIONS(583),
    [anon_sym_DASH_DASH] = ACTIONS(583),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(585),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1466),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1048),
    [anon_sym_readonly] = ACTIONS(1048),
    [anon_sym_get] = ACTIONS(1048),
    [anon_sym_set] = ACTIONS(1048),
    [anon_sym_declare] = ACTIONS(1048),
    [anon_sym_public] = ACTIONS(1048),
    [anon_sym_private] = ACTIONS(1048),
    [anon_sym_protected] = ACTIONS(1048),
    [anon_sym_override] = ACTIONS(1048),
    [anon_sym_module] = ACTIONS(1048),
    [anon_sym_any] = ACTIONS(1048),
    [anon_sym_number] = ACTIONS(1048),
    [anon_sym_boolean] = ACTIONS(1048),
    [anon_sym_string] = ACTIONS(1048),
    [anon_sym_symbol] = ACTIONS(1048),
    [anon_sym_object] = ACTIONS(1048),
    [sym_html_comment] = ACTIONS(5),
  },
  [500] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1322),
    [sym_expression] = STATE(1756),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5698),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5698),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5508),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1322),
    [sym_subscript_expression] = STATE(1322),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3003),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5698),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1322),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(484),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1456),
    [anon_sym_export] = ACTIONS(1048),
    [anon_sym_type] = ACTIONS(1048),
    [anon_sym_namespace] = ACTIONS(1050),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_typeof] = ACTIONS(581),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1048),
    [anon_sym_BANG] = ACTIONS(553),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(555),
    [anon_sym_yield] = ACTIONS(557),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1058),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1464),
    [anon_sym_using] = ACTIONS(567),
    [anon_sym_PLUS] = ACTIONS(581),
    [anon_sym_DASH] = ACTIONS(581),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(553),
    [anon_sym_void] = ACTIONS(581),
    [anon_sym_delete] = ACTIONS(581),
    [anon_sym_PLUS_PLUS] = ACTIONS(583),
    [anon_sym_DASH_DASH] = ACTIONS(583),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(585),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1466),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1048),
    [anon_sym_readonly] = ACTIONS(1048),
    [anon_sym_get] = ACTIONS(1048),
    [anon_sym_set] = ACTIONS(1048),
    [anon_sym_declare] = ACTIONS(1048),
    [anon_sym_public] = ACTIONS(1048),
    [anon_sym_private] = ACTIONS(1048),
    [anon_sym_protected] = ACTIONS(1048),
    [anon_sym_override] = ACTIONS(1048),
    [anon_sym_module] = ACTIONS(1048),
    [anon_sym_any] = ACTIONS(1048),
    [anon_sym_number] = ACTIONS(1048),
    [anon_sym_boolean] = ACTIONS(1048),
    [anon_sym_string] = ACTIONS(1048),
    [anon_sym_symbol] = ACTIONS(1048),
    [anon_sym_object] = ACTIONS(1048),
    [sym_html_comment] = ACTIONS(5),
  },
  [501] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1322),
    [sym_expression] = STATE(1757),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5698),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5698),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5508),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1322),
    [sym_subscript_expression] = STATE(1322),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3003),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5698),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1322),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(484),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1456),
    [anon_sym_export] = ACTIONS(1048),
    [anon_sym_type] = ACTIONS(1048),
    [anon_sym_namespace] = ACTIONS(1050),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_typeof] = ACTIONS(581),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1048),
    [anon_sym_BANG] = ACTIONS(553),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(555),
    [anon_sym_yield] = ACTIONS(557),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1058),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1464),
    [anon_sym_using] = ACTIONS(567),
    [anon_sym_PLUS] = ACTIONS(581),
    [anon_sym_DASH] = ACTIONS(581),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(553),
    [anon_sym_void] = ACTIONS(581),
    [anon_sym_delete] = ACTIONS(581),
    [anon_sym_PLUS_PLUS] = ACTIONS(583),
    [anon_sym_DASH_DASH] = ACTIONS(583),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(585),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1466),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1048),
    [anon_sym_readonly] = ACTIONS(1048),
    [anon_sym_get] = ACTIONS(1048),
    [anon_sym_set] = ACTIONS(1048),
    [anon_sym_declare] = ACTIONS(1048),
    [anon_sym_public] = ACTIONS(1048),
    [anon_sym_private] = ACTIONS(1048),
    [anon_sym_protected] = ACTIONS(1048),
    [anon_sym_override] = ACTIONS(1048),
    [anon_sym_module] = ACTIONS(1048),
    [anon_sym_any] = ACTIONS(1048),
    [anon_sym_number] = ACTIONS(1048),
    [anon_sym_boolean] = ACTIONS(1048),
    [anon_sym_string] = ACTIONS(1048),
    [anon_sym_symbol] = ACTIONS(1048),
    [anon_sym_object] = ACTIONS(1048),
    [sym_html_comment] = ACTIONS(5),
  },
  [502] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1322),
    [sym_expression] = STATE(1759),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5698),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5698),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5508),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1322),
    [sym_subscript_expression] = STATE(1322),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3003),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5698),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1322),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(484),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1456),
    [anon_sym_export] = ACTIONS(1048),
    [anon_sym_type] = ACTIONS(1048),
    [anon_sym_namespace] = ACTIONS(1050),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_typeof] = ACTIONS(581),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1048),
    [anon_sym_BANG] = ACTIONS(553),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(555),
    [anon_sym_yield] = ACTIONS(557),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1058),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1464),
    [anon_sym_using] = ACTIONS(567),
    [anon_sym_PLUS] = ACTIONS(581),
    [anon_sym_DASH] = ACTIONS(581),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(553),
    [anon_sym_void] = ACTIONS(581),
    [anon_sym_delete] = ACTIONS(581),
    [anon_sym_PLUS_PLUS] = ACTIONS(583),
    [anon_sym_DASH_DASH] = ACTIONS(583),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(585),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1466),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1048),
    [anon_sym_readonly] = ACTIONS(1048),
    [anon_sym_get] = ACTIONS(1048),
    [anon_sym_set] = ACTIONS(1048),
    [anon_sym_declare] = ACTIONS(1048),
    [anon_sym_public] = ACTIONS(1048),
    [anon_sym_private] = ACTIONS(1048),
    [anon_sym_protected] = ACTIONS(1048),
    [anon_sym_override] = ACTIONS(1048),
    [anon_sym_module] = ACTIONS(1048),
    [anon_sym_any] = ACTIONS(1048),
    [anon_sym_number] = ACTIONS(1048),
    [anon_sym_boolean] = ACTIONS(1048),
    [anon_sym_string] = ACTIONS(1048),
    [anon_sym_symbol] = ACTIONS(1048),
    [anon_sym_object] = ACTIONS(1048),
    [sym_html_comment] = ACTIONS(5),
  },
  [503] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1322),
    [sym_expression] = STATE(2427),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5698),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5698),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5508),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1322),
    [sym_subscript_expression] = STATE(1322),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3003),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5698),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1322),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(484),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1456),
    [anon_sym_export] = ACTIONS(1048),
    [anon_sym_type] = ACTIONS(1048),
    [anon_sym_namespace] = ACTIONS(1050),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_typeof] = ACTIONS(581),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1048),
    [anon_sym_BANG] = ACTIONS(553),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(555),
    [anon_sym_yield] = ACTIONS(557),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1058),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1464),
    [anon_sym_using] = ACTIONS(567),
    [anon_sym_PLUS] = ACTIONS(581),
    [anon_sym_DASH] = ACTIONS(581),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(553),
    [anon_sym_void] = ACTIONS(581),
    [anon_sym_delete] = ACTIONS(581),
    [anon_sym_PLUS_PLUS] = ACTIONS(583),
    [anon_sym_DASH_DASH] = ACTIONS(583),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(585),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1466),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1048),
    [anon_sym_readonly] = ACTIONS(1048),
    [anon_sym_get] = ACTIONS(1048),
    [anon_sym_set] = ACTIONS(1048),
    [anon_sym_declare] = ACTIONS(1048),
    [anon_sym_public] = ACTIONS(1048),
    [anon_sym_private] = ACTIONS(1048),
    [anon_sym_protected] = ACTIONS(1048),
    [anon_sym_override] = ACTIONS(1048),
    [anon_sym_module] = ACTIONS(1048),
    [anon_sym_any] = ACTIONS(1048),
    [anon_sym_number] = ACTIONS(1048),
    [anon_sym_boolean] = ACTIONS(1048),
    [anon_sym_string] = ACTIONS(1048),
    [anon_sym_symbol] = ACTIONS(1048),
    [anon_sym_object] = ACTIONS(1048),
    [sym_html_comment] = ACTIONS(5),
  },
  [504] = {
    [sym_import] = STATE(3636),
    [sym_parenthesized_expression] = STATE(1362),
    [sym_expression] = STATE(1807),
    [sym_primary_expression] = STATE(1810),
    [sym_yield_expression] = STATE(2358),
    [sym_object] = STATE(2222),
    [sym_object_pattern] = STATE(5492),
    [sym_array] = STATE(2222),
    [sym_array_pattern] = STATE(5492),
    [sym_class] = STATE(2222),
    [sym_function_expression] = STATE(2222),
    [sym_generator_function] = STATE(2222),
    [sym_arrow_function] = STATE(2222),
    [sym__call_signature] = STATE(5821),
    [sym_call_expression] = STATE(2222),
    [sym_new_expression] = STATE(1948),
    [sym_await_expression] = STATE(2358),
    [sym_member_expression] = STATE(1362),
    [sym_subscript_expression] = STATE(1362),
    [sym_assignment_expression] = STATE(2358),
    [sym__augmented_assignment_lhs] = STATE(3025),
    [sym_augmented_assignment_expression] = STATE(2358),
    [sym__destructuring_pattern] = STATE(5492),
    [sym_ternary_expression] = STATE(2358),
    [sym_binary_expression] = STATE(2358),
    [sym_unary_expression] = STATE(2358),
    [sym_update_expression] = STATE(2358),
    [sym_string] = STATE(2222),
    [sym_template_string] = STATE(2222),
    [sym_regex] = STATE(2222),
    [sym_meta_property] = STATE(2222),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1362),
    [sym_type_assertion] = STATE(2358),
    [sym_as_expression] = STATE(2358),
    [sym_satisfies_expression] = STATE(2358),
    [sym_instantiation_expression] = STATE(2358),
    [sym_internal_module] = STATE(2358),
    [sym_type_arguments] = STATE(428),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4408),
    [sym_identifier] = ACTIONS(1468),
    [anon_sym_export] = ACTIONS(1352),
    [anon_sym_type] = ACTIONS(1352),
    [anon_sym_namespace] = ACTIONS(1354),
    [anon_sym_LBRACE] = ACTIONS(665),
    [anon_sym_typeof] = ACTIONS(21),
    [anon_sym_import] = ACTIONS(669),
    [anon_sym_let] = ACTIONS(1352),
    [anon_sym_BANG] = ACTIONS(33),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_await] = ACTIONS(45),
    [anon_sym_yield] = ACTIONS(63),
    [anon_sym_LBRACK] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(676),
    [anon_sym_async] = ACTIONS(1362),
    [anon_sym_function] = ACTIONS(680),
    [anon_sym_new] = ACTIONS(1472),
    [anon_sym_using] = ACTIONS(75),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_SLASH] = ACTIONS(77),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(33),
    [anon_sym_void] = ACTIONS(21),
    [anon_sym_delete] = ACTIONS(21),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_DQUOTE] = ACTIONS(83),
    [anon_sym_SQUOTE] = ACTIONS(85),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(87),
    [sym_number] = ACTIONS(89),
    [sym_private_property_identifier] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(93),
    [sym_true] = ACTIONS(93),
    [sym_false] = ACTIONS(93),
    [sym_null] = ACTIONS(93),
    [sym_undefined] = ACTIONS(95),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1352),
    [anon_sym_readonly] = ACTIONS(1352),
    [anon_sym_get] = ACTIONS(1352),
    [anon_sym_set] = ACTIONS(1352),
    [anon_sym_declare] = ACTIONS(1352),
    [anon_sym_public] = ACTIONS(1352),
    [anon_sym_private] = ACTIONS(1352),
    [anon_sym_protected] = ACTIONS(1352),
    [anon_sym_override] = ACTIONS(1352),
    [anon_sym_module] = ACTIONS(1352),
    [anon_sym_any] = ACTIONS(1352),
    [anon_sym_number] = ACTIONS(1352),
    [anon_sym_boolean] = ACTIONS(1352),
    [anon_sym_string] = ACTIONS(1352),
    [anon_sym_symbol] = ACTIONS(1352),
    [anon_sym_object] = ACTIONS(1352),
    [sym_html_comment] = ACTIONS(5),
  },
  [505] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1322),
    [sym_expression] = STATE(1763),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5698),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5698),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5508),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1322),
    [sym_subscript_expression] = STATE(1322),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3003),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5698),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1322),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(484),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1456),
    [anon_sym_export] = ACTIONS(1048),
    [anon_sym_type] = ACTIONS(1048),
    [anon_sym_namespace] = ACTIONS(1050),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_typeof] = ACTIONS(581),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1048),
    [anon_sym_BANG] = ACTIONS(553),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(555),
    [anon_sym_yield] = ACTIONS(557),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1058),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1464),
    [anon_sym_using] = ACTIONS(567),
    [anon_sym_PLUS] = ACTIONS(581),
    [anon_sym_DASH] = ACTIONS(581),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(553),
    [anon_sym_void] = ACTIONS(581),
    [anon_sym_delete] = ACTIONS(581),
    [anon_sym_PLUS_PLUS] = ACTIONS(583),
    [anon_sym_DASH_DASH] = ACTIONS(583),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(585),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1466),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1048),
    [anon_sym_readonly] = ACTIONS(1048),
    [anon_sym_get] = ACTIONS(1048),
    [anon_sym_set] = ACTIONS(1048),
    [anon_sym_declare] = ACTIONS(1048),
    [anon_sym_public] = ACTIONS(1048),
    [anon_sym_private] = ACTIONS(1048),
    [anon_sym_protected] = ACTIONS(1048),
    [anon_sym_override] = ACTIONS(1048),
    [anon_sym_module] = ACTIONS(1048),
    [anon_sym_any] = ACTIONS(1048),
    [anon_sym_number] = ACTIONS(1048),
    [anon_sym_boolean] = ACTIONS(1048),
    [anon_sym_string] = ACTIONS(1048),
    [anon_sym_symbol] = ACTIONS(1048),
    [anon_sym_object] = ACTIONS(1048),
    [sym_html_comment] = ACTIONS(5),
  },
  [506] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1322),
    [sym_expression] = STATE(1764),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5698),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5698),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5508),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1322),
    [sym_subscript_expression] = STATE(1322),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3003),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5698),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1322),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(484),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1456),
    [anon_sym_export] = ACTIONS(1048),
    [anon_sym_type] = ACTIONS(1048),
    [anon_sym_namespace] = ACTIONS(1050),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_typeof] = ACTIONS(581),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1048),
    [anon_sym_BANG] = ACTIONS(553),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(555),
    [anon_sym_yield] = ACTIONS(557),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1058),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1464),
    [anon_sym_using] = ACTIONS(567),
    [anon_sym_PLUS] = ACTIONS(581),
    [anon_sym_DASH] = ACTIONS(581),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(553),
    [anon_sym_void] = ACTIONS(581),
    [anon_sym_delete] = ACTIONS(581),
    [anon_sym_PLUS_PLUS] = ACTIONS(583),
    [anon_sym_DASH_DASH] = ACTIONS(583),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(585),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1466),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1048),
    [anon_sym_readonly] = ACTIONS(1048),
    [anon_sym_get] = ACTIONS(1048),
    [anon_sym_set] = ACTIONS(1048),
    [anon_sym_declare] = ACTIONS(1048),
    [anon_sym_public] = ACTIONS(1048),
    [anon_sym_private] = ACTIONS(1048),
    [anon_sym_protected] = ACTIONS(1048),
    [anon_sym_override] = ACTIONS(1048),
    [anon_sym_module] = ACTIONS(1048),
    [anon_sym_any] = ACTIONS(1048),
    [anon_sym_number] = ACTIONS(1048),
    [anon_sym_boolean] = ACTIONS(1048),
    [anon_sym_string] = ACTIONS(1048),
    [anon_sym_symbol] = ACTIONS(1048),
    [anon_sym_object] = ACTIONS(1048),
    [sym_html_comment] = ACTIONS(5),
  },
  [507] = {
    [sym_import] = STATE(3636),
    [sym_parenthesized_expression] = STATE(1410),
    [sym_expression] = STATE(2239),
    [sym_primary_expression] = STATE(1810),
    [sym_yield_expression] = STATE(2358),
    [sym_object] = STATE(2222),
    [sym_object_pattern] = STATE(5580),
    [sym_array] = STATE(2222),
    [sym_array_pattern] = STATE(5580),
    [sym_class] = STATE(2222),
    [sym_function_expression] = STATE(2222),
    [sym_generator_function] = STATE(2222),
    [sym_arrow_function] = STATE(2222),
    [sym__call_signature] = STATE(5466),
    [sym_call_expression] = STATE(2222),
    [sym_new_expression] = STATE(1948),
    [sym_await_expression] = STATE(2358),
    [sym_member_expression] = STATE(1410),
    [sym_subscript_expression] = STATE(1410),
    [sym_assignment_expression] = STATE(2358),
    [sym__augmented_assignment_lhs] = STATE(3004),
    [sym_augmented_assignment_expression] = STATE(2358),
    [sym__destructuring_pattern] = STATE(5580),
    [sym_ternary_expression] = STATE(2358),
    [sym_binary_expression] = STATE(2358),
    [sym_unary_expression] = STATE(2358),
    [sym_update_expression] = STATE(2358),
    [sym_string] = STATE(2222),
    [sym_template_string] = STATE(2222),
    [sym_regex] = STATE(2222),
    [sym_meta_property] = STATE(2222),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1410),
    [sym_type_assertion] = STATE(2358),
    [sym_as_expression] = STATE(2358),
    [sym_satisfies_expression] = STATE(2358),
    [sym_instantiation_expression] = STATE(2358),
    [sym_internal_module] = STATE(2358),
    [sym_type_arguments] = STATE(452),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4408),
    [sym_identifier] = ACTIONS(1498),
    [anon_sym_export] = ACTIONS(1270),
    [anon_sym_type] = ACTIONS(1270),
    [anon_sym_namespace] = ACTIONS(1272),
    [anon_sym_LBRACE] = ACTIONS(665),
    [anon_sym_typeof] = ACTIONS(1298),
    [anon_sym_import] = ACTIONS(669),
    [anon_sym_let] = ACTIONS(1270),
    [anon_sym_BANG] = ACTIONS(1278),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_await] = ACTIONS(1282),
    [anon_sym_yield] = ACTIONS(1284),
    [anon_sym_LBRACK] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(676),
    [anon_sym_async] = ACTIONS(1288),
    [anon_sym_function] = ACTIONS(680),
    [anon_sym_new] = ACTIONS(1502),
    [anon_sym_using] = ACTIONS(1292),
    [anon_sym_PLUS] = ACTIONS(1298),
    [anon_sym_DASH] = ACTIONS(1298),
    [anon_sym_SLASH] = ACTIONS(77),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(1278),
    [anon_sym_void] = ACTIONS(1298),
    [anon_sym_delete] = ACTIONS(1298),
    [anon_sym_PLUS_PLUS] = ACTIONS(1300),
    [anon_sym_DASH_DASH] = ACTIONS(1300),
    [anon_sym_DQUOTE] = ACTIONS(83),
    [anon_sym_SQUOTE] = ACTIONS(85),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(87),
    [sym_number] = ACTIONS(2125),
    [sym_private_property_identifier] = ACTIONS(1306),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(93),
    [sym_true] = ACTIONS(93),
    [sym_false] = ACTIONS(93),
    [sym_null] = ACTIONS(93),
    [sym_undefined] = ACTIONS(1504),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1270),
    [anon_sym_readonly] = ACTIONS(1270),
    [anon_sym_get] = ACTIONS(1270),
    [anon_sym_set] = ACTIONS(1270),
    [anon_sym_declare] = ACTIONS(1270),
    [anon_sym_public] = ACTIONS(1270),
    [anon_sym_private] = ACTIONS(1270),
    [anon_sym_protected] = ACTIONS(1270),
    [anon_sym_override] = ACTIONS(1270),
    [anon_sym_module] = ACTIONS(1270),
    [anon_sym_any] = ACTIONS(1270),
    [anon_sym_number] = ACTIONS(1270),
    [anon_sym_boolean] = ACTIONS(1270),
    [anon_sym_string] = ACTIONS(1270),
    [anon_sym_symbol] = ACTIONS(1270),
    [anon_sym_object] = ACTIONS(1270),
    [sym_html_comment] = ACTIONS(5),
  },
  [508] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1322),
    [sym_expression] = STATE(1765),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5698),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5698),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5508),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1322),
    [sym_subscript_expression] = STATE(1322),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3003),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5698),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1322),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(484),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1456),
    [anon_sym_export] = ACTIONS(1048),
    [anon_sym_type] = ACTIONS(1048),
    [anon_sym_namespace] = ACTIONS(1050),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_typeof] = ACTIONS(581),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1048),
    [anon_sym_BANG] = ACTIONS(553),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(555),
    [anon_sym_yield] = ACTIONS(557),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1058),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1464),
    [anon_sym_using] = ACTIONS(567),
    [anon_sym_PLUS] = ACTIONS(581),
    [anon_sym_DASH] = ACTIONS(581),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(553),
    [anon_sym_void] = ACTIONS(581),
    [anon_sym_delete] = ACTIONS(581),
    [anon_sym_PLUS_PLUS] = ACTIONS(583),
    [anon_sym_DASH_DASH] = ACTIONS(583),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(585),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1466),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1048),
    [anon_sym_readonly] = ACTIONS(1048),
    [anon_sym_get] = ACTIONS(1048),
    [anon_sym_set] = ACTIONS(1048),
    [anon_sym_declare] = ACTIONS(1048),
    [anon_sym_public] = ACTIONS(1048),
    [anon_sym_private] = ACTIONS(1048),
    [anon_sym_protected] = ACTIONS(1048),
    [anon_sym_override] = ACTIONS(1048),
    [anon_sym_module] = ACTIONS(1048),
    [anon_sym_any] = ACTIONS(1048),
    [anon_sym_number] = ACTIONS(1048),
    [anon_sym_boolean] = ACTIONS(1048),
    [anon_sym_string] = ACTIONS(1048),
    [anon_sym_symbol] = ACTIONS(1048),
    [anon_sym_object] = ACTIONS(1048),
    [sym_html_comment] = ACTIONS(5),
  },
  [509] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1322),
    [sym_expression] = STATE(1776),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5698),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5698),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5508),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1322),
    [sym_subscript_expression] = STATE(1322),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3003),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5698),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1322),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(484),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1456),
    [anon_sym_export] = ACTIONS(1048),
    [anon_sym_type] = ACTIONS(1048),
    [anon_sym_namespace] = ACTIONS(1050),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_typeof] = ACTIONS(581),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1048),
    [anon_sym_BANG] = ACTIONS(553),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(555),
    [anon_sym_yield] = ACTIONS(557),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1058),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1464),
    [anon_sym_using] = ACTIONS(567),
    [anon_sym_PLUS] = ACTIONS(581),
    [anon_sym_DASH] = ACTIONS(581),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(553),
    [anon_sym_void] = ACTIONS(581),
    [anon_sym_delete] = ACTIONS(581),
    [anon_sym_PLUS_PLUS] = ACTIONS(583),
    [anon_sym_DASH_DASH] = ACTIONS(583),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(585),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1466),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1048),
    [anon_sym_readonly] = ACTIONS(1048),
    [anon_sym_get] = ACTIONS(1048),
    [anon_sym_set] = ACTIONS(1048),
    [anon_sym_declare] = ACTIONS(1048),
    [anon_sym_public] = ACTIONS(1048),
    [anon_sym_private] = ACTIONS(1048),
    [anon_sym_protected] = ACTIONS(1048),
    [anon_sym_override] = ACTIONS(1048),
    [anon_sym_module] = ACTIONS(1048),
    [anon_sym_any] = ACTIONS(1048),
    [anon_sym_number] = ACTIONS(1048),
    [anon_sym_boolean] = ACTIONS(1048),
    [anon_sym_string] = ACTIONS(1048),
    [anon_sym_symbol] = ACTIONS(1048),
    [anon_sym_object] = ACTIONS(1048),
    [sym_html_comment] = ACTIONS(5),
  },
  [510] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1322),
    [sym_expression] = STATE(1722),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5698),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5698),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5508),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1322),
    [sym_subscript_expression] = STATE(1322),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3003),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5698),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1322),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(484),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1456),
    [anon_sym_export] = ACTIONS(1048),
    [anon_sym_type] = ACTIONS(1048),
    [anon_sym_namespace] = ACTIONS(1050),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_typeof] = ACTIONS(581),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1048),
    [anon_sym_BANG] = ACTIONS(553),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(555),
    [anon_sym_yield] = ACTIONS(557),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1058),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1464),
    [anon_sym_using] = ACTIONS(567),
    [anon_sym_PLUS] = ACTIONS(581),
    [anon_sym_DASH] = ACTIONS(581),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(553),
    [anon_sym_void] = ACTIONS(581),
    [anon_sym_delete] = ACTIONS(581),
    [anon_sym_PLUS_PLUS] = ACTIONS(583),
    [anon_sym_DASH_DASH] = ACTIONS(583),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(585),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1466),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1048),
    [anon_sym_readonly] = ACTIONS(1048),
    [anon_sym_get] = ACTIONS(1048),
    [anon_sym_set] = ACTIONS(1048),
    [anon_sym_declare] = ACTIONS(1048),
    [anon_sym_public] = ACTIONS(1048),
    [anon_sym_private] = ACTIONS(1048),
    [anon_sym_protected] = ACTIONS(1048),
    [anon_sym_override] = ACTIONS(1048),
    [anon_sym_module] = ACTIONS(1048),
    [anon_sym_any] = ACTIONS(1048),
    [anon_sym_number] = ACTIONS(1048),
    [anon_sym_boolean] = ACTIONS(1048),
    [anon_sym_string] = ACTIONS(1048),
    [anon_sym_symbol] = ACTIONS(1048),
    [anon_sym_object] = ACTIONS(1048),
    [sym_html_comment] = ACTIONS(5),
  },
  [511] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1322),
    [sym_expression] = STATE(1776),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5698),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5698),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5508),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1322),
    [sym_subscript_expression] = STATE(1322),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3003),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5698),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1322),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(484),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1456),
    [anon_sym_export] = ACTIONS(1048),
    [anon_sym_type] = ACTIONS(1048),
    [anon_sym_namespace] = ACTIONS(1050),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_typeof] = ACTIONS(581),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1048),
    [anon_sym_BANG] = ACTIONS(553),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(555),
    [anon_sym_yield] = ACTIONS(557),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1058),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1464),
    [anon_sym_using] = ACTIONS(567),
    [anon_sym_PLUS] = ACTIONS(581),
    [anon_sym_DASH] = ACTIONS(581),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(553),
    [anon_sym_void] = ACTIONS(581),
    [anon_sym_delete] = ACTIONS(581),
    [anon_sym_PLUS_PLUS] = ACTIONS(583),
    [anon_sym_DASH_DASH] = ACTIONS(583),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(2171),
    [sym_private_property_identifier] = ACTIONS(585),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1466),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1048),
    [anon_sym_readonly] = ACTIONS(1048),
    [anon_sym_get] = ACTIONS(1048),
    [anon_sym_set] = ACTIONS(1048),
    [anon_sym_declare] = ACTIONS(1048),
    [anon_sym_public] = ACTIONS(1048),
    [anon_sym_private] = ACTIONS(1048),
    [anon_sym_protected] = ACTIONS(1048),
    [anon_sym_override] = ACTIONS(1048),
    [anon_sym_module] = ACTIONS(1048),
    [anon_sym_any] = ACTIONS(1048),
    [anon_sym_number] = ACTIONS(1048),
    [anon_sym_boolean] = ACTIONS(1048),
    [anon_sym_string] = ACTIONS(1048),
    [anon_sym_symbol] = ACTIONS(1048),
    [anon_sym_object] = ACTIONS(1048),
    [sym_html_comment] = ACTIONS(5),
  },
  [512] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1466),
    [sym_expression] = STATE(2644),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5708),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5708),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5800),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1466),
    [sym_subscript_expression] = STATE(1466),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3013),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5708),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1466),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(539),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(2215),
    [anon_sym_export] = ACTIONS(2217),
    [anon_sym_type] = ACTIONS(2217),
    [anon_sym_namespace] = ACTIONS(2219),
    [anon_sym_LBRACE] = ACTIONS(808),
    [anon_sym_typeof] = ACTIONS(179),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(2217),
    [anon_sym_BANG] = ACTIONS(175),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(140),
    [anon_sym_yield] = ACTIONS(142),
    [anon_sym_LBRACK] = ACTIONS(812),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(2221),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(2223),
    [anon_sym_using] = ACTIONS(158),
    [anon_sym_PLUS] = ACTIONS(179),
    [anon_sym_DASH] = ACTIONS(179),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(175),
    [anon_sym_void] = ACTIONS(179),
    [anon_sym_delete] = ACTIONS(179),
    [anon_sym_PLUS_PLUS] = ACTIONS(686),
    [anon_sym_DASH_DASH] = ACTIONS(686),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(192),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(2225),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(2217),
    [anon_sym_readonly] = ACTIONS(2217),
    [anon_sym_get] = ACTIONS(2217),
    [anon_sym_set] = ACTIONS(2217),
    [anon_sym_declare] = ACTIONS(2217),
    [anon_sym_public] = ACTIONS(2217),
    [anon_sym_private] = ACTIONS(2217),
    [anon_sym_protected] = ACTIONS(2217),
    [anon_sym_override] = ACTIONS(2217),
    [anon_sym_module] = ACTIONS(2217),
    [anon_sym_any] = ACTIONS(2217),
    [anon_sym_number] = ACTIONS(2217),
    [anon_sym_boolean] = ACTIONS(2217),
    [anon_sym_string] = ACTIONS(2217),
    [anon_sym_symbol] = ACTIONS(2217),
    [anon_sym_object] = ACTIONS(2217),
    [sym_html_comment] = ACTIONS(5),
  },
  [513] = {
    [sym_import] = STATE(3636),
    [sym_parenthesized_expression] = STATE(1364),
    [sym_expression] = STATE(1835),
    [sym_primary_expression] = STATE(1810),
    [sym_yield_expression] = STATE(2358),
    [sym_object] = STATE(2222),
    [sym_object_pattern] = STATE(5773),
    [sym_array] = STATE(2222),
    [sym_array_pattern] = STATE(5773),
    [sym_class] = STATE(2222),
    [sym_function_expression] = STATE(2222),
    [sym_generator_function] = STATE(2222),
    [sym_arrow_function] = STATE(2222),
    [sym__call_signature] = STATE(5771),
    [sym_call_expression] = STATE(2222),
    [sym_new_expression] = STATE(1948),
    [sym_await_expression] = STATE(2358),
    [sym_member_expression] = STATE(1364),
    [sym_subscript_expression] = STATE(1364),
    [sym_assignment_expression] = STATE(2358),
    [sym__augmented_assignment_lhs] = STATE(3020),
    [sym_augmented_assignment_expression] = STATE(2358),
    [sym__destructuring_pattern] = STATE(5773),
    [sym_ternary_expression] = STATE(2358),
    [sym_binary_expression] = STATE(2358),
    [sym_unary_expression] = STATE(2358),
    [sym_update_expression] = STATE(2358),
    [sym_string] = STATE(2222),
    [sym_template_string] = STATE(2222),
    [sym_regex] = STATE(2222),
    [sym_meta_property] = STATE(2222),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1364),
    [sym_type_assertion] = STATE(2358),
    [sym_as_expression] = STATE(2358),
    [sym_satisfies_expression] = STATE(2358),
    [sym_instantiation_expression] = STATE(2358),
    [sym_internal_module] = STATE(2358),
    [sym_type_arguments] = STATE(513),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4408),
    [sym_identifier] = ACTIONS(1474),
    [anon_sym_export] = ACTIONS(1386),
    [anon_sym_type] = ACTIONS(1386),
    [anon_sym_namespace] = ACTIONS(1388),
    [anon_sym_LBRACE] = ACTIONS(665),
    [anon_sym_typeof] = ACTIONS(1408),
    [anon_sym_import] = ACTIONS(669),
    [anon_sym_let] = ACTIONS(1386),
    [anon_sym_BANG] = ACTIONS(1392),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_await] = ACTIONS(1394),
    [anon_sym_yield] = ACTIONS(1396),
    [anon_sym_LBRACK] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(676),
    [anon_sym_async] = ACTIONS(1398),
    [anon_sym_function] = ACTIONS(680),
    [anon_sym_new] = ACTIONS(1478),
    [anon_sym_using] = ACTIONS(1402),
    [anon_sym_PLUS] = ACTIONS(1408),
    [anon_sym_DASH] = ACTIONS(1408),
    [anon_sym_SLASH] = ACTIONS(876),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(1392),
    [anon_sym_void] = ACTIONS(1408),
    [anon_sym_delete] = ACTIONS(1408),
    [anon_sym_PLUS_PLUS] = ACTIONS(1410),
    [anon_sym_DASH_DASH] = ACTIONS(1410),
    [anon_sym_DQUOTE] = ACTIONS(83),
    [anon_sym_SQUOTE] = ACTIONS(85),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(87),
    [sym_number] = ACTIONS(89),
    [sym_private_property_identifier] = ACTIONS(1412),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(93),
    [sym_true] = ACTIONS(93),
    [sym_false] = ACTIONS(93),
    [sym_null] = ACTIONS(93),
    [sym_undefined] = ACTIONS(1480),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1386),
    [anon_sym_readonly] = ACTIONS(1386),
    [anon_sym_get] = ACTIONS(1386),
    [anon_sym_set] = ACTIONS(1386),
    [anon_sym_declare] = ACTIONS(1386),
    [anon_sym_public] = ACTIONS(1386),
    [anon_sym_private] = ACTIONS(1386),
    [anon_sym_protected] = ACTIONS(1386),
    [anon_sym_override] = ACTIONS(1386),
    [anon_sym_module] = ACTIONS(1386),
    [anon_sym_any] = ACTIONS(1386),
    [anon_sym_number] = ACTIONS(1386),
    [anon_sym_boolean] = ACTIONS(1386),
    [anon_sym_string] = ACTIONS(1386),
    [anon_sym_symbol] = ACTIONS(1386),
    [anon_sym_object] = ACTIONS(1386),
    [sym_html_comment] = ACTIONS(5),
  },
  [514] = {
    [sym_import] = STATE(3636),
    [sym_parenthesized_expression] = STATE(1362),
    [sym_expression] = STATE(1808),
    [sym_primary_expression] = STATE(1810),
    [sym_yield_expression] = STATE(2358),
    [sym_object] = STATE(2222),
    [sym_object_pattern] = STATE(5492),
    [sym_array] = STATE(2222),
    [sym_array_pattern] = STATE(5492),
    [sym_class] = STATE(2222),
    [sym_function_expression] = STATE(2222),
    [sym_generator_function] = STATE(2222),
    [sym_arrow_function] = STATE(2222),
    [sym__call_signature] = STATE(5821),
    [sym_call_expression] = STATE(2222),
    [sym_new_expression] = STATE(1948),
    [sym_await_expression] = STATE(2358),
    [sym_member_expression] = STATE(1362),
    [sym_subscript_expression] = STATE(1362),
    [sym_assignment_expression] = STATE(2358),
    [sym__augmented_assignment_lhs] = STATE(3025),
    [sym_augmented_assignment_expression] = STATE(2358),
    [sym__destructuring_pattern] = STATE(5492),
    [sym_ternary_expression] = STATE(2358),
    [sym_binary_expression] = STATE(2358),
    [sym_unary_expression] = STATE(2358),
    [sym_update_expression] = STATE(2358),
    [sym_string] = STATE(2222),
    [sym_template_string] = STATE(2222),
    [sym_regex] = STATE(2222),
    [sym_meta_property] = STATE(2222),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1362),
    [sym_type_assertion] = STATE(2358),
    [sym_as_expression] = STATE(2358),
    [sym_satisfies_expression] = STATE(2358),
    [sym_instantiation_expression] = STATE(2358),
    [sym_internal_module] = STATE(2358),
    [sym_type_arguments] = STATE(428),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4408),
    [sym_identifier] = ACTIONS(1468),
    [anon_sym_export] = ACTIONS(1352),
    [anon_sym_type] = ACTIONS(1352),
    [anon_sym_namespace] = ACTIONS(1354),
    [anon_sym_LBRACE] = ACTIONS(665),
    [anon_sym_typeof] = ACTIONS(21),
    [anon_sym_import] = ACTIONS(669),
    [anon_sym_let] = ACTIONS(1352),
    [anon_sym_BANG] = ACTIONS(33),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_await] = ACTIONS(45),
    [anon_sym_yield] = ACTIONS(63),
    [anon_sym_LBRACK] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(676),
    [anon_sym_async] = ACTIONS(1362),
    [anon_sym_function] = ACTIONS(680),
    [anon_sym_new] = ACTIONS(1472),
    [anon_sym_using] = ACTIONS(75),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_SLASH] = ACTIONS(77),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(33),
    [anon_sym_void] = ACTIONS(21),
    [anon_sym_delete] = ACTIONS(21),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_DQUOTE] = ACTIONS(83),
    [anon_sym_SQUOTE] = ACTIONS(85),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(87),
    [sym_number] = ACTIONS(89),
    [sym_private_property_identifier] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(93),
    [sym_true] = ACTIONS(93),
    [sym_false] = ACTIONS(93),
    [sym_null] = ACTIONS(93),
    [sym_undefined] = ACTIONS(95),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1352),
    [anon_sym_readonly] = ACTIONS(1352),
    [anon_sym_get] = ACTIONS(1352),
    [anon_sym_set] = ACTIONS(1352),
    [anon_sym_declare] = ACTIONS(1352),
    [anon_sym_public] = ACTIONS(1352),
    [anon_sym_private] = ACTIONS(1352),
    [anon_sym_protected] = ACTIONS(1352),
    [anon_sym_override] = ACTIONS(1352),
    [anon_sym_module] = ACTIONS(1352),
    [anon_sym_any] = ACTIONS(1352),
    [anon_sym_number] = ACTIONS(1352),
    [anon_sym_boolean] = ACTIONS(1352),
    [anon_sym_string] = ACTIONS(1352),
    [anon_sym_symbol] = ACTIONS(1352),
    [anon_sym_object] = ACTIONS(1352),
    [sym_html_comment] = ACTIONS(5),
  },
  [515] = {
    [sym_import] = STATE(3636),
    [sym_parenthesized_expression] = STATE(1364),
    [sym_expression] = STATE(1837),
    [sym_primary_expression] = STATE(1810),
    [sym_yield_expression] = STATE(2358),
    [sym_object] = STATE(2222),
    [sym_object_pattern] = STATE(5773),
    [sym_array] = STATE(2222),
    [sym_array_pattern] = STATE(5773),
    [sym_class] = STATE(2222),
    [sym_function_expression] = STATE(2222),
    [sym_generator_function] = STATE(2222),
    [sym_arrow_function] = STATE(2222),
    [sym__call_signature] = STATE(5771),
    [sym_call_expression] = STATE(2222),
    [sym_new_expression] = STATE(1948),
    [sym_await_expression] = STATE(2358),
    [sym_member_expression] = STATE(1364),
    [sym_subscript_expression] = STATE(1364),
    [sym_assignment_expression] = STATE(2358),
    [sym__augmented_assignment_lhs] = STATE(3020),
    [sym_augmented_assignment_expression] = STATE(2358),
    [sym__destructuring_pattern] = STATE(5773),
    [sym_ternary_expression] = STATE(2358),
    [sym_binary_expression] = STATE(2358),
    [sym_unary_expression] = STATE(2358),
    [sym_update_expression] = STATE(2358),
    [sym_string] = STATE(2222),
    [sym_template_string] = STATE(2222),
    [sym_regex] = STATE(2222),
    [sym_meta_property] = STATE(2222),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1364),
    [sym_type_assertion] = STATE(2358),
    [sym_as_expression] = STATE(2358),
    [sym_satisfies_expression] = STATE(2358),
    [sym_instantiation_expression] = STATE(2358),
    [sym_internal_module] = STATE(2358),
    [sym_type_arguments] = STATE(513),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4408),
    [sym_identifier] = ACTIONS(1474),
    [anon_sym_export] = ACTIONS(1386),
    [anon_sym_type] = ACTIONS(1386),
    [anon_sym_namespace] = ACTIONS(1388),
    [anon_sym_LBRACE] = ACTIONS(665),
    [anon_sym_typeof] = ACTIONS(1408),
    [anon_sym_import] = ACTIONS(669),
    [anon_sym_let] = ACTIONS(1386),
    [anon_sym_BANG] = ACTIONS(1392),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_await] = ACTIONS(1394),
    [anon_sym_yield] = ACTIONS(1396),
    [anon_sym_LBRACK] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(676),
    [anon_sym_async] = ACTIONS(1398),
    [anon_sym_function] = ACTIONS(680),
    [anon_sym_new] = ACTIONS(1478),
    [anon_sym_using] = ACTIONS(1402),
    [anon_sym_PLUS] = ACTIONS(1408),
    [anon_sym_DASH] = ACTIONS(1408),
    [anon_sym_SLASH] = ACTIONS(876),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(1392),
    [anon_sym_void] = ACTIONS(1408),
    [anon_sym_delete] = ACTIONS(1408),
    [anon_sym_PLUS_PLUS] = ACTIONS(1410),
    [anon_sym_DASH_DASH] = ACTIONS(1410),
    [anon_sym_DQUOTE] = ACTIONS(83),
    [anon_sym_SQUOTE] = ACTIONS(85),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(87),
    [sym_number] = ACTIONS(89),
    [sym_private_property_identifier] = ACTIONS(1412),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(93),
    [sym_true] = ACTIONS(93),
    [sym_false] = ACTIONS(93),
    [sym_null] = ACTIONS(93),
    [sym_undefined] = ACTIONS(1480),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1386),
    [anon_sym_readonly] = ACTIONS(1386),
    [anon_sym_get] = ACTIONS(1386),
    [anon_sym_set] = ACTIONS(1386),
    [anon_sym_declare] = ACTIONS(1386),
    [anon_sym_public] = ACTIONS(1386),
    [anon_sym_private] = ACTIONS(1386),
    [anon_sym_protected] = ACTIONS(1386),
    [anon_sym_override] = ACTIONS(1386),
    [anon_sym_module] = ACTIONS(1386),
    [anon_sym_any] = ACTIONS(1386),
    [anon_sym_number] = ACTIONS(1386),
    [anon_sym_boolean] = ACTIONS(1386),
    [anon_sym_string] = ACTIONS(1386),
    [anon_sym_symbol] = ACTIONS(1386),
    [anon_sym_object] = ACTIONS(1386),
    [sym_html_comment] = ACTIONS(5),
  },
  [516] = {
    [sym_import] = STATE(3636),
    [sym_parenthesized_expression] = STATE(1364),
    [sym_expression] = STATE(1839),
    [sym_primary_expression] = STATE(1810),
    [sym_yield_expression] = STATE(2358),
    [sym_object] = STATE(2222),
    [sym_object_pattern] = STATE(5773),
    [sym_array] = STATE(2222),
    [sym_array_pattern] = STATE(5773),
    [sym_class] = STATE(2222),
    [sym_function_expression] = STATE(2222),
    [sym_generator_function] = STATE(2222),
    [sym_arrow_function] = STATE(2222),
    [sym__call_signature] = STATE(5771),
    [sym_call_expression] = STATE(2222),
    [sym_new_expression] = STATE(1948),
    [sym_await_expression] = STATE(2358),
    [sym_member_expression] = STATE(1364),
    [sym_subscript_expression] = STATE(1364),
    [sym_assignment_expression] = STATE(2358),
    [sym__augmented_assignment_lhs] = STATE(3020),
    [sym_augmented_assignment_expression] = STATE(2358),
    [sym__destructuring_pattern] = STATE(5773),
    [sym_ternary_expression] = STATE(2358),
    [sym_binary_expression] = STATE(2358),
    [sym_unary_expression] = STATE(2358),
    [sym_update_expression] = STATE(2358),
    [sym_string] = STATE(2222),
    [sym_template_string] = STATE(2222),
    [sym_regex] = STATE(2222),
    [sym_meta_property] = STATE(2222),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1364),
    [sym_type_assertion] = STATE(2358),
    [sym_as_expression] = STATE(2358),
    [sym_satisfies_expression] = STATE(2358),
    [sym_instantiation_expression] = STATE(2358),
    [sym_internal_module] = STATE(2358),
    [sym_type_arguments] = STATE(513),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4408),
    [sym_identifier] = ACTIONS(1474),
    [anon_sym_export] = ACTIONS(1386),
    [anon_sym_type] = ACTIONS(1386),
    [anon_sym_namespace] = ACTIONS(1388),
    [anon_sym_LBRACE] = ACTIONS(665),
    [anon_sym_typeof] = ACTIONS(1408),
    [anon_sym_import] = ACTIONS(669),
    [anon_sym_let] = ACTIONS(1386),
    [anon_sym_BANG] = ACTIONS(1392),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_await] = ACTIONS(1394),
    [anon_sym_yield] = ACTIONS(1396),
    [anon_sym_LBRACK] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(676),
    [anon_sym_async] = ACTIONS(1398),
    [anon_sym_function] = ACTIONS(680),
    [anon_sym_new] = ACTIONS(1478),
    [anon_sym_using] = ACTIONS(1402),
    [anon_sym_PLUS] = ACTIONS(1408),
    [anon_sym_DASH] = ACTIONS(1408),
    [anon_sym_SLASH] = ACTIONS(876),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(1392),
    [anon_sym_void] = ACTIONS(1408),
    [anon_sym_delete] = ACTIONS(1408),
    [anon_sym_PLUS_PLUS] = ACTIONS(1410),
    [anon_sym_DASH_DASH] = ACTIONS(1410),
    [anon_sym_DQUOTE] = ACTIONS(83),
    [anon_sym_SQUOTE] = ACTIONS(85),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(87),
    [sym_number] = ACTIONS(89),
    [sym_private_property_identifier] = ACTIONS(1412),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(93),
    [sym_true] = ACTIONS(93),
    [sym_false] = ACTIONS(93),
    [sym_null] = ACTIONS(93),
    [sym_undefined] = ACTIONS(1480),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1386),
    [anon_sym_readonly] = ACTIONS(1386),
    [anon_sym_get] = ACTIONS(1386),
    [anon_sym_set] = ACTIONS(1386),
    [anon_sym_declare] = ACTIONS(1386),
    [anon_sym_public] = ACTIONS(1386),
    [anon_sym_private] = ACTIONS(1386),
    [anon_sym_protected] = ACTIONS(1386),
    [anon_sym_override] = ACTIONS(1386),
    [anon_sym_module] = ACTIONS(1386),
    [anon_sym_any] = ACTIONS(1386),
    [anon_sym_number] = ACTIONS(1386),
    [anon_sym_boolean] = ACTIONS(1386),
    [anon_sym_string] = ACTIONS(1386),
    [anon_sym_symbol] = ACTIONS(1386),
    [anon_sym_object] = ACTIONS(1386),
    [sym_html_comment] = ACTIONS(5),
  },
  [517] = {
    [sym_import] = STATE(3636),
    [sym_parenthesized_expression] = STATE(1364),
    [sym_expression] = STATE(1840),
    [sym_primary_expression] = STATE(1810),
    [sym_yield_expression] = STATE(2358),
    [sym_object] = STATE(2222),
    [sym_object_pattern] = STATE(5773),
    [sym_array] = STATE(2222),
    [sym_array_pattern] = STATE(5773),
    [sym_class] = STATE(2222),
    [sym_function_expression] = STATE(2222),
    [sym_generator_function] = STATE(2222),
    [sym_arrow_function] = STATE(2222),
    [sym__call_signature] = STATE(5771),
    [sym_call_expression] = STATE(2222),
    [sym_new_expression] = STATE(1948),
    [sym_await_expression] = STATE(2358),
    [sym_member_expression] = STATE(1364),
    [sym_subscript_expression] = STATE(1364),
    [sym_assignment_expression] = STATE(2358),
    [sym__augmented_assignment_lhs] = STATE(3020),
    [sym_augmented_assignment_expression] = STATE(2358),
    [sym__destructuring_pattern] = STATE(5773),
    [sym_ternary_expression] = STATE(2358),
    [sym_binary_expression] = STATE(2358),
    [sym_unary_expression] = STATE(2358),
    [sym_update_expression] = STATE(2358),
    [sym_string] = STATE(2222),
    [sym_template_string] = STATE(2222),
    [sym_regex] = STATE(2222),
    [sym_meta_property] = STATE(2222),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1364),
    [sym_type_assertion] = STATE(2358),
    [sym_as_expression] = STATE(2358),
    [sym_satisfies_expression] = STATE(2358),
    [sym_instantiation_expression] = STATE(2358),
    [sym_internal_module] = STATE(2358),
    [sym_type_arguments] = STATE(513),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4408),
    [sym_identifier] = ACTIONS(1474),
    [anon_sym_export] = ACTIONS(1386),
    [anon_sym_type] = ACTIONS(1386),
    [anon_sym_namespace] = ACTIONS(1388),
    [anon_sym_LBRACE] = ACTIONS(665),
    [anon_sym_typeof] = ACTIONS(1408),
    [anon_sym_import] = ACTIONS(669),
    [anon_sym_let] = ACTIONS(1386),
    [anon_sym_BANG] = ACTIONS(1392),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_await] = ACTIONS(1394),
    [anon_sym_yield] = ACTIONS(1396),
    [anon_sym_LBRACK] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(676),
    [anon_sym_async] = ACTIONS(1398),
    [anon_sym_function] = ACTIONS(680),
    [anon_sym_new] = ACTIONS(1478),
    [anon_sym_using] = ACTIONS(1402),
    [anon_sym_PLUS] = ACTIONS(1408),
    [anon_sym_DASH] = ACTIONS(1408),
    [anon_sym_SLASH] = ACTIONS(876),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(1392),
    [anon_sym_void] = ACTIONS(1408),
    [anon_sym_delete] = ACTIONS(1408),
    [anon_sym_PLUS_PLUS] = ACTIONS(1410),
    [anon_sym_DASH_DASH] = ACTIONS(1410),
    [anon_sym_DQUOTE] = ACTIONS(83),
    [anon_sym_SQUOTE] = ACTIONS(85),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(87),
    [sym_number] = ACTIONS(89),
    [sym_private_property_identifier] = ACTIONS(1412),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(93),
    [sym_true] = ACTIONS(93),
    [sym_false] = ACTIONS(93),
    [sym_null] = ACTIONS(93),
    [sym_undefined] = ACTIONS(1480),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1386),
    [anon_sym_readonly] = ACTIONS(1386),
    [anon_sym_get] = ACTIONS(1386),
    [anon_sym_set] = ACTIONS(1386),
    [anon_sym_declare] = ACTIONS(1386),
    [anon_sym_public] = ACTIONS(1386),
    [anon_sym_private] = ACTIONS(1386),
    [anon_sym_protected] = ACTIONS(1386),
    [anon_sym_override] = ACTIONS(1386),
    [anon_sym_module] = ACTIONS(1386),
    [anon_sym_any] = ACTIONS(1386),
    [anon_sym_number] = ACTIONS(1386),
    [anon_sym_boolean] = ACTIONS(1386),
    [anon_sym_string] = ACTIONS(1386),
    [anon_sym_symbol] = ACTIONS(1386),
    [anon_sym_object] = ACTIONS(1386),
    [sym_html_comment] = ACTIONS(5),
  },
  [518] = {
    [sym_import] = STATE(3636),
    [sym_parenthesized_expression] = STATE(1364),
    [sym_expression] = STATE(1842),
    [sym_primary_expression] = STATE(1810),
    [sym_yield_expression] = STATE(2358),
    [sym_object] = STATE(2222),
    [sym_object_pattern] = STATE(5773),
    [sym_array] = STATE(2222),
    [sym_array_pattern] = STATE(5773),
    [sym_class] = STATE(2222),
    [sym_function_expression] = STATE(2222),
    [sym_generator_function] = STATE(2222),
    [sym_arrow_function] = STATE(2222),
    [sym__call_signature] = STATE(5771),
    [sym_call_expression] = STATE(2222),
    [sym_new_expression] = STATE(1948),
    [sym_await_expression] = STATE(2358),
    [sym_member_expression] = STATE(1364),
    [sym_subscript_expression] = STATE(1364),
    [sym_assignment_expression] = STATE(2358),
    [sym__augmented_assignment_lhs] = STATE(3020),
    [sym_augmented_assignment_expression] = STATE(2358),
    [sym__destructuring_pattern] = STATE(5773),
    [sym_ternary_expression] = STATE(2358),
    [sym_binary_expression] = STATE(2358),
    [sym_unary_expression] = STATE(2358),
    [sym_update_expression] = STATE(2358),
    [sym_string] = STATE(2222),
    [sym_template_string] = STATE(2222),
    [sym_regex] = STATE(2222),
    [sym_meta_property] = STATE(2222),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1364),
    [sym_type_assertion] = STATE(2358),
    [sym_as_expression] = STATE(2358),
    [sym_satisfies_expression] = STATE(2358),
    [sym_instantiation_expression] = STATE(2358),
    [sym_internal_module] = STATE(2358),
    [sym_type_arguments] = STATE(513),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4408),
    [sym_identifier] = ACTIONS(1474),
    [anon_sym_export] = ACTIONS(1386),
    [anon_sym_type] = ACTIONS(1386),
    [anon_sym_namespace] = ACTIONS(1388),
    [anon_sym_LBRACE] = ACTIONS(665),
    [anon_sym_typeof] = ACTIONS(1408),
    [anon_sym_import] = ACTIONS(669),
    [anon_sym_let] = ACTIONS(1386),
    [anon_sym_BANG] = ACTIONS(1392),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_await] = ACTIONS(1394),
    [anon_sym_yield] = ACTIONS(1396),
    [anon_sym_LBRACK] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(676),
    [anon_sym_async] = ACTIONS(1398),
    [anon_sym_function] = ACTIONS(680),
    [anon_sym_new] = ACTIONS(1478),
    [anon_sym_using] = ACTIONS(1402),
    [anon_sym_PLUS] = ACTIONS(1408),
    [anon_sym_DASH] = ACTIONS(1408),
    [anon_sym_SLASH] = ACTIONS(876),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(1392),
    [anon_sym_void] = ACTIONS(1408),
    [anon_sym_delete] = ACTIONS(1408),
    [anon_sym_PLUS_PLUS] = ACTIONS(1410),
    [anon_sym_DASH_DASH] = ACTIONS(1410),
    [anon_sym_DQUOTE] = ACTIONS(83),
    [anon_sym_SQUOTE] = ACTIONS(85),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(87),
    [sym_number] = ACTIONS(89),
    [sym_private_property_identifier] = ACTIONS(1412),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(93),
    [sym_true] = ACTIONS(93),
    [sym_false] = ACTIONS(93),
    [sym_null] = ACTIONS(93),
    [sym_undefined] = ACTIONS(1480),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1386),
    [anon_sym_readonly] = ACTIONS(1386),
    [anon_sym_get] = ACTIONS(1386),
    [anon_sym_set] = ACTIONS(1386),
    [anon_sym_declare] = ACTIONS(1386),
    [anon_sym_public] = ACTIONS(1386),
    [anon_sym_private] = ACTIONS(1386),
    [anon_sym_protected] = ACTIONS(1386),
    [anon_sym_override] = ACTIONS(1386),
    [anon_sym_module] = ACTIONS(1386),
    [anon_sym_any] = ACTIONS(1386),
    [anon_sym_number] = ACTIONS(1386),
    [anon_sym_boolean] = ACTIONS(1386),
    [anon_sym_string] = ACTIONS(1386),
    [anon_sym_symbol] = ACTIONS(1386),
    [anon_sym_object] = ACTIONS(1386),
    [sym_html_comment] = ACTIONS(5),
  },
  [519] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1456),
    [sym_expression] = STATE(2572),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5815),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5815),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5755),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1456),
    [sym_subscript_expression] = STATE(1456),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3029),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5815),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1456),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(594),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1506),
    [anon_sym_export] = ACTIONS(1234),
    [anon_sym_type] = ACTIONS(1234),
    [anon_sym_namespace] = ACTIONS(1236),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_typeof] = ACTIONS(1256),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1234),
    [anon_sym_BANG] = ACTIONS(1240),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(1242),
    [anon_sym_yield] = ACTIONS(1244),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1246),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1510),
    [anon_sym_using] = ACTIONS(1250),
    [anon_sym_PLUS] = ACTIONS(1256),
    [anon_sym_DASH] = ACTIONS(1256),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(1240),
    [anon_sym_void] = ACTIONS(1256),
    [anon_sym_delete] = ACTIONS(1256),
    [anon_sym_PLUS_PLUS] = ACTIONS(1258),
    [anon_sym_DASH_DASH] = ACTIONS(1258),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(1260),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1512),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1234),
    [anon_sym_readonly] = ACTIONS(1234),
    [anon_sym_get] = ACTIONS(1234),
    [anon_sym_set] = ACTIONS(1234),
    [anon_sym_declare] = ACTIONS(1234),
    [anon_sym_public] = ACTIONS(1234),
    [anon_sym_private] = ACTIONS(1234),
    [anon_sym_protected] = ACTIONS(1234),
    [anon_sym_override] = ACTIONS(1234),
    [anon_sym_module] = ACTIONS(1234),
    [anon_sym_any] = ACTIONS(1234),
    [anon_sym_number] = ACTIONS(1234),
    [anon_sym_boolean] = ACTIONS(1234),
    [anon_sym_string] = ACTIONS(1234),
    [anon_sym_symbol] = ACTIONS(1234),
    [anon_sym_object] = ACTIONS(1234),
    [sym_html_comment] = ACTIONS(5),
  },
  [520] = {
    [sym_import] = STATE(3636),
    [sym_parenthesized_expression] = STATE(1364),
    [sym_expression] = STATE(1843),
    [sym_primary_expression] = STATE(1810),
    [sym_yield_expression] = STATE(2358),
    [sym_object] = STATE(2222),
    [sym_object_pattern] = STATE(5773),
    [sym_array] = STATE(2222),
    [sym_array_pattern] = STATE(5773),
    [sym_class] = STATE(2222),
    [sym_function_expression] = STATE(2222),
    [sym_generator_function] = STATE(2222),
    [sym_arrow_function] = STATE(2222),
    [sym__call_signature] = STATE(5771),
    [sym_call_expression] = STATE(2222),
    [sym_new_expression] = STATE(1948),
    [sym_await_expression] = STATE(2358),
    [sym_member_expression] = STATE(1364),
    [sym_subscript_expression] = STATE(1364),
    [sym_assignment_expression] = STATE(2358),
    [sym__augmented_assignment_lhs] = STATE(3020),
    [sym_augmented_assignment_expression] = STATE(2358),
    [sym__destructuring_pattern] = STATE(5773),
    [sym_ternary_expression] = STATE(2358),
    [sym_binary_expression] = STATE(2358),
    [sym_unary_expression] = STATE(2358),
    [sym_update_expression] = STATE(2358),
    [sym_string] = STATE(2222),
    [sym_template_string] = STATE(2222),
    [sym_regex] = STATE(2222),
    [sym_meta_property] = STATE(2222),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1364),
    [sym_type_assertion] = STATE(2358),
    [sym_as_expression] = STATE(2358),
    [sym_satisfies_expression] = STATE(2358),
    [sym_instantiation_expression] = STATE(2358),
    [sym_internal_module] = STATE(2358),
    [sym_type_arguments] = STATE(513),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4408),
    [sym_identifier] = ACTIONS(1474),
    [anon_sym_export] = ACTIONS(1386),
    [anon_sym_type] = ACTIONS(1386),
    [anon_sym_namespace] = ACTIONS(1388),
    [anon_sym_LBRACE] = ACTIONS(665),
    [anon_sym_typeof] = ACTIONS(1408),
    [anon_sym_import] = ACTIONS(669),
    [anon_sym_let] = ACTIONS(1386),
    [anon_sym_BANG] = ACTIONS(1392),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_await] = ACTIONS(1394),
    [anon_sym_yield] = ACTIONS(1396),
    [anon_sym_LBRACK] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(676),
    [anon_sym_async] = ACTIONS(1398),
    [anon_sym_function] = ACTIONS(680),
    [anon_sym_new] = ACTIONS(1478),
    [anon_sym_using] = ACTIONS(1402),
    [anon_sym_PLUS] = ACTIONS(1408),
    [anon_sym_DASH] = ACTIONS(1408),
    [anon_sym_SLASH] = ACTIONS(876),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(1392),
    [anon_sym_void] = ACTIONS(1408),
    [anon_sym_delete] = ACTIONS(1408),
    [anon_sym_PLUS_PLUS] = ACTIONS(1410),
    [anon_sym_DASH_DASH] = ACTIONS(1410),
    [anon_sym_DQUOTE] = ACTIONS(83),
    [anon_sym_SQUOTE] = ACTIONS(85),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(87),
    [sym_number] = ACTIONS(89),
    [sym_private_property_identifier] = ACTIONS(1412),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(93),
    [sym_true] = ACTIONS(93),
    [sym_false] = ACTIONS(93),
    [sym_null] = ACTIONS(93),
    [sym_undefined] = ACTIONS(1480),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1386),
    [anon_sym_readonly] = ACTIONS(1386),
    [anon_sym_get] = ACTIONS(1386),
    [anon_sym_set] = ACTIONS(1386),
    [anon_sym_declare] = ACTIONS(1386),
    [anon_sym_public] = ACTIONS(1386),
    [anon_sym_private] = ACTIONS(1386),
    [anon_sym_protected] = ACTIONS(1386),
    [anon_sym_override] = ACTIONS(1386),
    [anon_sym_module] = ACTIONS(1386),
    [anon_sym_any] = ACTIONS(1386),
    [anon_sym_number] = ACTIONS(1386),
    [anon_sym_boolean] = ACTIONS(1386),
    [anon_sym_string] = ACTIONS(1386),
    [anon_sym_symbol] = ACTIONS(1386),
    [anon_sym_object] = ACTIONS(1386),
    [sym_html_comment] = ACTIONS(5),
  },
  [521] = {
    [sym_import] = STATE(3636),
    [sym_parenthesized_expression] = STATE(1364),
    [sym_expression] = STATE(1844),
    [sym_primary_expression] = STATE(1810),
    [sym_yield_expression] = STATE(2358),
    [sym_object] = STATE(2222),
    [sym_object_pattern] = STATE(5773),
    [sym_array] = STATE(2222),
    [sym_array_pattern] = STATE(5773),
    [sym_class] = STATE(2222),
    [sym_function_expression] = STATE(2222),
    [sym_generator_function] = STATE(2222),
    [sym_arrow_function] = STATE(2222),
    [sym__call_signature] = STATE(5771),
    [sym_call_expression] = STATE(2222),
    [sym_new_expression] = STATE(1948),
    [sym_await_expression] = STATE(2358),
    [sym_member_expression] = STATE(1364),
    [sym_subscript_expression] = STATE(1364),
    [sym_assignment_expression] = STATE(2358),
    [sym__augmented_assignment_lhs] = STATE(3020),
    [sym_augmented_assignment_expression] = STATE(2358),
    [sym__destructuring_pattern] = STATE(5773),
    [sym_ternary_expression] = STATE(2358),
    [sym_binary_expression] = STATE(2358),
    [sym_unary_expression] = STATE(2358),
    [sym_update_expression] = STATE(2358),
    [sym_string] = STATE(2222),
    [sym_template_string] = STATE(2222),
    [sym_regex] = STATE(2222),
    [sym_meta_property] = STATE(2222),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1364),
    [sym_type_assertion] = STATE(2358),
    [sym_as_expression] = STATE(2358),
    [sym_satisfies_expression] = STATE(2358),
    [sym_instantiation_expression] = STATE(2358),
    [sym_internal_module] = STATE(2358),
    [sym_type_arguments] = STATE(513),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4408),
    [sym_identifier] = ACTIONS(1474),
    [anon_sym_export] = ACTIONS(1386),
    [anon_sym_type] = ACTIONS(1386),
    [anon_sym_namespace] = ACTIONS(1388),
    [anon_sym_LBRACE] = ACTIONS(665),
    [anon_sym_typeof] = ACTIONS(1408),
    [anon_sym_import] = ACTIONS(669),
    [anon_sym_let] = ACTIONS(1386),
    [anon_sym_BANG] = ACTIONS(1392),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_await] = ACTIONS(1394),
    [anon_sym_yield] = ACTIONS(1396),
    [anon_sym_LBRACK] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(676),
    [anon_sym_async] = ACTIONS(1398),
    [anon_sym_function] = ACTIONS(680),
    [anon_sym_new] = ACTIONS(1478),
    [anon_sym_using] = ACTIONS(1402),
    [anon_sym_PLUS] = ACTIONS(1408),
    [anon_sym_DASH] = ACTIONS(1408),
    [anon_sym_SLASH] = ACTIONS(876),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(1392),
    [anon_sym_void] = ACTIONS(1408),
    [anon_sym_delete] = ACTIONS(1408),
    [anon_sym_PLUS_PLUS] = ACTIONS(1410),
    [anon_sym_DASH_DASH] = ACTIONS(1410),
    [anon_sym_DQUOTE] = ACTIONS(83),
    [anon_sym_SQUOTE] = ACTIONS(85),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(87),
    [sym_number] = ACTIONS(89),
    [sym_private_property_identifier] = ACTIONS(1412),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(93),
    [sym_true] = ACTIONS(93),
    [sym_false] = ACTIONS(93),
    [sym_null] = ACTIONS(93),
    [sym_undefined] = ACTIONS(1480),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1386),
    [anon_sym_readonly] = ACTIONS(1386),
    [anon_sym_get] = ACTIONS(1386),
    [anon_sym_set] = ACTIONS(1386),
    [anon_sym_declare] = ACTIONS(1386),
    [anon_sym_public] = ACTIONS(1386),
    [anon_sym_private] = ACTIONS(1386),
    [anon_sym_protected] = ACTIONS(1386),
    [anon_sym_override] = ACTIONS(1386),
    [anon_sym_module] = ACTIONS(1386),
    [anon_sym_any] = ACTIONS(1386),
    [anon_sym_number] = ACTIONS(1386),
    [anon_sym_boolean] = ACTIONS(1386),
    [anon_sym_string] = ACTIONS(1386),
    [anon_sym_symbol] = ACTIONS(1386),
    [anon_sym_object] = ACTIONS(1386),
    [sym_html_comment] = ACTIONS(5),
  },
  [522] = {
    [sym_import] = STATE(3636),
    [sym_parenthesized_expression] = STATE(1364),
    [sym_expression] = STATE(1845),
    [sym_primary_expression] = STATE(1810),
    [sym_yield_expression] = STATE(2358),
    [sym_object] = STATE(2222),
    [sym_object_pattern] = STATE(5773),
    [sym_array] = STATE(2222),
    [sym_array_pattern] = STATE(5773),
    [sym_class] = STATE(2222),
    [sym_function_expression] = STATE(2222),
    [sym_generator_function] = STATE(2222),
    [sym_arrow_function] = STATE(2222),
    [sym__call_signature] = STATE(5771),
    [sym_call_expression] = STATE(2222),
    [sym_new_expression] = STATE(1948),
    [sym_await_expression] = STATE(2358),
    [sym_member_expression] = STATE(1364),
    [sym_subscript_expression] = STATE(1364),
    [sym_assignment_expression] = STATE(2358),
    [sym__augmented_assignment_lhs] = STATE(3020),
    [sym_augmented_assignment_expression] = STATE(2358),
    [sym__destructuring_pattern] = STATE(5773),
    [sym_ternary_expression] = STATE(2358),
    [sym_binary_expression] = STATE(2358),
    [sym_unary_expression] = STATE(2358),
    [sym_update_expression] = STATE(2358),
    [sym_string] = STATE(2222),
    [sym_template_string] = STATE(2222),
    [sym_regex] = STATE(2222),
    [sym_meta_property] = STATE(2222),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1364),
    [sym_type_assertion] = STATE(2358),
    [sym_as_expression] = STATE(2358),
    [sym_satisfies_expression] = STATE(2358),
    [sym_instantiation_expression] = STATE(2358),
    [sym_internal_module] = STATE(2358),
    [sym_type_arguments] = STATE(513),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4408),
    [sym_identifier] = ACTIONS(1474),
    [anon_sym_export] = ACTIONS(1386),
    [anon_sym_type] = ACTIONS(1386),
    [anon_sym_namespace] = ACTIONS(1388),
    [anon_sym_LBRACE] = ACTIONS(665),
    [anon_sym_typeof] = ACTIONS(1408),
    [anon_sym_import] = ACTIONS(669),
    [anon_sym_let] = ACTIONS(1386),
    [anon_sym_BANG] = ACTIONS(1392),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_await] = ACTIONS(1394),
    [anon_sym_yield] = ACTIONS(1396),
    [anon_sym_LBRACK] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(676),
    [anon_sym_async] = ACTIONS(1398),
    [anon_sym_function] = ACTIONS(680),
    [anon_sym_new] = ACTIONS(1478),
    [anon_sym_using] = ACTIONS(1402),
    [anon_sym_PLUS] = ACTIONS(1408),
    [anon_sym_DASH] = ACTIONS(1408),
    [anon_sym_SLASH] = ACTIONS(876),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(1392),
    [anon_sym_void] = ACTIONS(1408),
    [anon_sym_delete] = ACTIONS(1408),
    [anon_sym_PLUS_PLUS] = ACTIONS(1410),
    [anon_sym_DASH_DASH] = ACTIONS(1410),
    [anon_sym_DQUOTE] = ACTIONS(83),
    [anon_sym_SQUOTE] = ACTIONS(85),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(87),
    [sym_number] = ACTIONS(89),
    [sym_private_property_identifier] = ACTIONS(1412),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(93),
    [sym_true] = ACTIONS(93),
    [sym_false] = ACTIONS(93),
    [sym_null] = ACTIONS(93),
    [sym_undefined] = ACTIONS(1480),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1386),
    [anon_sym_readonly] = ACTIONS(1386),
    [anon_sym_get] = ACTIONS(1386),
    [anon_sym_set] = ACTIONS(1386),
    [anon_sym_declare] = ACTIONS(1386),
    [anon_sym_public] = ACTIONS(1386),
    [anon_sym_private] = ACTIONS(1386),
    [anon_sym_protected] = ACTIONS(1386),
    [anon_sym_override] = ACTIONS(1386),
    [anon_sym_module] = ACTIONS(1386),
    [anon_sym_any] = ACTIONS(1386),
    [anon_sym_number] = ACTIONS(1386),
    [anon_sym_boolean] = ACTIONS(1386),
    [anon_sym_string] = ACTIONS(1386),
    [anon_sym_symbol] = ACTIONS(1386),
    [anon_sym_object] = ACTIONS(1386),
    [sym_html_comment] = ACTIONS(5),
  },
  [523] = {
    [sym_import] = STATE(3636),
    [sym_parenthesized_expression] = STATE(1364),
    [sym_expression] = STATE(1846),
    [sym_primary_expression] = STATE(1810),
    [sym_yield_expression] = STATE(2358),
    [sym_object] = STATE(2222),
    [sym_object_pattern] = STATE(5773),
    [sym_array] = STATE(2222),
    [sym_array_pattern] = STATE(5773),
    [sym_class] = STATE(2222),
    [sym_function_expression] = STATE(2222),
    [sym_generator_function] = STATE(2222),
    [sym_arrow_function] = STATE(2222),
    [sym__call_signature] = STATE(5771),
    [sym_call_expression] = STATE(2222),
    [sym_new_expression] = STATE(1948),
    [sym_await_expression] = STATE(2358),
    [sym_member_expression] = STATE(1364),
    [sym_subscript_expression] = STATE(1364),
    [sym_assignment_expression] = STATE(2358),
    [sym__augmented_assignment_lhs] = STATE(3020),
    [sym_augmented_assignment_expression] = STATE(2358),
    [sym__destructuring_pattern] = STATE(5773),
    [sym_ternary_expression] = STATE(2358),
    [sym_binary_expression] = STATE(2358),
    [sym_unary_expression] = STATE(2358),
    [sym_update_expression] = STATE(2358),
    [sym_string] = STATE(2222),
    [sym_template_string] = STATE(2222),
    [sym_regex] = STATE(2222),
    [sym_meta_property] = STATE(2222),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1364),
    [sym_type_assertion] = STATE(2358),
    [sym_as_expression] = STATE(2358),
    [sym_satisfies_expression] = STATE(2358),
    [sym_instantiation_expression] = STATE(2358),
    [sym_internal_module] = STATE(2358),
    [sym_type_arguments] = STATE(513),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4408),
    [sym_identifier] = ACTIONS(1474),
    [anon_sym_export] = ACTIONS(1386),
    [anon_sym_type] = ACTIONS(1386),
    [anon_sym_namespace] = ACTIONS(1388),
    [anon_sym_LBRACE] = ACTIONS(665),
    [anon_sym_typeof] = ACTIONS(1408),
    [anon_sym_import] = ACTIONS(669),
    [anon_sym_let] = ACTIONS(1386),
    [anon_sym_BANG] = ACTIONS(1392),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_await] = ACTIONS(1394),
    [anon_sym_yield] = ACTIONS(1396),
    [anon_sym_LBRACK] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(676),
    [anon_sym_async] = ACTIONS(1398),
    [anon_sym_function] = ACTIONS(680),
    [anon_sym_new] = ACTIONS(1478),
    [anon_sym_using] = ACTIONS(1402),
    [anon_sym_PLUS] = ACTIONS(1408),
    [anon_sym_DASH] = ACTIONS(1408),
    [anon_sym_SLASH] = ACTIONS(876),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(1392),
    [anon_sym_void] = ACTIONS(1408),
    [anon_sym_delete] = ACTIONS(1408),
    [anon_sym_PLUS_PLUS] = ACTIONS(1410),
    [anon_sym_DASH_DASH] = ACTIONS(1410),
    [anon_sym_DQUOTE] = ACTIONS(83),
    [anon_sym_SQUOTE] = ACTIONS(85),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(87),
    [sym_number] = ACTIONS(89),
    [sym_private_property_identifier] = ACTIONS(1412),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(93),
    [sym_true] = ACTIONS(93),
    [sym_false] = ACTIONS(93),
    [sym_null] = ACTIONS(93),
    [sym_undefined] = ACTIONS(1480),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1386),
    [anon_sym_readonly] = ACTIONS(1386),
    [anon_sym_get] = ACTIONS(1386),
    [anon_sym_set] = ACTIONS(1386),
    [anon_sym_declare] = ACTIONS(1386),
    [anon_sym_public] = ACTIONS(1386),
    [anon_sym_private] = ACTIONS(1386),
    [anon_sym_protected] = ACTIONS(1386),
    [anon_sym_override] = ACTIONS(1386),
    [anon_sym_module] = ACTIONS(1386),
    [anon_sym_any] = ACTIONS(1386),
    [anon_sym_number] = ACTIONS(1386),
    [anon_sym_boolean] = ACTIONS(1386),
    [anon_sym_string] = ACTIONS(1386),
    [anon_sym_symbol] = ACTIONS(1386),
    [anon_sym_object] = ACTIONS(1386),
    [sym_html_comment] = ACTIONS(5),
  },
  [524] = {
    [sym_import] = STATE(3636),
    [sym_parenthesized_expression] = STATE(1364),
    [sym_expression] = STATE(1847),
    [sym_primary_expression] = STATE(1810),
    [sym_yield_expression] = STATE(2358),
    [sym_object] = STATE(2222),
    [sym_object_pattern] = STATE(5773),
    [sym_array] = STATE(2222),
    [sym_array_pattern] = STATE(5773),
    [sym_class] = STATE(2222),
    [sym_function_expression] = STATE(2222),
    [sym_generator_function] = STATE(2222),
    [sym_arrow_function] = STATE(2222),
    [sym__call_signature] = STATE(5771),
    [sym_call_expression] = STATE(2222),
    [sym_new_expression] = STATE(1948),
    [sym_await_expression] = STATE(2358),
    [sym_member_expression] = STATE(1364),
    [sym_subscript_expression] = STATE(1364),
    [sym_assignment_expression] = STATE(2358),
    [sym__augmented_assignment_lhs] = STATE(3020),
    [sym_augmented_assignment_expression] = STATE(2358),
    [sym__destructuring_pattern] = STATE(5773),
    [sym_ternary_expression] = STATE(2358),
    [sym_binary_expression] = STATE(2358),
    [sym_unary_expression] = STATE(2358),
    [sym_update_expression] = STATE(2358),
    [sym_string] = STATE(2222),
    [sym_template_string] = STATE(2222),
    [sym_regex] = STATE(2222),
    [sym_meta_property] = STATE(2222),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1364),
    [sym_type_assertion] = STATE(2358),
    [sym_as_expression] = STATE(2358),
    [sym_satisfies_expression] = STATE(2358),
    [sym_instantiation_expression] = STATE(2358),
    [sym_internal_module] = STATE(2358),
    [sym_type_arguments] = STATE(513),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4408),
    [sym_identifier] = ACTIONS(1474),
    [anon_sym_export] = ACTIONS(1386),
    [anon_sym_type] = ACTIONS(1386),
    [anon_sym_namespace] = ACTIONS(1388),
    [anon_sym_LBRACE] = ACTIONS(665),
    [anon_sym_typeof] = ACTIONS(1408),
    [anon_sym_import] = ACTIONS(669),
    [anon_sym_let] = ACTIONS(1386),
    [anon_sym_BANG] = ACTIONS(1392),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_await] = ACTIONS(1394),
    [anon_sym_yield] = ACTIONS(1396),
    [anon_sym_LBRACK] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(676),
    [anon_sym_async] = ACTIONS(1398),
    [anon_sym_function] = ACTIONS(680),
    [anon_sym_new] = ACTIONS(1478),
    [anon_sym_using] = ACTIONS(1402),
    [anon_sym_PLUS] = ACTIONS(1408),
    [anon_sym_DASH] = ACTIONS(1408),
    [anon_sym_SLASH] = ACTIONS(876),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(1392),
    [anon_sym_void] = ACTIONS(1408),
    [anon_sym_delete] = ACTIONS(1408),
    [anon_sym_PLUS_PLUS] = ACTIONS(1410),
    [anon_sym_DASH_DASH] = ACTIONS(1410),
    [anon_sym_DQUOTE] = ACTIONS(83),
    [anon_sym_SQUOTE] = ACTIONS(85),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(87),
    [sym_number] = ACTIONS(89),
    [sym_private_property_identifier] = ACTIONS(1412),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(93),
    [sym_true] = ACTIONS(93),
    [sym_false] = ACTIONS(93),
    [sym_null] = ACTIONS(93),
    [sym_undefined] = ACTIONS(1480),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1386),
    [anon_sym_readonly] = ACTIONS(1386),
    [anon_sym_get] = ACTIONS(1386),
    [anon_sym_set] = ACTIONS(1386),
    [anon_sym_declare] = ACTIONS(1386),
    [anon_sym_public] = ACTIONS(1386),
    [anon_sym_private] = ACTIONS(1386),
    [anon_sym_protected] = ACTIONS(1386),
    [anon_sym_override] = ACTIONS(1386),
    [anon_sym_module] = ACTIONS(1386),
    [anon_sym_any] = ACTIONS(1386),
    [anon_sym_number] = ACTIONS(1386),
    [anon_sym_boolean] = ACTIONS(1386),
    [anon_sym_string] = ACTIONS(1386),
    [anon_sym_symbol] = ACTIONS(1386),
    [anon_sym_object] = ACTIONS(1386),
    [sym_html_comment] = ACTIONS(5),
  },
  [525] = {
    [sym_import] = STATE(3636),
    [sym_parenthesized_expression] = STATE(1364),
    [sym_expression] = STATE(1848),
    [sym_primary_expression] = STATE(1810),
    [sym_yield_expression] = STATE(2358),
    [sym_object] = STATE(2222),
    [sym_object_pattern] = STATE(5773),
    [sym_array] = STATE(2222),
    [sym_array_pattern] = STATE(5773),
    [sym_class] = STATE(2222),
    [sym_function_expression] = STATE(2222),
    [sym_generator_function] = STATE(2222),
    [sym_arrow_function] = STATE(2222),
    [sym__call_signature] = STATE(5771),
    [sym_call_expression] = STATE(2222),
    [sym_new_expression] = STATE(1948),
    [sym_await_expression] = STATE(2358),
    [sym_member_expression] = STATE(1364),
    [sym_subscript_expression] = STATE(1364),
    [sym_assignment_expression] = STATE(2358),
    [sym__augmented_assignment_lhs] = STATE(3020),
    [sym_augmented_assignment_expression] = STATE(2358),
    [sym__destructuring_pattern] = STATE(5773),
    [sym_ternary_expression] = STATE(2358),
    [sym_binary_expression] = STATE(2358),
    [sym_unary_expression] = STATE(2358),
    [sym_update_expression] = STATE(2358),
    [sym_string] = STATE(2222),
    [sym_template_string] = STATE(2222),
    [sym_regex] = STATE(2222),
    [sym_meta_property] = STATE(2222),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1364),
    [sym_type_assertion] = STATE(2358),
    [sym_as_expression] = STATE(2358),
    [sym_satisfies_expression] = STATE(2358),
    [sym_instantiation_expression] = STATE(2358),
    [sym_internal_module] = STATE(2358),
    [sym_type_arguments] = STATE(513),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4408),
    [sym_identifier] = ACTIONS(1474),
    [anon_sym_export] = ACTIONS(1386),
    [anon_sym_type] = ACTIONS(1386),
    [anon_sym_namespace] = ACTIONS(1388),
    [anon_sym_LBRACE] = ACTIONS(665),
    [anon_sym_typeof] = ACTIONS(1408),
    [anon_sym_import] = ACTIONS(669),
    [anon_sym_let] = ACTIONS(1386),
    [anon_sym_BANG] = ACTIONS(1392),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_await] = ACTIONS(1394),
    [anon_sym_yield] = ACTIONS(1396),
    [anon_sym_LBRACK] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(676),
    [anon_sym_async] = ACTIONS(1398),
    [anon_sym_function] = ACTIONS(680),
    [anon_sym_new] = ACTIONS(1478),
    [anon_sym_using] = ACTIONS(1402),
    [anon_sym_PLUS] = ACTIONS(1408),
    [anon_sym_DASH] = ACTIONS(1408),
    [anon_sym_SLASH] = ACTIONS(876),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(1392),
    [anon_sym_void] = ACTIONS(1408),
    [anon_sym_delete] = ACTIONS(1408),
    [anon_sym_PLUS_PLUS] = ACTIONS(1410),
    [anon_sym_DASH_DASH] = ACTIONS(1410),
    [anon_sym_DQUOTE] = ACTIONS(83),
    [anon_sym_SQUOTE] = ACTIONS(85),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(87),
    [sym_number] = ACTIONS(89),
    [sym_private_property_identifier] = ACTIONS(1412),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(93),
    [sym_true] = ACTIONS(93),
    [sym_false] = ACTIONS(93),
    [sym_null] = ACTIONS(93),
    [sym_undefined] = ACTIONS(1480),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1386),
    [anon_sym_readonly] = ACTIONS(1386),
    [anon_sym_get] = ACTIONS(1386),
    [anon_sym_set] = ACTIONS(1386),
    [anon_sym_declare] = ACTIONS(1386),
    [anon_sym_public] = ACTIONS(1386),
    [anon_sym_private] = ACTIONS(1386),
    [anon_sym_protected] = ACTIONS(1386),
    [anon_sym_override] = ACTIONS(1386),
    [anon_sym_module] = ACTIONS(1386),
    [anon_sym_any] = ACTIONS(1386),
    [anon_sym_number] = ACTIONS(1386),
    [anon_sym_boolean] = ACTIONS(1386),
    [anon_sym_string] = ACTIONS(1386),
    [anon_sym_symbol] = ACTIONS(1386),
    [anon_sym_object] = ACTIONS(1386),
    [sym_html_comment] = ACTIONS(5),
  },
  [526] = {
    [sym_import] = STATE(3636),
    [sym_parenthesized_expression] = STATE(1362),
    [sym_expression] = STATE(1789),
    [sym_primary_expression] = STATE(1810),
    [sym_yield_expression] = STATE(2358),
    [sym_object] = STATE(2222),
    [sym_object_pattern] = STATE(5492),
    [sym_array] = STATE(2222),
    [sym_array_pattern] = STATE(5492),
    [sym_class] = STATE(2222),
    [sym_function_expression] = STATE(2222),
    [sym_generator_function] = STATE(2222),
    [sym_arrow_function] = STATE(2222),
    [sym__call_signature] = STATE(5821),
    [sym_call_expression] = STATE(2222),
    [sym_new_expression] = STATE(1948),
    [sym_await_expression] = STATE(2358),
    [sym_member_expression] = STATE(1362),
    [sym_subscript_expression] = STATE(1362),
    [sym_assignment_expression] = STATE(2358),
    [sym__augmented_assignment_lhs] = STATE(3025),
    [sym_augmented_assignment_expression] = STATE(2358),
    [sym__destructuring_pattern] = STATE(5492),
    [sym_ternary_expression] = STATE(2358),
    [sym_binary_expression] = STATE(2358),
    [sym_unary_expression] = STATE(2358),
    [sym_update_expression] = STATE(2358),
    [sym_string] = STATE(2222),
    [sym_template_string] = STATE(2222),
    [sym_regex] = STATE(2222),
    [sym_meta_property] = STATE(2222),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1362),
    [sym_type_assertion] = STATE(2358),
    [sym_as_expression] = STATE(2358),
    [sym_satisfies_expression] = STATE(2358),
    [sym_instantiation_expression] = STATE(2358),
    [sym_internal_module] = STATE(2358),
    [sym_type_arguments] = STATE(428),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4408),
    [sym_identifier] = ACTIONS(1468),
    [anon_sym_export] = ACTIONS(1352),
    [anon_sym_type] = ACTIONS(1352),
    [anon_sym_namespace] = ACTIONS(1354),
    [anon_sym_LBRACE] = ACTIONS(665),
    [anon_sym_typeof] = ACTIONS(21),
    [anon_sym_import] = ACTIONS(669),
    [anon_sym_let] = ACTIONS(1352),
    [anon_sym_BANG] = ACTIONS(33),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_await] = ACTIONS(45),
    [anon_sym_yield] = ACTIONS(63),
    [anon_sym_LBRACK] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(676),
    [anon_sym_async] = ACTIONS(1362),
    [anon_sym_function] = ACTIONS(680),
    [anon_sym_new] = ACTIONS(1472),
    [anon_sym_using] = ACTIONS(75),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_SLASH] = ACTIONS(77),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(33),
    [anon_sym_void] = ACTIONS(21),
    [anon_sym_delete] = ACTIONS(21),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_DQUOTE] = ACTIONS(83),
    [anon_sym_SQUOTE] = ACTIONS(85),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(87),
    [sym_number] = ACTIONS(89),
    [sym_private_property_identifier] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(93),
    [sym_true] = ACTIONS(93),
    [sym_false] = ACTIONS(93),
    [sym_null] = ACTIONS(93),
    [sym_undefined] = ACTIONS(95),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1352),
    [anon_sym_readonly] = ACTIONS(1352),
    [anon_sym_get] = ACTIONS(1352),
    [anon_sym_set] = ACTIONS(1352),
    [anon_sym_declare] = ACTIONS(1352),
    [anon_sym_public] = ACTIONS(1352),
    [anon_sym_private] = ACTIONS(1352),
    [anon_sym_protected] = ACTIONS(1352),
    [anon_sym_override] = ACTIONS(1352),
    [anon_sym_module] = ACTIONS(1352),
    [anon_sym_any] = ACTIONS(1352),
    [anon_sym_number] = ACTIONS(1352),
    [anon_sym_boolean] = ACTIONS(1352),
    [anon_sym_string] = ACTIONS(1352),
    [anon_sym_symbol] = ACTIONS(1352),
    [anon_sym_object] = ACTIONS(1352),
    [sym_html_comment] = ACTIONS(5),
  },
  [527] = {
    [sym_import] = STATE(3636),
    [sym_parenthesized_expression] = STATE(1364),
    [sym_expression] = STATE(1850),
    [sym_primary_expression] = STATE(1810),
    [sym_yield_expression] = STATE(2358),
    [sym_object] = STATE(2222),
    [sym_object_pattern] = STATE(5773),
    [sym_array] = STATE(2222),
    [sym_array_pattern] = STATE(5773),
    [sym_class] = STATE(2222),
    [sym_function_expression] = STATE(2222),
    [sym_generator_function] = STATE(2222),
    [sym_arrow_function] = STATE(2222),
    [sym__call_signature] = STATE(5771),
    [sym_call_expression] = STATE(2222),
    [sym_new_expression] = STATE(1948),
    [sym_await_expression] = STATE(2358),
    [sym_member_expression] = STATE(1364),
    [sym_subscript_expression] = STATE(1364),
    [sym_assignment_expression] = STATE(2358),
    [sym__augmented_assignment_lhs] = STATE(3020),
    [sym_augmented_assignment_expression] = STATE(2358),
    [sym__destructuring_pattern] = STATE(5773),
    [sym_ternary_expression] = STATE(2358),
    [sym_binary_expression] = STATE(2358),
    [sym_unary_expression] = STATE(2358),
    [sym_update_expression] = STATE(2358),
    [sym_string] = STATE(2222),
    [sym_template_string] = STATE(2222),
    [sym_regex] = STATE(2222),
    [sym_meta_property] = STATE(2222),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1364),
    [sym_type_assertion] = STATE(2358),
    [sym_as_expression] = STATE(2358),
    [sym_satisfies_expression] = STATE(2358),
    [sym_instantiation_expression] = STATE(2358),
    [sym_internal_module] = STATE(2358),
    [sym_type_arguments] = STATE(513),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4408),
    [sym_identifier] = ACTIONS(1474),
    [anon_sym_export] = ACTIONS(1386),
    [anon_sym_type] = ACTIONS(1386),
    [anon_sym_namespace] = ACTIONS(1388),
    [anon_sym_LBRACE] = ACTIONS(665),
    [anon_sym_typeof] = ACTIONS(1408),
    [anon_sym_import] = ACTIONS(669),
    [anon_sym_let] = ACTIONS(1386),
    [anon_sym_BANG] = ACTIONS(1392),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_await] = ACTIONS(1394),
    [anon_sym_yield] = ACTIONS(1396),
    [anon_sym_LBRACK] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(676),
    [anon_sym_async] = ACTIONS(1398),
    [anon_sym_function] = ACTIONS(680),
    [anon_sym_new] = ACTIONS(1478),
    [anon_sym_using] = ACTIONS(1402),
    [anon_sym_PLUS] = ACTIONS(1408),
    [anon_sym_DASH] = ACTIONS(1408),
    [anon_sym_SLASH] = ACTIONS(876),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(1392),
    [anon_sym_void] = ACTIONS(1408),
    [anon_sym_delete] = ACTIONS(1408),
    [anon_sym_PLUS_PLUS] = ACTIONS(1410),
    [anon_sym_DASH_DASH] = ACTIONS(1410),
    [anon_sym_DQUOTE] = ACTIONS(83),
    [anon_sym_SQUOTE] = ACTIONS(85),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(87),
    [sym_number] = ACTIONS(89),
    [sym_private_property_identifier] = ACTIONS(1412),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(93),
    [sym_true] = ACTIONS(93),
    [sym_false] = ACTIONS(93),
    [sym_null] = ACTIONS(93),
    [sym_undefined] = ACTIONS(1480),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1386),
    [anon_sym_readonly] = ACTIONS(1386),
    [anon_sym_get] = ACTIONS(1386),
    [anon_sym_set] = ACTIONS(1386),
    [anon_sym_declare] = ACTIONS(1386),
    [anon_sym_public] = ACTIONS(1386),
    [anon_sym_private] = ACTIONS(1386),
    [anon_sym_protected] = ACTIONS(1386),
    [anon_sym_override] = ACTIONS(1386),
    [anon_sym_module] = ACTIONS(1386),
    [anon_sym_any] = ACTIONS(1386),
    [anon_sym_number] = ACTIONS(1386),
    [anon_sym_boolean] = ACTIONS(1386),
    [anon_sym_string] = ACTIONS(1386),
    [anon_sym_symbol] = ACTIONS(1386),
    [anon_sym_object] = ACTIONS(1386),
    [sym_html_comment] = ACTIONS(5),
  },
  [528] = {
    [sym_import] = STATE(3636),
    [sym_parenthesized_expression] = STATE(1364),
    [sym_expression] = STATE(1851),
    [sym_primary_expression] = STATE(1810),
    [sym_yield_expression] = STATE(2358),
    [sym_object] = STATE(2222),
    [sym_object_pattern] = STATE(5773),
    [sym_array] = STATE(2222),
    [sym_array_pattern] = STATE(5773),
    [sym_class] = STATE(2222),
    [sym_function_expression] = STATE(2222),
    [sym_generator_function] = STATE(2222),
    [sym_arrow_function] = STATE(2222),
    [sym__call_signature] = STATE(5771),
    [sym_call_expression] = STATE(2222),
    [sym_new_expression] = STATE(1948),
    [sym_await_expression] = STATE(2358),
    [sym_member_expression] = STATE(1364),
    [sym_subscript_expression] = STATE(1364),
    [sym_assignment_expression] = STATE(2358),
    [sym__augmented_assignment_lhs] = STATE(3020),
    [sym_augmented_assignment_expression] = STATE(2358),
    [sym__destructuring_pattern] = STATE(5773),
    [sym_ternary_expression] = STATE(2358),
    [sym_binary_expression] = STATE(2358),
    [sym_unary_expression] = STATE(2358),
    [sym_update_expression] = STATE(2358),
    [sym_string] = STATE(2222),
    [sym_template_string] = STATE(2222),
    [sym_regex] = STATE(2222),
    [sym_meta_property] = STATE(2222),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1364),
    [sym_type_assertion] = STATE(2358),
    [sym_as_expression] = STATE(2358),
    [sym_satisfies_expression] = STATE(2358),
    [sym_instantiation_expression] = STATE(2358),
    [sym_internal_module] = STATE(2358),
    [sym_type_arguments] = STATE(513),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4408),
    [sym_identifier] = ACTIONS(1474),
    [anon_sym_export] = ACTIONS(1386),
    [anon_sym_type] = ACTIONS(1386),
    [anon_sym_namespace] = ACTIONS(1388),
    [anon_sym_LBRACE] = ACTIONS(665),
    [anon_sym_typeof] = ACTIONS(1408),
    [anon_sym_import] = ACTIONS(669),
    [anon_sym_let] = ACTIONS(1386),
    [anon_sym_BANG] = ACTIONS(1392),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_await] = ACTIONS(1394),
    [anon_sym_yield] = ACTIONS(1396),
    [anon_sym_LBRACK] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(676),
    [anon_sym_async] = ACTIONS(1398),
    [anon_sym_function] = ACTIONS(680),
    [anon_sym_new] = ACTIONS(1478),
    [anon_sym_using] = ACTIONS(1402),
    [anon_sym_PLUS] = ACTIONS(1408),
    [anon_sym_DASH] = ACTIONS(1408),
    [anon_sym_SLASH] = ACTIONS(876),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(1392),
    [anon_sym_void] = ACTIONS(1408),
    [anon_sym_delete] = ACTIONS(1408),
    [anon_sym_PLUS_PLUS] = ACTIONS(1410),
    [anon_sym_DASH_DASH] = ACTIONS(1410),
    [anon_sym_DQUOTE] = ACTIONS(83),
    [anon_sym_SQUOTE] = ACTIONS(85),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(87),
    [sym_number] = ACTIONS(89),
    [sym_private_property_identifier] = ACTIONS(1412),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(93),
    [sym_true] = ACTIONS(93),
    [sym_false] = ACTIONS(93),
    [sym_null] = ACTIONS(93),
    [sym_undefined] = ACTIONS(1480),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1386),
    [anon_sym_readonly] = ACTIONS(1386),
    [anon_sym_get] = ACTIONS(1386),
    [anon_sym_set] = ACTIONS(1386),
    [anon_sym_declare] = ACTIONS(1386),
    [anon_sym_public] = ACTIONS(1386),
    [anon_sym_private] = ACTIONS(1386),
    [anon_sym_protected] = ACTIONS(1386),
    [anon_sym_override] = ACTIONS(1386),
    [anon_sym_module] = ACTIONS(1386),
    [anon_sym_any] = ACTIONS(1386),
    [anon_sym_number] = ACTIONS(1386),
    [anon_sym_boolean] = ACTIONS(1386),
    [anon_sym_string] = ACTIONS(1386),
    [anon_sym_symbol] = ACTIONS(1386),
    [anon_sym_object] = ACTIONS(1386),
    [sym_html_comment] = ACTIONS(5),
  },
  [529] = {
    [sym_import] = STATE(3636),
    [sym_parenthesized_expression] = STATE(1364),
    [sym_expression] = STATE(1852),
    [sym_primary_expression] = STATE(1810),
    [sym_yield_expression] = STATE(2358),
    [sym_object] = STATE(2222),
    [sym_object_pattern] = STATE(5773),
    [sym_array] = STATE(2222),
    [sym_array_pattern] = STATE(5773),
    [sym_class] = STATE(2222),
    [sym_function_expression] = STATE(2222),
    [sym_generator_function] = STATE(2222),
    [sym_arrow_function] = STATE(2222),
    [sym__call_signature] = STATE(5771),
    [sym_call_expression] = STATE(2222),
    [sym_new_expression] = STATE(1948),
    [sym_await_expression] = STATE(2358),
    [sym_member_expression] = STATE(1364),
    [sym_subscript_expression] = STATE(1364),
    [sym_assignment_expression] = STATE(2358),
    [sym__augmented_assignment_lhs] = STATE(3020),
    [sym_augmented_assignment_expression] = STATE(2358),
    [sym__destructuring_pattern] = STATE(5773),
    [sym_ternary_expression] = STATE(2358),
    [sym_binary_expression] = STATE(2358),
    [sym_unary_expression] = STATE(2358),
    [sym_update_expression] = STATE(2358),
    [sym_string] = STATE(2222),
    [sym_template_string] = STATE(2222),
    [sym_regex] = STATE(2222),
    [sym_meta_property] = STATE(2222),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1364),
    [sym_type_assertion] = STATE(2358),
    [sym_as_expression] = STATE(2358),
    [sym_satisfies_expression] = STATE(2358),
    [sym_instantiation_expression] = STATE(2358),
    [sym_internal_module] = STATE(2358),
    [sym_type_arguments] = STATE(513),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4408),
    [sym_identifier] = ACTIONS(1474),
    [anon_sym_export] = ACTIONS(1386),
    [anon_sym_type] = ACTIONS(1386),
    [anon_sym_namespace] = ACTIONS(1388),
    [anon_sym_LBRACE] = ACTIONS(665),
    [anon_sym_typeof] = ACTIONS(1408),
    [anon_sym_import] = ACTIONS(669),
    [anon_sym_let] = ACTIONS(1386),
    [anon_sym_BANG] = ACTIONS(1392),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_await] = ACTIONS(1394),
    [anon_sym_yield] = ACTIONS(1396),
    [anon_sym_LBRACK] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(676),
    [anon_sym_async] = ACTIONS(1398),
    [anon_sym_function] = ACTIONS(680),
    [anon_sym_new] = ACTIONS(1478),
    [anon_sym_using] = ACTIONS(1402),
    [anon_sym_PLUS] = ACTIONS(1408),
    [anon_sym_DASH] = ACTIONS(1408),
    [anon_sym_SLASH] = ACTIONS(876),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(1392),
    [anon_sym_void] = ACTIONS(1408),
    [anon_sym_delete] = ACTIONS(1408),
    [anon_sym_PLUS_PLUS] = ACTIONS(1410),
    [anon_sym_DASH_DASH] = ACTIONS(1410),
    [anon_sym_DQUOTE] = ACTIONS(83),
    [anon_sym_SQUOTE] = ACTIONS(85),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(87),
    [sym_number] = ACTIONS(89),
    [sym_private_property_identifier] = ACTIONS(1412),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(93),
    [sym_true] = ACTIONS(93),
    [sym_false] = ACTIONS(93),
    [sym_null] = ACTIONS(93),
    [sym_undefined] = ACTIONS(1480),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1386),
    [anon_sym_readonly] = ACTIONS(1386),
    [anon_sym_get] = ACTIONS(1386),
    [anon_sym_set] = ACTIONS(1386),
    [anon_sym_declare] = ACTIONS(1386),
    [anon_sym_public] = ACTIONS(1386),
    [anon_sym_private] = ACTIONS(1386),
    [anon_sym_protected] = ACTIONS(1386),
    [anon_sym_override] = ACTIONS(1386),
    [anon_sym_module] = ACTIONS(1386),
    [anon_sym_any] = ACTIONS(1386),
    [anon_sym_number] = ACTIONS(1386),
    [anon_sym_boolean] = ACTIONS(1386),
    [anon_sym_string] = ACTIONS(1386),
    [anon_sym_symbol] = ACTIONS(1386),
    [anon_sym_object] = ACTIONS(1386),
    [sym_html_comment] = ACTIONS(5),
  },
  [530] = {
    [sym_import] = STATE(3636),
    [sym_parenthesized_expression] = STATE(1364),
    [sym_expression] = STATE(1853),
    [sym_primary_expression] = STATE(1810),
    [sym_yield_expression] = STATE(2358),
    [sym_object] = STATE(2222),
    [sym_object_pattern] = STATE(5773),
    [sym_array] = STATE(2222),
    [sym_array_pattern] = STATE(5773),
    [sym_class] = STATE(2222),
    [sym_function_expression] = STATE(2222),
    [sym_generator_function] = STATE(2222),
    [sym_arrow_function] = STATE(2222),
    [sym__call_signature] = STATE(5771),
    [sym_call_expression] = STATE(2222),
    [sym_new_expression] = STATE(1948),
    [sym_await_expression] = STATE(2358),
    [sym_member_expression] = STATE(1364),
    [sym_subscript_expression] = STATE(1364),
    [sym_assignment_expression] = STATE(2358),
    [sym__augmented_assignment_lhs] = STATE(3020),
    [sym_augmented_assignment_expression] = STATE(2358),
    [sym__destructuring_pattern] = STATE(5773),
    [sym_ternary_expression] = STATE(2358),
    [sym_binary_expression] = STATE(2358),
    [sym_unary_expression] = STATE(2358),
    [sym_update_expression] = STATE(2358),
    [sym_string] = STATE(2222),
    [sym_template_string] = STATE(2222),
    [sym_regex] = STATE(2222),
    [sym_meta_property] = STATE(2222),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1364),
    [sym_type_assertion] = STATE(2358),
    [sym_as_expression] = STATE(2358),
    [sym_satisfies_expression] = STATE(2358),
    [sym_instantiation_expression] = STATE(2358),
    [sym_internal_module] = STATE(2358),
    [sym_type_arguments] = STATE(513),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4408),
    [sym_identifier] = ACTIONS(1474),
    [anon_sym_export] = ACTIONS(1386),
    [anon_sym_type] = ACTIONS(1386),
    [anon_sym_namespace] = ACTIONS(1388),
    [anon_sym_LBRACE] = ACTIONS(665),
    [anon_sym_typeof] = ACTIONS(1408),
    [anon_sym_import] = ACTIONS(669),
    [anon_sym_let] = ACTIONS(1386),
    [anon_sym_BANG] = ACTIONS(1392),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_await] = ACTIONS(1394),
    [anon_sym_yield] = ACTIONS(1396),
    [anon_sym_LBRACK] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(676),
    [anon_sym_async] = ACTIONS(1398),
    [anon_sym_function] = ACTIONS(680),
    [anon_sym_new] = ACTIONS(1478),
    [anon_sym_using] = ACTIONS(1402),
    [anon_sym_PLUS] = ACTIONS(1408),
    [anon_sym_DASH] = ACTIONS(1408),
    [anon_sym_SLASH] = ACTIONS(876),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(1392),
    [anon_sym_void] = ACTIONS(1408),
    [anon_sym_delete] = ACTIONS(1408),
    [anon_sym_PLUS_PLUS] = ACTIONS(1410),
    [anon_sym_DASH_DASH] = ACTIONS(1410),
    [anon_sym_DQUOTE] = ACTIONS(83),
    [anon_sym_SQUOTE] = ACTIONS(85),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(87),
    [sym_number] = ACTIONS(89),
    [sym_private_property_identifier] = ACTIONS(1412),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(93),
    [sym_true] = ACTIONS(93),
    [sym_false] = ACTIONS(93),
    [sym_null] = ACTIONS(93),
    [sym_undefined] = ACTIONS(1480),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1386),
    [anon_sym_readonly] = ACTIONS(1386),
    [anon_sym_get] = ACTIONS(1386),
    [anon_sym_set] = ACTIONS(1386),
    [anon_sym_declare] = ACTIONS(1386),
    [anon_sym_public] = ACTIONS(1386),
    [anon_sym_private] = ACTIONS(1386),
    [anon_sym_protected] = ACTIONS(1386),
    [anon_sym_override] = ACTIONS(1386),
    [anon_sym_module] = ACTIONS(1386),
    [anon_sym_any] = ACTIONS(1386),
    [anon_sym_number] = ACTIONS(1386),
    [anon_sym_boolean] = ACTIONS(1386),
    [anon_sym_string] = ACTIONS(1386),
    [anon_sym_symbol] = ACTIONS(1386),
    [anon_sym_object] = ACTIONS(1386),
    [sym_html_comment] = ACTIONS(5),
  },
  [531] = {
    [sym_import] = STATE(3636),
    [sym_parenthesized_expression] = STATE(1364),
    [sym_expression] = STATE(1855),
    [sym_primary_expression] = STATE(1810),
    [sym_yield_expression] = STATE(2358),
    [sym_object] = STATE(2222),
    [sym_object_pattern] = STATE(5773),
    [sym_array] = STATE(2222),
    [sym_array_pattern] = STATE(5773),
    [sym_class] = STATE(2222),
    [sym_function_expression] = STATE(2222),
    [sym_generator_function] = STATE(2222),
    [sym_arrow_function] = STATE(2222),
    [sym__call_signature] = STATE(5771),
    [sym_call_expression] = STATE(2222),
    [sym_new_expression] = STATE(1948),
    [sym_await_expression] = STATE(2358),
    [sym_member_expression] = STATE(1364),
    [sym_subscript_expression] = STATE(1364),
    [sym_assignment_expression] = STATE(2358),
    [sym__augmented_assignment_lhs] = STATE(3020),
    [sym_augmented_assignment_expression] = STATE(2358),
    [sym__destructuring_pattern] = STATE(5773),
    [sym_ternary_expression] = STATE(2358),
    [sym_binary_expression] = STATE(2358),
    [sym_unary_expression] = STATE(2358),
    [sym_update_expression] = STATE(2358),
    [sym_string] = STATE(2222),
    [sym_template_string] = STATE(2222),
    [sym_regex] = STATE(2222),
    [sym_meta_property] = STATE(2222),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1364),
    [sym_type_assertion] = STATE(2358),
    [sym_as_expression] = STATE(2358),
    [sym_satisfies_expression] = STATE(2358),
    [sym_instantiation_expression] = STATE(2358),
    [sym_internal_module] = STATE(2358),
    [sym_type_arguments] = STATE(513),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4408),
    [sym_identifier] = ACTIONS(1474),
    [anon_sym_export] = ACTIONS(1386),
    [anon_sym_type] = ACTIONS(1386),
    [anon_sym_namespace] = ACTIONS(1388),
    [anon_sym_LBRACE] = ACTIONS(665),
    [anon_sym_typeof] = ACTIONS(1408),
    [anon_sym_import] = ACTIONS(669),
    [anon_sym_let] = ACTIONS(1386),
    [anon_sym_BANG] = ACTIONS(1392),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_await] = ACTIONS(1394),
    [anon_sym_yield] = ACTIONS(1396),
    [anon_sym_LBRACK] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(676),
    [anon_sym_async] = ACTIONS(1398),
    [anon_sym_function] = ACTIONS(680),
    [anon_sym_new] = ACTIONS(1478),
    [anon_sym_using] = ACTIONS(1402),
    [anon_sym_PLUS] = ACTIONS(1408),
    [anon_sym_DASH] = ACTIONS(1408),
    [anon_sym_SLASH] = ACTIONS(876),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(1392),
    [anon_sym_void] = ACTIONS(1408),
    [anon_sym_delete] = ACTIONS(1408),
    [anon_sym_PLUS_PLUS] = ACTIONS(1410),
    [anon_sym_DASH_DASH] = ACTIONS(1410),
    [anon_sym_DQUOTE] = ACTIONS(83),
    [anon_sym_SQUOTE] = ACTIONS(85),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(87),
    [sym_number] = ACTIONS(89),
    [sym_private_property_identifier] = ACTIONS(1412),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(93),
    [sym_true] = ACTIONS(93),
    [sym_false] = ACTIONS(93),
    [sym_null] = ACTIONS(93),
    [sym_undefined] = ACTIONS(1480),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1386),
    [anon_sym_readonly] = ACTIONS(1386),
    [anon_sym_get] = ACTIONS(1386),
    [anon_sym_set] = ACTIONS(1386),
    [anon_sym_declare] = ACTIONS(1386),
    [anon_sym_public] = ACTIONS(1386),
    [anon_sym_private] = ACTIONS(1386),
    [anon_sym_protected] = ACTIONS(1386),
    [anon_sym_override] = ACTIONS(1386),
    [anon_sym_module] = ACTIONS(1386),
    [anon_sym_any] = ACTIONS(1386),
    [anon_sym_number] = ACTIONS(1386),
    [anon_sym_boolean] = ACTIONS(1386),
    [anon_sym_string] = ACTIONS(1386),
    [anon_sym_symbol] = ACTIONS(1386),
    [anon_sym_object] = ACTIONS(1386),
    [sym_html_comment] = ACTIONS(5),
  },
  [532] = {
    [sym_import] = STATE(3636),
    [sym_parenthesized_expression] = STATE(1362),
    [sym_expression] = STATE(1809),
    [sym_primary_expression] = STATE(1810),
    [sym_yield_expression] = STATE(2358),
    [sym_object] = STATE(2222),
    [sym_object_pattern] = STATE(5492),
    [sym_array] = STATE(2222),
    [sym_array_pattern] = STATE(5492),
    [sym_class] = STATE(2222),
    [sym_function_expression] = STATE(2222),
    [sym_generator_function] = STATE(2222),
    [sym_arrow_function] = STATE(2222),
    [sym__call_signature] = STATE(5821),
    [sym_call_expression] = STATE(2222),
    [sym_new_expression] = STATE(1948),
    [sym_await_expression] = STATE(2358),
    [sym_member_expression] = STATE(1362),
    [sym_subscript_expression] = STATE(1362),
    [sym_assignment_expression] = STATE(2358),
    [sym__augmented_assignment_lhs] = STATE(3025),
    [sym_augmented_assignment_expression] = STATE(2358),
    [sym__destructuring_pattern] = STATE(5492),
    [sym_ternary_expression] = STATE(2358),
    [sym_binary_expression] = STATE(2358),
    [sym_unary_expression] = STATE(2358),
    [sym_update_expression] = STATE(2358),
    [sym_string] = STATE(2222),
    [sym_template_string] = STATE(2222),
    [sym_regex] = STATE(2222),
    [sym_meta_property] = STATE(2222),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1362),
    [sym_type_assertion] = STATE(2358),
    [sym_as_expression] = STATE(2358),
    [sym_satisfies_expression] = STATE(2358),
    [sym_instantiation_expression] = STATE(2358),
    [sym_internal_module] = STATE(2358),
    [sym_type_arguments] = STATE(428),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4408),
    [sym_identifier] = ACTIONS(1468),
    [anon_sym_export] = ACTIONS(1352),
    [anon_sym_type] = ACTIONS(1352),
    [anon_sym_namespace] = ACTIONS(1354),
    [anon_sym_LBRACE] = ACTIONS(665),
    [anon_sym_typeof] = ACTIONS(21),
    [anon_sym_import] = ACTIONS(669),
    [anon_sym_let] = ACTIONS(1352),
    [anon_sym_BANG] = ACTIONS(33),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_await] = ACTIONS(45),
    [anon_sym_yield] = ACTIONS(63),
    [anon_sym_LBRACK] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(676),
    [anon_sym_async] = ACTIONS(1362),
    [anon_sym_function] = ACTIONS(680),
    [anon_sym_new] = ACTIONS(1472),
    [anon_sym_using] = ACTIONS(75),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_SLASH] = ACTIONS(77),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(33),
    [anon_sym_void] = ACTIONS(21),
    [anon_sym_delete] = ACTIONS(21),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_DQUOTE] = ACTIONS(83),
    [anon_sym_SQUOTE] = ACTIONS(85),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(87),
    [sym_number] = ACTIONS(89),
    [sym_private_property_identifier] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(93),
    [sym_true] = ACTIONS(93),
    [sym_false] = ACTIONS(93),
    [sym_null] = ACTIONS(93),
    [sym_undefined] = ACTIONS(95),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1352),
    [anon_sym_readonly] = ACTIONS(1352),
    [anon_sym_get] = ACTIONS(1352),
    [anon_sym_set] = ACTIONS(1352),
    [anon_sym_declare] = ACTIONS(1352),
    [anon_sym_public] = ACTIONS(1352),
    [anon_sym_private] = ACTIONS(1352),
    [anon_sym_protected] = ACTIONS(1352),
    [anon_sym_override] = ACTIONS(1352),
    [anon_sym_module] = ACTIONS(1352),
    [anon_sym_any] = ACTIONS(1352),
    [anon_sym_number] = ACTIONS(1352),
    [anon_sym_boolean] = ACTIONS(1352),
    [anon_sym_string] = ACTIONS(1352),
    [anon_sym_symbol] = ACTIONS(1352),
    [anon_sym_object] = ACTIONS(1352),
    [sym_html_comment] = ACTIONS(5),
  },
  [533] = {
    [sym_import] = STATE(3636),
    [sym_parenthesized_expression] = STATE(1364),
    [sym_expression] = STATE(1859),
    [sym_primary_expression] = STATE(1810),
    [sym_yield_expression] = STATE(2358),
    [sym_object] = STATE(2222),
    [sym_object_pattern] = STATE(5773),
    [sym_array] = STATE(2222),
    [sym_array_pattern] = STATE(5773),
    [sym_class] = STATE(2222),
    [sym_function_expression] = STATE(2222),
    [sym_generator_function] = STATE(2222),
    [sym_arrow_function] = STATE(2222),
    [sym__call_signature] = STATE(5771),
    [sym_call_expression] = STATE(2222),
    [sym_new_expression] = STATE(1948),
    [sym_await_expression] = STATE(2358),
    [sym_member_expression] = STATE(1364),
    [sym_subscript_expression] = STATE(1364),
    [sym_assignment_expression] = STATE(2358),
    [sym__augmented_assignment_lhs] = STATE(3020),
    [sym_augmented_assignment_expression] = STATE(2358),
    [sym__destructuring_pattern] = STATE(5773),
    [sym_ternary_expression] = STATE(2358),
    [sym_binary_expression] = STATE(2358),
    [sym_unary_expression] = STATE(2358),
    [sym_update_expression] = STATE(2358),
    [sym_string] = STATE(2222),
    [sym_template_string] = STATE(2222),
    [sym_regex] = STATE(2222),
    [sym_meta_property] = STATE(2222),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1364),
    [sym_type_assertion] = STATE(2358),
    [sym_as_expression] = STATE(2358),
    [sym_satisfies_expression] = STATE(2358),
    [sym_instantiation_expression] = STATE(2358),
    [sym_internal_module] = STATE(2358),
    [sym_type_arguments] = STATE(513),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4408),
    [sym_identifier] = ACTIONS(1474),
    [anon_sym_export] = ACTIONS(1386),
    [anon_sym_type] = ACTIONS(1386),
    [anon_sym_namespace] = ACTIONS(1388),
    [anon_sym_LBRACE] = ACTIONS(665),
    [anon_sym_typeof] = ACTIONS(1408),
    [anon_sym_import] = ACTIONS(669),
    [anon_sym_let] = ACTIONS(1386),
    [anon_sym_BANG] = ACTIONS(1392),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_await] = ACTIONS(1394),
    [anon_sym_yield] = ACTIONS(1396),
    [anon_sym_LBRACK] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(676),
    [anon_sym_async] = ACTIONS(1398),
    [anon_sym_function] = ACTIONS(680),
    [anon_sym_new] = ACTIONS(1478),
    [anon_sym_using] = ACTIONS(1402),
    [anon_sym_PLUS] = ACTIONS(1408),
    [anon_sym_DASH] = ACTIONS(1408),
    [anon_sym_SLASH] = ACTIONS(876),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(1392),
    [anon_sym_void] = ACTIONS(1408),
    [anon_sym_delete] = ACTIONS(1408),
    [anon_sym_PLUS_PLUS] = ACTIONS(1410),
    [anon_sym_DASH_DASH] = ACTIONS(1410),
    [anon_sym_DQUOTE] = ACTIONS(83),
    [anon_sym_SQUOTE] = ACTIONS(85),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(87),
    [sym_number] = ACTIONS(89),
    [sym_private_property_identifier] = ACTIONS(1412),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(93),
    [sym_true] = ACTIONS(93),
    [sym_false] = ACTIONS(93),
    [sym_null] = ACTIONS(93),
    [sym_undefined] = ACTIONS(1480),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1386),
    [anon_sym_readonly] = ACTIONS(1386),
    [anon_sym_get] = ACTIONS(1386),
    [anon_sym_set] = ACTIONS(1386),
    [anon_sym_declare] = ACTIONS(1386),
    [anon_sym_public] = ACTIONS(1386),
    [anon_sym_private] = ACTIONS(1386),
    [anon_sym_protected] = ACTIONS(1386),
    [anon_sym_override] = ACTIONS(1386),
    [anon_sym_module] = ACTIONS(1386),
    [anon_sym_any] = ACTIONS(1386),
    [anon_sym_number] = ACTIONS(1386),
    [anon_sym_boolean] = ACTIONS(1386),
    [anon_sym_string] = ACTIONS(1386),
    [anon_sym_symbol] = ACTIONS(1386),
    [anon_sym_object] = ACTIONS(1386),
    [sym_html_comment] = ACTIONS(5),
  },
  [534] = {
    [sym_import] = STATE(3636),
    [sym_parenthesized_expression] = STATE(1364),
    [sym_expression] = STATE(1860),
    [sym_primary_expression] = STATE(1810),
    [sym_yield_expression] = STATE(2358),
    [sym_object] = STATE(2222),
    [sym_object_pattern] = STATE(5773),
    [sym_array] = STATE(2222),
    [sym_array_pattern] = STATE(5773),
    [sym_class] = STATE(2222),
    [sym_function_expression] = STATE(2222),
    [sym_generator_function] = STATE(2222),
    [sym_arrow_function] = STATE(2222),
    [sym__call_signature] = STATE(5771),
    [sym_call_expression] = STATE(2222),
    [sym_new_expression] = STATE(1948),
    [sym_await_expression] = STATE(2358),
    [sym_member_expression] = STATE(1364),
    [sym_subscript_expression] = STATE(1364),
    [sym_assignment_expression] = STATE(2358),
    [sym__augmented_assignment_lhs] = STATE(3020),
    [sym_augmented_assignment_expression] = STATE(2358),
    [sym__destructuring_pattern] = STATE(5773),
    [sym_ternary_expression] = STATE(2358),
    [sym_binary_expression] = STATE(2358),
    [sym_unary_expression] = STATE(2358),
    [sym_update_expression] = STATE(2358),
    [sym_string] = STATE(2222),
    [sym_template_string] = STATE(2222),
    [sym_regex] = STATE(2222),
    [sym_meta_property] = STATE(2222),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1364),
    [sym_type_assertion] = STATE(2358),
    [sym_as_expression] = STATE(2358),
    [sym_satisfies_expression] = STATE(2358),
    [sym_instantiation_expression] = STATE(2358),
    [sym_internal_module] = STATE(2358),
    [sym_type_arguments] = STATE(513),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4408),
    [sym_identifier] = ACTIONS(1474),
    [anon_sym_export] = ACTIONS(1386),
    [anon_sym_type] = ACTIONS(1386),
    [anon_sym_namespace] = ACTIONS(1388),
    [anon_sym_LBRACE] = ACTIONS(665),
    [anon_sym_typeof] = ACTIONS(1408),
    [anon_sym_import] = ACTIONS(669),
    [anon_sym_let] = ACTIONS(1386),
    [anon_sym_BANG] = ACTIONS(1392),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_await] = ACTIONS(1394),
    [anon_sym_yield] = ACTIONS(1396),
    [anon_sym_LBRACK] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(676),
    [anon_sym_async] = ACTIONS(1398),
    [anon_sym_function] = ACTIONS(680),
    [anon_sym_new] = ACTIONS(1478),
    [anon_sym_using] = ACTIONS(1402),
    [anon_sym_PLUS] = ACTIONS(1408),
    [anon_sym_DASH] = ACTIONS(1408),
    [anon_sym_SLASH] = ACTIONS(876),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(1392),
    [anon_sym_void] = ACTIONS(1408),
    [anon_sym_delete] = ACTIONS(1408),
    [anon_sym_PLUS_PLUS] = ACTIONS(1410),
    [anon_sym_DASH_DASH] = ACTIONS(1410),
    [anon_sym_DQUOTE] = ACTIONS(83),
    [anon_sym_SQUOTE] = ACTIONS(85),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(87),
    [sym_number] = ACTIONS(89),
    [sym_private_property_identifier] = ACTIONS(1412),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(93),
    [sym_true] = ACTIONS(93),
    [sym_false] = ACTIONS(93),
    [sym_null] = ACTIONS(93),
    [sym_undefined] = ACTIONS(1480),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1386),
    [anon_sym_readonly] = ACTIONS(1386),
    [anon_sym_get] = ACTIONS(1386),
    [anon_sym_set] = ACTIONS(1386),
    [anon_sym_declare] = ACTIONS(1386),
    [anon_sym_public] = ACTIONS(1386),
    [anon_sym_private] = ACTIONS(1386),
    [anon_sym_protected] = ACTIONS(1386),
    [anon_sym_override] = ACTIONS(1386),
    [anon_sym_module] = ACTIONS(1386),
    [anon_sym_any] = ACTIONS(1386),
    [anon_sym_number] = ACTIONS(1386),
    [anon_sym_boolean] = ACTIONS(1386),
    [anon_sym_string] = ACTIONS(1386),
    [anon_sym_symbol] = ACTIONS(1386),
    [anon_sym_object] = ACTIONS(1386),
    [sym_html_comment] = ACTIONS(5),
  },
  [535] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1322),
    [sym_expression] = STATE(1776),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5698),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5698),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5508),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1322),
    [sym_subscript_expression] = STATE(1322),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3003),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5698),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1322),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(484),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1456),
    [anon_sym_export] = ACTIONS(1048),
    [anon_sym_type] = ACTIONS(1048),
    [anon_sym_namespace] = ACTIONS(1050),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_typeof] = ACTIONS(581),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1048),
    [anon_sym_BANG] = ACTIONS(553),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(555),
    [anon_sym_yield] = ACTIONS(557),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1058),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1464),
    [anon_sym_using] = ACTIONS(567),
    [anon_sym_PLUS] = ACTIONS(581),
    [anon_sym_DASH] = ACTIONS(581),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(553),
    [anon_sym_void] = ACTIONS(581),
    [anon_sym_delete] = ACTIONS(581),
    [anon_sym_PLUS_PLUS] = ACTIONS(583),
    [anon_sym_DASH_DASH] = ACTIONS(583),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(2173),
    [sym_private_property_identifier] = ACTIONS(585),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1466),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1048),
    [anon_sym_readonly] = ACTIONS(1048),
    [anon_sym_get] = ACTIONS(1048),
    [anon_sym_set] = ACTIONS(1048),
    [anon_sym_declare] = ACTIONS(1048),
    [anon_sym_public] = ACTIONS(1048),
    [anon_sym_private] = ACTIONS(1048),
    [anon_sym_protected] = ACTIONS(1048),
    [anon_sym_override] = ACTIONS(1048),
    [anon_sym_module] = ACTIONS(1048),
    [anon_sym_any] = ACTIONS(1048),
    [anon_sym_number] = ACTIONS(1048),
    [anon_sym_boolean] = ACTIONS(1048),
    [anon_sym_string] = ACTIONS(1048),
    [anon_sym_symbol] = ACTIONS(1048),
    [anon_sym_object] = ACTIONS(1048),
    [sym_html_comment] = ACTIONS(5),
  },
  [536] = {
    [sym_import] = STATE(3636),
    [sym_parenthesized_expression] = STATE(1362),
    [sym_expression] = STATE(1811),
    [sym_primary_expression] = STATE(1810),
    [sym_yield_expression] = STATE(2358),
    [sym_object] = STATE(2222),
    [sym_object_pattern] = STATE(5492),
    [sym_array] = STATE(2222),
    [sym_array_pattern] = STATE(5492),
    [sym_class] = STATE(2222),
    [sym_function_expression] = STATE(2222),
    [sym_generator_function] = STATE(2222),
    [sym_arrow_function] = STATE(2222),
    [sym__call_signature] = STATE(5821),
    [sym_call_expression] = STATE(2222),
    [sym_new_expression] = STATE(1948),
    [sym_await_expression] = STATE(2358),
    [sym_member_expression] = STATE(1362),
    [sym_subscript_expression] = STATE(1362),
    [sym_assignment_expression] = STATE(2358),
    [sym__augmented_assignment_lhs] = STATE(3025),
    [sym_augmented_assignment_expression] = STATE(2358),
    [sym__destructuring_pattern] = STATE(5492),
    [sym_ternary_expression] = STATE(2358),
    [sym_binary_expression] = STATE(2358),
    [sym_unary_expression] = STATE(2358),
    [sym_update_expression] = STATE(2358),
    [sym_string] = STATE(2222),
    [sym_template_string] = STATE(2222),
    [sym_regex] = STATE(2222),
    [sym_meta_property] = STATE(2222),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1362),
    [sym_type_assertion] = STATE(2358),
    [sym_as_expression] = STATE(2358),
    [sym_satisfies_expression] = STATE(2358),
    [sym_instantiation_expression] = STATE(2358),
    [sym_internal_module] = STATE(2358),
    [sym_type_arguments] = STATE(428),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4408),
    [sym_identifier] = ACTIONS(1468),
    [anon_sym_export] = ACTIONS(1352),
    [anon_sym_type] = ACTIONS(1352),
    [anon_sym_namespace] = ACTIONS(1354),
    [anon_sym_LBRACE] = ACTIONS(665),
    [anon_sym_typeof] = ACTIONS(21),
    [anon_sym_import] = ACTIONS(669),
    [anon_sym_let] = ACTIONS(1352),
    [anon_sym_BANG] = ACTIONS(33),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_await] = ACTIONS(45),
    [anon_sym_yield] = ACTIONS(63),
    [anon_sym_LBRACK] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(676),
    [anon_sym_async] = ACTIONS(1362),
    [anon_sym_function] = ACTIONS(680),
    [anon_sym_new] = ACTIONS(1472),
    [anon_sym_using] = ACTIONS(75),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_SLASH] = ACTIONS(77),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(33),
    [anon_sym_void] = ACTIONS(21),
    [anon_sym_delete] = ACTIONS(21),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_DQUOTE] = ACTIONS(83),
    [anon_sym_SQUOTE] = ACTIONS(85),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(87),
    [sym_number] = ACTIONS(89),
    [sym_private_property_identifier] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(93),
    [sym_true] = ACTIONS(93),
    [sym_false] = ACTIONS(93),
    [sym_null] = ACTIONS(93),
    [sym_undefined] = ACTIONS(95),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1352),
    [anon_sym_readonly] = ACTIONS(1352),
    [anon_sym_get] = ACTIONS(1352),
    [anon_sym_set] = ACTIONS(1352),
    [anon_sym_declare] = ACTIONS(1352),
    [anon_sym_public] = ACTIONS(1352),
    [anon_sym_private] = ACTIONS(1352),
    [anon_sym_protected] = ACTIONS(1352),
    [anon_sym_override] = ACTIONS(1352),
    [anon_sym_module] = ACTIONS(1352),
    [anon_sym_any] = ACTIONS(1352),
    [anon_sym_number] = ACTIONS(1352),
    [anon_sym_boolean] = ACTIONS(1352),
    [anon_sym_string] = ACTIONS(1352),
    [anon_sym_symbol] = ACTIONS(1352),
    [anon_sym_object] = ACTIONS(1352),
    [sym_html_comment] = ACTIONS(5),
  },
  [537] = {
    [sym_import] = STATE(3636),
    [sym_parenthesized_expression] = STATE(1364),
    [sym_expression] = STATE(1861),
    [sym_primary_expression] = STATE(1810),
    [sym_yield_expression] = STATE(2358),
    [sym_object] = STATE(2222),
    [sym_object_pattern] = STATE(5773),
    [sym_array] = STATE(2222),
    [sym_array_pattern] = STATE(5773),
    [sym_class] = STATE(2222),
    [sym_function_expression] = STATE(2222),
    [sym_generator_function] = STATE(2222),
    [sym_arrow_function] = STATE(2222),
    [sym__call_signature] = STATE(5771),
    [sym_call_expression] = STATE(2222),
    [sym_new_expression] = STATE(1948),
    [sym_await_expression] = STATE(2358),
    [sym_member_expression] = STATE(1364),
    [sym_subscript_expression] = STATE(1364),
    [sym_assignment_expression] = STATE(2358),
    [sym__augmented_assignment_lhs] = STATE(3020),
    [sym_augmented_assignment_expression] = STATE(2358),
    [sym__destructuring_pattern] = STATE(5773),
    [sym_ternary_expression] = STATE(2358),
    [sym_binary_expression] = STATE(2358),
    [sym_unary_expression] = STATE(2358),
    [sym_update_expression] = STATE(2358),
    [sym_string] = STATE(2222),
    [sym_template_string] = STATE(2222),
    [sym_regex] = STATE(2222),
    [sym_meta_property] = STATE(2222),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1364),
    [sym_type_assertion] = STATE(2358),
    [sym_as_expression] = STATE(2358),
    [sym_satisfies_expression] = STATE(2358),
    [sym_instantiation_expression] = STATE(2358),
    [sym_internal_module] = STATE(2358),
    [sym_type_arguments] = STATE(513),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4408),
    [sym_identifier] = ACTIONS(1474),
    [anon_sym_export] = ACTIONS(1386),
    [anon_sym_type] = ACTIONS(1386),
    [anon_sym_namespace] = ACTIONS(1388),
    [anon_sym_LBRACE] = ACTIONS(665),
    [anon_sym_typeof] = ACTIONS(1408),
    [anon_sym_import] = ACTIONS(669),
    [anon_sym_let] = ACTIONS(1386),
    [anon_sym_BANG] = ACTIONS(1392),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_await] = ACTIONS(1394),
    [anon_sym_yield] = ACTIONS(1396),
    [anon_sym_LBRACK] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(676),
    [anon_sym_async] = ACTIONS(1398),
    [anon_sym_function] = ACTIONS(680),
    [anon_sym_new] = ACTIONS(1478),
    [anon_sym_using] = ACTIONS(1402),
    [anon_sym_PLUS] = ACTIONS(1408),
    [anon_sym_DASH] = ACTIONS(1408),
    [anon_sym_SLASH] = ACTIONS(876),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(1392),
    [anon_sym_void] = ACTIONS(1408),
    [anon_sym_delete] = ACTIONS(1408),
    [anon_sym_PLUS_PLUS] = ACTIONS(1410),
    [anon_sym_DASH_DASH] = ACTIONS(1410),
    [anon_sym_DQUOTE] = ACTIONS(83),
    [anon_sym_SQUOTE] = ACTIONS(85),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(87),
    [sym_number] = ACTIONS(89),
    [sym_private_property_identifier] = ACTIONS(1412),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(93),
    [sym_true] = ACTIONS(93),
    [sym_false] = ACTIONS(93),
    [sym_null] = ACTIONS(93),
    [sym_undefined] = ACTIONS(1480),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1386),
    [anon_sym_readonly] = ACTIONS(1386),
    [anon_sym_get] = ACTIONS(1386),
    [anon_sym_set] = ACTIONS(1386),
    [anon_sym_declare] = ACTIONS(1386),
    [anon_sym_public] = ACTIONS(1386),
    [anon_sym_private] = ACTIONS(1386),
    [anon_sym_protected] = ACTIONS(1386),
    [anon_sym_override] = ACTIONS(1386),
    [anon_sym_module] = ACTIONS(1386),
    [anon_sym_any] = ACTIONS(1386),
    [anon_sym_number] = ACTIONS(1386),
    [anon_sym_boolean] = ACTIONS(1386),
    [anon_sym_string] = ACTIONS(1386),
    [anon_sym_symbol] = ACTIONS(1386),
    [anon_sym_object] = ACTIONS(1386),
    [sym_html_comment] = ACTIONS(5),
  },
  [538] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1459),
    [sym_expression] = STATE(2517),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5827),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5827),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5529),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1459),
    [sym_subscript_expression] = STATE(1459),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(2979),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5827),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1459),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(647),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1514),
    [anon_sym_export] = ACTIONS(1074),
    [anon_sym_type] = ACTIONS(1074),
    [anon_sym_namespace] = ACTIONS(1076),
    [anon_sym_LBRACE] = ACTIONS(808),
    [anon_sym_typeof] = ACTIONS(1100),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1074),
    [anon_sym_BANG] = ACTIONS(1082),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(1084),
    [anon_sym_yield] = ACTIONS(1086),
    [anon_sym_LBRACK] = ACTIONS(812),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1090),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1518),
    [anon_sym_using] = ACTIONS(1094),
    [anon_sym_PLUS] = ACTIONS(1100),
    [anon_sym_DASH] = ACTIONS(1100),
    [anon_sym_SLASH] = ACTIONS(958),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(1082),
    [anon_sym_void] = ACTIONS(1100),
    [anon_sym_delete] = ACTIONS(1100),
    [anon_sym_PLUS_PLUS] = ACTIONS(1102),
    [anon_sym_DASH_DASH] = ACTIONS(1102),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(1108),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1520),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1074),
    [anon_sym_readonly] = ACTIONS(1074),
    [anon_sym_get] = ACTIONS(1074),
    [anon_sym_set] = ACTIONS(1074),
    [anon_sym_declare] = ACTIONS(1074),
    [anon_sym_public] = ACTIONS(1074),
    [anon_sym_private] = ACTIONS(1074),
    [anon_sym_protected] = ACTIONS(1074),
    [anon_sym_override] = ACTIONS(1074),
    [anon_sym_module] = ACTIONS(1074),
    [anon_sym_any] = ACTIONS(1074),
    [anon_sym_number] = ACTIONS(1074),
    [anon_sym_boolean] = ACTIONS(1074),
    [anon_sym_string] = ACTIONS(1074),
    [anon_sym_symbol] = ACTIONS(1074),
    [anon_sym_object] = ACTIONS(1074),
    [sym_html_comment] = ACTIONS(5),
  },
  [539] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1213),
    [sym_expression] = STATE(2527),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5522),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5522),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5800),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1213),
    [sym_subscript_expression] = STATE(1213),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3013),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5522),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1213),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(539),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(802),
    [anon_sym_export] = ACTIONS(804),
    [anon_sym_type] = ACTIONS(804),
    [anon_sym_namespace] = ACTIONS(806),
    [anon_sym_LBRACE] = ACTIONS(808),
    [anon_sym_typeof] = ACTIONS(179),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(804),
    [anon_sym_BANG] = ACTIONS(175),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(140),
    [anon_sym_yield] = ACTIONS(142),
    [anon_sym_LBRACK] = ACTIONS(812),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(816),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(818),
    [anon_sym_using] = ACTIONS(158),
    [anon_sym_PLUS] = ACTIONS(179),
    [anon_sym_DASH] = ACTIONS(179),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(175),
    [anon_sym_void] = ACTIONS(179),
    [anon_sym_delete] = ACTIONS(179),
    [anon_sym_PLUS_PLUS] = ACTIONS(686),
    [anon_sym_DASH_DASH] = ACTIONS(686),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(192),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(822),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(804),
    [anon_sym_readonly] = ACTIONS(804),
    [anon_sym_get] = ACTIONS(804),
    [anon_sym_set] = ACTIONS(804),
    [anon_sym_declare] = ACTIONS(804),
    [anon_sym_public] = ACTIONS(804),
    [anon_sym_private] = ACTIONS(804),
    [anon_sym_protected] = ACTIONS(804),
    [anon_sym_override] = ACTIONS(804),
    [anon_sym_module] = ACTIONS(804),
    [anon_sym_any] = ACTIONS(804),
    [anon_sym_number] = ACTIONS(804),
    [anon_sym_boolean] = ACTIONS(804),
    [anon_sym_string] = ACTIONS(804),
    [anon_sym_symbol] = ACTIONS(804),
    [anon_sym_object] = ACTIONS(804),
    [sym_html_comment] = ACTIONS(5),
  },
  [540] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1213),
    [sym_expression] = STATE(2608),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5522),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5522),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5800),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1213),
    [sym_subscript_expression] = STATE(1213),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3013),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5522),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1213),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(539),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(802),
    [anon_sym_export] = ACTIONS(804),
    [anon_sym_type] = ACTIONS(804),
    [anon_sym_namespace] = ACTIONS(806),
    [anon_sym_LBRACE] = ACTIONS(808),
    [anon_sym_typeof] = ACTIONS(179),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(804),
    [anon_sym_BANG] = ACTIONS(175),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(140),
    [anon_sym_yield] = ACTIONS(142),
    [anon_sym_LBRACK] = ACTIONS(812),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(816),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(818),
    [anon_sym_using] = ACTIONS(158),
    [anon_sym_PLUS] = ACTIONS(179),
    [anon_sym_DASH] = ACTIONS(179),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(175),
    [anon_sym_void] = ACTIONS(179),
    [anon_sym_delete] = ACTIONS(179),
    [anon_sym_PLUS_PLUS] = ACTIONS(686),
    [anon_sym_DASH_DASH] = ACTIONS(686),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(192),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(822),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(804),
    [anon_sym_readonly] = ACTIONS(804),
    [anon_sym_get] = ACTIONS(804),
    [anon_sym_set] = ACTIONS(804),
    [anon_sym_declare] = ACTIONS(804),
    [anon_sym_public] = ACTIONS(804),
    [anon_sym_private] = ACTIONS(804),
    [anon_sym_protected] = ACTIONS(804),
    [anon_sym_override] = ACTIONS(804),
    [anon_sym_module] = ACTIONS(804),
    [anon_sym_any] = ACTIONS(804),
    [anon_sym_number] = ACTIONS(804),
    [anon_sym_boolean] = ACTIONS(804),
    [anon_sym_string] = ACTIONS(804),
    [anon_sym_symbol] = ACTIONS(804),
    [anon_sym_object] = ACTIONS(804),
    [sym_html_comment] = ACTIONS(5),
  },
  [541] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1213),
    [sym_expression] = STATE(2529),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5522),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5522),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5800),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1213),
    [sym_subscript_expression] = STATE(1213),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3013),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5522),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1213),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(539),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(802),
    [anon_sym_export] = ACTIONS(804),
    [anon_sym_type] = ACTIONS(804),
    [anon_sym_namespace] = ACTIONS(806),
    [anon_sym_LBRACE] = ACTIONS(808),
    [anon_sym_typeof] = ACTIONS(179),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(804),
    [anon_sym_BANG] = ACTIONS(175),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(140),
    [anon_sym_yield] = ACTIONS(142),
    [anon_sym_LBRACK] = ACTIONS(812),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(816),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(818),
    [anon_sym_using] = ACTIONS(158),
    [anon_sym_PLUS] = ACTIONS(179),
    [anon_sym_DASH] = ACTIONS(179),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(175),
    [anon_sym_void] = ACTIONS(179),
    [anon_sym_delete] = ACTIONS(179),
    [anon_sym_PLUS_PLUS] = ACTIONS(686),
    [anon_sym_DASH_DASH] = ACTIONS(686),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(192),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(822),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(804),
    [anon_sym_readonly] = ACTIONS(804),
    [anon_sym_get] = ACTIONS(804),
    [anon_sym_set] = ACTIONS(804),
    [anon_sym_declare] = ACTIONS(804),
    [anon_sym_public] = ACTIONS(804),
    [anon_sym_private] = ACTIONS(804),
    [anon_sym_protected] = ACTIONS(804),
    [anon_sym_override] = ACTIONS(804),
    [anon_sym_module] = ACTIONS(804),
    [anon_sym_any] = ACTIONS(804),
    [anon_sym_number] = ACTIONS(804),
    [anon_sym_boolean] = ACTIONS(804),
    [anon_sym_string] = ACTIONS(804),
    [anon_sym_symbol] = ACTIONS(804),
    [anon_sym_object] = ACTIONS(804),
    [sym_html_comment] = ACTIONS(5),
  },
  [542] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1213),
    [sym_expression] = STATE(2530),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5522),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5522),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5800),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1213),
    [sym_subscript_expression] = STATE(1213),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3013),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5522),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1213),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(539),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(802),
    [anon_sym_export] = ACTIONS(804),
    [anon_sym_type] = ACTIONS(804),
    [anon_sym_namespace] = ACTIONS(806),
    [anon_sym_LBRACE] = ACTIONS(808),
    [anon_sym_typeof] = ACTIONS(179),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(804),
    [anon_sym_BANG] = ACTIONS(175),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(140),
    [anon_sym_yield] = ACTIONS(142),
    [anon_sym_LBRACK] = ACTIONS(812),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(816),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(818),
    [anon_sym_using] = ACTIONS(158),
    [anon_sym_PLUS] = ACTIONS(179),
    [anon_sym_DASH] = ACTIONS(179),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(175),
    [anon_sym_void] = ACTIONS(179),
    [anon_sym_delete] = ACTIONS(179),
    [anon_sym_PLUS_PLUS] = ACTIONS(686),
    [anon_sym_DASH_DASH] = ACTIONS(686),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(192),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(822),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(804),
    [anon_sym_readonly] = ACTIONS(804),
    [anon_sym_get] = ACTIONS(804),
    [anon_sym_set] = ACTIONS(804),
    [anon_sym_declare] = ACTIONS(804),
    [anon_sym_public] = ACTIONS(804),
    [anon_sym_private] = ACTIONS(804),
    [anon_sym_protected] = ACTIONS(804),
    [anon_sym_override] = ACTIONS(804),
    [anon_sym_module] = ACTIONS(804),
    [anon_sym_any] = ACTIONS(804),
    [anon_sym_number] = ACTIONS(804),
    [anon_sym_boolean] = ACTIONS(804),
    [anon_sym_string] = ACTIONS(804),
    [anon_sym_symbol] = ACTIONS(804),
    [anon_sym_object] = ACTIONS(804),
    [sym_html_comment] = ACTIONS(5),
  },
  [543] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1213),
    [sym_expression] = STATE(2532),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5522),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5522),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5800),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1213),
    [sym_subscript_expression] = STATE(1213),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3013),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5522),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1213),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(539),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(802),
    [anon_sym_export] = ACTIONS(804),
    [anon_sym_type] = ACTIONS(804),
    [anon_sym_namespace] = ACTIONS(806),
    [anon_sym_LBRACE] = ACTIONS(808),
    [anon_sym_typeof] = ACTIONS(179),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(804),
    [anon_sym_BANG] = ACTIONS(175),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(140),
    [anon_sym_yield] = ACTIONS(142),
    [anon_sym_LBRACK] = ACTIONS(812),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(816),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(818),
    [anon_sym_using] = ACTIONS(158),
    [anon_sym_PLUS] = ACTIONS(179),
    [anon_sym_DASH] = ACTIONS(179),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(175),
    [anon_sym_void] = ACTIONS(179),
    [anon_sym_delete] = ACTIONS(179),
    [anon_sym_PLUS_PLUS] = ACTIONS(686),
    [anon_sym_DASH_DASH] = ACTIONS(686),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(192),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(822),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(804),
    [anon_sym_readonly] = ACTIONS(804),
    [anon_sym_get] = ACTIONS(804),
    [anon_sym_set] = ACTIONS(804),
    [anon_sym_declare] = ACTIONS(804),
    [anon_sym_public] = ACTIONS(804),
    [anon_sym_private] = ACTIONS(804),
    [anon_sym_protected] = ACTIONS(804),
    [anon_sym_override] = ACTIONS(804),
    [anon_sym_module] = ACTIONS(804),
    [anon_sym_any] = ACTIONS(804),
    [anon_sym_number] = ACTIONS(804),
    [anon_sym_boolean] = ACTIONS(804),
    [anon_sym_string] = ACTIONS(804),
    [anon_sym_symbol] = ACTIONS(804),
    [anon_sym_object] = ACTIONS(804),
    [sym_html_comment] = ACTIONS(5),
  },
  [544] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1213),
    [sym_expression] = STATE(2533),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5522),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5522),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5800),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1213),
    [sym_subscript_expression] = STATE(1213),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3013),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5522),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1213),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(539),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(802),
    [anon_sym_export] = ACTIONS(804),
    [anon_sym_type] = ACTIONS(804),
    [anon_sym_namespace] = ACTIONS(806),
    [anon_sym_LBRACE] = ACTIONS(808),
    [anon_sym_typeof] = ACTIONS(179),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(804),
    [anon_sym_BANG] = ACTIONS(175),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(140),
    [anon_sym_yield] = ACTIONS(142),
    [anon_sym_LBRACK] = ACTIONS(812),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(816),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(818),
    [anon_sym_using] = ACTIONS(158),
    [anon_sym_PLUS] = ACTIONS(179),
    [anon_sym_DASH] = ACTIONS(179),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(175),
    [anon_sym_void] = ACTIONS(179),
    [anon_sym_delete] = ACTIONS(179),
    [anon_sym_PLUS_PLUS] = ACTIONS(686),
    [anon_sym_DASH_DASH] = ACTIONS(686),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(192),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(822),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(804),
    [anon_sym_readonly] = ACTIONS(804),
    [anon_sym_get] = ACTIONS(804),
    [anon_sym_set] = ACTIONS(804),
    [anon_sym_declare] = ACTIONS(804),
    [anon_sym_public] = ACTIONS(804),
    [anon_sym_private] = ACTIONS(804),
    [anon_sym_protected] = ACTIONS(804),
    [anon_sym_override] = ACTIONS(804),
    [anon_sym_module] = ACTIONS(804),
    [anon_sym_any] = ACTIONS(804),
    [anon_sym_number] = ACTIONS(804),
    [anon_sym_boolean] = ACTIONS(804),
    [anon_sym_string] = ACTIONS(804),
    [anon_sym_symbol] = ACTIONS(804),
    [anon_sym_object] = ACTIONS(804),
    [sym_html_comment] = ACTIONS(5),
  },
  [545] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1213),
    [sym_expression] = STATE(2534),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5522),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5522),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5800),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1213),
    [sym_subscript_expression] = STATE(1213),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3013),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5522),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1213),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(539),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(802),
    [anon_sym_export] = ACTIONS(804),
    [anon_sym_type] = ACTIONS(804),
    [anon_sym_namespace] = ACTIONS(806),
    [anon_sym_LBRACE] = ACTIONS(808),
    [anon_sym_typeof] = ACTIONS(179),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(804),
    [anon_sym_BANG] = ACTIONS(175),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(140),
    [anon_sym_yield] = ACTIONS(142),
    [anon_sym_LBRACK] = ACTIONS(812),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(816),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(818),
    [anon_sym_using] = ACTIONS(158),
    [anon_sym_PLUS] = ACTIONS(179),
    [anon_sym_DASH] = ACTIONS(179),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(175),
    [anon_sym_void] = ACTIONS(179),
    [anon_sym_delete] = ACTIONS(179),
    [anon_sym_PLUS_PLUS] = ACTIONS(686),
    [anon_sym_DASH_DASH] = ACTIONS(686),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(192),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(822),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(804),
    [anon_sym_readonly] = ACTIONS(804),
    [anon_sym_get] = ACTIONS(804),
    [anon_sym_set] = ACTIONS(804),
    [anon_sym_declare] = ACTIONS(804),
    [anon_sym_public] = ACTIONS(804),
    [anon_sym_private] = ACTIONS(804),
    [anon_sym_protected] = ACTIONS(804),
    [anon_sym_override] = ACTIONS(804),
    [anon_sym_module] = ACTIONS(804),
    [anon_sym_any] = ACTIONS(804),
    [anon_sym_number] = ACTIONS(804),
    [anon_sym_boolean] = ACTIONS(804),
    [anon_sym_string] = ACTIONS(804),
    [anon_sym_symbol] = ACTIONS(804),
    [anon_sym_object] = ACTIONS(804),
    [sym_html_comment] = ACTIONS(5),
  },
  [546] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1213),
    [sym_expression] = STATE(2535),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5522),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5522),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5800),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1213),
    [sym_subscript_expression] = STATE(1213),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3013),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5522),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1213),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(539),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(802),
    [anon_sym_export] = ACTIONS(804),
    [anon_sym_type] = ACTIONS(804),
    [anon_sym_namespace] = ACTIONS(806),
    [anon_sym_LBRACE] = ACTIONS(808),
    [anon_sym_typeof] = ACTIONS(179),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(804),
    [anon_sym_BANG] = ACTIONS(175),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(140),
    [anon_sym_yield] = ACTIONS(142),
    [anon_sym_LBRACK] = ACTIONS(812),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(816),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(818),
    [anon_sym_using] = ACTIONS(158),
    [anon_sym_PLUS] = ACTIONS(179),
    [anon_sym_DASH] = ACTIONS(179),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(175),
    [anon_sym_void] = ACTIONS(179),
    [anon_sym_delete] = ACTIONS(179),
    [anon_sym_PLUS_PLUS] = ACTIONS(686),
    [anon_sym_DASH_DASH] = ACTIONS(686),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(192),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(822),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(804),
    [anon_sym_readonly] = ACTIONS(804),
    [anon_sym_get] = ACTIONS(804),
    [anon_sym_set] = ACTIONS(804),
    [anon_sym_declare] = ACTIONS(804),
    [anon_sym_public] = ACTIONS(804),
    [anon_sym_private] = ACTIONS(804),
    [anon_sym_protected] = ACTIONS(804),
    [anon_sym_override] = ACTIONS(804),
    [anon_sym_module] = ACTIONS(804),
    [anon_sym_any] = ACTIONS(804),
    [anon_sym_number] = ACTIONS(804),
    [anon_sym_boolean] = ACTIONS(804),
    [anon_sym_string] = ACTIONS(804),
    [anon_sym_symbol] = ACTIONS(804),
    [anon_sym_object] = ACTIONS(804),
    [sym_html_comment] = ACTIONS(5),
  },
  [547] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1213),
    [sym_expression] = STATE(2536),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5522),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5522),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5800),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1213),
    [sym_subscript_expression] = STATE(1213),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3013),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5522),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1213),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(539),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(802),
    [anon_sym_export] = ACTIONS(804),
    [anon_sym_type] = ACTIONS(804),
    [anon_sym_namespace] = ACTIONS(806),
    [anon_sym_LBRACE] = ACTIONS(808),
    [anon_sym_typeof] = ACTIONS(179),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(804),
    [anon_sym_BANG] = ACTIONS(175),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(140),
    [anon_sym_yield] = ACTIONS(142),
    [anon_sym_LBRACK] = ACTIONS(812),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(816),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(818),
    [anon_sym_using] = ACTIONS(158),
    [anon_sym_PLUS] = ACTIONS(179),
    [anon_sym_DASH] = ACTIONS(179),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(175),
    [anon_sym_void] = ACTIONS(179),
    [anon_sym_delete] = ACTIONS(179),
    [anon_sym_PLUS_PLUS] = ACTIONS(686),
    [anon_sym_DASH_DASH] = ACTIONS(686),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(192),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(822),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(804),
    [anon_sym_readonly] = ACTIONS(804),
    [anon_sym_get] = ACTIONS(804),
    [anon_sym_set] = ACTIONS(804),
    [anon_sym_declare] = ACTIONS(804),
    [anon_sym_public] = ACTIONS(804),
    [anon_sym_private] = ACTIONS(804),
    [anon_sym_protected] = ACTIONS(804),
    [anon_sym_override] = ACTIONS(804),
    [anon_sym_module] = ACTIONS(804),
    [anon_sym_any] = ACTIONS(804),
    [anon_sym_number] = ACTIONS(804),
    [anon_sym_boolean] = ACTIONS(804),
    [anon_sym_string] = ACTIONS(804),
    [anon_sym_symbol] = ACTIONS(804),
    [anon_sym_object] = ACTIONS(804),
    [sym_html_comment] = ACTIONS(5),
  },
  [548] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1213),
    [sym_expression] = STATE(2537),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5522),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5522),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5800),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1213),
    [sym_subscript_expression] = STATE(1213),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3013),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5522),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1213),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(539),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(802),
    [anon_sym_export] = ACTIONS(804),
    [anon_sym_type] = ACTIONS(804),
    [anon_sym_namespace] = ACTIONS(806),
    [anon_sym_LBRACE] = ACTIONS(808),
    [anon_sym_typeof] = ACTIONS(179),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(804),
    [anon_sym_BANG] = ACTIONS(175),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(140),
    [anon_sym_yield] = ACTIONS(142),
    [anon_sym_LBRACK] = ACTIONS(812),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(816),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(818),
    [anon_sym_using] = ACTIONS(158),
    [anon_sym_PLUS] = ACTIONS(179),
    [anon_sym_DASH] = ACTIONS(179),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(175),
    [anon_sym_void] = ACTIONS(179),
    [anon_sym_delete] = ACTIONS(179),
    [anon_sym_PLUS_PLUS] = ACTIONS(686),
    [anon_sym_DASH_DASH] = ACTIONS(686),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(192),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(822),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(804),
    [anon_sym_readonly] = ACTIONS(804),
    [anon_sym_get] = ACTIONS(804),
    [anon_sym_set] = ACTIONS(804),
    [anon_sym_declare] = ACTIONS(804),
    [anon_sym_public] = ACTIONS(804),
    [anon_sym_private] = ACTIONS(804),
    [anon_sym_protected] = ACTIONS(804),
    [anon_sym_override] = ACTIONS(804),
    [anon_sym_module] = ACTIONS(804),
    [anon_sym_any] = ACTIONS(804),
    [anon_sym_number] = ACTIONS(804),
    [anon_sym_boolean] = ACTIONS(804),
    [anon_sym_string] = ACTIONS(804),
    [anon_sym_symbol] = ACTIONS(804),
    [anon_sym_object] = ACTIONS(804),
    [sym_html_comment] = ACTIONS(5),
  },
  [549] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1213),
    [sym_expression] = STATE(2538),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5522),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5522),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5800),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1213),
    [sym_subscript_expression] = STATE(1213),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3013),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5522),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1213),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(539),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(802),
    [anon_sym_export] = ACTIONS(804),
    [anon_sym_type] = ACTIONS(804),
    [anon_sym_namespace] = ACTIONS(806),
    [anon_sym_LBRACE] = ACTIONS(808),
    [anon_sym_typeof] = ACTIONS(179),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(804),
    [anon_sym_BANG] = ACTIONS(175),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(140),
    [anon_sym_yield] = ACTIONS(142),
    [anon_sym_LBRACK] = ACTIONS(812),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(816),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(818),
    [anon_sym_using] = ACTIONS(158),
    [anon_sym_PLUS] = ACTIONS(179),
    [anon_sym_DASH] = ACTIONS(179),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(175),
    [anon_sym_void] = ACTIONS(179),
    [anon_sym_delete] = ACTIONS(179),
    [anon_sym_PLUS_PLUS] = ACTIONS(686),
    [anon_sym_DASH_DASH] = ACTIONS(686),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(192),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(822),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(804),
    [anon_sym_readonly] = ACTIONS(804),
    [anon_sym_get] = ACTIONS(804),
    [anon_sym_set] = ACTIONS(804),
    [anon_sym_declare] = ACTIONS(804),
    [anon_sym_public] = ACTIONS(804),
    [anon_sym_private] = ACTIONS(804),
    [anon_sym_protected] = ACTIONS(804),
    [anon_sym_override] = ACTIONS(804),
    [anon_sym_module] = ACTIONS(804),
    [anon_sym_any] = ACTIONS(804),
    [anon_sym_number] = ACTIONS(804),
    [anon_sym_boolean] = ACTIONS(804),
    [anon_sym_string] = ACTIONS(804),
    [anon_sym_symbol] = ACTIONS(804),
    [anon_sym_object] = ACTIONS(804),
    [sym_html_comment] = ACTIONS(5),
  },
  [550] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1213),
    [sym_expression] = STATE(2539),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5522),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5522),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5800),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1213),
    [sym_subscript_expression] = STATE(1213),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3013),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5522),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1213),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(539),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(802),
    [anon_sym_export] = ACTIONS(804),
    [anon_sym_type] = ACTIONS(804),
    [anon_sym_namespace] = ACTIONS(806),
    [anon_sym_LBRACE] = ACTIONS(808),
    [anon_sym_typeof] = ACTIONS(179),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(804),
    [anon_sym_BANG] = ACTIONS(175),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(140),
    [anon_sym_yield] = ACTIONS(142),
    [anon_sym_LBRACK] = ACTIONS(812),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(816),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(818),
    [anon_sym_using] = ACTIONS(158),
    [anon_sym_PLUS] = ACTIONS(179),
    [anon_sym_DASH] = ACTIONS(179),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(175),
    [anon_sym_void] = ACTIONS(179),
    [anon_sym_delete] = ACTIONS(179),
    [anon_sym_PLUS_PLUS] = ACTIONS(686),
    [anon_sym_DASH_DASH] = ACTIONS(686),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(192),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(822),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(804),
    [anon_sym_readonly] = ACTIONS(804),
    [anon_sym_get] = ACTIONS(804),
    [anon_sym_set] = ACTIONS(804),
    [anon_sym_declare] = ACTIONS(804),
    [anon_sym_public] = ACTIONS(804),
    [anon_sym_private] = ACTIONS(804),
    [anon_sym_protected] = ACTIONS(804),
    [anon_sym_override] = ACTIONS(804),
    [anon_sym_module] = ACTIONS(804),
    [anon_sym_any] = ACTIONS(804),
    [anon_sym_number] = ACTIONS(804),
    [anon_sym_boolean] = ACTIONS(804),
    [anon_sym_string] = ACTIONS(804),
    [anon_sym_symbol] = ACTIONS(804),
    [anon_sym_object] = ACTIONS(804),
    [sym_html_comment] = ACTIONS(5),
  },
  [551] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1213),
    [sym_expression] = STATE(2540),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5522),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5522),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5800),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1213),
    [sym_subscript_expression] = STATE(1213),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3013),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5522),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1213),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(539),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(802),
    [anon_sym_export] = ACTIONS(804),
    [anon_sym_type] = ACTIONS(804),
    [anon_sym_namespace] = ACTIONS(806),
    [anon_sym_LBRACE] = ACTIONS(808),
    [anon_sym_typeof] = ACTIONS(179),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(804),
    [anon_sym_BANG] = ACTIONS(175),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(140),
    [anon_sym_yield] = ACTIONS(142),
    [anon_sym_LBRACK] = ACTIONS(812),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(816),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(818),
    [anon_sym_using] = ACTIONS(158),
    [anon_sym_PLUS] = ACTIONS(179),
    [anon_sym_DASH] = ACTIONS(179),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(175),
    [anon_sym_void] = ACTIONS(179),
    [anon_sym_delete] = ACTIONS(179),
    [anon_sym_PLUS_PLUS] = ACTIONS(686),
    [anon_sym_DASH_DASH] = ACTIONS(686),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(192),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(822),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(804),
    [anon_sym_readonly] = ACTIONS(804),
    [anon_sym_get] = ACTIONS(804),
    [anon_sym_set] = ACTIONS(804),
    [anon_sym_declare] = ACTIONS(804),
    [anon_sym_public] = ACTIONS(804),
    [anon_sym_private] = ACTIONS(804),
    [anon_sym_protected] = ACTIONS(804),
    [anon_sym_override] = ACTIONS(804),
    [anon_sym_module] = ACTIONS(804),
    [anon_sym_any] = ACTIONS(804),
    [anon_sym_number] = ACTIONS(804),
    [anon_sym_boolean] = ACTIONS(804),
    [anon_sym_string] = ACTIONS(804),
    [anon_sym_symbol] = ACTIONS(804),
    [anon_sym_object] = ACTIONS(804),
    [sym_html_comment] = ACTIONS(5),
  },
  [552] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1213),
    [sym_expression] = STATE(2541),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5522),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5522),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5800),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1213),
    [sym_subscript_expression] = STATE(1213),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3013),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5522),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1213),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(539),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(802),
    [anon_sym_export] = ACTIONS(804),
    [anon_sym_type] = ACTIONS(804),
    [anon_sym_namespace] = ACTIONS(806),
    [anon_sym_LBRACE] = ACTIONS(808),
    [anon_sym_typeof] = ACTIONS(179),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(804),
    [anon_sym_BANG] = ACTIONS(175),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(140),
    [anon_sym_yield] = ACTIONS(142),
    [anon_sym_LBRACK] = ACTIONS(812),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(816),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(818),
    [anon_sym_using] = ACTIONS(158),
    [anon_sym_PLUS] = ACTIONS(179),
    [anon_sym_DASH] = ACTIONS(179),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(175),
    [anon_sym_void] = ACTIONS(179),
    [anon_sym_delete] = ACTIONS(179),
    [anon_sym_PLUS_PLUS] = ACTIONS(686),
    [anon_sym_DASH_DASH] = ACTIONS(686),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(192),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(822),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(804),
    [anon_sym_readonly] = ACTIONS(804),
    [anon_sym_get] = ACTIONS(804),
    [anon_sym_set] = ACTIONS(804),
    [anon_sym_declare] = ACTIONS(804),
    [anon_sym_public] = ACTIONS(804),
    [anon_sym_private] = ACTIONS(804),
    [anon_sym_protected] = ACTIONS(804),
    [anon_sym_override] = ACTIONS(804),
    [anon_sym_module] = ACTIONS(804),
    [anon_sym_any] = ACTIONS(804),
    [anon_sym_number] = ACTIONS(804),
    [anon_sym_boolean] = ACTIONS(804),
    [anon_sym_string] = ACTIONS(804),
    [anon_sym_symbol] = ACTIONS(804),
    [anon_sym_object] = ACTIONS(804),
    [sym_html_comment] = ACTIONS(5),
  },
  [553] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1213),
    [sym_expression] = STATE(2542),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5522),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5522),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5800),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1213),
    [sym_subscript_expression] = STATE(1213),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3013),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5522),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1213),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(539),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(802),
    [anon_sym_export] = ACTIONS(804),
    [anon_sym_type] = ACTIONS(804),
    [anon_sym_namespace] = ACTIONS(806),
    [anon_sym_LBRACE] = ACTIONS(808),
    [anon_sym_typeof] = ACTIONS(179),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(804),
    [anon_sym_BANG] = ACTIONS(175),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(140),
    [anon_sym_yield] = ACTIONS(142),
    [anon_sym_LBRACK] = ACTIONS(812),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(816),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(818),
    [anon_sym_using] = ACTIONS(158),
    [anon_sym_PLUS] = ACTIONS(179),
    [anon_sym_DASH] = ACTIONS(179),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(175),
    [anon_sym_void] = ACTIONS(179),
    [anon_sym_delete] = ACTIONS(179),
    [anon_sym_PLUS_PLUS] = ACTIONS(686),
    [anon_sym_DASH_DASH] = ACTIONS(686),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(192),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(822),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(804),
    [anon_sym_readonly] = ACTIONS(804),
    [anon_sym_get] = ACTIONS(804),
    [anon_sym_set] = ACTIONS(804),
    [anon_sym_declare] = ACTIONS(804),
    [anon_sym_public] = ACTIONS(804),
    [anon_sym_private] = ACTIONS(804),
    [anon_sym_protected] = ACTIONS(804),
    [anon_sym_override] = ACTIONS(804),
    [anon_sym_module] = ACTIONS(804),
    [anon_sym_any] = ACTIONS(804),
    [anon_sym_number] = ACTIONS(804),
    [anon_sym_boolean] = ACTIONS(804),
    [anon_sym_string] = ACTIONS(804),
    [anon_sym_symbol] = ACTIONS(804),
    [anon_sym_object] = ACTIONS(804),
    [sym_html_comment] = ACTIONS(5),
  },
  [554] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1213),
    [sym_expression] = STATE(2543),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5522),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5522),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5800),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1213),
    [sym_subscript_expression] = STATE(1213),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3013),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5522),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1213),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(539),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(802),
    [anon_sym_export] = ACTIONS(804),
    [anon_sym_type] = ACTIONS(804),
    [anon_sym_namespace] = ACTIONS(806),
    [anon_sym_LBRACE] = ACTIONS(808),
    [anon_sym_typeof] = ACTIONS(179),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(804),
    [anon_sym_BANG] = ACTIONS(175),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(140),
    [anon_sym_yield] = ACTIONS(142),
    [anon_sym_LBRACK] = ACTIONS(812),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(816),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(818),
    [anon_sym_using] = ACTIONS(158),
    [anon_sym_PLUS] = ACTIONS(179),
    [anon_sym_DASH] = ACTIONS(179),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(175),
    [anon_sym_void] = ACTIONS(179),
    [anon_sym_delete] = ACTIONS(179),
    [anon_sym_PLUS_PLUS] = ACTIONS(686),
    [anon_sym_DASH_DASH] = ACTIONS(686),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(192),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(822),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(804),
    [anon_sym_readonly] = ACTIONS(804),
    [anon_sym_get] = ACTIONS(804),
    [anon_sym_set] = ACTIONS(804),
    [anon_sym_declare] = ACTIONS(804),
    [anon_sym_public] = ACTIONS(804),
    [anon_sym_private] = ACTIONS(804),
    [anon_sym_protected] = ACTIONS(804),
    [anon_sym_override] = ACTIONS(804),
    [anon_sym_module] = ACTIONS(804),
    [anon_sym_any] = ACTIONS(804),
    [anon_sym_number] = ACTIONS(804),
    [anon_sym_boolean] = ACTIONS(804),
    [anon_sym_string] = ACTIONS(804),
    [anon_sym_symbol] = ACTIONS(804),
    [anon_sym_object] = ACTIONS(804),
    [sym_html_comment] = ACTIONS(5),
  },
  [555] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1213),
    [sym_expression] = STATE(2545),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5522),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5522),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5800),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1213),
    [sym_subscript_expression] = STATE(1213),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3013),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5522),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1213),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(539),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(802),
    [anon_sym_export] = ACTIONS(804),
    [anon_sym_type] = ACTIONS(804),
    [anon_sym_namespace] = ACTIONS(806),
    [anon_sym_LBRACE] = ACTIONS(808),
    [anon_sym_typeof] = ACTIONS(179),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(804),
    [anon_sym_BANG] = ACTIONS(175),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(140),
    [anon_sym_yield] = ACTIONS(142),
    [anon_sym_LBRACK] = ACTIONS(812),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(816),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(818),
    [anon_sym_using] = ACTIONS(158),
    [anon_sym_PLUS] = ACTIONS(179),
    [anon_sym_DASH] = ACTIONS(179),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(175),
    [anon_sym_void] = ACTIONS(179),
    [anon_sym_delete] = ACTIONS(179),
    [anon_sym_PLUS_PLUS] = ACTIONS(686),
    [anon_sym_DASH_DASH] = ACTIONS(686),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(192),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(822),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(804),
    [anon_sym_readonly] = ACTIONS(804),
    [anon_sym_get] = ACTIONS(804),
    [anon_sym_set] = ACTIONS(804),
    [anon_sym_declare] = ACTIONS(804),
    [anon_sym_public] = ACTIONS(804),
    [anon_sym_private] = ACTIONS(804),
    [anon_sym_protected] = ACTIONS(804),
    [anon_sym_override] = ACTIONS(804),
    [anon_sym_module] = ACTIONS(804),
    [anon_sym_any] = ACTIONS(804),
    [anon_sym_number] = ACTIONS(804),
    [anon_sym_boolean] = ACTIONS(804),
    [anon_sym_string] = ACTIONS(804),
    [anon_sym_symbol] = ACTIONS(804),
    [anon_sym_object] = ACTIONS(804),
    [sym_html_comment] = ACTIONS(5),
  },
  [556] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1213),
    [sym_expression] = STATE(2549),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5522),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5522),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5800),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1213),
    [sym_subscript_expression] = STATE(1213),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3013),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5522),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1213),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(539),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(802),
    [anon_sym_export] = ACTIONS(804),
    [anon_sym_type] = ACTIONS(804),
    [anon_sym_namespace] = ACTIONS(806),
    [anon_sym_LBRACE] = ACTIONS(808),
    [anon_sym_typeof] = ACTIONS(179),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(804),
    [anon_sym_BANG] = ACTIONS(175),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(140),
    [anon_sym_yield] = ACTIONS(142),
    [anon_sym_LBRACK] = ACTIONS(812),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(816),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(818),
    [anon_sym_using] = ACTIONS(158),
    [anon_sym_PLUS] = ACTIONS(179),
    [anon_sym_DASH] = ACTIONS(179),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(175),
    [anon_sym_void] = ACTIONS(179),
    [anon_sym_delete] = ACTIONS(179),
    [anon_sym_PLUS_PLUS] = ACTIONS(686),
    [anon_sym_DASH_DASH] = ACTIONS(686),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(192),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(822),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(804),
    [anon_sym_readonly] = ACTIONS(804),
    [anon_sym_get] = ACTIONS(804),
    [anon_sym_set] = ACTIONS(804),
    [anon_sym_declare] = ACTIONS(804),
    [anon_sym_public] = ACTIONS(804),
    [anon_sym_private] = ACTIONS(804),
    [anon_sym_protected] = ACTIONS(804),
    [anon_sym_override] = ACTIONS(804),
    [anon_sym_module] = ACTIONS(804),
    [anon_sym_any] = ACTIONS(804),
    [anon_sym_number] = ACTIONS(804),
    [anon_sym_boolean] = ACTIONS(804),
    [anon_sym_string] = ACTIONS(804),
    [anon_sym_symbol] = ACTIONS(804),
    [anon_sym_object] = ACTIONS(804),
    [sym_html_comment] = ACTIONS(5),
  },
  [557] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1213),
    [sym_expression] = STATE(2550),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5522),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5522),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5800),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1213),
    [sym_subscript_expression] = STATE(1213),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3013),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5522),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1213),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(539),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(802),
    [anon_sym_export] = ACTIONS(804),
    [anon_sym_type] = ACTIONS(804),
    [anon_sym_namespace] = ACTIONS(806),
    [anon_sym_LBRACE] = ACTIONS(808),
    [anon_sym_typeof] = ACTIONS(179),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(804),
    [anon_sym_BANG] = ACTIONS(175),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(140),
    [anon_sym_yield] = ACTIONS(142),
    [anon_sym_LBRACK] = ACTIONS(812),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(816),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(818),
    [anon_sym_using] = ACTIONS(158),
    [anon_sym_PLUS] = ACTIONS(179),
    [anon_sym_DASH] = ACTIONS(179),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(175),
    [anon_sym_void] = ACTIONS(179),
    [anon_sym_delete] = ACTIONS(179),
    [anon_sym_PLUS_PLUS] = ACTIONS(686),
    [anon_sym_DASH_DASH] = ACTIONS(686),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(192),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(822),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(804),
    [anon_sym_readonly] = ACTIONS(804),
    [anon_sym_get] = ACTIONS(804),
    [anon_sym_set] = ACTIONS(804),
    [anon_sym_declare] = ACTIONS(804),
    [anon_sym_public] = ACTIONS(804),
    [anon_sym_private] = ACTIONS(804),
    [anon_sym_protected] = ACTIONS(804),
    [anon_sym_override] = ACTIONS(804),
    [anon_sym_module] = ACTIONS(804),
    [anon_sym_any] = ACTIONS(804),
    [anon_sym_number] = ACTIONS(804),
    [anon_sym_boolean] = ACTIONS(804),
    [anon_sym_string] = ACTIONS(804),
    [anon_sym_symbol] = ACTIONS(804),
    [anon_sym_object] = ACTIONS(804),
    [sym_html_comment] = ACTIONS(5),
  },
  [558] = {
    [sym_import] = STATE(3636),
    [sym_parenthesized_expression] = STATE(1364),
    [sym_expression] = STATE(1873),
    [sym_primary_expression] = STATE(1810),
    [sym_yield_expression] = STATE(2358),
    [sym_object] = STATE(2222),
    [sym_object_pattern] = STATE(5773),
    [sym_array] = STATE(2222),
    [sym_array_pattern] = STATE(5773),
    [sym_class] = STATE(2222),
    [sym_function_expression] = STATE(2222),
    [sym_generator_function] = STATE(2222),
    [sym_arrow_function] = STATE(2222),
    [sym__call_signature] = STATE(5771),
    [sym_call_expression] = STATE(2222),
    [sym_new_expression] = STATE(1948),
    [sym_await_expression] = STATE(2358),
    [sym_member_expression] = STATE(1364),
    [sym_subscript_expression] = STATE(1364),
    [sym_assignment_expression] = STATE(2358),
    [sym__augmented_assignment_lhs] = STATE(3020),
    [sym_augmented_assignment_expression] = STATE(2358),
    [sym__destructuring_pattern] = STATE(5773),
    [sym_ternary_expression] = STATE(2358),
    [sym_binary_expression] = STATE(2358),
    [sym_unary_expression] = STATE(2358),
    [sym_update_expression] = STATE(2358),
    [sym_string] = STATE(2222),
    [sym_template_string] = STATE(2222),
    [sym_regex] = STATE(2222),
    [sym_meta_property] = STATE(2222),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1364),
    [sym_type_assertion] = STATE(2358),
    [sym_as_expression] = STATE(2358),
    [sym_satisfies_expression] = STATE(2358),
    [sym_instantiation_expression] = STATE(2358),
    [sym_internal_module] = STATE(2358),
    [sym_type_arguments] = STATE(513),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4408),
    [sym_identifier] = ACTIONS(1474),
    [anon_sym_export] = ACTIONS(1386),
    [anon_sym_type] = ACTIONS(1386),
    [anon_sym_namespace] = ACTIONS(1388),
    [anon_sym_LBRACE] = ACTIONS(665),
    [anon_sym_typeof] = ACTIONS(1408),
    [anon_sym_import] = ACTIONS(669),
    [anon_sym_let] = ACTIONS(1386),
    [anon_sym_BANG] = ACTIONS(1392),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_await] = ACTIONS(1394),
    [anon_sym_yield] = ACTIONS(1396),
    [anon_sym_LBRACK] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(676),
    [anon_sym_async] = ACTIONS(1398),
    [anon_sym_function] = ACTIONS(680),
    [anon_sym_new] = ACTIONS(1478),
    [anon_sym_using] = ACTIONS(1402),
    [anon_sym_PLUS] = ACTIONS(1408),
    [anon_sym_DASH] = ACTIONS(1408),
    [anon_sym_SLASH] = ACTIONS(876),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(1392),
    [anon_sym_void] = ACTIONS(1408),
    [anon_sym_delete] = ACTIONS(1408),
    [anon_sym_PLUS_PLUS] = ACTIONS(1410),
    [anon_sym_DASH_DASH] = ACTIONS(1410),
    [anon_sym_DQUOTE] = ACTIONS(83),
    [anon_sym_SQUOTE] = ACTIONS(85),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(87),
    [sym_number] = ACTIONS(2125),
    [sym_private_property_identifier] = ACTIONS(1412),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(93),
    [sym_true] = ACTIONS(93),
    [sym_false] = ACTIONS(93),
    [sym_null] = ACTIONS(93),
    [sym_undefined] = ACTIONS(1480),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1386),
    [anon_sym_readonly] = ACTIONS(1386),
    [anon_sym_get] = ACTIONS(1386),
    [anon_sym_set] = ACTIONS(1386),
    [anon_sym_declare] = ACTIONS(1386),
    [anon_sym_public] = ACTIONS(1386),
    [anon_sym_private] = ACTIONS(1386),
    [anon_sym_protected] = ACTIONS(1386),
    [anon_sym_override] = ACTIONS(1386),
    [anon_sym_module] = ACTIONS(1386),
    [anon_sym_any] = ACTIONS(1386),
    [anon_sym_number] = ACTIONS(1386),
    [anon_sym_boolean] = ACTIONS(1386),
    [anon_sym_string] = ACTIONS(1386),
    [anon_sym_symbol] = ACTIONS(1386),
    [anon_sym_object] = ACTIONS(1386),
    [sym_html_comment] = ACTIONS(5),
  },
  [559] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1213),
    [sym_expression] = STATE(2551),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5522),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5522),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5800),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1213),
    [sym_subscript_expression] = STATE(1213),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3013),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5522),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1213),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(539),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(802),
    [anon_sym_export] = ACTIONS(804),
    [anon_sym_type] = ACTIONS(804),
    [anon_sym_namespace] = ACTIONS(806),
    [anon_sym_LBRACE] = ACTIONS(808),
    [anon_sym_typeof] = ACTIONS(179),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(804),
    [anon_sym_BANG] = ACTIONS(175),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(140),
    [anon_sym_yield] = ACTIONS(142),
    [anon_sym_LBRACK] = ACTIONS(812),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(816),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(818),
    [anon_sym_using] = ACTIONS(158),
    [anon_sym_PLUS] = ACTIONS(179),
    [anon_sym_DASH] = ACTIONS(179),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(175),
    [anon_sym_void] = ACTIONS(179),
    [anon_sym_delete] = ACTIONS(179),
    [anon_sym_PLUS_PLUS] = ACTIONS(686),
    [anon_sym_DASH_DASH] = ACTIONS(686),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(192),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(822),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(804),
    [anon_sym_readonly] = ACTIONS(804),
    [anon_sym_get] = ACTIONS(804),
    [anon_sym_set] = ACTIONS(804),
    [anon_sym_declare] = ACTIONS(804),
    [anon_sym_public] = ACTIONS(804),
    [anon_sym_private] = ACTIONS(804),
    [anon_sym_protected] = ACTIONS(804),
    [anon_sym_override] = ACTIONS(804),
    [anon_sym_module] = ACTIONS(804),
    [anon_sym_any] = ACTIONS(804),
    [anon_sym_number] = ACTIONS(804),
    [anon_sym_boolean] = ACTIONS(804),
    [anon_sym_string] = ACTIONS(804),
    [anon_sym_symbol] = ACTIONS(804),
    [anon_sym_object] = ACTIONS(804),
    [sym_html_comment] = ACTIONS(5),
  },
  [560] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1213),
    [sym_expression] = STATE(2577),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5522),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5522),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5800),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1213),
    [sym_subscript_expression] = STATE(1213),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3013),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5522),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1213),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(539),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(802),
    [anon_sym_export] = ACTIONS(804),
    [anon_sym_type] = ACTIONS(804),
    [anon_sym_namespace] = ACTIONS(806),
    [anon_sym_LBRACE] = ACTIONS(808),
    [anon_sym_typeof] = ACTIONS(179),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(804),
    [anon_sym_BANG] = ACTIONS(175),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(140),
    [anon_sym_yield] = ACTIONS(142),
    [anon_sym_LBRACK] = ACTIONS(812),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(816),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(818),
    [anon_sym_using] = ACTIONS(158),
    [anon_sym_PLUS] = ACTIONS(179),
    [anon_sym_DASH] = ACTIONS(179),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(175),
    [anon_sym_void] = ACTIONS(179),
    [anon_sym_delete] = ACTIONS(179),
    [anon_sym_PLUS_PLUS] = ACTIONS(686),
    [anon_sym_DASH_DASH] = ACTIONS(686),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(192),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(822),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(804),
    [anon_sym_readonly] = ACTIONS(804),
    [anon_sym_get] = ACTIONS(804),
    [anon_sym_set] = ACTIONS(804),
    [anon_sym_declare] = ACTIONS(804),
    [anon_sym_public] = ACTIONS(804),
    [anon_sym_private] = ACTIONS(804),
    [anon_sym_protected] = ACTIONS(804),
    [anon_sym_override] = ACTIONS(804),
    [anon_sym_module] = ACTIONS(804),
    [anon_sym_any] = ACTIONS(804),
    [anon_sym_number] = ACTIONS(804),
    [anon_sym_boolean] = ACTIONS(804),
    [anon_sym_string] = ACTIONS(804),
    [anon_sym_symbol] = ACTIONS(804),
    [anon_sym_object] = ACTIONS(804),
    [sym_html_comment] = ACTIONS(5),
  },
  [561] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1213),
    [sym_expression] = STATE(2578),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5522),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5522),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5800),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1213),
    [sym_subscript_expression] = STATE(1213),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3013),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5522),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1213),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(539),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(802),
    [anon_sym_export] = ACTIONS(804),
    [anon_sym_type] = ACTIONS(804),
    [anon_sym_namespace] = ACTIONS(806),
    [anon_sym_LBRACE] = ACTIONS(808),
    [anon_sym_typeof] = ACTIONS(179),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(804),
    [anon_sym_BANG] = ACTIONS(175),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(140),
    [anon_sym_yield] = ACTIONS(142),
    [anon_sym_LBRACK] = ACTIONS(812),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(816),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(818),
    [anon_sym_using] = ACTIONS(158),
    [anon_sym_PLUS] = ACTIONS(179),
    [anon_sym_DASH] = ACTIONS(179),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(175),
    [anon_sym_void] = ACTIONS(179),
    [anon_sym_delete] = ACTIONS(179),
    [anon_sym_PLUS_PLUS] = ACTIONS(686),
    [anon_sym_DASH_DASH] = ACTIONS(686),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(192),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(822),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(804),
    [anon_sym_readonly] = ACTIONS(804),
    [anon_sym_get] = ACTIONS(804),
    [anon_sym_set] = ACTIONS(804),
    [anon_sym_declare] = ACTIONS(804),
    [anon_sym_public] = ACTIONS(804),
    [anon_sym_private] = ACTIONS(804),
    [anon_sym_protected] = ACTIONS(804),
    [anon_sym_override] = ACTIONS(804),
    [anon_sym_module] = ACTIONS(804),
    [anon_sym_any] = ACTIONS(804),
    [anon_sym_number] = ACTIONS(804),
    [anon_sym_boolean] = ACTIONS(804),
    [anon_sym_string] = ACTIONS(804),
    [anon_sym_symbol] = ACTIONS(804),
    [anon_sym_object] = ACTIONS(804),
    [sym_html_comment] = ACTIONS(5),
  },
  [562] = {
    [sym_import] = STATE(3636),
    [sym_parenthesized_expression] = STATE(1410),
    [sym_expression] = STATE(2411),
    [sym_primary_expression] = STATE(1810),
    [sym_yield_expression] = STATE(2358),
    [sym_object] = STATE(2222),
    [sym_object_pattern] = STATE(5580),
    [sym_array] = STATE(2222),
    [sym_array_pattern] = STATE(5580),
    [sym_class] = STATE(2222),
    [sym_function_expression] = STATE(2222),
    [sym_generator_function] = STATE(2222),
    [sym_arrow_function] = STATE(2222),
    [sym__call_signature] = STATE(5466),
    [sym_call_expression] = STATE(2222),
    [sym_new_expression] = STATE(1948),
    [sym_await_expression] = STATE(2358),
    [sym_member_expression] = STATE(1410),
    [sym_subscript_expression] = STATE(1410),
    [sym_assignment_expression] = STATE(2358),
    [sym__augmented_assignment_lhs] = STATE(3004),
    [sym_augmented_assignment_expression] = STATE(2358),
    [sym__destructuring_pattern] = STATE(5580),
    [sym_ternary_expression] = STATE(2358),
    [sym_binary_expression] = STATE(2358),
    [sym_unary_expression] = STATE(2358),
    [sym_update_expression] = STATE(2358),
    [sym_string] = STATE(2222),
    [sym_template_string] = STATE(2222),
    [sym_regex] = STATE(2222),
    [sym_meta_property] = STATE(2222),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1410),
    [sym_type_assertion] = STATE(2358),
    [sym_as_expression] = STATE(2358),
    [sym_satisfies_expression] = STATE(2358),
    [sym_instantiation_expression] = STATE(2358),
    [sym_internal_module] = STATE(2358),
    [sym_type_arguments] = STATE(452),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4408),
    [sym_identifier] = ACTIONS(1498),
    [anon_sym_export] = ACTIONS(1270),
    [anon_sym_type] = ACTIONS(1270),
    [anon_sym_namespace] = ACTIONS(1272),
    [anon_sym_LBRACE] = ACTIONS(665),
    [anon_sym_typeof] = ACTIONS(1298),
    [anon_sym_import] = ACTIONS(669),
    [anon_sym_let] = ACTIONS(1270),
    [anon_sym_BANG] = ACTIONS(1278),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_await] = ACTIONS(1282),
    [anon_sym_yield] = ACTIONS(1284),
    [anon_sym_LBRACK] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(676),
    [anon_sym_async] = ACTIONS(1288),
    [anon_sym_function] = ACTIONS(680),
    [anon_sym_new] = ACTIONS(1502),
    [anon_sym_using] = ACTIONS(1292),
    [anon_sym_PLUS] = ACTIONS(1298),
    [anon_sym_DASH] = ACTIONS(1298),
    [anon_sym_SLASH] = ACTIONS(77),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(1278),
    [anon_sym_void] = ACTIONS(1298),
    [anon_sym_delete] = ACTIONS(1298),
    [anon_sym_PLUS_PLUS] = ACTIONS(1300),
    [anon_sym_DASH_DASH] = ACTIONS(1300),
    [anon_sym_DQUOTE] = ACTIONS(83),
    [anon_sym_SQUOTE] = ACTIONS(85),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(87),
    [sym_number] = ACTIONS(89),
    [sym_private_property_identifier] = ACTIONS(1306),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(93),
    [sym_true] = ACTIONS(93),
    [sym_false] = ACTIONS(93),
    [sym_null] = ACTIONS(93),
    [sym_undefined] = ACTIONS(1504),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1270),
    [anon_sym_readonly] = ACTIONS(1270),
    [anon_sym_get] = ACTIONS(1270),
    [anon_sym_set] = ACTIONS(1270),
    [anon_sym_declare] = ACTIONS(1270),
    [anon_sym_public] = ACTIONS(1270),
    [anon_sym_private] = ACTIONS(1270),
    [anon_sym_protected] = ACTIONS(1270),
    [anon_sym_override] = ACTIONS(1270),
    [anon_sym_module] = ACTIONS(1270),
    [anon_sym_any] = ACTIONS(1270),
    [anon_sym_number] = ACTIONS(1270),
    [anon_sym_boolean] = ACTIONS(1270),
    [anon_sym_string] = ACTIONS(1270),
    [anon_sym_symbol] = ACTIONS(1270),
    [anon_sym_object] = ACTIONS(1270),
    [sym_html_comment] = ACTIONS(5),
  },
  [563] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1387),
    [sym_expression] = STATE(2106),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5803),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5803),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5585),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1387),
    [sym_subscript_expression] = STATE(1387),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3009),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5803),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1387),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(566),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1490),
    [anon_sym_export] = ACTIONS(1422),
    [anon_sym_type] = ACTIONS(1422),
    [anon_sym_namespace] = ACTIONS(1424),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_typeof] = ACTIONS(1444),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1422),
    [anon_sym_BANG] = ACTIONS(1428),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(1430),
    [anon_sym_yield] = ACTIONS(1432),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1434),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1494),
    [anon_sym_using] = ACTIONS(1438),
    [anon_sym_PLUS] = ACTIONS(1444),
    [anon_sym_DASH] = ACTIONS(1444),
    [anon_sym_SLASH] = ACTIONS(942),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(1428),
    [anon_sym_void] = ACTIONS(1444),
    [anon_sym_delete] = ACTIONS(1444),
    [anon_sym_PLUS_PLUS] = ACTIONS(1446),
    [anon_sym_DASH_DASH] = ACTIONS(1446),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(2171),
    [sym_private_property_identifier] = ACTIONS(1448),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1496),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1422),
    [anon_sym_readonly] = ACTIONS(1422),
    [anon_sym_get] = ACTIONS(1422),
    [anon_sym_set] = ACTIONS(1422),
    [anon_sym_declare] = ACTIONS(1422),
    [anon_sym_public] = ACTIONS(1422),
    [anon_sym_private] = ACTIONS(1422),
    [anon_sym_protected] = ACTIONS(1422),
    [anon_sym_override] = ACTIONS(1422),
    [anon_sym_module] = ACTIONS(1422),
    [anon_sym_any] = ACTIONS(1422),
    [anon_sym_number] = ACTIONS(1422),
    [anon_sym_boolean] = ACTIONS(1422),
    [anon_sym_string] = ACTIONS(1422),
    [anon_sym_symbol] = ACTIONS(1422),
    [anon_sym_object] = ACTIONS(1422),
    [sym_html_comment] = ACTIONS(5),
  },
  [564] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1465),
    [sym_expression] = STATE(2644),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5867),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5867),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5800),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1465),
    [sym_subscript_expression] = STATE(1465),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3013),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5867),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1465),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(539),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(2227),
    [anon_sym_export] = ACTIONS(2229),
    [anon_sym_type] = ACTIONS(2229),
    [anon_sym_namespace] = ACTIONS(2231),
    [anon_sym_LBRACE] = ACTIONS(808),
    [anon_sym_typeof] = ACTIONS(179),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(2229),
    [anon_sym_BANG] = ACTIONS(175),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(140),
    [anon_sym_yield] = ACTIONS(142),
    [anon_sym_LBRACK] = ACTIONS(812),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(2233),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(2235),
    [anon_sym_using] = ACTIONS(158),
    [anon_sym_PLUS] = ACTIONS(179),
    [anon_sym_DASH] = ACTIONS(179),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(175),
    [anon_sym_void] = ACTIONS(179),
    [anon_sym_delete] = ACTIONS(179),
    [anon_sym_PLUS_PLUS] = ACTIONS(686),
    [anon_sym_DASH_DASH] = ACTIONS(686),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(192),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(2237),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(2229),
    [anon_sym_readonly] = ACTIONS(2229),
    [anon_sym_get] = ACTIONS(2229),
    [anon_sym_set] = ACTIONS(2229),
    [anon_sym_declare] = ACTIONS(2229),
    [anon_sym_public] = ACTIONS(2229),
    [anon_sym_private] = ACTIONS(2229),
    [anon_sym_protected] = ACTIONS(2229),
    [anon_sym_override] = ACTIONS(2229),
    [anon_sym_module] = ACTIONS(2229),
    [anon_sym_any] = ACTIONS(2229),
    [anon_sym_number] = ACTIONS(2229),
    [anon_sym_boolean] = ACTIONS(2229),
    [anon_sym_string] = ACTIONS(2229),
    [anon_sym_symbol] = ACTIONS(2229),
    [anon_sym_object] = ACTIONS(2229),
    [sym_html_comment] = ACTIONS(5),
  },
  [565] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1456),
    [sym_expression] = STATE(2587),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5815),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5815),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5755),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1456),
    [sym_subscript_expression] = STATE(1456),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3029),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5815),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1456),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(594),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1506),
    [anon_sym_export] = ACTIONS(1234),
    [anon_sym_type] = ACTIONS(1234),
    [anon_sym_namespace] = ACTIONS(1236),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_typeof] = ACTIONS(1256),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1234),
    [anon_sym_BANG] = ACTIONS(1240),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(1242),
    [anon_sym_yield] = ACTIONS(1244),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1246),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1510),
    [anon_sym_using] = ACTIONS(1250),
    [anon_sym_PLUS] = ACTIONS(1256),
    [anon_sym_DASH] = ACTIONS(1256),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(1240),
    [anon_sym_void] = ACTIONS(1256),
    [anon_sym_delete] = ACTIONS(1256),
    [anon_sym_PLUS_PLUS] = ACTIONS(1258),
    [anon_sym_DASH_DASH] = ACTIONS(1258),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(1260),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1512),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1234),
    [anon_sym_readonly] = ACTIONS(1234),
    [anon_sym_get] = ACTIONS(1234),
    [anon_sym_set] = ACTIONS(1234),
    [anon_sym_declare] = ACTIONS(1234),
    [anon_sym_public] = ACTIONS(1234),
    [anon_sym_private] = ACTIONS(1234),
    [anon_sym_protected] = ACTIONS(1234),
    [anon_sym_override] = ACTIONS(1234),
    [anon_sym_module] = ACTIONS(1234),
    [anon_sym_any] = ACTIONS(1234),
    [anon_sym_number] = ACTIONS(1234),
    [anon_sym_boolean] = ACTIONS(1234),
    [anon_sym_string] = ACTIONS(1234),
    [anon_sym_symbol] = ACTIONS(1234),
    [anon_sym_object] = ACTIONS(1234),
    [sym_html_comment] = ACTIONS(5),
  },
  [566] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1387),
    [sym_expression] = STATE(2080),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5803),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5803),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5585),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1387),
    [sym_subscript_expression] = STATE(1387),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3009),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5803),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1387),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(566),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1490),
    [anon_sym_export] = ACTIONS(1422),
    [anon_sym_type] = ACTIONS(1422),
    [anon_sym_namespace] = ACTIONS(1424),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_typeof] = ACTIONS(1444),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1422),
    [anon_sym_BANG] = ACTIONS(1428),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(1430),
    [anon_sym_yield] = ACTIONS(1432),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1434),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1494),
    [anon_sym_using] = ACTIONS(1438),
    [anon_sym_PLUS] = ACTIONS(1444),
    [anon_sym_DASH] = ACTIONS(1444),
    [anon_sym_SLASH] = ACTIONS(942),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(1428),
    [anon_sym_void] = ACTIONS(1444),
    [anon_sym_delete] = ACTIONS(1444),
    [anon_sym_PLUS_PLUS] = ACTIONS(1446),
    [anon_sym_DASH_DASH] = ACTIONS(1446),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(1448),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1496),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1422),
    [anon_sym_readonly] = ACTIONS(1422),
    [anon_sym_get] = ACTIONS(1422),
    [anon_sym_set] = ACTIONS(1422),
    [anon_sym_declare] = ACTIONS(1422),
    [anon_sym_public] = ACTIONS(1422),
    [anon_sym_private] = ACTIONS(1422),
    [anon_sym_protected] = ACTIONS(1422),
    [anon_sym_override] = ACTIONS(1422),
    [anon_sym_module] = ACTIONS(1422),
    [anon_sym_any] = ACTIONS(1422),
    [anon_sym_number] = ACTIONS(1422),
    [anon_sym_boolean] = ACTIONS(1422),
    [anon_sym_string] = ACTIONS(1422),
    [anon_sym_symbol] = ACTIONS(1422),
    [anon_sym_object] = ACTIONS(1422),
    [sym_html_comment] = ACTIONS(5),
  },
  [567] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1387),
    [sym_expression] = STATE(2082),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5803),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5803),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5585),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1387),
    [sym_subscript_expression] = STATE(1387),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3009),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5803),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1387),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(566),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1490),
    [anon_sym_export] = ACTIONS(1422),
    [anon_sym_type] = ACTIONS(1422),
    [anon_sym_namespace] = ACTIONS(1424),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_typeof] = ACTIONS(1444),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1422),
    [anon_sym_BANG] = ACTIONS(1428),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(1430),
    [anon_sym_yield] = ACTIONS(1432),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1434),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1494),
    [anon_sym_using] = ACTIONS(1438),
    [anon_sym_PLUS] = ACTIONS(1444),
    [anon_sym_DASH] = ACTIONS(1444),
    [anon_sym_SLASH] = ACTIONS(942),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(1428),
    [anon_sym_void] = ACTIONS(1444),
    [anon_sym_delete] = ACTIONS(1444),
    [anon_sym_PLUS_PLUS] = ACTIONS(1446),
    [anon_sym_DASH_DASH] = ACTIONS(1446),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(1448),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1496),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1422),
    [anon_sym_readonly] = ACTIONS(1422),
    [anon_sym_get] = ACTIONS(1422),
    [anon_sym_set] = ACTIONS(1422),
    [anon_sym_declare] = ACTIONS(1422),
    [anon_sym_public] = ACTIONS(1422),
    [anon_sym_private] = ACTIONS(1422),
    [anon_sym_protected] = ACTIONS(1422),
    [anon_sym_override] = ACTIONS(1422),
    [anon_sym_module] = ACTIONS(1422),
    [anon_sym_any] = ACTIONS(1422),
    [anon_sym_number] = ACTIONS(1422),
    [anon_sym_boolean] = ACTIONS(1422),
    [anon_sym_string] = ACTIONS(1422),
    [anon_sym_symbol] = ACTIONS(1422),
    [anon_sym_object] = ACTIONS(1422),
    [sym_html_comment] = ACTIONS(5),
  },
  [568] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1387),
    [sym_expression] = STATE(2083),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5803),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5803),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5585),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1387),
    [sym_subscript_expression] = STATE(1387),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3009),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5803),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1387),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(566),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1490),
    [anon_sym_export] = ACTIONS(1422),
    [anon_sym_type] = ACTIONS(1422),
    [anon_sym_namespace] = ACTIONS(1424),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_typeof] = ACTIONS(1444),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1422),
    [anon_sym_BANG] = ACTIONS(1428),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(1430),
    [anon_sym_yield] = ACTIONS(1432),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1434),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1494),
    [anon_sym_using] = ACTIONS(1438),
    [anon_sym_PLUS] = ACTIONS(1444),
    [anon_sym_DASH] = ACTIONS(1444),
    [anon_sym_SLASH] = ACTIONS(942),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(1428),
    [anon_sym_void] = ACTIONS(1444),
    [anon_sym_delete] = ACTIONS(1444),
    [anon_sym_PLUS_PLUS] = ACTIONS(1446),
    [anon_sym_DASH_DASH] = ACTIONS(1446),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(1448),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1496),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1422),
    [anon_sym_readonly] = ACTIONS(1422),
    [anon_sym_get] = ACTIONS(1422),
    [anon_sym_set] = ACTIONS(1422),
    [anon_sym_declare] = ACTIONS(1422),
    [anon_sym_public] = ACTIONS(1422),
    [anon_sym_private] = ACTIONS(1422),
    [anon_sym_protected] = ACTIONS(1422),
    [anon_sym_override] = ACTIONS(1422),
    [anon_sym_module] = ACTIONS(1422),
    [anon_sym_any] = ACTIONS(1422),
    [anon_sym_number] = ACTIONS(1422),
    [anon_sym_boolean] = ACTIONS(1422),
    [anon_sym_string] = ACTIONS(1422),
    [anon_sym_symbol] = ACTIONS(1422),
    [anon_sym_object] = ACTIONS(1422),
    [sym_html_comment] = ACTIONS(5),
  },
  [569] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1387),
    [sym_expression] = STATE(2084),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5803),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5803),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5585),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1387),
    [sym_subscript_expression] = STATE(1387),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3009),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5803),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1387),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(566),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1490),
    [anon_sym_export] = ACTIONS(1422),
    [anon_sym_type] = ACTIONS(1422),
    [anon_sym_namespace] = ACTIONS(1424),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_typeof] = ACTIONS(1444),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1422),
    [anon_sym_BANG] = ACTIONS(1428),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(1430),
    [anon_sym_yield] = ACTIONS(1432),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1434),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1494),
    [anon_sym_using] = ACTIONS(1438),
    [anon_sym_PLUS] = ACTIONS(1444),
    [anon_sym_DASH] = ACTIONS(1444),
    [anon_sym_SLASH] = ACTIONS(942),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(1428),
    [anon_sym_void] = ACTIONS(1444),
    [anon_sym_delete] = ACTIONS(1444),
    [anon_sym_PLUS_PLUS] = ACTIONS(1446),
    [anon_sym_DASH_DASH] = ACTIONS(1446),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(1448),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1496),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1422),
    [anon_sym_readonly] = ACTIONS(1422),
    [anon_sym_get] = ACTIONS(1422),
    [anon_sym_set] = ACTIONS(1422),
    [anon_sym_declare] = ACTIONS(1422),
    [anon_sym_public] = ACTIONS(1422),
    [anon_sym_private] = ACTIONS(1422),
    [anon_sym_protected] = ACTIONS(1422),
    [anon_sym_override] = ACTIONS(1422),
    [anon_sym_module] = ACTIONS(1422),
    [anon_sym_any] = ACTIONS(1422),
    [anon_sym_number] = ACTIONS(1422),
    [anon_sym_boolean] = ACTIONS(1422),
    [anon_sym_string] = ACTIONS(1422),
    [anon_sym_symbol] = ACTIONS(1422),
    [anon_sym_object] = ACTIONS(1422),
    [sym_html_comment] = ACTIONS(5),
  },
  [570] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1387),
    [sym_expression] = STATE(2086),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5803),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5803),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5585),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1387),
    [sym_subscript_expression] = STATE(1387),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3009),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5803),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1387),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(566),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1490),
    [anon_sym_export] = ACTIONS(1422),
    [anon_sym_type] = ACTIONS(1422),
    [anon_sym_namespace] = ACTIONS(1424),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_typeof] = ACTIONS(1444),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1422),
    [anon_sym_BANG] = ACTIONS(1428),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(1430),
    [anon_sym_yield] = ACTIONS(1432),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1434),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1494),
    [anon_sym_using] = ACTIONS(1438),
    [anon_sym_PLUS] = ACTIONS(1444),
    [anon_sym_DASH] = ACTIONS(1444),
    [anon_sym_SLASH] = ACTIONS(942),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(1428),
    [anon_sym_void] = ACTIONS(1444),
    [anon_sym_delete] = ACTIONS(1444),
    [anon_sym_PLUS_PLUS] = ACTIONS(1446),
    [anon_sym_DASH_DASH] = ACTIONS(1446),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(1448),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1496),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1422),
    [anon_sym_readonly] = ACTIONS(1422),
    [anon_sym_get] = ACTIONS(1422),
    [anon_sym_set] = ACTIONS(1422),
    [anon_sym_declare] = ACTIONS(1422),
    [anon_sym_public] = ACTIONS(1422),
    [anon_sym_private] = ACTIONS(1422),
    [anon_sym_protected] = ACTIONS(1422),
    [anon_sym_override] = ACTIONS(1422),
    [anon_sym_module] = ACTIONS(1422),
    [anon_sym_any] = ACTIONS(1422),
    [anon_sym_number] = ACTIONS(1422),
    [anon_sym_boolean] = ACTIONS(1422),
    [anon_sym_string] = ACTIONS(1422),
    [anon_sym_symbol] = ACTIONS(1422),
    [anon_sym_object] = ACTIONS(1422),
    [sym_html_comment] = ACTIONS(5),
  },
  [571] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1387),
    [sym_expression] = STATE(2087),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5803),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5803),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5585),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1387),
    [sym_subscript_expression] = STATE(1387),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3009),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5803),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1387),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(566),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1490),
    [anon_sym_export] = ACTIONS(1422),
    [anon_sym_type] = ACTIONS(1422),
    [anon_sym_namespace] = ACTIONS(1424),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_typeof] = ACTIONS(1444),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1422),
    [anon_sym_BANG] = ACTIONS(1428),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(1430),
    [anon_sym_yield] = ACTIONS(1432),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1434),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1494),
    [anon_sym_using] = ACTIONS(1438),
    [anon_sym_PLUS] = ACTIONS(1444),
    [anon_sym_DASH] = ACTIONS(1444),
    [anon_sym_SLASH] = ACTIONS(942),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(1428),
    [anon_sym_void] = ACTIONS(1444),
    [anon_sym_delete] = ACTIONS(1444),
    [anon_sym_PLUS_PLUS] = ACTIONS(1446),
    [anon_sym_DASH_DASH] = ACTIONS(1446),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(1448),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1496),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1422),
    [anon_sym_readonly] = ACTIONS(1422),
    [anon_sym_get] = ACTIONS(1422),
    [anon_sym_set] = ACTIONS(1422),
    [anon_sym_declare] = ACTIONS(1422),
    [anon_sym_public] = ACTIONS(1422),
    [anon_sym_private] = ACTIONS(1422),
    [anon_sym_protected] = ACTIONS(1422),
    [anon_sym_override] = ACTIONS(1422),
    [anon_sym_module] = ACTIONS(1422),
    [anon_sym_any] = ACTIONS(1422),
    [anon_sym_number] = ACTIONS(1422),
    [anon_sym_boolean] = ACTIONS(1422),
    [anon_sym_string] = ACTIONS(1422),
    [anon_sym_symbol] = ACTIONS(1422),
    [anon_sym_object] = ACTIONS(1422),
    [sym_html_comment] = ACTIONS(5),
  },
  [572] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1387),
    [sym_expression] = STATE(2088),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5803),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5803),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5585),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1387),
    [sym_subscript_expression] = STATE(1387),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3009),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5803),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1387),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(566),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1490),
    [anon_sym_export] = ACTIONS(1422),
    [anon_sym_type] = ACTIONS(1422),
    [anon_sym_namespace] = ACTIONS(1424),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_typeof] = ACTIONS(1444),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1422),
    [anon_sym_BANG] = ACTIONS(1428),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(1430),
    [anon_sym_yield] = ACTIONS(1432),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1434),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1494),
    [anon_sym_using] = ACTIONS(1438),
    [anon_sym_PLUS] = ACTIONS(1444),
    [anon_sym_DASH] = ACTIONS(1444),
    [anon_sym_SLASH] = ACTIONS(942),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(1428),
    [anon_sym_void] = ACTIONS(1444),
    [anon_sym_delete] = ACTIONS(1444),
    [anon_sym_PLUS_PLUS] = ACTIONS(1446),
    [anon_sym_DASH_DASH] = ACTIONS(1446),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(1448),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1496),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1422),
    [anon_sym_readonly] = ACTIONS(1422),
    [anon_sym_get] = ACTIONS(1422),
    [anon_sym_set] = ACTIONS(1422),
    [anon_sym_declare] = ACTIONS(1422),
    [anon_sym_public] = ACTIONS(1422),
    [anon_sym_private] = ACTIONS(1422),
    [anon_sym_protected] = ACTIONS(1422),
    [anon_sym_override] = ACTIONS(1422),
    [anon_sym_module] = ACTIONS(1422),
    [anon_sym_any] = ACTIONS(1422),
    [anon_sym_number] = ACTIONS(1422),
    [anon_sym_boolean] = ACTIONS(1422),
    [anon_sym_string] = ACTIONS(1422),
    [anon_sym_symbol] = ACTIONS(1422),
    [anon_sym_object] = ACTIONS(1422),
    [sym_html_comment] = ACTIONS(5),
  },
  [573] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1387),
    [sym_expression] = STATE(2089),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5803),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5803),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5585),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1387),
    [sym_subscript_expression] = STATE(1387),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3009),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5803),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1387),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(566),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1490),
    [anon_sym_export] = ACTIONS(1422),
    [anon_sym_type] = ACTIONS(1422),
    [anon_sym_namespace] = ACTIONS(1424),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_typeof] = ACTIONS(1444),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1422),
    [anon_sym_BANG] = ACTIONS(1428),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(1430),
    [anon_sym_yield] = ACTIONS(1432),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1434),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1494),
    [anon_sym_using] = ACTIONS(1438),
    [anon_sym_PLUS] = ACTIONS(1444),
    [anon_sym_DASH] = ACTIONS(1444),
    [anon_sym_SLASH] = ACTIONS(942),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(1428),
    [anon_sym_void] = ACTIONS(1444),
    [anon_sym_delete] = ACTIONS(1444),
    [anon_sym_PLUS_PLUS] = ACTIONS(1446),
    [anon_sym_DASH_DASH] = ACTIONS(1446),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(1448),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1496),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1422),
    [anon_sym_readonly] = ACTIONS(1422),
    [anon_sym_get] = ACTIONS(1422),
    [anon_sym_set] = ACTIONS(1422),
    [anon_sym_declare] = ACTIONS(1422),
    [anon_sym_public] = ACTIONS(1422),
    [anon_sym_private] = ACTIONS(1422),
    [anon_sym_protected] = ACTIONS(1422),
    [anon_sym_override] = ACTIONS(1422),
    [anon_sym_module] = ACTIONS(1422),
    [anon_sym_any] = ACTIONS(1422),
    [anon_sym_number] = ACTIONS(1422),
    [anon_sym_boolean] = ACTIONS(1422),
    [anon_sym_string] = ACTIONS(1422),
    [anon_sym_symbol] = ACTIONS(1422),
    [anon_sym_object] = ACTIONS(1422),
    [sym_html_comment] = ACTIONS(5),
  },
  [574] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1387),
    [sym_expression] = STATE(2090),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5803),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5803),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5585),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1387),
    [sym_subscript_expression] = STATE(1387),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3009),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5803),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1387),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(566),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1490),
    [anon_sym_export] = ACTIONS(1422),
    [anon_sym_type] = ACTIONS(1422),
    [anon_sym_namespace] = ACTIONS(1424),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_typeof] = ACTIONS(1444),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1422),
    [anon_sym_BANG] = ACTIONS(1428),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(1430),
    [anon_sym_yield] = ACTIONS(1432),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1434),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1494),
    [anon_sym_using] = ACTIONS(1438),
    [anon_sym_PLUS] = ACTIONS(1444),
    [anon_sym_DASH] = ACTIONS(1444),
    [anon_sym_SLASH] = ACTIONS(942),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(1428),
    [anon_sym_void] = ACTIONS(1444),
    [anon_sym_delete] = ACTIONS(1444),
    [anon_sym_PLUS_PLUS] = ACTIONS(1446),
    [anon_sym_DASH_DASH] = ACTIONS(1446),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(1448),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1496),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1422),
    [anon_sym_readonly] = ACTIONS(1422),
    [anon_sym_get] = ACTIONS(1422),
    [anon_sym_set] = ACTIONS(1422),
    [anon_sym_declare] = ACTIONS(1422),
    [anon_sym_public] = ACTIONS(1422),
    [anon_sym_private] = ACTIONS(1422),
    [anon_sym_protected] = ACTIONS(1422),
    [anon_sym_override] = ACTIONS(1422),
    [anon_sym_module] = ACTIONS(1422),
    [anon_sym_any] = ACTIONS(1422),
    [anon_sym_number] = ACTIONS(1422),
    [anon_sym_boolean] = ACTIONS(1422),
    [anon_sym_string] = ACTIONS(1422),
    [anon_sym_symbol] = ACTIONS(1422),
    [anon_sym_object] = ACTIONS(1422),
    [sym_html_comment] = ACTIONS(5),
  },
  [575] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1387),
    [sym_expression] = STATE(2091),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5803),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5803),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5585),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1387),
    [sym_subscript_expression] = STATE(1387),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3009),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5803),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1387),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(566),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1490),
    [anon_sym_export] = ACTIONS(1422),
    [anon_sym_type] = ACTIONS(1422),
    [anon_sym_namespace] = ACTIONS(1424),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_typeof] = ACTIONS(1444),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1422),
    [anon_sym_BANG] = ACTIONS(1428),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(1430),
    [anon_sym_yield] = ACTIONS(1432),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1434),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1494),
    [anon_sym_using] = ACTIONS(1438),
    [anon_sym_PLUS] = ACTIONS(1444),
    [anon_sym_DASH] = ACTIONS(1444),
    [anon_sym_SLASH] = ACTIONS(942),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(1428),
    [anon_sym_void] = ACTIONS(1444),
    [anon_sym_delete] = ACTIONS(1444),
    [anon_sym_PLUS_PLUS] = ACTIONS(1446),
    [anon_sym_DASH_DASH] = ACTIONS(1446),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(1448),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1496),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1422),
    [anon_sym_readonly] = ACTIONS(1422),
    [anon_sym_get] = ACTIONS(1422),
    [anon_sym_set] = ACTIONS(1422),
    [anon_sym_declare] = ACTIONS(1422),
    [anon_sym_public] = ACTIONS(1422),
    [anon_sym_private] = ACTIONS(1422),
    [anon_sym_protected] = ACTIONS(1422),
    [anon_sym_override] = ACTIONS(1422),
    [anon_sym_module] = ACTIONS(1422),
    [anon_sym_any] = ACTIONS(1422),
    [anon_sym_number] = ACTIONS(1422),
    [anon_sym_boolean] = ACTIONS(1422),
    [anon_sym_string] = ACTIONS(1422),
    [anon_sym_symbol] = ACTIONS(1422),
    [anon_sym_object] = ACTIONS(1422),
    [sym_html_comment] = ACTIONS(5),
  },
  [576] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1387),
    [sym_expression] = STATE(2092),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5803),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5803),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5585),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1387),
    [sym_subscript_expression] = STATE(1387),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3009),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5803),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1387),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(566),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1490),
    [anon_sym_export] = ACTIONS(1422),
    [anon_sym_type] = ACTIONS(1422),
    [anon_sym_namespace] = ACTIONS(1424),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_typeof] = ACTIONS(1444),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1422),
    [anon_sym_BANG] = ACTIONS(1428),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(1430),
    [anon_sym_yield] = ACTIONS(1432),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1434),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1494),
    [anon_sym_using] = ACTIONS(1438),
    [anon_sym_PLUS] = ACTIONS(1444),
    [anon_sym_DASH] = ACTIONS(1444),
    [anon_sym_SLASH] = ACTIONS(942),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(1428),
    [anon_sym_void] = ACTIONS(1444),
    [anon_sym_delete] = ACTIONS(1444),
    [anon_sym_PLUS_PLUS] = ACTIONS(1446),
    [anon_sym_DASH_DASH] = ACTIONS(1446),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(1448),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1496),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1422),
    [anon_sym_readonly] = ACTIONS(1422),
    [anon_sym_get] = ACTIONS(1422),
    [anon_sym_set] = ACTIONS(1422),
    [anon_sym_declare] = ACTIONS(1422),
    [anon_sym_public] = ACTIONS(1422),
    [anon_sym_private] = ACTIONS(1422),
    [anon_sym_protected] = ACTIONS(1422),
    [anon_sym_override] = ACTIONS(1422),
    [anon_sym_module] = ACTIONS(1422),
    [anon_sym_any] = ACTIONS(1422),
    [anon_sym_number] = ACTIONS(1422),
    [anon_sym_boolean] = ACTIONS(1422),
    [anon_sym_string] = ACTIONS(1422),
    [anon_sym_symbol] = ACTIONS(1422),
    [anon_sym_object] = ACTIONS(1422),
    [sym_html_comment] = ACTIONS(5),
  },
  [577] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1387),
    [sym_expression] = STATE(2093),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5803),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5803),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5585),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1387),
    [sym_subscript_expression] = STATE(1387),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3009),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5803),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1387),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(566),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1490),
    [anon_sym_export] = ACTIONS(1422),
    [anon_sym_type] = ACTIONS(1422),
    [anon_sym_namespace] = ACTIONS(1424),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_typeof] = ACTIONS(1444),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1422),
    [anon_sym_BANG] = ACTIONS(1428),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(1430),
    [anon_sym_yield] = ACTIONS(1432),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1434),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1494),
    [anon_sym_using] = ACTIONS(1438),
    [anon_sym_PLUS] = ACTIONS(1444),
    [anon_sym_DASH] = ACTIONS(1444),
    [anon_sym_SLASH] = ACTIONS(942),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(1428),
    [anon_sym_void] = ACTIONS(1444),
    [anon_sym_delete] = ACTIONS(1444),
    [anon_sym_PLUS_PLUS] = ACTIONS(1446),
    [anon_sym_DASH_DASH] = ACTIONS(1446),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(1448),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1496),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1422),
    [anon_sym_readonly] = ACTIONS(1422),
    [anon_sym_get] = ACTIONS(1422),
    [anon_sym_set] = ACTIONS(1422),
    [anon_sym_declare] = ACTIONS(1422),
    [anon_sym_public] = ACTIONS(1422),
    [anon_sym_private] = ACTIONS(1422),
    [anon_sym_protected] = ACTIONS(1422),
    [anon_sym_override] = ACTIONS(1422),
    [anon_sym_module] = ACTIONS(1422),
    [anon_sym_any] = ACTIONS(1422),
    [anon_sym_number] = ACTIONS(1422),
    [anon_sym_boolean] = ACTIONS(1422),
    [anon_sym_string] = ACTIONS(1422),
    [anon_sym_symbol] = ACTIONS(1422),
    [anon_sym_object] = ACTIONS(1422),
    [sym_html_comment] = ACTIONS(5),
  },
  [578] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1387),
    [sym_expression] = STATE(2094),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5803),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5803),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5585),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1387),
    [sym_subscript_expression] = STATE(1387),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3009),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5803),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1387),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(566),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1490),
    [anon_sym_export] = ACTIONS(1422),
    [anon_sym_type] = ACTIONS(1422),
    [anon_sym_namespace] = ACTIONS(1424),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_typeof] = ACTIONS(1444),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1422),
    [anon_sym_BANG] = ACTIONS(1428),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(1430),
    [anon_sym_yield] = ACTIONS(1432),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1434),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1494),
    [anon_sym_using] = ACTIONS(1438),
    [anon_sym_PLUS] = ACTIONS(1444),
    [anon_sym_DASH] = ACTIONS(1444),
    [anon_sym_SLASH] = ACTIONS(942),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(1428),
    [anon_sym_void] = ACTIONS(1444),
    [anon_sym_delete] = ACTIONS(1444),
    [anon_sym_PLUS_PLUS] = ACTIONS(1446),
    [anon_sym_DASH_DASH] = ACTIONS(1446),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(1448),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1496),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1422),
    [anon_sym_readonly] = ACTIONS(1422),
    [anon_sym_get] = ACTIONS(1422),
    [anon_sym_set] = ACTIONS(1422),
    [anon_sym_declare] = ACTIONS(1422),
    [anon_sym_public] = ACTIONS(1422),
    [anon_sym_private] = ACTIONS(1422),
    [anon_sym_protected] = ACTIONS(1422),
    [anon_sym_override] = ACTIONS(1422),
    [anon_sym_module] = ACTIONS(1422),
    [anon_sym_any] = ACTIONS(1422),
    [anon_sym_number] = ACTIONS(1422),
    [anon_sym_boolean] = ACTIONS(1422),
    [anon_sym_string] = ACTIONS(1422),
    [anon_sym_symbol] = ACTIONS(1422),
    [anon_sym_object] = ACTIONS(1422),
    [sym_html_comment] = ACTIONS(5),
  },
  [579] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1387),
    [sym_expression] = STATE(2095),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5803),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5803),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5585),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1387),
    [sym_subscript_expression] = STATE(1387),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3009),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5803),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1387),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(566),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1490),
    [anon_sym_export] = ACTIONS(1422),
    [anon_sym_type] = ACTIONS(1422),
    [anon_sym_namespace] = ACTIONS(1424),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_typeof] = ACTIONS(1444),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1422),
    [anon_sym_BANG] = ACTIONS(1428),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(1430),
    [anon_sym_yield] = ACTIONS(1432),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1434),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1494),
    [anon_sym_using] = ACTIONS(1438),
    [anon_sym_PLUS] = ACTIONS(1444),
    [anon_sym_DASH] = ACTIONS(1444),
    [anon_sym_SLASH] = ACTIONS(942),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(1428),
    [anon_sym_void] = ACTIONS(1444),
    [anon_sym_delete] = ACTIONS(1444),
    [anon_sym_PLUS_PLUS] = ACTIONS(1446),
    [anon_sym_DASH_DASH] = ACTIONS(1446),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(1448),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1496),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1422),
    [anon_sym_readonly] = ACTIONS(1422),
    [anon_sym_get] = ACTIONS(1422),
    [anon_sym_set] = ACTIONS(1422),
    [anon_sym_declare] = ACTIONS(1422),
    [anon_sym_public] = ACTIONS(1422),
    [anon_sym_private] = ACTIONS(1422),
    [anon_sym_protected] = ACTIONS(1422),
    [anon_sym_override] = ACTIONS(1422),
    [anon_sym_module] = ACTIONS(1422),
    [anon_sym_any] = ACTIONS(1422),
    [anon_sym_number] = ACTIONS(1422),
    [anon_sym_boolean] = ACTIONS(1422),
    [anon_sym_string] = ACTIONS(1422),
    [anon_sym_symbol] = ACTIONS(1422),
    [anon_sym_object] = ACTIONS(1422),
    [sym_html_comment] = ACTIONS(5),
  },
  [580] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1387),
    [sym_expression] = STATE(2096),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5803),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5803),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5585),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1387),
    [sym_subscript_expression] = STATE(1387),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3009),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5803),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1387),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(566),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1490),
    [anon_sym_export] = ACTIONS(1422),
    [anon_sym_type] = ACTIONS(1422),
    [anon_sym_namespace] = ACTIONS(1424),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_typeof] = ACTIONS(1444),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1422),
    [anon_sym_BANG] = ACTIONS(1428),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(1430),
    [anon_sym_yield] = ACTIONS(1432),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1434),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1494),
    [anon_sym_using] = ACTIONS(1438),
    [anon_sym_PLUS] = ACTIONS(1444),
    [anon_sym_DASH] = ACTIONS(1444),
    [anon_sym_SLASH] = ACTIONS(942),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(1428),
    [anon_sym_void] = ACTIONS(1444),
    [anon_sym_delete] = ACTIONS(1444),
    [anon_sym_PLUS_PLUS] = ACTIONS(1446),
    [anon_sym_DASH_DASH] = ACTIONS(1446),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(1448),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1496),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1422),
    [anon_sym_readonly] = ACTIONS(1422),
    [anon_sym_get] = ACTIONS(1422),
    [anon_sym_set] = ACTIONS(1422),
    [anon_sym_declare] = ACTIONS(1422),
    [anon_sym_public] = ACTIONS(1422),
    [anon_sym_private] = ACTIONS(1422),
    [anon_sym_protected] = ACTIONS(1422),
    [anon_sym_override] = ACTIONS(1422),
    [anon_sym_module] = ACTIONS(1422),
    [anon_sym_any] = ACTIONS(1422),
    [anon_sym_number] = ACTIONS(1422),
    [anon_sym_boolean] = ACTIONS(1422),
    [anon_sym_string] = ACTIONS(1422),
    [anon_sym_symbol] = ACTIONS(1422),
    [anon_sym_object] = ACTIONS(1422),
    [sym_html_comment] = ACTIONS(5),
  },
  [581] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1387),
    [sym_expression] = STATE(2097),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5803),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5803),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5585),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1387),
    [sym_subscript_expression] = STATE(1387),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3009),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5803),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1387),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(566),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1490),
    [anon_sym_export] = ACTIONS(1422),
    [anon_sym_type] = ACTIONS(1422),
    [anon_sym_namespace] = ACTIONS(1424),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_typeof] = ACTIONS(1444),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1422),
    [anon_sym_BANG] = ACTIONS(1428),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(1430),
    [anon_sym_yield] = ACTIONS(1432),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1434),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1494),
    [anon_sym_using] = ACTIONS(1438),
    [anon_sym_PLUS] = ACTIONS(1444),
    [anon_sym_DASH] = ACTIONS(1444),
    [anon_sym_SLASH] = ACTIONS(942),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(1428),
    [anon_sym_void] = ACTIONS(1444),
    [anon_sym_delete] = ACTIONS(1444),
    [anon_sym_PLUS_PLUS] = ACTIONS(1446),
    [anon_sym_DASH_DASH] = ACTIONS(1446),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(1448),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1496),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1422),
    [anon_sym_readonly] = ACTIONS(1422),
    [anon_sym_get] = ACTIONS(1422),
    [anon_sym_set] = ACTIONS(1422),
    [anon_sym_declare] = ACTIONS(1422),
    [anon_sym_public] = ACTIONS(1422),
    [anon_sym_private] = ACTIONS(1422),
    [anon_sym_protected] = ACTIONS(1422),
    [anon_sym_override] = ACTIONS(1422),
    [anon_sym_module] = ACTIONS(1422),
    [anon_sym_any] = ACTIONS(1422),
    [anon_sym_number] = ACTIONS(1422),
    [anon_sym_boolean] = ACTIONS(1422),
    [anon_sym_string] = ACTIONS(1422),
    [anon_sym_symbol] = ACTIONS(1422),
    [anon_sym_object] = ACTIONS(1422),
    [sym_html_comment] = ACTIONS(5),
  },
  [582] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1387),
    [sym_expression] = STATE(2099),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5803),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5803),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5585),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1387),
    [sym_subscript_expression] = STATE(1387),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3009),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5803),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1387),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(566),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1490),
    [anon_sym_export] = ACTIONS(1422),
    [anon_sym_type] = ACTIONS(1422),
    [anon_sym_namespace] = ACTIONS(1424),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_typeof] = ACTIONS(1444),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1422),
    [anon_sym_BANG] = ACTIONS(1428),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(1430),
    [anon_sym_yield] = ACTIONS(1432),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1434),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1494),
    [anon_sym_using] = ACTIONS(1438),
    [anon_sym_PLUS] = ACTIONS(1444),
    [anon_sym_DASH] = ACTIONS(1444),
    [anon_sym_SLASH] = ACTIONS(942),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(1428),
    [anon_sym_void] = ACTIONS(1444),
    [anon_sym_delete] = ACTIONS(1444),
    [anon_sym_PLUS_PLUS] = ACTIONS(1446),
    [anon_sym_DASH_DASH] = ACTIONS(1446),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(1448),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1496),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1422),
    [anon_sym_readonly] = ACTIONS(1422),
    [anon_sym_get] = ACTIONS(1422),
    [anon_sym_set] = ACTIONS(1422),
    [anon_sym_declare] = ACTIONS(1422),
    [anon_sym_public] = ACTIONS(1422),
    [anon_sym_private] = ACTIONS(1422),
    [anon_sym_protected] = ACTIONS(1422),
    [anon_sym_override] = ACTIONS(1422),
    [anon_sym_module] = ACTIONS(1422),
    [anon_sym_any] = ACTIONS(1422),
    [anon_sym_number] = ACTIONS(1422),
    [anon_sym_boolean] = ACTIONS(1422),
    [anon_sym_string] = ACTIONS(1422),
    [anon_sym_symbol] = ACTIONS(1422),
    [anon_sym_object] = ACTIONS(1422),
    [sym_html_comment] = ACTIONS(5),
  },
  [583] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1387),
    [sym_expression] = STATE(2103),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5803),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5803),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5585),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1387),
    [sym_subscript_expression] = STATE(1387),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3009),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5803),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1387),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(566),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1490),
    [anon_sym_export] = ACTIONS(1422),
    [anon_sym_type] = ACTIONS(1422),
    [anon_sym_namespace] = ACTIONS(1424),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_typeof] = ACTIONS(1444),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1422),
    [anon_sym_BANG] = ACTIONS(1428),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(1430),
    [anon_sym_yield] = ACTIONS(1432),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1434),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1494),
    [anon_sym_using] = ACTIONS(1438),
    [anon_sym_PLUS] = ACTIONS(1444),
    [anon_sym_DASH] = ACTIONS(1444),
    [anon_sym_SLASH] = ACTIONS(942),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(1428),
    [anon_sym_void] = ACTIONS(1444),
    [anon_sym_delete] = ACTIONS(1444),
    [anon_sym_PLUS_PLUS] = ACTIONS(1446),
    [anon_sym_DASH_DASH] = ACTIONS(1446),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(1448),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1496),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1422),
    [anon_sym_readonly] = ACTIONS(1422),
    [anon_sym_get] = ACTIONS(1422),
    [anon_sym_set] = ACTIONS(1422),
    [anon_sym_declare] = ACTIONS(1422),
    [anon_sym_public] = ACTIONS(1422),
    [anon_sym_private] = ACTIONS(1422),
    [anon_sym_protected] = ACTIONS(1422),
    [anon_sym_override] = ACTIONS(1422),
    [anon_sym_module] = ACTIONS(1422),
    [anon_sym_any] = ACTIONS(1422),
    [anon_sym_number] = ACTIONS(1422),
    [anon_sym_boolean] = ACTIONS(1422),
    [anon_sym_string] = ACTIONS(1422),
    [anon_sym_symbol] = ACTIONS(1422),
    [anon_sym_object] = ACTIONS(1422),
    [sym_html_comment] = ACTIONS(5),
  },
  [584] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1387),
    [sym_expression] = STATE(2104),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5803),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5803),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5585),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1387),
    [sym_subscript_expression] = STATE(1387),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3009),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5803),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1387),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(566),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1490),
    [anon_sym_export] = ACTIONS(1422),
    [anon_sym_type] = ACTIONS(1422),
    [anon_sym_namespace] = ACTIONS(1424),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_typeof] = ACTIONS(1444),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1422),
    [anon_sym_BANG] = ACTIONS(1428),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(1430),
    [anon_sym_yield] = ACTIONS(1432),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1434),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1494),
    [anon_sym_using] = ACTIONS(1438),
    [anon_sym_PLUS] = ACTIONS(1444),
    [anon_sym_DASH] = ACTIONS(1444),
    [anon_sym_SLASH] = ACTIONS(942),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(1428),
    [anon_sym_void] = ACTIONS(1444),
    [anon_sym_delete] = ACTIONS(1444),
    [anon_sym_PLUS_PLUS] = ACTIONS(1446),
    [anon_sym_DASH_DASH] = ACTIONS(1446),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(1448),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1496),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1422),
    [anon_sym_readonly] = ACTIONS(1422),
    [anon_sym_get] = ACTIONS(1422),
    [anon_sym_set] = ACTIONS(1422),
    [anon_sym_declare] = ACTIONS(1422),
    [anon_sym_public] = ACTIONS(1422),
    [anon_sym_private] = ACTIONS(1422),
    [anon_sym_protected] = ACTIONS(1422),
    [anon_sym_override] = ACTIONS(1422),
    [anon_sym_module] = ACTIONS(1422),
    [anon_sym_any] = ACTIONS(1422),
    [anon_sym_number] = ACTIONS(1422),
    [anon_sym_boolean] = ACTIONS(1422),
    [anon_sym_string] = ACTIONS(1422),
    [anon_sym_symbol] = ACTIONS(1422),
    [anon_sym_object] = ACTIONS(1422),
    [sym_html_comment] = ACTIONS(5),
  },
  [585] = {
    [sym_import] = STATE(3636),
    [sym_parenthesized_expression] = STATE(1362),
    [sym_expression] = STATE(1782),
    [sym_primary_expression] = STATE(1810),
    [sym_yield_expression] = STATE(2358),
    [sym_object] = STATE(2222),
    [sym_object_pattern] = STATE(5492),
    [sym_array] = STATE(2222),
    [sym_array_pattern] = STATE(5492),
    [sym_class] = STATE(2222),
    [sym_function_expression] = STATE(2222),
    [sym_generator_function] = STATE(2222),
    [sym_arrow_function] = STATE(2222),
    [sym__call_signature] = STATE(5821),
    [sym_call_expression] = STATE(2222),
    [sym_new_expression] = STATE(1948),
    [sym_await_expression] = STATE(2358),
    [sym_member_expression] = STATE(1362),
    [sym_subscript_expression] = STATE(1362),
    [sym_assignment_expression] = STATE(2358),
    [sym__augmented_assignment_lhs] = STATE(3025),
    [sym_augmented_assignment_expression] = STATE(2358),
    [sym__destructuring_pattern] = STATE(5492),
    [sym_ternary_expression] = STATE(2358),
    [sym_binary_expression] = STATE(2358),
    [sym_unary_expression] = STATE(2358),
    [sym_update_expression] = STATE(2358),
    [sym_string] = STATE(2222),
    [sym_template_string] = STATE(2222),
    [sym_regex] = STATE(2222),
    [sym_meta_property] = STATE(2222),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1362),
    [sym_type_assertion] = STATE(2358),
    [sym_as_expression] = STATE(2358),
    [sym_satisfies_expression] = STATE(2358),
    [sym_instantiation_expression] = STATE(2358),
    [sym_internal_module] = STATE(2358),
    [sym_type_arguments] = STATE(428),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4408),
    [sym_identifier] = ACTIONS(1468),
    [anon_sym_export] = ACTIONS(1352),
    [anon_sym_type] = ACTIONS(1352),
    [anon_sym_namespace] = ACTIONS(1354),
    [anon_sym_LBRACE] = ACTIONS(665),
    [anon_sym_typeof] = ACTIONS(21),
    [anon_sym_import] = ACTIONS(669),
    [anon_sym_let] = ACTIONS(1352),
    [anon_sym_BANG] = ACTIONS(33),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_await] = ACTIONS(45),
    [anon_sym_yield] = ACTIONS(63),
    [anon_sym_LBRACK] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(676),
    [anon_sym_async] = ACTIONS(1362),
    [anon_sym_function] = ACTIONS(680),
    [anon_sym_new] = ACTIONS(1472),
    [anon_sym_using] = ACTIONS(75),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_SLASH] = ACTIONS(77),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(33),
    [anon_sym_void] = ACTIONS(21),
    [anon_sym_delete] = ACTIONS(21),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_DQUOTE] = ACTIONS(83),
    [anon_sym_SQUOTE] = ACTIONS(85),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(87),
    [sym_number] = ACTIONS(89),
    [sym_private_property_identifier] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(93),
    [sym_true] = ACTIONS(93),
    [sym_false] = ACTIONS(93),
    [sym_null] = ACTIONS(93),
    [sym_undefined] = ACTIONS(95),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1352),
    [anon_sym_readonly] = ACTIONS(1352),
    [anon_sym_get] = ACTIONS(1352),
    [anon_sym_set] = ACTIONS(1352),
    [anon_sym_declare] = ACTIONS(1352),
    [anon_sym_public] = ACTIONS(1352),
    [anon_sym_private] = ACTIONS(1352),
    [anon_sym_protected] = ACTIONS(1352),
    [anon_sym_override] = ACTIONS(1352),
    [anon_sym_module] = ACTIONS(1352),
    [anon_sym_any] = ACTIONS(1352),
    [anon_sym_number] = ACTIONS(1352),
    [anon_sym_boolean] = ACTIONS(1352),
    [anon_sym_string] = ACTIONS(1352),
    [anon_sym_symbol] = ACTIONS(1352),
    [anon_sym_object] = ACTIONS(1352),
    [sym_html_comment] = ACTIONS(5),
  },
  [586] = {
    [sym_import] = STATE(3636),
    [sym_parenthesized_expression] = STATE(1362),
    [sym_expression] = STATE(1876),
    [sym_primary_expression] = STATE(1810),
    [sym_yield_expression] = STATE(2358),
    [sym_object] = STATE(2222),
    [sym_object_pattern] = STATE(5492),
    [sym_array] = STATE(2222),
    [sym_array_pattern] = STATE(5492),
    [sym_class] = STATE(2222),
    [sym_function_expression] = STATE(2222),
    [sym_generator_function] = STATE(2222),
    [sym_arrow_function] = STATE(2222),
    [sym__call_signature] = STATE(5821),
    [sym_call_expression] = STATE(2222),
    [sym_new_expression] = STATE(1948),
    [sym_await_expression] = STATE(2358),
    [sym_member_expression] = STATE(1362),
    [sym_subscript_expression] = STATE(1362),
    [sym_assignment_expression] = STATE(2358),
    [sym__augmented_assignment_lhs] = STATE(3025),
    [sym_augmented_assignment_expression] = STATE(2358),
    [sym__destructuring_pattern] = STATE(5492),
    [sym_ternary_expression] = STATE(2358),
    [sym_binary_expression] = STATE(2358),
    [sym_unary_expression] = STATE(2358),
    [sym_update_expression] = STATE(2358),
    [sym_string] = STATE(2222),
    [sym_template_string] = STATE(2222),
    [sym_regex] = STATE(2222),
    [sym_meta_property] = STATE(2222),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1362),
    [sym_type_assertion] = STATE(2358),
    [sym_as_expression] = STATE(2358),
    [sym_satisfies_expression] = STATE(2358),
    [sym_instantiation_expression] = STATE(2358),
    [sym_internal_module] = STATE(2358),
    [sym_type_arguments] = STATE(428),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4408),
    [sym_identifier] = ACTIONS(1468),
    [anon_sym_export] = ACTIONS(1352),
    [anon_sym_type] = ACTIONS(1352),
    [anon_sym_namespace] = ACTIONS(1354),
    [anon_sym_LBRACE] = ACTIONS(665),
    [anon_sym_typeof] = ACTIONS(21),
    [anon_sym_import] = ACTIONS(669),
    [anon_sym_let] = ACTIONS(1352),
    [anon_sym_BANG] = ACTIONS(33),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_await] = ACTIONS(45),
    [anon_sym_yield] = ACTIONS(63),
    [anon_sym_LBRACK] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(676),
    [anon_sym_async] = ACTIONS(1362),
    [anon_sym_function] = ACTIONS(680),
    [anon_sym_new] = ACTIONS(1472),
    [anon_sym_using] = ACTIONS(75),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_SLASH] = ACTIONS(77),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(33),
    [anon_sym_void] = ACTIONS(21),
    [anon_sym_delete] = ACTIONS(21),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_DQUOTE] = ACTIONS(83),
    [anon_sym_SQUOTE] = ACTIONS(85),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(87),
    [sym_number] = ACTIONS(89),
    [sym_private_property_identifier] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(93),
    [sym_true] = ACTIONS(93),
    [sym_false] = ACTIONS(93),
    [sym_null] = ACTIONS(93),
    [sym_undefined] = ACTIONS(95),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1352),
    [anon_sym_readonly] = ACTIONS(1352),
    [anon_sym_get] = ACTIONS(1352),
    [anon_sym_set] = ACTIONS(1352),
    [anon_sym_declare] = ACTIONS(1352),
    [anon_sym_public] = ACTIONS(1352),
    [anon_sym_private] = ACTIONS(1352),
    [anon_sym_protected] = ACTIONS(1352),
    [anon_sym_override] = ACTIONS(1352),
    [anon_sym_module] = ACTIONS(1352),
    [anon_sym_any] = ACTIONS(1352),
    [anon_sym_number] = ACTIONS(1352),
    [anon_sym_boolean] = ACTIONS(1352),
    [anon_sym_string] = ACTIONS(1352),
    [anon_sym_symbol] = ACTIONS(1352),
    [anon_sym_object] = ACTIONS(1352),
    [sym_html_comment] = ACTIONS(5),
  },
  [587] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1387),
    [sym_expression] = STATE(2105),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5803),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5803),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5585),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1387),
    [sym_subscript_expression] = STATE(1387),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3009),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5803),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1387),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(566),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1490),
    [anon_sym_export] = ACTIONS(1422),
    [anon_sym_type] = ACTIONS(1422),
    [anon_sym_namespace] = ACTIONS(1424),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_typeof] = ACTIONS(1444),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1422),
    [anon_sym_BANG] = ACTIONS(1428),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(1430),
    [anon_sym_yield] = ACTIONS(1432),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1434),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1494),
    [anon_sym_using] = ACTIONS(1438),
    [anon_sym_PLUS] = ACTIONS(1444),
    [anon_sym_DASH] = ACTIONS(1444),
    [anon_sym_SLASH] = ACTIONS(942),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(1428),
    [anon_sym_void] = ACTIONS(1444),
    [anon_sym_delete] = ACTIONS(1444),
    [anon_sym_PLUS_PLUS] = ACTIONS(1446),
    [anon_sym_DASH_DASH] = ACTIONS(1446),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(1448),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1496),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1422),
    [anon_sym_readonly] = ACTIONS(1422),
    [anon_sym_get] = ACTIONS(1422),
    [anon_sym_set] = ACTIONS(1422),
    [anon_sym_declare] = ACTIONS(1422),
    [anon_sym_public] = ACTIONS(1422),
    [anon_sym_private] = ACTIONS(1422),
    [anon_sym_protected] = ACTIONS(1422),
    [anon_sym_override] = ACTIONS(1422),
    [anon_sym_module] = ACTIONS(1422),
    [anon_sym_any] = ACTIONS(1422),
    [anon_sym_number] = ACTIONS(1422),
    [anon_sym_boolean] = ACTIONS(1422),
    [anon_sym_string] = ACTIONS(1422),
    [anon_sym_symbol] = ACTIONS(1422),
    [anon_sym_object] = ACTIONS(1422),
    [sym_html_comment] = ACTIONS(5),
  },
  [588] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1387),
    [sym_expression] = STATE(2106),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5803),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5803),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5585),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1387),
    [sym_subscript_expression] = STATE(1387),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3009),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5803),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1387),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(566),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1490),
    [anon_sym_export] = ACTIONS(1422),
    [anon_sym_type] = ACTIONS(1422),
    [anon_sym_namespace] = ACTIONS(1424),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_typeof] = ACTIONS(1444),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1422),
    [anon_sym_BANG] = ACTIONS(1428),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(1430),
    [anon_sym_yield] = ACTIONS(1432),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1434),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1494),
    [anon_sym_using] = ACTIONS(1438),
    [anon_sym_PLUS] = ACTIONS(1444),
    [anon_sym_DASH] = ACTIONS(1444),
    [anon_sym_SLASH] = ACTIONS(942),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(1428),
    [anon_sym_void] = ACTIONS(1444),
    [anon_sym_delete] = ACTIONS(1444),
    [anon_sym_PLUS_PLUS] = ACTIONS(1446),
    [anon_sym_DASH_DASH] = ACTIONS(1446),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(1448),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1496),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1422),
    [anon_sym_readonly] = ACTIONS(1422),
    [anon_sym_get] = ACTIONS(1422),
    [anon_sym_set] = ACTIONS(1422),
    [anon_sym_declare] = ACTIONS(1422),
    [anon_sym_public] = ACTIONS(1422),
    [anon_sym_private] = ACTIONS(1422),
    [anon_sym_protected] = ACTIONS(1422),
    [anon_sym_override] = ACTIONS(1422),
    [anon_sym_module] = ACTIONS(1422),
    [anon_sym_any] = ACTIONS(1422),
    [anon_sym_number] = ACTIONS(1422),
    [anon_sym_boolean] = ACTIONS(1422),
    [anon_sym_string] = ACTIONS(1422),
    [anon_sym_symbol] = ACTIONS(1422),
    [anon_sym_object] = ACTIONS(1422),
    [sym_html_comment] = ACTIONS(5),
  },
  [589] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1387),
    [sym_expression] = STATE(2107),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5803),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5803),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5585),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1387),
    [sym_subscript_expression] = STATE(1387),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3009),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5803),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1387),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(566),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1490),
    [anon_sym_export] = ACTIONS(1422),
    [anon_sym_type] = ACTIONS(1422),
    [anon_sym_namespace] = ACTIONS(1424),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_typeof] = ACTIONS(1444),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1422),
    [anon_sym_BANG] = ACTIONS(1428),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(1430),
    [anon_sym_yield] = ACTIONS(1432),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1434),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1494),
    [anon_sym_using] = ACTIONS(1438),
    [anon_sym_PLUS] = ACTIONS(1444),
    [anon_sym_DASH] = ACTIONS(1444),
    [anon_sym_SLASH] = ACTIONS(942),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(1428),
    [anon_sym_void] = ACTIONS(1444),
    [anon_sym_delete] = ACTIONS(1444),
    [anon_sym_PLUS_PLUS] = ACTIONS(1446),
    [anon_sym_DASH_DASH] = ACTIONS(1446),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(1448),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1496),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1422),
    [anon_sym_readonly] = ACTIONS(1422),
    [anon_sym_get] = ACTIONS(1422),
    [anon_sym_set] = ACTIONS(1422),
    [anon_sym_declare] = ACTIONS(1422),
    [anon_sym_public] = ACTIONS(1422),
    [anon_sym_private] = ACTIONS(1422),
    [anon_sym_protected] = ACTIONS(1422),
    [anon_sym_override] = ACTIONS(1422),
    [anon_sym_module] = ACTIONS(1422),
    [anon_sym_any] = ACTIONS(1422),
    [anon_sym_number] = ACTIONS(1422),
    [anon_sym_boolean] = ACTIONS(1422),
    [anon_sym_string] = ACTIONS(1422),
    [anon_sym_symbol] = ACTIONS(1422),
    [anon_sym_object] = ACTIONS(1422),
    [sym_html_comment] = ACTIONS(5),
  },
  [590] = {
    [sym_namespace_export] = STATE(5206),
    [sym_export_clause] = STATE(4427),
    [sym_declaration] = STATE(919),
    [sym_variable_declaration] = STATE(831),
    [sym_lexical_declaration] = STATE(831),
    [sym_class_declaration] = STATE(831),
    [sym_function_declaration] = STATE(831),
    [sym_generator_function_declaration] = STATE(831),
    [sym_decorator] = STATE(1344),
    [sym_function_signature] = STATE(831),
    [sym_ambient_declaration] = STATE(831),
    [sym_abstract_class_declaration] = STATE(831),
    [sym_module] = STATE(831),
    [sym_internal_module] = STATE(824),
    [sym_import_alias] = STATE(831),
    [sym_interface_declaration] = STATE(831),
    [sym_enum_declaration] = STATE(831),
    [sym_type_alias_declaration] = STATE(831),
    [aux_sym_export_statement_repeat1] = STATE(4301),
    [aux_sym_object_repeat1] = STATE(4810),
    [aux_sym_object_pattern_repeat1] = STATE(4815),
    [anon_sym_STAR] = ACTIONS(2127),
    [anon_sym_default] = ACTIONS(2129),
    [anon_sym_type] = ACTIONS(2131),
    [anon_sym_EQ] = ACTIONS(2133),
    [anon_sym_as] = ACTIONS(2135),
    [anon_sym_namespace] = ACTIONS(2137),
    [anon_sym_LBRACE] = ACTIONS(2139),
    [anon_sym_COMMA] = ACTIONS(154),
    [anon_sym_RBRACE] = ACTIONS(692),
    [anon_sym_import] = ACTIONS(2141),
    [anon_sym_var] = ACTIONS(2143),
    [anon_sym_let] = ACTIONS(2145),
    [anon_sym_const] = ACTIONS(2147),
    [anon_sym_BANG] = ACTIONS(120),
    [anon_sym_LPAREN] = ACTIONS(2149),
    [anon_sym_SEMI] = ACTIONS(154),
    [anon_sym_in] = ACTIONS(120),
    [anon_sym_COLON] = ACTIONS(671),
    [anon_sym_LBRACK] = ACTIONS(154),
    [anon_sym_DOT] = ACTIONS(154),
    [anon_sym_class] = ACTIONS(2152),
    [anon_sym_async] = ACTIONS(2154),
    [anon_sym_function] = ACTIONS(2156),
    [anon_sym_EQ_GT] = ACTIONS(682),
    [anon_sym_QMARK_DOT] = ACTIONS(154),
    [anon_sym_PLUS_EQ] = ACTIONS(160),
    [anon_sym_DASH_EQ] = ACTIONS(160),
    [anon_sym_STAR_EQ] = ACTIONS(160),
    [anon_sym_SLASH_EQ] = ACTIONS(160),
    [anon_sym_PERCENT_EQ] = ACTIONS(160),
    [anon_sym_CARET_EQ] = ACTIONS(160),
    [anon_sym_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_LT_LT_EQ] = ACTIONS(160),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(160),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP] = ACTIONS(120),
    [anon_sym_PIPE_PIPE] = ACTIONS(120),
    [anon_sym_GT_GT] = ACTIONS(120),
    [anon_sym_GT_GT_GT] = ACTIONS(120),
    [anon_sym_LT_LT] = ACTIONS(120),
    [anon_sym_AMP] = ACTIONS(120),
    [anon_sym_CARET] = ACTIONS(120),
    [anon_sym_PIPE] = ACTIONS(120),
    [anon_sym_PLUS] = ACTIONS(120),
    [anon_sym_DASH] = ACTIONS(120),
    [anon_sym_SLASH] = ACTIONS(120),
    [anon_sym_PERCENT] = ACTIONS(120),
    [anon_sym_STAR_STAR] = ACTIONS(120),
    [anon_sym_LT] = ACTIONS(2158),
    [anon_sym_LT_EQ] = ACTIONS(154),
    [anon_sym_EQ_EQ] = ACTIONS(120),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(154),
    [anon_sym_BANG_EQ] = ACTIONS(120),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(154),
    [anon_sym_GT_EQ] = ACTIONS(154),
    [anon_sym_GT] = ACTIONS(120),
    [anon_sym_QMARK_QMARK] = ACTIONS(120),
    [anon_sym_instanceof] = ACTIONS(154),
    [anon_sym_PLUS_PLUS] = ACTIONS(154),
    [anon_sym_DASH_DASH] = ACTIONS(154),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(154),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_QMARK] = ACTIONS(690),
    [anon_sym_declare] = ACTIONS(2161),
    [anon_sym_module] = ACTIONS(2163),
    [anon_sym_abstract] = ACTIONS(2165),
    [anon_sym_satisfies] = ACTIONS(154),
    [anon_sym_interface] = ACTIONS(2167),
    [anon_sym_enum] = ACTIONS(2169),
    [sym__automatic_semicolon] = ACTIONS(154),
    [sym__ternary_qmark] = ACTIONS(154),
    [sym_html_comment] = ACTIONS(5),
  },
  [591] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1456),
    [sym_expression] = STATE(2404),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5815),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5815),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5755),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1456),
    [sym_subscript_expression] = STATE(1456),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3029),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5815),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1456),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(594),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1506),
    [anon_sym_export] = ACTIONS(1234),
    [anon_sym_type] = ACTIONS(1234),
    [anon_sym_namespace] = ACTIONS(1236),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_typeof] = ACTIONS(1256),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1234),
    [anon_sym_BANG] = ACTIONS(1240),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(1242),
    [anon_sym_yield] = ACTIONS(1244),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1246),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1510),
    [anon_sym_using] = ACTIONS(1250),
    [anon_sym_PLUS] = ACTIONS(1256),
    [anon_sym_DASH] = ACTIONS(1256),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(1240),
    [anon_sym_void] = ACTIONS(1256),
    [anon_sym_delete] = ACTIONS(1256),
    [anon_sym_PLUS_PLUS] = ACTIONS(1258),
    [anon_sym_DASH_DASH] = ACTIONS(1258),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(2171),
    [sym_private_property_identifier] = ACTIONS(1260),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1512),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1234),
    [anon_sym_readonly] = ACTIONS(1234),
    [anon_sym_get] = ACTIONS(1234),
    [anon_sym_set] = ACTIONS(1234),
    [anon_sym_declare] = ACTIONS(1234),
    [anon_sym_public] = ACTIONS(1234),
    [anon_sym_private] = ACTIONS(1234),
    [anon_sym_protected] = ACTIONS(1234),
    [anon_sym_override] = ACTIONS(1234),
    [anon_sym_module] = ACTIONS(1234),
    [anon_sym_any] = ACTIONS(1234),
    [anon_sym_number] = ACTIONS(1234),
    [anon_sym_boolean] = ACTIONS(1234),
    [anon_sym_string] = ACTIONS(1234),
    [anon_sym_symbol] = ACTIONS(1234),
    [anon_sym_object] = ACTIONS(1234),
    [sym_html_comment] = ACTIONS(5),
  },
  [592] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1464),
    [sym_expression] = STATE(2644),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5615),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5615),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5800),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1464),
    [sym_subscript_expression] = STATE(1464),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3013),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5615),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1464),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(539),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(2239),
    [anon_sym_export] = ACTIONS(2241),
    [anon_sym_type] = ACTIONS(2241),
    [anon_sym_namespace] = ACTIONS(2243),
    [anon_sym_LBRACE] = ACTIONS(808),
    [anon_sym_typeof] = ACTIONS(179),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(2241),
    [anon_sym_BANG] = ACTIONS(175),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(140),
    [anon_sym_yield] = ACTIONS(142),
    [anon_sym_LBRACK] = ACTIONS(812),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(2245),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(2247),
    [anon_sym_using] = ACTIONS(158),
    [anon_sym_PLUS] = ACTIONS(179),
    [anon_sym_DASH] = ACTIONS(179),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(175),
    [anon_sym_void] = ACTIONS(179),
    [anon_sym_delete] = ACTIONS(179),
    [anon_sym_PLUS_PLUS] = ACTIONS(686),
    [anon_sym_DASH_DASH] = ACTIONS(686),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(192),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(2249),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(2241),
    [anon_sym_readonly] = ACTIONS(2241),
    [anon_sym_get] = ACTIONS(2241),
    [anon_sym_set] = ACTIONS(2241),
    [anon_sym_declare] = ACTIONS(2241),
    [anon_sym_public] = ACTIONS(2241),
    [anon_sym_private] = ACTIONS(2241),
    [anon_sym_protected] = ACTIONS(2241),
    [anon_sym_override] = ACTIONS(2241),
    [anon_sym_module] = ACTIONS(2241),
    [anon_sym_any] = ACTIONS(2241),
    [anon_sym_number] = ACTIONS(2241),
    [anon_sym_boolean] = ACTIONS(2241),
    [anon_sym_string] = ACTIONS(2241),
    [anon_sym_symbol] = ACTIONS(2241),
    [anon_sym_object] = ACTIONS(2241),
    [sym_html_comment] = ACTIONS(5),
  },
  [593] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1456),
    [sym_expression] = STATE(2589),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5815),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5815),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5755),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1456),
    [sym_subscript_expression] = STATE(1456),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3029),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5815),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1456),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(594),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1506),
    [anon_sym_export] = ACTIONS(1234),
    [anon_sym_type] = ACTIONS(1234),
    [anon_sym_namespace] = ACTIONS(1236),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_typeof] = ACTIONS(1256),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1234),
    [anon_sym_BANG] = ACTIONS(1240),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(1242),
    [anon_sym_yield] = ACTIONS(1244),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1246),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1510),
    [anon_sym_using] = ACTIONS(1250),
    [anon_sym_PLUS] = ACTIONS(1256),
    [anon_sym_DASH] = ACTIONS(1256),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(1240),
    [anon_sym_void] = ACTIONS(1256),
    [anon_sym_delete] = ACTIONS(1256),
    [anon_sym_PLUS_PLUS] = ACTIONS(1258),
    [anon_sym_DASH_DASH] = ACTIONS(1258),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(1260),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1512),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1234),
    [anon_sym_readonly] = ACTIONS(1234),
    [anon_sym_get] = ACTIONS(1234),
    [anon_sym_set] = ACTIONS(1234),
    [anon_sym_declare] = ACTIONS(1234),
    [anon_sym_public] = ACTIONS(1234),
    [anon_sym_private] = ACTIONS(1234),
    [anon_sym_protected] = ACTIONS(1234),
    [anon_sym_override] = ACTIONS(1234),
    [anon_sym_module] = ACTIONS(1234),
    [anon_sym_any] = ACTIONS(1234),
    [anon_sym_number] = ACTIONS(1234),
    [anon_sym_boolean] = ACTIONS(1234),
    [anon_sym_string] = ACTIONS(1234),
    [anon_sym_symbol] = ACTIONS(1234),
    [anon_sym_object] = ACTIONS(1234),
    [sym_html_comment] = ACTIONS(5),
  },
  [594] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1456),
    [sym_expression] = STATE(2458),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5815),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5815),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5755),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1456),
    [sym_subscript_expression] = STATE(1456),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3029),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5815),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1456),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(594),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1506),
    [anon_sym_export] = ACTIONS(1234),
    [anon_sym_type] = ACTIONS(1234),
    [anon_sym_namespace] = ACTIONS(1236),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_typeof] = ACTIONS(1256),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1234),
    [anon_sym_BANG] = ACTIONS(1240),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(1242),
    [anon_sym_yield] = ACTIONS(1244),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1246),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1510),
    [anon_sym_using] = ACTIONS(1250),
    [anon_sym_PLUS] = ACTIONS(1256),
    [anon_sym_DASH] = ACTIONS(1256),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(1240),
    [anon_sym_void] = ACTIONS(1256),
    [anon_sym_delete] = ACTIONS(1256),
    [anon_sym_PLUS_PLUS] = ACTIONS(1258),
    [anon_sym_DASH_DASH] = ACTIONS(1258),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(1260),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1512),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1234),
    [anon_sym_readonly] = ACTIONS(1234),
    [anon_sym_get] = ACTIONS(1234),
    [anon_sym_set] = ACTIONS(1234),
    [anon_sym_declare] = ACTIONS(1234),
    [anon_sym_public] = ACTIONS(1234),
    [anon_sym_private] = ACTIONS(1234),
    [anon_sym_protected] = ACTIONS(1234),
    [anon_sym_override] = ACTIONS(1234),
    [anon_sym_module] = ACTIONS(1234),
    [anon_sym_any] = ACTIONS(1234),
    [anon_sym_number] = ACTIONS(1234),
    [anon_sym_boolean] = ACTIONS(1234),
    [anon_sym_string] = ACTIONS(1234),
    [anon_sym_symbol] = ACTIONS(1234),
    [anon_sym_object] = ACTIONS(1234),
    [sym_html_comment] = ACTIONS(5),
  },
  [595] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1456),
    [sym_expression] = STATE(2468),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5815),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5815),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5755),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1456),
    [sym_subscript_expression] = STATE(1456),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3029),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5815),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1456),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(594),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1506),
    [anon_sym_export] = ACTIONS(1234),
    [anon_sym_type] = ACTIONS(1234),
    [anon_sym_namespace] = ACTIONS(1236),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_typeof] = ACTIONS(1256),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1234),
    [anon_sym_BANG] = ACTIONS(1240),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(1242),
    [anon_sym_yield] = ACTIONS(1244),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1246),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1510),
    [anon_sym_using] = ACTIONS(1250),
    [anon_sym_PLUS] = ACTIONS(1256),
    [anon_sym_DASH] = ACTIONS(1256),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(1240),
    [anon_sym_void] = ACTIONS(1256),
    [anon_sym_delete] = ACTIONS(1256),
    [anon_sym_PLUS_PLUS] = ACTIONS(1258),
    [anon_sym_DASH_DASH] = ACTIONS(1258),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(1260),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1512),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1234),
    [anon_sym_readonly] = ACTIONS(1234),
    [anon_sym_get] = ACTIONS(1234),
    [anon_sym_set] = ACTIONS(1234),
    [anon_sym_declare] = ACTIONS(1234),
    [anon_sym_public] = ACTIONS(1234),
    [anon_sym_private] = ACTIONS(1234),
    [anon_sym_protected] = ACTIONS(1234),
    [anon_sym_override] = ACTIONS(1234),
    [anon_sym_module] = ACTIONS(1234),
    [anon_sym_any] = ACTIONS(1234),
    [anon_sym_number] = ACTIONS(1234),
    [anon_sym_boolean] = ACTIONS(1234),
    [anon_sym_string] = ACTIONS(1234),
    [anon_sym_symbol] = ACTIONS(1234),
    [anon_sym_object] = ACTIONS(1234),
    [sym_html_comment] = ACTIONS(5),
  },
  [596] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1456),
    [sym_expression] = STATE(2469),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5815),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5815),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5755),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1456),
    [sym_subscript_expression] = STATE(1456),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3029),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5815),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1456),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(594),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1506),
    [anon_sym_export] = ACTIONS(1234),
    [anon_sym_type] = ACTIONS(1234),
    [anon_sym_namespace] = ACTIONS(1236),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_typeof] = ACTIONS(1256),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1234),
    [anon_sym_BANG] = ACTIONS(1240),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(1242),
    [anon_sym_yield] = ACTIONS(1244),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1246),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1510),
    [anon_sym_using] = ACTIONS(1250),
    [anon_sym_PLUS] = ACTIONS(1256),
    [anon_sym_DASH] = ACTIONS(1256),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(1240),
    [anon_sym_void] = ACTIONS(1256),
    [anon_sym_delete] = ACTIONS(1256),
    [anon_sym_PLUS_PLUS] = ACTIONS(1258),
    [anon_sym_DASH_DASH] = ACTIONS(1258),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(1260),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1512),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1234),
    [anon_sym_readonly] = ACTIONS(1234),
    [anon_sym_get] = ACTIONS(1234),
    [anon_sym_set] = ACTIONS(1234),
    [anon_sym_declare] = ACTIONS(1234),
    [anon_sym_public] = ACTIONS(1234),
    [anon_sym_private] = ACTIONS(1234),
    [anon_sym_protected] = ACTIONS(1234),
    [anon_sym_override] = ACTIONS(1234),
    [anon_sym_module] = ACTIONS(1234),
    [anon_sym_any] = ACTIONS(1234),
    [anon_sym_number] = ACTIONS(1234),
    [anon_sym_boolean] = ACTIONS(1234),
    [anon_sym_string] = ACTIONS(1234),
    [anon_sym_symbol] = ACTIONS(1234),
    [anon_sym_object] = ACTIONS(1234),
    [sym_html_comment] = ACTIONS(5),
  },
  [597] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1456),
    [sym_expression] = STATE(2471),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5815),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5815),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5755),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1456),
    [sym_subscript_expression] = STATE(1456),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3029),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5815),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1456),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(594),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1506),
    [anon_sym_export] = ACTIONS(1234),
    [anon_sym_type] = ACTIONS(1234),
    [anon_sym_namespace] = ACTIONS(1236),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_typeof] = ACTIONS(1256),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1234),
    [anon_sym_BANG] = ACTIONS(1240),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(1242),
    [anon_sym_yield] = ACTIONS(1244),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1246),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1510),
    [anon_sym_using] = ACTIONS(1250),
    [anon_sym_PLUS] = ACTIONS(1256),
    [anon_sym_DASH] = ACTIONS(1256),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(1240),
    [anon_sym_void] = ACTIONS(1256),
    [anon_sym_delete] = ACTIONS(1256),
    [anon_sym_PLUS_PLUS] = ACTIONS(1258),
    [anon_sym_DASH_DASH] = ACTIONS(1258),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(1260),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1512),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1234),
    [anon_sym_readonly] = ACTIONS(1234),
    [anon_sym_get] = ACTIONS(1234),
    [anon_sym_set] = ACTIONS(1234),
    [anon_sym_declare] = ACTIONS(1234),
    [anon_sym_public] = ACTIONS(1234),
    [anon_sym_private] = ACTIONS(1234),
    [anon_sym_protected] = ACTIONS(1234),
    [anon_sym_override] = ACTIONS(1234),
    [anon_sym_module] = ACTIONS(1234),
    [anon_sym_any] = ACTIONS(1234),
    [anon_sym_number] = ACTIONS(1234),
    [anon_sym_boolean] = ACTIONS(1234),
    [anon_sym_string] = ACTIONS(1234),
    [anon_sym_symbol] = ACTIONS(1234),
    [anon_sym_object] = ACTIONS(1234),
    [sym_html_comment] = ACTIONS(5),
  },
  [598] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1456),
    [sym_expression] = STATE(2479),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5815),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5815),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5755),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1456),
    [sym_subscript_expression] = STATE(1456),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3029),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5815),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1456),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(594),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1506),
    [anon_sym_export] = ACTIONS(1234),
    [anon_sym_type] = ACTIONS(1234),
    [anon_sym_namespace] = ACTIONS(1236),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_typeof] = ACTIONS(1256),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1234),
    [anon_sym_BANG] = ACTIONS(1240),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(1242),
    [anon_sym_yield] = ACTIONS(1244),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1246),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1510),
    [anon_sym_using] = ACTIONS(1250),
    [anon_sym_PLUS] = ACTIONS(1256),
    [anon_sym_DASH] = ACTIONS(1256),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(1240),
    [anon_sym_void] = ACTIONS(1256),
    [anon_sym_delete] = ACTIONS(1256),
    [anon_sym_PLUS_PLUS] = ACTIONS(1258),
    [anon_sym_DASH_DASH] = ACTIONS(1258),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(1260),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1512),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1234),
    [anon_sym_readonly] = ACTIONS(1234),
    [anon_sym_get] = ACTIONS(1234),
    [anon_sym_set] = ACTIONS(1234),
    [anon_sym_declare] = ACTIONS(1234),
    [anon_sym_public] = ACTIONS(1234),
    [anon_sym_private] = ACTIONS(1234),
    [anon_sym_protected] = ACTIONS(1234),
    [anon_sym_override] = ACTIONS(1234),
    [anon_sym_module] = ACTIONS(1234),
    [anon_sym_any] = ACTIONS(1234),
    [anon_sym_number] = ACTIONS(1234),
    [anon_sym_boolean] = ACTIONS(1234),
    [anon_sym_string] = ACTIONS(1234),
    [anon_sym_symbol] = ACTIONS(1234),
    [anon_sym_object] = ACTIONS(1234),
    [sym_html_comment] = ACTIONS(5),
  },
  [599] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1456),
    [sym_expression] = STATE(2481),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5815),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5815),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5755),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1456),
    [sym_subscript_expression] = STATE(1456),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3029),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5815),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1456),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(594),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1506),
    [anon_sym_export] = ACTIONS(1234),
    [anon_sym_type] = ACTIONS(1234),
    [anon_sym_namespace] = ACTIONS(1236),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_typeof] = ACTIONS(1256),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1234),
    [anon_sym_BANG] = ACTIONS(1240),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(1242),
    [anon_sym_yield] = ACTIONS(1244),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1246),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1510),
    [anon_sym_using] = ACTIONS(1250),
    [anon_sym_PLUS] = ACTIONS(1256),
    [anon_sym_DASH] = ACTIONS(1256),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(1240),
    [anon_sym_void] = ACTIONS(1256),
    [anon_sym_delete] = ACTIONS(1256),
    [anon_sym_PLUS_PLUS] = ACTIONS(1258),
    [anon_sym_DASH_DASH] = ACTIONS(1258),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(1260),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1512),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1234),
    [anon_sym_readonly] = ACTIONS(1234),
    [anon_sym_get] = ACTIONS(1234),
    [anon_sym_set] = ACTIONS(1234),
    [anon_sym_declare] = ACTIONS(1234),
    [anon_sym_public] = ACTIONS(1234),
    [anon_sym_private] = ACTIONS(1234),
    [anon_sym_protected] = ACTIONS(1234),
    [anon_sym_override] = ACTIONS(1234),
    [anon_sym_module] = ACTIONS(1234),
    [anon_sym_any] = ACTIONS(1234),
    [anon_sym_number] = ACTIONS(1234),
    [anon_sym_boolean] = ACTIONS(1234),
    [anon_sym_string] = ACTIONS(1234),
    [anon_sym_symbol] = ACTIONS(1234),
    [anon_sym_object] = ACTIONS(1234),
    [sym_html_comment] = ACTIONS(5),
  },
  [600] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1456),
    [sym_expression] = STATE(2482),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5815),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5815),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5755),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1456),
    [sym_subscript_expression] = STATE(1456),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3029),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5815),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1456),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(594),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1506),
    [anon_sym_export] = ACTIONS(1234),
    [anon_sym_type] = ACTIONS(1234),
    [anon_sym_namespace] = ACTIONS(1236),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_typeof] = ACTIONS(1256),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1234),
    [anon_sym_BANG] = ACTIONS(1240),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(1242),
    [anon_sym_yield] = ACTIONS(1244),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1246),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1510),
    [anon_sym_using] = ACTIONS(1250),
    [anon_sym_PLUS] = ACTIONS(1256),
    [anon_sym_DASH] = ACTIONS(1256),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(1240),
    [anon_sym_void] = ACTIONS(1256),
    [anon_sym_delete] = ACTIONS(1256),
    [anon_sym_PLUS_PLUS] = ACTIONS(1258),
    [anon_sym_DASH_DASH] = ACTIONS(1258),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(1260),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1512),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1234),
    [anon_sym_readonly] = ACTIONS(1234),
    [anon_sym_get] = ACTIONS(1234),
    [anon_sym_set] = ACTIONS(1234),
    [anon_sym_declare] = ACTIONS(1234),
    [anon_sym_public] = ACTIONS(1234),
    [anon_sym_private] = ACTIONS(1234),
    [anon_sym_protected] = ACTIONS(1234),
    [anon_sym_override] = ACTIONS(1234),
    [anon_sym_module] = ACTIONS(1234),
    [anon_sym_any] = ACTIONS(1234),
    [anon_sym_number] = ACTIONS(1234),
    [anon_sym_boolean] = ACTIONS(1234),
    [anon_sym_string] = ACTIONS(1234),
    [anon_sym_symbol] = ACTIONS(1234),
    [anon_sym_object] = ACTIONS(1234),
    [sym_html_comment] = ACTIONS(5),
  },
  [601] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1456),
    [sym_expression] = STATE(2483),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5815),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5815),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5755),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1456),
    [sym_subscript_expression] = STATE(1456),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3029),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5815),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1456),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(594),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1506),
    [anon_sym_export] = ACTIONS(1234),
    [anon_sym_type] = ACTIONS(1234),
    [anon_sym_namespace] = ACTIONS(1236),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_typeof] = ACTIONS(1256),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1234),
    [anon_sym_BANG] = ACTIONS(1240),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(1242),
    [anon_sym_yield] = ACTIONS(1244),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1246),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1510),
    [anon_sym_using] = ACTIONS(1250),
    [anon_sym_PLUS] = ACTIONS(1256),
    [anon_sym_DASH] = ACTIONS(1256),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(1240),
    [anon_sym_void] = ACTIONS(1256),
    [anon_sym_delete] = ACTIONS(1256),
    [anon_sym_PLUS_PLUS] = ACTIONS(1258),
    [anon_sym_DASH_DASH] = ACTIONS(1258),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(1260),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1512),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1234),
    [anon_sym_readonly] = ACTIONS(1234),
    [anon_sym_get] = ACTIONS(1234),
    [anon_sym_set] = ACTIONS(1234),
    [anon_sym_declare] = ACTIONS(1234),
    [anon_sym_public] = ACTIONS(1234),
    [anon_sym_private] = ACTIONS(1234),
    [anon_sym_protected] = ACTIONS(1234),
    [anon_sym_override] = ACTIONS(1234),
    [anon_sym_module] = ACTIONS(1234),
    [anon_sym_any] = ACTIONS(1234),
    [anon_sym_number] = ACTIONS(1234),
    [anon_sym_boolean] = ACTIONS(1234),
    [anon_sym_string] = ACTIONS(1234),
    [anon_sym_symbol] = ACTIONS(1234),
    [anon_sym_object] = ACTIONS(1234),
    [sym_html_comment] = ACTIONS(5),
  },
  [602] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1456),
    [sym_expression] = STATE(2512),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5815),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5815),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5755),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1456),
    [sym_subscript_expression] = STATE(1456),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3029),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5815),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1456),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(594),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1506),
    [anon_sym_export] = ACTIONS(1234),
    [anon_sym_type] = ACTIONS(1234),
    [anon_sym_namespace] = ACTIONS(1236),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_typeof] = ACTIONS(1256),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1234),
    [anon_sym_BANG] = ACTIONS(1240),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(1242),
    [anon_sym_yield] = ACTIONS(1244),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1246),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1510),
    [anon_sym_using] = ACTIONS(1250),
    [anon_sym_PLUS] = ACTIONS(1256),
    [anon_sym_DASH] = ACTIONS(1256),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(1240),
    [anon_sym_void] = ACTIONS(1256),
    [anon_sym_delete] = ACTIONS(1256),
    [anon_sym_PLUS_PLUS] = ACTIONS(1258),
    [anon_sym_DASH_DASH] = ACTIONS(1258),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(1260),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1512),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1234),
    [anon_sym_readonly] = ACTIONS(1234),
    [anon_sym_get] = ACTIONS(1234),
    [anon_sym_set] = ACTIONS(1234),
    [anon_sym_declare] = ACTIONS(1234),
    [anon_sym_public] = ACTIONS(1234),
    [anon_sym_private] = ACTIONS(1234),
    [anon_sym_protected] = ACTIONS(1234),
    [anon_sym_override] = ACTIONS(1234),
    [anon_sym_module] = ACTIONS(1234),
    [anon_sym_any] = ACTIONS(1234),
    [anon_sym_number] = ACTIONS(1234),
    [anon_sym_boolean] = ACTIONS(1234),
    [anon_sym_string] = ACTIONS(1234),
    [anon_sym_symbol] = ACTIONS(1234),
    [anon_sym_object] = ACTIONS(1234),
    [sym_html_comment] = ACTIONS(5),
  },
  [603] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1456),
    [sym_expression] = STATE(2518),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5815),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5815),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5755),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1456),
    [sym_subscript_expression] = STATE(1456),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3029),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5815),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1456),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(594),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1506),
    [anon_sym_export] = ACTIONS(1234),
    [anon_sym_type] = ACTIONS(1234),
    [anon_sym_namespace] = ACTIONS(1236),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_typeof] = ACTIONS(1256),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1234),
    [anon_sym_BANG] = ACTIONS(1240),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(1242),
    [anon_sym_yield] = ACTIONS(1244),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1246),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1510),
    [anon_sym_using] = ACTIONS(1250),
    [anon_sym_PLUS] = ACTIONS(1256),
    [anon_sym_DASH] = ACTIONS(1256),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(1240),
    [anon_sym_void] = ACTIONS(1256),
    [anon_sym_delete] = ACTIONS(1256),
    [anon_sym_PLUS_PLUS] = ACTIONS(1258),
    [anon_sym_DASH_DASH] = ACTIONS(1258),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(1260),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1512),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1234),
    [anon_sym_readonly] = ACTIONS(1234),
    [anon_sym_get] = ACTIONS(1234),
    [anon_sym_set] = ACTIONS(1234),
    [anon_sym_declare] = ACTIONS(1234),
    [anon_sym_public] = ACTIONS(1234),
    [anon_sym_private] = ACTIONS(1234),
    [anon_sym_protected] = ACTIONS(1234),
    [anon_sym_override] = ACTIONS(1234),
    [anon_sym_module] = ACTIONS(1234),
    [anon_sym_any] = ACTIONS(1234),
    [anon_sym_number] = ACTIONS(1234),
    [anon_sym_boolean] = ACTIONS(1234),
    [anon_sym_string] = ACTIONS(1234),
    [anon_sym_symbol] = ACTIONS(1234),
    [anon_sym_object] = ACTIONS(1234),
    [sym_html_comment] = ACTIONS(5),
  },
  [604] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1456),
    [sym_expression] = STATE(2519),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5815),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5815),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5755),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1456),
    [sym_subscript_expression] = STATE(1456),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3029),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5815),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1456),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(594),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1506),
    [anon_sym_export] = ACTIONS(1234),
    [anon_sym_type] = ACTIONS(1234),
    [anon_sym_namespace] = ACTIONS(1236),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_typeof] = ACTIONS(1256),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1234),
    [anon_sym_BANG] = ACTIONS(1240),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(1242),
    [anon_sym_yield] = ACTIONS(1244),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1246),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1510),
    [anon_sym_using] = ACTIONS(1250),
    [anon_sym_PLUS] = ACTIONS(1256),
    [anon_sym_DASH] = ACTIONS(1256),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(1240),
    [anon_sym_void] = ACTIONS(1256),
    [anon_sym_delete] = ACTIONS(1256),
    [anon_sym_PLUS_PLUS] = ACTIONS(1258),
    [anon_sym_DASH_DASH] = ACTIONS(1258),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(1260),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1512),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1234),
    [anon_sym_readonly] = ACTIONS(1234),
    [anon_sym_get] = ACTIONS(1234),
    [anon_sym_set] = ACTIONS(1234),
    [anon_sym_declare] = ACTIONS(1234),
    [anon_sym_public] = ACTIONS(1234),
    [anon_sym_private] = ACTIONS(1234),
    [anon_sym_protected] = ACTIONS(1234),
    [anon_sym_override] = ACTIONS(1234),
    [anon_sym_module] = ACTIONS(1234),
    [anon_sym_any] = ACTIONS(1234),
    [anon_sym_number] = ACTIONS(1234),
    [anon_sym_boolean] = ACTIONS(1234),
    [anon_sym_string] = ACTIONS(1234),
    [anon_sym_symbol] = ACTIONS(1234),
    [anon_sym_object] = ACTIONS(1234),
    [sym_html_comment] = ACTIONS(5),
  },
  [605] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1456),
    [sym_expression] = STATE(2446),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5815),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5815),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5755),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1456),
    [sym_subscript_expression] = STATE(1456),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3029),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5815),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1456),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(594),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1506),
    [anon_sym_export] = ACTIONS(1234),
    [anon_sym_type] = ACTIONS(1234),
    [anon_sym_namespace] = ACTIONS(1236),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_typeof] = ACTIONS(1256),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1234),
    [anon_sym_BANG] = ACTIONS(1240),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(1242),
    [anon_sym_yield] = ACTIONS(1244),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1246),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1510),
    [anon_sym_using] = ACTIONS(1250),
    [anon_sym_PLUS] = ACTIONS(1256),
    [anon_sym_DASH] = ACTIONS(1256),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(1240),
    [anon_sym_void] = ACTIONS(1256),
    [anon_sym_delete] = ACTIONS(1256),
    [anon_sym_PLUS_PLUS] = ACTIONS(1258),
    [anon_sym_DASH_DASH] = ACTIONS(1258),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(1260),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1512),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1234),
    [anon_sym_readonly] = ACTIONS(1234),
    [anon_sym_get] = ACTIONS(1234),
    [anon_sym_set] = ACTIONS(1234),
    [anon_sym_declare] = ACTIONS(1234),
    [anon_sym_public] = ACTIONS(1234),
    [anon_sym_private] = ACTIONS(1234),
    [anon_sym_protected] = ACTIONS(1234),
    [anon_sym_override] = ACTIONS(1234),
    [anon_sym_module] = ACTIONS(1234),
    [anon_sym_any] = ACTIONS(1234),
    [anon_sym_number] = ACTIONS(1234),
    [anon_sym_boolean] = ACTIONS(1234),
    [anon_sym_string] = ACTIONS(1234),
    [anon_sym_symbol] = ACTIONS(1234),
    [anon_sym_object] = ACTIONS(1234),
    [sym_html_comment] = ACTIONS(5),
  },
  [606] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1456),
    [sym_expression] = STATE(2447),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5815),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5815),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5755),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1456),
    [sym_subscript_expression] = STATE(1456),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3029),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5815),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1456),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(594),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1506),
    [anon_sym_export] = ACTIONS(1234),
    [anon_sym_type] = ACTIONS(1234),
    [anon_sym_namespace] = ACTIONS(1236),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_typeof] = ACTIONS(1256),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1234),
    [anon_sym_BANG] = ACTIONS(1240),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(1242),
    [anon_sym_yield] = ACTIONS(1244),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1246),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1510),
    [anon_sym_using] = ACTIONS(1250),
    [anon_sym_PLUS] = ACTIONS(1256),
    [anon_sym_DASH] = ACTIONS(1256),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(1240),
    [anon_sym_void] = ACTIONS(1256),
    [anon_sym_delete] = ACTIONS(1256),
    [anon_sym_PLUS_PLUS] = ACTIONS(1258),
    [anon_sym_DASH_DASH] = ACTIONS(1258),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(1260),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1512),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1234),
    [anon_sym_readonly] = ACTIONS(1234),
    [anon_sym_get] = ACTIONS(1234),
    [anon_sym_set] = ACTIONS(1234),
    [anon_sym_declare] = ACTIONS(1234),
    [anon_sym_public] = ACTIONS(1234),
    [anon_sym_private] = ACTIONS(1234),
    [anon_sym_protected] = ACTIONS(1234),
    [anon_sym_override] = ACTIONS(1234),
    [anon_sym_module] = ACTIONS(1234),
    [anon_sym_any] = ACTIONS(1234),
    [anon_sym_number] = ACTIONS(1234),
    [anon_sym_boolean] = ACTIONS(1234),
    [anon_sym_string] = ACTIONS(1234),
    [anon_sym_symbol] = ACTIONS(1234),
    [anon_sym_object] = ACTIONS(1234),
    [sym_html_comment] = ACTIONS(5),
  },
  [607] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1456),
    [sym_expression] = STATE(2360),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5815),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5815),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5755),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1456),
    [sym_subscript_expression] = STATE(1456),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3029),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5815),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1456),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(594),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1506),
    [anon_sym_export] = ACTIONS(1234),
    [anon_sym_type] = ACTIONS(1234),
    [anon_sym_namespace] = ACTIONS(1236),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_typeof] = ACTIONS(1256),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1234),
    [anon_sym_BANG] = ACTIONS(1240),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(1242),
    [anon_sym_yield] = ACTIONS(1244),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1246),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1510),
    [anon_sym_using] = ACTIONS(1250),
    [anon_sym_PLUS] = ACTIONS(1256),
    [anon_sym_DASH] = ACTIONS(1256),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(1240),
    [anon_sym_void] = ACTIONS(1256),
    [anon_sym_delete] = ACTIONS(1256),
    [anon_sym_PLUS_PLUS] = ACTIONS(1258),
    [anon_sym_DASH_DASH] = ACTIONS(1258),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(1260),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1512),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1234),
    [anon_sym_readonly] = ACTIONS(1234),
    [anon_sym_get] = ACTIONS(1234),
    [anon_sym_set] = ACTIONS(1234),
    [anon_sym_declare] = ACTIONS(1234),
    [anon_sym_public] = ACTIONS(1234),
    [anon_sym_private] = ACTIONS(1234),
    [anon_sym_protected] = ACTIONS(1234),
    [anon_sym_override] = ACTIONS(1234),
    [anon_sym_module] = ACTIONS(1234),
    [anon_sym_any] = ACTIONS(1234),
    [anon_sym_number] = ACTIONS(1234),
    [anon_sym_boolean] = ACTIONS(1234),
    [anon_sym_string] = ACTIONS(1234),
    [anon_sym_symbol] = ACTIONS(1234),
    [anon_sym_object] = ACTIONS(1234),
    [sym_html_comment] = ACTIONS(5),
  },
  [608] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1456),
    [sym_expression] = STATE(2361),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5815),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5815),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5755),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1456),
    [sym_subscript_expression] = STATE(1456),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3029),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5815),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1456),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(594),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1506),
    [anon_sym_export] = ACTIONS(1234),
    [anon_sym_type] = ACTIONS(1234),
    [anon_sym_namespace] = ACTIONS(1236),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_typeof] = ACTIONS(1256),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1234),
    [anon_sym_BANG] = ACTIONS(1240),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(1242),
    [anon_sym_yield] = ACTIONS(1244),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1246),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1510),
    [anon_sym_using] = ACTIONS(1250),
    [anon_sym_PLUS] = ACTIONS(1256),
    [anon_sym_DASH] = ACTIONS(1256),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(1240),
    [anon_sym_void] = ACTIONS(1256),
    [anon_sym_delete] = ACTIONS(1256),
    [anon_sym_PLUS_PLUS] = ACTIONS(1258),
    [anon_sym_DASH_DASH] = ACTIONS(1258),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(1260),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1512),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1234),
    [anon_sym_readonly] = ACTIONS(1234),
    [anon_sym_get] = ACTIONS(1234),
    [anon_sym_set] = ACTIONS(1234),
    [anon_sym_declare] = ACTIONS(1234),
    [anon_sym_public] = ACTIONS(1234),
    [anon_sym_private] = ACTIONS(1234),
    [anon_sym_protected] = ACTIONS(1234),
    [anon_sym_override] = ACTIONS(1234),
    [anon_sym_module] = ACTIONS(1234),
    [anon_sym_any] = ACTIONS(1234),
    [anon_sym_number] = ACTIONS(1234),
    [anon_sym_boolean] = ACTIONS(1234),
    [anon_sym_string] = ACTIONS(1234),
    [anon_sym_symbol] = ACTIONS(1234),
    [anon_sym_object] = ACTIONS(1234),
    [sym_html_comment] = ACTIONS(5),
  },
  [609] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1456),
    [sym_expression] = STATE(2362),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5815),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5815),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5755),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1456),
    [sym_subscript_expression] = STATE(1456),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3029),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5815),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1456),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(594),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1506),
    [anon_sym_export] = ACTIONS(1234),
    [anon_sym_type] = ACTIONS(1234),
    [anon_sym_namespace] = ACTIONS(1236),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_typeof] = ACTIONS(1256),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1234),
    [anon_sym_BANG] = ACTIONS(1240),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(1242),
    [anon_sym_yield] = ACTIONS(1244),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1246),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1510),
    [anon_sym_using] = ACTIONS(1250),
    [anon_sym_PLUS] = ACTIONS(1256),
    [anon_sym_DASH] = ACTIONS(1256),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(1240),
    [anon_sym_void] = ACTIONS(1256),
    [anon_sym_delete] = ACTIONS(1256),
    [anon_sym_PLUS_PLUS] = ACTIONS(1258),
    [anon_sym_DASH_DASH] = ACTIONS(1258),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(1260),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1512),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1234),
    [anon_sym_readonly] = ACTIONS(1234),
    [anon_sym_get] = ACTIONS(1234),
    [anon_sym_set] = ACTIONS(1234),
    [anon_sym_declare] = ACTIONS(1234),
    [anon_sym_public] = ACTIONS(1234),
    [anon_sym_private] = ACTIONS(1234),
    [anon_sym_protected] = ACTIONS(1234),
    [anon_sym_override] = ACTIONS(1234),
    [anon_sym_module] = ACTIONS(1234),
    [anon_sym_any] = ACTIONS(1234),
    [anon_sym_number] = ACTIONS(1234),
    [anon_sym_boolean] = ACTIONS(1234),
    [anon_sym_string] = ACTIONS(1234),
    [anon_sym_symbol] = ACTIONS(1234),
    [anon_sym_object] = ACTIONS(1234),
    [sym_html_comment] = ACTIONS(5),
  },
  [610] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1456),
    [sym_expression] = STATE(2364),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5815),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5815),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5755),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1456),
    [sym_subscript_expression] = STATE(1456),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3029),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5815),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1456),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(594),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1506),
    [anon_sym_export] = ACTIONS(1234),
    [anon_sym_type] = ACTIONS(1234),
    [anon_sym_namespace] = ACTIONS(1236),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_typeof] = ACTIONS(1256),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1234),
    [anon_sym_BANG] = ACTIONS(1240),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(1242),
    [anon_sym_yield] = ACTIONS(1244),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1246),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1510),
    [anon_sym_using] = ACTIONS(1250),
    [anon_sym_PLUS] = ACTIONS(1256),
    [anon_sym_DASH] = ACTIONS(1256),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(1240),
    [anon_sym_void] = ACTIONS(1256),
    [anon_sym_delete] = ACTIONS(1256),
    [anon_sym_PLUS_PLUS] = ACTIONS(1258),
    [anon_sym_DASH_DASH] = ACTIONS(1258),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(1260),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1512),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1234),
    [anon_sym_readonly] = ACTIONS(1234),
    [anon_sym_get] = ACTIONS(1234),
    [anon_sym_set] = ACTIONS(1234),
    [anon_sym_declare] = ACTIONS(1234),
    [anon_sym_public] = ACTIONS(1234),
    [anon_sym_private] = ACTIONS(1234),
    [anon_sym_protected] = ACTIONS(1234),
    [anon_sym_override] = ACTIONS(1234),
    [anon_sym_module] = ACTIONS(1234),
    [anon_sym_any] = ACTIONS(1234),
    [anon_sym_number] = ACTIONS(1234),
    [anon_sym_boolean] = ACTIONS(1234),
    [anon_sym_string] = ACTIONS(1234),
    [anon_sym_symbol] = ACTIONS(1234),
    [anon_sym_object] = ACTIONS(1234),
    [sym_html_comment] = ACTIONS(5),
  },
  [611] = {
    [sym_import] = STATE(3636),
    [sym_parenthesized_expression] = STATE(1362),
    [sym_expression] = STATE(1812),
    [sym_primary_expression] = STATE(1810),
    [sym_yield_expression] = STATE(2358),
    [sym_object] = STATE(2222),
    [sym_object_pattern] = STATE(5492),
    [sym_array] = STATE(2222),
    [sym_array_pattern] = STATE(5492),
    [sym_class] = STATE(2222),
    [sym_function_expression] = STATE(2222),
    [sym_generator_function] = STATE(2222),
    [sym_arrow_function] = STATE(2222),
    [sym__call_signature] = STATE(5821),
    [sym_call_expression] = STATE(2222),
    [sym_new_expression] = STATE(1948),
    [sym_await_expression] = STATE(2358),
    [sym_member_expression] = STATE(1362),
    [sym_subscript_expression] = STATE(1362),
    [sym_assignment_expression] = STATE(2358),
    [sym__augmented_assignment_lhs] = STATE(3025),
    [sym_augmented_assignment_expression] = STATE(2358),
    [sym__destructuring_pattern] = STATE(5492),
    [sym_ternary_expression] = STATE(2358),
    [sym_binary_expression] = STATE(2358),
    [sym_unary_expression] = STATE(2358),
    [sym_update_expression] = STATE(2358),
    [sym_string] = STATE(2222),
    [sym_template_string] = STATE(2222),
    [sym_regex] = STATE(2222),
    [sym_meta_property] = STATE(2222),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1362),
    [sym_type_assertion] = STATE(2358),
    [sym_as_expression] = STATE(2358),
    [sym_satisfies_expression] = STATE(2358),
    [sym_instantiation_expression] = STATE(2358),
    [sym_internal_module] = STATE(2358),
    [sym_type_arguments] = STATE(428),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4408),
    [sym_identifier] = ACTIONS(1468),
    [anon_sym_export] = ACTIONS(1352),
    [anon_sym_type] = ACTIONS(1352),
    [anon_sym_namespace] = ACTIONS(1354),
    [anon_sym_LBRACE] = ACTIONS(665),
    [anon_sym_typeof] = ACTIONS(21),
    [anon_sym_import] = ACTIONS(669),
    [anon_sym_let] = ACTIONS(1352),
    [anon_sym_BANG] = ACTIONS(33),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_await] = ACTIONS(45),
    [anon_sym_yield] = ACTIONS(63),
    [anon_sym_LBRACK] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(676),
    [anon_sym_async] = ACTIONS(1362),
    [anon_sym_function] = ACTIONS(680),
    [anon_sym_new] = ACTIONS(1472),
    [anon_sym_using] = ACTIONS(75),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_SLASH] = ACTIONS(77),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(33),
    [anon_sym_void] = ACTIONS(21),
    [anon_sym_delete] = ACTIONS(21),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_DQUOTE] = ACTIONS(83),
    [anon_sym_SQUOTE] = ACTIONS(85),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(87),
    [sym_number] = ACTIONS(89),
    [sym_private_property_identifier] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(93),
    [sym_true] = ACTIONS(93),
    [sym_false] = ACTIONS(93),
    [sym_null] = ACTIONS(93),
    [sym_undefined] = ACTIONS(95),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1352),
    [anon_sym_readonly] = ACTIONS(1352),
    [anon_sym_get] = ACTIONS(1352),
    [anon_sym_set] = ACTIONS(1352),
    [anon_sym_declare] = ACTIONS(1352),
    [anon_sym_public] = ACTIONS(1352),
    [anon_sym_private] = ACTIONS(1352),
    [anon_sym_protected] = ACTIONS(1352),
    [anon_sym_override] = ACTIONS(1352),
    [anon_sym_module] = ACTIONS(1352),
    [anon_sym_any] = ACTIONS(1352),
    [anon_sym_number] = ACTIONS(1352),
    [anon_sym_boolean] = ACTIONS(1352),
    [anon_sym_string] = ACTIONS(1352),
    [anon_sym_symbol] = ACTIONS(1352),
    [anon_sym_object] = ACTIONS(1352),
    [sym_html_comment] = ACTIONS(5),
  },
  [612] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1456),
    [sym_expression] = STATE(2368),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5815),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5815),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5755),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1456),
    [sym_subscript_expression] = STATE(1456),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3029),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5815),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1456),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(594),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1506),
    [anon_sym_export] = ACTIONS(1234),
    [anon_sym_type] = ACTIONS(1234),
    [anon_sym_namespace] = ACTIONS(1236),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_typeof] = ACTIONS(1256),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1234),
    [anon_sym_BANG] = ACTIONS(1240),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(1242),
    [anon_sym_yield] = ACTIONS(1244),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1246),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1510),
    [anon_sym_using] = ACTIONS(1250),
    [anon_sym_PLUS] = ACTIONS(1256),
    [anon_sym_DASH] = ACTIONS(1256),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(1240),
    [anon_sym_void] = ACTIONS(1256),
    [anon_sym_delete] = ACTIONS(1256),
    [anon_sym_PLUS_PLUS] = ACTIONS(1258),
    [anon_sym_DASH_DASH] = ACTIONS(1258),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(1260),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1512),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1234),
    [anon_sym_readonly] = ACTIONS(1234),
    [anon_sym_get] = ACTIONS(1234),
    [anon_sym_set] = ACTIONS(1234),
    [anon_sym_declare] = ACTIONS(1234),
    [anon_sym_public] = ACTIONS(1234),
    [anon_sym_private] = ACTIONS(1234),
    [anon_sym_protected] = ACTIONS(1234),
    [anon_sym_override] = ACTIONS(1234),
    [anon_sym_module] = ACTIONS(1234),
    [anon_sym_any] = ACTIONS(1234),
    [anon_sym_number] = ACTIONS(1234),
    [anon_sym_boolean] = ACTIONS(1234),
    [anon_sym_string] = ACTIONS(1234),
    [anon_sym_symbol] = ACTIONS(1234),
    [anon_sym_object] = ACTIONS(1234),
    [sym_html_comment] = ACTIONS(5),
  },
  [613] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1456),
    [sym_expression] = STATE(2369),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5815),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5815),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5755),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1456),
    [sym_subscript_expression] = STATE(1456),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3029),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5815),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1456),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(594),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1506),
    [anon_sym_export] = ACTIONS(1234),
    [anon_sym_type] = ACTIONS(1234),
    [anon_sym_namespace] = ACTIONS(1236),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_typeof] = ACTIONS(1256),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1234),
    [anon_sym_BANG] = ACTIONS(1240),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(1242),
    [anon_sym_yield] = ACTIONS(1244),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1246),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1510),
    [anon_sym_using] = ACTIONS(1250),
    [anon_sym_PLUS] = ACTIONS(1256),
    [anon_sym_DASH] = ACTIONS(1256),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(1240),
    [anon_sym_void] = ACTIONS(1256),
    [anon_sym_delete] = ACTIONS(1256),
    [anon_sym_PLUS_PLUS] = ACTIONS(1258),
    [anon_sym_DASH_DASH] = ACTIONS(1258),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(1260),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1512),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1234),
    [anon_sym_readonly] = ACTIONS(1234),
    [anon_sym_get] = ACTIONS(1234),
    [anon_sym_set] = ACTIONS(1234),
    [anon_sym_declare] = ACTIONS(1234),
    [anon_sym_public] = ACTIONS(1234),
    [anon_sym_private] = ACTIONS(1234),
    [anon_sym_protected] = ACTIONS(1234),
    [anon_sym_override] = ACTIONS(1234),
    [anon_sym_module] = ACTIONS(1234),
    [anon_sym_any] = ACTIONS(1234),
    [anon_sym_number] = ACTIONS(1234),
    [anon_sym_boolean] = ACTIONS(1234),
    [anon_sym_string] = ACTIONS(1234),
    [anon_sym_symbol] = ACTIONS(1234),
    [anon_sym_object] = ACTIONS(1234),
    [sym_html_comment] = ACTIONS(5),
  },
  [614] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1456),
    [sym_expression] = STATE(2373),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5815),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5815),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5755),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1456),
    [sym_subscript_expression] = STATE(1456),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3029),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5815),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1456),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(594),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1506),
    [anon_sym_export] = ACTIONS(1234),
    [anon_sym_type] = ACTIONS(1234),
    [anon_sym_namespace] = ACTIONS(1236),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_typeof] = ACTIONS(1256),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1234),
    [anon_sym_BANG] = ACTIONS(1240),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(1242),
    [anon_sym_yield] = ACTIONS(1244),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1246),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1510),
    [anon_sym_using] = ACTIONS(1250),
    [anon_sym_PLUS] = ACTIONS(1256),
    [anon_sym_DASH] = ACTIONS(1256),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(1240),
    [anon_sym_void] = ACTIONS(1256),
    [anon_sym_delete] = ACTIONS(1256),
    [anon_sym_PLUS_PLUS] = ACTIONS(1258),
    [anon_sym_DASH_DASH] = ACTIONS(1258),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(1260),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1512),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1234),
    [anon_sym_readonly] = ACTIONS(1234),
    [anon_sym_get] = ACTIONS(1234),
    [anon_sym_set] = ACTIONS(1234),
    [anon_sym_declare] = ACTIONS(1234),
    [anon_sym_public] = ACTIONS(1234),
    [anon_sym_private] = ACTIONS(1234),
    [anon_sym_protected] = ACTIONS(1234),
    [anon_sym_override] = ACTIONS(1234),
    [anon_sym_module] = ACTIONS(1234),
    [anon_sym_any] = ACTIONS(1234),
    [anon_sym_number] = ACTIONS(1234),
    [anon_sym_boolean] = ACTIONS(1234),
    [anon_sym_string] = ACTIONS(1234),
    [anon_sym_symbol] = ACTIONS(1234),
    [anon_sym_object] = ACTIONS(1234),
    [sym_html_comment] = ACTIONS(5),
  },
  [615] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1456),
    [sym_expression] = STATE(2404),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5815),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5815),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5755),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1456),
    [sym_subscript_expression] = STATE(1456),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3029),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5815),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1456),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(594),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1506),
    [anon_sym_export] = ACTIONS(1234),
    [anon_sym_type] = ACTIONS(1234),
    [anon_sym_namespace] = ACTIONS(1236),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_typeof] = ACTIONS(1256),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1234),
    [anon_sym_BANG] = ACTIONS(1240),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(1242),
    [anon_sym_yield] = ACTIONS(1244),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1246),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1510),
    [anon_sym_using] = ACTIONS(1250),
    [anon_sym_PLUS] = ACTIONS(1256),
    [anon_sym_DASH] = ACTIONS(1256),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(1240),
    [anon_sym_void] = ACTIONS(1256),
    [anon_sym_delete] = ACTIONS(1256),
    [anon_sym_PLUS_PLUS] = ACTIONS(1258),
    [anon_sym_DASH_DASH] = ACTIONS(1258),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(1260),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1512),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1234),
    [anon_sym_readonly] = ACTIONS(1234),
    [anon_sym_get] = ACTIONS(1234),
    [anon_sym_set] = ACTIONS(1234),
    [anon_sym_declare] = ACTIONS(1234),
    [anon_sym_public] = ACTIONS(1234),
    [anon_sym_private] = ACTIONS(1234),
    [anon_sym_protected] = ACTIONS(1234),
    [anon_sym_override] = ACTIONS(1234),
    [anon_sym_module] = ACTIONS(1234),
    [anon_sym_any] = ACTIONS(1234),
    [anon_sym_number] = ACTIONS(1234),
    [anon_sym_boolean] = ACTIONS(1234),
    [anon_sym_string] = ACTIONS(1234),
    [anon_sym_symbol] = ACTIONS(1234),
    [anon_sym_object] = ACTIONS(1234),
    [sym_html_comment] = ACTIONS(5),
  },
  [616] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1456),
    [sym_expression] = STATE(2405),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5815),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5815),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5755),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1456),
    [sym_subscript_expression] = STATE(1456),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3029),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5815),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1456),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(594),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1506),
    [anon_sym_export] = ACTIONS(1234),
    [anon_sym_type] = ACTIONS(1234),
    [anon_sym_namespace] = ACTIONS(1236),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_typeof] = ACTIONS(1256),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1234),
    [anon_sym_BANG] = ACTIONS(1240),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(1242),
    [anon_sym_yield] = ACTIONS(1244),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1246),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1510),
    [anon_sym_using] = ACTIONS(1250),
    [anon_sym_PLUS] = ACTIONS(1256),
    [anon_sym_DASH] = ACTIONS(1256),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(1240),
    [anon_sym_void] = ACTIONS(1256),
    [anon_sym_delete] = ACTIONS(1256),
    [anon_sym_PLUS_PLUS] = ACTIONS(1258),
    [anon_sym_DASH_DASH] = ACTIONS(1258),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(1260),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1512),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1234),
    [anon_sym_readonly] = ACTIONS(1234),
    [anon_sym_get] = ACTIONS(1234),
    [anon_sym_set] = ACTIONS(1234),
    [anon_sym_declare] = ACTIONS(1234),
    [anon_sym_public] = ACTIONS(1234),
    [anon_sym_private] = ACTIONS(1234),
    [anon_sym_protected] = ACTIONS(1234),
    [anon_sym_override] = ACTIONS(1234),
    [anon_sym_module] = ACTIONS(1234),
    [anon_sym_any] = ACTIONS(1234),
    [anon_sym_number] = ACTIONS(1234),
    [anon_sym_boolean] = ACTIONS(1234),
    [anon_sym_string] = ACTIONS(1234),
    [anon_sym_symbol] = ACTIONS(1234),
    [anon_sym_object] = ACTIONS(1234),
    [sym_html_comment] = ACTIONS(5),
  },
  [617] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1457),
    [sym_expression] = STATE(2414),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5823),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5823),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5477),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1457),
    [sym_subscript_expression] = STATE(1457),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(2986),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5823),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1457),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(620),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1522),
    [anon_sym_export] = ACTIONS(1178),
    [anon_sym_type] = ACTIONS(1178),
    [anon_sym_namespace] = ACTIONS(1180),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_typeof] = ACTIONS(1202),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1178),
    [anon_sym_BANG] = ACTIONS(1186),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(1188),
    [anon_sym_yield] = ACTIONS(1190),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1192),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1526),
    [anon_sym_using] = ACTIONS(1196),
    [anon_sym_PLUS] = ACTIONS(1202),
    [anon_sym_DASH] = ACTIONS(1202),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(1186),
    [anon_sym_void] = ACTIONS(1202),
    [anon_sym_delete] = ACTIONS(1202),
    [anon_sym_PLUS_PLUS] = ACTIONS(1204),
    [anon_sym_DASH_DASH] = ACTIONS(1204),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(2171),
    [sym_private_property_identifier] = ACTIONS(1206),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1528),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1178),
    [anon_sym_readonly] = ACTIONS(1178),
    [anon_sym_get] = ACTIONS(1178),
    [anon_sym_set] = ACTIONS(1178),
    [anon_sym_declare] = ACTIONS(1178),
    [anon_sym_public] = ACTIONS(1178),
    [anon_sym_private] = ACTIONS(1178),
    [anon_sym_protected] = ACTIONS(1178),
    [anon_sym_override] = ACTIONS(1178),
    [anon_sym_module] = ACTIONS(1178),
    [anon_sym_any] = ACTIONS(1178),
    [anon_sym_number] = ACTIONS(1178),
    [anon_sym_boolean] = ACTIONS(1178),
    [anon_sym_string] = ACTIONS(1178),
    [anon_sym_symbol] = ACTIONS(1178),
    [anon_sym_object] = ACTIONS(1178),
    [sym_html_comment] = ACTIONS(5),
  },
  [618] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1469),
    [sym_expression] = STATE(2644),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5783),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5783),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5800),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1469),
    [sym_subscript_expression] = STATE(1469),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3013),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5783),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1469),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(539),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(2251),
    [anon_sym_export] = ACTIONS(2253),
    [anon_sym_type] = ACTIONS(2253),
    [anon_sym_namespace] = ACTIONS(2255),
    [anon_sym_LBRACE] = ACTIONS(808),
    [anon_sym_typeof] = ACTIONS(179),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(2253),
    [anon_sym_BANG] = ACTIONS(175),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(140),
    [anon_sym_yield] = ACTIONS(142),
    [anon_sym_LBRACK] = ACTIONS(812),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(2257),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(2259),
    [anon_sym_using] = ACTIONS(158),
    [anon_sym_PLUS] = ACTIONS(179),
    [anon_sym_DASH] = ACTIONS(179),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(175),
    [anon_sym_void] = ACTIONS(179),
    [anon_sym_delete] = ACTIONS(179),
    [anon_sym_PLUS_PLUS] = ACTIONS(686),
    [anon_sym_DASH_DASH] = ACTIONS(686),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(192),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(2261),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(2253),
    [anon_sym_readonly] = ACTIONS(2253),
    [anon_sym_get] = ACTIONS(2253),
    [anon_sym_set] = ACTIONS(2253),
    [anon_sym_declare] = ACTIONS(2253),
    [anon_sym_public] = ACTIONS(2253),
    [anon_sym_private] = ACTIONS(2253),
    [anon_sym_protected] = ACTIONS(2253),
    [anon_sym_override] = ACTIONS(2253),
    [anon_sym_module] = ACTIONS(2253),
    [anon_sym_any] = ACTIONS(2253),
    [anon_sym_number] = ACTIONS(2253),
    [anon_sym_boolean] = ACTIONS(2253),
    [anon_sym_string] = ACTIONS(2253),
    [anon_sym_symbol] = ACTIONS(2253),
    [anon_sym_object] = ACTIONS(2253),
    [sym_html_comment] = ACTIONS(5),
  },
  [619] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1456),
    [sym_expression] = STATE(2590),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5815),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5815),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5755),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1456),
    [sym_subscript_expression] = STATE(1456),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3029),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5815),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1456),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(594),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1506),
    [anon_sym_export] = ACTIONS(1234),
    [anon_sym_type] = ACTIONS(1234),
    [anon_sym_namespace] = ACTIONS(1236),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_typeof] = ACTIONS(1256),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1234),
    [anon_sym_BANG] = ACTIONS(1240),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(1242),
    [anon_sym_yield] = ACTIONS(1244),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1246),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1510),
    [anon_sym_using] = ACTIONS(1250),
    [anon_sym_PLUS] = ACTIONS(1256),
    [anon_sym_DASH] = ACTIONS(1256),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(1240),
    [anon_sym_void] = ACTIONS(1256),
    [anon_sym_delete] = ACTIONS(1256),
    [anon_sym_PLUS_PLUS] = ACTIONS(1258),
    [anon_sym_DASH_DASH] = ACTIONS(1258),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(1260),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1512),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1234),
    [anon_sym_readonly] = ACTIONS(1234),
    [anon_sym_get] = ACTIONS(1234),
    [anon_sym_set] = ACTIONS(1234),
    [anon_sym_declare] = ACTIONS(1234),
    [anon_sym_public] = ACTIONS(1234),
    [anon_sym_private] = ACTIONS(1234),
    [anon_sym_protected] = ACTIONS(1234),
    [anon_sym_override] = ACTIONS(1234),
    [anon_sym_module] = ACTIONS(1234),
    [anon_sym_any] = ACTIONS(1234),
    [anon_sym_number] = ACTIONS(1234),
    [anon_sym_boolean] = ACTIONS(1234),
    [anon_sym_string] = ACTIONS(1234),
    [anon_sym_symbol] = ACTIONS(1234),
    [anon_sym_object] = ACTIONS(1234),
    [sym_html_comment] = ACTIONS(5),
  },
  [620] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1457),
    [sym_expression] = STATE(2387),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5823),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5823),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5477),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1457),
    [sym_subscript_expression] = STATE(1457),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(2986),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5823),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1457),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(620),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1522),
    [anon_sym_export] = ACTIONS(1178),
    [anon_sym_type] = ACTIONS(1178),
    [anon_sym_namespace] = ACTIONS(1180),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_typeof] = ACTIONS(1202),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1178),
    [anon_sym_BANG] = ACTIONS(1186),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(1188),
    [anon_sym_yield] = ACTIONS(1190),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1192),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1526),
    [anon_sym_using] = ACTIONS(1196),
    [anon_sym_PLUS] = ACTIONS(1202),
    [anon_sym_DASH] = ACTIONS(1202),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(1186),
    [anon_sym_void] = ACTIONS(1202),
    [anon_sym_delete] = ACTIONS(1202),
    [anon_sym_PLUS_PLUS] = ACTIONS(1204),
    [anon_sym_DASH_DASH] = ACTIONS(1204),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(1206),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1528),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1178),
    [anon_sym_readonly] = ACTIONS(1178),
    [anon_sym_get] = ACTIONS(1178),
    [anon_sym_set] = ACTIONS(1178),
    [anon_sym_declare] = ACTIONS(1178),
    [anon_sym_public] = ACTIONS(1178),
    [anon_sym_private] = ACTIONS(1178),
    [anon_sym_protected] = ACTIONS(1178),
    [anon_sym_override] = ACTIONS(1178),
    [anon_sym_module] = ACTIONS(1178),
    [anon_sym_any] = ACTIONS(1178),
    [anon_sym_number] = ACTIONS(1178),
    [anon_sym_boolean] = ACTIONS(1178),
    [anon_sym_string] = ACTIONS(1178),
    [anon_sym_symbol] = ACTIONS(1178),
    [anon_sym_object] = ACTIONS(1178),
    [sym_html_comment] = ACTIONS(5),
  },
  [621] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1457),
    [sym_expression] = STATE(2389),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5823),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5823),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5477),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1457),
    [sym_subscript_expression] = STATE(1457),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(2986),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5823),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1457),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(620),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1522),
    [anon_sym_export] = ACTIONS(1178),
    [anon_sym_type] = ACTIONS(1178),
    [anon_sym_namespace] = ACTIONS(1180),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_typeof] = ACTIONS(1202),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1178),
    [anon_sym_BANG] = ACTIONS(1186),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(1188),
    [anon_sym_yield] = ACTIONS(1190),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1192),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1526),
    [anon_sym_using] = ACTIONS(1196),
    [anon_sym_PLUS] = ACTIONS(1202),
    [anon_sym_DASH] = ACTIONS(1202),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(1186),
    [anon_sym_void] = ACTIONS(1202),
    [anon_sym_delete] = ACTIONS(1202),
    [anon_sym_PLUS_PLUS] = ACTIONS(1204),
    [anon_sym_DASH_DASH] = ACTIONS(1204),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(1206),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1528),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1178),
    [anon_sym_readonly] = ACTIONS(1178),
    [anon_sym_get] = ACTIONS(1178),
    [anon_sym_set] = ACTIONS(1178),
    [anon_sym_declare] = ACTIONS(1178),
    [anon_sym_public] = ACTIONS(1178),
    [anon_sym_private] = ACTIONS(1178),
    [anon_sym_protected] = ACTIONS(1178),
    [anon_sym_override] = ACTIONS(1178),
    [anon_sym_module] = ACTIONS(1178),
    [anon_sym_any] = ACTIONS(1178),
    [anon_sym_number] = ACTIONS(1178),
    [anon_sym_boolean] = ACTIONS(1178),
    [anon_sym_string] = ACTIONS(1178),
    [anon_sym_symbol] = ACTIONS(1178),
    [anon_sym_object] = ACTIONS(1178),
    [sym_html_comment] = ACTIONS(5),
  },
  [622] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1457),
    [sym_expression] = STATE(2390),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5823),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5823),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5477),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1457),
    [sym_subscript_expression] = STATE(1457),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(2986),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5823),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1457),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(620),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1522),
    [anon_sym_export] = ACTIONS(1178),
    [anon_sym_type] = ACTIONS(1178),
    [anon_sym_namespace] = ACTIONS(1180),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_typeof] = ACTIONS(1202),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1178),
    [anon_sym_BANG] = ACTIONS(1186),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(1188),
    [anon_sym_yield] = ACTIONS(1190),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1192),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1526),
    [anon_sym_using] = ACTIONS(1196),
    [anon_sym_PLUS] = ACTIONS(1202),
    [anon_sym_DASH] = ACTIONS(1202),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(1186),
    [anon_sym_void] = ACTIONS(1202),
    [anon_sym_delete] = ACTIONS(1202),
    [anon_sym_PLUS_PLUS] = ACTIONS(1204),
    [anon_sym_DASH_DASH] = ACTIONS(1204),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(1206),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1528),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1178),
    [anon_sym_readonly] = ACTIONS(1178),
    [anon_sym_get] = ACTIONS(1178),
    [anon_sym_set] = ACTIONS(1178),
    [anon_sym_declare] = ACTIONS(1178),
    [anon_sym_public] = ACTIONS(1178),
    [anon_sym_private] = ACTIONS(1178),
    [anon_sym_protected] = ACTIONS(1178),
    [anon_sym_override] = ACTIONS(1178),
    [anon_sym_module] = ACTIONS(1178),
    [anon_sym_any] = ACTIONS(1178),
    [anon_sym_number] = ACTIONS(1178),
    [anon_sym_boolean] = ACTIONS(1178),
    [anon_sym_string] = ACTIONS(1178),
    [anon_sym_symbol] = ACTIONS(1178),
    [anon_sym_object] = ACTIONS(1178),
    [sym_html_comment] = ACTIONS(5),
  },
  [623] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1457),
    [sym_expression] = STATE(2391),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5823),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5823),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5477),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1457),
    [sym_subscript_expression] = STATE(1457),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(2986),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5823),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1457),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(620),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1522),
    [anon_sym_export] = ACTIONS(1178),
    [anon_sym_type] = ACTIONS(1178),
    [anon_sym_namespace] = ACTIONS(1180),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_typeof] = ACTIONS(1202),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1178),
    [anon_sym_BANG] = ACTIONS(1186),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(1188),
    [anon_sym_yield] = ACTIONS(1190),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1192),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1526),
    [anon_sym_using] = ACTIONS(1196),
    [anon_sym_PLUS] = ACTIONS(1202),
    [anon_sym_DASH] = ACTIONS(1202),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(1186),
    [anon_sym_void] = ACTIONS(1202),
    [anon_sym_delete] = ACTIONS(1202),
    [anon_sym_PLUS_PLUS] = ACTIONS(1204),
    [anon_sym_DASH_DASH] = ACTIONS(1204),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(1206),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1528),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1178),
    [anon_sym_readonly] = ACTIONS(1178),
    [anon_sym_get] = ACTIONS(1178),
    [anon_sym_set] = ACTIONS(1178),
    [anon_sym_declare] = ACTIONS(1178),
    [anon_sym_public] = ACTIONS(1178),
    [anon_sym_private] = ACTIONS(1178),
    [anon_sym_protected] = ACTIONS(1178),
    [anon_sym_override] = ACTIONS(1178),
    [anon_sym_module] = ACTIONS(1178),
    [anon_sym_any] = ACTIONS(1178),
    [anon_sym_number] = ACTIONS(1178),
    [anon_sym_boolean] = ACTIONS(1178),
    [anon_sym_string] = ACTIONS(1178),
    [anon_sym_symbol] = ACTIONS(1178),
    [anon_sym_object] = ACTIONS(1178),
    [sym_html_comment] = ACTIONS(5),
  },
  [624] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1457),
    [sym_expression] = STATE(2393),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5823),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5823),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5477),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1457),
    [sym_subscript_expression] = STATE(1457),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(2986),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5823),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1457),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(620),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1522),
    [anon_sym_export] = ACTIONS(1178),
    [anon_sym_type] = ACTIONS(1178),
    [anon_sym_namespace] = ACTIONS(1180),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_typeof] = ACTIONS(1202),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1178),
    [anon_sym_BANG] = ACTIONS(1186),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(1188),
    [anon_sym_yield] = ACTIONS(1190),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1192),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1526),
    [anon_sym_using] = ACTIONS(1196),
    [anon_sym_PLUS] = ACTIONS(1202),
    [anon_sym_DASH] = ACTIONS(1202),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(1186),
    [anon_sym_void] = ACTIONS(1202),
    [anon_sym_delete] = ACTIONS(1202),
    [anon_sym_PLUS_PLUS] = ACTIONS(1204),
    [anon_sym_DASH_DASH] = ACTIONS(1204),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(1206),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1528),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1178),
    [anon_sym_readonly] = ACTIONS(1178),
    [anon_sym_get] = ACTIONS(1178),
    [anon_sym_set] = ACTIONS(1178),
    [anon_sym_declare] = ACTIONS(1178),
    [anon_sym_public] = ACTIONS(1178),
    [anon_sym_private] = ACTIONS(1178),
    [anon_sym_protected] = ACTIONS(1178),
    [anon_sym_override] = ACTIONS(1178),
    [anon_sym_module] = ACTIONS(1178),
    [anon_sym_any] = ACTIONS(1178),
    [anon_sym_number] = ACTIONS(1178),
    [anon_sym_boolean] = ACTIONS(1178),
    [anon_sym_string] = ACTIONS(1178),
    [anon_sym_symbol] = ACTIONS(1178),
    [anon_sym_object] = ACTIONS(1178),
    [sym_html_comment] = ACTIONS(5),
  },
  [625] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1457),
    [sym_expression] = STATE(2394),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5823),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5823),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5477),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1457),
    [sym_subscript_expression] = STATE(1457),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(2986),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5823),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1457),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(620),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1522),
    [anon_sym_export] = ACTIONS(1178),
    [anon_sym_type] = ACTIONS(1178),
    [anon_sym_namespace] = ACTIONS(1180),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_typeof] = ACTIONS(1202),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1178),
    [anon_sym_BANG] = ACTIONS(1186),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(1188),
    [anon_sym_yield] = ACTIONS(1190),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1192),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1526),
    [anon_sym_using] = ACTIONS(1196),
    [anon_sym_PLUS] = ACTIONS(1202),
    [anon_sym_DASH] = ACTIONS(1202),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(1186),
    [anon_sym_void] = ACTIONS(1202),
    [anon_sym_delete] = ACTIONS(1202),
    [anon_sym_PLUS_PLUS] = ACTIONS(1204),
    [anon_sym_DASH_DASH] = ACTIONS(1204),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(1206),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1528),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1178),
    [anon_sym_readonly] = ACTIONS(1178),
    [anon_sym_get] = ACTIONS(1178),
    [anon_sym_set] = ACTIONS(1178),
    [anon_sym_declare] = ACTIONS(1178),
    [anon_sym_public] = ACTIONS(1178),
    [anon_sym_private] = ACTIONS(1178),
    [anon_sym_protected] = ACTIONS(1178),
    [anon_sym_override] = ACTIONS(1178),
    [anon_sym_module] = ACTIONS(1178),
    [anon_sym_any] = ACTIONS(1178),
    [anon_sym_number] = ACTIONS(1178),
    [anon_sym_boolean] = ACTIONS(1178),
    [anon_sym_string] = ACTIONS(1178),
    [anon_sym_symbol] = ACTIONS(1178),
    [anon_sym_object] = ACTIONS(1178),
    [sym_html_comment] = ACTIONS(5),
  },
  [626] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1457),
    [sym_expression] = STATE(2395),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5823),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5823),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5477),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1457),
    [sym_subscript_expression] = STATE(1457),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(2986),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5823),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1457),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(620),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1522),
    [anon_sym_export] = ACTIONS(1178),
    [anon_sym_type] = ACTIONS(1178),
    [anon_sym_namespace] = ACTIONS(1180),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_typeof] = ACTIONS(1202),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1178),
    [anon_sym_BANG] = ACTIONS(1186),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(1188),
    [anon_sym_yield] = ACTIONS(1190),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1192),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1526),
    [anon_sym_using] = ACTIONS(1196),
    [anon_sym_PLUS] = ACTIONS(1202),
    [anon_sym_DASH] = ACTIONS(1202),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(1186),
    [anon_sym_void] = ACTIONS(1202),
    [anon_sym_delete] = ACTIONS(1202),
    [anon_sym_PLUS_PLUS] = ACTIONS(1204),
    [anon_sym_DASH_DASH] = ACTIONS(1204),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(1206),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1528),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1178),
    [anon_sym_readonly] = ACTIONS(1178),
    [anon_sym_get] = ACTIONS(1178),
    [anon_sym_set] = ACTIONS(1178),
    [anon_sym_declare] = ACTIONS(1178),
    [anon_sym_public] = ACTIONS(1178),
    [anon_sym_private] = ACTIONS(1178),
    [anon_sym_protected] = ACTIONS(1178),
    [anon_sym_override] = ACTIONS(1178),
    [anon_sym_module] = ACTIONS(1178),
    [anon_sym_any] = ACTIONS(1178),
    [anon_sym_number] = ACTIONS(1178),
    [anon_sym_boolean] = ACTIONS(1178),
    [anon_sym_string] = ACTIONS(1178),
    [anon_sym_symbol] = ACTIONS(1178),
    [anon_sym_object] = ACTIONS(1178),
    [sym_html_comment] = ACTIONS(5),
  },
  [627] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1457),
    [sym_expression] = STATE(2396),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5823),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5823),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5477),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1457),
    [sym_subscript_expression] = STATE(1457),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(2986),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5823),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1457),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(620),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1522),
    [anon_sym_export] = ACTIONS(1178),
    [anon_sym_type] = ACTIONS(1178),
    [anon_sym_namespace] = ACTIONS(1180),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_typeof] = ACTIONS(1202),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1178),
    [anon_sym_BANG] = ACTIONS(1186),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(1188),
    [anon_sym_yield] = ACTIONS(1190),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1192),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1526),
    [anon_sym_using] = ACTIONS(1196),
    [anon_sym_PLUS] = ACTIONS(1202),
    [anon_sym_DASH] = ACTIONS(1202),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(1186),
    [anon_sym_void] = ACTIONS(1202),
    [anon_sym_delete] = ACTIONS(1202),
    [anon_sym_PLUS_PLUS] = ACTIONS(1204),
    [anon_sym_DASH_DASH] = ACTIONS(1204),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(1206),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1528),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1178),
    [anon_sym_readonly] = ACTIONS(1178),
    [anon_sym_get] = ACTIONS(1178),
    [anon_sym_set] = ACTIONS(1178),
    [anon_sym_declare] = ACTIONS(1178),
    [anon_sym_public] = ACTIONS(1178),
    [anon_sym_private] = ACTIONS(1178),
    [anon_sym_protected] = ACTIONS(1178),
    [anon_sym_override] = ACTIONS(1178),
    [anon_sym_module] = ACTIONS(1178),
    [anon_sym_any] = ACTIONS(1178),
    [anon_sym_number] = ACTIONS(1178),
    [anon_sym_boolean] = ACTIONS(1178),
    [anon_sym_string] = ACTIONS(1178),
    [anon_sym_symbol] = ACTIONS(1178),
    [anon_sym_object] = ACTIONS(1178),
    [sym_html_comment] = ACTIONS(5),
  },
  [628] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1457),
    [sym_expression] = STATE(2399),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5823),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5823),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5477),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1457),
    [sym_subscript_expression] = STATE(1457),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(2986),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5823),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1457),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(620),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1522),
    [anon_sym_export] = ACTIONS(1178),
    [anon_sym_type] = ACTIONS(1178),
    [anon_sym_namespace] = ACTIONS(1180),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_typeof] = ACTIONS(1202),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1178),
    [anon_sym_BANG] = ACTIONS(1186),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(1188),
    [anon_sym_yield] = ACTIONS(1190),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1192),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1526),
    [anon_sym_using] = ACTIONS(1196),
    [anon_sym_PLUS] = ACTIONS(1202),
    [anon_sym_DASH] = ACTIONS(1202),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(1186),
    [anon_sym_void] = ACTIONS(1202),
    [anon_sym_delete] = ACTIONS(1202),
    [anon_sym_PLUS_PLUS] = ACTIONS(1204),
    [anon_sym_DASH_DASH] = ACTIONS(1204),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(1206),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1528),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1178),
    [anon_sym_readonly] = ACTIONS(1178),
    [anon_sym_get] = ACTIONS(1178),
    [anon_sym_set] = ACTIONS(1178),
    [anon_sym_declare] = ACTIONS(1178),
    [anon_sym_public] = ACTIONS(1178),
    [anon_sym_private] = ACTIONS(1178),
    [anon_sym_protected] = ACTIONS(1178),
    [anon_sym_override] = ACTIONS(1178),
    [anon_sym_module] = ACTIONS(1178),
    [anon_sym_any] = ACTIONS(1178),
    [anon_sym_number] = ACTIONS(1178),
    [anon_sym_boolean] = ACTIONS(1178),
    [anon_sym_string] = ACTIONS(1178),
    [anon_sym_symbol] = ACTIONS(1178),
    [anon_sym_object] = ACTIONS(1178),
    [sym_html_comment] = ACTIONS(5),
  },
  [629] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1457),
    [sym_expression] = STATE(2400),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5823),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5823),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5477),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1457),
    [sym_subscript_expression] = STATE(1457),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(2986),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5823),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1457),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(620),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1522),
    [anon_sym_export] = ACTIONS(1178),
    [anon_sym_type] = ACTIONS(1178),
    [anon_sym_namespace] = ACTIONS(1180),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_typeof] = ACTIONS(1202),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1178),
    [anon_sym_BANG] = ACTIONS(1186),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(1188),
    [anon_sym_yield] = ACTIONS(1190),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1192),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1526),
    [anon_sym_using] = ACTIONS(1196),
    [anon_sym_PLUS] = ACTIONS(1202),
    [anon_sym_DASH] = ACTIONS(1202),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(1186),
    [anon_sym_void] = ACTIONS(1202),
    [anon_sym_delete] = ACTIONS(1202),
    [anon_sym_PLUS_PLUS] = ACTIONS(1204),
    [anon_sym_DASH_DASH] = ACTIONS(1204),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(1206),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1528),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1178),
    [anon_sym_readonly] = ACTIONS(1178),
    [anon_sym_get] = ACTIONS(1178),
    [anon_sym_set] = ACTIONS(1178),
    [anon_sym_declare] = ACTIONS(1178),
    [anon_sym_public] = ACTIONS(1178),
    [anon_sym_private] = ACTIONS(1178),
    [anon_sym_protected] = ACTIONS(1178),
    [anon_sym_override] = ACTIONS(1178),
    [anon_sym_module] = ACTIONS(1178),
    [anon_sym_any] = ACTIONS(1178),
    [anon_sym_number] = ACTIONS(1178),
    [anon_sym_boolean] = ACTIONS(1178),
    [anon_sym_string] = ACTIONS(1178),
    [anon_sym_symbol] = ACTIONS(1178),
    [anon_sym_object] = ACTIONS(1178),
    [sym_html_comment] = ACTIONS(5),
  },
  [630] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1457),
    [sym_expression] = STATE(2402),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5823),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5823),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5477),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1457),
    [sym_subscript_expression] = STATE(1457),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(2986),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5823),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1457),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(620),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1522),
    [anon_sym_export] = ACTIONS(1178),
    [anon_sym_type] = ACTIONS(1178),
    [anon_sym_namespace] = ACTIONS(1180),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_typeof] = ACTIONS(1202),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1178),
    [anon_sym_BANG] = ACTIONS(1186),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(1188),
    [anon_sym_yield] = ACTIONS(1190),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1192),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1526),
    [anon_sym_using] = ACTIONS(1196),
    [anon_sym_PLUS] = ACTIONS(1202),
    [anon_sym_DASH] = ACTIONS(1202),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(1186),
    [anon_sym_void] = ACTIONS(1202),
    [anon_sym_delete] = ACTIONS(1202),
    [anon_sym_PLUS_PLUS] = ACTIONS(1204),
    [anon_sym_DASH_DASH] = ACTIONS(1204),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(1206),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1528),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1178),
    [anon_sym_readonly] = ACTIONS(1178),
    [anon_sym_get] = ACTIONS(1178),
    [anon_sym_set] = ACTIONS(1178),
    [anon_sym_declare] = ACTIONS(1178),
    [anon_sym_public] = ACTIONS(1178),
    [anon_sym_private] = ACTIONS(1178),
    [anon_sym_protected] = ACTIONS(1178),
    [anon_sym_override] = ACTIONS(1178),
    [anon_sym_module] = ACTIONS(1178),
    [anon_sym_any] = ACTIONS(1178),
    [anon_sym_number] = ACTIONS(1178),
    [anon_sym_boolean] = ACTIONS(1178),
    [anon_sym_string] = ACTIONS(1178),
    [anon_sym_symbol] = ACTIONS(1178),
    [anon_sym_object] = ACTIONS(1178),
    [sym_html_comment] = ACTIONS(5),
  },
  [631] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1457),
    [sym_expression] = STATE(2403),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5823),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5823),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5477),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1457),
    [sym_subscript_expression] = STATE(1457),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(2986),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5823),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1457),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(620),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1522),
    [anon_sym_export] = ACTIONS(1178),
    [anon_sym_type] = ACTIONS(1178),
    [anon_sym_namespace] = ACTIONS(1180),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_typeof] = ACTIONS(1202),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1178),
    [anon_sym_BANG] = ACTIONS(1186),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(1188),
    [anon_sym_yield] = ACTIONS(1190),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1192),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1526),
    [anon_sym_using] = ACTIONS(1196),
    [anon_sym_PLUS] = ACTIONS(1202),
    [anon_sym_DASH] = ACTIONS(1202),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(1186),
    [anon_sym_void] = ACTIONS(1202),
    [anon_sym_delete] = ACTIONS(1202),
    [anon_sym_PLUS_PLUS] = ACTIONS(1204),
    [anon_sym_DASH_DASH] = ACTIONS(1204),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(1206),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1528),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1178),
    [anon_sym_readonly] = ACTIONS(1178),
    [anon_sym_get] = ACTIONS(1178),
    [anon_sym_set] = ACTIONS(1178),
    [anon_sym_declare] = ACTIONS(1178),
    [anon_sym_public] = ACTIONS(1178),
    [anon_sym_private] = ACTIONS(1178),
    [anon_sym_protected] = ACTIONS(1178),
    [anon_sym_override] = ACTIONS(1178),
    [anon_sym_module] = ACTIONS(1178),
    [anon_sym_any] = ACTIONS(1178),
    [anon_sym_number] = ACTIONS(1178),
    [anon_sym_boolean] = ACTIONS(1178),
    [anon_sym_string] = ACTIONS(1178),
    [anon_sym_symbol] = ACTIONS(1178),
    [anon_sym_object] = ACTIONS(1178),
    [sym_html_comment] = ACTIONS(5),
  },
  [632] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1457),
    [sym_expression] = STATE(2408),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5823),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5823),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5477),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1457),
    [sym_subscript_expression] = STATE(1457),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(2986),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5823),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1457),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(620),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1522),
    [anon_sym_export] = ACTIONS(1178),
    [anon_sym_type] = ACTIONS(1178),
    [anon_sym_namespace] = ACTIONS(1180),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_typeof] = ACTIONS(1202),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1178),
    [anon_sym_BANG] = ACTIONS(1186),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(1188),
    [anon_sym_yield] = ACTIONS(1190),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1192),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1526),
    [anon_sym_using] = ACTIONS(1196),
    [anon_sym_PLUS] = ACTIONS(1202),
    [anon_sym_DASH] = ACTIONS(1202),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(1186),
    [anon_sym_void] = ACTIONS(1202),
    [anon_sym_delete] = ACTIONS(1202),
    [anon_sym_PLUS_PLUS] = ACTIONS(1204),
    [anon_sym_DASH_DASH] = ACTIONS(1204),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(1206),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1528),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1178),
    [anon_sym_readonly] = ACTIONS(1178),
    [anon_sym_get] = ACTIONS(1178),
    [anon_sym_set] = ACTIONS(1178),
    [anon_sym_declare] = ACTIONS(1178),
    [anon_sym_public] = ACTIONS(1178),
    [anon_sym_private] = ACTIONS(1178),
    [anon_sym_protected] = ACTIONS(1178),
    [anon_sym_override] = ACTIONS(1178),
    [anon_sym_module] = ACTIONS(1178),
    [anon_sym_any] = ACTIONS(1178),
    [anon_sym_number] = ACTIONS(1178),
    [anon_sym_boolean] = ACTIONS(1178),
    [anon_sym_string] = ACTIONS(1178),
    [anon_sym_symbol] = ACTIONS(1178),
    [anon_sym_object] = ACTIONS(1178),
    [sym_html_comment] = ACTIONS(5),
  },
  [633] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1457),
    [sym_expression] = STATE(2409),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5823),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5823),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5477),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1457),
    [sym_subscript_expression] = STATE(1457),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(2986),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5823),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1457),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(620),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1522),
    [anon_sym_export] = ACTIONS(1178),
    [anon_sym_type] = ACTIONS(1178),
    [anon_sym_namespace] = ACTIONS(1180),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_typeof] = ACTIONS(1202),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1178),
    [anon_sym_BANG] = ACTIONS(1186),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(1188),
    [anon_sym_yield] = ACTIONS(1190),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1192),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1526),
    [anon_sym_using] = ACTIONS(1196),
    [anon_sym_PLUS] = ACTIONS(1202),
    [anon_sym_DASH] = ACTIONS(1202),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(1186),
    [anon_sym_void] = ACTIONS(1202),
    [anon_sym_delete] = ACTIONS(1202),
    [anon_sym_PLUS_PLUS] = ACTIONS(1204),
    [anon_sym_DASH_DASH] = ACTIONS(1204),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(1206),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1528),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1178),
    [anon_sym_readonly] = ACTIONS(1178),
    [anon_sym_get] = ACTIONS(1178),
    [anon_sym_set] = ACTIONS(1178),
    [anon_sym_declare] = ACTIONS(1178),
    [anon_sym_public] = ACTIONS(1178),
    [anon_sym_private] = ACTIONS(1178),
    [anon_sym_protected] = ACTIONS(1178),
    [anon_sym_override] = ACTIONS(1178),
    [anon_sym_module] = ACTIONS(1178),
    [anon_sym_any] = ACTIONS(1178),
    [anon_sym_number] = ACTIONS(1178),
    [anon_sym_boolean] = ACTIONS(1178),
    [anon_sym_string] = ACTIONS(1178),
    [anon_sym_symbol] = ACTIONS(1178),
    [anon_sym_object] = ACTIONS(1178),
    [sym_html_comment] = ACTIONS(5),
  },
  [634] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1457),
    [sym_expression] = STATE(2410),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5823),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5823),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5477),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1457),
    [sym_subscript_expression] = STATE(1457),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(2986),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5823),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1457),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(620),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1522),
    [anon_sym_export] = ACTIONS(1178),
    [anon_sym_type] = ACTIONS(1178),
    [anon_sym_namespace] = ACTIONS(1180),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_typeof] = ACTIONS(1202),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1178),
    [anon_sym_BANG] = ACTIONS(1186),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(1188),
    [anon_sym_yield] = ACTIONS(1190),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1192),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1526),
    [anon_sym_using] = ACTIONS(1196),
    [anon_sym_PLUS] = ACTIONS(1202),
    [anon_sym_DASH] = ACTIONS(1202),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(1186),
    [anon_sym_void] = ACTIONS(1202),
    [anon_sym_delete] = ACTIONS(1202),
    [anon_sym_PLUS_PLUS] = ACTIONS(1204),
    [anon_sym_DASH_DASH] = ACTIONS(1204),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(1206),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1528),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1178),
    [anon_sym_readonly] = ACTIONS(1178),
    [anon_sym_get] = ACTIONS(1178),
    [anon_sym_set] = ACTIONS(1178),
    [anon_sym_declare] = ACTIONS(1178),
    [anon_sym_public] = ACTIONS(1178),
    [anon_sym_private] = ACTIONS(1178),
    [anon_sym_protected] = ACTIONS(1178),
    [anon_sym_override] = ACTIONS(1178),
    [anon_sym_module] = ACTIONS(1178),
    [anon_sym_any] = ACTIONS(1178),
    [anon_sym_number] = ACTIONS(1178),
    [anon_sym_boolean] = ACTIONS(1178),
    [anon_sym_string] = ACTIONS(1178),
    [anon_sym_symbol] = ACTIONS(1178),
    [anon_sym_object] = ACTIONS(1178),
    [sym_html_comment] = ACTIONS(5),
  },
  [635] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1457),
    [sym_expression] = STATE(2412),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5823),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5823),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5477),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1457),
    [sym_subscript_expression] = STATE(1457),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(2986),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5823),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1457),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(620),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1522),
    [anon_sym_export] = ACTIONS(1178),
    [anon_sym_type] = ACTIONS(1178),
    [anon_sym_namespace] = ACTIONS(1180),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_typeof] = ACTIONS(1202),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1178),
    [anon_sym_BANG] = ACTIONS(1186),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(1188),
    [anon_sym_yield] = ACTIONS(1190),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1192),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1526),
    [anon_sym_using] = ACTIONS(1196),
    [anon_sym_PLUS] = ACTIONS(1202),
    [anon_sym_DASH] = ACTIONS(1202),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(1186),
    [anon_sym_void] = ACTIONS(1202),
    [anon_sym_delete] = ACTIONS(1202),
    [anon_sym_PLUS_PLUS] = ACTIONS(1204),
    [anon_sym_DASH_DASH] = ACTIONS(1204),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(1206),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1528),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1178),
    [anon_sym_readonly] = ACTIONS(1178),
    [anon_sym_get] = ACTIONS(1178),
    [anon_sym_set] = ACTIONS(1178),
    [anon_sym_declare] = ACTIONS(1178),
    [anon_sym_public] = ACTIONS(1178),
    [anon_sym_private] = ACTIONS(1178),
    [anon_sym_protected] = ACTIONS(1178),
    [anon_sym_override] = ACTIONS(1178),
    [anon_sym_module] = ACTIONS(1178),
    [anon_sym_any] = ACTIONS(1178),
    [anon_sym_number] = ACTIONS(1178),
    [anon_sym_boolean] = ACTIONS(1178),
    [anon_sym_string] = ACTIONS(1178),
    [anon_sym_symbol] = ACTIONS(1178),
    [anon_sym_object] = ACTIONS(1178),
    [sym_html_comment] = ACTIONS(5),
  },
  [636] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1398),
    [sym_expression] = STATE(1922),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5544),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5544),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5558),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1398),
    [sym_subscript_expression] = STATE(1398),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(2980),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5544),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1398),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(638),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1482),
    [anon_sym_export] = ACTIONS(1158),
    [anon_sym_type] = ACTIONS(1158),
    [anon_sym_namespace] = ACTIONS(1160),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_typeof] = ACTIONS(756),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1158),
    [anon_sym_BANG] = ACTIONS(732),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(736),
    [anon_sym_yield] = ACTIONS(738),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1164),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1486),
    [anon_sym_using] = ACTIONS(746),
    [anon_sym_PLUS] = ACTIONS(756),
    [anon_sym_DASH] = ACTIONS(756),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(732),
    [anon_sym_void] = ACTIONS(756),
    [anon_sym_delete] = ACTIONS(756),
    [anon_sym_PLUS_PLUS] = ACTIONS(758),
    [anon_sym_DASH_DASH] = ACTIONS(758),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(764),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1488),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1158),
    [anon_sym_readonly] = ACTIONS(1158),
    [anon_sym_get] = ACTIONS(1158),
    [anon_sym_set] = ACTIONS(1158),
    [anon_sym_declare] = ACTIONS(1158),
    [anon_sym_public] = ACTIONS(1158),
    [anon_sym_private] = ACTIONS(1158),
    [anon_sym_protected] = ACTIONS(1158),
    [anon_sym_override] = ACTIONS(1158),
    [anon_sym_module] = ACTIONS(1158),
    [anon_sym_any] = ACTIONS(1158),
    [anon_sym_number] = ACTIONS(1158),
    [anon_sym_boolean] = ACTIONS(1158),
    [anon_sym_string] = ACTIONS(1158),
    [anon_sym_symbol] = ACTIONS(1158),
    [anon_sym_object] = ACTIONS(1158),
    [sym_html_comment] = ACTIONS(5),
  },
  [637] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1457),
    [sym_expression] = STATE(2418),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5823),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5823),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5477),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1457),
    [sym_subscript_expression] = STATE(1457),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(2986),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5823),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1457),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(620),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1522),
    [anon_sym_export] = ACTIONS(1178),
    [anon_sym_type] = ACTIONS(1178),
    [anon_sym_namespace] = ACTIONS(1180),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_typeof] = ACTIONS(1202),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1178),
    [anon_sym_BANG] = ACTIONS(1186),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(1188),
    [anon_sym_yield] = ACTIONS(1190),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1192),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1526),
    [anon_sym_using] = ACTIONS(1196),
    [anon_sym_PLUS] = ACTIONS(1202),
    [anon_sym_DASH] = ACTIONS(1202),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(1186),
    [anon_sym_void] = ACTIONS(1202),
    [anon_sym_delete] = ACTIONS(1202),
    [anon_sym_PLUS_PLUS] = ACTIONS(1204),
    [anon_sym_DASH_DASH] = ACTIONS(1204),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(1206),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1528),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1178),
    [anon_sym_readonly] = ACTIONS(1178),
    [anon_sym_get] = ACTIONS(1178),
    [anon_sym_set] = ACTIONS(1178),
    [anon_sym_declare] = ACTIONS(1178),
    [anon_sym_public] = ACTIONS(1178),
    [anon_sym_private] = ACTIONS(1178),
    [anon_sym_protected] = ACTIONS(1178),
    [anon_sym_override] = ACTIONS(1178),
    [anon_sym_module] = ACTIONS(1178),
    [anon_sym_any] = ACTIONS(1178),
    [anon_sym_number] = ACTIONS(1178),
    [anon_sym_boolean] = ACTIONS(1178),
    [anon_sym_string] = ACTIONS(1178),
    [anon_sym_symbol] = ACTIONS(1178),
    [anon_sym_object] = ACTIONS(1178),
    [sym_html_comment] = ACTIONS(5),
  },
  [638] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1398),
    [sym_expression] = STATE(1976),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5544),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5544),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5558),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1398),
    [sym_subscript_expression] = STATE(1398),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(2980),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5544),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1398),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(638),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1482),
    [anon_sym_export] = ACTIONS(1158),
    [anon_sym_type] = ACTIONS(1158),
    [anon_sym_namespace] = ACTIONS(1160),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_typeof] = ACTIONS(756),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1158),
    [anon_sym_BANG] = ACTIONS(732),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(736),
    [anon_sym_yield] = ACTIONS(738),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1164),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1486),
    [anon_sym_using] = ACTIONS(746),
    [anon_sym_PLUS] = ACTIONS(756),
    [anon_sym_DASH] = ACTIONS(756),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(732),
    [anon_sym_void] = ACTIONS(756),
    [anon_sym_delete] = ACTIONS(756),
    [anon_sym_PLUS_PLUS] = ACTIONS(758),
    [anon_sym_DASH_DASH] = ACTIONS(758),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(764),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1488),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1158),
    [anon_sym_readonly] = ACTIONS(1158),
    [anon_sym_get] = ACTIONS(1158),
    [anon_sym_set] = ACTIONS(1158),
    [anon_sym_declare] = ACTIONS(1158),
    [anon_sym_public] = ACTIONS(1158),
    [anon_sym_private] = ACTIONS(1158),
    [anon_sym_protected] = ACTIONS(1158),
    [anon_sym_override] = ACTIONS(1158),
    [anon_sym_module] = ACTIONS(1158),
    [anon_sym_any] = ACTIONS(1158),
    [anon_sym_number] = ACTIONS(1158),
    [anon_sym_boolean] = ACTIONS(1158),
    [anon_sym_string] = ACTIONS(1158),
    [anon_sym_symbol] = ACTIONS(1158),
    [anon_sym_object] = ACTIONS(1158),
    [sym_html_comment] = ACTIONS(5),
  },
  [639] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1398),
    [sym_expression] = STATE(1888),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5544),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5544),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5558),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1398),
    [sym_subscript_expression] = STATE(1398),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(2980),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5544),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1398),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(638),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1482),
    [anon_sym_export] = ACTIONS(1158),
    [anon_sym_type] = ACTIONS(1158),
    [anon_sym_namespace] = ACTIONS(1160),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_typeof] = ACTIONS(756),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1158),
    [anon_sym_BANG] = ACTIONS(732),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(736),
    [anon_sym_yield] = ACTIONS(738),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1164),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1486),
    [anon_sym_using] = ACTIONS(746),
    [anon_sym_PLUS] = ACTIONS(756),
    [anon_sym_DASH] = ACTIONS(756),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(732),
    [anon_sym_void] = ACTIONS(756),
    [anon_sym_delete] = ACTIONS(756),
    [anon_sym_PLUS_PLUS] = ACTIONS(758),
    [anon_sym_DASH_DASH] = ACTIONS(758),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(764),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1488),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1158),
    [anon_sym_readonly] = ACTIONS(1158),
    [anon_sym_get] = ACTIONS(1158),
    [anon_sym_set] = ACTIONS(1158),
    [anon_sym_declare] = ACTIONS(1158),
    [anon_sym_public] = ACTIONS(1158),
    [anon_sym_private] = ACTIONS(1158),
    [anon_sym_protected] = ACTIONS(1158),
    [anon_sym_override] = ACTIONS(1158),
    [anon_sym_module] = ACTIONS(1158),
    [anon_sym_any] = ACTIONS(1158),
    [anon_sym_number] = ACTIONS(1158),
    [anon_sym_boolean] = ACTIONS(1158),
    [anon_sym_string] = ACTIONS(1158),
    [anon_sym_symbol] = ACTIONS(1158),
    [anon_sym_object] = ACTIONS(1158),
    [sym_html_comment] = ACTIONS(5),
  },
  [640] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1457),
    [sym_expression] = STATE(2423),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5823),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5823),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5477),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1457),
    [sym_subscript_expression] = STATE(1457),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(2986),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5823),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1457),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(620),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1522),
    [anon_sym_export] = ACTIONS(1178),
    [anon_sym_type] = ACTIONS(1178),
    [anon_sym_namespace] = ACTIONS(1180),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_typeof] = ACTIONS(1202),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1178),
    [anon_sym_BANG] = ACTIONS(1186),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(1188),
    [anon_sym_yield] = ACTIONS(1190),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1192),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1526),
    [anon_sym_using] = ACTIONS(1196),
    [anon_sym_PLUS] = ACTIONS(1202),
    [anon_sym_DASH] = ACTIONS(1202),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(1186),
    [anon_sym_void] = ACTIONS(1202),
    [anon_sym_delete] = ACTIONS(1202),
    [anon_sym_PLUS_PLUS] = ACTIONS(1204),
    [anon_sym_DASH_DASH] = ACTIONS(1204),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(1206),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1528),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1178),
    [anon_sym_readonly] = ACTIONS(1178),
    [anon_sym_get] = ACTIONS(1178),
    [anon_sym_set] = ACTIONS(1178),
    [anon_sym_declare] = ACTIONS(1178),
    [anon_sym_public] = ACTIONS(1178),
    [anon_sym_private] = ACTIONS(1178),
    [anon_sym_protected] = ACTIONS(1178),
    [anon_sym_override] = ACTIONS(1178),
    [anon_sym_module] = ACTIONS(1178),
    [anon_sym_any] = ACTIONS(1178),
    [anon_sym_number] = ACTIONS(1178),
    [anon_sym_boolean] = ACTIONS(1178),
    [anon_sym_string] = ACTIONS(1178),
    [anon_sym_symbol] = ACTIONS(1178),
    [anon_sym_object] = ACTIONS(1178),
    [sym_html_comment] = ACTIONS(5),
  },
  [641] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1457),
    [sym_expression] = STATE(2424),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5823),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5823),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5477),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1457),
    [sym_subscript_expression] = STATE(1457),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(2986),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5823),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1457),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(620),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1522),
    [anon_sym_export] = ACTIONS(1178),
    [anon_sym_type] = ACTIONS(1178),
    [anon_sym_namespace] = ACTIONS(1180),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_typeof] = ACTIONS(1202),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1178),
    [anon_sym_BANG] = ACTIONS(1186),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(1188),
    [anon_sym_yield] = ACTIONS(1190),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1192),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1526),
    [anon_sym_using] = ACTIONS(1196),
    [anon_sym_PLUS] = ACTIONS(1202),
    [anon_sym_DASH] = ACTIONS(1202),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(1186),
    [anon_sym_void] = ACTIONS(1202),
    [anon_sym_delete] = ACTIONS(1202),
    [anon_sym_PLUS_PLUS] = ACTIONS(1204),
    [anon_sym_DASH_DASH] = ACTIONS(1204),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(1206),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1528),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1178),
    [anon_sym_readonly] = ACTIONS(1178),
    [anon_sym_get] = ACTIONS(1178),
    [anon_sym_set] = ACTIONS(1178),
    [anon_sym_declare] = ACTIONS(1178),
    [anon_sym_public] = ACTIONS(1178),
    [anon_sym_private] = ACTIONS(1178),
    [anon_sym_protected] = ACTIONS(1178),
    [anon_sym_override] = ACTIONS(1178),
    [anon_sym_module] = ACTIONS(1178),
    [anon_sym_any] = ACTIONS(1178),
    [anon_sym_number] = ACTIONS(1178),
    [anon_sym_boolean] = ACTIONS(1178),
    [anon_sym_string] = ACTIONS(1178),
    [anon_sym_symbol] = ACTIONS(1178),
    [anon_sym_object] = ACTIONS(1178),
    [sym_html_comment] = ACTIONS(5),
  },
  [642] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1457),
    [sym_expression] = STATE(2426),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5823),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5823),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5477),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1457),
    [sym_subscript_expression] = STATE(1457),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(2986),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5823),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1457),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(620),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1522),
    [anon_sym_export] = ACTIONS(1178),
    [anon_sym_type] = ACTIONS(1178),
    [anon_sym_namespace] = ACTIONS(1180),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_typeof] = ACTIONS(1202),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1178),
    [anon_sym_BANG] = ACTIONS(1186),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(1188),
    [anon_sym_yield] = ACTIONS(1190),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1192),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1526),
    [anon_sym_using] = ACTIONS(1196),
    [anon_sym_PLUS] = ACTIONS(1202),
    [anon_sym_DASH] = ACTIONS(1202),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(1186),
    [anon_sym_void] = ACTIONS(1202),
    [anon_sym_delete] = ACTIONS(1202),
    [anon_sym_PLUS_PLUS] = ACTIONS(1204),
    [anon_sym_DASH_DASH] = ACTIONS(1204),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(1206),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1528),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1178),
    [anon_sym_readonly] = ACTIONS(1178),
    [anon_sym_get] = ACTIONS(1178),
    [anon_sym_set] = ACTIONS(1178),
    [anon_sym_declare] = ACTIONS(1178),
    [anon_sym_public] = ACTIONS(1178),
    [anon_sym_private] = ACTIONS(1178),
    [anon_sym_protected] = ACTIONS(1178),
    [anon_sym_override] = ACTIONS(1178),
    [anon_sym_module] = ACTIONS(1178),
    [anon_sym_any] = ACTIONS(1178),
    [anon_sym_number] = ACTIONS(1178),
    [anon_sym_boolean] = ACTIONS(1178),
    [anon_sym_string] = ACTIONS(1178),
    [anon_sym_symbol] = ACTIONS(1178),
    [anon_sym_object] = ACTIONS(1178),
    [sym_html_comment] = ACTIONS(5),
  },
  [643] = {
    [sym_import] = STATE(3636),
    [sym_parenthesized_expression] = STATE(1362),
    [sym_expression] = STATE(1872),
    [sym_primary_expression] = STATE(1810),
    [sym_yield_expression] = STATE(2358),
    [sym_object] = STATE(2222),
    [sym_object_pattern] = STATE(5492),
    [sym_array] = STATE(2222),
    [sym_array_pattern] = STATE(5492),
    [sym_class] = STATE(2222),
    [sym_function_expression] = STATE(2222),
    [sym_generator_function] = STATE(2222),
    [sym_arrow_function] = STATE(2222),
    [sym__call_signature] = STATE(5821),
    [sym_call_expression] = STATE(2222),
    [sym_new_expression] = STATE(1948),
    [sym_await_expression] = STATE(2358),
    [sym_member_expression] = STATE(1362),
    [sym_subscript_expression] = STATE(1362),
    [sym_assignment_expression] = STATE(2358),
    [sym__augmented_assignment_lhs] = STATE(3025),
    [sym_augmented_assignment_expression] = STATE(2358),
    [sym__destructuring_pattern] = STATE(5492),
    [sym_ternary_expression] = STATE(2358),
    [sym_binary_expression] = STATE(2358),
    [sym_unary_expression] = STATE(2358),
    [sym_update_expression] = STATE(2358),
    [sym_string] = STATE(2222),
    [sym_template_string] = STATE(2222),
    [sym_regex] = STATE(2222),
    [sym_meta_property] = STATE(2222),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1362),
    [sym_type_assertion] = STATE(2358),
    [sym_as_expression] = STATE(2358),
    [sym_satisfies_expression] = STATE(2358),
    [sym_instantiation_expression] = STATE(2358),
    [sym_internal_module] = STATE(2358),
    [sym_type_arguments] = STATE(428),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4408),
    [sym_identifier] = ACTIONS(1468),
    [anon_sym_export] = ACTIONS(1352),
    [anon_sym_type] = ACTIONS(1352),
    [anon_sym_namespace] = ACTIONS(1354),
    [anon_sym_LBRACE] = ACTIONS(665),
    [anon_sym_typeof] = ACTIONS(21),
    [anon_sym_import] = ACTIONS(669),
    [anon_sym_let] = ACTIONS(1352),
    [anon_sym_BANG] = ACTIONS(33),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_await] = ACTIONS(45),
    [anon_sym_yield] = ACTIONS(63),
    [anon_sym_LBRACK] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(676),
    [anon_sym_async] = ACTIONS(1362),
    [anon_sym_function] = ACTIONS(680),
    [anon_sym_new] = ACTIONS(1472),
    [anon_sym_using] = ACTIONS(75),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_SLASH] = ACTIONS(77),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(33),
    [anon_sym_void] = ACTIONS(21),
    [anon_sym_delete] = ACTIONS(21),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_DQUOTE] = ACTIONS(83),
    [anon_sym_SQUOTE] = ACTIONS(85),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(87),
    [sym_number] = ACTIONS(89),
    [sym_private_property_identifier] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(93),
    [sym_true] = ACTIONS(93),
    [sym_false] = ACTIONS(93),
    [sym_null] = ACTIONS(93),
    [sym_undefined] = ACTIONS(95),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1352),
    [anon_sym_readonly] = ACTIONS(1352),
    [anon_sym_get] = ACTIONS(1352),
    [anon_sym_set] = ACTIONS(1352),
    [anon_sym_declare] = ACTIONS(1352),
    [anon_sym_public] = ACTIONS(1352),
    [anon_sym_private] = ACTIONS(1352),
    [anon_sym_protected] = ACTIONS(1352),
    [anon_sym_override] = ACTIONS(1352),
    [anon_sym_module] = ACTIONS(1352),
    [anon_sym_any] = ACTIONS(1352),
    [anon_sym_number] = ACTIONS(1352),
    [anon_sym_boolean] = ACTIONS(1352),
    [anon_sym_string] = ACTIONS(1352),
    [anon_sym_symbol] = ACTIONS(1352),
    [anon_sym_object] = ACTIONS(1352),
    [sym_html_comment] = ACTIONS(5),
  },
  [644] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1457),
    [sym_expression] = STATE(2414),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5823),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5823),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5477),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1457),
    [sym_subscript_expression] = STATE(1457),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(2986),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5823),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1457),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(620),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1522),
    [anon_sym_export] = ACTIONS(1178),
    [anon_sym_type] = ACTIONS(1178),
    [anon_sym_namespace] = ACTIONS(1180),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_typeof] = ACTIONS(1202),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1178),
    [anon_sym_BANG] = ACTIONS(1186),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(1188),
    [anon_sym_yield] = ACTIONS(1190),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1192),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1526),
    [anon_sym_using] = ACTIONS(1196),
    [anon_sym_PLUS] = ACTIONS(1202),
    [anon_sym_DASH] = ACTIONS(1202),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(1186),
    [anon_sym_void] = ACTIONS(1202),
    [anon_sym_delete] = ACTIONS(1202),
    [anon_sym_PLUS_PLUS] = ACTIONS(1204),
    [anon_sym_DASH_DASH] = ACTIONS(1204),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(1206),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1528),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1178),
    [anon_sym_readonly] = ACTIONS(1178),
    [anon_sym_get] = ACTIONS(1178),
    [anon_sym_set] = ACTIONS(1178),
    [anon_sym_declare] = ACTIONS(1178),
    [anon_sym_public] = ACTIONS(1178),
    [anon_sym_private] = ACTIONS(1178),
    [anon_sym_protected] = ACTIONS(1178),
    [anon_sym_override] = ACTIONS(1178),
    [anon_sym_module] = ACTIONS(1178),
    [anon_sym_any] = ACTIONS(1178),
    [anon_sym_number] = ACTIONS(1178),
    [anon_sym_boolean] = ACTIONS(1178),
    [anon_sym_string] = ACTIONS(1178),
    [anon_sym_symbol] = ACTIONS(1178),
    [anon_sym_object] = ACTIONS(1178),
    [sym_html_comment] = ACTIONS(5),
  },
  [645] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1457),
    [sym_expression] = STATE(2415),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5823),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5823),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5477),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1457),
    [sym_subscript_expression] = STATE(1457),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(2986),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5823),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1457),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(620),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1522),
    [anon_sym_export] = ACTIONS(1178),
    [anon_sym_type] = ACTIONS(1178),
    [anon_sym_namespace] = ACTIONS(1180),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_typeof] = ACTIONS(1202),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1178),
    [anon_sym_BANG] = ACTIONS(1186),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(1188),
    [anon_sym_yield] = ACTIONS(1190),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1192),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1526),
    [anon_sym_using] = ACTIONS(1196),
    [anon_sym_PLUS] = ACTIONS(1202),
    [anon_sym_DASH] = ACTIONS(1202),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(1186),
    [anon_sym_void] = ACTIONS(1202),
    [anon_sym_delete] = ACTIONS(1202),
    [anon_sym_PLUS_PLUS] = ACTIONS(1204),
    [anon_sym_DASH_DASH] = ACTIONS(1204),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(1206),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1528),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1178),
    [anon_sym_readonly] = ACTIONS(1178),
    [anon_sym_get] = ACTIONS(1178),
    [anon_sym_set] = ACTIONS(1178),
    [anon_sym_declare] = ACTIONS(1178),
    [anon_sym_public] = ACTIONS(1178),
    [anon_sym_private] = ACTIONS(1178),
    [anon_sym_protected] = ACTIONS(1178),
    [anon_sym_override] = ACTIONS(1178),
    [anon_sym_module] = ACTIONS(1178),
    [anon_sym_any] = ACTIONS(1178),
    [anon_sym_number] = ACTIONS(1178),
    [anon_sym_boolean] = ACTIONS(1178),
    [anon_sym_string] = ACTIONS(1178),
    [anon_sym_symbol] = ACTIONS(1178),
    [anon_sym_object] = ACTIONS(1178),
    [sym_html_comment] = ACTIONS(5),
  },
  [646] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1470),
    [sym_expression] = STATE(2644),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5489),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5489),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5800),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1470),
    [sym_subscript_expression] = STATE(1470),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3013),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5489),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1470),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(539),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(2263),
    [anon_sym_export] = ACTIONS(2265),
    [anon_sym_type] = ACTIONS(2265),
    [anon_sym_namespace] = ACTIONS(2267),
    [anon_sym_LBRACE] = ACTIONS(808),
    [anon_sym_typeof] = ACTIONS(179),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(2265),
    [anon_sym_BANG] = ACTIONS(175),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(140),
    [anon_sym_yield] = ACTIONS(142),
    [anon_sym_LBRACK] = ACTIONS(812),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(2269),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(2271),
    [anon_sym_using] = ACTIONS(158),
    [anon_sym_PLUS] = ACTIONS(179),
    [anon_sym_DASH] = ACTIONS(179),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(175),
    [anon_sym_void] = ACTIONS(179),
    [anon_sym_delete] = ACTIONS(179),
    [anon_sym_PLUS_PLUS] = ACTIONS(686),
    [anon_sym_DASH_DASH] = ACTIONS(686),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(192),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(2273),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(2265),
    [anon_sym_readonly] = ACTIONS(2265),
    [anon_sym_get] = ACTIONS(2265),
    [anon_sym_set] = ACTIONS(2265),
    [anon_sym_declare] = ACTIONS(2265),
    [anon_sym_public] = ACTIONS(2265),
    [anon_sym_private] = ACTIONS(2265),
    [anon_sym_protected] = ACTIONS(2265),
    [anon_sym_override] = ACTIONS(2265),
    [anon_sym_module] = ACTIONS(2265),
    [anon_sym_any] = ACTIONS(2265),
    [anon_sym_number] = ACTIONS(2265),
    [anon_sym_boolean] = ACTIONS(2265),
    [anon_sym_string] = ACTIONS(2265),
    [anon_sym_symbol] = ACTIONS(2265),
    [anon_sym_object] = ACTIONS(2265),
    [sym_html_comment] = ACTIONS(5),
  },
  [647] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1459),
    [sym_expression] = STATE(2484),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5827),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5827),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5529),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1459),
    [sym_subscript_expression] = STATE(1459),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(2979),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5827),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1459),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(647),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1514),
    [anon_sym_export] = ACTIONS(1074),
    [anon_sym_type] = ACTIONS(1074),
    [anon_sym_namespace] = ACTIONS(1076),
    [anon_sym_LBRACE] = ACTIONS(808),
    [anon_sym_typeof] = ACTIONS(1100),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1074),
    [anon_sym_BANG] = ACTIONS(1082),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(1084),
    [anon_sym_yield] = ACTIONS(1086),
    [anon_sym_LBRACK] = ACTIONS(812),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1090),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1518),
    [anon_sym_using] = ACTIONS(1094),
    [anon_sym_PLUS] = ACTIONS(1100),
    [anon_sym_DASH] = ACTIONS(1100),
    [anon_sym_SLASH] = ACTIONS(958),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(1082),
    [anon_sym_void] = ACTIONS(1100),
    [anon_sym_delete] = ACTIONS(1100),
    [anon_sym_PLUS_PLUS] = ACTIONS(1102),
    [anon_sym_DASH_DASH] = ACTIONS(1102),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(1108),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1520),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1074),
    [anon_sym_readonly] = ACTIONS(1074),
    [anon_sym_get] = ACTIONS(1074),
    [anon_sym_set] = ACTIONS(1074),
    [anon_sym_declare] = ACTIONS(1074),
    [anon_sym_public] = ACTIONS(1074),
    [anon_sym_private] = ACTIONS(1074),
    [anon_sym_protected] = ACTIONS(1074),
    [anon_sym_override] = ACTIONS(1074),
    [anon_sym_module] = ACTIONS(1074),
    [anon_sym_any] = ACTIONS(1074),
    [anon_sym_number] = ACTIONS(1074),
    [anon_sym_boolean] = ACTIONS(1074),
    [anon_sym_string] = ACTIONS(1074),
    [anon_sym_symbol] = ACTIONS(1074),
    [anon_sym_object] = ACTIONS(1074),
    [sym_html_comment] = ACTIONS(5),
  },
  [648] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1459),
    [sym_expression] = STATE(2486),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5827),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5827),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5529),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1459),
    [sym_subscript_expression] = STATE(1459),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(2979),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5827),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1459),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(647),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1514),
    [anon_sym_export] = ACTIONS(1074),
    [anon_sym_type] = ACTIONS(1074),
    [anon_sym_namespace] = ACTIONS(1076),
    [anon_sym_LBRACE] = ACTIONS(808),
    [anon_sym_typeof] = ACTIONS(1100),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1074),
    [anon_sym_BANG] = ACTIONS(1082),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(1084),
    [anon_sym_yield] = ACTIONS(1086),
    [anon_sym_LBRACK] = ACTIONS(812),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1090),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1518),
    [anon_sym_using] = ACTIONS(1094),
    [anon_sym_PLUS] = ACTIONS(1100),
    [anon_sym_DASH] = ACTIONS(1100),
    [anon_sym_SLASH] = ACTIONS(958),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(1082),
    [anon_sym_void] = ACTIONS(1100),
    [anon_sym_delete] = ACTIONS(1100),
    [anon_sym_PLUS_PLUS] = ACTIONS(1102),
    [anon_sym_DASH_DASH] = ACTIONS(1102),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(1108),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1520),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1074),
    [anon_sym_readonly] = ACTIONS(1074),
    [anon_sym_get] = ACTIONS(1074),
    [anon_sym_set] = ACTIONS(1074),
    [anon_sym_declare] = ACTIONS(1074),
    [anon_sym_public] = ACTIONS(1074),
    [anon_sym_private] = ACTIONS(1074),
    [anon_sym_protected] = ACTIONS(1074),
    [anon_sym_override] = ACTIONS(1074),
    [anon_sym_module] = ACTIONS(1074),
    [anon_sym_any] = ACTIONS(1074),
    [anon_sym_number] = ACTIONS(1074),
    [anon_sym_boolean] = ACTIONS(1074),
    [anon_sym_string] = ACTIONS(1074),
    [anon_sym_symbol] = ACTIONS(1074),
    [anon_sym_object] = ACTIONS(1074),
    [sym_html_comment] = ACTIONS(5),
  },
  [649] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1459),
    [sym_expression] = STATE(2487),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5827),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5827),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5529),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1459),
    [sym_subscript_expression] = STATE(1459),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(2979),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5827),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1459),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(647),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1514),
    [anon_sym_export] = ACTIONS(1074),
    [anon_sym_type] = ACTIONS(1074),
    [anon_sym_namespace] = ACTIONS(1076),
    [anon_sym_LBRACE] = ACTIONS(808),
    [anon_sym_typeof] = ACTIONS(1100),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1074),
    [anon_sym_BANG] = ACTIONS(1082),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(1084),
    [anon_sym_yield] = ACTIONS(1086),
    [anon_sym_LBRACK] = ACTIONS(812),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1090),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1518),
    [anon_sym_using] = ACTIONS(1094),
    [anon_sym_PLUS] = ACTIONS(1100),
    [anon_sym_DASH] = ACTIONS(1100),
    [anon_sym_SLASH] = ACTIONS(958),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(1082),
    [anon_sym_void] = ACTIONS(1100),
    [anon_sym_delete] = ACTIONS(1100),
    [anon_sym_PLUS_PLUS] = ACTIONS(1102),
    [anon_sym_DASH_DASH] = ACTIONS(1102),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(1108),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1520),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1074),
    [anon_sym_readonly] = ACTIONS(1074),
    [anon_sym_get] = ACTIONS(1074),
    [anon_sym_set] = ACTIONS(1074),
    [anon_sym_declare] = ACTIONS(1074),
    [anon_sym_public] = ACTIONS(1074),
    [anon_sym_private] = ACTIONS(1074),
    [anon_sym_protected] = ACTIONS(1074),
    [anon_sym_override] = ACTIONS(1074),
    [anon_sym_module] = ACTIONS(1074),
    [anon_sym_any] = ACTIONS(1074),
    [anon_sym_number] = ACTIONS(1074),
    [anon_sym_boolean] = ACTIONS(1074),
    [anon_sym_string] = ACTIONS(1074),
    [anon_sym_symbol] = ACTIONS(1074),
    [anon_sym_object] = ACTIONS(1074),
    [sym_html_comment] = ACTIONS(5),
  },
  [650] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1459),
    [sym_expression] = STATE(2488),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5827),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5827),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5529),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1459),
    [sym_subscript_expression] = STATE(1459),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(2979),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5827),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1459),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(647),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1514),
    [anon_sym_export] = ACTIONS(1074),
    [anon_sym_type] = ACTIONS(1074),
    [anon_sym_namespace] = ACTIONS(1076),
    [anon_sym_LBRACE] = ACTIONS(808),
    [anon_sym_typeof] = ACTIONS(1100),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1074),
    [anon_sym_BANG] = ACTIONS(1082),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(1084),
    [anon_sym_yield] = ACTIONS(1086),
    [anon_sym_LBRACK] = ACTIONS(812),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1090),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1518),
    [anon_sym_using] = ACTIONS(1094),
    [anon_sym_PLUS] = ACTIONS(1100),
    [anon_sym_DASH] = ACTIONS(1100),
    [anon_sym_SLASH] = ACTIONS(958),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(1082),
    [anon_sym_void] = ACTIONS(1100),
    [anon_sym_delete] = ACTIONS(1100),
    [anon_sym_PLUS_PLUS] = ACTIONS(1102),
    [anon_sym_DASH_DASH] = ACTIONS(1102),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(1108),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1520),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1074),
    [anon_sym_readonly] = ACTIONS(1074),
    [anon_sym_get] = ACTIONS(1074),
    [anon_sym_set] = ACTIONS(1074),
    [anon_sym_declare] = ACTIONS(1074),
    [anon_sym_public] = ACTIONS(1074),
    [anon_sym_private] = ACTIONS(1074),
    [anon_sym_protected] = ACTIONS(1074),
    [anon_sym_override] = ACTIONS(1074),
    [anon_sym_module] = ACTIONS(1074),
    [anon_sym_any] = ACTIONS(1074),
    [anon_sym_number] = ACTIONS(1074),
    [anon_sym_boolean] = ACTIONS(1074),
    [anon_sym_string] = ACTIONS(1074),
    [anon_sym_symbol] = ACTIONS(1074),
    [anon_sym_object] = ACTIONS(1074),
    [sym_html_comment] = ACTIONS(5),
  },
  [651] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1459),
    [sym_expression] = STATE(2490),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5827),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5827),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5529),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1459),
    [sym_subscript_expression] = STATE(1459),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(2979),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5827),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1459),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(647),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1514),
    [anon_sym_export] = ACTIONS(1074),
    [anon_sym_type] = ACTIONS(1074),
    [anon_sym_namespace] = ACTIONS(1076),
    [anon_sym_LBRACE] = ACTIONS(808),
    [anon_sym_typeof] = ACTIONS(1100),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1074),
    [anon_sym_BANG] = ACTIONS(1082),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(1084),
    [anon_sym_yield] = ACTIONS(1086),
    [anon_sym_LBRACK] = ACTIONS(812),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1090),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1518),
    [anon_sym_using] = ACTIONS(1094),
    [anon_sym_PLUS] = ACTIONS(1100),
    [anon_sym_DASH] = ACTIONS(1100),
    [anon_sym_SLASH] = ACTIONS(958),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(1082),
    [anon_sym_void] = ACTIONS(1100),
    [anon_sym_delete] = ACTIONS(1100),
    [anon_sym_PLUS_PLUS] = ACTIONS(1102),
    [anon_sym_DASH_DASH] = ACTIONS(1102),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(1108),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1520),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1074),
    [anon_sym_readonly] = ACTIONS(1074),
    [anon_sym_get] = ACTIONS(1074),
    [anon_sym_set] = ACTIONS(1074),
    [anon_sym_declare] = ACTIONS(1074),
    [anon_sym_public] = ACTIONS(1074),
    [anon_sym_private] = ACTIONS(1074),
    [anon_sym_protected] = ACTIONS(1074),
    [anon_sym_override] = ACTIONS(1074),
    [anon_sym_module] = ACTIONS(1074),
    [anon_sym_any] = ACTIONS(1074),
    [anon_sym_number] = ACTIONS(1074),
    [anon_sym_boolean] = ACTIONS(1074),
    [anon_sym_string] = ACTIONS(1074),
    [anon_sym_symbol] = ACTIONS(1074),
    [anon_sym_object] = ACTIONS(1074),
    [sym_html_comment] = ACTIONS(5),
  },
  [652] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1459),
    [sym_expression] = STATE(2491),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5827),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5827),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5529),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1459),
    [sym_subscript_expression] = STATE(1459),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(2979),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5827),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1459),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(647),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1514),
    [anon_sym_export] = ACTIONS(1074),
    [anon_sym_type] = ACTIONS(1074),
    [anon_sym_namespace] = ACTIONS(1076),
    [anon_sym_LBRACE] = ACTIONS(808),
    [anon_sym_typeof] = ACTIONS(1100),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1074),
    [anon_sym_BANG] = ACTIONS(1082),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(1084),
    [anon_sym_yield] = ACTIONS(1086),
    [anon_sym_LBRACK] = ACTIONS(812),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1090),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1518),
    [anon_sym_using] = ACTIONS(1094),
    [anon_sym_PLUS] = ACTIONS(1100),
    [anon_sym_DASH] = ACTIONS(1100),
    [anon_sym_SLASH] = ACTIONS(958),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(1082),
    [anon_sym_void] = ACTIONS(1100),
    [anon_sym_delete] = ACTIONS(1100),
    [anon_sym_PLUS_PLUS] = ACTIONS(1102),
    [anon_sym_DASH_DASH] = ACTIONS(1102),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(1108),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1520),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1074),
    [anon_sym_readonly] = ACTIONS(1074),
    [anon_sym_get] = ACTIONS(1074),
    [anon_sym_set] = ACTIONS(1074),
    [anon_sym_declare] = ACTIONS(1074),
    [anon_sym_public] = ACTIONS(1074),
    [anon_sym_private] = ACTIONS(1074),
    [anon_sym_protected] = ACTIONS(1074),
    [anon_sym_override] = ACTIONS(1074),
    [anon_sym_module] = ACTIONS(1074),
    [anon_sym_any] = ACTIONS(1074),
    [anon_sym_number] = ACTIONS(1074),
    [anon_sym_boolean] = ACTIONS(1074),
    [anon_sym_string] = ACTIONS(1074),
    [anon_sym_symbol] = ACTIONS(1074),
    [anon_sym_object] = ACTIONS(1074),
    [sym_html_comment] = ACTIONS(5),
  },
  [653] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1459),
    [sym_expression] = STATE(2492),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5827),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5827),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5529),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1459),
    [sym_subscript_expression] = STATE(1459),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(2979),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5827),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1459),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(647),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1514),
    [anon_sym_export] = ACTIONS(1074),
    [anon_sym_type] = ACTIONS(1074),
    [anon_sym_namespace] = ACTIONS(1076),
    [anon_sym_LBRACE] = ACTIONS(808),
    [anon_sym_typeof] = ACTIONS(1100),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1074),
    [anon_sym_BANG] = ACTIONS(1082),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(1084),
    [anon_sym_yield] = ACTIONS(1086),
    [anon_sym_LBRACK] = ACTIONS(812),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1090),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1518),
    [anon_sym_using] = ACTIONS(1094),
    [anon_sym_PLUS] = ACTIONS(1100),
    [anon_sym_DASH] = ACTIONS(1100),
    [anon_sym_SLASH] = ACTIONS(958),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(1082),
    [anon_sym_void] = ACTIONS(1100),
    [anon_sym_delete] = ACTIONS(1100),
    [anon_sym_PLUS_PLUS] = ACTIONS(1102),
    [anon_sym_DASH_DASH] = ACTIONS(1102),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(1108),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1520),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1074),
    [anon_sym_readonly] = ACTIONS(1074),
    [anon_sym_get] = ACTIONS(1074),
    [anon_sym_set] = ACTIONS(1074),
    [anon_sym_declare] = ACTIONS(1074),
    [anon_sym_public] = ACTIONS(1074),
    [anon_sym_private] = ACTIONS(1074),
    [anon_sym_protected] = ACTIONS(1074),
    [anon_sym_override] = ACTIONS(1074),
    [anon_sym_module] = ACTIONS(1074),
    [anon_sym_any] = ACTIONS(1074),
    [anon_sym_number] = ACTIONS(1074),
    [anon_sym_boolean] = ACTIONS(1074),
    [anon_sym_string] = ACTIONS(1074),
    [anon_sym_symbol] = ACTIONS(1074),
    [anon_sym_object] = ACTIONS(1074),
    [sym_html_comment] = ACTIONS(5),
  },
  [654] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1459),
    [sym_expression] = STATE(2493),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5827),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5827),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5529),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1459),
    [sym_subscript_expression] = STATE(1459),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(2979),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5827),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1459),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(647),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1514),
    [anon_sym_export] = ACTIONS(1074),
    [anon_sym_type] = ACTIONS(1074),
    [anon_sym_namespace] = ACTIONS(1076),
    [anon_sym_LBRACE] = ACTIONS(808),
    [anon_sym_typeof] = ACTIONS(1100),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1074),
    [anon_sym_BANG] = ACTIONS(1082),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(1084),
    [anon_sym_yield] = ACTIONS(1086),
    [anon_sym_LBRACK] = ACTIONS(812),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1090),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1518),
    [anon_sym_using] = ACTIONS(1094),
    [anon_sym_PLUS] = ACTIONS(1100),
    [anon_sym_DASH] = ACTIONS(1100),
    [anon_sym_SLASH] = ACTIONS(958),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(1082),
    [anon_sym_void] = ACTIONS(1100),
    [anon_sym_delete] = ACTIONS(1100),
    [anon_sym_PLUS_PLUS] = ACTIONS(1102),
    [anon_sym_DASH_DASH] = ACTIONS(1102),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(1108),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1520),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1074),
    [anon_sym_readonly] = ACTIONS(1074),
    [anon_sym_get] = ACTIONS(1074),
    [anon_sym_set] = ACTIONS(1074),
    [anon_sym_declare] = ACTIONS(1074),
    [anon_sym_public] = ACTIONS(1074),
    [anon_sym_private] = ACTIONS(1074),
    [anon_sym_protected] = ACTIONS(1074),
    [anon_sym_override] = ACTIONS(1074),
    [anon_sym_module] = ACTIONS(1074),
    [anon_sym_any] = ACTIONS(1074),
    [anon_sym_number] = ACTIONS(1074),
    [anon_sym_boolean] = ACTIONS(1074),
    [anon_sym_string] = ACTIONS(1074),
    [anon_sym_symbol] = ACTIONS(1074),
    [anon_sym_object] = ACTIONS(1074),
    [sym_html_comment] = ACTIONS(5),
  },
  [655] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1459),
    [sym_expression] = STATE(2494),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5827),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5827),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5529),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1459),
    [sym_subscript_expression] = STATE(1459),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(2979),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5827),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1459),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(647),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1514),
    [anon_sym_export] = ACTIONS(1074),
    [anon_sym_type] = ACTIONS(1074),
    [anon_sym_namespace] = ACTIONS(1076),
    [anon_sym_LBRACE] = ACTIONS(808),
    [anon_sym_typeof] = ACTIONS(1100),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1074),
    [anon_sym_BANG] = ACTIONS(1082),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(1084),
    [anon_sym_yield] = ACTIONS(1086),
    [anon_sym_LBRACK] = ACTIONS(812),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1090),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1518),
    [anon_sym_using] = ACTIONS(1094),
    [anon_sym_PLUS] = ACTIONS(1100),
    [anon_sym_DASH] = ACTIONS(1100),
    [anon_sym_SLASH] = ACTIONS(958),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(1082),
    [anon_sym_void] = ACTIONS(1100),
    [anon_sym_delete] = ACTIONS(1100),
    [anon_sym_PLUS_PLUS] = ACTIONS(1102),
    [anon_sym_DASH_DASH] = ACTIONS(1102),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(1108),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1520),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1074),
    [anon_sym_readonly] = ACTIONS(1074),
    [anon_sym_get] = ACTIONS(1074),
    [anon_sym_set] = ACTIONS(1074),
    [anon_sym_declare] = ACTIONS(1074),
    [anon_sym_public] = ACTIONS(1074),
    [anon_sym_private] = ACTIONS(1074),
    [anon_sym_protected] = ACTIONS(1074),
    [anon_sym_override] = ACTIONS(1074),
    [anon_sym_module] = ACTIONS(1074),
    [anon_sym_any] = ACTIONS(1074),
    [anon_sym_number] = ACTIONS(1074),
    [anon_sym_boolean] = ACTIONS(1074),
    [anon_sym_string] = ACTIONS(1074),
    [anon_sym_symbol] = ACTIONS(1074),
    [anon_sym_object] = ACTIONS(1074),
    [sym_html_comment] = ACTIONS(5),
  },
  [656] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1459),
    [sym_expression] = STATE(2495),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5827),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5827),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5529),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1459),
    [sym_subscript_expression] = STATE(1459),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(2979),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5827),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1459),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(647),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1514),
    [anon_sym_export] = ACTIONS(1074),
    [anon_sym_type] = ACTIONS(1074),
    [anon_sym_namespace] = ACTIONS(1076),
    [anon_sym_LBRACE] = ACTIONS(808),
    [anon_sym_typeof] = ACTIONS(1100),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1074),
    [anon_sym_BANG] = ACTIONS(1082),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(1084),
    [anon_sym_yield] = ACTIONS(1086),
    [anon_sym_LBRACK] = ACTIONS(812),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1090),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1518),
    [anon_sym_using] = ACTIONS(1094),
    [anon_sym_PLUS] = ACTIONS(1100),
    [anon_sym_DASH] = ACTIONS(1100),
    [anon_sym_SLASH] = ACTIONS(958),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(1082),
    [anon_sym_void] = ACTIONS(1100),
    [anon_sym_delete] = ACTIONS(1100),
    [anon_sym_PLUS_PLUS] = ACTIONS(1102),
    [anon_sym_DASH_DASH] = ACTIONS(1102),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(1108),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1520),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1074),
    [anon_sym_readonly] = ACTIONS(1074),
    [anon_sym_get] = ACTIONS(1074),
    [anon_sym_set] = ACTIONS(1074),
    [anon_sym_declare] = ACTIONS(1074),
    [anon_sym_public] = ACTIONS(1074),
    [anon_sym_private] = ACTIONS(1074),
    [anon_sym_protected] = ACTIONS(1074),
    [anon_sym_override] = ACTIONS(1074),
    [anon_sym_module] = ACTIONS(1074),
    [anon_sym_any] = ACTIONS(1074),
    [anon_sym_number] = ACTIONS(1074),
    [anon_sym_boolean] = ACTIONS(1074),
    [anon_sym_string] = ACTIONS(1074),
    [anon_sym_symbol] = ACTIONS(1074),
    [anon_sym_object] = ACTIONS(1074),
    [sym_html_comment] = ACTIONS(5),
  },
  [657] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1459),
    [sym_expression] = STATE(2496),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5827),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5827),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5529),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1459),
    [sym_subscript_expression] = STATE(1459),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(2979),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5827),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1459),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(647),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1514),
    [anon_sym_export] = ACTIONS(1074),
    [anon_sym_type] = ACTIONS(1074),
    [anon_sym_namespace] = ACTIONS(1076),
    [anon_sym_LBRACE] = ACTIONS(808),
    [anon_sym_typeof] = ACTIONS(1100),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1074),
    [anon_sym_BANG] = ACTIONS(1082),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(1084),
    [anon_sym_yield] = ACTIONS(1086),
    [anon_sym_LBRACK] = ACTIONS(812),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1090),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1518),
    [anon_sym_using] = ACTIONS(1094),
    [anon_sym_PLUS] = ACTIONS(1100),
    [anon_sym_DASH] = ACTIONS(1100),
    [anon_sym_SLASH] = ACTIONS(958),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(1082),
    [anon_sym_void] = ACTIONS(1100),
    [anon_sym_delete] = ACTIONS(1100),
    [anon_sym_PLUS_PLUS] = ACTIONS(1102),
    [anon_sym_DASH_DASH] = ACTIONS(1102),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(1108),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1520),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1074),
    [anon_sym_readonly] = ACTIONS(1074),
    [anon_sym_get] = ACTIONS(1074),
    [anon_sym_set] = ACTIONS(1074),
    [anon_sym_declare] = ACTIONS(1074),
    [anon_sym_public] = ACTIONS(1074),
    [anon_sym_private] = ACTIONS(1074),
    [anon_sym_protected] = ACTIONS(1074),
    [anon_sym_override] = ACTIONS(1074),
    [anon_sym_module] = ACTIONS(1074),
    [anon_sym_any] = ACTIONS(1074),
    [anon_sym_number] = ACTIONS(1074),
    [anon_sym_boolean] = ACTIONS(1074),
    [anon_sym_string] = ACTIONS(1074),
    [anon_sym_symbol] = ACTIONS(1074),
    [anon_sym_object] = ACTIONS(1074),
    [sym_html_comment] = ACTIONS(5),
  },
  [658] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1459),
    [sym_expression] = STATE(2497),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5827),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5827),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5529),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1459),
    [sym_subscript_expression] = STATE(1459),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(2979),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5827),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1459),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(647),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1514),
    [anon_sym_export] = ACTIONS(1074),
    [anon_sym_type] = ACTIONS(1074),
    [anon_sym_namespace] = ACTIONS(1076),
    [anon_sym_LBRACE] = ACTIONS(808),
    [anon_sym_typeof] = ACTIONS(1100),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1074),
    [anon_sym_BANG] = ACTIONS(1082),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(1084),
    [anon_sym_yield] = ACTIONS(1086),
    [anon_sym_LBRACK] = ACTIONS(812),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1090),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1518),
    [anon_sym_using] = ACTIONS(1094),
    [anon_sym_PLUS] = ACTIONS(1100),
    [anon_sym_DASH] = ACTIONS(1100),
    [anon_sym_SLASH] = ACTIONS(958),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(1082),
    [anon_sym_void] = ACTIONS(1100),
    [anon_sym_delete] = ACTIONS(1100),
    [anon_sym_PLUS_PLUS] = ACTIONS(1102),
    [anon_sym_DASH_DASH] = ACTIONS(1102),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(1108),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1520),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1074),
    [anon_sym_readonly] = ACTIONS(1074),
    [anon_sym_get] = ACTIONS(1074),
    [anon_sym_set] = ACTIONS(1074),
    [anon_sym_declare] = ACTIONS(1074),
    [anon_sym_public] = ACTIONS(1074),
    [anon_sym_private] = ACTIONS(1074),
    [anon_sym_protected] = ACTIONS(1074),
    [anon_sym_override] = ACTIONS(1074),
    [anon_sym_module] = ACTIONS(1074),
    [anon_sym_any] = ACTIONS(1074),
    [anon_sym_number] = ACTIONS(1074),
    [anon_sym_boolean] = ACTIONS(1074),
    [anon_sym_string] = ACTIONS(1074),
    [anon_sym_symbol] = ACTIONS(1074),
    [anon_sym_object] = ACTIONS(1074),
    [sym_html_comment] = ACTIONS(5),
  },
  [659] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1459),
    [sym_expression] = STATE(2498),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5827),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5827),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5529),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1459),
    [sym_subscript_expression] = STATE(1459),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(2979),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5827),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1459),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(647),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1514),
    [anon_sym_export] = ACTIONS(1074),
    [anon_sym_type] = ACTIONS(1074),
    [anon_sym_namespace] = ACTIONS(1076),
    [anon_sym_LBRACE] = ACTIONS(808),
    [anon_sym_typeof] = ACTIONS(1100),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1074),
    [anon_sym_BANG] = ACTIONS(1082),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(1084),
    [anon_sym_yield] = ACTIONS(1086),
    [anon_sym_LBRACK] = ACTIONS(812),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1090),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1518),
    [anon_sym_using] = ACTIONS(1094),
    [anon_sym_PLUS] = ACTIONS(1100),
    [anon_sym_DASH] = ACTIONS(1100),
    [anon_sym_SLASH] = ACTIONS(958),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(1082),
    [anon_sym_void] = ACTIONS(1100),
    [anon_sym_delete] = ACTIONS(1100),
    [anon_sym_PLUS_PLUS] = ACTIONS(1102),
    [anon_sym_DASH_DASH] = ACTIONS(1102),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(1108),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1520),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1074),
    [anon_sym_readonly] = ACTIONS(1074),
    [anon_sym_get] = ACTIONS(1074),
    [anon_sym_set] = ACTIONS(1074),
    [anon_sym_declare] = ACTIONS(1074),
    [anon_sym_public] = ACTIONS(1074),
    [anon_sym_private] = ACTIONS(1074),
    [anon_sym_protected] = ACTIONS(1074),
    [anon_sym_override] = ACTIONS(1074),
    [anon_sym_module] = ACTIONS(1074),
    [anon_sym_any] = ACTIONS(1074),
    [anon_sym_number] = ACTIONS(1074),
    [anon_sym_boolean] = ACTIONS(1074),
    [anon_sym_string] = ACTIONS(1074),
    [anon_sym_symbol] = ACTIONS(1074),
    [anon_sym_object] = ACTIONS(1074),
    [sym_html_comment] = ACTIONS(5),
  },
  [660] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1459),
    [sym_expression] = STATE(2499),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5827),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5827),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5529),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1459),
    [sym_subscript_expression] = STATE(1459),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(2979),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5827),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1459),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(647),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1514),
    [anon_sym_export] = ACTIONS(1074),
    [anon_sym_type] = ACTIONS(1074),
    [anon_sym_namespace] = ACTIONS(1076),
    [anon_sym_LBRACE] = ACTIONS(808),
    [anon_sym_typeof] = ACTIONS(1100),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1074),
    [anon_sym_BANG] = ACTIONS(1082),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(1084),
    [anon_sym_yield] = ACTIONS(1086),
    [anon_sym_LBRACK] = ACTIONS(812),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1090),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1518),
    [anon_sym_using] = ACTIONS(1094),
    [anon_sym_PLUS] = ACTIONS(1100),
    [anon_sym_DASH] = ACTIONS(1100),
    [anon_sym_SLASH] = ACTIONS(958),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(1082),
    [anon_sym_void] = ACTIONS(1100),
    [anon_sym_delete] = ACTIONS(1100),
    [anon_sym_PLUS_PLUS] = ACTIONS(1102),
    [anon_sym_DASH_DASH] = ACTIONS(1102),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(1108),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1520),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1074),
    [anon_sym_readonly] = ACTIONS(1074),
    [anon_sym_get] = ACTIONS(1074),
    [anon_sym_set] = ACTIONS(1074),
    [anon_sym_declare] = ACTIONS(1074),
    [anon_sym_public] = ACTIONS(1074),
    [anon_sym_private] = ACTIONS(1074),
    [anon_sym_protected] = ACTIONS(1074),
    [anon_sym_override] = ACTIONS(1074),
    [anon_sym_module] = ACTIONS(1074),
    [anon_sym_any] = ACTIONS(1074),
    [anon_sym_number] = ACTIONS(1074),
    [anon_sym_boolean] = ACTIONS(1074),
    [anon_sym_string] = ACTIONS(1074),
    [anon_sym_symbol] = ACTIONS(1074),
    [anon_sym_object] = ACTIONS(1074),
    [sym_html_comment] = ACTIONS(5),
  },
  [661] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1459),
    [sym_expression] = STATE(2500),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5827),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5827),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5529),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1459),
    [sym_subscript_expression] = STATE(1459),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(2979),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5827),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1459),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(647),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1514),
    [anon_sym_export] = ACTIONS(1074),
    [anon_sym_type] = ACTIONS(1074),
    [anon_sym_namespace] = ACTIONS(1076),
    [anon_sym_LBRACE] = ACTIONS(808),
    [anon_sym_typeof] = ACTIONS(1100),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1074),
    [anon_sym_BANG] = ACTIONS(1082),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(1084),
    [anon_sym_yield] = ACTIONS(1086),
    [anon_sym_LBRACK] = ACTIONS(812),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1090),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1518),
    [anon_sym_using] = ACTIONS(1094),
    [anon_sym_PLUS] = ACTIONS(1100),
    [anon_sym_DASH] = ACTIONS(1100),
    [anon_sym_SLASH] = ACTIONS(958),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(1082),
    [anon_sym_void] = ACTIONS(1100),
    [anon_sym_delete] = ACTIONS(1100),
    [anon_sym_PLUS_PLUS] = ACTIONS(1102),
    [anon_sym_DASH_DASH] = ACTIONS(1102),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(1108),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1520),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1074),
    [anon_sym_readonly] = ACTIONS(1074),
    [anon_sym_get] = ACTIONS(1074),
    [anon_sym_set] = ACTIONS(1074),
    [anon_sym_declare] = ACTIONS(1074),
    [anon_sym_public] = ACTIONS(1074),
    [anon_sym_private] = ACTIONS(1074),
    [anon_sym_protected] = ACTIONS(1074),
    [anon_sym_override] = ACTIONS(1074),
    [anon_sym_module] = ACTIONS(1074),
    [anon_sym_any] = ACTIONS(1074),
    [anon_sym_number] = ACTIONS(1074),
    [anon_sym_boolean] = ACTIONS(1074),
    [anon_sym_string] = ACTIONS(1074),
    [anon_sym_symbol] = ACTIONS(1074),
    [anon_sym_object] = ACTIONS(1074),
    [sym_html_comment] = ACTIONS(5),
  },
  [662] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1459),
    [sym_expression] = STATE(2501),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5827),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5827),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5529),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1459),
    [sym_subscript_expression] = STATE(1459),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(2979),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5827),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1459),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(647),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1514),
    [anon_sym_export] = ACTIONS(1074),
    [anon_sym_type] = ACTIONS(1074),
    [anon_sym_namespace] = ACTIONS(1076),
    [anon_sym_LBRACE] = ACTIONS(808),
    [anon_sym_typeof] = ACTIONS(1100),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1074),
    [anon_sym_BANG] = ACTIONS(1082),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(1084),
    [anon_sym_yield] = ACTIONS(1086),
    [anon_sym_LBRACK] = ACTIONS(812),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1090),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1518),
    [anon_sym_using] = ACTIONS(1094),
    [anon_sym_PLUS] = ACTIONS(1100),
    [anon_sym_DASH] = ACTIONS(1100),
    [anon_sym_SLASH] = ACTIONS(958),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(1082),
    [anon_sym_void] = ACTIONS(1100),
    [anon_sym_delete] = ACTIONS(1100),
    [anon_sym_PLUS_PLUS] = ACTIONS(1102),
    [anon_sym_DASH_DASH] = ACTIONS(1102),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(1108),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1520),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1074),
    [anon_sym_readonly] = ACTIONS(1074),
    [anon_sym_get] = ACTIONS(1074),
    [anon_sym_set] = ACTIONS(1074),
    [anon_sym_declare] = ACTIONS(1074),
    [anon_sym_public] = ACTIONS(1074),
    [anon_sym_private] = ACTIONS(1074),
    [anon_sym_protected] = ACTIONS(1074),
    [anon_sym_override] = ACTIONS(1074),
    [anon_sym_module] = ACTIONS(1074),
    [anon_sym_any] = ACTIONS(1074),
    [anon_sym_number] = ACTIONS(1074),
    [anon_sym_boolean] = ACTIONS(1074),
    [anon_sym_string] = ACTIONS(1074),
    [anon_sym_symbol] = ACTIONS(1074),
    [anon_sym_object] = ACTIONS(1074),
    [sym_html_comment] = ACTIONS(5),
  },
  [663] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1459),
    [sym_expression] = STATE(2503),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5827),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5827),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5529),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1459),
    [sym_subscript_expression] = STATE(1459),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(2979),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5827),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1459),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(647),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1514),
    [anon_sym_export] = ACTIONS(1074),
    [anon_sym_type] = ACTIONS(1074),
    [anon_sym_namespace] = ACTIONS(1076),
    [anon_sym_LBRACE] = ACTIONS(808),
    [anon_sym_typeof] = ACTIONS(1100),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1074),
    [anon_sym_BANG] = ACTIONS(1082),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(1084),
    [anon_sym_yield] = ACTIONS(1086),
    [anon_sym_LBRACK] = ACTIONS(812),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1090),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1518),
    [anon_sym_using] = ACTIONS(1094),
    [anon_sym_PLUS] = ACTIONS(1100),
    [anon_sym_DASH] = ACTIONS(1100),
    [anon_sym_SLASH] = ACTIONS(958),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(1082),
    [anon_sym_void] = ACTIONS(1100),
    [anon_sym_delete] = ACTIONS(1100),
    [anon_sym_PLUS_PLUS] = ACTIONS(1102),
    [anon_sym_DASH_DASH] = ACTIONS(1102),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(1108),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1520),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1074),
    [anon_sym_readonly] = ACTIONS(1074),
    [anon_sym_get] = ACTIONS(1074),
    [anon_sym_set] = ACTIONS(1074),
    [anon_sym_declare] = ACTIONS(1074),
    [anon_sym_public] = ACTIONS(1074),
    [anon_sym_private] = ACTIONS(1074),
    [anon_sym_protected] = ACTIONS(1074),
    [anon_sym_override] = ACTIONS(1074),
    [anon_sym_module] = ACTIONS(1074),
    [anon_sym_any] = ACTIONS(1074),
    [anon_sym_number] = ACTIONS(1074),
    [anon_sym_boolean] = ACTIONS(1074),
    [anon_sym_string] = ACTIONS(1074),
    [anon_sym_symbol] = ACTIONS(1074),
    [anon_sym_object] = ACTIONS(1074),
    [sym_html_comment] = ACTIONS(5),
  },
  [664] = {
    [sym_import] = STATE(3636),
    [sym_parenthesized_expression] = STATE(1362),
    [sym_expression] = STATE(1830),
    [sym_primary_expression] = STATE(1810),
    [sym_yield_expression] = STATE(2358),
    [sym_object] = STATE(2222),
    [sym_object_pattern] = STATE(5492),
    [sym_array] = STATE(2222),
    [sym_array_pattern] = STATE(5492),
    [sym_class] = STATE(2222),
    [sym_function_expression] = STATE(2222),
    [sym_generator_function] = STATE(2222),
    [sym_arrow_function] = STATE(2222),
    [sym__call_signature] = STATE(5821),
    [sym_call_expression] = STATE(2222),
    [sym_new_expression] = STATE(1948),
    [sym_await_expression] = STATE(2358),
    [sym_member_expression] = STATE(1362),
    [sym_subscript_expression] = STATE(1362),
    [sym_assignment_expression] = STATE(2358),
    [sym__augmented_assignment_lhs] = STATE(3025),
    [sym_augmented_assignment_expression] = STATE(2358),
    [sym__destructuring_pattern] = STATE(5492),
    [sym_ternary_expression] = STATE(2358),
    [sym_binary_expression] = STATE(2358),
    [sym_unary_expression] = STATE(2358),
    [sym_update_expression] = STATE(2358),
    [sym_string] = STATE(2222),
    [sym_template_string] = STATE(2222),
    [sym_regex] = STATE(2222),
    [sym_meta_property] = STATE(2222),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1362),
    [sym_type_assertion] = STATE(2358),
    [sym_as_expression] = STATE(2358),
    [sym_satisfies_expression] = STATE(2358),
    [sym_instantiation_expression] = STATE(2358),
    [sym_internal_module] = STATE(2358),
    [sym_type_arguments] = STATE(428),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4408),
    [sym_identifier] = ACTIONS(1468),
    [anon_sym_export] = ACTIONS(1352),
    [anon_sym_type] = ACTIONS(1352),
    [anon_sym_namespace] = ACTIONS(1354),
    [anon_sym_LBRACE] = ACTIONS(665),
    [anon_sym_typeof] = ACTIONS(21),
    [anon_sym_import] = ACTIONS(669),
    [anon_sym_let] = ACTIONS(1352),
    [anon_sym_BANG] = ACTIONS(33),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_await] = ACTIONS(45),
    [anon_sym_yield] = ACTIONS(63),
    [anon_sym_LBRACK] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(676),
    [anon_sym_async] = ACTIONS(1362),
    [anon_sym_function] = ACTIONS(680),
    [anon_sym_new] = ACTIONS(1472),
    [anon_sym_using] = ACTIONS(75),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_SLASH] = ACTIONS(77),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(33),
    [anon_sym_void] = ACTIONS(21),
    [anon_sym_delete] = ACTIONS(21),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_DQUOTE] = ACTIONS(83),
    [anon_sym_SQUOTE] = ACTIONS(85),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(87),
    [sym_number] = ACTIONS(89),
    [sym_private_property_identifier] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(93),
    [sym_true] = ACTIONS(93),
    [sym_false] = ACTIONS(93),
    [sym_null] = ACTIONS(93),
    [sym_undefined] = ACTIONS(95),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1352),
    [anon_sym_readonly] = ACTIONS(1352),
    [anon_sym_get] = ACTIONS(1352),
    [anon_sym_set] = ACTIONS(1352),
    [anon_sym_declare] = ACTIONS(1352),
    [anon_sym_public] = ACTIONS(1352),
    [anon_sym_private] = ACTIONS(1352),
    [anon_sym_protected] = ACTIONS(1352),
    [anon_sym_override] = ACTIONS(1352),
    [anon_sym_module] = ACTIONS(1352),
    [anon_sym_any] = ACTIONS(1352),
    [anon_sym_number] = ACTIONS(1352),
    [anon_sym_boolean] = ACTIONS(1352),
    [anon_sym_string] = ACTIONS(1352),
    [anon_sym_symbol] = ACTIONS(1352),
    [anon_sym_object] = ACTIONS(1352),
    [sym_html_comment] = ACTIONS(5),
  },
  [665] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1459),
    [sym_expression] = STATE(2507),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5827),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5827),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5529),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1459),
    [sym_subscript_expression] = STATE(1459),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(2979),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5827),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1459),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(647),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1514),
    [anon_sym_export] = ACTIONS(1074),
    [anon_sym_type] = ACTIONS(1074),
    [anon_sym_namespace] = ACTIONS(1076),
    [anon_sym_LBRACE] = ACTIONS(808),
    [anon_sym_typeof] = ACTIONS(1100),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1074),
    [anon_sym_BANG] = ACTIONS(1082),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(1084),
    [anon_sym_yield] = ACTIONS(1086),
    [anon_sym_LBRACK] = ACTIONS(812),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1090),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1518),
    [anon_sym_using] = ACTIONS(1094),
    [anon_sym_PLUS] = ACTIONS(1100),
    [anon_sym_DASH] = ACTIONS(1100),
    [anon_sym_SLASH] = ACTIONS(958),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(1082),
    [anon_sym_void] = ACTIONS(1100),
    [anon_sym_delete] = ACTIONS(1100),
    [anon_sym_PLUS_PLUS] = ACTIONS(1102),
    [anon_sym_DASH_DASH] = ACTIONS(1102),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(1108),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1520),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1074),
    [anon_sym_readonly] = ACTIONS(1074),
    [anon_sym_get] = ACTIONS(1074),
    [anon_sym_set] = ACTIONS(1074),
    [anon_sym_declare] = ACTIONS(1074),
    [anon_sym_public] = ACTIONS(1074),
    [anon_sym_private] = ACTIONS(1074),
    [anon_sym_protected] = ACTIONS(1074),
    [anon_sym_override] = ACTIONS(1074),
    [anon_sym_module] = ACTIONS(1074),
    [anon_sym_any] = ACTIONS(1074),
    [anon_sym_number] = ACTIONS(1074),
    [anon_sym_boolean] = ACTIONS(1074),
    [anon_sym_string] = ACTIONS(1074),
    [anon_sym_symbol] = ACTIONS(1074),
    [anon_sym_object] = ACTIONS(1074),
    [sym_html_comment] = ACTIONS(5),
  },
  [666] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1459),
    [sym_expression] = STATE(2508),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5827),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5827),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5529),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1459),
    [sym_subscript_expression] = STATE(1459),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(2979),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5827),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1459),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(647),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1514),
    [anon_sym_export] = ACTIONS(1074),
    [anon_sym_type] = ACTIONS(1074),
    [anon_sym_namespace] = ACTIONS(1076),
    [anon_sym_LBRACE] = ACTIONS(808),
    [anon_sym_typeof] = ACTIONS(1100),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1074),
    [anon_sym_BANG] = ACTIONS(1082),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(1084),
    [anon_sym_yield] = ACTIONS(1086),
    [anon_sym_LBRACK] = ACTIONS(812),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1090),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1518),
    [anon_sym_using] = ACTIONS(1094),
    [anon_sym_PLUS] = ACTIONS(1100),
    [anon_sym_DASH] = ACTIONS(1100),
    [anon_sym_SLASH] = ACTIONS(958),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(1082),
    [anon_sym_void] = ACTIONS(1100),
    [anon_sym_delete] = ACTIONS(1100),
    [anon_sym_PLUS_PLUS] = ACTIONS(1102),
    [anon_sym_DASH_DASH] = ACTIONS(1102),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(1108),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1520),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1074),
    [anon_sym_readonly] = ACTIONS(1074),
    [anon_sym_get] = ACTIONS(1074),
    [anon_sym_set] = ACTIONS(1074),
    [anon_sym_declare] = ACTIONS(1074),
    [anon_sym_public] = ACTIONS(1074),
    [anon_sym_private] = ACTIONS(1074),
    [anon_sym_protected] = ACTIONS(1074),
    [anon_sym_override] = ACTIONS(1074),
    [anon_sym_module] = ACTIONS(1074),
    [anon_sym_any] = ACTIONS(1074),
    [anon_sym_number] = ACTIONS(1074),
    [anon_sym_boolean] = ACTIONS(1074),
    [anon_sym_string] = ACTIONS(1074),
    [anon_sym_symbol] = ACTIONS(1074),
    [anon_sym_object] = ACTIONS(1074),
    [sym_html_comment] = ACTIONS(5),
  },
  [667] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1459),
    [sym_expression] = STATE(2509),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5827),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5827),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5529),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1459),
    [sym_subscript_expression] = STATE(1459),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(2979),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5827),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1459),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(647),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1514),
    [anon_sym_export] = ACTIONS(1074),
    [anon_sym_type] = ACTIONS(1074),
    [anon_sym_namespace] = ACTIONS(1076),
    [anon_sym_LBRACE] = ACTIONS(808),
    [anon_sym_typeof] = ACTIONS(1100),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1074),
    [anon_sym_BANG] = ACTIONS(1082),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(1084),
    [anon_sym_yield] = ACTIONS(1086),
    [anon_sym_LBRACK] = ACTIONS(812),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1090),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1518),
    [anon_sym_using] = ACTIONS(1094),
    [anon_sym_PLUS] = ACTIONS(1100),
    [anon_sym_DASH] = ACTIONS(1100),
    [anon_sym_SLASH] = ACTIONS(958),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(1082),
    [anon_sym_void] = ACTIONS(1100),
    [anon_sym_delete] = ACTIONS(1100),
    [anon_sym_PLUS_PLUS] = ACTIONS(1102),
    [anon_sym_DASH_DASH] = ACTIONS(1102),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(1108),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1520),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1074),
    [anon_sym_readonly] = ACTIONS(1074),
    [anon_sym_get] = ACTIONS(1074),
    [anon_sym_set] = ACTIONS(1074),
    [anon_sym_declare] = ACTIONS(1074),
    [anon_sym_public] = ACTIONS(1074),
    [anon_sym_private] = ACTIONS(1074),
    [anon_sym_protected] = ACTIONS(1074),
    [anon_sym_override] = ACTIONS(1074),
    [anon_sym_module] = ACTIONS(1074),
    [anon_sym_any] = ACTIONS(1074),
    [anon_sym_number] = ACTIONS(1074),
    [anon_sym_boolean] = ACTIONS(1074),
    [anon_sym_string] = ACTIONS(1074),
    [anon_sym_symbol] = ACTIONS(1074),
    [anon_sym_object] = ACTIONS(1074),
    [sym_html_comment] = ACTIONS(5),
  },
  [668] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1459),
    [sym_expression] = STATE(2514),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5827),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5827),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5529),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1459),
    [sym_subscript_expression] = STATE(1459),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(2979),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5827),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1459),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(647),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1514),
    [anon_sym_export] = ACTIONS(1074),
    [anon_sym_type] = ACTIONS(1074),
    [anon_sym_namespace] = ACTIONS(1076),
    [anon_sym_LBRACE] = ACTIONS(808),
    [anon_sym_typeof] = ACTIONS(1100),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1074),
    [anon_sym_BANG] = ACTIONS(1082),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(1084),
    [anon_sym_yield] = ACTIONS(1086),
    [anon_sym_LBRACK] = ACTIONS(812),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1090),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1518),
    [anon_sym_using] = ACTIONS(1094),
    [anon_sym_PLUS] = ACTIONS(1100),
    [anon_sym_DASH] = ACTIONS(1100),
    [anon_sym_SLASH] = ACTIONS(958),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(1082),
    [anon_sym_void] = ACTIONS(1100),
    [anon_sym_delete] = ACTIONS(1100),
    [anon_sym_PLUS_PLUS] = ACTIONS(1102),
    [anon_sym_DASH_DASH] = ACTIONS(1102),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(1108),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1520),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1074),
    [anon_sym_readonly] = ACTIONS(1074),
    [anon_sym_get] = ACTIONS(1074),
    [anon_sym_set] = ACTIONS(1074),
    [anon_sym_declare] = ACTIONS(1074),
    [anon_sym_public] = ACTIONS(1074),
    [anon_sym_private] = ACTIONS(1074),
    [anon_sym_protected] = ACTIONS(1074),
    [anon_sym_override] = ACTIONS(1074),
    [anon_sym_module] = ACTIONS(1074),
    [anon_sym_any] = ACTIONS(1074),
    [anon_sym_number] = ACTIONS(1074),
    [anon_sym_boolean] = ACTIONS(1074),
    [anon_sym_string] = ACTIONS(1074),
    [anon_sym_symbol] = ACTIONS(1074),
    [anon_sym_object] = ACTIONS(1074),
    [sym_html_comment] = ACTIONS(5),
  },
  [669] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1459),
    [sym_expression] = STATE(2515),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5827),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5827),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5529),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1459),
    [sym_subscript_expression] = STATE(1459),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(2979),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5827),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1459),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(647),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1514),
    [anon_sym_export] = ACTIONS(1074),
    [anon_sym_type] = ACTIONS(1074),
    [anon_sym_namespace] = ACTIONS(1076),
    [anon_sym_LBRACE] = ACTIONS(808),
    [anon_sym_typeof] = ACTIONS(1100),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1074),
    [anon_sym_BANG] = ACTIONS(1082),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(1084),
    [anon_sym_yield] = ACTIONS(1086),
    [anon_sym_LBRACK] = ACTIONS(812),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1090),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1518),
    [anon_sym_using] = ACTIONS(1094),
    [anon_sym_PLUS] = ACTIONS(1100),
    [anon_sym_DASH] = ACTIONS(1100),
    [anon_sym_SLASH] = ACTIONS(958),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(1082),
    [anon_sym_void] = ACTIONS(1100),
    [anon_sym_delete] = ACTIONS(1100),
    [anon_sym_PLUS_PLUS] = ACTIONS(1102),
    [anon_sym_DASH_DASH] = ACTIONS(1102),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(1108),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1520),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1074),
    [anon_sym_readonly] = ACTIONS(1074),
    [anon_sym_get] = ACTIONS(1074),
    [anon_sym_set] = ACTIONS(1074),
    [anon_sym_declare] = ACTIONS(1074),
    [anon_sym_public] = ACTIONS(1074),
    [anon_sym_private] = ACTIONS(1074),
    [anon_sym_protected] = ACTIONS(1074),
    [anon_sym_override] = ACTIONS(1074),
    [anon_sym_module] = ACTIONS(1074),
    [anon_sym_any] = ACTIONS(1074),
    [anon_sym_number] = ACTIONS(1074),
    [anon_sym_boolean] = ACTIONS(1074),
    [anon_sym_string] = ACTIONS(1074),
    [anon_sym_symbol] = ACTIONS(1074),
    [anon_sym_object] = ACTIONS(1074),
    [sym_html_comment] = ACTIONS(5),
  },
  [670] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1473),
    [sym_expression] = STATE(2644),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5541),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5541),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5800),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1473),
    [sym_subscript_expression] = STATE(1473),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3013),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5541),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1473),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(539),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(2275),
    [anon_sym_export] = ACTIONS(2277),
    [anon_sym_type] = ACTIONS(2277),
    [anon_sym_namespace] = ACTIONS(2279),
    [anon_sym_LBRACE] = ACTIONS(808),
    [anon_sym_typeof] = ACTIONS(179),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(2277),
    [anon_sym_BANG] = ACTIONS(175),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(140),
    [anon_sym_yield] = ACTIONS(142),
    [anon_sym_LBRACK] = ACTIONS(812),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(2281),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(2283),
    [anon_sym_using] = ACTIONS(158),
    [anon_sym_PLUS] = ACTIONS(179),
    [anon_sym_DASH] = ACTIONS(179),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(175),
    [anon_sym_void] = ACTIONS(179),
    [anon_sym_delete] = ACTIONS(179),
    [anon_sym_PLUS_PLUS] = ACTIONS(686),
    [anon_sym_DASH_DASH] = ACTIONS(686),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(192),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(2285),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(2277),
    [anon_sym_readonly] = ACTIONS(2277),
    [anon_sym_get] = ACTIONS(2277),
    [anon_sym_set] = ACTIONS(2277),
    [anon_sym_declare] = ACTIONS(2277),
    [anon_sym_public] = ACTIONS(2277),
    [anon_sym_private] = ACTIONS(2277),
    [anon_sym_protected] = ACTIONS(2277),
    [anon_sym_override] = ACTIONS(2277),
    [anon_sym_module] = ACTIONS(2277),
    [anon_sym_any] = ACTIONS(2277),
    [anon_sym_number] = ACTIONS(2277),
    [anon_sym_boolean] = ACTIONS(2277),
    [anon_sym_string] = ACTIONS(2277),
    [anon_sym_symbol] = ACTIONS(2277),
    [anon_sym_object] = ACTIONS(2277),
    [sym_html_comment] = ACTIONS(5),
  },
  [671] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1456),
    [sym_expression] = STATE(2595),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5815),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5815),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5755),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1456),
    [sym_subscript_expression] = STATE(1456),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3029),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5815),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1456),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(594),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1506),
    [anon_sym_export] = ACTIONS(1234),
    [anon_sym_type] = ACTIONS(1234),
    [anon_sym_namespace] = ACTIONS(1236),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_typeof] = ACTIONS(1256),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1234),
    [anon_sym_BANG] = ACTIONS(1240),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(1242),
    [anon_sym_yield] = ACTIONS(1244),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1246),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1510),
    [anon_sym_using] = ACTIONS(1250),
    [anon_sym_PLUS] = ACTIONS(1256),
    [anon_sym_DASH] = ACTIONS(1256),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(1240),
    [anon_sym_void] = ACTIONS(1256),
    [anon_sym_delete] = ACTIONS(1256),
    [anon_sym_PLUS_PLUS] = ACTIONS(1258),
    [anon_sym_DASH_DASH] = ACTIONS(1258),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(1260),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1512),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1234),
    [anon_sym_readonly] = ACTIONS(1234),
    [anon_sym_get] = ACTIONS(1234),
    [anon_sym_set] = ACTIONS(1234),
    [anon_sym_declare] = ACTIONS(1234),
    [anon_sym_public] = ACTIONS(1234),
    [anon_sym_private] = ACTIONS(1234),
    [anon_sym_protected] = ACTIONS(1234),
    [anon_sym_override] = ACTIONS(1234),
    [anon_sym_module] = ACTIONS(1234),
    [anon_sym_any] = ACTIONS(1234),
    [anon_sym_number] = ACTIONS(1234),
    [anon_sym_boolean] = ACTIONS(1234),
    [anon_sym_string] = ACTIONS(1234),
    [anon_sym_symbol] = ACTIONS(1234),
    [anon_sym_object] = ACTIONS(1234),
    [sym_html_comment] = ACTIONS(5),
  },
  [672] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1322),
    [sym_expression] = STATE(2425),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5698),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5698),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5508),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1322),
    [sym_subscript_expression] = STATE(1322),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3003),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5698),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1322),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(484),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1456),
    [anon_sym_export] = ACTIONS(1048),
    [anon_sym_type] = ACTIONS(1048),
    [anon_sym_namespace] = ACTIONS(1050),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_typeof] = ACTIONS(581),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1048),
    [anon_sym_BANG] = ACTIONS(553),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(555),
    [anon_sym_yield] = ACTIONS(557),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1058),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1464),
    [anon_sym_using] = ACTIONS(567),
    [anon_sym_PLUS] = ACTIONS(581),
    [anon_sym_DASH] = ACTIONS(581),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(553),
    [anon_sym_void] = ACTIONS(581),
    [anon_sym_delete] = ACTIONS(581),
    [anon_sym_PLUS_PLUS] = ACTIONS(583),
    [anon_sym_DASH_DASH] = ACTIONS(583),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(585),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1466),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1048),
    [anon_sym_readonly] = ACTIONS(1048),
    [anon_sym_get] = ACTIONS(1048),
    [anon_sym_set] = ACTIONS(1048),
    [anon_sym_declare] = ACTIONS(1048),
    [anon_sym_public] = ACTIONS(1048),
    [anon_sym_private] = ACTIONS(1048),
    [anon_sym_protected] = ACTIONS(1048),
    [anon_sym_override] = ACTIONS(1048),
    [anon_sym_module] = ACTIONS(1048),
    [anon_sym_any] = ACTIONS(1048),
    [anon_sym_number] = ACTIONS(1048),
    [anon_sym_boolean] = ACTIONS(1048),
    [anon_sym_string] = ACTIONS(1048),
    [anon_sym_symbol] = ACTIONS(1048),
    [anon_sym_object] = ACTIONS(1048),
    [sym_html_comment] = ACTIONS(5),
  },
  [673] = {
    [sym_import] = STATE(3636),
    [sym_parenthesized_expression] = STATE(1410),
    [sym_expression] = STATE(2239),
    [sym_primary_expression] = STATE(1810),
    [sym_yield_expression] = STATE(2358),
    [sym_object] = STATE(2222),
    [sym_object_pattern] = STATE(5580),
    [sym_array] = STATE(2222),
    [sym_array_pattern] = STATE(5580),
    [sym_class] = STATE(2222),
    [sym_function_expression] = STATE(2222),
    [sym_generator_function] = STATE(2222),
    [sym_arrow_function] = STATE(2222),
    [sym__call_signature] = STATE(5466),
    [sym_call_expression] = STATE(2222),
    [sym_new_expression] = STATE(1948),
    [sym_await_expression] = STATE(2358),
    [sym_member_expression] = STATE(1410),
    [sym_subscript_expression] = STATE(1410),
    [sym_assignment_expression] = STATE(2358),
    [sym__augmented_assignment_lhs] = STATE(3004),
    [sym_augmented_assignment_expression] = STATE(2358),
    [sym__destructuring_pattern] = STATE(5580),
    [sym_ternary_expression] = STATE(2358),
    [sym_binary_expression] = STATE(2358),
    [sym_unary_expression] = STATE(2358),
    [sym_update_expression] = STATE(2358),
    [sym_string] = STATE(2222),
    [sym_template_string] = STATE(2222),
    [sym_regex] = STATE(2222),
    [sym_meta_property] = STATE(2222),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1410),
    [sym_type_assertion] = STATE(2358),
    [sym_as_expression] = STATE(2358),
    [sym_satisfies_expression] = STATE(2358),
    [sym_instantiation_expression] = STATE(2358),
    [sym_internal_module] = STATE(2358),
    [sym_type_arguments] = STATE(452),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4408),
    [sym_identifier] = ACTIONS(1498),
    [anon_sym_export] = ACTIONS(1270),
    [anon_sym_type] = ACTIONS(1270),
    [anon_sym_namespace] = ACTIONS(1272),
    [anon_sym_LBRACE] = ACTIONS(665),
    [anon_sym_typeof] = ACTIONS(1298),
    [anon_sym_import] = ACTIONS(669),
    [anon_sym_let] = ACTIONS(1270),
    [anon_sym_BANG] = ACTIONS(1278),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_await] = ACTIONS(1282),
    [anon_sym_yield] = ACTIONS(1284),
    [anon_sym_LBRACK] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(676),
    [anon_sym_async] = ACTIONS(1288),
    [anon_sym_function] = ACTIONS(680),
    [anon_sym_new] = ACTIONS(1502),
    [anon_sym_using] = ACTIONS(1292),
    [anon_sym_PLUS] = ACTIONS(1298),
    [anon_sym_DASH] = ACTIONS(1298),
    [anon_sym_SLASH] = ACTIONS(77),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(1278),
    [anon_sym_void] = ACTIONS(1298),
    [anon_sym_delete] = ACTIONS(1298),
    [anon_sym_PLUS_PLUS] = ACTIONS(1300),
    [anon_sym_DASH_DASH] = ACTIONS(1300),
    [anon_sym_DQUOTE] = ACTIONS(83),
    [anon_sym_SQUOTE] = ACTIONS(85),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(87),
    [sym_number] = ACTIONS(89),
    [sym_private_property_identifier] = ACTIONS(1306),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(93),
    [sym_true] = ACTIONS(93),
    [sym_false] = ACTIONS(93),
    [sym_null] = ACTIONS(93),
    [sym_undefined] = ACTIONS(1504),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1270),
    [anon_sym_readonly] = ACTIONS(1270),
    [anon_sym_get] = ACTIONS(1270),
    [anon_sym_set] = ACTIONS(1270),
    [anon_sym_declare] = ACTIONS(1270),
    [anon_sym_public] = ACTIONS(1270),
    [anon_sym_private] = ACTIONS(1270),
    [anon_sym_protected] = ACTIONS(1270),
    [anon_sym_override] = ACTIONS(1270),
    [anon_sym_module] = ACTIONS(1270),
    [anon_sym_any] = ACTIONS(1270),
    [anon_sym_number] = ACTIONS(1270),
    [anon_sym_boolean] = ACTIONS(1270),
    [anon_sym_string] = ACTIONS(1270),
    [anon_sym_symbol] = ACTIONS(1270),
    [anon_sym_object] = ACTIONS(1270),
    [sym_html_comment] = ACTIONS(5),
  },
  [674] = {
    [sym_import] = STATE(3636),
    [sym_parenthesized_expression] = STATE(1410),
    [sym_expression] = STATE(2240),
    [sym_primary_expression] = STATE(1810),
    [sym_yield_expression] = STATE(2358),
    [sym_object] = STATE(2222),
    [sym_object_pattern] = STATE(5580),
    [sym_array] = STATE(2222),
    [sym_array_pattern] = STATE(5580),
    [sym_class] = STATE(2222),
    [sym_function_expression] = STATE(2222),
    [sym_generator_function] = STATE(2222),
    [sym_arrow_function] = STATE(2222),
    [sym__call_signature] = STATE(5466),
    [sym_call_expression] = STATE(2222),
    [sym_new_expression] = STATE(1948),
    [sym_await_expression] = STATE(2358),
    [sym_member_expression] = STATE(1410),
    [sym_subscript_expression] = STATE(1410),
    [sym_assignment_expression] = STATE(2358),
    [sym__augmented_assignment_lhs] = STATE(3004),
    [sym_augmented_assignment_expression] = STATE(2358),
    [sym__destructuring_pattern] = STATE(5580),
    [sym_ternary_expression] = STATE(2358),
    [sym_binary_expression] = STATE(2358),
    [sym_unary_expression] = STATE(2358),
    [sym_update_expression] = STATE(2358),
    [sym_string] = STATE(2222),
    [sym_template_string] = STATE(2222),
    [sym_regex] = STATE(2222),
    [sym_meta_property] = STATE(2222),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1410),
    [sym_type_assertion] = STATE(2358),
    [sym_as_expression] = STATE(2358),
    [sym_satisfies_expression] = STATE(2358),
    [sym_instantiation_expression] = STATE(2358),
    [sym_internal_module] = STATE(2358),
    [sym_type_arguments] = STATE(452),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4408),
    [sym_identifier] = ACTIONS(1498),
    [anon_sym_export] = ACTIONS(1270),
    [anon_sym_type] = ACTIONS(1270),
    [anon_sym_namespace] = ACTIONS(1272),
    [anon_sym_LBRACE] = ACTIONS(665),
    [anon_sym_typeof] = ACTIONS(1298),
    [anon_sym_import] = ACTIONS(669),
    [anon_sym_let] = ACTIONS(1270),
    [anon_sym_BANG] = ACTIONS(1278),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_await] = ACTIONS(1282),
    [anon_sym_yield] = ACTIONS(1284),
    [anon_sym_LBRACK] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(676),
    [anon_sym_async] = ACTIONS(1288),
    [anon_sym_function] = ACTIONS(680),
    [anon_sym_new] = ACTIONS(1502),
    [anon_sym_using] = ACTIONS(1292),
    [anon_sym_PLUS] = ACTIONS(1298),
    [anon_sym_DASH] = ACTIONS(1298),
    [anon_sym_SLASH] = ACTIONS(77),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(1278),
    [anon_sym_void] = ACTIONS(1298),
    [anon_sym_delete] = ACTIONS(1298),
    [anon_sym_PLUS_PLUS] = ACTIONS(1300),
    [anon_sym_DASH_DASH] = ACTIONS(1300),
    [anon_sym_DQUOTE] = ACTIONS(83),
    [anon_sym_SQUOTE] = ACTIONS(85),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(87),
    [sym_number] = ACTIONS(89),
    [sym_private_property_identifier] = ACTIONS(1306),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(93),
    [sym_true] = ACTIONS(93),
    [sym_false] = ACTIONS(93),
    [sym_null] = ACTIONS(93),
    [sym_undefined] = ACTIONS(1504),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1270),
    [anon_sym_readonly] = ACTIONS(1270),
    [anon_sym_get] = ACTIONS(1270),
    [anon_sym_set] = ACTIONS(1270),
    [anon_sym_declare] = ACTIONS(1270),
    [anon_sym_public] = ACTIONS(1270),
    [anon_sym_private] = ACTIONS(1270),
    [anon_sym_protected] = ACTIONS(1270),
    [anon_sym_override] = ACTIONS(1270),
    [anon_sym_module] = ACTIONS(1270),
    [anon_sym_any] = ACTIONS(1270),
    [anon_sym_number] = ACTIONS(1270),
    [anon_sym_boolean] = ACTIONS(1270),
    [anon_sym_string] = ACTIONS(1270),
    [anon_sym_symbol] = ACTIONS(1270),
    [anon_sym_object] = ACTIONS(1270),
    [sym_html_comment] = ACTIONS(5),
  },
  [675] = {
    [sym_import] = STATE(3636),
    [sym_parenthesized_expression] = STATE(1410),
    [sym_expression] = STATE(2242),
    [sym_primary_expression] = STATE(1810),
    [sym_yield_expression] = STATE(2358),
    [sym_object] = STATE(2222),
    [sym_object_pattern] = STATE(5580),
    [sym_array] = STATE(2222),
    [sym_array_pattern] = STATE(5580),
    [sym_class] = STATE(2222),
    [sym_function_expression] = STATE(2222),
    [sym_generator_function] = STATE(2222),
    [sym_arrow_function] = STATE(2222),
    [sym__call_signature] = STATE(5466),
    [sym_call_expression] = STATE(2222),
    [sym_new_expression] = STATE(1948),
    [sym_await_expression] = STATE(2358),
    [sym_member_expression] = STATE(1410),
    [sym_subscript_expression] = STATE(1410),
    [sym_assignment_expression] = STATE(2358),
    [sym__augmented_assignment_lhs] = STATE(3004),
    [sym_augmented_assignment_expression] = STATE(2358),
    [sym__destructuring_pattern] = STATE(5580),
    [sym_ternary_expression] = STATE(2358),
    [sym_binary_expression] = STATE(2358),
    [sym_unary_expression] = STATE(2358),
    [sym_update_expression] = STATE(2358),
    [sym_string] = STATE(2222),
    [sym_template_string] = STATE(2222),
    [sym_regex] = STATE(2222),
    [sym_meta_property] = STATE(2222),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1410),
    [sym_type_assertion] = STATE(2358),
    [sym_as_expression] = STATE(2358),
    [sym_satisfies_expression] = STATE(2358),
    [sym_instantiation_expression] = STATE(2358),
    [sym_internal_module] = STATE(2358),
    [sym_type_arguments] = STATE(452),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4408),
    [sym_identifier] = ACTIONS(1498),
    [anon_sym_export] = ACTIONS(1270),
    [anon_sym_type] = ACTIONS(1270),
    [anon_sym_namespace] = ACTIONS(1272),
    [anon_sym_LBRACE] = ACTIONS(665),
    [anon_sym_typeof] = ACTIONS(1298),
    [anon_sym_import] = ACTIONS(669),
    [anon_sym_let] = ACTIONS(1270),
    [anon_sym_BANG] = ACTIONS(1278),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_await] = ACTIONS(1282),
    [anon_sym_yield] = ACTIONS(1284),
    [anon_sym_LBRACK] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(676),
    [anon_sym_async] = ACTIONS(1288),
    [anon_sym_function] = ACTIONS(680),
    [anon_sym_new] = ACTIONS(1502),
    [anon_sym_using] = ACTIONS(1292),
    [anon_sym_PLUS] = ACTIONS(1298),
    [anon_sym_DASH] = ACTIONS(1298),
    [anon_sym_SLASH] = ACTIONS(77),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(1278),
    [anon_sym_void] = ACTIONS(1298),
    [anon_sym_delete] = ACTIONS(1298),
    [anon_sym_PLUS_PLUS] = ACTIONS(1300),
    [anon_sym_DASH_DASH] = ACTIONS(1300),
    [anon_sym_DQUOTE] = ACTIONS(83),
    [anon_sym_SQUOTE] = ACTIONS(85),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(87),
    [sym_number] = ACTIONS(89),
    [sym_private_property_identifier] = ACTIONS(1306),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(93),
    [sym_true] = ACTIONS(93),
    [sym_false] = ACTIONS(93),
    [sym_null] = ACTIONS(93),
    [sym_undefined] = ACTIONS(1504),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1270),
    [anon_sym_readonly] = ACTIONS(1270),
    [anon_sym_get] = ACTIONS(1270),
    [anon_sym_set] = ACTIONS(1270),
    [anon_sym_declare] = ACTIONS(1270),
    [anon_sym_public] = ACTIONS(1270),
    [anon_sym_private] = ACTIONS(1270),
    [anon_sym_protected] = ACTIONS(1270),
    [anon_sym_override] = ACTIONS(1270),
    [anon_sym_module] = ACTIONS(1270),
    [anon_sym_any] = ACTIONS(1270),
    [anon_sym_number] = ACTIONS(1270),
    [anon_sym_boolean] = ACTIONS(1270),
    [anon_sym_string] = ACTIONS(1270),
    [anon_sym_symbol] = ACTIONS(1270),
    [anon_sym_object] = ACTIONS(1270),
    [sym_html_comment] = ACTIONS(5),
  },
  [676] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1322),
    [sym_expression] = STATE(1777),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5698),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5698),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5508),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1322),
    [sym_subscript_expression] = STATE(1322),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3003),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5698),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1322),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(484),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1456),
    [anon_sym_export] = ACTIONS(1048),
    [anon_sym_type] = ACTIONS(1048),
    [anon_sym_namespace] = ACTIONS(1050),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_typeof] = ACTIONS(581),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1048),
    [anon_sym_BANG] = ACTIONS(553),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(555),
    [anon_sym_yield] = ACTIONS(557),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1058),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1464),
    [anon_sym_using] = ACTIONS(567),
    [anon_sym_PLUS] = ACTIONS(581),
    [anon_sym_DASH] = ACTIONS(581),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(553),
    [anon_sym_void] = ACTIONS(581),
    [anon_sym_delete] = ACTIONS(581),
    [anon_sym_PLUS_PLUS] = ACTIONS(583),
    [anon_sym_DASH_DASH] = ACTIONS(583),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(585),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1466),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1048),
    [anon_sym_readonly] = ACTIONS(1048),
    [anon_sym_get] = ACTIONS(1048),
    [anon_sym_set] = ACTIONS(1048),
    [anon_sym_declare] = ACTIONS(1048),
    [anon_sym_public] = ACTIONS(1048),
    [anon_sym_private] = ACTIONS(1048),
    [anon_sym_protected] = ACTIONS(1048),
    [anon_sym_override] = ACTIONS(1048),
    [anon_sym_module] = ACTIONS(1048),
    [anon_sym_any] = ACTIONS(1048),
    [anon_sym_number] = ACTIONS(1048),
    [anon_sym_boolean] = ACTIONS(1048),
    [anon_sym_string] = ACTIONS(1048),
    [anon_sym_symbol] = ACTIONS(1048),
    [anon_sym_object] = ACTIONS(1048),
    [sym_html_comment] = ACTIONS(5),
  },
  [677] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1322),
    [sym_expression] = STATE(2312),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(4276),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(4276),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5508),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1363),
    [sym_subscript_expression] = STATE(1363),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3003),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(4276),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1363),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(484),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(2287),
    [anon_sym_export] = ACTIONS(1216),
    [anon_sym_type] = ACTIONS(1216),
    [anon_sym_namespace] = ACTIONS(1218),
    [anon_sym_LBRACE] = ACTIONS(808),
    [anon_sym_typeof] = ACTIONS(581),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1216),
    [anon_sym_BANG] = ACTIONS(553),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(555),
    [anon_sym_yield] = ACTIONS(557),
    [anon_sym_LBRACK] = ACTIONS(812),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1222),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(2289),
    [anon_sym_using] = ACTIONS(567),
    [anon_sym_PLUS] = ACTIONS(581),
    [anon_sym_DASH] = ACTIONS(581),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(553),
    [anon_sym_void] = ACTIONS(581),
    [anon_sym_delete] = ACTIONS(581),
    [anon_sym_PLUS_PLUS] = ACTIONS(583),
    [anon_sym_DASH_DASH] = ACTIONS(583),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(585),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(2291),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1216),
    [anon_sym_readonly] = ACTIONS(1216),
    [anon_sym_get] = ACTIONS(1216),
    [anon_sym_set] = ACTIONS(1216),
    [anon_sym_declare] = ACTIONS(1216),
    [anon_sym_public] = ACTIONS(1216),
    [anon_sym_private] = ACTIONS(1216),
    [anon_sym_protected] = ACTIONS(1216),
    [anon_sym_override] = ACTIONS(1216),
    [anon_sym_module] = ACTIONS(1216),
    [anon_sym_any] = ACTIONS(1216),
    [anon_sym_number] = ACTIONS(1216),
    [anon_sym_boolean] = ACTIONS(1216),
    [anon_sym_string] = ACTIONS(1216),
    [anon_sym_symbol] = ACTIONS(1216),
    [anon_sym_object] = ACTIONS(1216),
    [sym_html_comment] = ACTIONS(5),
  },
  [678] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1459),
    [sym_expression] = STATE(2514),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5827),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5827),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5529),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1459),
    [sym_subscript_expression] = STATE(1459),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(2979),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5827),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1459),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(647),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1514),
    [anon_sym_export] = ACTIONS(1074),
    [anon_sym_type] = ACTIONS(1074),
    [anon_sym_namespace] = ACTIONS(1076),
    [anon_sym_LBRACE] = ACTIONS(808),
    [anon_sym_typeof] = ACTIONS(1100),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1074),
    [anon_sym_BANG] = ACTIONS(1082),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(1084),
    [anon_sym_yield] = ACTIONS(1086),
    [anon_sym_LBRACK] = ACTIONS(812),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1090),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1518),
    [anon_sym_using] = ACTIONS(1094),
    [anon_sym_PLUS] = ACTIONS(1100),
    [anon_sym_DASH] = ACTIONS(1100),
    [anon_sym_SLASH] = ACTIONS(958),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(1082),
    [anon_sym_void] = ACTIONS(1100),
    [anon_sym_delete] = ACTIONS(1100),
    [anon_sym_PLUS_PLUS] = ACTIONS(1102),
    [anon_sym_DASH_DASH] = ACTIONS(1102),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(2171),
    [sym_private_property_identifier] = ACTIONS(1108),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1520),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1074),
    [anon_sym_readonly] = ACTIONS(1074),
    [anon_sym_get] = ACTIONS(1074),
    [anon_sym_set] = ACTIONS(1074),
    [anon_sym_declare] = ACTIONS(1074),
    [anon_sym_public] = ACTIONS(1074),
    [anon_sym_private] = ACTIONS(1074),
    [anon_sym_protected] = ACTIONS(1074),
    [anon_sym_override] = ACTIONS(1074),
    [anon_sym_module] = ACTIONS(1074),
    [anon_sym_any] = ACTIONS(1074),
    [anon_sym_number] = ACTIONS(1074),
    [anon_sym_boolean] = ACTIONS(1074),
    [anon_sym_string] = ACTIONS(1074),
    [anon_sym_symbol] = ACTIONS(1074),
    [anon_sym_object] = ACTIONS(1074),
    [sym_html_comment] = ACTIONS(5),
  },
  [679] = {
    [sym_import] = STATE(3636),
    [sym_parenthesized_expression] = STATE(1364),
    [sym_expression] = STATE(1873),
    [sym_primary_expression] = STATE(1810),
    [sym_yield_expression] = STATE(2358),
    [sym_object] = STATE(2222),
    [sym_object_pattern] = STATE(5773),
    [sym_array] = STATE(2222),
    [sym_array_pattern] = STATE(5773),
    [sym_class] = STATE(2222),
    [sym_function_expression] = STATE(2222),
    [sym_generator_function] = STATE(2222),
    [sym_arrow_function] = STATE(2222),
    [sym__call_signature] = STATE(5771),
    [sym_call_expression] = STATE(2222),
    [sym_new_expression] = STATE(1948),
    [sym_await_expression] = STATE(2358),
    [sym_member_expression] = STATE(1364),
    [sym_subscript_expression] = STATE(1364),
    [sym_assignment_expression] = STATE(2358),
    [sym__augmented_assignment_lhs] = STATE(3020),
    [sym_augmented_assignment_expression] = STATE(2358),
    [sym__destructuring_pattern] = STATE(5773),
    [sym_ternary_expression] = STATE(2358),
    [sym_binary_expression] = STATE(2358),
    [sym_unary_expression] = STATE(2358),
    [sym_update_expression] = STATE(2358),
    [sym_string] = STATE(2222),
    [sym_template_string] = STATE(2222),
    [sym_regex] = STATE(2222),
    [sym_meta_property] = STATE(2222),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1364),
    [sym_type_assertion] = STATE(2358),
    [sym_as_expression] = STATE(2358),
    [sym_satisfies_expression] = STATE(2358),
    [sym_instantiation_expression] = STATE(2358),
    [sym_internal_module] = STATE(2358),
    [sym_type_arguments] = STATE(513),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4408),
    [sym_identifier] = ACTIONS(1474),
    [anon_sym_export] = ACTIONS(1386),
    [anon_sym_type] = ACTIONS(1386),
    [anon_sym_namespace] = ACTIONS(1388),
    [anon_sym_LBRACE] = ACTIONS(665),
    [anon_sym_typeof] = ACTIONS(1408),
    [anon_sym_import] = ACTIONS(669),
    [anon_sym_let] = ACTIONS(1386),
    [anon_sym_BANG] = ACTIONS(1392),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_await] = ACTIONS(1394),
    [anon_sym_yield] = ACTIONS(1396),
    [anon_sym_LBRACK] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(676),
    [anon_sym_async] = ACTIONS(1398),
    [anon_sym_function] = ACTIONS(680),
    [anon_sym_new] = ACTIONS(1478),
    [anon_sym_using] = ACTIONS(1402),
    [anon_sym_PLUS] = ACTIONS(1408),
    [anon_sym_DASH] = ACTIONS(1408),
    [anon_sym_SLASH] = ACTIONS(876),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(1392),
    [anon_sym_void] = ACTIONS(1408),
    [anon_sym_delete] = ACTIONS(1408),
    [anon_sym_PLUS_PLUS] = ACTIONS(1410),
    [anon_sym_DASH_DASH] = ACTIONS(1410),
    [anon_sym_DQUOTE] = ACTIONS(83),
    [anon_sym_SQUOTE] = ACTIONS(85),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(87),
    [sym_number] = ACTIONS(89),
    [sym_private_property_identifier] = ACTIONS(1412),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(93),
    [sym_true] = ACTIONS(93),
    [sym_false] = ACTIONS(93),
    [sym_null] = ACTIONS(93),
    [sym_undefined] = ACTIONS(1480),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1386),
    [anon_sym_readonly] = ACTIONS(1386),
    [anon_sym_get] = ACTIONS(1386),
    [anon_sym_set] = ACTIONS(1386),
    [anon_sym_declare] = ACTIONS(1386),
    [anon_sym_public] = ACTIONS(1386),
    [anon_sym_private] = ACTIONS(1386),
    [anon_sym_protected] = ACTIONS(1386),
    [anon_sym_override] = ACTIONS(1386),
    [anon_sym_module] = ACTIONS(1386),
    [anon_sym_any] = ACTIONS(1386),
    [anon_sym_number] = ACTIONS(1386),
    [anon_sym_boolean] = ACTIONS(1386),
    [anon_sym_string] = ACTIONS(1386),
    [anon_sym_symbol] = ACTIONS(1386),
    [anon_sym_object] = ACTIONS(1386),
    [sym_html_comment] = ACTIONS(5),
  },
  [680] = {
    [sym_import] = STATE(3636),
    [sym_parenthesized_expression] = STATE(1364),
    [sym_expression] = STATE(1874),
    [sym_primary_expression] = STATE(1810),
    [sym_yield_expression] = STATE(2358),
    [sym_object] = STATE(2222),
    [sym_object_pattern] = STATE(5773),
    [sym_array] = STATE(2222),
    [sym_array_pattern] = STATE(5773),
    [sym_class] = STATE(2222),
    [sym_function_expression] = STATE(2222),
    [sym_generator_function] = STATE(2222),
    [sym_arrow_function] = STATE(2222),
    [sym__call_signature] = STATE(5771),
    [sym_call_expression] = STATE(2222),
    [sym_new_expression] = STATE(1948),
    [sym_await_expression] = STATE(2358),
    [sym_member_expression] = STATE(1364),
    [sym_subscript_expression] = STATE(1364),
    [sym_assignment_expression] = STATE(2358),
    [sym__augmented_assignment_lhs] = STATE(3020),
    [sym_augmented_assignment_expression] = STATE(2358),
    [sym__destructuring_pattern] = STATE(5773),
    [sym_ternary_expression] = STATE(2358),
    [sym_binary_expression] = STATE(2358),
    [sym_unary_expression] = STATE(2358),
    [sym_update_expression] = STATE(2358),
    [sym_string] = STATE(2222),
    [sym_template_string] = STATE(2222),
    [sym_regex] = STATE(2222),
    [sym_meta_property] = STATE(2222),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1364),
    [sym_type_assertion] = STATE(2358),
    [sym_as_expression] = STATE(2358),
    [sym_satisfies_expression] = STATE(2358),
    [sym_instantiation_expression] = STATE(2358),
    [sym_internal_module] = STATE(2358),
    [sym_type_arguments] = STATE(513),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4408),
    [sym_identifier] = ACTIONS(1474),
    [anon_sym_export] = ACTIONS(1386),
    [anon_sym_type] = ACTIONS(1386),
    [anon_sym_namespace] = ACTIONS(1388),
    [anon_sym_LBRACE] = ACTIONS(665),
    [anon_sym_typeof] = ACTIONS(1408),
    [anon_sym_import] = ACTIONS(669),
    [anon_sym_let] = ACTIONS(1386),
    [anon_sym_BANG] = ACTIONS(1392),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_await] = ACTIONS(1394),
    [anon_sym_yield] = ACTIONS(1396),
    [anon_sym_LBRACK] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(676),
    [anon_sym_async] = ACTIONS(1398),
    [anon_sym_function] = ACTIONS(680),
    [anon_sym_new] = ACTIONS(1478),
    [anon_sym_using] = ACTIONS(1402),
    [anon_sym_PLUS] = ACTIONS(1408),
    [anon_sym_DASH] = ACTIONS(1408),
    [anon_sym_SLASH] = ACTIONS(876),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(1392),
    [anon_sym_void] = ACTIONS(1408),
    [anon_sym_delete] = ACTIONS(1408),
    [anon_sym_PLUS_PLUS] = ACTIONS(1410),
    [anon_sym_DASH_DASH] = ACTIONS(1410),
    [anon_sym_DQUOTE] = ACTIONS(83),
    [anon_sym_SQUOTE] = ACTIONS(85),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(87),
    [sym_number] = ACTIONS(89),
    [sym_private_property_identifier] = ACTIONS(1412),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(93),
    [sym_true] = ACTIONS(93),
    [sym_false] = ACTIONS(93),
    [sym_null] = ACTIONS(93),
    [sym_undefined] = ACTIONS(1480),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1386),
    [anon_sym_readonly] = ACTIONS(1386),
    [anon_sym_get] = ACTIONS(1386),
    [anon_sym_set] = ACTIONS(1386),
    [anon_sym_declare] = ACTIONS(1386),
    [anon_sym_public] = ACTIONS(1386),
    [anon_sym_private] = ACTIONS(1386),
    [anon_sym_protected] = ACTIONS(1386),
    [anon_sym_override] = ACTIONS(1386),
    [anon_sym_module] = ACTIONS(1386),
    [anon_sym_any] = ACTIONS(1386),
    [anon_sym_number] = ACTIONS(1386),
    [anon_sym_boolean] = ACTIONS(1386),
    [anon_sym_string] = ACTIONS(1386),
    [anon_sym_symbol] = ACTIONS(1386),
    [anon_sym_object] = ACTIONS(1386),
    [sym_html_comment] = ACTIONS(5),
  },
  [681] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1387),
    [sym_expression] = STATE(2109),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5803),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5803),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5585),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1387),
    [sym_subscript_expression] = STATE(1387),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3009),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5803),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1387),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(566),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1490),
    [anon_sym_export] = ACTIONS(1422),
    [anon_sym_type] = ACTIONS(1422),
    [anon_sym_namespace] = ACTIONS(1424),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_typeof] = ACTIONS(1444),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1422),
    [anon_sym_BANG] = ACTIONS(1428),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(1430),
    [anon_sym_yield] = ACTIONS(1432),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1434),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1494),
    [anon_sym_using] = ACTIONS(1438),
    [anon_sym_PLUS] = ACTIONS(1444),
    [anon_sym_DASH] = ACTIONS(1444),
    [anon_sym_SLASH] = ACTIONS(942),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(1428),
    [anon_sym_void] = ACTIONS(1444),
    [anon_sym_delete] = ACTIONS(1444),
    [anon_sym_PLUS_PLUS] = ACTIONS(1446),
    [anon_sym_DASH_DASH] = ACTIONS(1446),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(1448),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1496),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1422),
    [anon_sym_readonly] = ACTIONS(1422),
    [anon_sym_get] = ACTIONS(1422),
    [anon_sym_set] = ACTIONS(1422),
    [anon_sym_declare] = ACTIONS(1422),
    [anon_sym_public] = ACTIONS(1422),
    [anon_sym_private] = ACTIONS(1422),
    [anon_sym_protected] = ACTIONS(1422),
    [anon_sym_override] = ACTIONS(1422),
    [anon_sym_module] = ACTIONS(1422),
    [anon_sym_any] = ACTIONS(1422),
    [anon_sym_number] = ACTIONS(1422),
    [anon_sym_boolean] = ACTIONS(1422),
    [anon_sym_string] = ACTIONS(1422),
    [anon_sym_symbol] = ACTIONS(1422),
    [anon_sym_object] = ACTIONS(1422),
    [sym_html_comment] = ACTIONS(5),
  },
  [682] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1398),
    [sym_expression] = STATE(1919),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5544),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5544),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5558),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1398),
    [sym_subscript_expression] = STATE(1398),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(2980),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5544),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1398),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(638),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1482),
    [anon_sym_export] = ACTIONS(1158),
    [anon_sym_type] = ACTIONS(1158),
    [anon_sym_namespace] = ACTIONS(1160),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_typeof] = ACTIONS(756),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1158),
    [anon_sym_BANG] = ACTIONS(732),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(736),
    [anon_sym_yield] = ACTIONS(738),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1164),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1486),
    [anon_sym_using] = ACTIONS(746),
    [anon_sym_PLUS] = ACTIONS(756),
    [anon_sym_DASH] = ACTIONS(756),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(732),
    [anon_sym_void] = ACTIONS(756),
    [anon_sym_delete] = ACTIONS(756),
    [anon_sym_PLUS_PLUS] = ACTIONS(758),
    [anon_sym_DASH_DASH] = ACTIONS(758),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(764),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1488),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1158),
    [anon_sym_readonly] = ACTIONS(1158),
    [anon_sym_get] = ACTIONS(1158),
    [anon_sym_set] = ACTIONS(1158),
    [anon_sym_declare] = ACTIONS(1158),
    [anon_sym_public] = ACTIONS(1158),
    [anon_sym_private] = ACTIONS(1158),
    [anon_sym_protected] = ACTIONS(1158),
    [anon_sym_override] = ACTIONS(1158),
    [anon_sym_module] = ACTIONS(1158),
    [anon_sym_any] = ACTIONS(1158),
    [anon_sym_number] = ACTIONS(1158),
    [anon_sym_boolean] = ACTIONS(1158),
    [anon_sym_string] = ACTIONS(1158),
    [anon_sym_symbol] = ACTIONS(1158),
    [anon_sym_object] = ACTIONS(1158),
    [sym_html_comment] = ACTIONS(5),
  },
  [683] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1456),
    [sym_expression] = STATE(2407),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5815),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5815),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5755),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1456),
    [sym_subscript_expression] = STATE(1456),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3029),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5815),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1456),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(594),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1506),
    [anon_sym_export] = ACTIONS(1234),
    [anon_sym_type] = ACTIONS(1234),
    [anon_sym_namespace] = ACTIONS(1236),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_typeof] = ACTIONS(1256),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1234),
    [anon_sym_BANG] = ACTIONS(1240),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(1242),
    [anon_sym_yield] = ACTIONS(1244),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1246),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1510),
    [anon_sym_using] = ACTIONS(1250),
    [anon_sym_PLUS] = ACTIONS(1256),
    [anon_sym_DASH] = ACTIONS(1256),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(1240),
    [anon_sym_void] = ACTIONS(1256),
    [anon_sym_delete] = ACTIONS(1256),
    [anon_sym_PLUS_PLUS] = ACTIONS(1258),
    [anon_sym_DASH_DASH] = ACTIONS(1258),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(1260),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1512),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1234),
    [anon_sym_readonly] = ACTIONS(1234),
    [anon_sym_get] = ACTIONS(1234),
    [anon_sym_set] = ACTIONS(1234),
    [anon_sym_declare] = ACTIONS(1234),
    [anon_sym_public] = ACTIONS(1234),
    [anon_sym_private] = ACTIONS(1234),
    [anon_sym_protected] = ACTIONS(1234),
    [anon_sym_override] = ACTIONS(1234),
    [anon_sym_module] = ACTIONS(1234),
    [anon_sym_any] = ACTIONS(1234),
    [anon_sym_number] = ACTIONS(1234),
    [anon_sym_boolean] = ACTIONS(1234),
    [anon_sym_string] = ACTIONS(1234),
    [anon_sym_symbol] = ACTIONS(1234),
    [anon_sym_object] = ACTIONS(1234),
    [sym_html_comment] = ACTIONS(5),
  },
  [684] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1457),
    [sym_expression] = STATE(2417),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5823),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5823),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5477),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1457),
    [sym_subscript_expression] = STATE(1457),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(2986),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5823),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1457),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(620),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1522),
    [anon_sym_export] = ACTIONS(1178),
    [anon_sym_type] = ACTIONS(1178),
    [anon_sym_namespace] = ACTIONS(1180),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_typeof] = ACTIONS(1202),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1178),
    [anon_sym_BANG] = ACTIONS(1186),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(1188),
    [anon_sym_yield] = ACTIONS(1190),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1192),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1526),
    [anon_sym_using] = ACTIONS(1196),
    [anon_sym_PLUS] = ACTIONS(1202),
    [anon_sym_DASH] = ACTIONS(1202),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(1186),
    [anon_sym_void] = ACTIONS(1202),
    [anon_sym_delete] = ACTIONS(1202),
    [anon_sym_PLUS_PLUS] = ACTIONS(1204),
    [anon_sym_DASH_DASH] = ACTIONS(1204),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(1206),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1528),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1178),
    [anon_sym_readonly] = ACTIONS(1178),
    [anon_sym_get] = ACTIONS(1178),
    [anon_sym_set] = ACTIONS(1178),
    [anon_sym_declare] = ACTIONS(1178),
    [anon_sym_public] = ACTIONS(1178),
    [anon_sym_private] = ACTIONS(1178),
    [anon_sym_protected] = ACTIONS(1178),
    [anon_sym_override] = ACTIONS(1178),
    [anon_sym_module] = ACTIONS(1178),
    [anon_sym_any] = ACTIONS(1178),
    [anon_sym_number] = ACTIONS(1178),
    [anon_sym_boolean] = ACTIONS(1178),
    [anon_sym_string] = ACTIONS(1178),
    [anon_sym_symbol] = ACTIONS(1178),
    [anon_sym_object] = ACTIONS(1178),
    [sym_html_comment] = ACTIONS(5),
  },
  [685] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1467),
    [sym_expression] = STATE(2644),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5610),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5610),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5800),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1467),
    [sym_subscript_expression] = STATE(1467),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3013),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5610),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1467),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(539),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(2293),
    [anon_sym_export] = ACTIONS(2295),
    [anon_sym_type] = ACTIONS(2295),
    [anon_sym_namespace] = ACTIONS(2297),
    [anon_sym_LBRACE] = ACTIONS(808),
    [anon_sym_typeof] = ACTIONS(179),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(2295),
    [anon_sym_BANG] = ACTIONS(175),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(140),
    [anon_sym_yield] = ACTIONS(142),
    [anon_sym_LBRACK] = ACTIONS(812),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(2299),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(2301),
    [anon_sym_using] = ACTIONS(158),
    [anon_sym_PLUS] = ACTIONS(179),
    [anon_sym_DASH] = ACTIONS(179),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(175),
    [anon_sym_void] = ACTIONS(179),
    [anon_sym_delete] = ACTIONS(179),
    [anon_sym_PLUS_PLUS] = ACTIONS(686),
    [anon_sym_DASH_DASH] = ACTIONS(686),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(192),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(2303),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(2295),
    [anon_sym_readonly] = ACTIONS(2295),
    [anon_sym_get] = ACTIONS(2295),
    [anon_sym_set] = ACTIONS(2295),
    [anon_sym_declare] = ACTIONS(2295),
    [anon_sym_public] = ACTIONS(2295),
    [anon_sym_private] = ACTIONS(2295),
    [anon_sym_protected] = ACTIONS(2295),
    [anon_sym_override] = ACTIONS(2295),
    [anon_sym_module] = ACTIONS(2295),
    [anon_sym_any] = ACTIONS(2295),
    [anon_sym_number] = ACTIONS(2295),
    [anon_sym_boolean] = ACTIONS(2295),
    [anon_sym_string] = ACTIONS(2295),
    [anon_sym_symbol] = ACTIONS(2295),
    [anon_sym_object] = ACTIONS(2295),
    [sym_html_comment] = ACTIONS(5),
  },
  [686] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1456),
    [sym_expression] = STATE(2601),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5815),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5815),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5755),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1456),
    [sym_subscript_expression] = STATE(1456),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3029),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5815),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1456),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(594),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1506),
    [anon_sym_export] = ACTIONS(1234),
    [anon_sym_type] = ACTIONS(1234),
    [anon_sym_namespace] = ACTIONS(1236),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_typeof] = ACTIONS(1256),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1234),
    [anon_sym_BANG] = ACTIONS(1240),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(1242),
    [anon_sym_yield] = ACTIONS(1244),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1246),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1510),
    [anon_sym_using] = ACTIONS(1250),
    [anon_sym_PLUS] = ACTIONS(1256),
    [anon_sym_DASH] = ACTIONS(1256),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(1240),
    [anon_sym_void] = ACTIONS(1256),
    [anon_sym_delete] = ACTIONS(1256),
    [anon_sym_PLUS_PLUS] = ACTIONS(1258),
    [anon_sym_DASH_DASH] = ACTIONS(1258),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(1260),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1512),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1234),
    [anon_sym_readonly] = ACTIONS(1234),
    [anon_sym_get] = ACTIONS(1234),
    [anon_sym_set] = ACTIONS(1234),
    [anon_sym_declare] = ACTIONS(1234),
    [anon_sym_public] = ACTIONS(1234),
    [anon_sym_private] = ACTIONS(1234),
    [anon_sym_protected] = ACTIONS(1234),
    [anon_sym_override] = ACTIONS(1234),
    [anon_sym_module] = ACTIONS(1234),
    [anon_sym_any] = ACTIONS(1234),
    [anon_sym_number] = ACTIONS(1234),
    [anon_sym_boolean] = ACTIONS(1234),
    [anon_sym_string] = ACTIONS(1234),
    [anon_sym_symbol] = ACTIONS(1234),
    [anon_sym_object] = ACTIONS(1234),
    [sym_html_comment] = ACTIONS(5),
  },
  [687] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1472),
    [sym_expression] = STATE(2644),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5788),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5788),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5800),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1472),
    [sym_subscript_expression] = STATE(1472),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3013),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5788),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1472),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(539),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(2305),
    [anon_sym_export] = ACTIONS(2307),
    [anon_sym_type] = ACTIONS(2307),
    [anon_sym_namespace] = ACTIONS(2309),
    [anon_sym_LBRACE] = ACTIONS(808),
    [anon_sym_typeof] = ACTIONS(179),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(2307),
    [anon_sym_BANG] = ACTIONS(175),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(140),
    [anon_sym_yield] = ACTIONS(142),
    [anon_sym_LBRACK] = ACTIONS(812),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(2311),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(2313),
    [anon_sym_using] = ACTIONS(158),
    [anon_sym_PLUS] = ACTIONS(179),
    [anon_sym_DASH] = ACTIONS(179),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(175),
    [anon_sym_void] = ACTIONS(179),
    [anon_sym_delete] = ACTIONS(179),
    [anon_sym_PLUS_PLUS] = ACTIONS(686),
    [anon_sym_DASH_DASH] = ACTIONS(686),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(192),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(2315),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(2307),
    [anon_sym_readonly] = ACTIONS(2307),
    [anon_sym_get] = ACTIONS(2307),
    [anon_sym_set] = ACTIONS(2307),
    [anon_sym_declare] = ACTIONS(2307),
    [anon_sym_public] = ACTIONS(2307),
    [anon_sym_private] = ACTIONS(2307),
    [anon_sym_protected] = ACTIONS(2307),
    [anon_sym_override] = ACTIONS(2307),
    [anon_sym_module] = ACTIONS(2307),
    [anon_sym_any] = ACTIONS(2307),
    [anon_sym_number] = ACTIONS(2307),
    [anon_sym_boolean] = ACTIONS(2307),
    [anon_sym_string] = ACTIONS(2307),
    [anon_sym_symbol] = ACTIONS(2307),
    [anon_sym_object] = ACTIONS(2307),
    [sym_html_comment] = ACTIONS(5),
  },
  [688] = {
    [sym_import] = STATE(3639),
    [sym_parenthesized_expression] = STATE(1456),
    [sym_expression] = STATE(2606),
    [sym_primary_expression] = STATE(1515),
    [sym_yield_expression] = STATE(1652),
    [sym_object] = STATE(1687),
    [sym_object_pattern] = STATE(5815),
    [sym_array] = STATE(1687),
    [sym_array_pattern] = STATE(5815),
    [sym_class] = STATE(1687),
    [sym_function_expression] = STATE(1687),
    [sym_generator_function] = STATE(1687),
    [sym_arrow_function] = STATE(1687),
    [sym__call_signature] = STATE(5755),
    [sym_call_expression] = STATE(1687),
    [sym_new_expression] = STATE(1648),
    [sym_await_expression] = STATE(1652),
    [sym_member_expression] = STATE(1456),
    [sym_subscript_expression] = STATE(1456),
    [sym_assignment_expression] = STATE(1652),
    [sym__augmented_assignment_lhs] = STATE(3029),
    [sym_augmented_assignment_expression] = STATE(1652),
    [sym__destructuring_pattern] = STATE(5815),
    [sym_ternary_expression] = STATE(1652),
    [sym_binary_expression] = STATE(1652),
    [sym_unary_expression] = STATE(1652),
    [sym_update_expression] = STATE(1652),
    [sym_string] = STATE(1687),
    [sym_template_string] = STATE(1687),
    [sym_regex] = STATE(1687),
    [sym_meta_property] = STATE(1687),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1456),
    [sym_type_assertion] = STATE(1652),
    [sym_as_expression] = STATE(1652),
    [sym_satisfies_expression] = STATE(1652),
    [sym_instantiation_expression] = STATE(1652),
    [sym_internal_module] = STATE(1652),
    [sym_type_arguments] = STATE(594),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4429),
    [sym_identifier] = ACTIONS(1506),
    [anon_sym_export] = ACTIONS(1234),
    [anon_sym_type] = ACTIONS(1234),
    [anon_sym_namespace] = ACTIONS(1236),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_typeof] = ACTIONS(1256),
    [anon_sym_import] = ACTIONS(131),
    [anon_sym_let] = ACTIONS(1234),
    [anon_sym_BANG] = ACTIONS(1240),
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(1242),
    [anon_sym_yield] = ACTIONS(1244),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_class] = ACTIONS(146),
    [anon_sym_async] = ACTIONS(1246),
    [anon_sym_function] = ACTIONS(150),
    [anon_sym_new] = ACTIONS(1510),
    [anon_sym_using] = ACTIONS(1250),
    [anon_sym_PLUS] = ACTIONS(1256),
    [anon_sym_DASH] = ACTIONS(1256),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(1240),
    [anon_sym_void] = ACTIONS(1256),
    [anon_sym_delete] = ACTIONS(1256),
    [anon_sym_PLUS_PLUS] = ACTIONS(1258),
    [anon_sym_DASH_DASH] = ACTIONS(1258),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(820),
    [sym_number] = ACTIONS(714),
    [sym_private_property_identifier] = ACTIONS(1260),
    [sym_this] = ACTIONS(196),
    [sym_super] = ACTIONS(196),
    [sym_true] = ACTIONS(196),
    [sym_false] = ACTIONS(196),
    [sym_null] = ACTIONS(196),
    [sym_undefined] = ACTIONS(1512),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1234),
    [anon_sym_readonly] = ACTIONS(1234),
    [anon_sym_get] = ACTIONS(1234),
    [anon_sym_set] = ACTIONS(1234),
    [anon_sym_declare] = ACTIONS(1234),
    [anon_sym_public] = ACTIONS(1234),
    [anon_sym_private] = ACTIONS(1234),
    [anon_sym_protected] = ACTIONS(1234),
    [anon_sym_override] = ACTIONS(1234),
    [anon_sym_module] = ACTIONS(1234),
    [anon_sym_any] = ACTIONS(1234),
    [anon_sym_number] = ACTIONS(1234),
    [anon_sym_boolean] = ACTIONS(1234),
    [anon_sym_string] = ACTIONS(1234),
    [anon_sym_symbol] = ACTIONS(1234),
    [anon_sym_object] = ACTIONS(1234),
    [sym_html_comment] = ACTIONS(5),
  },
  [689] = {
    [sym_import] = STATE(3636),
    [sym_parenthesized_expression] = STATE(1364),
    [sym_expression] = STATE(1849),
    [sym_primary_expression] = STATE(1810),
    [sym_yield_expression] = STATE(2358),
    [sym_object] = STATE(2222),
    [sym_object_pattern] = STATE(5773),
    [sym_array] = STATE(2222),
    [sym_array_pattern] = STATE(5773),
    [sym_class] = STATE(2222),
    [sym_function_expression] = STATE(2222),
    [sym_generator_function] = STATE(2222),
    [sym_arrow_function] = STATE(2222),
    [sym__call_signature] = STATE(5771),
    [sym_call_expression] = STATE(2222),
    [sym_new_expression] = STATE(1948),
    [sym_await_expression] = STATE(2358),
    [sym_member_expression] = STATE(1364),
    [sym_subscript_expression] = STATE(1364),
    [sym_assignment_expression] = STATE(2358),
    [sym__augmented_assignment_lhs] = STATE(3020),
    [sym_augmented_assignment_expression] = STATE(2358),
    [sym__destructuring_pattern] = STATE(5773),
    [sym_ternary_expression] = STATE(2358),
    [sym_binary_expression] = STATE(2358),
    [sym_unary_expression] = STATE(2358),
    [sym_update_expression] = STATE(2358),
    [sym_string] = STATE(2222),
    [sym_template_string] = STATE(2222),
    [sym_regex] = STATE(2222),
    [sym_meta_property] = STATE(2222),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3806),
    [sym_non_null_expression] = STATE(1364),
    [sym_type_assertion] = STATE(2358),
    [sym_as_expression] = STATE(2358),
    [sym_satisfies_expression] = STATE(2358),
    [sym_instantiation_expression] = STATE(2358),
    [sym_internal_module] = STATE(2358),
    [sym_type_arguments] = STATE(513),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_export_statement_repeat1] = STATE(4408),
    [sym_identifier] = ACTIONS(1474),
    [anon_sym_export] = ACTIONS(1386),
    [anon_sym_type] = ACTIONS(1386),
    [anon_sym_namespace] = ACTIONS(1388),
    [anon_sym_LBRACE] = ACTIONS(665),
    [anon_sym_typeof] = ACTIONS(1408),
    [anon_sym_import] = ACTIONS(669),
    [anon_sym_let] = ACTIONS(1386),
    [anon_sym_BANG] = ACTIONS(1392),
    [anon_sym_LPAREN] = ACTIONS(41),
    [anon_sym_await] = ACTIONS(1394),
    [anon_sym_yield] = ACTIONS(1396),
    [anon_sym_LBRACK] = ACTIONS(65),
    [anon_sym_class] = ACTIONS(676),
    [anon_sym_async] = ACTIONS(1398),
    [anon_sym_function] = ACTIONS(680),
    [anon_sym_new] = ACTIONS(1478),
    [anon_sym_using] = ACTIONS(1402),
    [anon_sym_PLUS] = ACTIONS(1408),
    [anon_sym_DASH] = ACTIONS(1408),
    [anon_sym_SLASH] = ACTIONS(876),
    [anon_sym_LT] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(1392),
    [anon_sym_void] = ACTIONS(1408),
    [anon_sym_delete] = ACTIONS(1408),
    [anon_sym_PLUS_PLUS] = ACTIONS(1410),
    [anon_sym_DASH_DASH] = ACTIONS(1410),
    [anon_sym_DQUOTE] = ACTIONS(83),
    [anon_sym_SQUOTE] = ACTIONS(85),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(87),
    [sym_number] = ACTIONS(89),
    [sym_private_property_identifier] = ACTIONS(1412),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(93),
    [sym_true] = ACTIONS(93),
    [sym_false] = ACTIONS(93),
    [sym_null] = ACTIONS(93),
    [sym_undefined] = ACTIONS(1480),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(1386),
    [anon_sym_readonly] = ACTIONS(1386),
    [anon_sym_get] = ACTIONS(1386),
    [anon_sym_set] = ACTIONS(1386),
    [anon_sym_declare] = ACTIONS(1386),
    [anon_sym_public] = ACTIONS(1386),
    [anon_sym_private] = ACTIONS(1386),
    [anon_sym_protected] = ACTIONS(1386),
    [anon_sym_override] = ACTIONS(1386),
    [anon_sym_module] = ACTIONS(1386),
    [anon_sym_any] = ACTIONS(1386),
    [anon_sym_number] = ACTIONS(1386),
    [anon_sym_boolean] = ACTIONS(1386),
    [anon_sym_string] = ACTIONS(1386),
    [anon_sym_symbol] = ACTIONS(1386),
    [anon_sym_object] = ACTIONS(1386),
    [sym_html_comment] = ACTIONS(5),
  },
  [690] = {
    [sym__call_signature] = STATE(5693),
    [sym_string] = STATE(3816),
    [sym_formal_parameters] = STATE(3806),
    [sym__property_name] = STATE(3816),
    [sym_computed_property_name] = STATE(3816),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_object_repeat1] = STATE(4792),
    [aux_sym_object_pattern_repeat1] = STATE(4815),
    [sym_identifier] = ACTIONS(2317),
    [anon_sym_export] = ACTIONS(2319),
    [anon_sym_STAR] = ACTIONS(2321),
    [anon_sym_type] = ACTIONS(2319),
    [anon_sym_EQ] = ACTIONS(661),
    [anon_sym_as] = ACTIONS(120),
    [anon_sym_namespace] = ACTIONS(2319),
    [anon_sym_COMMA] = ACTIONS(154),
    [anon_sym_RBRACE] = ACTIONS(694),
    [anon_sym_let] = ACTIONS(2319),
    [anon_sym_BANG] = ACTIONS(120),
    [anon_sym_LPAREN] = ACTIONS(2324),
    [anon_sym_SEMI] = ACTIONS(154),
    [anon_sym_in] = ACTIONS(120),
    [anon_sym_COLON] = ACTIONS(671),
    [anon_sym_LBRACK] = ACTIONS(2328),
    [anon_sym_DOT] = ACTIONS(120),
    [anon_sym_async] = ACTIONS(2319),
    [anon_sym_function] = ACTIONS(2331),
    [anon_sym_EQ_GT] = ACTIONS(682),
    [anon_sym_QMARK_DOT] = ACTIONS(154),
    [anon_sym_new] = ACTIONS(2319),
    [anon_sym_PLUS_EQ] = ACTIONS(160),
    [anon_sym_DASH_EQ] = ACTIONS(160),
    [anon_sym_STAR_EQ] = ACTIONS(160),
    [anon_sym_SLASH_EQ] = ACTIONS(160),
    [anon_sym_PERCENT_EQ] = ACTIONS(160),
    [anon_sym_CARET_EQ] = ACTIONS(160),
    [anon_sym_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_LT_LT_EQ] = ACTIONS(160),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(160),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP] = ACTIONS(120),
    [anon_sym_PIPE_PIPE] = ACTIONS(120),
    [anon_sym_GT_GT] = ACTIONS(120),
    [anon_sym_GT_GT_GT] = ACTIONS(120),
    [anon_sym_LT_LT] = ACTIONS(120),
    [anon_sym_AMP] = ACTIONS(120),
    [anon_sym_CARET] = ACTIONS(120),
    [anon_sym_PIPE] = ACTIONS(120),
    [anon_sym_PLUS] = ACTIONS(120),
    [anon_sym_DASH] = ACTIONS(120),
    [anon_sym_SLASH] = ACTIONS(120),
    [anon_sym_PERCENT] = ACTIONS(120),
    [anon_sym_STAR_STAR] = ACTIONS(120),
    [anon_sym_LT] = ACTIONS(2333),
    [anon_sym_LT_EQ] = ACTIONS(154),
    [anon_sym_EQ_EQ] = ACTIONS(120),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(154),
    [anon_sym_BANG_EQ] = ACTIONS(120),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(154),
    [anon_sym_GT_EQ] = ACTIONS(154),
    [anon_sym_GT] = ACTIONS(120),
    [anon_sym_QMARK_QMARK] = ACTIONS(120),
    [anon_sym_instanceof] = ACTIONS(120),
    [anon_sym_PLUS_PLUS] = ACTIONS(154),
    [anon_sym_DASH_DASH] = ACTIONS(154),
    [anon_sym_DQUOTE] = ACTIONS(1550),
    [anon_sym_SQUOTE] = ACTIONS(1552),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(154),
    [sym_number] = ACTIONS(2337),
    [sym_private_property_identifier] = ACTIONS(2337),
    [anon_sym_static] = ACTIONS(2319),
    [anon_sym_readonly] = ACTIONS(2319),
    [anon_sym_get] = ACTIONS(2339),
    [anon_sym_set] = ACTIONS(2339),
    [anon_sym_QMARK] = ACTIONS(690),
    [anon_sym_declare] = ACTIONS(2319),
    [anon_sym_public] = ACTIONS(2319),
    [anon_sym_private] = ACTIONS(2319),
    [anon_sym_protected] = ACTIONS(2319),
    [anon_sym_override] = ACTIONS(2319),
    [anon_sym_module] = ACTIONS(2319),
    [anon_sym_any] = ACTIONS(2319),
    [anon_sym_number] = ACTIONS(2319),
    [anon_sym_boolean] = ACTIONS(2319),
    [anon_sym_string] = ACTIONS(2319),
    [anon_sym_symbol] = ACTIONS(2319),
    [anon_sym_object] = ACTIONS(2319),
    [anon_sym_satisfies] = ACTIONS(120),
    [sym__automatic_semicolon] = ACTIONS(154),
    [sym__ternary_qmark] = ACTIONS(154),
    [sym_html_comment] = ACTIONS(5),
  },
  [691] = {
    [sym__call_signature] = STATE(5693),
    [sym_string] = STATE(3816),
    [sym_formal_parameters] = STATE(3806),
    [sym__property_name] = STATE(3816),
    [sym_computed_property_name] = STATE(3816),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_object_repeat1] = STATE(4810),
    [aux_sym_object_pattern_repeat1] = STATE(4815),
    [sym_identifier] = ACTIONS(2317),
    [anon_sym_export] = ACTIONS(2319),
    [anon_sym_STAR] = ACTIONS(2321),
    [anon_sym_type] = ACTIONS(2319),
    [anon_sym_EQ] = ACTIONS(661),
    [anon_sym_as] = ACTIONS(120),
    [anon_sym_namespace] = ACTIONS(2319),
    [anon_sym_COMMA] = ACTIONS(154),
    [anon_sym_RBRACE] = ACTIONS(692),
    [anon_sym_let] = ACTIONS(2319),
    [anon_sym_BANG] = ACTIONS(120),
    [anon_sym_LPAREN] = ACTIONS(2324),
    [anon_sym_SEMI] = ACTIONS(154),
    [anon_sym_in] = ACTIONS(120),
    [anon_sym_COLON] = ACTIONS(671),
    [anon_sym_LBRACK] = ACTIONS(2328),
    [anon_sym_DOT] = ACTIONS(120),
    [anon_sym_async] = ACTIONS(2319),
    [anon_sym_function] = ACTIONS(2331),
    [anon_sym_EQ_GT] = ACTIONS(682),
    [anon_sym_QMARK_DOT] = ACTIONS(154),
    [anon_sym_new] = ACTIONS(2319),
    [anon_sym_PLUS_EQ] = ACTIONS(160),
    [anon_sym_DASH_EQ] = ACTIONS(160),
    [anon_sym_STAR_EQ] = ACTIONS(160),
    [anon_sym_SLASH_EQ] = ACTIONS(160),
    [anon_sym_PERCENT_EQ] = ACTIONS(160),
    [anon_sym_CARET_EQ] = ACTIONS(160),
    [anon_sym_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_LT_LT_EQ] = ACTIONS(160),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(160),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP] = ACTIONS(120),
    [anon_sym_PIPE_PIPE] = ACTIONS(120),
    [anon_sym_GT_GT] = ACTIONS(120),
    [anon_sym_GT_GT_GT] = ACTIONS(120),
    [anon_sym_LT_LT] = ACTIONS(120),
    [anon_sym_AMP] = ACTIONS(120),
    [anon_sym_CARET] = ACTIONS(120),
    [anon_sym_PIPE] = ACTIONS(120),
    [anon_sym_PLUS] = ACTIONS(120),
    [anon_sym_DASH] = ACTIONS(120),
    [anon_sym_SLASH] = ACTIONS(120),
    [anon_sym_PERCENT] = ACTIONS(120),
    [anon_sym_STAR_STAR] = ACTIONS(120),
    [anon_sym_LT] = ACTIONS(2333),
    [anon_sym_LT_EQ] = ACTIONS(154),
    [anon_sym_EQ_EQ] = ACTIONS(120),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(154),
    [anon_sym_BANG_EQ] = ACTIONS(120),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(154),
    [anon_sym_GT_EQ] = ACTIONS(154),
    [anon_sym_GT] = ACTIONS(120),
    [anon_sym_QMARK_QMARK] = ACTIONS(120),
    [anon_sym_instanceof] = ACTIONS(120),
    [anon_sym_PLUS_PLUS] = ACTIONS(154),
    [anon_sym_DASH_DASH] = ACTIONS(154),
    [anon_sym_DQUOTE] = ACTIONS(1550),
    [anon_sym_SQUOTE] = ACTIONS(1552),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(154),
    [sym_number] = ACTIONS(2337),
    [sym_private_property_identifier] = ACTIONS(2337),
    [anon_sym_static] = ACTIONS(2319),
    [anon_sym_readonly] = ACTIONS(2319),
    [anon_sym_get] = ACTIONS(2339),
    [anon_sym_set] = ACTIONS(2339),
    [anon_sym_QMARK] = ACTIONS(690),
    [anon_sym_declare] = ACTIONS(2319),
    [anon_sym_public] = ACTIONS(2319),
    [anon_sym_private] = ACTIONS(2319),
    [anon_sym_protected] = ACTIONS(2319),
    [anon_sym_override] = ACTIONS(2319),
    [anon_sym_module] = ACTIONS(2319),
    [anon_sym_any] = ACTIONS(2319),
    [anon_sym_number] = ACTIONS(2319),
    [anon_sym_boolean] = ACTIONS(2319),
    [anon_sym_string] = ACTIONS(2319),
    [anon_sym_symbol] = ACTIONS(2319),
    [anon_sym_object] = ACTIONS(2319),
    [anon_sym_satisfies] = ACTIONS(120),
    [sym__automatic_semicolon] = ACTIONS(154),
    [sym__ternary_qmark] = ACTIONS(154),
    [sym_html_comment] = ACTIONS(5),
  },
  [692] = {
    [sym__call_signature] = STATE(5693),
    [sym_string] = STATE(3816),
    [sym_formal_parameters] = STATE(3806),
    [sym__property_name] = STATE(3816),
    [sym_computed_property_name] = STATE(3816),
    [sym_type_parameters] = STATE(5328),
    [aux_sym_object_repeat1] = STATE(4792),
    [aux_sym_object_pattern_repeat1] = STATE(4815),
    [sym_identifier] = ACTIONS(2317),
    [anon_sym_export] = ACTIONS(2319),
    [anon_sym_STAR] = ACTIONS(2321),
    [anon_sym_type] = ACTIONS(2319),
    [anon_sym_EQ] = ACTIONS(661),
    [anon_sym_as] = ACTIONS(120),
    [anon_sym_namespace] = ACTIONS(2319),
    [anon_sym_COMMA] = ACTIONS(154),
    [anon_sym_RBRACE] = ACTIONS(667),
    [anon_sym_let] = ACTIONS(2319),
    [anon_sym_BANG] = ACTIONS(120),
    [anon_sym_LPAREN] = ACTIONS(2324),
    [anon_sym_SEMI] = ACTIONS(154),
    [anon_sym_in] = ACTIONS(120),
    [anon_sym_COLON] = ACTIONS(671),
    [anon_sym_LBRACK] = ACTIONS(2328),
    [anon_sym_DOT] = ACTIONS(120),
    [anon_sym_async] = ACTIONS(2319),
    [anon_sym_function] = ACTIONS(2331),
    [anon_sym_EQ_GT] = ACTIONS(682),
    [anon_sym_QMARK_DOT] = ACTIONS(154),
    [anon_sym_new] = ACTIONS(2319),
    [anon_sym_PLUS_EQ] = ACTIONS(160),
    [anon_sym_DASH_EQ] = ACTIONS(160),
    [anon_sym_STAR_EQ] = ACTIONS(160),
    [anon_sym_SLASH_EQ] = ACTIONS(160),
    [anon_sym_PERCENT_EQ] = ACTIONS(160),
    [anon_sym_CARET_EQ] = ACTIONS(160),
    [anon_sym_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_LT_LT_EQ] = ACTIONS(160),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(160),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP] = ACTIONS(120),
    [anon_sym_PIPE_PIPE] = ACTIONS(120),
    [anon_sym_GT_GT] = ACTIONS(120),
    [anon_sym_GT_GT_GT] = ACTIONS(120),
    [anon_sym_LT_LT] = ACTIONS(120),
    [anon_sym_AMP] = ACTIONS(120),
    [anon_sym_CARET] = ACTIONS(120),
    [anon_sym_PIPE] = ACTIONS(120),
    [anon_sym_PLUS] = ACTIONS(120),
    [anon_sym_DASH] = ACTIONS(120),
    [anon_sym_SLASH] = ACTIONS(120),
    [anon_sym_PERCENT] = ACTIONS(120),
    [anon_sym_STAR_STAR] = ACTIONS(120),
    [anon_sym_LT] = ACTIONS(2333),
    [anon_sym_LT_EQ] = ACTIONS(154),
    [anon_sym_EQ_EQ] = ACTIONS(120),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(154),
    [anon_sym_BANG_EQ] = ACTIONS(120),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(154),
    [anon_sym_GT_EQ] = ACTIONS(154),
    [anon_sym_GT] = ACTIONS(120),
    [anon_sym_QMARK_QMARK] = ACTIONS(120),
    [anon_sym_instanceof] = ACTIONS(120),
    [anon_sym_PLUS_PLUS] = ACTIONS(154),
    [anon_sym_DASH_DASH] = ACTIONS(154),
    [anon_sym_DQUOTE] = ACTIONS(1550),
    [anon_sym_SQUOTE] = ACTIONS(1552),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(154),
    [sym_number] = ACTIONS(2337),
    [sym_private_property_identifier] = ACTIONS(2337),
    [anon_sym_static] = ACTIONS(2319),
    [anon_sym_readonly] = ACTIONS(2319),
    [anon_sym_get] = ACTIONS(2339),
    [anon_sym_set] = ACTIONS(2339),
    [anon_sym_QMARK] = ACTIONS(690),
    [anon_sym_declare] = ACTIONS(2319),
    [anon_sym_public] = ACTIONS(2319),
    [anon_sym_private] = ACTIONS(2319),
    [anon_sym_protected] = ACTIONS(2319),
    [anon_sym_override] = ACTIONS(2319),
    [anon_sym_module] = ACTIONS(2319),
    [anon_sym_any] = ACTIONS(2319),
    [anon_sym_number] = ACTIONS(2319),
    [anon_sym_boolean] = ACTIONS(2319),
    [anon_sym_string] = ACTIONS(2319),
    [anon_sym_symbol] = ACTIONS(2319),
    [anon_sym_object] = ACTIONS(2319),
    [anon_sym_satisfies] = ACTIONS(120),
    [sym__automatic_semicolon] = ACTIONS(154),
    [sym__ternary_qmark] = ACTIONS(154),
    [sym_html_comment] = ACTIONS(5),
  },
  [693] = {
    [sym_declaration] = STATE(867),
    [sym_variable_declaration] = STATE(831),
    [sym_lexical_declaration] = STATE(831),
    [sym_class_declaration] = STATE(831),
    [sym_function_declaration] = STATE(831),
    [sym_generator_function_declaration] = STATE(831),
    [sym_decorator] = STATE(1344),
    [sym_function_signature] = STATE(831),
    [sym_ambient_declaration] = STATE(831),
    [sym_abstract_class_declaration] = STATE(831),
    [sym_module] = STATE(831),
    [sym_internal_module] = STATE(824),
    [sym_import_alias] = STATE(831),
    [sym_interface_declaration] = STATE(831),
    [sym_enum_declaration] = STATE(831),
    [sym_type_alias_declaration] = STATE(831),
    [aux_sym_export_statement_repeat1] = STATE(4301),
    [aux_sym_object_repeat1] = STATE(4792),
    [aux_sym_object_pattern_repeat1] = STATE(4815),
    [anon_sym_STAR] = ACTIONS(120),
    [anon_sym_type] = ACTIONS(2341),
    [anon_sym_EQ] = ACTIONS(661),
    [anon_sym_as] = ACTIONS(120),
    [anon_sym_namespace] = ACTIONS(2137),
    [anon_sym_COMMA] = ACTIONS(154),
    [anon_sym_RBRACE] = ACTIONS(667),
    [anon_sym_import] = ACTIONS(2141),
    [anon_sym_var] = ACTIONS(2143),
    [anon_sym_let] = ACTIONS(2145),
    [anon_sym_const] = ACTIONS(2147),
    [anon_sym_BANG] = ACTIONS(120),
    [anon_sym_LPAREN] = ACTIONS(2149),
    [anon_sym_SEMI] = ACTIONS(154),
    [anon_sym_in] = ACTIONS(120),
    [anon_sym_COLON] = ACTIONS(671),
    [anon_sym_LBRACK] = ACTIONS(154),
    [anon_sym_DOT] = ACTIONS(154),
    [anon_sym_class] = ACTIONS(2152),
    [anon_sym_async] = ACTIONS(2154),
    [anon_sym_function] = ACTIONS(2156),
    [anon_sym_EQ_GT] = ACTIONS(682),
    [anon_sym_QMARK_DOT] = ACTIONS(154),
    [anon_sym_PLUS_EQ] = ACTIONS(160),
    [anon_sym_DASH_EQ] = ACTIONS(160),
    [anon_sym_STAR_EQ] = ACTIONS(160),
    [anon_sym_SLASH_EQ] = ACTIONS(160),
    [anon_sym_PERCENT_EQ] = ACTIONS(160),
    [anon_sym_CARET_EQ] = ACTIONS(160),
    [anon_sym_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_LT_LT_EQ] = ACTIONS(160),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(160),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP] = ACTIONS(120),
    [anon_sym_PIPE_PIPE] = ACTIONS(120),
    [anon_sym_GT_GT] = ACTIONS(120),
    [anon_sym_GT_GT_GT] = ACTIONS(120),
    [anon_sym_LT_LT] = ACTIONS(120),
    [anon_sym_AMP] = ACTIONS(120),
    [anon_sym_CARET] = ACTIONS(120),
    [anon_sym_PIPE] = ACTIONS(120),
    [anon_sym_PLUS] = ACTIONS(120),
    [anon_sym_DASH] = ACTIONS(120),
    [anon_sym_SLASH] = ACTIONS(120),
    [anon_sym_PERCENT] = ACTIONS(120),
    [anon_sym_STAR_STAR] = ACTIONS(120),
    [anon_sym_LT] = ACTIONS(2158),
    [anon_sym_LT_EQ] = ACTIONS(154),
    [anon_sym_EQ_EQ] = ACTIONS(120),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(154),
    [anon_sym_BANG_EQ] = ACTIONS(120),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(154),
    [anon_sym_GT_EQ] = ACTIONS(154),
    [anon_sym_GT] = ACTIONS(120),
    [anon_sym_QMARK_QMARK] = ACTIONS(120),
    [anon_sym_instanceof] = ACTIONS(154),
    [anon_sym_PLUS_PLUS] = ACTIONS(154),
    [anon_sym_DASH_DASH] = ACTIONS(154),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(154),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_QMARK] = ACTIONS(690),
    [anon_sym_declare] = ACTIONS(2161),
    [anon_sym_module] = ACTIONS(2343),
    [anon_sym_abstract] = ACTIONS(2165),
    [anon_sym_satisfies] = ACTIONS(154),
    [anon_sym_global] = ACTIONS(2345),
    [anon_sym_interface] = ACTIONS(2167),
    [anon_sym_enum] = ACTIONS(2169),
    [sym__automatic_semicolon] = ACTIONS(154),
    [sym__ternary_qmark] = ACTIONS(154),
    [sym_html_comment] = ACTIONS(5),
  },
  [694] = {
    [sym_declaration] = STATE(867),
    [sym_variable_declaration] = STATE(831),
    [sym_lexical_declaration] = STATE(831),
    [sym_class_declaration] = STATE(831),
    [sym_function_declaration] = STATE(831),
    [sym_generator_function_declaration] = STATE(831),
    [sym_decorator] = STATE(1344),
    [sym_function_signature] = STATE(831),
    [sym_ambient_declaration] = STATE(831),
    [sym_abstract_class_declaration] = STATE(831),
    [sym_module] = STATE(831),
    [sym_internal_module] = STATE(824),
    [sym_import_alias] = STATE(831),
    [sym_interface_declaration] = STATE(831),
    [sym_enum_declaration] = STATE(831),
    [sym_type_alias_declaration] = STATE(831),
    [aux_sym_export_statement_repeat1] = STATE(4301),
    [aux_sym_object_repeat1] = STATE(4810),
    [aux_sym_object_pattern_repeat1] = STATE(4815),
    [anon_sym_STAR] = ACTIONS(120),
    [anon_sym_type] = ACTIONS(2341),
    [anon_sym_EQ] = ACTIONS(661),
    [anon_sym_as] = ACTIONS(120),
    [anon_sym_namespace] = ACTIONS(2137),
    [anon_sym_COMMA] = ACTIONS(154),
    [anon_sym_RBRACE] = ACTIONS(692),
    [anon_sym_import] = ACTIONS(2141),
    [anon_sym_var] = ACTIONS(2143),
    [anon_sym_let] = ACTIONS(2145),
    [anon_sym_const] = ACTIONS(2147),
    [anon_sym_BANG] = ACTIONS(120),
    [anon_sym_LPAREN] = ACTIONS(2149),
    [anon_sym_SEMI] = ACTIONS(154),
    [anon_sym_in] = ACTIONS(120),
    [anon_sym_COLON] = ACTIONS(671),
    [anon_sym_LBRACK] = ACTIONS(154),
    [anon_sym_DOT] = ACTIONS(154),
    [anon_sym_class] = ACTIONS(2152),
    [anon_sym_async] = ACTIONS(2154),
    [anon_sym_function] = ACTIONS(2156),
    [anon_sym_EQ_GT] = ACTIONS(682),
    [anon_sym_QMARK_DOT] = ACTIONS(154),
    [anon_sym_PLUS_EQ] = ACTIONS(160),
    [anon_sym_DASH_EQ] = ACTIONS(160),
    [anon_sym_STAR_EQ] = ACTIONS(160),
    [anon_sym_SLASH_EQ] = ACTIONS(160),
    [anon_sym_PERCENT_EQ] = ACTIONS(160),
    [anon_sym_CARET_EQ] = ACTIONS(160),
    [anon_sym_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_LT_LT_EQ] = ACTIONS(160),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(160),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP] = ACTIONS(120),
    [anon_sym_PIPE_PIPE] = ACTIONS(120),
    [anon_sym_GT_GT] = ACTIONS(120),
    [anon_sym_GT_GT_GT] = ACTIONS(120),
    [anon_sym_LT_LT] = ACTIONS(120),
    [anon_sym_AMP] = ACTIONS(120),
    [anon_sym_CARET] = ACTIONS(120),
    [anon_sym_PIPE] = ACTIONS(120),
    [anon_sym_PLUS] = ACTIONS(120),
    [anon_sym_DASH] = ACTIONS(120),
    [anon_sym_SLASH] = ACTIONS(120),
    [anon_sym_PERCENT] = ACTIONS(120),
    [anon_sym_STAR_STAR] = ACTIONS(120),
    [anon_sym_LT] = ACTIONS(2158),
    [anon_sym_LT_EQ] = ACTIONS(154),
    [anon_sym_EQ_EQ] = ACTIONS(120),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(154),
    [anon_sym_BANG_EQ] = ACTIONS(120),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(154),
    [anon_sym_GT_EQ] = ACTIONS(154),
    [anon_sym_GT] = ACTIONS(120),
    [anon_sym_QMARK_QMARK] = ACTIONS(120),
    [anon_sym_instanceof] = ACTIONS(154),
    [anon_sym_PLUS_PLUS] = ACTIONS(154),
    [anon_sym_DASH_DASH] = ACTIONS(154),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(154),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_QMARK] = ACTIONS(690),
    [anon_sym_declare] = ACTIONS(2161),
    [anon_sym_module] = ACTIONS(2343),
    [anon_sym_abstract] = ACTIONS(2165),
    [anon_sym_satisfies] = ACTIONS(154),
    [anon_sym_global] = ACTIONS(2345),
    [anon_sym_interface] = ACTIONS(2167),
    [anon_sym_enum] = ACTIONS(2169),
    [sym__automatic_semicolon] = ACTIONS(154),
    [sym__ternary_qmark] = ACTIONS(154),
    [sym_html_comment] = ACTIONS(5),
  },
  [695] = {
    [sym_declaration] = STATE(867),
    [sym_variable_declaration] = STATE(831),
    [sym_lexical_declaration] = STATE(831),
    [sym_class_declaration] = STATE(831),
    [sym_function_declaration] = STATE(831),
    [sym_generator_function_declaration] = STATE(831),
    [sym_decorator] = STATE(1344),
    [sym_function_signature] = STATE(831),
    [sym_ambient_declaration] = STATE(831),
    [sym_abstract_class_declaration] = STATE(831),
    [sym_module] = STATE(831),
    [sym_internal_module] = STATE(824),
    [sym_import_alias] = STATE(831),
    [sym_interface_declaration] = STATE(831),
    [sym_enum_declaration] = STATE(831),
    [sym_type_alias_declaration] = STATE(831),
    [aux_sym_export_statement_repeat1] = STATE(4301),
    [aux_sym_object_repeat1] = STATE(4792),
    [aux_sym_object_pattern_repeat1] = STATE(4815),
    [anon_sym_STAR] = ACTIONS(120),
    [anon_sym_type] = ACTIONS(2341),
    [anon_sym_EQ] = ACTIONS(661),
    [anon_sym_as] = ACTIONS(120),
    [anon_sym_namespace] = ACTIONS(2137),
    [anon_sym_COMMA] = ACTIONS(154),
    [anon_sym_RBRACE] = ACTIONS(694),
    [anon_sym_import] = ACTIONS(2141),
    [anon_sym_var] = ACTIONS(2143),
    [anon_sym_let] = ACTIONS(2145),
    [anon_sym_const] = ACTIONS(2147),
    [anon_sym_BANG] = ACTIONS(120),
    [anon_sym_LPAREN] = ACTIONS(2149),
    [anon_sym_SEMI] = ACTIONS(154),
    [anon_sym_in] = ACTIONS(120),
    [anon_sym_COLON] = ACTIONS(671),
    [anon_sym_LBRACK] = ACTIONS(154),
    [anon_sym_DOT] = ACTIONS(154),
    [anon_sym_class] = ACTIONS(2152),
    [anon_sym_async] = ACTIONS(2154),
    [anon_sym_function] = ACTIONS(2156),
    [anon_sym_EQ_GT] = ACTIONS(682),
    [anon_sym_QMARK_DOT] = ACTIONS(154),
    [anon_sym_PLUS_EQ] = ACTIONS(160),
    [anon_sym_DASH_EQ] = ACTIONS(160),
    [anon_sym_STAR_EQ] = ACTIONS(160),
    [anon_sym_SLASH_EQ] = ACTIONS(160),
    [anon_sym_PERCENT_EQ] = ACTIONS(160),
    [anon_sym_CARET_EQ] = ACTIONS(160),
    [anon_sym_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_LT_LT_EQ] = ACTIONS(160),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(160),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP] = ACTIONS(120),
    [anon_sym_PIPE_PIPE] = ACTIONS(120),
    [anon_sym_GT_GT] = ACTIONS(120),
    [anon_sym_GT_GT_GT] = ACTIONS(120),
    [anon_sym_LT_LT] = ACTIONS(120),
    [anon_sym_AMP] = ACTIONS(120),
    [anon_sym_CARET] = ACTIONS(120),
    [anon_sym_PIPE] = ACTIONS(120),
    [anon_sym_PLUS] = ACTIONS(120),
    [anon_sym_DASH] = ACTIONS(120),
    [anon_sym_SLASH] = ACTIONS(120),
    [anon_sym_PERCENT] = ACTIONS(120),
    [anon_sym_STAR_STAR] = ACTIONS(120),
    [anon_sym_LT] = ACTIONS(2158),
    [anon_sym_LT_EQ] = ACTIONS(154),
    [anon_sym_EQ_EQ] = ACTIONS(120),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(154),
    [anon_sym_BANG_EQ] = ACTIONS(120),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(154),
    [anon_sym_GT_EQ] = ACTIONS(154),
    [anon_sym_GT] = ACTIONS(120),
    [anon_sym_QMARK_QMARK] = ACTIONS(120),
    [anon_sym_instanceof] = ACTIONS(154),
    [anon_sym_PLUS_PLUS] = ACTIONS(154),
    [anon_sym_DASH_DASH] = ACTIONS(154),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(154),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_QMARK] = ACTIONS(690),
    [anon_sym_declare] = ACTIONS(2161),
    [anon_sym_module] = ACTIONS(2343),
    [anon_sym_abstract] = ACTIONS(2165),
    [anon_sym_satisfies] = ACTIONS(154),
    [anon_sym_global] = ACTIONS(2345),
    [anon_sym_interface] = ACTIONS(2167),
    [anon_sym_enum] = ACTIONS(2169),
    [sym__automatic_semicolon] = ACTIONS(154),
    [sym__ternary_qmark] = ACTIONS(154),
    [sym_html_comment] = ACTIONS(5),
  },
  [696] = {
    [sym_namespace_export] = STATE(5206),
    [sym_export_clause] = STATE(4427),
    [sym_declaration] = STATE(919),
    [sym_variable_declaration] = STATE(831),
    [sym_lexical_declaration] = STATE(831),
    [sym_class_declaration] = STATE(831),
    [sym_function_declaration] = STATE(831),
    [sym_generator_function_declaration] = STATE(831),
    [sym_decorator] = STATE(1344),
    [sym_function_signature] = STATE(831),
    [sym_ambient_declaration] = STATE(831),
    [sym_abstract_class_declaration] = STATE(831),
    [sym_module] = STATE(831),
    [sym_internal_module] = STATE(824),
    [sym_import_alias] = STATE(831),
    [sym_interface_declaration] = STATE(831),
    [sym_enum_declaration] = STATE(831),
    [sym_type_alias_declaration] = STATE(831),
    [aux_sym_export_statement_repeat1] = STATE(4301),
    [anon_sym_STAR] = ACTIONS(2127),
    [anon_sym_default] = ACTIONS(2129),
    [anon_sym_type] = ACTIONS(2131),
    [anon_sym_EQ] = ACTIONS(2347),
    [anon_sym_as] = ACTIONS(2135),
    [anon_sym_namespace] = ACTIONS(2137),
    [anon_sym_LBRACE] = ACTIONS(2139),
    [anon_sym_COMMA] = ACTIONS(154),
    [anon_sym_import] = ACTIONS(2141),
    [anon_sym_var] = ACTIONS(2143),
    [anon_sym_let] = ACTIONS(2145),
    [anon_sym_const] = ACTIONS(2147),
    [anon_sym_BANG] = ACTIONS(120),
    [anon_sym_LPAREN] = ACTIONS(154),
    [anon_sym_SEMI] = ACTIONS(154),
    [anon_sym_in] = ACTIONS(120),
    [anon_sym_COLON] = ACTIONS(860),
    [anon_sym_LBRACK] = ACTIONS(154),
    [anon_sym_DOT] = ACTIONS(154),
    [anon_sym_class] = ACTIONS(2152),
    [anon_sym_async] = ACTIONS(2154),
    [anon_sym_function] = ACTIONS(2156),
    [anon_sym_EQ_GT] = ACTIONS(682),
    [anon_sym_QMARK_DOT] = ACTIONS(154),
    [anon_sym_PLUS_EQ] = ACTIONS(160),
    [anon_sym_DASH_EQ] = ACTIONS(160),
    [anon_sym_STAR_EQ] = ACTIONS(160),
    [anon_sym_SLASH_EQ] = ACTIONS(160),
    [anon_sym_PERCENT_EQ] = ACTIONS(160),
    [anon_sym_CARET_EQ] = ACTIONS(160),
    [anon_sym_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_LT_LT_EQ] = ACTIONS(160),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(160),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP] = ACTIONS(120),
    [anon_sym_PIPE_PIPE] = ACTIONS(120),
    [anon_sym_GT_GT] = ACTIONS(120),
    [anon_sym_GT_GT_GT] = ACTIONS(120),
    [anon_sym_LT_LT] = ACTIONS(120),
    [anon_sym_AMP] = ACTIONS(120),
    [anon_sym_CARET] = ACTIONS(120),
    [anon_sym_PIPE] = ACTIONS(120),
    [anon_sym_PLUS] = ACTIONS(120),
    [anon_sym_DASH] = ACTIONS(120),
    [anon_sym_SLASH] = ACTIONS(120),
    [anon_sym_PERCENT] = ACTIONS(120),
    [anon_sym_STAR_STAR] = ACTIONS(120),
    [anon_sym_LT] = ACTIONS(120),
    [anon_sym_LT_EQ] = ACTIONS(154),
    [anon_sym_EQ_EQ] = ACTIONS(120),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(154),
    [anon_sym_BANG_EQ] = ACTIONS(120),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(154),
    [anon_sym_GT_EQ] = ACTIONS(154),
    [anon_sym_GT] = ACTIONS(120),
    [anon_sym_QMARK_QMARK] = ACTIONS(120),
    [anon_sym_instanceof] = ACTIONS(154),
    [anon_sym_PLUS_PLUS] = ACTIONS(154),
    [anon_sym_DASH_DASH] = ACTIONS(154),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(154),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_declare] = ACTIONS(2161),
    [anon_sym_module] = ACTIONS(2163),
    [anon_sym_abstract] = ACTIONS(2165),
    [anon_sym_satisfies] = ACTIONS(154),
    [anon_sym_interface] = ACTIONS(2167),
    [anon_sym_enum] = ACTIONS(2169),
    [sym__automatic_semicolon] = ACTIONS(154),
    [sym__ternary_qmark] = ACTIONS(154),
    [sym_html_comment] = ACTIONS(5),
  },
  [697] = {
    [sym_namespace_export] = STATE(5206),
    [sym_export_clause] = STATE(4427),
    [sym_declaration] = STATE(919),
    [sym_variable_declaration] = STATE(831),
    [sym_lexical_declaration] = STATE(831),
    [sym_class_declaration] = STATE(831),
    [sym_function_declaration] = STATE(831),
    [sym_generator_function_declaration] = STATE(831),
    [sym_decorator] = STATE(1344),
    [sym_function_signature] = STATE(831),
    [sym_ambient_declaration] = STATE(831),
    [sym_abstract_class_declaration] = STATE(831),
    [sym_module] = STATE(831),
    [sym_internal_module] = STATE(824),
    [sym_import_alias] = STATE(831),
    [sym_interface_declaration] = STATE(831),
    [sym_enum_declaration] = STATE(831),
    [sym_type_alias_declaration] = STATE(831),
    [aux_sym_export_statement_repeat1] = STATE(4301),
    [anon_sym_STAR] = ACTIONS(2127),
    [anon_sym_default] = ACTIONS(2349),
    [anon_sym_type] = ACTIONS(2131),
    [anon_sym_EQ] = ACTIONS(2347),
    [anon_sym_as] = ACTIONS(2135),
    [anon_sym_namespace] = ACTIONS(2137),
    [anon_sym_LBRACE] = ACTIONS(2139),
    [anon_sym_COMMA] = ACTIONS(154),
    [anon_sym_import] = ACTIONS(2141),
    [anon_sym_var] = ACTIONS(2143),
    [anon_sym_let] = ACTIONS(2145),
    [anon_sym_const] = ACTIONS(2147),
    [anon_sym_BANG] = ACTIONS(120),
    [anon_sym_LPAREN] = ACTIONS(154),
    [anon_sym_SEMI] = ACTIONS(154),
    [anon_sym_in] = ACTIONS(120),
    [anon_sym_COLON] = ACTIONS(878),
    [anon_sym_LBRACK] = ACTIONS(154),
    [anon_sym_DOT] = ACTIONS(154),
    [anon_sym_class] = ACTIONS(2152),
    [anon_sym_async] = ACTIONS(2154),
    [anon_sym_function] = ACTIONS(2156),
    [anon_sym_EQ_GT] = ACTIONS(682),
    [anon_sym_QMARK_DOT] = ACTIONS(154),
    [anon_sym_PLUS_EQ] = ACTIONS(160),
    [anon_sym_DASH_EQ] = ACTIONS(160),
    [anon_sym_STAR_EQ] = ACTIONS(160),
    [anon_sym_SLASH_EQ] = ACTIONS(160),
    [anon_sym_PERCENT_EQ] = ACTIONS(160),
    [anon_sym_CARET_EQ] = ACTIONS(160),
    [anon_sym_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_LT_LT_EQ] = ACTIONS(160),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(160),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP] = ACTIONS(120),
    [anon_sym_PIPE_PIPE] = ACTIONS(120),
    [anon_sym_GT_GT] = ACTIONS(120),
    [anon_sym_GT_GT_GT] = ACTIONS(120),
    [anon_sym_LT_LT] = ACTIONS(120),
    [anon_sym_AMP] = ACTIONS(120),
    [anon_sym_CARET] = ACTIONS(120),
    [anon_sym_PIPE] = ACTIONS(120),
    [anon_sym_PLUS] = ACTIONS(120),
    [anon_sym_DASH] = ACTIONS(120),
    [anon_sym_SLASH] = ACTIONS(120),
    [anon_sym_PERCENT] = ACTIONS(120),
    [anon_sym_STAR_STAR] = ACTIONS(120),
    [anon_sym_LT] = ACTIONS(120),
    [anon_sym_LT_EQ] = ACTIONS(154),
    [anon_sym_EQ_EQ] = ACTIONS(120),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(154),
    [anon_sym_BANG_EQ] = ACTIONS(120),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(154),
    [anon_sym_GT_EQ] = ACTIONS(154),
    [anon_sym_GT] = ACTIONS(120),
    [anon_sym_QMARK_QMARK] = ACTIONS(120),
    [anon_sym_instanceof] = ACTIONS(154),
    [anon_sym_PLUS_PLUS] = ACTIONS(154),
    [anon_sym_DASH_DASH] = ACTIONS(154),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(154),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_declare] = ACTIONS(2161),
    [anon_sym_module] = ACTIONS(2163),
    [anon_sym_abstract] = ACTIONS(2165),
    [anon_sym_satisfies] = ACTIONS(154),
    [anon_sym_interface] = ACTIONS(2167),
    [anon_sym_enum] = ACTIONS(2169),
    [sym__automatic_semicolon] = ACTIONS(154),
    [sym__ternary_qmark] = ACTIONS(154),
    [sym_html_comment] = ACTIONS(5),
  },
  [698] = {
    [sym_string] = STATE(3816),
    [sym__property_name] = STATE(3816),
    [sym_computed_property_name] = STATE(3816),
    [sym_override_modifier] = STATE(2813),
    [aux_sym_object_repeat1] = STATE(4792),
    [aux_sym_object_pattern_repeat1] = STATE(4815),
    [sym_identifier] = ACTIONS(2351),
    [anon_sym_export] = ACTIONS(2351),
    [anon_sym_STAR] = ACTIONS(2321),
    [anon_sym_type] = ACTIONS(2351),
    [anon_sym_EQ] = ACTIONS(661),
    [anon_sym_as] = ACTIONS(120),
    [anon_sym_namespace] = ACTIONS(2351),
    [anon_sym_COMMA] = ACTIONS(154),
    [anon_sym_RBRACE] = ACTIONS(667),
    [anon_sym_let] = ACTIONS(2351),
    [anon_sym_BANG] = ACTIONS(120),
    [anon_sym_LPAREN] = ACTIONS(2149),
    [anon_sym_SEMI] = ACTIONS(154),
    [anon_sym_in] = ACTIONS(120),
    [anon_sym_COLON] = ACTIONS(671),
    [anon_sym_LBRACK] = ACTIONS(2328),
    [anon_sym_DOT] = ACTIONS(120),
    [anon_sym_async] = ACTIONS(2353),
    [anon_sym_EQ_GT] = ACTIONS(682),
    [anon_sym_QMARK_DOT] = ACTIONS(154),
    [anon_sym_new] = ACTIONS(2351),
    [anon_sym_PLUS_EQ] = ACTIONS(160),
    [anon_sym_DASH_EQ] = ACTIONS(160),
    [anon_sym_STAR_EQ] = ACTIONS(160),
    [anon_sym_SLASH_EQ] = ACTIONS(160),
    [anon_sym_PERCENT_EQ] = ACTIONS(160),
    [anon_sym_CARET_EQ] = ACTIONS(160),
    [anon_sym_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_LT_LT_EQ] = ACTIONS(160),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(160),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP] = ACTIONS(120),
    [anon_sym_PIPE_PIPE] = ACTIONS(120),
    [anon_sym_GT_GT] = ACTIONS(120),
    [anon_sym_GT_GT_GT] = ACTIONS(120),
    [anon_sym_LT_LT] = ACTIONS(120),
    [anon_sym_AMP] = ACTIONS(120),
    [anon_sym_CARET] = ACTIONS(120),
    [anon_sym_PIPE] = ACTIONS(120),
    [anon_sym_PLUS] = ACTIONS(120),
    [anon_sym_DASH] = ACTIONS(120),
    [anon_sym_SLASH] = ACTIONS(120),
    [anon_sym_PERCENT] = ACTIONS(120),
    [anon_sym_STAR_STAR] = ACTIONS(120),
    [anon_sym_LT] = ACTIONS(2158),
    [anon_sym_LT_EQ] = ACTIONS(154),
    [anon_sym_EQ_EQ] = ACTIONS(120),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(154),
    [anon_sym_BANG_EQ] = ACTIONS(120),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(154),
    [anon_sym_GT_EQ] = ACTIONS(154),
    [anon_sym_GT] = ACTIONS(120),
    [anon_sym_QMARK_QMARK] = ACTIONS(120),
    [anon_sym_instanceof] = ACTIONS(120),
    [anon_sym_PLUS_PLUS] = ACTIONS(154),
    [anon_sym_DASH_DASH] = ACTIONS(154),
    [anon_sym_DQUOTE] = ACTIONS(1550),
    [anon_sym_SQUOTE] = ACTIONS(1552),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(154),
    [sym_number] = ACTIONS(2337),
    [sym_private_property_identifier] = ACTIONS(2337),
    [anon_sym_static] = ACTIONS(2351),
    [anon_sym_readonly] = ACTIONS(2355),
    [anon_sym_get] = ACTIONS(2357),
    [anon_sym_set] = ACTIONS(2357),
    [anon_sym_QMARK] = ACTIONS(690),
    [anon_sym_declare] = ACTIONS(2351),
    [anon_sym_public] = ACTIONS(2351),
    [anon_sym_private] = ACTIONS(2351),
    [anon_sym_protected] = ACTIONS(2351),
    [anon_sym_override] = ACTIONS(2359),
    [anon_sym_module] = ACTIONS(2351),
    [anon_sym_any] = ACTIONS(2351),
    [anon_sym_number] = ACTIONS(2351),
    [anon_sym_boolean] = ACTIONS(2351),
    [anon_sym_string] = ACTIONS(2351),
    [anon_sym_symbol] = ACTIONS(2351),
    [anon_sym_object] = ACTIONS(2351),
    [anon_sym_satisfies] = ACTIONS(120),
    [sym__automatic_semicolon] = ACTIONS(154),
    [sym__ternary_qmark] = ACTIONS(154),
    [sym_html_comment] = ACTIONS(5),
  },
  [699] = {
    [sym_string] = STATE(3816),
    [sym__property_name] = STATE(3816),
    [sym_computed_property_name] = STATE(3816),
    [sym_override_modifier] = STATE(2813),
    [aux_sym_object_repeat1] = STATE(4810),
    [aux_sym_object_pattern_repeat1] = STATE(4815),
    [sym_identifier] = ACTIONS(2351),
    [anon_sym_export] = ACTIONS(2351),
    [anon_sym_STAR] = ACTIONS(2321),
    [anon_sym_type] = ACTIONS(2351),
    [anon_sym_EQ] = ACTIONS(661),
    [anon_sym_as] = ACTIONS(120),
    [anon_sym_namespace] = ACTIONS(2351),
    [anon_sym_COMMA] = ACTIONS(154),
    [anon_sym_RBRACE] = ACTIONS(692),
    [anon_sym_let] = ACTIONS(2351),
    [anon_sym_BANG] = ACTIONS(120),
    [anon_sym_LPAREN] = ACTIONS(2149),
    [anon_sym_SEMI] = ACTIONS(154),
    [anon_sym_in] = ACTIONS(120),
    [anon_sym_COLON] = ACTIONS(671),
    [anon_sym_LBRACK] = ACTIONS(2328),
    [anon_sym_DOT] = ACTIONS(120),
    [anon_sym_async] = ACTIONS(2353),
    [anon_sym_EQ_GT] = ACTIONS(682),
    [anon_sym_QMARK_DOT] = ACTIONS(154),
    [anon_sym_new] = ACTIONS(2351),
    [anon_sym_PLUS_EQ] = ACTIONS(160),
    [anon_sym_DASH_EQ] = ACTIONS(160),
    [anon_sym_STAR_EQ] = ACTIONS(160),
    [anon_sym_SLASH_EQ] = ACTIONS(160),
    [anon_sym_PERCENT_EQ] = ACTIONS(160),
    [anon_sym_CARET_EQ] = ACTIONS(160),
    [anon_sym_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_LT_LT_EQ] = ACTIONS(160),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(160),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP] = ACTIONS(120),
    [anon_sym_PIPE_PIPE] = ACTIONS(120),
    [anon_sym_GT_GT] = ACTIONS(120),
    [anon_sym_GT_GT_GT] = ACTIONS(120),
    [anon_sym_LT_LT] = ACTIONS(120),
    [anon_sym_AMP] = ACTIONS(120),
    [anon_sym_CARET] = ACTIONS(120),
    [anon_sym_PIPE] = ACTIONS(120),
    [anon_sym_PLUS] = ACTIONS(120),
    [anon_sym_DASH] = ACTIONS(120),
    [anon_sym_SLASH] = ACTIONS(120),
    [anon_sym_PERCENT] = ACTIONS(120),
    [anon_sym_STAR_STAR] = ACTIONS(120),
    [anon_sym_LT] = ACTIONS(2158),
    [anon_sym_LT_EQ] = ACTIONS(154),
    [anon_sym_EQ_EQ] = ACTIONS(120),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(154),
    [anon_sym_BANG_EQ] = ACTIONS(120),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(154),
    [anon_sym_GT_EQ] = ACTIONS(154),
    [anon_sym_GT] = ACTIONS(120),
    [anon_sym_QMARK_QMARK] = ACTIONS(120),
    [anon_sym_instanceof] = ACTIONS(120),
    [anon_sym_PLUS_PLUS] = ACTIONS(154),
    [anon_sym_DASH_DASH] = ACTIONS(154),
    [anon_sym_DQUOTE] = ACTIONS(1550),
    [anon_sym_SQUOTE] = ACTIONS(1552),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(154),
    [sym_number] = ACTIONS(2337),
    [sym_private_property_identifier] = ACTIONS(2337),
    [anon_sym_static] = ACTIONS(2351),
    [anon_sym_readonly] = ACTIONS(2355),
    [anon_sym_get] = ACTIONS(2357),
    [anon_sym_set] = ACTIONS(2357),
    [anon_sym_QMARK] = ACTIONS(690),
    [anon_sym_declare] = ACTIONS(2351),
    [anon_sym_public] = ACTIONS(2351),
    [anon_sym_private] = ACTIONS(2351),
    [anon_sym_protected] = ACTIONS(2351),
    [anon_sym_override] = ACTIONS(2359),
    [anon_sym_module] = ACTIONS(2351),
    [anon_sym_any] = ACTIONS(2351),
    [anon_sym_number] = ACTIONS(2351),
    [anon_sym_boolean] = ACTIONS(2351),
    [anon_sym_string] = ACTIONS(2351),
    [anon_sym_symbol] = ACTIONS(2351),
    [anon_sym_object] = ACTIONS(2351),
    [anon_sym_satisfies] = ACTIONS(120),
    [sym__automatic_semicolon] = ACTIONS(154),
    [sym__ternary_qmark] = ACTIONS(154),
    [sym_html_comment] = ACTIONS(5),
  },
  [700] = {
    [sym_string] = STATE(3816),
    [sym__property_name] = STATE(3816),
    [sym_computed_property_name] = STATE(3816),
    [sym_override_modifier] = STATE(2813),
    [aux_sym_object_repeat1] = STATE(4792),
    [aux_sym_object_pattern_repeat1] = STATE(4815),
    [sym_identifier] = ACTIONS(2351),
    [anon_sym_export] = ACTIONS(2351),
    [anon_sym_STAR] = ACTIONS(2321),
    [anon_sym_type] = ACTIONS(2351),
    [anon_sym_EQ] = ACTIONS(661),
    [anon_sym_as] = ACTIONS(120),
    [anon_sym_namespace] = ACTIONS(2351),
    [anon_sym_COMMA] = ACTIONS(154),
    [anon_sym_RBRACE] = ACTIONS(694),
    [anon_sym_let] = ACTIONS(2351),
    [anon_sym_BANG] = ACTIONS(120),
    [anon_sym_LPAREN] = ACTIONS(2149),
    [anon_sym_SEMI] = ACTIONS(154),
    [anon_sym_in] = ACTIONS(120),
    [anon_sym_COLON] = ACTIONS(671),
    [anon_sym_LBRACK] = ACTIONS(2328),
    [anon_sym_DOT] = ACTIONS(120),
    [anon_sym_async] = ACTIONS(2353),
    [anon_sym_EQ_GT] = ACTIONS(682),
    [anon_sym_QMARK_DOT] = ACTIONS(154),
    [anon_sym_new] = ACTIONS(2351),
    [anon_sym_PLUS_EQ] = ACTIONS(160),
    [anon_sym_DASH_EQ] = ACTIONS(160),
    [anon_sym_STAR_EQ] = ACTIONS(160),
    [anon_sym_SLASH_EQ] = ACTIONS(160),
    [anon_sym_PERCENT_EQ] = ACTIONS(160),
    [anon_sym_CARET_EQ] = ACTIONS(160),
    [anon_sym_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_LT_LT_EQ] = ACTIONS(160),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(160),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP] = ACTIONS(120),
    [anon_sym_PIPE_PIPE] = ACTIONS(120),
    [anon_sym_GT_GT] = ACTIONS(120),
    [anon_sym_GT_GT_GT] = ACTIONS(120),
    [anon_sym_LT_LT] = ACTIONS(120),
    [anon_sym_AMP] = ACTIONS(120),
    [anon_sym_CARET] = ACTIONS(120),
    [anon_sym_PIPE] = ACTIONS(120),
    [anon_sym_PLUS] = ACTIONS(120),
    [anon_sym_DASH] = ACTIONS(120),
    [anon_sym_SLASH] = ACTIONS(120),
    [anon_sym_PERCENT] = ACTIONS(120),
    [anon_sym_STAR_STAR] = ACTIONS(120),
    [anon_sym_LT] = ACTIONS(2158),
    [anon_sym_LT_EQ] = ACTIONS(154),
    [anon_sym_EQ_EQ] = ACTIONS(120),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(154),
    [anon_sym_BANG_EQ] = ACTIONS(120),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(154),
    [anon_sym_GT_EQ] = ACTIONS(154),
    [anon_sym_GT] = ACTIONS(120),
    [anon_sym_QMARK_QMARK] = ACTIONS(120),
    [anon_sym_instanceof] = ACTIONS(120),
    [anon_sym_PLUS_PLUS] = ACTIONS(154),
    [anon_sym_DASH_DASH] = ACTIONS(154),
    [anon_sym_DQUOTE] = ACTIONS(1550),
    [anon_sym_SQUOTE] = ACTIONS(1552),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(154),
    [sym_number] = ACTIONS(2337),
    [sym_private_property_identifier] = ACTIONS(2337),
    [anon_sym_static] = ACTIONS(2351),
    [anon_sym_readonly] = ACTIONS(2355),
    [anon_sym_get] = ACTIONS(2357),
    [anon_sym_set] = ACTIONS(2357),
    [anon_sym_QMARK] = ACTIONS(690),
    [anon_sym_declare] = ACTIONS(2351),
    [anon_sym_public] = ACTIONS(2351),
    [anon_sym_private] = ACTIONS(2351),
    [anon_sym_protected] = ACTIONS(2351),
    [anon_sym_override] = ACTIONS(2359),
    [anon_sym_module] = ACTIONS(2351),
    [anon_sym_any] = ACTIONS(2351),
    [anon_sym_number] = ACTIONS(2351),
    [anon_sym_boolean] = ACTIONS(2351),
    [anon_sym_string] = ACTIONS(2351),
    [anon_sym_symbol] = ACTIONS(2351),
    [anon_sym_object] = ACTIONS(2351),
    [anon_sym_satisfies] = ACTIONS(120),
    [sym__automatic_semicolon] = ACTIONS(154),
    [sym__ternary_qmark] = ACTIONS(154),
    [sym_html_comment] = ACTIONS(5),
  },
  [701] = {
    [sym_string] = STATE(3816),
    [sym__property_name] = STATE(3816),
    [sym_computed_property_name] = STATE(3816),
    [aux_sym_object_repeat1] = STATE(4792),
    [aux_sym_object_pattern_repeat1] = STATE(4815),
    [sym_identifier] = ACTIONS(2351),
    [anon_sym_export] = ACTIONS(2351),
    [anon_sym_STAR] = ACTIONS(120),
    [anon_sym_type] = ACTIONS(2351),
    [anon_sym_EQ] = ACTIONS(661),
    [anon_sym_as] = ACTIONS(120),
    [anon_sym_namespace] = ACTIONS(2351),
    [anon_sym_COMMA] = ACTIONS(154),
    [anon_sym_RBRACE] = ACTIONS(667),
    [anon_sym_let] = ACTIONS(2351),
    [anon_sym_BANG] = ACTIONS(120),
    [anon_sym_LPAREN] = ACTIONS(2149),
    [anon_sym_SEMI] = ACTIONS(154),
    [anon_sym_in] = ACTIONS(120),
    [anon_sym_COLON] = ACTIONS(671),
    [anon_sym_LBRACK] = ACTIONS(2328),
    [anon_sym_DOT] = ACTIONS(120),
    [anon_sym_async] = ACTIONS(2351),
    [anon_sym_EQ_GT] = ACTIONS(682),
    [anon_sym_QMARK_DOT] = ACTIONS(154),
    [anon_sym_new] = ACTIONS(2351),
    [anon_sym_PLUS_EQ] = ACTIONS(160),
    [anon_sym_DASH_EQ] = ACTIONS(160),
    [anon_sym_STAR_EQ] = ACTIONS(160),
    [anon_sym_SLASH_EQ] = ACTIONS(160),
    [anon_sym_PERCENT_EQ] = ACTIONS(160),
    [anon_sym_CARET_EQ] = ACTIONS(160),
    [anon_sym_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_LT_LT_EQ] = ACTIONS(160),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(160),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP] = ACTIONS(120),
    [anon_sym_PIPE_PIPE] = ACTIONS(120),
    [anon_sym_GT_GT] = ACTIONS(120),
    [anon_sym_GT_GT_GT] = ACTIONS(120),
    [anon_sym_LT_LT] = ACTIONS(120),
    [anon_sym_AMP] = ACTIONS(120),
    [anon_sym_CARET] = ACTIONS(120),
    [anon_sym_PIPE] = ACTIONS(120),
    [anon_sym_PLUS] = ACTIONS(120),
    [anon_sym_DASH] = ACTIONS(120),
    [anon_sym_SLASH] = ACTIONS(120),
    [anon_sym_PERCENT] = ACTIONS(120),
    [anon_sym_STAR_STAR] = ACTIONS(120),
    [anon_sym_LT] = ACTIONS(2158),
    [anon_sym_LT_EQ] = ACTIONS(154),
    [anon_sym_EQ_EQ] = ACTIONS(120),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(154),
    [anon_sym_BANG_EQ] = ACTIONS(120),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(154),
    [anon_sym_GT_EQ] = ACTIONS(154),
    [anon_sym_GT] = ACTIONS(120),
    [anon_sym_QMARK_QMARK] = ACTIONS(120),
    [anon_sym_instanceof] = ACTIONS(120),
    [anon_sym_PLUS_PLUS] = ACTIONS(154),
    [anon_sym_DASH_DASH] = ACTIONS(154),
    [anon_sym_DQUOTE] = ACTIONS(1550),
    [anon_sym_SQUOTE] = ACTIONS(1552),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(154),
    [sym_number] = ACTIONS(2337),
    [sym_private_property_identifier] = ACTIONS(2337),
    [anon_sym_static] = ACTIONS(2351),
    [anon_sym_readonly] = ACTIONS(2351),
    [anon_sym_get] = ACTIONS(2351),
    [anon_sym_set] = ACTIONS(2351),
    [anon_sym_QMARK] = ACTIONS(690),
    [anon_sym_declare] = ACTIONS(2351),
    [anon_sym_public] = ACTIONS(2351),
    [anon_sym_private] = ACTIONS(2351),
    [anon_sym_protected] = ACTIONS(2351),
    [anon_sym_override] = ACTIONS(2351),
    [anon_sym_module] = ACTIONS(2351),
    [anon_sym_any] = ACTIONS(2351),
    [anon_sym_number] = ACTIONS(2351),
    [anon_sym_boolean] = ACTIONS(2351),
    [anon_sym_string] = ACTIONS(2351),
    [anon_sym_symbol] = ACTIONS(2351),
    [anon_sym_object] = ACTIONS(2351),
    [anon_sym_satisfies] = ACTIONS(120),
    [sym__automatic_semicolon] = ACTIONS(154),
    [sym__ternary_qmark] = ACTIONS(154),
    [sym_html_comment] = ACTIONS(5),
  },
  [702] = {
    [sym_string] = STATE(3816),
    [sym__property_name] = STATE(3816),
    [sym_computed_property_name] = STATE(3816),
    [aux_sym_object_repeat1] = STATE(4810),
    [aux_sym_object_pattern_repeat1] = STATE(4815),
    [sym_identifier] = ACTIONS(2351),
    [anon_sym_export] = ACTIONS(2351),
    [anon_sym_STAR] = ACTIONS(120),
    [anon_sym_type] = ACTIONS(2351),
    [anon_sym_EQ] = ACTIONS(661),
    [anon_sym_as] = ACTIONS(120),
    [anon_sym_namespace] = ACTIONS(2351),
    [anon_sym_COMMA] = ACTIONS(154),
    [anon_sym_RBRACE] = ACTIONS(692),
    [anon_sym_let] = ACTIONS(2351),
    [anon_sym_BANG] = ACTIONS(120),
    [anon_sym_LPAREN] = ACTIONS(2149),
    [anon_sym_SEMI] = ACTIONS(154),
    [anon_sym_in] = ACTIONS(120),
    [anon_sym_COLON] = ACTIONS(671),
    [anon_sym_LBRACK] = ACTIONS(2328),
    [anon_sym_DOT] = ACTIONS(120),
    [anon_sym_async] = ACTIONS(2351),
    [anon_sym_EQ_GT] = ACTIONS(682),
    [anon_sym_QMARK_DOT] = ACTIONS(154),
    [anon_sym_new] = ACTIONS(2351),
    [anon_sym_PLUS_EQ] = ACTIONS(160),
    [anon_sym_DASH_EQ] = ACTIONS(160),
    [anon_sym_STAR_EQ] = ACTIONS(160),
    [anon_sym_SLASH_EQ] = ACTIONS(160),
    [anon_sym_PERCENT_EQ] = ACTIONS(160),
    [anon_sym_CARET_EQ] = ACTIONS(160),
    [anon_sym_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_LT_LT_EQ] = ACTIONS(160),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(160),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP] = ACTIONS(120),
    [anon_sym_PIPE_PIPE] = ACTIONS(120),
    [anon_sym_GT_GT] = ACTIONS(120),
    [anon_sym_GT_GT_GT] = ACTIONS(120),
    [anon_sym_LT_LT] = ACTIONS(120),
    [anon_sym_AMP] = ACTIONS(120),
    [anon_sym_CARET] = ACTIONS(120),
    [anon_sym_PIPE] = ACTIONS(120),
    [anon_sym_PLUS] = ACTIONS(120),
    [anon_sym_DASH] = ACTIONS(120),
    [anon_sym_SLASH] = ACTIONS(120),
    [anon_sym_PERCENT] = ACTIONS(120),
    [anon_sym_STAR_STAR] = ACTIONS(120),
    [anon_sym_LT] = ACTIONS(2158),
    [anon_sym_LT_EQ] = ACTIONS(154),
    [anon_sym_EQ_EQ] = ACTIONS(120),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(154),
    [anon_sym_BANG_EQ] = ACTIONS(120),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(154),
    [anon_sym_GT_EQ] = ACTIONS(154),
    [anon_sym_GT] = ACTIONS(120),
    [anon_sym_QMARK_QMARK] = ACTIONS(120),
    [anon_sym_instanceof] = ACTIONS(120),
    [anon_sym_PLUS_PLUS] = ACTIONS(154),
    [anon_sym_DASH_DASH] = ACTIONS(154),
    [anon_sym_DQUOTE] = ACTIONS(1550),
    [anon_sym_SQUOTE] = ACTIONS(1552),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(154),
    [sym_number] = ACTIONS(2337),
    [sym_private_property_identifier] = ACTIONS(2337),
    [anon_sym_static] = ACTIONS(2351),
    [anon_sym_readonly] = ACTIONS(2351),
    [anon_sym_get] = ACTIONS(2351),
    [anon_sym_set] = ACTIONS(2351),
    [anon_sym_QMARK] = ACTIONS(690),
    [anon_sym_declare] = ACTIONS(2351),
    [anon_sym_public] = ACTIONS(2351),
    [anon_sym_private] = ACTIONS(2351),
    [anon_sym_protected] = ACTIONS(2351),
    [anon_sym_override] = ACTIONS(2351),
    [anon_sym_module] = ACTIONS(2351),
    [anon_sym_any] = ACTIONS(2351),
    [anon_sym_number] = ACTIONS(2351),
    [anon_sym_boolean] = ACTIONS(2351),
    [anon_sym_string] = ACTIONS(2351),
    [anon_sym_symbol] = ACTIONS(2351),
    [anon_sym_object] = ACTIONS(2351),
    [anon_sym_satisfies] = ACTIONS(120),
    [sym__automatic_semicolon] = ACTIONS(154),
    [sym__ternary_qmark] = ACTIONS(154),
    [sym_html_comment] = ACTIONS(5),
  },
  [703] = {
    [sym_string] = STATE(3816),
    [sym__property_name] = STATE(3816),
    [sym_computed_property_name] = STATE(3816),
    [aux_sym_object_repeat1] = STATE(4792),
    [aux_sym_object_pattern_repeat1] = STATE(4815),
    [sym_identifier] = ACTIONS(2351),
    [anon_sym_export] = ACTIONS(2351),
    [anon_sym_STAR] = ACTIONS(2321),
    [anon_sym_type] = ACTIONS(2351),
    [anon_sym_EQ] = ACTIONS(661),
    [anon_sym_as] = ACTIONS(120),
    [anon_sym_namespace] = ACTIONS(2351),
    [anon_sym_COMMA] = ACTIONS(154),
    [anon_sym_RBRACE] = ACTIONS(667),
    [anon_sym_let] = ACTIONS(2351),
    [anon_sym_BANG] = ACTIONS(120),
    [anon_sym_LPAREN] = ACTIONS(2149),
    [anon_sym_SEMI] = ACTIONS(154),
    [anon_sym_in] = ACTIONS(120),
    [anon_sym_COLON] = ACTIONS(671),
    [anon_sym_LBRACK] = ACTIONS(2328),
    [anon_sym_DOT] = ACTIONS(120),
    [anon_sym_async] = ACTIONS(2353),
    [anon_sym_EQ_GT] = ACTIONS(682),
    [anon_sym_QMARK_DOT] = ACTIONS(154),
    [anon_sym_new] = ACTIONS(2351),
    [anon_sym_PLUS_EQ] = ACTIONS(160),
    [anon_sym_DASH_EQ] = ACTIONS(160),
    [anon_sym_STAR_EQ] = ACTIONS(160),
    [anon_sym_SLASH_EQ] = ACTIONS(160),
    [anon_sym_PERCENT_EQ] = ACTIONS(160),
    [anon_sym_CARET_EQ] = ACTIONS(160),
    [anon_sym_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_LT_LT_EQ] = ACTIONS(160),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(160),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP] = ACTIONS(120),
    [anon_sym_PIPE_PIPE] = ACTIONS(120),
    [anon_sym_GT_GT] = ACTIONS(120),
    [anon_sym_GT_GT_GT] = ACTIONS(120),
    [anon_sym_LT_LT] = ACTIONS(120),
    [anon_sym_AMP] = ACTIONS(120),
    [anon_sym_CARET] = ACTIONS(120),
    [anon_sym_PIPE] = ACTIONS(120),
    [anon_sym_PLUS] = ACTIONS(120),
    [anon_sym_DASH] = ACTIONS(120),
    [anon_sym_SLASH] = ACTIONS(120),
    [anon_sym_PERCENT] = ACTIONS(120),
    [anon_sym_STAR_STAR] = ACTIONS(120),
    [anon_sym_LT] = ACTIONS(2158),
    [anon_sym_LT_EQ] = ACTIONS(154),
    [anon_sym_EQ_EQ] = ACTIONS(120),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(154),
    [anon_sym_BANG_EQ] = ACTIONS(120),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(154),
    [anon_sym_GT_EQ] = ACTIONS(154),
    [anon_sym_GT] = ACTIONS(120),
    [anon_sym_QMARK_QMARK] = ACTIONS(120),
    [anon_sym_instanceof] = ACTIONS(120),
    [anon_sym_PLUS_PLUS] = ACTIONS(154),
    [anon_sym_DASH_DASH] = ACTIONS(154),
    [anon_sym_DQUOTE] = ACTIONS(1550),
    [anon_sym_SQUOTE] = ACTIONS(1552),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(154),
    [sym_number] = ACTIONS(2337),
    [sym_private_property_identifier] = ACTIONS(2337),
    [anon_sym_static] = ACTIONS(2351),
    [anon_sym_readonly] = ACTIONS(2351),
    [anon_sym_get] = ACTIONS(2357),
    [anon_sym_set] = ACTIONS(2357),
    [anon_sym_QMARK] = ACTIONS(690),
    [anon_sym_declare] = ACTIONS(2351),
    [anon_sym_public] = ACTIONS(2351),
    [anon_sym_private] = ACTIONS(2351),
    [anon_sym_protected] = ACTIONS(2351),
    [anon_sym_override] = ACTIONS(2351),
    [anon_sym_module] = ACTIONS(2351),
    [anon_sym_any] = ACTIONS(2351),
    [anon_sym_number] = ACTIONS(2351),
    [anon_sym_boolean] = ACTIONS(2351),
    [anon_sym_string] = ACTIONS(2351),
    [anon_sym_symbol] = ACTIONS(2351),
    [anon_sym_object] = ACTIONS(2351),
    [anon_sym_satisfies] = ACTIONS(120),
    [sym__automatic_semicolon] = ACTIONS(154),
    [sym__ternary_qmark] = ACTIONS(154),
    [sym_html_comment] = ACTIONS(5),
  },
  [704] = {
    [sym_string] = STATE(3816),
    [sym__property_name] = STATE(3816),
    [sym_computed_property_name] = STATE(3816),
    [aux_sym_object_repeat1] = STATE(4810),
    [aux_sym_object_pattern_repeat1] = STATE(4815),
    [sym_identifier] = ACTIONS(2351),
    [anon_sym_export] = ACTIONS(2351),
    [anon_sym_STAR] = ACTIONS(2321),
    [anon_sym_type] = ACTIONS(2351),
    [anon_sym_EQ] = ACTIONS(661),
    [anon_sym_as] = ACTIONS(120),
    [anon_sym_namespace] = ACTIONS(2351),
    [anon_sym_COMMA] = ACTIONS(154),
    [anon_sym_RBRACE] = ACTIONS(692),
    [anon_sym_let] = ACTIONS(2351),
    [anon_sym_BANG] = ACTIONS(120),
    [anon_sym_LPAREN] = ACTIONS(2149),
    [anon_sym_SEMI] = ACTIONS(154),
    [anon_sym_in] = ACTIONS(120),
    [anon_sym_COLON] = ACTIONS(671),
    [anon_sym_LBRACK] = ACTIONS(2328),
    [anon_sym_DOT] = ACTIONS(120),
    [anon_sym_async] = ACTIONS(2353),
    [anon_sym_EQ_GT] = ACTIONS(682),
    [anon_sym_QMARK_DOT] = ACTIONS(154),
    [anon_sym_new] = ACTIONS(2351),
    [anon_sym_PLUS_EQ] = ACTIONS(160),
    [anon_sym_DASH_EQ] = ACTIONS(160),
    [anon_sym_STAR_EQ] = ACTIONS(160),
    [anon_sym_SLASH_EQ] = ACTIONS(160),
    [anon_sym_PERCENT_EQ] = ACTIONS(160),
    [anon_sym_CARET_EQ] = ACTIONS(160),
    [anon_sym_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_LT_LT_EQ] = ACTIONS(160),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(160),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP] = ACTIONS(120),
    [anon_sym_PIPE_PIPE] = ACTIONS(120),
    [anon_sym_GT_GT] = ACTIONS(120),
    [anon_sym_GT_GT_GT] = ACTIONS(120),
    [anon_sym_LT_LT] = ACTIONS(120),
    [anon_sym_AMP] = ACTIONS(120),
    [anon_sym_CARET] = ACTIONS(120),
    [anon_sym_PIPE] = ACTIONS(120),
    [anon_sym_PLUS] = ACTIONS(120),
    [anon_sym_DASH] = ACTIONS(120),
    [anon_sym_SLASH] = ACTIONS(120),
    [anon_sym_PERCENT] = ACTIONS(120),
    [anon_sym_STAR_STAR] = ACTIONS(120),
    [anon_sym_LT] = ACTIONS(2158),
    [anon_sym_LT_EQ] = ACTIONS(154),
    [anon_sym_EQ_EQ] = ACTIONS(120),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(154),
    [anon_sym_BANG_EQ] = ACTIONS(120),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(154),
    [anon_sym_GT_EQ] = ACTIONS(154),
    [anon_sym_GT] = ACTIONS(120),
    [anon_sym_QMARK_QMARK] = ACTIONS(120),
    [anon_sym_instanceof] = ACTIONS(120),
    [anon_sym_PLUS_PLUS] = ACTIONS(154),
    [anon_sym_DASH_DASH] = ACTIONS(154),
    [anon_sym_DQUOTE] = ACTIONS(1550),
    [anon_sym_SQUOTE] = ACTIONS(1552),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(154),
    [sym_number] = ACTIONS(2337),
    [sym_private_property_identifier] = ACTIONS(2337),
    [anon_sym_static] = ACTIONS(2351),
    [anon_sym_readonly] = ACTIONS(2351),
    [anon_sym_get] = ACTIONS(2357),
    [anon_sym_set] = ACTIONS(2357),
    [anon_sym_QMARK] = ACTIONS(690),
    [anon_sym_declare] = ACTIONS(2351),
    [anon_sym_public] = ACTIONS(2351),
    [anon_sym_private] = ACTIONS(2351),
    [anon_sym_protected] = ACTIONS(2351),
    [anon_sym_override] = ACTIONS(2351),
    [anon_sym_module] = ACTIONS(2351),
    [anon_sym_any] = ACTIONS(2351),
    [anon_sym_number] = ACTIONS(2351),
    [anon_sym_boolean] = ACTIONS(2351),
    [anon_sym_string] = ACTIONS(2351),
    [anon_sym_symbol] = ACTIONS(2351),
    [anon_sym_object] = ACTIONS(2351),
    [anon_sym_satisfies] = ACTIONS(120),
    [sym__automatic_semicolon] = ACTIONS(154),
    [sym__ternary_qmark] = ACTIONS(154),
    [sym_html_comment] = ACTIONS(5),
  },
  [705] = {
    [sym_string] = STATE(3816),
    [sym__property_name] = STATE(3816),
    [sym_computed_property_name] = STATE(3816),
    [aux_sym_object_repeat1] = STATE(4792),
    [aux_sym_object_pattern_repeat1] = STATE(4815),
    [sym_identifier] = ACTIONS(2351),
    [anon_sym_export] = ACTIONS(2351),
    [anon_sym_STAR] = ACTIONS(2321),
    [anon_sym_type] = ACTIONS(2351),
    [anon_sym_EQ] = ACTIONS(661),
    [anon_sym_as] = ACTIONS(120),
    [anon_sym_namespace] = ACTIONS(2351),
    [anon_sym_COMMA] = ACTIONS(154),
    [anon_sym_RBRACE] = ACTIONS(694),
    [anon_sym_let] = ACTIONS(2351),
    [anon_sym_BANG] = ACTIONS(120),
    [anon_sym_LPAREN] = ACTIONS(2149),
    [anon_sym_SEMI] = ACTIONS(154),
    [anon_sym_in] = ACTIONS(120),
    [anon_sym_COLON] = ACTIONS(671),
    [anon_sym_LBRACK] = ACTIONS(2328),
    [anon_sym_DOT] = ACTIONS(120),
    [anon_sym_async] = ACTIONS(2353),
    [anon_sym_EQ_GT] = ACTIONS(682),
    [anon_sym_QMARK_DOT] = ACTIONS(154),
    [anon_sym_new] = ACTIONS(2351),
    [anon_sym_PLUS_EQ] = ACTIONS(160),
    [anon_sym_DASH_EQ] = ACTIONS(160),
    [anon_sym_STAR_EQ] = ACTIONS(160),
    [anon_sym_SLASH_EQ] = ACTIONS(160),
    [anon_sym_PERCENT_EQ] = ACTIONS(160),
    [anon_sym_CARET_EQ] = ACTIONS(160),
    [anon_sym_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_LT_LT_EQ] = ACTIONS(160),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(160),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP] = ACTIONS(120),
    [anon_sym_PIPE_PIPE] = ACTIONS(120),
    [anon_sym_GT_GT] = ACTIONS(120),
    [anon_sym_GT_GT_GT] = ACTIONS(120),
    [anon_sym_LT_LT] = ACTIONS(120),
    [anon_sym_AMP] = ACTIONS(120),
    [anon_sym_CARET] = ACTIONS(120),
    [anon_sym_PIPE] = ACTIONS(120),
    [anon_sym_PLUS] = ACTIONS(120),
    [anon_sym_DASH] = ACTIONS(120),
    [anon_sym_SLASH] = ACTIONS(120),
    [anon_sym_PERCENT] = ACTIONS(120),
    [anon_sym_STAR_STAR] = ACTIONS(120),
    [anon_sym_LT] = ACTIONS(2158),
    [anon_sym_LT_EQ] = ACTIONS(154),
    [anon_sym_EQ_EQ] = ACTIONS(120),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(154),
    [anon_sym_BANG_EQ] = ACTIONS(120),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(154),
    [anon_sym_GT_EQ] = ACTIONS(154),
    [anon_sym_GT] = ACTIONS(120),
    [anon_sym_QMARK_QMARK] = ACTIONS(120),
    [anon_sym_instanceof] = ACTIONS(120),
    [anon_sym_PLUS_PLUS] = ACTIONS(154),
    [anon_sym_DASH_DASH] = ACTIONS(154),
    [anon_sym_DQUOTE] = ACTIONS(1550),
    [anon_sym_SQUOTE] = ACTIONS(1552),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(154),
    [sym_number] = ACTIONS(2337),
    [sym_private_property_identifier] = ACTIONS(2337),
    [anon_sym_static] = ACTIONS(2351),
    [anon_sym_readonly] = ACTIONS(2351),
    [anon_sym_get] = ACTIONS(2357),
    [anon_sym_set] = ACTIONS(2357),
    [anon_sym_QMARK] = ACTIONS(690),
    [anon_sym_declare] = ACTIONS(2351),
    [anon_sym_public] = ACTIONS(2351),
    [anon_sym_private] = ACTIONS(2351),
    [anon_sym_protected] = ACTIONS(2351),
    [anon_sym_override] = ACTIONS(2351),
    [anon_sym_module] = ACTIONS(2351),
    [anon_sym_any] = ACTIONS(2351),
    [anon_sym_number] = ACTIONS(2351),
    [anon_sym_boolean] = ACTIONS(2351),
    [anon_sym_string] = ACTIONS(2351),
    [anon_sym_symbol] = ACTIONS(2351),
    [anon_sym_object] = ACTIONS(2351),
    [anon_sym_satisfies] = ACTIONS(120),
    [sym__automatic_semicolon] = ACTIONS(154),
    [sym__ternary_qmark] = ACTIONS(154),
    [sym_html_comment] = ACTIONS(5),
  },
  [706] = {
    [sym_string] = STATE(3816),
    [sym__property_name] = STATE(3816),
    [sym_computed_property_name] = STATE(3816),
    [aux_sym_object_repeat1] = STATE(4792),
    [aux_sym_object_pattern_repeat1] = STATE(4815),
    [sym_identifier] = ACTIONS(2351),
    [anon_sym_export] = ACTIONS(2351),
    [anon_sym_STAR] = ACTIONS(120),
    [anon_sym_type] = ACTIONS(2351),
    [anon_sym_EQ] = ACTIONS(661),
    [anon_sym_as] = ACTIONS(120),
    [anon_sym_namespace] = ACTIONS(2351),
    [anon_sym_COMMA] = ACTIONS(154),
    [anon_sym_RBRACE] = ACTIONS(694),
    [anon_sym_let] = ACTIONS(2351),
    [anon_sym_BANG] = ACTIONS(120),
    [anon_sym_LPAREN] = ACTIONS(2149),
    [anon_sym_SEMI] = ACTIONS(154),
    [anon_sym_in] = ACTIONS(120),
    [anon_sym_COLON] = ACTIONS(671),
    [anon_sym_LBRACK] = ACTIONS(2328),
    [anon_sym_DOT] = ACTIONS(120),
    [anon_sym_async] = ACTIONS(2351),
    [anon_sym_EQ_GT] = ACTIONS(682),
    [anon_sym_QMARK_DOT] = ACTIONS(154),
    [anon_sym_new] = ACTIONS(2351),
    [anon_sym_PLUS_EQ] = ACTIONS(160),
    [anon_sym_DASH_EQ] = ACTIONS(160),
    [anon_sym_STAR_EQ] = ACTIONS(160),
    [anon_sym_SLASH_EQ] = ACTIONS(160),
    [anon_sym_PERCENT_EQ] = ACTIONS(160),
    [anon_sym_CARET_EQ] = ACTIONS(160),
    [anon_sym_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_LT_LT_EQ] = ACTIONS(160),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(160),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP] = ACTIONS(120),
    [anon_sym_PIPE_PIPE] = ACTIONS(120),
    [anon_sym_GT_GT] = ACTIONS(120),
    [anon_sym_GT_GT_GT] = ACTIONS(120),
    [anon_sym_LT_LT] = ACTIONS(120),
    [anon_sym_AMP] = ACTIONS(120),
    [anon_sym_CARET] = ACTIONS(120),
    [anon_sym_PIPE] = ACTIONS(120),
    [anon_sym_PLUS] = ACTIONS(120),
    [anon_sym_DASH] = ACTIONS(120),
    [anon_sym_SLASH] = ACTIONS(120),
    [anon_sym_PERCENT] = ACTIONS(120),
    [anon_sym_STAR_STAR] = ACTIONS(120),
    [anon_sym_LT] = ACTIONS(2158),
    [anon_sym_LT_EQ] = ACTIONS(154),
    [anon_sym_EQ_EQ] = ACTIONS(120),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(154),
    [anon_sym_BANG_EQ] = ACTIONS(120),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(154),
    [anon_sym_GT_EQ] = ACTIONS(154),
    [anon_sym_GT] = ACTIONS(120),
    [anon_sym_QMARK_QMARK] = ACTIONS(120),
    [anon_sym_instanceof] = ACTIONS(120),
    [anon_sym_PLUS_PLUS] = ACTIONS(154),
    [anon_sym_DASH_DASH] = ACTIONS(154),
    [anon_sym_DQUOTE] = ACTIONS(1550),
    [anon_sym_SQUOTE] = ACTIONS(1552),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(154),
    [sym_number] = ACTIONS(2337),
    [sym_private_property_identifier] = ACTIONS(2337),
    [anon_sym_static] = ACTIONS(2351),
    [anon_sym_readonly] = ACTIONS(2351),
    [anon_sym_get] = ACTIONS(2351),
    [anon_sym_set] = ACTIONS(2351),
    [anon_sym_QMARK] = ACTIONS(690),
    [anon_sym_declare] = ACTIONS(2351),
    [anon_sym_public] = ACTIONS(2351),
    [anon_sym_private] = ACTIONS(2351),
    [anon_sym_protected] = ACTIONS(2351),
    [anon_sym_override] = ACTIONS(2351),
    [anon_sym_module] = ACTIONS(2351),
    [anon_sym_any] = ACTIONS(2351),
    [anon_sym_number] = ACTIONS(2351),
    [anon_sym_boolean] = ACTIONS(2351),
    [anon_sym_string] = ACTIONS(2351),
    [anon_sym_symbol] = ACTIONS(2351),
    [anon_sym_object] = ACTIONS(2351),
    [anon_sym_satisfies] = ACTIONS(120),
    [sym__automatic_semicolon] = ACTIONS(154),
    [sym__ternary_qmark] = ACTIONS(154),
    [sym_html_comment] = ACTIONS(5),
  },
  [707] = {
    [sym_declaration] = STATE(867),
    [sym_variable_declaration] = STATE(831),
    [sym_lexical_declaration] = STATE(831),
    [sym_class_declaration] = STATE(831),
    [sym_function_declaration] = STATE(831),
    [sym_generator_function_declaration] = STATE(831),
    [sym_decorator] = STATE(1344),
    [sym_function_signature] = STATE(831),
    [sym_ambient_declaration] = STATE(831),
    [sym_abstract_class_declaration] = STATE(831),
    [sym_module] = STATE(831),
    [sym_internal_module] = STATE(824),
    [sym_import_alias] = STATE(831),
    [sym_interface_declaration] = STATE(831),
    [sym_enum_declaration] = STATE(831),
    [sym_type_alias_declaration] = STATE(831),
    [aux_sym_export_statement_repeat1] = STATE(4301),
    [anon_sym_STAR] = ACTIONS(120),
    [anon_sym_type] = ACTIONS(2341),
    [anon_sym_EQ] = ACTIONS(858),
    [anon_sym_as] = ACTIONS(120),
    [anon_sym_namespace] = ACTIONS(2137),
    [anon_sym_COMMA] = ACTIONS(154),
    [anon_sym_import] = ACTIONS(2141),
    [anon_sym_var] = ACTIONS(2143),
    [anon_sym_let] = ACTIONS(2145),
    [anon_sym_const] = ACTIONS(2147),
    [anon_sym_BANG] = ACTIONS(120),
    [anon_sym_LPAREN] = ACTIONS(154),
    [anon_sym_SEMI] = ACTIONS(154),
    [anon_sym_in] = ACTIONS(120),
    [anon_sym_COLON] = ACTIONS(860),
    [anon_sym_LBRACK] = ACTIONS(154),
    [anon_sym_DOT] = ACTIONS(154),
    [anon_sym_class] = ACTIONS(2152),
    [anon_sym_async] = ACTIONS(2154),
    [anon_sym_function] = ACTIONS(2156),
    [anon_sym_EQ_GT] = ACTIONS(682),
    [anon_sym_QMARK_DOT] = ACTIONS(154),
    [anon_sym_PLUS_EQ] = ACTIONS(160),
    [anon_sym_DASH_EQ] = ACTIONS(160),
    [anon_sym_STAR_EQ] = ACTIONS(160),
    [anon_sym_SLASH_EQ] = ACTIONS(160),
    [anon_sym_PERCENT_EQ] = ACTIONS(160),
    [anon_sym_CARET_EQ] = ACTIONS(160),
    [anon_sym_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_LT_LT_EQ] = ACTIONS(160),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(160),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP] = ACTIONS(120),
    [anon_sym_PIPE_PIPE] = ACTIONS(120),
    [anon_sym_GT_GT] = ACTIONS(120),
    [anon_sym_GT_GT_GT] = ACTIONS(120),
    [anon_sym_LT_LT] = ACTIONS(120),
    [anon_sym_AMP] = ACTIONS(120),
    [anon_sym_CARET] = ACTIONS(120),
    [anon_sym_PIPE] = ACTIONS(120),
    [anon_sym_PLUS] = ACTIONS(120),
    [anon_sym_DASH] = ACTIONS(120),
    [anon_sym_SLASH] = ACTIONS(120),
    [anon_sym_PERCENT] = ACTIONS(120),
    [anon_sym_STAR_STAR] = ACTIONS(120),
    [anon_sym_LT] = ACTIONS(120),
    [anon_sym_LT_EQ] = ACTIONS(154),
    [anon_sym_EQ_EQ] = ACTIONS(120),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(154),
    [anon_sym_BANG_EQ] = ACTIONS(120),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(154),
    [anon_sym_GT_EQ] = ACTIONS(154),
    [anon_sym_GT] = ACTIONS(120),
    [anon_sym_QMARK_QMARK] = ACTIONS(120),
    [anon_sym_instanceof] = ACTIONS(154),
    [anon_sym_PLUS_PLUS] = ACTIONS(154),
    [anon_sym_DASH_DASH] = ACTIONS(154),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(154),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_declare] = ACTIONS(2161),
    [anon_sym_module] = ACTIONS(2343),
    [anon_sym_abstract] = ACTIONS(2165),
    [anon_sym_satisfies] = ACTIONS(154),
    [anon_sym_global] = ACTIONS(2345),
    [anon_sym_interface] = ACTIONS(2167),
    [anon_sym_enum] = ACTIONS(2169),
    [sym__automatic_semicolon] = ACTIONS(154),
    [sym__ternary_qmark] = ACTIONS(154),
    [sym_html_comment] = ACTIONS(5),
  },
  [708] = {
    [ts_builtin_sym_end] = ACTIONS(1726),
    [sym_identifier] = ACTIONS(1728),
    [anon_sym_export] = ACTIONS(1728),
    [anon_sym_default] = ACTIONS(1728),
    [anon_sym_type] = ACTIONS(1728),
    [anon_sym_EQ] = ACTIONS(1728),
    [anon_sym_namespace] = ACTIONS(1728),
    [anon_sym_LBRACE] = ACTIONS(1726),
    [anon_sym_COMMA] = ACTIONS(1726),
    [anon_sym_RBRACE] = ACTIONS(1726),
    [anon_sym_typeof] = ACTIONS(1728),
    [anon_sym_import] = ACTIONS(1728),
    [anon_sym_from] = ACTIONS(1728),
    [anon_sym_with] = ACTIONS(1728),
    [anon_sym_var] = ACTIONS(1728),
    [anon_sym_let] = ACTIONS(1728),
    [anon_sym_const] = ACTIONS(1728),
    [anon_sym_BANG] = ACTIONS(1726),
    [anon_sym_else] = ACTIONS(1728),
    [anon_sym_if] = ACTIONS(1728),
    [anon_sym_switch] = ACTIONS(1728),
    [anon_sym_for] = ACTIONS(1728),
    [anon_sym_LPAREN] = ACTIONS(1726),
    [anon_sym_SEMI] = ACTIONS(1726),
    [anon_sym_RPAREN] = ACTIONS(1726),
    [anon_sym_await] = ACTIONS(1728),
    [anon_sym_while] = ACTIONS(1728),
    [anon_sym_do] = ACTIONS(1728),
    [anon_sym_try] = ACTIONS(1728),
    [anon_sym_break] = ACTIONS(1728),
    [anon_sym_continue] = ACTIONS(1728),
    [anon_sym_debugger] = ACTIONS(1728),
    [anon_sym_return] = ACTIONS(1728),
    [anon_sym_throw] = ACTIONS(1728),
    [anon_sym_COLON] = ACTIONS(1726),
    [anon_sym_case] = ACTIONS(1728),
    [anon_sym_yield] = ACTIONS(1728),
    [anon_sym_LBRACK] = ACTIONS(1726),
    [anon_sym_RBRACK] = ACTIONS(1726),
    [anon_sym_class] = ACTIONS(1728),
    [anon_sym_async] = ACTIONS(1728),
    [anon_sym_function] = ACTIONS(1728),
    [anon_sym_EQ_GT] = ACTIONS(1726),
    [anon_sym_new] = ACTIONS(1728),
    [anon_sym_using] = ACTIONS(1728),
    [anon_sym_AMP] = ACTIONS(1726),
    [anon_sym_PIPE] = ACTIONS(1726),
    [anon_sym_PLUS] = ACTIONS(1728),
    [anon_sym_DASH] = ACTIONS(1728),
    [anon_sym_SLASH] = ACTIONS(1728),
    [anon_sym_LT] = ACTIONS(1726),
    [anon_sym_GT] = ACTIONS(1726),
    [anon_sym_TILDE] = ACTIONS(1726),
    [anon_sym_void] = ACTIONS(1728),
    [anon_sym_delete] = ACTIONS(1728),
    [anon_sym_PLUS_PLUS] = ACTIONS(1726),
    [anon_sym_DASH_DASH] = ACTIONS(1726),
    [anon_sym_DQUOTE] = ACTIONS(1726),
    [anon_sym_SQUOTE] = ACTIONS(1726),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1726),
    [sym_number] = ACTIONS(1726),
    [sym_private_property_identifier] = ACTIONS(1726),
    [sym_this] = ACTIONS(1728),
    [sym_super] = ACTIONS(1728),
    [sym_true] = ACTIONS(1728),
    [sym_false] = ACTIONS(1728),
    [sym_null] = ACTIONS(1728),
    [sym_undefined] = ACTIONS(1728),
    [anon_sym_AT] = ACTIONS(1726),
    [anon_sym_static] = ACTIONS(1728),
    [anon_sym_readonly] = ACTIONS(1728),
    [anon_sym_get] = ACTIONS(1728),
    [anon_sym_set] = ACTIONS(1728),
    [anon_sym_QMARK] = ACTIONS(1726),
    [anon_sym_declare] = ACTIONS(1728),
    [anon_sym_public] = ACTIONS(1728),
    [anon_sym_private] = ACTIONS(1728),
    [anon_sym_protected] = ACTIONS(1728),
    [anon_sym_override] = ACTIONS(1728),
    [anon_sym_module] = ACTIONS(1728),
    [anon_sym_any] = ACTIONS(1728),
    [anon_sym_number] = ACTIONS(1728),
    [anon_sym_boolean] = ACTIONS(1728),
    [anon_sym_string] = ACTIONS(1728),
    [anon_sym_symbol] = ACTIONS(1728),
    [anon_sym_object] = ACTIONS(1728),
    [anon_sym_abstract] = ACTIONS(1728),
    [anon_sym_extends] = ACTIONS(1728),
    [anon_sym_interface] = ACTIONS(1728),
    [anon_sym_enum] = ACTIONS(1728),
    [sym_html_comment] = ACTIONS(5),
  },
  [709] = {
    [ts_builtin_sym_end] = ACTIONS(1754),
    [sym_identifier] = ACTIONS(1756),
    [anon_sym_export] = ACTIONS(1756),
    [anon_sym_default] = ACTIONS(1756),
    [anon_sym_type] = ACTIONS(1756),
    [anon_sym_EQ] = ACTIONS(1756),
    [anon_sym_namespace] = ACTIONS(1756),
    [anon_sym_LBRACE] = ACTIONS(1754),
    [anon_sym_COMMA] = ACTIONS(1754),
    [anon_sym_RBRACE] = ACTIONS(1754),
    [anon_sym_typeof] = ACTIONS(1756),
    [anon_sym_import] = ACTIONS(1756),
    [anon_sym_from] = ACTIONS(1756),
    [anon_sym_with] = ACTIONS(1756),
    [anon_sym_var] = ACTIONS(1756),
    [anon_sym_let] = ACTIONS(1756),
    [anon_sym_const] = ACTIONS(1756),
    [anon_sym_BANG] = ACTIONS(1754),
    [anon_sym_else] = ACTIONS(1756),
    [anon_sym_if] = ACTIONS(1756),
    [anon_sym_switch] = ACTIONS(1756),
    [anon_sym_for] = ACTIONS(1756),
    [anon_sym_LPAREN] = ACTIONS(1754),
    [anon_sym_SEMI] = ACTIONS(1754),
    [anon_sym_RPAREN] = ACTIONS(1754),
    [anon_sym_await] = ACTIONS(1756),
    [anon_sym_while] = ACTIONS(1756),
    [anon_sym_do] = ACTIONS(1756),
    [anon_sym_try] = ACTIONS(1756),
    [anon_sym_break] = ACTIONS(1756),
    [anon_sym_continue] = ACTIONS(1756),
    [anon_sym_debugger] = ACTIONS(1756),
    [anon_sym_return] = ACTIONS(1756),
    [anon_sym_throw] = ACTIONS(1756),
    [anon_sym_COLON] = ACTIONS(1754),
    [anon_sym_case] = ACTIONS(1756),
    [anon_sym_yield] = ACTIONS(1756),
    [anon_sym_LBRACK] = ACTIONS(1754),
    [anon_sym_RBRACK] = ACTIONS(1754),
    [anon_sym_class] = ACTIONS(1756),
    [anon_sym_async] = ACTIONS(1756),
    [anon_sym_function] = ACTIONS(1756),
    [anon_sym_EQ_GT] = ACTIONS(1754),
    [anon_sym_new] = ACTIONS(1756),
    [anon_sym_using] = ACTIONS(1756),
    [anon_sym_AMP] = ACTIONS(1754),
    [anon_sym_PIPE] = ACTIONS(1754),
    [anon_sym_PLUS] = ACTIONS(1756),
    [anon_sym_DASH] = ACTIONS(1756),
    [anon_sym_SLASH] = ACTIONS(1756),
    [anon_sym_LT] = ACTIONS(1754),
    [anon_sym_GT] = ACTIONS(1754),
    [anon_sym_TILDE] = ACTIONS(1754),
    [anon_sym_void] = ACTIONS(1756),
    [anon_sym_delete] = ACTIONS(1756),
    [anon_sym_PLUS_PLUS] = ACTIONS(1754),
    [anon_sym_DASH_DASH] = ACTIONS(1754),
    [anon_sym_DQUOTE] = ACTIONS(1754),
    [anon_sym_SQUOTE] = ACTIONS(1754),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1754),
    [sym_number] = ACTIONS(1754),
    [sym_private_property_identifier] = ACTIONS(1754),
    [sym_this] = ACTIONS(1756),
    [sym_super] = ACTIONS(1756),
    [sym_true] = ACTIONS(1756),
    [sym_false] = ACTIONS(1756),
    [sym_null] = ACTIONS(1756),
    [sym_undefined] = ACTIONS(1756),
    [anon_sym_AT] = ACTIONS(1754),
    [anon_sym_static] = ACTIONS(1756),
    [anon_sym_readonly] = ACTIONS(1756),
    [anon_sym_get] = ACTIONS(1756),
    [anon_sym_set] = ACTIONS(1756),
    [anon_sym_QMARK] = ACTIONS(1754),
    [anon_sym_declare] = ACTIONS(1756),
    [anon_sym_public] = ACTIONS(1756),
    [anon_sym_private] = ACTIONS(1756),
    [anon_sym_protected] = ACTIONS(1756),
    [anon_sym_override] = ACTIONS(1756),
    [anon_sym_module] = ACTIONS(1756),
    [anon_sym_any] = ACTIONS(1756),
    [anon_sym_number] = ACTIONS(1756),
    [anon_sym_boolean] = ACTIONS(1756),
    [anon_sym_string] = ACTIONS(1756),
    [anon_sym_symbol] = ACTIONS(1756),
    [anon_sym_object] = ACTIONS(1756),
    [anon_sym_abstract] = ACTIONS(1756),
    [anon_sym_extends] = ACTIONS(1756),
    [anon_sym_interface] = ACTIONS(1756),
    [anon_sym_enum] = ACTIONS(1756),
    [sym_html_comment] = ACTIONS(5),
  },
  [710] = {
    [sym_declaration] = STATE(867),
    [sym_variable_declaration] = STATE(831),
    [sym_lexical_declaration] = STATE(831),
    [sym_class_declaration] = STATE(831),
    [sym_function_declaration] = STATE(831),
    [sym_generator_function_declaration] = STATE(831),
    [sym_decorator] = STATE(1344),
    [sym_function_signature] = STATE(831),
    [sym_ambient_declaration] = STATE(831),
    [sym_abstract_class_declaration] = STATE(831),
    [sym_module] = STATE(831),
    [sym_internal_module] = STATE(824),
    [sym_import_alias] = STATE(831),
    [sym_interface_declaration] = STATE(831),
    [sym_enum_declaration] = STATE(831),
    [sym_type_alias_declaration] = STATE(831),
    [aux_sym_export_statement_repeat1] = STATE(4301),
    [anon_sym_STAR] = ACTIONS(120),
    [anon_sym_type] = ACTIONS(2341),
    [anon_sym_EQ] = ACTIONS(858),
    [anon_sym_as] = ACTIONS(120),
    [anon_sym_namespace] = ACTIONS(2137),
    [anon_sym_COMMA] = ACTIONS(154),
    [anon_sym_import] = ACTIONS(2141),
    [anon_sym_var] = ACTIONS(2143),
    [anon_sym_let] = ACTIONS(2145),
    [anon_sym_const] = ACTIONS(2147),
    [anon_sym_BANG] = ACTIONS(120),
    [anon_sym_LPAREN] = ACTIONS(154),
    [anon_sym_SEMI] = ACTIONS(154),
    [anon_sym_in] = ACTIONS(120),
    [anon_sym_COLON] = ACTIONS(878),
    [anon_sym_LBRACK] = ACTIONS(154),
    [anon_sym_DOT] = ACTIONS(154),
    [anon_sym_class] = ACTIONS(2152),
    [anon_sym_async] = ACTIONS(2154),
    [anon_sym_function] = ACTIONS(2156),
    [anon_sym_EQ_GT] = ACTIONS(682),
    [anon_sym_QMARK_DOT] = ACTIONS(154),
    [anon_sym_PLUS_EQ] = ACTIONS(160),
    [anon_sym_DASH_EQ] = ACTIONS(160),
    [anon_sym_STAR_EQ] = ACTIONS(160),
    [anon_sym_SLASH_EQ] = ACTIONS(160),
    [anon_sym_PERCENT_EQ] = ACTIONS(160),
    [anon_sym_CARET_EQ] = ACTIONS(160),
    [anon_sym_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_LT_LT_EQ] = ACTIONS(160),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(160),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP] = ACTIONS(120),
    [anon_sym_PIPE_PIPE] = ACTIONS(120),
    [anon_sym_GT_GT] = ACTIONS(120),
    [anon_sym_GT_GT_GT] = ACTIONS(120),
    [anon_sym_LT_LT] = ACTIONS(120),
    [anon_sym_AMP] = ACTIONS(120),
    [anon_sym_CARET] = ACTIONS(120),
    [anon_sym_PIPE] = ACTIONS(120),
    [anon_sym_PLUS] = ACTIONS(120),
    [anon_sym_DASH] = ACTIONS(120),
    [anon_sym_SLASH] = ACTIONS(120),
    [anon_sym_PERCENT] = ACTIONS(120),
    [anon_sym_STAR_STAR] = ACTIONS(120),
    [anon_sym_LT] = ACTIONS(120),
    [anon_sym_LT_EQ] = ACTIONS(154),
    [anon_sym_EQ_EQ] = ACTIONS(120),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(154),
    [anon_sym_BANG_EQ] = ACTIONS(120),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(154),
    [anon_sym_GT_EQ] = ACTIONS(154),
    [anon_sym_GT] = ACTIONS(120),
    [anon_sym_QMARK_QMARK] = ACTIONS(120),
    [anon_sym_instanceof] = ACTIONS(154),
    [anon_sym_PLUS_PLUS] = ACTIONS(154),
    [anon_sym_DASH_DASH] = ACTIONS(154),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(154),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_declare] = ACTIONS(2161),
    [anon_sym_module] = ACTIONS(2343),
    [anon_sym_abstract] = ACTIONS(2165),
    [anon_sym_satisfies] = ACTIONS(154),
    [anon_sym_global] = ACTIONS(2345),
    [anon_sym_interface] = ACTIONS(2167),
    [anon_sym_enum] = ACTIONS(2169),
    [sym__automatic_semicolon] = ACTIONS(154),
    [sym__ternary_qmark] = ACTIONS(154),
    [sym_html_comment] = ACTIONS(5),
  },
  [711] = {
    [ts_builtin_sym_end] = ACTIONS(2361),
    [sym_identifier] = ACTIONS(2363),
    [anon_sym_export] = ACTIONS(2363),
    [anon_sym_default] = ACTIONS(2363),
    [anon_sym_type] = ACTIONS(2363),
    [anon_sym_EQ] = ACTIONS(2363),
    [anon_sym_namespace] = ACTIONS(2363),
    [anon_sym_LBRACE] = ACTIONS(2361),
    [anon_sym_COMMA] = ACTIONS(2361),
    [anon_sym_RBRACE] = ACTIONS(2361),
    [anon_sym_typeof] = ACTIONS(2363),
    [anon_sym_import] = ACTIONS(2363),
    [anon_sym_with] = ACTIONS(2363),
    [anon_sym_var] = ACTIONS(2363),
    [anon_sym_let] = ACTIONS(2363),
    [anon_sym_const] = ACTIONS(2363),
    [anon_sym_BANG] = ACTIONS(2361),
    [anon_sym_else] = ACTIONS(2363),
    [anon_sym_if] = ACTIONS(2363),
    [anon_sym_switch] = ACTIONS(2363),
    [anon_sym_for] = ACTIONS(2363),
    [anon_sym_LPAREN] = ACTIONS(2361),
    [anon_sym_SEMI] = ACTIONS(2361),
    [anon_sym_RPAREN] = ACTIONS(2361),
    [anon_sym_await] = ACTIONS(2363),
    [anon_sym_while] = ACTIONS(2363),
    [anon_sym_do] = ACTIONS(2363),
    [anon_sym_try] = ACTIONS(2363),
    [anon_sym_break] = ACTIONS(2363),
    [anon_sym_continue] = ACTIONS(2363),
    [anon_sym_debugger] = ACTIONS(2363),
    [anon_sym_return] = ACTIONS(2363),
    [anon_sym_throw] = ACTIONS(2363),
    [anon_sym_COLON] = ACTIONS(2361),
    [anon_sym_case] = ACTIONS(2363),
    [anon_sym_yield] = ACTIONS(2363),
    [anon_sym_LBRACK] = ACTIONS(2361),
    [anon_sym_RBRACK] = ACTIONS(2361),
    [anon_sym_class] = ACTIONS(2363),
    [anon_sym_async] = ACTIONS(2363),
    [anon_sym_function] = ACTIONS(2363),
    [anon_sym_EQ_GT] = ACTIONS(2361),
    [anon_sym_new] = ACTIONS(2363),
    [anon_sym_using] = ACTIONS(2363),
    [anon_sym_AMP] = ACTIONS(2361),
    [anon_sym_PIPE] = ACTIONS(2361),
    [anon_sym_PLUS] = ACTIONS(2363),
    [anon_sym_DASH] = ACTIONS(2363),
    [anon_sym_SLASH] = ACTIONS(2363),
    [anon_sym_LT] = ACTIONS(2361),
    [anon_sym_GT] = ACTIONS(2361),
    [anon_sym_TILDE] = ACTIONS(2361),
    [anon_sym_void] = ACTIONS(2363),
    [anon_sym_delete] = ACTIONS(2363),
    [anon_sym_PLUS_PLUS] = ACTIONS(2361),
    [anon_sym_DASH_DASH] = ACTIONS(2361),
    [anon_sym_DQUOTE] = ACTIONS(2361),
    [anon_sym_SQUOTE] = ACTIONS(2361),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(2361),
    [sym_number] = ACTIONS(2361),
    [sym_private_property_identifier] = ACTIONS(2361),
    [sym_this] = ACTIONS(2363),
    [sym_super] = ACTIONS(2363),
    [sym_true] = ACTIONS(2363),
    [sym_false] = ACTIONS(2363),
    [sym_null] = ACTIONS(2363),
    [sym_undefined] = ACTIONS(2363),
    [anon_sym_AT] = ACTIONS(2361),
    [anon_sym_static] = ACTIONS(2363),
    [anon_sym_readonly] = ACTIONS(2363),
    [anon_sym_get] = ACTIONS(2363),
    [anon_sym_set] = ACTIONS(2363),
    [anon_sym_QMARK] = ACTIONS(2361),
    [anon_sym_declare] = ACTIONS(2363),
    [anon_sym_public] = ACTIONS(2363),
    [anon_sym_private] = ACTIONS(2363),
    [anon_sym_protected] = ACTIONS(2363),
    [anon_sym_override] = ACTIONS(2363),
    [anon_sym_module] = ACTIONS(2363),
    [anon_sym_any] = ACTIONS(2363),
    [anon_sym_number] = ACTIONS(2363),
    [anon_sym_boolean] = ACTIONS(2363),
    [anon_sym_string] = ACTIONS(2363),
    [anon_sym_symbol] = ACTIONS(2363),
    [anon_sym_object] = ACTIONS(2363),
    [anon_sym_abstract] = ACTIONS(2363),
    [anon_sym_extends] = ACTIONS(2363),
    [anon_sym_interface] = ACTIONS(2363),
    [anon_sym_enum] = ACTIONS(2363),
    [sym_html_comment] = ACTIONS(5),
  },
  [712] = {
    [ts_builtin_sym_end] = ACTIONS(2365),
    [sym_identifier] = ACTIONS(2367),
    [anon_sym_export] = ACTIONS(2367),
    [anon_sym_default] = ACTIONS(2367),
    [anon_sym_type] = ACTIONS(2367),
    [anon_sym_EQ] = ACTIONS(2367),
    [anon_sym_namespace] = ACTIONS(2367),
    [anon_sym_LBRACE] = ACTIONS(2365),
    [anon_sym_COMMA] = ACTIONS(2365),
    [anon_sym_RBRACE] = ACTIONS(2365),
    [anon_sym_typeof] = ACTIONS(2367),
    [anon_sym_import] = ACTIONS(2367),
    [anon_sym_with] = ACTIONS(2367),
    [anon_sym_var] = ACTIONS(2367),
    [anon_sym_let] = ACTIONS(2367),
    [anon_sym_const] = ACTIONS(2367),
    [anon_sym_BANG] = ACTIONS(2365),
    [anon_sym_else] = ACTIONS(2367),
    [anon_sym_if] = ACTIONS(2367),
    [anon_sym_switch] = ACTIONS(2367),
    [anon_sym_for] = ACTIONS(2367),
    [anon_sym_LPAREN] = ACTIONS(2365),
    [anon_sym_SEMI] = ACTIONS(2365),
    [anon_sym_RPAREN] = ACTIONS(2365),
    [anon_sym_await] = ACTIONS(2367),
    [anon_sym_while] = ACTIONS(2367),
    [anon_sym_do] = ACTIONS(2367),
    [anon_sym_try] = ACTIONS(2367),
    [anon_sym_break] = ACTIONS(2367),
    [anon_sym_continue] = ACTIONS(2367),
    [anon_sym_debugger] = ACTIONS(2367),
    [anon_sym_return] = ACTIONS(2367),
    [anon_sym_throw] = ACTIONS(2367),
    [anon_sym_COLON] = ACTIONS(2365),
    [anon_sym_case] = ACTIONS(2367),
    [anon_sym_yield] = ACTIONS(2367),
    [anon_sym_LBRACK] = ACTIONS(2365),
    [anon_sym_RBRACK] = ACTIONS(2365),
    [anon_sym_class] = ACTIONS(2367),
    [anon_sym_async] = ACTIONS(2367),
    [anon_sym_function] = ACTIONS(2367),
    [anon_sym_EQ_GT] = ACTIONS(2365),
    [anon_sym_new] = ACTIONS(2367),
    [anon_sym_using] = ACTIONS(2367),
    [anon_sym_AMP] = ACTIONS(2365),
    [anon_sym_PIPE] = ACTIONS(2365),
    [anon_sym_PLUS] = ACTIONS(2367),
    [anon_sym_DASH] = ACTIONS(2367),
    [anon_sym_SLASH] = ACTIONS(2367),
    [anon_sym_LT] = ACTIONS(2365),
    [anon_sym_GT] = ACTIONS(2365),
    [anon_sym_TILDE] = ACTIONS(2365),
    [anon_sym_void] = ACTIONS(2367),
    [anon_sym_delete] = ACTIONS(2367),
    [anon_sym_PLUS_PLUS] = ACTIONS(2365),
    [anon_sym_DASH_DASH] = ACTIONS(2365),
    [anon_sym_DQUOTE] = ACTIONS(2365),
    [anon_sym_SQUOTE] = ACTIONS(2365),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(2365),
    [sym_number] = ACTIONS(2365),
    [sym_private_property_identifier] = ACTIONS(2365),
    [sym_this] = ACTIONS(2367),
    [sym_super] = ACTIONS(2367),
    [sym_true] = ACTIONS(2367),
    [sym_false] = ACTIONS(2367),
    [sym_null] = ACTIONS(2367),
    [sym_undefined] = ACTIONS(2367),
    [anon_sym_AT] = ACTIONS(2365),
    [anon_sym_static] = ACTIONS(2367),
    [anon_sym_readonly] = ACTIONS(2367),
    [anon_sym_get] = ACTIONS(2367),
    [anon_sym_set] = ACTIONS(2367),
    [anon_sym_QMARK] = ACTIONS(2365),
    [anon_sym_declare] = ACTIONS(2367),
    [anon_sym_public] = ACTIONS(2367),
    [anon_sym_private] = ACTIONS(2367),
    [anon_sym_protected] = ACTIONS(2367),
    [anon_sym_override] = ACTIONS(2367),
    [anon_sym_module] = ACTIONS(2367),
    [anon_sym_any] = ACTIONS(2367),
    [anon_sym_number] = ACTIONS(2367),
    [anon_sym_boolean] = ACTIONS(2367),
    [anon_sym_string] = ACTIONS(2367),
    [anon_sym_symbol] = ACTIONS(2367),
    [anon_sym_object] = ACTIONS(2367),
    [anon_sym_abstract] = ACTIONS(2367),
    [anon_sym_extends] = ACTIONS(2367),
    [anon_sym_interface] = ACTIONS(2367),
    [anon_sym_enum] = ACTIONS(2367),
    [sym_html_comment] = ACTIONS(5),
  },
  [713] = {
    [ts_builtin_sym_end] = ACTIONS(2369),
    [sym_identifier] = ACTIONS(2371),
    [anon_sym_export] = ACTIONS(2371),
    [anon_sym_default] = ACTIONS(2371),
    [anon_sym_type] = ACTIONS(2371),
    [anon_sym_EQ] = ACTIONS(2371),
    [anon_sym_namespace] = ACTIONS(2371),
    [anon_sym_LBRACE] = ACTIONS(2369),
    [anon_sym_COMMA] = ACTIONS(2369),
    [anon_sym_RBRACE] = ACTIONS(2369),
    [anon_sym_typeof] = ACTIONS(2371),
    [anon_sym_import] = ACTIONS(2371),
    [anon_sym_with] = ACTIONS(2371),
    [anon_sym_var] = ACTIONS(2371),
    [anon_sym_let] = ACTIONS(2371),
    [anon_sym_const] = ACTIONS(2371),
    [anon_sym_BANG] = ACTIONS(2369),
    [anon_sym_else] = ACTIONS(2371),
    [anon_sym_if] = ACTIONS(2371),
    [anon_sym_switch] = ACTIONS(2371),
    [anon_sym_for] = ACTIONS(2371),
    [anon_sym_LPAREN] = ACTIONS(2369),
    [anon_sym_SEMI] = ACTIONS(2369),
    [anon_sym_RPAREN] = ACTIONS(2369),
    [anon_sym_await] = ACTIONS(2371),
    [anon_sym_while] = ACTIONS(2371),
    [anon_sym_do] = ACTIONS(2371),
    [anon_sym_try] = ACTIONS(2371),
    [anon_sym_break] = ACTIONS(2371),
    [anon_sym_continue] = ACTIONS(2371),
    [anon_sym_debugger] = ACTIONS(2371),
    [anon_sym_return] = ACTIONS(2371),
    [anon_sym_throw] = ACTIONS(2371),
    [anon_sym_COLON] = ACTIONS(2369),
    [anon_sym_case] = ACTIONS(2371),
    [anon_sym_yield] = ACTIONS(2371),
    [anon_sym_LBRACK] = ACTIONS(2369),
    [anon_sym_RBRACK] = ACTIONS(2369),
    [anon_sym_class] = ACTIONS(2371),
    [anon_sym_async] = ACTIONS(2371),
    [anon_sym_function] = ACTIONS(2371),
    [anon_sym_EQ_GT] = ACTIONS(2369),
    [anon_sym_new] = ACTIONS(2371),
    [anon_sym_using] = ACTIONS(2371),
    [anon_sym_AMP] = ACTIONS(2369),
    [anon_sym_PIPE] = ACTIONS(2369),
    [anon_sym_PLUS] = ACTIONS(2371),
    [anon_sym_DASH] = ACTIONS(2371),
    [anon_sym_SLASH] = ACTIONS(2371),
    [anon_sym_LT] = ACTIONS(2369),
    [anon_sym_GT] = ACTIONS(2369),
    [anon_sym_TILDE] = ACTIONS(2369),
    [anon_sym_void] = ACTIONS(2371),
    [anon_sym_delete] = ACTIONS(2371),
    [anon_sym_PLUS_PLUS] = ACTIONS(2369),
    [anon_sym_DASH_DASH] = ACTIONS(2369),
    [anon_sym_DQUOTE] = ACTIONS(2369),
    [anon_sym_SQUOTE] = ACTIONS(2369),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(2369),
    [sym_number] = ACTIONS(2369),
    [sym_private_property_identifier] = ACTIONS(2369),
    [sym_this] = ACTIONS(2371),
    [sym_super] = ACTIONS(2371),
    [sym_true] = ACTIONS(2371),
    [sym_false] = ACTIONS(2371),
    [sym_null] = ACTIONS(2371),
    [sym_undefined] = ACTIONS(2371),
    [anon_sym_AT] = ACTIONS(2369),
    [anon_sym_static] = ACTIONS(2371),
    [anon_sym_readonly] = ACTIONS(2371),
    [anon_sym_get] = ACTIONS(2371),
    [anon_sym_set] = ACTIONS(2371),
    [anon_sym_QMARK] = ACTIONS(2369),
    [anon_sym_declare] = ACTIONS(2371),
    [anon_sym_public] = ACTIONS(2371),
    [anon_sym_private] = ACTIONS(2371),
    [anon_sym_protected] = ACTIONS(2371),
    [anon_sym_override] = ACTIONS(2371),
    [anon_sym_module] = ACTIONS(2371),
    [anon_sym_any] = ACTIONS(2371),
    [anon_sym_number] = ACTIONS(2371),
    [anon_sym_boolean] = ACTIONS(2371),
    [anon_sym_string] = ACTIONS(2371),
    [anon_sym_symbol] = ACTIONS(2371),
    [anon_sym_object] = ACTIONS(2371),
    [anon_sym_abstract] = ACTIONS(2371),
    [anon_sym_extends] = ACTIONS(2371),
    [anon_sym_interface] = ACTIONS(2371),
    [anon_sym_enum] = ACTIONS(2371),
    [sym_html_comment] = ACTIONS(5),
  },
  [714] = {
    [ts_builtin_sym_end] = ACTIONS(2373),
    [sym_identifier] = ACTIONS(2375),
    [anon_sym_export] = ACTIONS(2375),
    [anon_sym_default] = ACTIONS(2375),
    [anon_sym_type] = ACTIONS(2375),
    [anon_sym_EQ] = ACTIONS(2375),
    [anon_sym_namespace] = ACTIONS(2375),
    [anon_sym_LBRACE] = ACTIONS(2373),
    [anon_sym_COMMA] = ACTIONS(2373),
    [anon_sym_RBRACE] = ACTIONS(2373),
    [anon_sym_typeof] = ACTIONS(2375),
    [anon_sym_import] = ACTIONS(2375),
    [anon_sym_with] = ACTIONS(2375),
    [anon_sym_var] = ACTIONS(2375),
    [anon_sym_let] = ACTIONS(2375),
    [anon_sym_const] = ACTIONS(2375),
    [anon_sym_BANG] = ACTIONS(2373),
    [anon_sym_else] = ACTIONS(2375),
    [anon_sym_if] = ACTIONS(2375),
    [anon_sym_switch] = ACTIONS(2375),
    [anon_sym_for] = ACTIONS(2375),
    [anon_sym_LPAREN] = ACTIONS(2373),
    [anon_sym_SEMI] = ACTIONS(2373),
    [anon_sym_RPAREN] = ACTIONS(2373),
    [anon_sym_await] = ACTIONS(2375),
    [anon_sym_while] = ACTIONS(2375),
    [anon_sym_do] = ACTIONS(2375),
    [anon_sym_try] = ACTIONS(2375),
    [anon_sym_break] = ACTIONS(2375),
    [anon_sym_continue] = ACTIONS(2375),
    [anon_sym_debugger] = ACTIONS(2375),
    [anon_sym_return] = ACTIONS(2375),
    [anon_sym_throw] = ACTIONS(2375),
    [anon_sym_COLON] = ACTIONS(2373),
    [anon_sym_case] = ACTIONS(2375),
    [anon_sym_yield] = ACTIONS(2375),
    [anon_sym_LBRACK] = ACTIONS(2373),
    [anon_sym_RBRACK] = ACTIONS(2373),
    [anon_sym_class] = ACTIONS(2375),
    [anon_sym_async] = ACTIONS(2375),
    [anon_sym_function] = ACTIONS(2375),
    [anon_sym_EQ_GT] = ACTIONS(2373),
    [anon_sym_new] = ACTIONS(2375),
    [anon_sym_using] = ACTIONS(2375),
    [anon_sym_AMP] = ACTIONS(2373),
    [anon_sym_PIPE] = ACTIONS(2373),
    [anon_sym_PLUS] = ACTIONS(2375),
    [anon_sym_DASH] = ACTIONS(2375),
    [anon_sym_SLASH] = ACTIONS(2375),
    [anon_sym_LT] = ACTIONS(2373),
    [anon_sym_GT] = ACTIONS(2373),
    [anon_sym_TILDE] = ACTIONS(2373),
    [anon_sym_void] = ACTIONS(2375),
    [anon_sym_delete] = ACTIONS(2375),
    [anon_sym_PLUS_PLUS] = ACTIONS(2373),
    [anon_sym_DASH_DASH] = ACTIONS(2373),
    [anon_sym_DQUOTE] = ACTIONS(2373),
    [anon_sym_SQUOTE] = ACTIONS(2373),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(2373),
    [sym_number] = ACTIONS(2373),
    [sym_private_property_identifier] = ACTIONS(2373),
    [sym_this] = ACTIONS(2375),
    [sym_super] = ACTIONS(2375),
    [sym_true] = ACTIONS(2375),
    [sym_false] = ACTIONS(2375),
    [sym_null] = ACTIONS(2375),
    [sym_undefined] = ACTIONS(2375),
    [anon_sym_AT] = ACTIONS(2373),
    [anon_sym_static] = ACTIONS(2375),
    [anon_sym_readonly] = ACTIONS(2375),
    [anon_sym_get] = ACTIONS(2375),
    [anon_sym_set] = ACTIONS(2375),
    [anon_sym_QMARK] = ACTIONS(2373),
    [anon_sym_declare] = ACTIONS(2375),
    [anon_sym_public] = ACTIONS(2375),
    [anon_sym_private] = ACTIONS(2375),
    [anon_sym_protected] = ACTIONS(2375),
    [anon_sym_override] = ACTIONS(2375),
    [anon_sym_module] = ACTIONS(2375),
    [anon_sym_any] = ACTIONS(2375),
    [anon_sym_number] = ACTIONS(2375),
    [anon_sym_boolean] = ACTIONS(2375),
    [anon_sym_string] = ACTIONS(2375),
    [anon_sym_symbol] = ACTIONS(2375),
    [anon_sym_object] = ACTIONS(2375),
    [anon_sym_abstract] = ACTIONS(2375),
    [anon_sym_extends] = ACTIONS(2375),
    [anon_sym_interface] = ACTIONS(2375),
    [anon_sym_enum] = ACTIONS(2375),
    [sym_html_comment] = ACTIONS(5),
  },
  [715] = {
    [ts_builtin_sym_end] = ACTIONS(2377),
    [sym_identifier] = ACTIONS(2379),
    [anon_sym_export] = ACTIONS(2379),
    [anon_sym_default] = ACTIONS(2379),
    [anon_sym_type] = ACTIONS(2379),
    [anon_sym_EQ] = ACTIONS(2379),
    [anon_sym_namespace] = ACTIONS(2379),
    [anon_sym_LBRACE] = ACTIONS(2377),
    [anon_sym_COMMA] = ACTIONS(2377),
    [anon_sym_RBRACE] = ACTIONS(2377),
    [anon_sym_typeof] = ACTIONS(2379),
    [anon_sym_import] = ACTIONS(2379),
    [anon_sym_with] = ACTIONS(2379),
    [anon_sym_var] = ACTIONS(2379),
    [anon_sym_let] = ACTIONS(2379),
    [anon_sym_const] = ACTIONS(2379),
    [anon_sym_BANG] = ACTIONS(2377),
    [anon_sym_else] = ACTIONS(2379),
    [anon_sym_if] = ACTIONS(2379),
    [anon_sym_switch] = ACTIONS(2379),
    [anon_sym_for] = ACTIONS(2379),
    [anon_sym_LPAREN] = ACTIONS(2377),
    [anon_sym_SEMI] = ACTIONS(2377),
    [anon_sym_RPAREN] = ACTIONS(2377),
    [anon_sym_await] = ACTIONS(2379),
    [anon_sym_while] = ACTIONS(2379),
    [anon_sym_do] = ACTIONS(2379),
    [anon_sym_try] = ACTIONS(2379),
    [anon_sym_break] = ACTIONS(2379),
    [anon_sym_continue] = ACTIONS(2379),
    [anon_sym_debugger] = ACTIONS(2379),
    [anon_sym_return] = ACTIONS(2379),
    [anon_sym_throw] = ACTIONS(2379),
    [anon_sym_COLON] = ACTIONS(2377),
    [anon_sym_case] = ACTIONS(2379),
    [anon_sym_yield] = ACTIONS(2379),
    [anon_sym_LBRACK] = ACTIONS(2377),
    [anon_sym_RBRACK] = ACTIONS(2377),
    [anon_sym_class] = ACTIONS(2379),
    [anon_sym_async] = ACTIONS(2379),
    [anon_sym_function] = ACTIONS(2379),
    [anon_sym_EQ_GT] = ACTIONS(2377),
    [anon_sym_new] = ACTIONS(2379),
    [anon_sym_using] = ACTIONS(2379),
    [anon_sym_AMP] = ACTIONS(2377),
    [anon_sym_PIPE] = ACTIONS(2377),
    [anon_sym_PLUS] = ACTIONS(2379),
    [anon_sym_DASH] = ACTIONS(2379),
    [anon_sym_SLASH] = ACTIONS(2379),
    [anon_sym_LT] = ACTIONS(2377),
    [anon_sym_GT] = ACTIONS(2377),
    [anon_sym_TILDE] = ACTIONS(2377),
    [anon_sym_void] = ACTIONS(2379),
    [anon_sym_delete] = ACTIONS(2379),
    [anon_sym_PLUS_PLUS] = ACTIONS(2377),
    [anon_sym_DASH_DASH] = ACTIONS(2377),
    [anon_sym_DQUOTE] = ACTIONS(2377),
    [anon_sym_SQUOTE] = ACTIONS(2377),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(2377),
    [sym_number] = ACTIONS(2377),
    [sym_private_property_identifier] = ACTIONS(2377),
    [sym_this] = ACTIONS(2379),
    [sym_super] = ACTIONS(2379),
    [sym_true] = ACTIONS(2379),
    [sym_false] = ACTIONS(2379),
    [sym_null] = ACTIONS(2379),
    [sym_undefined] = ACTIONS(2379),
    [anon_sym_AT] = ACTIONS(2377),
    [anon_sym_static] = ACTIONS(2379),
    [anon_sym_readonly] = ACTIONS(2379),
    [anon_sym_get] = ACTIONS(2379),
    [anon_sym_set] = ACTIONS(2379),
    [anon_sym_QMARK] = ACTIONS(2377),
    [anon_sym_declare] = ACTIONS(2379),
    [anon_sym_public] = ACTIONS(2379),
    [anon_sym_private] = ACTIONS(2379),
    [anon_sym_protected] = ACTIONS(2379),
    [anon_sym_override] = ACTIONS(2379),
    [anon_sym_module] = ACTIONS(2379),
    [anon_sym_any] = ACTIONS(2379),
    [anon_sym_number] = ACTIONS(2379),
    [anon_sym_boolean] = ACTIONS(2379),
    [anon_sym_string] = ACTIONS(2379),
    [anon_sym_symbol] = ACTIONS(2379),
    [anon_sym_object] = ACTIONS(2379),
    [anon_sym_abstract] = ACTIONS(2379),
    [anon_sym_extends] = ACTIONS(2379),
    [anon_sym_interface] = ACTIONS(2379),
    [anon_sym_enum] = ACTIONS(2379),
    [sym_html_comment] = ACTIONS(5),
  },
  [716] = {
    [aux_sym_object_repeat1] = STATE(4810),
    [aux_sym_object_pattern_repeat1] = STATE(4815),
    [sym_identifier] = ACTIONS(1969),
    [anon_sym_export] = ACTIONS(1969),
    [anon_sym_STAR] = ACTIONS(1969),
    [anon_sym_type] = ACTIONS(1969),
    [anon_sym_EQ] = ACTIONS(661),
    [anon_sym_as] = ACTIONS(120),
    [anon_sym_namespace] = ACTIONS(1969),
    [anon_sym_COMMA] = ACTIONS(154),
    [anon_sym_RBRACE] = ACTIONS(692),
    [anon_sym_let] = ACTIONS(1969),
    [anon_sym_BANG] = ACTIONS(120),
    [anon_sym_LPAREN] = ACTIONS(2149),
    [anon_sym_SEMI] = ACTIONS(154),
    [anon_sym_in] = ACTIONS(120),
    [anon_sym_COLON] = ACTIONS(671),
    [anon_sym_LBRACK] = ACTIONS(1971),
    [anon_sym_DOT] = ACTIONS(120),
    [anon_sym_async] = ACTIONS(1969),
    [anon_sym_EQ_GT] = ACTIONS(682),
    [anon_sym_QMARK_DOT] = ACTIONS(154),
    [anon_sym_new] = ACTIONS(1969),
    [anon_sym_PLUS_EQ] = ACTIONS(160),
    [anon_sym_DASH_EQ] = ACTIONS(160),
    [anon_sym_STAR_EQ] = ACTIONS(160),
    [anon_sym_SLASH_EQ] = ACTIONS(160),
    [anon_sym_PERCENT_EQ] = ACTIONS(160),
    [anon_sym_CARET_EQ] = ACTIONS(160),
    [anon_sym_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_LT_LT_EQ] = ACTIONS(160),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(160),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP] = ACTIONS(120),
    [anon_sym_PIPE_PIPE] = ACTIONS(120),
    [anon_sym_GT_GT] = ACTIONS(120),
    [anon_sym_GT_GT_GT] = ACTIONS(120),
    [anon_sym_LT_LT] = ACTIONS(120),
    [anon_sym_AMP] = ACTIONS(120),
    [anon_sym_CARET] = ACTIONS(120),
    [anon_sym_PIPE] = ACTIONS(120),
    [anon_sym_PLUS] = ACTIONS(120),
    [anon_sym_DASH] = ACTIONS(120),
    [anon_sym_SLASH] = ACTIONS(120),
    [anon_sym_PERCENT] = ACTIONS(120),
    [anon_sym_STAR_STAR] = ACTIONS(120),
    [anon_sym_LT] = ACTIONS(2158),
    [anon_sym_LT_EQ] = ACTIONS(154),
    [anon_sym_EQ_EQ] = ACTIONS(120),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(154),
    [anon_sym_BANG_EQ] = ACTIONS(120),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(154),
    [anon_sym_GT_EQ] = ACTIONS(154),
    [anon_sym_GT] = ACTIONS(120),
    [anon_sym_QMARK_QMARK] = ACTIONS(120),
    [anon_sym_instanceof] = ACTIONS(120),
    [anon_sym_PLUS_PLUS] = ACTIONS(154),
    [anon_sym_DASH_DASH] = ACTIONS(154),
    [anon_sym_DQUOTE] = ACTIONS(1971),
    [anon_sym_SQUOTE] = ACTIONS(1971),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(154),
    [sym_number] = ACTIONS(1971),
    [sym_private_property_identifier] = ACTIONS(1971),
    [anon_sym_static] = ACTIONS(1969),
    [anon_sym_readonly] = ACTIONS(1969),
    [anon_sym_get] = ACTIONS(1969),
    [anon_sym_set] = ACTIONS(1969),
    [anon_sym_QMARK] = ACTIONS(690),
    [anon_sym_declare] = ACTIONS(1969),
    [anon_sym_public] = ACTIONS(1969),
    [anon_sym_private] = ACTIONS(1969),
    [anon_sym_protected] = ACTIONS(1969),
    [anon_sym_override] = ACTIONS(1969),
    [anon_sym_module] = ACTIONS(1969),
    [anon_sym_any] = ACTIONS(1969),
    [anon_sym_number] = ACTIONS(1969),
    [anon_sym_boolean] = ACTIONS(1969),
    [anon_sym_string] = ACTIONS(1969),
    [anon_sym_symbol] = ACTIONS(1969),
    [anon_sym_object] = ACTIONS(1969),
    [anon_sym_satisfies] = ACTIONS(120),
    [sym__automatic_semicolon] = ACTIONS(154),
    [sym__ternary_qmark] = ACTIONS(154),
    [sym_html_comment] = ACTIONS(5),
  },
  [717] = {
    [aux_sym_object_repeat1] = STATE(4792),
    [aux_sym_object_pattern_repeat1] = STATE(4815),
    [sym_identifier] = ACTIONS(1969),
    [anon_sym_export] = ACTIONS(1969),
    [anon_sym_STAR] = ACTIONS(1969),
    [anon_sym_type] = ACTIONS(1969),
    [anon_sym_EQ] = ACTIONS(661),
    [anon_sym_as] = ACTIONS(120),
    [anon_sym_namespace] = ACTIONS(1969),
    [anon_sym_COMMA] = ACTIONS(154),
    [anon_sym_RBRACE] = ACTIONS(667),
    [anon_sym_let] = ACTIONS(1969),
    [anon_sym_BANG] = ACTIONS(120),
    [anon_sym_LPAREN] = ACTIONS(2149),
    [anon_sym_SEMI] = ACTIONS(154),
    [anon_sym_in] = ACTIONS(120),
    [anon_sym_COLON] = ACTIONS(671),
    [anon_sym_LBRACK] = ACTIONS(1971),
    [anon_sym_DOT] = ACTIONS(120),
    [anon_sym_async] = ACTIONS(1969),
    [anon_sym_EQ_GT] = ACTIONS(682),
    [anon_sym_QMARK_DOT] = ACTIONS(154),
    [anon_sym_new] = ACTIONS(1969),
    [anon_sym_PLUS_EQ] = ACTIONS(160),
    [anon_sym_DASH_EQ] = ACTIONS(160),
    [anon_sym_STAR_EQ] = ACTIONS(160),
    [anon_sym_SLASH_EQ] = ACTIONS(160),
    [anon_sym_PERCENT_EQ] = ACTIONS(160),
    [anon_sym_CARET_EQ] = ACTIONS(160),
    [anon_sym_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_LT_LT_EQ] = ACTIONS(160),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(160),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP] = ACTIONS(120),
    [anon_sym_PIPE_PIPE] = ACTIONS(120),
    [anon_sym_GT_GT] = ACTIONS(120),
    [anon_sym_GT_GT_GT] = ACTIONS(120),
    [anon_sym_LT_LT] = ACTIONS(120),
    [anon_sym_AMP] = ACTIONS(120),
    [anon_sym_CARET] = ACTIONS(120),
    [anon_sym_PIPE] = ACTIONS(120),
    [anon_sym_PLUS] = ACTIONS(120),
    [anon_sym_DASH] = ACTIONS(120),
    [anon_sym_SLASH] = ACTIONS(120),
    [anon_sym_PERCENT] = ACTIONS(120),
    [anon_sym_STAR_STAR] = ACTIONS(120),
    [anon_sym_LT] = ACTIONS(2158),
    [anon_sym_LT_EQ] = ACTIONS(154),
    [anon_sym_EQ_EQ] = ACTIONS(120),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(154),
    [anon_sym_BANG_EQ] = ACTIONS(120),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(154),
    [anon_sym_GT_EQ] = ACTIONS(154),
    [anon_sym_GT] = ACTIONS(120),
    [anon_sym_QMARK_QMARK] = ACTIONS(120),
    [anon_sym_instanceof] = ACTIONS(120),
    [anon_sym_PLUS_PLUS] = ACTIONS(154),
    [anon_sym_DASH_DASH] = ACTIONS(154),
    [anon_sym_DQUOTE] = ACTIONS(1971),
    [anon_sym_SQUOTE] = ACTIONS(1971),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(154),
    [sym_number] = ACTIONS(1971),
    [sym_private_property_identifier] = ACTIONS(1971),
    [anon_sym_static] = ACTIONS(1969),
    [anon_sym_readonly] = ACTIONS(1969),
    [anon_sym_get] = ACTIONS(1969),
    [anon_sym_set] = ACTIONS(1969),
    [anon_sym_QMARK] = ACTIONS(690),
    [anon_sym_declare] = ACTIONS(1969),
    [anon_sym_public] = ACTIONS(1969),
    [anon_sym_private] = ACTIONS(1969),
    [anon_sym_protected] = ACTIONS(1969),
    [anon_sym_override] = ACTIONS(1969),
    [anon_sym_module] = ACTIONS(1969),
    [anon_sym_any] = ACTIONS(1969),
    [anon_sym_number] = ACTIONS(1969),
    [anon_sym_boolean] = ACTIONS(1969),
    [anon_sym_string] = ACTIONS(1969),
    [anon_sym_symbol] = ACTIONS(1969),
    [anon_sym_object] = ACTIONS(1969),
    [anon_sym_satisfies] = ACTIONS(120),
    [sym__automatic_semicolon] = ACTIONS(154),
    [sym__ternary_qmark] = ACTIONS(154),
    [sym_html_comment] = ACTIONS(5),
  },
  [718] = {
    [aux_sym_object_repeat1] = STATE(4792),
    [aux_sym_object_pattern_repeat1] = STATE(4815),
    [sym_identifier] = ACTIONS(1973),
    [anon_sym_export] = ACTIONS(1973),
    [anon_sym_STAR] = ACTIONS(1973),
    [anon_sym_type] = ACTIONS(1973),
    [anon_sym_EQ] = ACTIONS(661),
    [anon_sym_as] = ACTIONS(120),
    [anon_sym_namespace] = ACTIONS(1973),
    [anon_sym_COMMA] = ACTIONS(154),
    [anon_sym_RBRACE] = ACTIONS(667),
    [anon_sym_let] = ACTIONS(1973),
    [anon_sym_BANG] = ACTIONS(120),
    [anon_sym_LPAREN] = ACTIONS(2149),
    [anon_sym_SEMI] = ACTIONS(154),
    [anon_sym_in] = ACTIONS(120),
    [anon_sym_COLON] = ACTIONS(671),
    [anon_sym_LBRACK] = ACTIONS(1975),
    [anon_sym_DOT] = ACTIONS(120),
    [anon_sym_async] = ACTIONS(1973),
    [anon_sym_EQ_GT] = ACTIONS(682),
    [anon_sym_QMARK_DOT] = ACTIONS(154),
    [anon_sym_new] = ACTIONS(1973),
    [anon_sym_PLUS_EQ] = ACTIONS(160),
    [anon_sym_DASH_EQ] = ACTIONS(160),
    [anon_sym_STAR_EQ] = ACTIONS(160),
    [anon_sym_SLASH_EQ] = ACTIONS(160),
    [anon_sym_PERCENT_EQ] = ACTIONS(160),
    [anon_sym_CARET_EQ] = ACTIONS(160),
    [anon_sym_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_LT_LT_EQ] = ACTIONS(160),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(160),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP] = ACTIONS(120),
    [anon_sym_PIPE_PIPE] = ACTIONS(120),
    [anon_sym_GT_GT] = ACTIONS(120),
    [anon_sym_GT_GT_GT] = ACTIONS(120),
    [anon_sym_LT_LT] = ACTIONS(120),
    [anon_sym_AMP] = ACTIONS(120),
    [anon_sym_CARET] = ACTIONS(120),
    [anon_sym_PIPE] = ACTIONS(120),
    [anon_sym_PLUS] = ACTIONS(120),
    [anon_sym_DASH] = ACTIONS(120),
    [anon_sym_SLASH] = ACTIONS(120),
    [anon_sym_PERCENT] = ACTIONS(120),
    [anon_sym_STAR_STAR] = ACTIONS(120),
    [anon_sym_LT] = ACTIONS(2158),
    [anon_sym_LT_EQ] = ACTIONS(154),
    [anon_sym_EQ_EQ] = ACTIONS(120),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(154),
    [anon_sym_BANG_EQ] = ACTIONS(120),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(154),
    [anon_sym_GT_EQ] = ACTIONS(154),
    [anon_sym_GT] = ACTIONS(120),
    [anon_sym_QMARK_QMARK] = ACTIONS(120),
    [anon_sym_instanceof] = ACTIONS(120),
    [anon_sym_PLUS_PLUS] = ACTIONS(154),
    [anon_sym_DASH_DASH] = ACTIONS(154),
    [anon_sym_DQUOTE] = ACTIONS(1975),
    [anon_sym_SQUOTE] = ACTIONS(1975),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(154),
    [sym_number] = ACTIONS(1975),
    [sym_private_property_identifier] = ACTIONS(1975),
    [anon_sym_static] = ACTIONS(1973),
    [anon_sym_readonly] = ACTIONS(1973),
    [anon_sym_get] = ACTIONS(1973),
    [anon_sym_set] = ACTIONS(1973),
    [anon_sym_QMARK] = ACTIONS(690),
    [anon_sym_declare] = ACTIONS(1973),
    [anon_sym_public] = ACTIONS(1973),
    [anon_sym_private] = ACTIONS(1973),
    [anon_sym_protected] = ACTIONS(1973),
    [anon_sym_override] = ACTIONS(1973),
    [anon_sym_module] = ACTIONS(1973),
    [anon_sym_any] = ACTIONS(1973),
    [anon_sym_number] = ACTIONS(1973),
    [anon_sym_boolean] = ACTIONS(1973),
    [anon_sym_string] = ACTIONS(1973),
    [anon_sym_symbol] = ACTIONS(1973),
    [anon_sym_object] = ACTIONS(1973),
    [anon_sym_satisfies] = ACTIONS(120),
    [sym__automatic_semicolon] = ACTIONS(154),
    [sym__ternary_qmark] = ACTIONS(154),
    [sym_html_comment] = ACTIONS(5),
  },
  [719] = {
    [aux_sym_object_repeat1] = STATE(4810),
    [aux_sym_object_pattern_repeat1] = STATE(4815),
    [sym_identifier] = ACTIONS(1973),
    [anon_sym_export] = ACTIONS(1973),
    [anon_sym_STAR] = ACTIONS(1973),
    [anon_sym_type] = ACTIONS(1973),
    [anon_sym_EQ] = ACTIONS(661),
    [anon_sym_as] = ACTIONS(120),
    [anon_sym_namespace] = ACTIONS(1973),
    [anon_sym_COMMA] = ACTIONS(154),
    [anon_sym_RBRACE] = ACTIONS(692),
    [anon_sym_let] = ACTIONS(1973),
    [anon_sym_BANG] = ACTIONS(120),
    [anon_sym_LPAREN] = ACTIONS(2149),
    [anon_sym_SEMI] = ACTIONS(154),
    [anon_sym_in] = ACTIONS(120),
    [anon_sym_COLON] = ACTIONS(671),
    [anon_sym_LBRACK] = ACTIONS(1975),
    [anon_sym_DOT] = ACTIONS(120),
    [anon_sym_async] = ACTIONS(1973),
    [anon_sym_EQ_GT] = ACTIONS(682),
    [anon_sym_QMARK_DOT] = ACTIONS(154),
    [anon_sym_new] = ACTIONS(1973),
    [anon_sym_PLUS_EQ] = ACTIONS(160),
    [anon_sym_DASH_EQ] = ACTIONS(160),
    [anon_sym_STAR_EQ] = ACTIONS(160),
    [anon_sym_SLASH_EQ] = ACTIONS(160),
    [anon_sym_PERCENT_EQ] = ACTIONS(160),
    [anon_sym_CARET_EQ] = ACTIONS(160),
    [anon_sym_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_LT_LT_EQ] = ACTIONS(160),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(160),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP] = ACTIONS(120),
    [anon_sym_PIPE_PIPE] = ACTIONS(120),
    [anon_sym_GT_GT] = ACTIONS(120),
    [anon_sym_GT_GT_GT] = ACTIONS(120),
    [anon_sym_LT_LT] = ACTIONS(120),
    [anon_sym_AMP] = ACTIONS(120),
    [anon_sym_CARET] = ACTIONS(120),
    [anon_sym_PIPE] = ACTIONS(120),
    [anon_sym_PLUS] = ACTIONS(120),
    [anon_sym_DASH] = ACTIONS(120),
    [anon_sym_SLASH] = ACTIONS(120),
    [anon_sym_PERCENT] = ACTIONS(120),
    [anon_sym_STAR_STAR] = ACTIONS(120),
    [anon_sym_LT] = ACTIONS(2158),
    [anon_sym_LT_EQ] = ACTIONS(154),
    [anon_sym_EQ_EQ] = ACTIONS(120),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(154),
    [anon_sym_BANG_EQ] = ACTIONS(120),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(154),
    [anon_sym_GT_EQ] = ACTIONS(154),
    [anon_sym_GT] = ACTIONS(120),
    [anon_sym_QMARK_QMARK] = ACTIONS(120),
    [anon_sym_instanceof] = ACTIONS(120),
    [anon_sym_PLUS_PLUS] = ACTIONS(154),
    [anon_sym_DASH_DASH] = ACTIONS(154),
    [anon_sym_DQUOTE] = ACTIONS(1975),
    [anon_sym_SQUOTE] = ACTIONS(1975),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(154),
    [sym_number] = ACTIONS(1975),
    [sym_private_property_identifier] = ACTIONS(1975),
    [anon_sym_static] = ACTIONS(1973),
    [anon_sym_readonly] = ACTIONS(1973),
    [anon_sym_get] = ACTIONS(1973),
    [anon_sym_set] = ACTIONS(1973),
    [anon_sym_QMARK] = ACTIONS(690),
    [anon_sym_declare] = ACTIONS(1973),
    [anon_sym_public] = ACTIONS(1973),
    [anon_sym_private] = ACTIONS(1973),
    [anon_sym_protected] = ACTIONS(1973),
    [anon_sym_override] = ACTIONS(1973),
    [anon_sym_module] = ACTIONS(1973),
    [anon_sym_any] = ACTIONS(1973),
    [anon_sym_number] = ACTIONS(1973),
    [anon_sym_boolean] = ACTIONS(1973),
    [anon_sym_string] = ACTIONS(1973),
    [anon_sym_symbol] = ACTIONS(1973),
    [anon_sym_object] = ACTIONS(1973),
    [anon_sym_satisfies] = ACTIONS(120),
    [sym__automatic_semicolon] = ACTIONS(154),
    [sym__ternary_qmark] = ACTIONS(154),
    [sym_html_comment] = ACTIONS(5),
  },
  [720] = {
    [sym_declaration] = STATE(4310),
    [sym_variable_declaration] = STATE(4275),
    [sym_lexical_declaration] = STATE(4275),
    [sym_class_declaration] = STATE(4275),
    [sym_function_declaration] = STATE(4275),
    [sym_generator_function_declaration] = STATE(4275),
    [sym_decorator] = STATE(1344),
    [sym_function_signature] = STATE(4275),
    [sym_ambient_declaration] = STATE(4275),
    [sym_abstract_class_declaration] = STATE(4275),
    [sym_module] = STATE(4275),
    [sym_internal_module] = STATE(4287),
    [sym_import_alias] = STATE(4275),
    [sym_interface_declaration] = STATE(4275),
    [sym_enum_declaration] = STATE(4275),
    [sym_type_alias_declaration] = STATE(4275),
    [aux_sym_export_statement_repeat1] = STATE(4304),
    [anon_sym_STAR] = ACTIONS(120),
    [anon_sym_type] = ACTIONS(2381),
    [anon_sym_EQ] = ACTIONS(918),
    [anon_sym_as] = ACTIONS(120),
    [anon_sym_namespace] = ACTIONS(2383),
    [anon_sym_import] = ACTIONS(2385),
    [anon_sym_var] = ACTIONS(2387),
    [anon_sym_let] = ACTIONS(2389),
    [anon_sym_const] = ACTIONS(2391),
    [anon_sym_BANG] = ACTIONS(120),
    [anon_sym_LPAREN] = ACTIONS(154),
    [anon_sym_SEMI] = ACTIONS(154),
    [anon_sym_in] = ACTIONS(120),
    [anon_sym_LBRACK] = ACTIONS(154),
    [anon_sym_DOT] = ACTIONS(154),
    [anon_sym_class] = ACTIONS(2393),
    [anon_sym_async] = ACTIONS(2395),
    [anon_sym_function] = ACTIONS(2397),
    [anon_sym_EQ_GT] = ACTIONS(924),
    [anon_sym_QMARK_DOT] = ACTIONS(154),
    [anon_sym_PLUS_EQ] = ACTIONS(160),
    [anon_sym_DASH_EQ] = ACTIONS(160),
    [anon_sym_STAR_EQ] = ACTIONS(160),
    [anon_sym_SLASH_EQ] = ACTIONS(160),
    [anon_sym_PERCENT_EQ] = ACTIONS(160),
    [anon_sym_CARET_EQ] = ACTIONS(160),
    [anon_sym_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_LT_LT_EQ] = ACTIONS(160),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(160),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP] = ACTIONS(120),
    [anon_sym_PIPE_PIPE] = ACTIONS(120),
    [anon_sym_GT_GT] = ACTIONS(120),
    [anon_sym_GT_GT_GT] = ACTIONS(120),
    [anon_sym_LT_LT] = ACTIONS(120),
    [anon_sym_AMP] = ACTIONS(120),
    [anon_sym_CARET] = ACTIONS(120),
    [anon_sym_PIPE] = ACTIONS(120),
    [anon_sym_PLUS] = ACTIONS(120),
    [anon_sym_DASH] = ACTIONS(120),
    [anon_sym_SLASH] = ACTIONS(120),
    [anon_sym_PERCENT] = ACTIONS(120),
    [anon_sym_STAR_STAR] = ACTIONS(120),
    [anon_sym_LT] = ACTIONS(120),
    [anon_sym_LT_EQ] = ACTIONS(154),
    [anon_sym_EQ_EQ] = ACTIONS(120),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(154),
    [anon_sym_BANG_EQ] = ACTIONS(120),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(154),
    [anon_sym_GT_EQ] = ACTIONS(154),
    [anon_sym_GT] = ACTIONS(120),
    [anon_sym_QMARK_QMARK] = ACTIONS(120),
    [anon_sym_instanceof] = ACTIONS(154),
    [anon_sym_PLUS_PLUS] = ACTIONS(154),
    [anon_sym_DASH_DASH] = ACTIONS(154),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(154),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_declare] = ACTIONS(2399),
    [anon_sym_module] = ACTIONS(2401),
    [anon_sym_abstract] = ACTIONS(2403),
    [anon_sym_satisfies] = ACTIONS(154),
    [anon_sym_global] = ACTIONS(2405),
    [anon_sym_interface] = ACTIONS(2407),
    [anon_sym_enum] = ACTIONS(2409),
    [sym__automatic_semicolon] = ACTIONS(154),
    [sym__ternary_qmark] = ACTIONS(154),
    [sym_html_comment] = ACTIONS(5),
  },
  [721] = {
    [sym_declaration] = STATE(867),
    [sym_variable_declaration] = STATE(831),
    [sym_lexical_declaration] = STATE(831),
    [sym_class_declaration] = STATE(831),
    [sym_function_declaration] = STATE(831),
    [sym_generator_function_declaration] = STATE(831),
    [sym_decorator] = STATE(1344),
    [sym_function_signature] = STATE(831),
    [sym_ambient_declaration] = STATE(831),
    [sym_abstract_class_declaration] = STATE(831),
    [sym_module] = STATE(831),
    [sym_internal_module] = STATE(824),
    [sym_import_alias] = STATE(831),
    [sym_interface_declaration] = STATE(831),
    [sym_enum_declaration] = STATE(831),
    [sym_type_alias_declaration] = STATE(831),
    [aux_sym_export_statement_repeat1] = STATE(4301),
    [anon_sym_STAR] = ACTIONS(120),
    [anon_sym_type] = ACTIONS(2341),
    [anon_sym_EQ] = ACTIONS(918),
    [anon_sym_as] = ACTIONS(120),
    [anon_sym_namespace] = ACTIONS(2137),
    [anon_sym_import] = ACTIONS(2141),
    [anon_sym_var] = ACTIONS(2143),
    [anon_sym_let] = ACTIONS(2145),
    [anon_sym_const] = ACTIONS(2147),
    [anon_sym_BANG] = ACTIONS(120),
    [anon_sym_LPAREN] = ACTIONS(154),
    [anon_sym_SEMI] = ACTIONS(154),
    [anon_sym_in] = ACTIONS(120),
    [anon_sym_LBRACK] = ACTIONS(154),
    [anon_sym_DOT] = ACTIONS(154),
    [anon_sym_class] = ACTIONS(2152),
    [anon_sym_async] = ACTIONS(2154),
    [anon_sym_function] = ACTIONS(2156),
    [anon_sym_EQ_GT] = ACTIONS(924),
    [anon_sym_QMARK_DOT] = ACTIONS(154),
    [anon_sym_PLUS_EQ] = ACTIONS(160),
    [anon_sym_DASH_EQ] = ACTIONS(160),
    [anon_sym_STAR_EQ] = ACTIONS(160),
    [anon_sym_SLASH_EQ] = ACTIONS(160),
    [anon_sym_PERCENT_EQ] = ACTIONS(160),
    [anon_sym_CARET_EQ] = ACTIONS(160),
    [anon_sym_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_LT_LT_EQ] = ACTIONS(160),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(160),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP] = ACTIONS(120),
    [anon_sym_PIPE_PIPE] = ACTIONS(120),
    [anon_sym_GT_GT] = ACTIONS(120),
    [anon_sym_GT_GT_GT] = ACTIONS(120),
    [anon_sym_LT_LT] = ACTIONS(120),
    [anon_sym_AMP] = ACTIONS(120),
    [anon_sym_CARET] = ACTIONS(120),
    [anon_sym_PIPE] = ACTIONS(120),
    [anon_sym_PLUS] = ACTIONS(120),
    [anon_sym_DASH] = ACTIONS(120),
    [anon_sym_SLASH] = ACTIONS(120),
    [anon_sym_PERCENT] = ACTIONS(120),
    [anon_sym_STAR_STAR] = ACTIONS(120),
    [anon_sym_LT] = ACTIONS(120),
    [anon_sym_LT_EQ] = ACTIONS(154),
    [anon_sym_EQ_EQ] = ACTIONS(120),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(154),
    [anon_sym_BANG_EQ] = ACTIONS(120),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(154),
    [anon_sym_GT_EQ] = ACTIONS(154),
    [anon_sym_GT] = ACTIONS(120),
    [anon_sym_QMARK_QMARK] = ACTIONS(120),
    [anon_sym_instanceof] = ACTIONS(154),
    [anon_sym_PLUS_PLUS] = ACTIONS(154),
    [anon_sym_DASH_DASH] = ACTIONS(154),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(154),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_declare] = ACTIONS(2161),
    [anon_sym_module] = ACTIONS(2343),
    [anon_sym_abstract] = ACTIONS(2165),
    [anon_sym_satisfies] = ACTIONS(154),
    [anon_sym_global] = ACTIONS(2345),
    [anon_sym_interface] = ACTIONS(2167),
    [anon_sym_enum] = ACTIONS(2169),
    [sym__automatic_semicolon] = ACTIONS(154),
    [sym__ternary_qmark] = ACTIONS(154),
    [sym_html_comment] = ACTIONS(5),
  },
  [722] = {
    [aux_sym_object_repeat1] = STATE(4792),
    [aux_sym_object_pattern_repeat1] = STATE(4815),
    [sym_identifier] = ACTIONS(1969),
    [anon_sym_export] = ACTIONS(1969),
    [anon_sym_STAR] = ACTIONS(1969),
    [anon_sym_type] = ACTIONS(1969),
    [anon_sym_EQ] = ACTIONS(661),
    [anon_sym_as] = ACTIONS(120),
    [anon_sym_namespace] = ACTIONS(1969),
    [anon_sym_COMMA] = ACTIONS(154),
    [anon_sym_RBRACE] = ACTIONS(694),
    [anon_sym_let] = ACTIONS(1969),
    [anon_sym_BANG] = ACTIONS(120),
    [anon_sym_LPAREN] = ACTIONS(2149),
    [anon_sym_SEMI] = ACTIONS(154),
    [anon_sym_in] = ACTIONS(120),
    [anon_sym_COLON] = ACTIONS(671),
    [anon_sym_LBRACK] = ACTIONS(1971),
    [anon_sym_DOT] = ACTIONS(120),
    [anon_sym_async] = ACTIONS(1969),
    [anon_sym_EQ_GT] = ACTIONS(682),
    [anon_sym_QMARK_DOT] = ACTIONS(154),
    [anon_sym_new] = ACTIONS(1969),
    [anon_sym_PLUS_EQ] = ACTIONS(160),
    [anon_sym_DASH_EQ] = ACTIONS(160),
    [anon_sym_STAR_EQ] = ACTIONS(160),
    [anon_sym_SLASH_EQ] = ACTIONS(160),
    [anon_sym_PERCENT_EQ] = ACTIONS(160),
    [anon_sym_CARET_EQ] = ACTIONS(160),
    [anon_sym_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_LT_LT_EQ] = ACTIONS(160),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(160),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP] = ACTIONS(120),
    [anon_sym_PIPE_PIPE] = ACTIONS(120),
    [anon_sym_GT_GT] = ACTIONS(120),
    [anon_sym_GT_GT_GT] = ACTIONS(120),
    [anon_sym_LT_LT] = ACTIONS(120),
    [anon_sym_AMP] = ACTIONS(120),
    [anon_sym_CARET] = ACTIONS(120),
    [anon_sym_PIPE] = ACTIONS(120),
    [anon_sym_PLUS] = ACTIONS(120),
    [anon_sym_DASH] = ACTIONS(120),
    [anon_sym_SLASH] = ACTIONS(120),
    [anon_sym_PERCENT] = ACTIONS(120),
    [anon_sym_STAR_STAR] = ACTIONS(120),
    [anon_sym_LT] = ACTIONS(2158),
    [anon_sym_LT_EQ] = ACTIONS(154),
    [anon_sym_EQ_EQ] = ACTIONS(120),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(154),
    [anon_sym_BANG_EQ] = ACTIONS(120),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(154),
    [anon_sym_GT_EQ] = ACTIONS(154),
    [anon_sym_GT] = ACTIONS(120),
    [anon_sym_QMARK_QMARK] = ACTIONS(120),
    [anon_sym_instanceof] = ACTIONS(120),
    [anon_sym_PLUS_PLUS] = ACTIONS(154),
    [anon_sym_DASH_DASH] = ACTIONS(154),
    [anon_sym_DQUOTE] = ACTIONS(1971),
    [anon_sym_SQUOTE] = ACTIONS(1971),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(154),
    [sym_number] = ACTIONS(1971),
    [sym_private_property_identifier] = ACTIONS(1971),
    [anon_sym_static] = ACTIONS(1969),
    [anon_sym_readonly] = ACTIONS(1969),
    [anon_sym_get] = ACTIONS(1969),
    [anon_sym_set] = ACTIONS(1969),
    [anon_sym_QMARK] = ACTIONS(690),
    [anon_sym_declare] = ACTIONS(1969),
    [anon_sym_public] = ACTIONS(1969),
    [anon_sym_private] = ACTIONS(1969),
    [anon_sym_protected] = ACTIONS(1969),
    [anon_sym_override] = ACTIONS(1969),
    [anon_sym_module] = ACTIONS(1969),
    [anon_sym_any] = ACTIONS(1969),
    [anon_sym_number] = ACTIONS(1969),
    [anon_sym_boolean] = ACTIONS(1969),
    [anon_sym_string] = ACTIONS(1969),
    [anon_sym_symbol] = ACTIONS(1969),
    [anon_sym_object] = ACTIONS(1969),
    [anon_sym_satisfies] = ACTIONS(120),
    [sym__automatic_semicolon] = ACTIONS(154),
    [sym__ternary_qmark] = ACTIONS(154),
    [sym_html_comment] = ACTIONS(5),
  },
  [723] = {
    [aux_sym_object_repeat1] = STATE(4792),
    [aux_sym_object_pattern_repeat1] = STATE(4815),
    [sym_identifier] = ACTIONS(1973),
    [anon_sym_export] = ACTIONS(1973),
    [anon_sym_STAR] = ACTIONS(1973),
    [anon_sym_type] = ACTIONS(1973),
    [anon_sym_EQ] = ACTIONS(661),
    [anon_sym_as] = ACTIONS(120),
    [anon_sym_namespace] = ACTIONS(1973),
    [anon_sym_COMMA] = ACTIONS(154),
    [anon_sym_RBRACE] = ACTIONS(694),
    [anon_sym_let] = ACTIONS(1973),
    [anon_sym_BANG] = ACTIONS(120),
    [anon_sym_LPAREN] = ACTIONS(2149),
    [anon_sym_SEMI] = ACTIONS(154),
    [anon_sym_in] = ACTIONS(120),
    [anon_sym_COLON] = ACTIONS(671),
    [anon_sym_LBRACK] = ACTIONS(1975),
    [anon_sym_DOT] = ACTIONS(120),
    [anon_sym_async] = ACTIONS(1973),
    [anon_sym_EQ_GT] = ACTIONS(682),
    [anon_sym_QMARK_DOT] = ACTIONS(154),
    [anon_sym_new] = ACTIONS(1973),
    [anon_sym_PLUS_EQ] = ACTIONS(160),
    [anon_sym_DASH_EQ] = ACTIONS(160),
    [anon_sym_STAR_EQ] = ACTIONS(160),
    [anon_sym_SLASH_EQ] = ACTIONS(160),
    [anon_sym_PERCENT_EQ] = ACTIONS(160),
    [anon_sym_CARET_EQ] = ACTIONS(160),
    [anon_sym_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_LT_LT_EQ] = ACTIONS(160),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(160),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP] = ACTIONS(120),
    [anon_sym_PIPE_PIPE] = ACTIONS(120),
    [anon_sym_GT_GT] = ACTIONS(120),
    [anon_sym_GT_GT_GT] = ACTIONS(120),
    [anon_sym_LT_LT] = ACTIONS(120),
    [anon_sym_AMP] = ACTIONS(120),
    [anon_sym_CARET] = ACTIONS(120),
    [anon_sym_PIPE] = ACTIONS(120),
    [anon_sym_PLUS] = ACTIONS(120),
    [anon_sym_DASH] = ACTIONS(120),
    [anon_sym_SLASH] = ACTIONS(120),
    [anon_sym_PERCENT] = ACTIONS(120),
    [anon_sym_STAR_STAR] = ACTIONS(120),
    [anon_sym_LT] = ACTIONS(2158),
    [anon_sym_LT_EQ] = ACTIONS(154),
    [anon_sym_EQ_EQ] = ACTIONS(120),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(154),
    [anon_sym_BANG_EQ] = ACTIONS(120),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(154),
    [anon_sym_GT_EQ] = ACTIONS(154),
    [anon_sym_GT] = ACTIONS(120),
    [anon_sym_QMARK_QMARK] = ACTIONS(120),
    [anon_sym_instanceof] = ACTIONS(120),
    [anon_sym_PLUS_PLUS] = ACTIONS(154),
    [anon_sym_DASH_DASH] = ACTIONS(154),
    [anon_sym_DQUOTE] = ACTIONS(1975),
    [anon_sym_SQUOTE] = ACTIONS(1975),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(154),
    [sym_number] = ACTIONS(1975),
    [sym_private_property_identifier] = ACTIONS(1975),
    [anon_sym_static] = ACTIONS(1973),
    [anon_sym_readonly] = ACTIONS(1973),
    [anon_sym_get] = ACTIONS(1973),
    [anon_sym_set] = ACTIONS(1973),
    [anon_sym_QMARK] = ACTIONS(690),
    [anon_sym_declare] = ACTIONS(1973),
    [anon_sym_public] = ACTIONS(1973),
    [anon_sym_private] = ACTIONS(1973),
    [anon_sym_protected] = ACTIONS(1973),
    [anon_sym_override] = ACTIONS(1973),
    [anon_sym_module] = ACTIONS(1973),
    [anon_sym_any] = ACTIONS(1973),
    [anon_sym_number] = ACTIONS(1973),
    [anon_sym_boolean] = ACTIONS(1973),
    [anon_sym_string] = ACTIONS(1973),
    [anon_sym_symbol] = ACTIONS(1973),
    [anon_sym_object] = ACTIONS(1973),
    [anon_sym_satisfies] = ACTIONS(120),
    [sym__automatic_semicolon] = ACTIONS(154),
    [sym__ternary_qmark] = ACTIONS(154),
    [sym_html_comment] = ACTIONS(5),
  },
  [724] = {
    [sym__call_signature] = STATE(5834),
    [sym_formal_parameters] = STATE(3806),
    [sym_type_parameters] = STATE(5328),
    [sym_identifier] = ACTIONS(2411),
    [anon_sym_export] = ACTIONS(2413),
    [anon_sym_STAR] = ACTIONS(120),
    [anon_sym_type] = ACTIONS(2413),
    [anon_sym_EQ] = ACTIONS(824),
    [anon_sym_as] = ACTIONS(120),
    [anon_sym_namespace] = ACTIONS(2413),
    [anon_sym_COMMA] = ACTIONS(826),
    [anon_sym_RBRACE] = ACTIONS(826),
    [anon_sym_let] = ACTIONS(2413),
    [anon_sym_BANG] = ACTIONS(120),
    [anon_sym_LPAREN] = ACTIONS(2415),
    [anon_sym_RPAREN] = ACTIONS(826),
    [anon_sym_in] = ACTIONS(120),
    [anon_sym_COLON] = ACTIONS(826),
    [anon_sym_LBRACK] = ACTIONS(154),
    [anon_sym_RBRACK] = ACTIONS(826),
    [anon_sym_DOT] = ACTIONS(154),
    [anon_sym_async] = ACTIONS(2413),
    [anon_sym_function] = ACTIONS(2418),
    [anon_sym_EQ_GT] = ACTIONS(225),
    [anon_sym_QMARK_DOT] = ACTIONS(154),
    [anon_sym_new] = ACTIONS(2413),
    [anon_sym_PLUS_EQ] = ACTIONS(160),
    [anon_sym_DASH_EQ] = ACTIONS(160),
    [anon_sym_STAR_EQ] = ACTIONS(160),
    [anon_sym_SLASH_EQ] = ACTIONS(160),
    [anon_sym_PERCENT_EQ] = ACTIONS(160),
    [anon_sym_CARET_EQ] = ACTIONS(160),
    [anon_sym_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_LT_LT_EQ] = ACTIONS(160),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(160),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP] = ACTIONS(120),
    [anon_sym_PIPE_PIPE] = ACTIONS(120),
    [anon_sym_GT_GT] = ACTIONS(120),
    [anon_sym_GT_GT_GT] = ACTIONS(120),
    [anon_sym_LT_LT] = ACTIONS(120),
    [anon_sym_AMP] = ACTIONS(120),
    [anon_sym_CARET] = ACTIONS(120),
    [anon_sym_PIPE] = ACTIONS(120),
    [anon_sym_PLUS] = ACTIONS(120),
    [anon_sym_DASH] = ACTIONS(120),
    [anon_sym_SLASH] = ACTIONS(120),
    [anon_sym_PERCENT] = ACTIONS(120),
    [anon_sym_STAR_STAR] = ACTIONS(120),
    [anon_sym_LT] = ACTIONS(2420),
    [anon_sym_LT_EQ] = ACTIONS(154),
    [anon_sym_EQ_EQ] = ACTIONS(120),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(154),
    [anon_sym_BANG_EQ] = ACTIONS(120),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(154),
    [anon_sym_GT_EQ] = ACTIONS(154),
    [anon_sym_GT] = ACTIONS(120),
    [anon_sym_QMARK_QMARK] = ACTIONS(120),
    [anon_sym_instanceof] = ACTIONS(120),
    [anon_sym_PLUS_PLUS] = ACTIONS(154),
    [anon_sym_DASH_DASH] = ACTIONS(154),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(154),
    [anon_sym_static] = ACTIONS(2413),
    [anon_sym_readonly] = ACTIONS(2413),
    [anon_sym_get] = ACTIONS(2413),
    [anon_sym_set] = ACTIONS(2413),
    [anon_sym_QMARK] = ACTIONS(828),
    [anon_sym_declare] = ACTIONS(2413),
    [anon_sym_public] = ACTIONS(2413),
    [anon_sym_private] = ACTIONS(2413),
    [anon_sym_protected] = ACTIONS(2413),
    [anon_sym_override] = ACTIONS(2413),
    [anon_sym_module] = ACTIONS(2413),
    [anon_sym_any] = ACTIONS(2413),
    [anon_sym_number] = ACTIONS(2413),
    [anon_sym_boolean] = ACTIONS(2413),
    [anon_sym_string] = ACTIONS(2413),
    [anon_sym_symbol] = ACTIONS(2413),
    [anon_sym_object] = ACTIONS(2413),
    [anon_sym_satisfies] = ACTIONS(120),
    [sym__ternary_qmark] = ACTIONS(154),
    [sym_html_comment] = ACTIONS(5),
  },
  [725] = {
    [sym__call_signature] = STATE(5834),
    [sym_formal_parameters] = STATE(3806),
    [sym_type_parameters] = STATE(5328),
    [sym_identifier] = ACTIONS(2411),
    [anon_sym_export] = ACTIONS(2413),
    [anon_sym_STAR] = ACTIONS(120),
    [anon_sym_type] = ACTIONS(2413),
    [anon_sym_EQ] = ACTIONS(220),
    [anon_sym_as] = ACTIONS(120),
    [anon_sym_namespace] = ACTIONS(2413),
    [anon_sym_COMMA] = ACTIONS(223),
    [anon_sym_RBRACE] = ACTIONS(223),
    [anon_sym_let] = ACTIONS(2413),
    [anon_sym_BANG] = ACTIONS(120),
    [anon_sym_LPAREN] = ACTIONS(2415),
    [anon_sym_RPAREN] = ACTIONS(223),
    [anon_sym_in] = ACTIONS(120),
    [anon_sym_COLON] = ACTIONS(223),
    [anon_sym_LBRACK] = ACTIONS(154),
    [anon_sym_RBRACK] = ACTIONS(223),
    [anon_sym_DOT] = ACTIONS(154),
    [anon_sym_async] = ACTIONS(2413),
    [anon_sym_function] = ACTIONS(2418),
    [anon_sym_EQ_GT] = ACTIONS(225),
    [anon_sym_QMARK_DOT] = ACTIONS(154),
    [anon_sym_new] = ACTIONS(2413),
    [anon_sym_PLUS_EQ] = ACTIONS(160),
    [anon_sym_DASH_EQ] = ACTIONS(160),
    [anon_sym_STAR_EQ] = ACTIONS(160),
    [anon_sym_SLASH_EQ] = ACTIONS(160),
    [anon_sym_PERCENT_EQ] = ACTIONS(160),
    [anon_sym_CARET_EQ] = ACTIONS(160),
    [anon_sym_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_LT_LT_EQ] = ACTIONS(160),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(160),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP] = ACTIONS(120),
    [anon_sym_PIPE_PIPE] = ACTIONS(120),
    [anon_sym_GT_GT] = ACTIONS(120),
    [anon_sym_GT_GT_GT] = ACTIONS(120),
    [anon_sym_LT_LT] = ACTIONS(120),
    [anon_sym_AMP] = ACTIONS(120),
    [anon_sym_CARET] = ACTIONS(120),
    [anon_sym_PIPE] = ACTIONS(120),
    [anon_sym_PLUS] = ACTIONS(120),
    [anon_sym_DASH] = ACTIONS(120),
    [anon_sym_SLASH] = ACTIONS(120),
    [anon_sym_PERCENT] = ACTIONS(120),
    [anon_sym_STAR_STAR] = ACTIONS(120),
    [anon_sym_LT] = ACTIONS(2420),
    [anon_sym_LT_EQ] = ACTIONS(154),
    [anon_sym_EQ_EQ] = ACTIONS(120),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(154),
    [anon_sym_BANG_EQ] = ACTIONS(120),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(154),
    [anon_sym_GT_EQ] = ACTIONS(154),
    [anon_sym_GT] = ACTIONS(120),
    [anon_sym_QMARK_QMARK] = ACTIONS(120),
    [anon_sym_instanceof] = ACTIONS(120),
    [anon_sym_PLUS_PLUS] = ACTIONS(154),
    [anon_sym_DASH_DASH] = ACTIONS(154),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(154),
    [anon_sym_static] = ACTIONS(2413),
    [anon_sym_readonly] = ACTIONS(2413),
    [anon_sym_get] = ACTIONS(2413),
    [anon_sym_set] = ACTIONS(2413),
    [anon_sym_QMARK] = ACTIONS(720),
    [anon_sym_declare] = ACTIONS(2413),
    [anon_sym_public] = ACTIONS(2413),
    [anon_sym_private] = ACTIONS(2413),
    [anon_sym_protected] = ACTIONS(2413),
    [anon_sym_override] = ACTIONS(2413),
    [anon_sym_module] = ACTIONS(2413),
    [anon_sym_any] = ACTIONS(2413),
    [anon_sym_number] = ACTIONS(2413),
    [anon_sym_boolean] = ACTIONS(2413),
    [anon_sym_string] = ACTIONS(2413),
    [anon_sym_symbol] = ACTIONS(2413),
    [anon_sym_object] = ACTIONS(2413),
    [anon_sym_satisfies] = ACTIONS(120),
    [sym__ternary_qmark] = ACTIONS(154),
    [sym_html_comment] = ACTIONS(5),
  },
  [726] = {
    [sym__call_signature] = STATE(5594),
    [sym_formal_parameters] = STATE(3806),
    [sym_type_parameters] = STATE(5328),
    [sym_identifier] = ACTIONS(2423),
    [anon_sym_export] = ACTIONS(2425),
    [anon_sym_STAR] = ACTIONS(120),
    [anon_sym_type] = ACTIONS(2425),
    [anon_sym_EQ] = ACTIONS(824),
    [anon_sym_as] = ACTIONS(120),
    [anon_sym_namespace] = ACTIONS(2425),
    [anon_sym_COMMA] = ACTIONS(154),
    [anon_sym_RBRACE] = ACTIONS(154),
    [anon_sym_let] = ACTIONS(2425),
    [anon_sym_BANG] = ACTIONS(120),
    [anon_sym_LPAREN] = ACTIONS(2415),
    [anon_sym_SEMI] = ACTIONS(154),
    [anon_sym_in] = ACTIONS(120),
    [anon_sym_COLON] = ACTIONS(154),
    [anon_sym_LBRACK] = ACTIONS(154),
    [anon_sym_RBRACK] = ACTIONS(154),
    [anon_sym_DOT] = ACTIONS(154),
    [anon_sym_async] = ACTIONS(2425),
    [anon_sym_function] = ACTIONS(2418),
    [anon_sym_EQ_GT] = ACTIONS(844),
    [anon_sym_QMARK_DOT] = ACTIONS(154),
    [anon_sym_new] = ACTIONS(2425),
    [anon_sym_PLUS_EQ] = ACTIONS(160),
    [anon_sym_DASH_EQ] = ACTIONS(160),
    [anon_sym_STAR_EQ] = ACTIONS(160),
    [anon_sym_SLASH_EQ] = ACTIONS(160),
    [anon_sym_PERCENT_EQ] = ACTIONS(160),
    [anon_sym_CARET_EQ] = ACTIONS(160),
    [anon_sym_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_LT_LT_EQ] = ACTIONS(160),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(160),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP] = ACTIONS(120),
    [anon_sym_PIPE_PIPE] = ACTIONS(120),
    [anon_sym_GT_GT] = ACTIONS(120),
    [anon_sym_GT_GT_GT] = ACTIONS(120),
    [anon_sym_LT_LT] = ACTIONS(120),
    [anon_sym_AMP] = ACTIONS(120),
    [anon_sym_CARET] = ACTIONS(120),
    [anon_sym_PIPE] = ACTIONS(120),
    [anon_sym_PLUS] = ACTIONS(120),
    [anon_sym_DASH] = ACTIONS(120),
    [anon_sym_SLASH] = ACTIONS(120),
    [anon_sym_PERCENT] = ACTIONS(120),
    [anon_sym_STAR_STAR] = ACTIONS(120),
    [anon_sym_LT] = ACTIONS(2420),
    [anon_sym_LT_EQ] = ACTIONS(154),
    [anon_sym_EQ_EQ] = ACTIONS(120),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(154),
    [anon_sym_BANG_EQ] = ACTIONS(120),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(154),
    [anon_sym_GT_EQ] = ACTIONS(154),
    [anon_sym_GT] = ACTIONS(120),
    [anon_sym_QMARK_QMARK] = ACTIONS(120),
    [anon_sym_instanceof] = ACTIONS(120),
    [anon_sym_PLUS_PLUS] = ACTIONS(154),
    [anon_sym_DASH_DASH] = ACTIONS(154),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(154),
    [anon_sym_static] = ACTIONS(2425),
    [anon_sym_readonly] = ACTIONS(2425),
    [anon_sym_get] = ACTIONS(2425),
    [anon_sym_set] = ACTIONS(2425),
    [anon_sym_declare] = ACTIONS(2425),
    [anon_sym_public] = ACTIONS(2425),
    [anon_sym_private] = ACTIONS(2425),
    [anon_sym_protected] = ACTIONS(2425),
    [anon_sym_override] = ACTIONS(2425),
    [anon_sym_module] = ACTIONS(2425),
    [anon_sym_any] = ACTIONS(2425),
    [anon_sym_number] = ACTIONS(2425),
    [anon_sym_boolean] = ACTIONS(2425),
    [anon_sym_string] = ACTIONS(2425),
    [anon_sym_symbol] = ACTIONS(2425),
    [anon_sym_object] = ACTIONS(2425),
    [anon_sym_satisfies] = ACTIONS(120),
    [sym__ternary_qmark] = ACTIONS(154),
    [sym_html_comment] = ACTIONS(5),
  },
  [727] = {
    [sym__call_signature] = STATE(5594),
    [sym_formal_parameters] = STATE(3806),
    [sym_type_parameters] = STATE(5328),
    [sym_identifier] = ACTIONS(2423),
    [anon_sym_export] = ACTIONS(2425),
    [anon_sym_STAR] = ACTIONS(120),
    [anon_sym_type] = ACTIONS(2425),
    [anon_sym_EQ] = ACTIONS(834),
    [anon_sym_as] = ACTIONS(120),
    [anon_sym_namespace] = ACTIONS(2425),
    [anon_sym_COMMA] = ACTIONS(154),
    [anon_sym_RBRACE] = ACTIONS(154),
    [anon_sym_let] = ACTIONS(2425),
    [anon_sym_BANG] = ACTIONS(120),
    [anon_sym_LPAREN] = ACTIONS(2415),
    [anon_sym_SEMI] = ACTIONS(154),
    [anon_sym_in] = ACTIONS(120),
    [anon_sym_COLON] = ACTIONS(154),
    [anon_sym_LBRACK] = ACTIONS(154),
    [anon_sym_RBRACK] = ACTIONS(154),
    [anon_sym_DOT] = ACTIONS(154),
    [anon_sym_async] = ACTIONS(2425),
    [anon_sym_function] = ACTIONS(2418),
    [anon_sym_EQ_GT] = ACTIONS(844),
    [anon_sym_QMARK_DOT] = ACTIONS(154),
    [anon_sym_new] = ACTIONS(2425),
    [anon_sym_PLUS_EQ] = ACTIONS(160),
    [anon_sym_DASH_EQ] = ACTIONS(160),
    [anon_sym_STAR_EQ] = ACTIONS(160),
    [anon_sym_SLASH_EQ] = ACTIONS(160),
    [anon_sym_PERCENT_EQ] = ACTIONS(160),
    [anon_sym_CARET_EQ] = ACTIONS(160),
    [anon_sym_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_LT_LT_EQ] = ACTIONS(160),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(160),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP] = ACTIONS(120),
    [anon_sym_PIPE_PIPE] = ACTIONS(120),
    [anon_sym_GT_GT] = ACTIONS(120),
    [anon_sym_GT_GT_GT] = ACTIONS(120),
    [anon_sym_LT_LT] = ACTIONS(120),
    [anon_sym_AMP] = ACTIONS(120),
    [anon_sym_CARET] = ACTIONS(120),
    [anon_sym_PIPE] = ACTIONS(120),
    [anon_sym_PLUS] = ACTIONS(120),
    [anon_sym_DASH] = ACTIONS(120),
    [anon_sym_SLASH] = ACTIONS(120),
    [anon_sym_PERCENT] = ACTIONS(120),
    [anon_sym_STAR_STAR] = ACTIONS(120),
    [anon_sym_LT] = ACTIONS(2420),
    [anon_sym_LT_EQ] = ACTIONS(154),
    [anon_sym_EQ_EQ] = ACTIONS(120),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(154),
    [anon_sym_BANG_EQ] = ACTIONS(120),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(154),
    [anon_sym_GT_EQ] = ACTIONS(154),
    [anon_sym_GT] = ACTIONS(120),
    [anon_sym_QMARK_QMARK] = ACTIONS(120),
    [anon_sym_instanceof] = ACTIONS(120),
    [anon_sym_PLUS_PLUS] = ACTIONS(154),
    [anon_sym_DASH_DASH] = ACTIONS(154),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(154),
    [anon_sym_static] = ACTIONS(2425),
    [anon_sym_readonly] = ACTIONS(2425),
    [anon_sym_get] = ACTIONS(2425),
    [anon_sym_set] = ACTIONS(2425),
    [anon_sym_declare] = ACTIONS(2425),
    [anon_sym_public] = ACTIONS(2425),
    [anon_sym_private] = ACTIONS(2425),
    [anon_sym_protected] = ACTIONS(2425),
    [anon_sym_override] = ACTIONS(2425),
    [anon_sym_module] = ACTIONS(2425),
    [anon_sym_any] = ACTIONS(2425),
    [anon_sym_number] = ACTIONS(2425),
    [anon_sym_boolean] = ACTIONS(2425),
    [anon_sym_string] = ACTIONS(2425),
    [anon_sym_symbol] = ACTIONS(2425),
    [anon_sym_object] = ACTIONS(2425),
    [anon_sym_satisfies] = ACTIONS(120),
    [sym__ternary_qmark] = ACTIONS(154),
    [sym_html_comment] = ACTIONS(5),
  },
  [728] = {
    [sym__call_signature] = STATE(5693),
    [sym_formal_parameters] = STATE(3806),
    [sym_type_parameters] = STATE(5328),
    [sym_identifier] = ACTIONS(2427),
    [anon_sym_export] = ACTIONS(2429),
    [anon_sym_STAR] = ACTIONS(120),
    [anon_sym_type] = ACTIONS(2429),
    [anon_sym_EQ] = ACTIONS(858),
    [anon_sym_as] = ACTIONS(120),
    [anon_sym_namespace] = ACTIONS(2429),
    [anon_sym_COMMA] = ACTIONS(154),
    [anon_sym_let] = ACTIONS(2429),
    [anon_sym_BANG] = ACTIONS(120),
    [anon_sym_LPAREN] = ACTIONS(2415),
    [anon_sym_SEMI] = ACTIONS(154),
    [anon_sym_in] = ACTIONS(120),
    [anon_sym_COLON] = ACTIONS(860),
    [anon_sym_LBRACK] = ACTIONS(154),
    [anon_sym_DOT] = ACTIONS(154),
    [anon_sym_async] = ACTIONS(2429),
    [anon_sym_function] = ACTIONS(2331),
    [anon_sym_EQ_GT] = ACTIONS(682),
    [anon_sym_QMARK_DOT] = ACTIONS(154),
    [anon_sym_new] = ACTIONS(2429),
    [anon_sym_PLUS_EQ] = ACTIONS(160),
    [anon_sym_DASH_EQ] = ACTIONS(160),
    [anon_sym_STAR_EQ] = ACTIONS(160),
    [anon_sym_SLASH_EQ] = ACTIONS(160),
    [anon_sym_PERCENT_EQ] = ACTIONS(160),
    [anon_sym_CARET_EQ] = ACTIONS(160),
    [anon_sym_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_LT_LT_EQ] = ACTIONS(160),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(160),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP] = ACTIONS(120),
    [anon_sym_PIPE_PIPE] = ACTIONS(120),
    [anon_sym_GT_GT] = ACTIONS(120),
    [anon_sym_GT_GT_GT] = ACTIONS(120),
    [anon_sym_LT_LT] = ACTIONS(120),
    [anon_sym_AMP] = ACTIONS(120),
    [anon_sym_CARET] = ACTIONS(120),
    [anon_sym_PIPE] = ACTIONS(120),
    [anon_sym_PLUS] = ACTIONS(120),
    [anon_sym_DASH] = ACTIONS(120),
    [anon_sym_SLASH] = ACTIONS(120),
    [anon_sym_PERCENT] = ACTIONS(120),
    [anon_sym_STAR_STAR] = ACTIONS(120),
    [anon_sym_LT] = ACTIONS(2420),
    [anon_sym_LT_EQ] = ACTIONS(154),
    [anon_sym_EQ_EQ] = ACTIONS(120),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(154),
    [anon_sym_BANG_EQ] = ACTIONS(120),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(154),
    [anon_sym_GT_EQ] = ACTIONS(154),
    [anon_sym_GT] = ACTIONS(120),
    [anon_sym_QMARK_QMARK] = ACTIONS(120),
    [anon_sym_instanceof] = ACTIONS(120),
    [anon_sym_PLUS_PLUS] = ACTIONS(154),
    [anon_sym_DASH_DASH] = ACTIONS(154),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(154),
    [anon_sym_static] = ACTIONS(2429),
    [anon_sym_readonly] = ACTIONS(2429),
    [anon_sym_get] = ACTIONS(2429),
    [anon_sym_set] = ACTIONS(2429),
    [anon_sym_declare] = ACTIONS(2429),
    [anon_sym_public] = ACTIONS(2429),
    [anon_sym_private] = ACTIONS(2429),
    [anon_sym_protected] = ACTIONS(2429),
    [anon_sym_override] = ACTIONS(2429),
    [anon_sym_module] = ACTIONS(2429),
    [anon_sym_any] = ACTIONS(2429),
    [anon_sym_number] = ACTIONS(2429),
    [anon_sym_boolean] = ACTIONS(2429),
    [anon_sym_string] = ACTIONS(2429),
    [anon_sym_symbol] = ACTIONS(2429),
    [anon_sym_object] = ACTIONS(2429),
    [anon_sym_satisfies] = ACTIONS(120),
    [sym__automatic_semicolon] = ACTIONS(154),
    [sym__ternary_qmark] = ACTIONS(154),
    [sym_html_comment] = ACTIONS(5),
  },
  [729] = {
    [sym__call_signature] = STATE(5693),
    [sym_formal_parameters] = STATE(3806),
    [sym_type_parameters] = STATE(5328),
    [sym_identifier] = ACTIONS(2427),
    [anon_sym_export] = ACTIONS(2429),
    [anon_sym_STAR] = ACTIONS(120),
    [anon_sym_type] = ACTIONS(2429),
    [anon_sym_EQ] = ACTIONS(858),
    [anon_sym_as] = ACTIONS(120),
    [anon_sym_namespace] = ACTIONS(2429),
    [anon_sym_COMMA] = ACTIONS(154),
    [anon_sym_let] = ACTIONS(2429),
    [anon_sym_BANG] = ACTIONS(120),
    [anon_sym_LPAREN] = ACTIONS(2415),
    [anon_sym_SEMI] = ACTIONS(154),
    [anon_sym_in] = ACTIONS(120),
    [anon_sym_COLON] = ACTIONS(878),
    [anon_sym_LBRACK] = ACTIONS(154),
    [anon_sym_DOT] = ACTIONS(154),
    [anon_sym_async] = ACTIONS(2429),
    [anon_sym_function] = ACTIONS(2431),
    [anon_sym_EQ_GT] = ACTIONS(682),
    [anon_sym_QMARK_DOT] = ACTIONS(154),
    [anon_sym_new] = ACTIONS(2429),
    [anon_sym_PLUS_EQ] = ACTIONS(160),
    [anon_sym_DASH_EQ] = ACTIONS(160),
    [anon_sym_STAR_EQ] = ACTIONS(160),
    [anon_sym_SLASH_EQ] = ACTIONS(160),
    [anon_sym_PERCENT_EQ] = ACTIONS(160),
    [anon_sym_CARET_EQ] = ACTIONS(160),
    [anon_sym_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_LT_LT_EQ] = ACTIONS(160),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(160),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP] = ACTIONS(120),
    [anon_sym_PIPE_PIPE] = ACTIONS(120),
    [anon_sym_GT_GT] = ACTIONS(120),
    [anon_sym_GT_GT_GT] = ACTIONS(120),
    [anon_sym_LT_LT] = ACTIONS(120),
    [anon_sym_AMP] = ACTIONS(120),
    [anon_sym_CARET] = ACTIONS(120),
    [anon_sym_PIPE] = ACTIONS(120),
    [anon_sym_PLUS] = ACTIONS(120),
    [anon_sym_DASH] = ACTIONS(120),
    [anon_sym_SLASH] = ACTIONS(120),
    [anon_sym_PERCENT] = ACTIONS(120),
    [anon_sym_STAR_STAR] = ACTIONS(120),
    [anon_sym_LT] = ACTIONS(2420),
    [anon_sym_LT_EQ] = ACTIONS(154),
    [anon_sym_EQ_EQ] = ACTIONS(120),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(154),
    [anon_sym_BANG_EQ] = ACTIONS(120),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(154),
    [anon_sym_GT_EQ] = ACTIONS(154),
    [anon_sym_GT] = ACTIONS(120),
    [anon_sym_QMARK_QMARK] = ACTIONS(120),
    [anon_sym_instanceof] = ACTIONS(120),
    [anon_sym_PLUS_PLUS] = ACTIONS(154),
    [anon_sym_DASH_DASH] = ACTIONS(154),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(154),
    [anon_sym_static] = ACTIONS(2429),
    [anon_sym_readonly] = ACTIONS(2429),
    [anon_sym_get] = ACTIONS(2429),
    [anon_sym_set] = ACTIONS(2429),
    [anon_sym_declare] = ACTIONS(2429),
    [anon_sym_public] = ACTIONS(2429),
    [anon_sym_private] = ACTIONS(2429),
    [anon_sym_protected] = ACTIONS(2429),
    [anon_sym_override] = ACTIONS(2429),
    [anon_sym_module] = ACTIONS(2429),
    [anon_sym_any] = ACTIONS(2429),
    [anon_sym_number] = ACTIONS(2429),
    [anon_sym_boolean] = ACTIONS(2429),
    [anon_sym_string] = ACTIONS(2429),
    [anon_sym_symbol] = ACTIONS(2429),
    [anon_sym_object] = ACTIONS(2429),
    [anon_sym_satisfies] = ACTIONS(120),
    [sym__automatic_semicolon] = ACTIONS(154),
    [sym__ternary_qmark] = ACTIONS(154),
    [sym_html_comment] = ACTIONS(5),
  },
  [730] = {
    [sym__call_signature] = STATE(5693),
    [sym_formal_parameters] = STATE(3806),
    [sym_type_parameters] = STATE(5328),
    [sym_identifier] = ACTIONS(2427),
    [anon_sym_export] = ACTIONS(2429),
    [anon_sym_STAR] = ACTIONS(120),
    [anon_sym_type] = ACTIONS(2429),
    [anon_sym_EQ] = ACTIONS(824),
    [anon_sym_as] = ACTIONS(120),
    [anon_sym_namespace] = ACTIONS(2429),
    [anon_sym_COMMA] = ACTIONS(154),
    [anon_sym_RBRACE] = ACTIONS(154),
    [anon_sym_let] = ACTIONS(2429),
    [anon_sym_BANG] = ACTIONS(120),
    [anon_sym_LPAREN] = ACTIONS(2415),
    [anon_sym_SEMI] = ACTIONS(154),
    [anon_sym_in] = ACTIONS(120),
    [anon_sym_LBRACK] = ACTIONS(154),
    [anon_sym_DOT] = ACTIONS(154),
    [anon_sym_async] = ACTIONS(2429),
    [anon_sym_function] = ACTIONS(2433),
    [anon_sym_EQ_GT] = ACTIONS(682),
    [anon_sym_QMARK_DOT] = ACTIONS(154),
    [anon_sym_new] = ACTIONS(2429),
    [anon_sym_PLUS_EQ] = ACTIONS(160),
    [anon_sym_DASH_EQ] = ACTIONS(160),
    [anon_sym_STAR_EQ] = ACTIONS(160),
    [anon_sym_SLASH_EQ] = ACTIONS(160),
    [anon_sym_PERCENT_EQ] = ACTIONS(160),
    [anon_sym_CARET_EQ] = ACTIONS(160),
    [anon_sym_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_LT_LT_EQ] = ACTIONS(160),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(160),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP] = ACTIONS(120),
    [anon_sym_PIPE_PIPE] = ACTIONS(120),
    [anon_sym_GT_GT] = ACTIONS(120),
    [anon_sym_GT_GT_GT] = ACTIONS(120),
    [anon_sym_LT_LT] = ACTIONS(120),
    [anon_sym_AMP] = ACTIONS(120),
    [anon_sym_CARET] = ACTIONS(120),
    [anon_sym_PIPE] = ACTIONS(120),
    [anon_sym_PLUS] = ACTIONS(120),
    [anon_sym_DASH] = ACTIONS(120),
    [anon_sym_SLASH] = ACTIONS(120),
    [anon_sym_PERCENT] = ACTIONS(120),
    [anon_sym_STAR_STAR] = ACTIONS(120),
    [anon_sym_LT] = ACTIONS(2420),
    [anon_sym_LT_EQ] = ACTIONS(154),
    [anon_sym_EQ_EQ] = ACTIONS(120),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(154),
    [anon_sym_BANG_EQ] = ACTIONS(120),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(154),
    [anon_sym_GT_EQ] = ACTIONS(154),
    [anon_sym_GT] = ACTIONS(120),
    [anon_sym_QMARK_QMARK] = ACTIONS(120),
    [anon_sym_instanceof] = ACTIONS(120),
    [anon_sym_PLUS_PLUS] = ACTIONS(154),
    [anon_sym_DASH_DASH] = ACTIONS(154),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(154),
    [anon_sym_static] = ACTIONS(2429),
    [anon_sym_readonly] = ACTIONS(2429),
    [anon_sym_get] = ACTIONS(2429),
    [anon_sym_set] = ACTIONS(2429),
    [anon_sym_declare] = ACTIONS(2429),
    [anon_sym_public] = ACTIONS(2429),
    [anon_sym_private] = ACTIONS(2429),
    [anon_sym_protected] = ACTIONS(2429),
    [anon_sym_override] = ACTIONS(2429),
    [anon_sym_module] = ACTIONS(2429),
    [anon_sym_any] = ACTIONS(2429),
    [anon_sym_number] = ACTIONS(2429),
    [anon_sym_boolean] = ACTIONS(2429),
    [anon_sym_string] = ACTIONS(2429),
    [anon_sym_symbol] = ACTIONS(2429),
    [anon_sym_object] = ACTIONS(2429),
    [anon_sym_satisfies] = ACTIONS(120),
    [sym__automatic_semicolon] = ACTIONS(154),
    [sym__ternary_qmark] = ACTIONS(154),
    [sym_html_comment] = ACTIONS(5),
  },
  [731] = {
    [sym__call_signature] = STATE(5594),
    [sym_formal_parameters] = STATE(3806),
    [sym_type_parameters] = STATE(5328),
    [sym_identifier] = ACTIONS(2423),
    [anon_sym_export] = ACTIONS(2425),
    [anon_sym_STAR] = ACTIONS(120),
    [anon_sym_type] = ACTIONS(2425),
    [anon_sym_EQ] = ACTIONS(834),
    [anon_sym_as] = ACTIONS(120),
    [anon_sym_namespace] = ACTIONS(2425),
    [anon_sym_COMMA] = ACTIONS(899),
    [anon_sym_RBRACE] = ACTIONS(899),
    [anon_sym_let] = ACTIONS(2425),
    [anon_sym_BANG] = ACTIONS(120),
    [anon_sym_LPAREN] = ACTIONS(2415),
    [anon_sym_in] = ACTIONS(120),
    [anon_sym_COLON] = ACTIONS(826),
    [anon_sym_LBRACK] = ACTIONS(154),
    [anon_sym_RBRACK] = ACTIONS(899),
    [anon_sym_DOT] = ACTIONS(154),
    [anon_sym_async] = ACTIONS(2425),
    [anon_sym_function] = ACTIONS(2418),
    [anon_sym_EQ_GT] = ACTIONS(844),
    [anon_sym_QMARK_DOT] = ACTIONS(154),
    [anon_sym_new] = ACTIONS(2425),
    [anon_sym_PLUS_EQ] = ACTIONS(160),
    [anon_sym_DASH_EQ] = ACTIONS(160),
    [anon_sym_STAR_EQ] = ACTIONS(160),
    [anon_sym_SLASH_EQ] = ACTIONS(160),
    [anon_sym_PERCENT_EQ] = ACTIONS(160),
    [anon_sym_CARET_EQ] = ACTIONS(160),
    [anon_sym_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_LT_LT_EQ] = ACTIONS(160),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(160),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP] = ACTIONS(120),
    [anon_sym_PIPE_PIPE] = ACTIONS(120),
    [anon_sym_GT_GT] = ACTIONS(120),
    [anon_sym_GT_GT_GT] = ACTIONS(120),
    [anon_sym_LT_LT] = ACTIONS(120),
    [anon_sym_AMP] = ACTIONS(120),
    [anon_sym_CARET] = ACTIONS(120),
    [anon_sym_PIPE] = ACTIONS(120),
    [anon_sym_PLUS] = ACTIONS(120),
    [anon_sym_DASH] = ACTIONS(120),
    [anon_sym_SLASH] = ACTIONS(120),
    [anon_sym_PERCENT] = ACTIONS(120),
    [anon_sym_STAR_STAR] = ACTIONS(120),
    [anon_sym_LT] = ACTIONS(2420),
    [anon_sym_LT_EQ] = ACTIONS(154),
    [anon_sym_EQ_EQ] = ACTIONS(120),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(154),
    [anon_sym_BANG_EQ] = ACTIONS(120),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(154),
    [anon_sym_GT_EQ] = ACTIONS(154),
    [anon_sym_GT] = ACTIONS(120),
    [anon_sym_QMARK_QMARK] = ACTIONS(120),
    [anon_sym_instanceof] = ACTIONS(120),
    [anon_sym_PLUS_PLUS] = ACTIONS(154),
    [anon_sym_DASH_DASH] = ACTIONS(154),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(154),
    [anon_sym_static] = ACTIONS(2425),
    [anon_sym_readonly] = ACTIONS(2425),
    [anon_sym_get] = ACTIONS(2425),
    [anon_sym_set] = ACTIONS(2425),
    [anon_sym_declare] = ACTIONS(2425),
    [anon_sym_public] = ACTIONS(2425),
    [anon_sym_private] = ACTIONS(2425),
    [anon_sym_protected] = ACTIONS(2425),
    [anon_sym_override] = ACTIONS(2425),
    [anon_sym_module] = ACTIONS(2425),
    [anon_sym_any] = ACTIONS(2425),
    [anon_sym_number] = ACTIONS(2425),
    [anon_sym_boolean] = ACTIONS(2425),
    [anon_sym_string] = ACTIONS(2425),
    [anon_sym_symbol] = ACTIONS(2425),
    [anon_sym_object] = ACTIONS(2425),
    [anon_sym_satisfies] = ACTIONS(120),
    [sym__ternary_qmark] = ACTIONS(154),
    [sym_html_comment] = ACTIONS(5),
  },
  [732] = {
    [sym__call_signature] = STATE(5779),
    [sym_formal_parameters] = STATE(3806),
    [sym_type_parameters] = STATE(5328),
    [sym_identifier] = ACTIONS(2435),
    [anon_sym_export] = ACTIONS(2437),
    [anon_sym_STAR] = ACTIONS(120),
    [anon_sym_type] = ACTIONS(2437),
    [anon_sym_EQ] = ACTIONS(866),
    [anon_sym_as] = ACTIONS(120),
    [anon_sym_namespace] = ACTIONS(2437),
    [anon_sym_COMMA] = ACTIONS(154),
    [anon_sym_let] = ACTIONS(2437),
    [anon_sym_BANG] = ACTIONS(120),
    [anon_sym_LPAREN] = ACTIONS(2415),
    [anon_sym_SEMI] = ACTIONS(154),
    [anon_sym_in] = ACTIONS(120),
    [anon_sym_of] = ACTIONS(120),
    [anon_sym_LBRACK] = ACTIONS(154),
    [anon_sym_DOT] = ACTIONS(154),
    [anon_sym_async] = ACTIONS(2437),
    [anon_sym_function] = ACTIONS(2433),
    [anon_sym_EQ_GT] = ACTIONS(872),
    [anon_sym_QMARK_DOT] = ACTIONS(154),
    [anon_sym_new] = ACTIONS(2437),
    [anon_sym_PLUS_EQ] = ACTIONS(160),
    [anon_sym_DASH_EQ] = ACTIONS(160),
    [anon_sym_STAR_EQ] = ACTIONS(160),
    [anon_sym_SLASH_EQ] = ACTIONS(160),
    [anon_sym_PERCENT_EQ] = ACTIONS(160),
    [anon_sym_CARET_EQ] = ACTIONS(160),
    [anon_sym_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_LT_LT_EQ] = ACTIONS(160),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(160),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP] = ACTIONS(120),
    [anon_sym_PIPE_PIPE] = ACTIONS(120),
    [anon_sym_GT_GT] = ACTIONS(120),
    [anon_sym_GT_GT_GT] = ACTIONS(120),
    [anon_sym_LT_LT] = ACTIONS(120),
    [anon_sym_AMP] = ACTIONS(120),
    [anon_sym_CARET] = ACTIONS(120),
    [anon_sym_PIPE] = ACTIONS(120),
    [anon_sym_PLUS] = ACTIONS(120),
    [anon_sym_DASH] = ACTIONS(120),
    [anon_sym_SLASH] = ACTIONS(120),
    [anon_sym_PERCENT] = ACTIONS(120),
    [anon_sym_STAR_STAR] = ACTIONS(120),
    [anon_sym_LT] = ACTIONS(2420),
    [anon_sym_LT_EQ] = ACTIONS(154),
    [anon_sym_EQ_EQ] = ACTIONS(120),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(154),
    [anon_sym_BANG_EQ] = ACTIONS(120),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(154),
    [anon_sym_GT_EQ] = ACTIONS(154),
    [anon_sym_GT] = ACTIONS(120),
    [anon_sym_QMARK_QMARK] = ACTIONS(120),
    [anon_sym_instanceof] = ACTIONS(120),
    [anon_sym_PLUS_PLUS] = ACTIONS(154),
    [anon_sym_DASH_DASH] = ACTIONS(154),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(154),
    [anon_sym_static] = ACTIONS(2437),
    [anon_sym_readonly] = ACTIONS(2437),
    [anon_sym_get] = ACTIONS(2437),
    [anon_sym_set] = ACTIONS(2437),
    [anon_sym_declare] = ACTIONS(2437),
    [anon_sym_public] = ACTIONS(2437),
    [anon_sym_private] = ACTIONS(2437),
    [anon_sym_protected] = ACTIONS(2437),
    [anon_sym_override] = ACTIONS(2437),
    [anon_sym_module] = ACTIONS(2437),
    [anon_sym_any] = ACTIONS(2437),
    [anon_sym_number] = ACTIONS(2437),
    [anon_sym_boolean] = ACTIONS(2437),
    [anon_sym_string] = ACTIONS(2437),
    [anon_sym_symbol] = ACTIONS(2437),
    [anon_sym_object] = ACTIONS(2437),
    [anon_sym_satisfies] = ACTIONS(120),
    [sym__automatic_semicolon] = ACTIONS(154),
    [sym__ternary_qmark] = ACTIONS(154),
    [sym_html_comment] = ACTIONS(5),
  },
  [733] = {
    [sym__call_signature] = STATE(5814),
    [sym_formal_parameters] = STATE(3806),
    [sym_type_parameters] = STATE(5328),
    [sym_identifier] = ACTIONS(2439),
    [anon_sym_export] = ACTIONS(2441),
    [anon_sym_STAR] = ACTIONS(120),
    [anon_sym_type] = ACTIONS(2441),
    [anon_sym_EQ] = ACTIONS(117),
    [anon_sym_as] = ACTIONS(120),
    [anon_sym_namespace] = ACTIONS(2441),
    [anon_sym_COMMA] = ACTIONS(126),
    [anon_sym_let] = ACTIONS(2441),
    [anon_sym_BANG] = ACTIONS(120),
    [anon_sym_LPAREN] = ACTIONS(2415),
    [anon_sym_RPAREN] = ACTIONS(126),
    [anon_sym_in] = ACTIONS(120),
    [anon_sym_COLON] = ACTIONS(126),
    [anon_sym_LBRACK] = ACTIONS(154),
    [anon_sym_DOT] = ACTIONS(154),
    [anon_sym_async] = ACTIONS(2441),
    [anon_sym_function] = ACTIONS(2418),
    [anon_sym_EQ_GT] = ACTIONS(152),
    [anon_sym_QMARK_DOT] = ACTIONS(154),
    [anon_sym_new] = ACTIONS(2441),
    [anon_sym_PLUS_EQ] = ACTIONS(160),
    [anon_sym_DASH_EQ] = ACTIONS(160),
    [anon_sym_STAR_EQ] = ACTIONS(160),
    [anon_sym_SLASH_EQ] = ACTIONS(160),
    [anon_sym_PERCENT_EQ] = ACTIONS(160),
    [anon_sym_CARET_EQ] = ACTIONS(160),
    [anon_sym_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_LT_LT_EQ] = ACTIONS(160),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(160),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP] = ACTIONS(120),
    [anon_sym_PIPE_PIPE] = ACTIONS(120),
    [anon_sym_GT_GT] = ACTIONS(120),
    [anon_sym_GT_GT_GT] = ACTIONS(120),
    [anon_sym_LT_LT] = ACTIONS(120),
    [anon_sym_AMP] = ACTIONS(120),
    [anon_sym_CARET] = ACTIONS(120),
    [anon_sym_PIPE] = ACTIONS(120),
    [anon_sym_PLUS] = ACTIONS(120),
    [anon_sym_DASH] = ACTIONS(120),
    [anon_sym_SLASH] = ACTIONS(120),
    [anon_sym_PERCENT] = ACTIONS(120),
    [anon_sym_STAR_STAR] = ACTIONS(120),
    [anon_sym_LT] = ACTIONS(2420),
    [anon_sym_LT_EQ] = ACTIONS(154),
    [anon_sym_EQ_EQ] = ACTIONS(120),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(154),
    [anon_sym_BANG_EQ] = ACTIONS(120),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(154),
    [anon_sym_GT_EQ] = ACTIONS(154),
    [anon_sym_GT] = ACTIONS(120),
    [anon_sym_QMARK_QMARK] = ACTIONS(120),
    [anon_sym_instanceof] = ACTIONS(120),
    [anon_sym_PLUS_PLUS] = ACTIONS(154),
    [anon_sym_DASH_DASH] = ACTIONS(154),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(154),
    [anon_sym_static] = ACTIONS(2441),
    [anon_sym_readonly] = ACTIONS(2441),
    [anon_sym_get] = ACTIONS(2441),
    [anon_sym_set] = ACTIONS(2441),
    [anon_sym_QMARK] = ACTIONS(720),
    [anon_sym_declare] = ACTIONS(2441),
    [anon_sym_public] = ACTIONS(2441),
    [anon_sym_private] = ACTIONS(2441),
    [anon_sym_protected] = ACTIONS(2441),
    [anon_sym_override] = ACTIONS(2441),
    [anon_sym_module] = ACTIONS(2441),
    [anon_sym_any] = ACTIONS(2441),
    [anon_sym_number] = ACTIONS(2441),
    [anon_sym_boolean] = ACTIONS(2441),
    [anon_sym_string] = ACTIONS(2441),
    [anon_sym_symbol] = ACTIONS(2441),
    [anon_sym_object] = ACTIONS(2441),
    [anon_sym_satisfies] = ACTIONS(120),
    [sym__ternary_qmark] = ACTIONS(154),
    [sym_html_comment] = ACTIONS(5),
  },
  [734] = {
    [sym__call_signature] = STATE(5779),
    [sym_formal_parameters] = STATE(3806),
    [sym_type_parameters] = STATE(5328),
    [sym_identifier] = ACTIONS(2435),
    [anon_sym_export] = ACTIONS(2437),
    [anon_sym_STAR] = ACTIONS(120),
    [anon_sym_type] = ACTIONS(2437),
    [anon_sym_EQ] = ACTIONS(824),
    [anon_sym_as] = ACTIONS(120),
    [anon_sym_namespace] = ACTIONS(2437),
    [anon_sym_COMMA] = ACTIONS(154),
    [anon_sym_let] = ACTIONS(2437),
    [anon_sym_BANG] = ACTIONS(120),
    [anon_sym_LPAREN] = ACTIONS(2415),
    [anon_sym_SEMI] = ACTIONS(154),
    [anon_sym_in] = ACTIONS(120),
    [anon_sym_of] = ACTIONS(120),
    [anon_sym_LBRACK] = ACTIONS(154),
    [anon_sym_DOT] = ACTIONS(154),
    [anon_sym_async] = ACTIONS(2437),
    [anon_sym_function] = ACTIONS(2433),
    [anon_sym_EQ_GT] = ACTIONS(872),
    [anon_sym_QMARK_DOT] = ACTIONS(154),
    [anon_sym_new] = ACTIONS(2437),
    [anon_sym_PLUS_EQ] = ACTIONS(160),
    [anon_sym_DASH_EQ] = ACTIONS(160),
    [anon_sym_STAR_EQ] = ACTIONS(160),
    [anon_sym_SLASH_EQ] = ACTIONS(160),
    [anon_sym_PERCENT_EQ] = ACTIONS(160),
    [anon_sym_CARET_EQ] = ACTIONS(160),
    [anon_sym_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_LT_LT_EQ] = ACTIONS(160),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(160),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP] = ACTIONS(120),
    [anon_sym_PIPE_PIPE] = ACTIONS(120),
    [anon_sym_GT_GT] = ACTIONS(120),
    [anon_sym_GT_GT_GT] = ACTIONS(120),
    [anon_sym_LT_LT] = ACTIONS(120),
    [anon_sym_AMP] = ACTIONS(120),
    [anon_sym_CARET] = ACTIONS(120),
    [anon_sym_PIPE] = ACTIONS(120),
    [anon_sym_PLUS] = ACTIONS(120),
    [anon_sym_DASH] = ACTIONS(120),
    [anon_sym_SLASH] = ACTIONS(120),
    [anon_sym_PERCENT] = ACTIONS(120),
    [anon_sym_STAR_STAR] = ACTIONS(120),
    [anon_sym_LT] = ACTIONS(2420),
    [anon_sym_LT_EQ] = ACTIONS(154),
    [anon_sym_EQ_EQ] = ACTIONS(120),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(154),
    [anon_sym_BANG_EQ] = ACTIONS(120),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(154),
    [anon_sym_GT_EQ] = ACTIONS(154),
    [anon_sym_GT] = ACTIONS(120),
    [anon_sym_QMARK_QMARK] = ACTIONS(120),
    [anon_sym_instanceof] = ACTIONS(120),
    [anon_sym_PLUS_PLUS] = ACTIONS(154),
    [anon_sym_DASH_DASH] = ACTIONS(154),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(154),
    [anon_sym_static] = ACTIONS(2437),
    [anon_sym_readonly] = ACTIONS(2437),
    [anon_sym_get] = ACTIONS(2437),
    [anon_sym_set] = ACTIONS(2437),
    [anon_sym_declare] = ACTIONS(2437),
    [anon_sym_public] = ACTIONS(2437),
    [anon_sym_private] = ACTIONS(2437),
    [anon_sym_protected] = ACTIONS(2437),
    [anon_sym_override] = ACTIONS(2437),
    [anon_sym_module] = ACTIONS(2437),
    [anon_sym_any] = ACTIONS(2437),
    [anon_sym_number] = ACTIONS(2437),
    [anon_sym_boolean] = ACTIONS(2437),
    [anon_sym_string] = ACTIONS(2437),
    [anon_sym_symbol] = ACTIONS(2437),
    [anon_sym_object] = ACTIONS(2437),
    [anon_sym_satisfies] = ACTIONS(120),
    [sym__automatic_semicolon] = ACTIONS(154),
    [sym__ternary_qmark] = ACTIONS(154),
    [sym_html_comment] = ACTIONS(5),
  },
  [735] = {
    [sym__call_signature] = STATE(5693),
    [sym_formal_parameters] = STATE(3806),
    [sym_type_parameters] = STATE(5328),
    [sym_identifier] = ACTIONS(2427),
    [anon_sym_export] = ACTIONS(2429),
    [anon_sym_STAR] = ACTIONS(120),
    [anon_sym_type] = ACTIONS(2429),
    [anon_sym_EQ] = ACTIONS(858),
    [anon_sym_as] = ACTIONS(120),
    [anon_sym_namespace] = ACTIONS(2429),
    [anon_sym_COMMA] = ACTIONS(154),
    [anon_sym_RBRACE] = ACTIONS(154),
    [anon_sym_let] = ACTIONS(2429),
    [anon_sym_BANG] = ACTIONS(120),
    [anon_sym_LPAREN] = ACTIONS(2415),
    [anon_sym_SEMI] = ACTIONS(154),
    [anon_sym_in] = ACTIONS(120),
    [anon_sym_LBRACK] = ACTIONS(154),
    [anon_sym_DOT] = ACTIONS(154),
    [anon_sym_async] = ACTIONS(2429),
    [anon_sym_function] = ACTIONS(2433),
    [anon_sym_EQ_GT] = ACTIONS(682),
    [anon_sym_QMARK_DOT] = ACTIONS(154),
    [anon_sym_new] = ACTIONS(2429),
    [anon_sym_PLUS_EQ] = ACTIONS(160),
    [anon_sym_DASH_EQ] = ACTIONS(160),
    [anon_sym_STAR_EQ] = ACTIONS(160),
    [anon_sym_SLASH_EQ] = ACTIONS(160),
    [anon_sym_PERCENT_EQ] = ACTIONS(160),
    [anon_sym_CARET_EQ] = ACTIONS(160),
    [anon_sym_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_LT_LT_EQ] = ACTIONS(160),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(160),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP] = ACTIONS(120),
    [anon_sym_PIPE_PIPE] = ACTIONS(120),
    [anon_sym_GT_GT] = ACTIONS(120),
    [anon_sym_GT_GT_GT] = ACTIONS(120),
    [anon_sym_LT_LT] = ACTIONS(120),
    [anon_sym_AMP] = ACTIONS(120),
    [anon_sym_CARET] = ACTIONS(120),
    [anon_sym_PIPE] = ACTIONS(120),
    [anon_sym_PLUS] = ACTIONS(120),
    [anon_sym_DASH] = ACTIONS(120),
    [anon_sym_SLASH] = ACTIONS(120),
    [anon_sym_PERCENT] = ACTIONS(120),
    [anon_sym_STAR_STAR] = ACTIONS(120),
    [anon_sym_LT] = ACTIONS(2420),
    [anon_sym_LT_EQ] = ACTIONS(154),
    [anon_sym_EQ_EQ] = ACTIONS(120),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(154),
    [anon_sym_BANG_EQ] = ACTIONS(120),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(154),
    [anon_sym_GT_EQ] = ACTIONS(154),
    [anon_sym_GT] = ACTIONS(120),
    [anon_sym_QMARK_QMARK] = ACTIONS(120),
    [anon_sym_instanceof] = ACTIONS(120),
    [anon_sym_PLUS_PLUS] = ACTIONS(154),
    [anon_sym_DASH_DASH] = ACTIONS(154),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(154),
    [anon_sym_static] = ACTIONS(2429),
    [anon_sym_readonly] = ACTIONS(2429),
    [anon_sym_get] = ACTIONS(2429),
    [anon_sym_set] = ACTIONS(2429),
    [anon_sym_declare] = ACTIONS(2429),
    [anon_sym_public] = ACTIONS(2429),
    [anon_sym_private] = ACTIONS(2429),
    [anon_sym_protected] = ACTIONS(2429),
    [anon_sym_override] = ACTIONS(2429),
    [anon_sym_module] = ACTIONS(2429),
    [anon_sym_any] = ACTIONS(2429),
    [anon_sym_number] = ACTIONS(2429),
    [anon_sym_boolean] = ACTIONS(2429),
    [anon_sym_string] = ACTIONS(2429),
    [anon_sym_symbol] = ACTIONS(2429),
    [anon_sym_object] = ACTIONS(2429),
    [anon_sym_satisfies] = ACTIONS(120),
    [sym__automatic_semicolon] = ACTIONS(154),
    [sym__ternary_qmark] = ACTIONS(154),
    [sym_html_comment] = ACTIONS(5),
  },
  [736] = {
    [sym__call_signature] = STATE(5481),
    [sym_formal_parameters] = STATE(3806),
    [sym_type_parameters] = STATE(5328),
    [sym_identifier] = ACTIONS(2443),
    [anon_sym_export] = ACTIONS(2445),
    [anon_sym_STAR] = ACTIONS(120),
    [anon_sym_type] = ACTIONS(2445),
    [anon_sym_EQ] = ACTIONS(886),
    [anon_sym_as] = ACTIONS(120),
    [anon_sym_namespace] = ACTIONS(2445),
    [anon_sym_COMMA] = ACTIONS(223),
    [anon_sym_let] = ACTIONS(2445),
    [anon_sym_BANG] = ACTIONS(120),
    [anon_sym_LPAREN] = ACTIONS(2415),
    [anon_sym_in] = ACTIONS(120),
    [anon_sym_COLON] = ACTIONS(891),
    [anon_sym_LBRACK] = ACTIONS(154),
    [anon_sym_RBRACK] = ACTIONS(126),
    [anon_sym_DOT] = ACTIONS(154),
    [anon_sym_async] = ACTIONS(2445),
    [anon_sym_function] = ACTIONS(2418),
    [anon_sym_EQ_GT] = ACTIONS(895),
    [anon_sym_QMARK_DOT] = ACTIONS(154),
    [anon_sym_new] = ACTIONS(2445),
    [anon_sym_PLUS_EQ] = ACTIONS(160),
    [anon_sym_DASH_EQ] = ACTIONS(160),
    [anon_sym_STAR_EQ] = ACTIONS(160),
    [anon_sym_SLASH_EQ] = ACTIONS(160),
    [anon_sym_PERCENT_EQ] = ACTIONS(160),
    [anon_sym_CARET_EQ] = ACTIONS(160),
    [anon_sym_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_LT_LT_EQ] = ACTIONS(160),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(160),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP] = ACTIONS(120),
    [anon_sym_PIPE_PIPE] = ACTIONS(120),
    [anon_sym_GT_GT] = ACTIONS(120),
    [anon_sym_GT_GT_GT] = ACTIONS(120),
    [anon_sym_LT_LT] = ACTIONS(120),
    [anon_sym_AMP] = ACTIONS(120),
    [anon_sym_CARET] = ACTIONS(120),
    [anon_sym_PIPE] = ACTIONS(120),
    [anon_sym_PLUS] = ACTIONS(120),
    [anon_sym_DASH] = ACTIONS(120),
    [anon_sym_SLASH] = ACTIONS(120),
    [anon_sym_PERCENT] = ACTIONS(120),
    [anon_sym_STAR_STAR] = ACTIONS(120),
    [anon_sym_LT] = ACTIONS(2420),
    [anon_sym_LT_EQ] = ACTIONS(154),
    [anon_sym_EQ_EQ] = ACTIONS(120),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(154),
    [anon_sym_BANG_EQ] = ACTIONS(120),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(154),
    [anon_sym_GT_EQ] = ACTIONS(154),
    [anon_sym_GT] = ACTIONS(120),
    [anon_sym_QMARK_QMARK] = ACTIONS(120),
    [anon_sym_instanceof] = ACTIONS(120),
    [anon_sym_PLUS_PLUS] = ACTIONS(154),
    [anon_sym_DASH_DASH] = ACTIONS(154),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(154),
    [anon_sym_static] = ACTIONS(2445),
    [anon_sym_readonly] = ACTIONS(2445),
    [anon_sym_get] = ACTIONS(2445),
    [anon_sym_set] = ACTIONS(2445),
    [anon_sym_declare] = ACTIONS(2445),
    [anon_sym_public] = ACTIONS(2445),
    [anon_sym_private] = ACTIONS(2445),
    [anon_sym_protected] = ACTIONS(2445),
    [anon_sym_override] = ACTIONS(2445),
    [anon_sym_module] = ACTIONS(2445),
    [anon_sym_any] = ACTIONS(2445),
    [anon_sym_number] = ACTIONS(2445),
    [anon_sym_boolean] = ACTIONS(2445),
    [anon_sym_string] = ACTIONS(2445),
    [anon_sym_symbol] = ACTIONS(2445),
    [anon_sym_object] = ACTIONS(2445),
    [anon_sym_satisfies] = ACTIONS(120),
    [sym__ternary_qmark] = ACTIONS(154),
    [sym_html_comment] = ACTIONS(5),
  },
  [737] = {
    [sym__call_signature] = STATE(5591),
    [sym_formal_parameters] = STATE(3806),
    [sym_type_parameters] = STATE(5328),
    [sym_identifier] = ACTIONS(2447),
    [anon_sym_export] = ACTIONS(2449),
    [anon_sym_STAR] = ACTIONS(120),
    [anon_sym_type] = ACTIONS(2449),
    [anon_sym_EQ] = ACTIONS(932),
    [anon_sym_as] = ACTIONS(120),
    [anon_sym_namespace] = ACTIONS(2449),
    [anon_sym_LBRACE] = ACTIONS(154),
    [anon_sym_COMMA] = ACTIONS(154),
    [anon_sym_let] = ACTIONS(2449),
    [anon_sym_BANG] = ACTIONS(120),
    [anon_sym_LPAREN] = ACTIONS(2415),
    [anon_sym_in] = ACTIONS(120),
    [anon_sym_LBRACK] = ACTIONS(154),
    [anon_sym_DOT] = ACTIONS(154),
    [anon_sym_async] = ACTIONS(2449),
    [anon_sym_function] = ACTIONS(2418),
    [anon_sym_EQ_GT] = ACTIONS(938),
    [anon_sym_QMARK_DOT] = ACTIONS(154),
    [anon_sym_new] = ACTIONS(2449),
    [anon_sym_PLUS_EQ] = ACTIONS(160),
    [anon_sym_DASH_EQ] = ACTIONS(160),
    [anon_sym_STAR_EQ] = ACTIONS(160),
    [anon_sym_SLASH_EQ] = ACTIONS(160),
    [anon_sym_PERCENT_EQ] = ACTIONS(160),
    [anon_sym_CARET_EQ] = ACTIONS(160),
    [anon_sym_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_LT_LT_EQ] = ACTIONS(160),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(160),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP] = ACTIONS(120),
    [anon_sym_PIPE_PIPE] = ACTIONS(120),
    [anon_sym_GT_GT] = ACTIONS(120),
    [anon_sym_GT_GT_GT] = ACTIONS(120),
    [anon_sym_LT_LT] = ACTIONS(120),
    [anon_sym_AMP] = ACTIONS(120),
    [anon_sym_CARET] = ACTIONS(120),
    [anon_sym_PIPE] = ACTIONS(120),
    [anon_sym_PLUS] = ACTIONS(120),
    [anon_sym_DASH] = ACTIONS(120),
    [anon_sym_SLASH] = ACTIONS(120),
    [anon_sym_PERCENT] = ACTIONS(120),
    [anon_sym_STAR_STAR] = ACTIONS(120),
    [anon_sym_LT] = ACTIONS(2420),
    [anon_sym_LT_EQ] = ACTIONS(154),
    [anon_sym_EQ_EQ] = ACTIONS(120),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(154),
    [anon_sym_BANG_EQ] = ACTIONS(120),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(154),
    [anon_sym_GT_EQ] = ACTIONS(154),
    [anon_sym_GT] = ACTIONS(120),
    [anon_sym_QMARK_QMARK] = ACTIONS(120),
    [anon_sym_instanceof] = ACTIONS(120),
    [anon_sym_PLUS_PLUS] = ACTIONS(154),
    [anon_sym_DASH_DASH] = ACTIONS(154),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(154),
    [anon_sym_static] = ACTIONS(2449),
    [anon_sym_readonly] = ACTIONS(2449),
    [anon_sym_get] = ACTIONS(2449),
    [anon_sym_set] = ACTIONS(2449),
    [anon_sym_declare] = ACTIONS(2449),
    [anon_sym_public] = ACTIONS(2449),
    [anon_sym_private] = ACTIONS(2449),
    [anon_sym_protected] = ACTIONS(2449),
    [anon_sym_override] = ACTIONS(2449),
    [anon_sym_module] = ACTIONS(2449),
    [anon_sym_any] = ACTIONS(2449),
    [anon_sym_number] = ACTIONS(2449),
    [anon_sym_boolean] = ACTIONS(2449),
    [anon_sym_string] = ACTIONS(2449),
    [anon_sym_symbol] = ACTIONS(2449),
    [anon_sym_object] = ACTIONS(2449),
    [anon_sym_satisfies] = ACTIONS(120),
    [anon_sym_implements] = ACTIONS(120),
    [sym__ternary_qmark] = ACTIONS(154),
    [sym_html_comment] = ACTIONS(5),
  },
  [738] = {
    [sym__call_signature] = STATE(5594),
    [sym_formal_parameters] = STATE(3806),
    [sym_type_parameters] = STATE(5328),
    [sym_identifier] = ACTIONS(2423),
    [anon_sym_export] = ACTIONS(2425),
    [anon_sym_STAR] = ACTIONS(120),
    [anon_sym_type] = ACTIONS(2425),
    [anon_sym_EQ] = ACTIONS(907),
    [anon_sym_as] = ACTIONS(120),
    [anon_sym_namespace] = ACTIONS(2425),
    [anon_sym_COMMA] = ACTIONS(126),
    [anon_sym_RBRACE] = ACTIONS(126),
    [anon_sym_let] = ACTIONS(2425),
    [anon_sym_BANG] = ACTIONS(120),
    [anon_sym_LPAREN] = ACTIONS(2415),
    [anon_sym_in] = ACTIONS(120),
    [anon_sym_LBRACK] = ACTIONS(154),
    [anon_sym_RBRACK] = ACTIONS(126),
    [anon_sym_DOT] = ACTIONS(154),
    [anon_sym_async] = ACTIONS(2425),
    [anon_sym_function] = ACTIONS(2418),
    [anon_sym_EQ_GT] = ACTIONS(844),
    [anon_sym_QMARK_DOT] = ACTIONS(154),
    [anon_sym_new] = ACTIONS(2425),
    [anon_sym_PLUS_EQ] = ACTIONS(160),
    [anon_sym_DASH_EQ] = ACTIONS(160),
    [anon_sym_STAR_EQ] = ACTIONS(160),
    [anon_sym_SLASH_EQ] = ACTIONS(160),
    [anon_sym_PERCENT_EQ] = ACTIONS(160),
    [anon_sym_CARET_EQ] = ACTIONS(160),
    [anon_sym_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_LT_LT_EQ] = ACTIONS(160),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(160),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP] = ACTIONS(120),
    [anon_sym_PIPE_PIPE] = ACTIONS(120),
    [anon_sym_GT_GT] = ACTIONS(120),
    [anon_sym_GT_GT_GT] = ACTIONS(120),
    [anon_sym_LT_LT] = ACTIONS(120),
    [anon_sym_AMP] = ACTIONS(120),
    [anon_sym_CARET] = ACTIONS(120),
    [anon_sym_PIPE] = ACTIONS(120),
    [anon_sym_PLUS] = ACTIONS(120),
    [anon_sym_DASH] = ACTIONS(120),
    [anon_sym_SLASH] = ACTIONS(120),
    [anon_sym_PERCENT] = ACTIONS(120),
    [anon_sym_STAR_STAR] = ACTIONS(120),
    [anon_sym_LT] = ACTIONS(2420),
    [anon_sym_LT_EQ] = ACTIONS(154),
    [anon_sym_EQ_EQ] = ACTIONS(120),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(154),
    [anon_sym_BANG_EQ] = ACTIONS(120),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(154),
    [anon_sym_GT_EQ] = ACTIONS(154),
    [anon_sym_GT] = ACTIONS(120),
    [anon_sym_QMARK_QMARK] = ACTIONS(120),
    [anon_sym_instanceof] = ACTIONS(120),
    [anon_sym_PLUS_PLUS] = ACTIONS(154),
    [anon_sym_DASH_DASH] = ACTIONS(154),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(154),
    [anon_sym_static] = ACTIONS(2425),
    [anon_sym_readonly] = ACTIONS(2425),
    [anon_sym_get] = ACTIONS(2425),
    [anon_sym_set] = ACTIONS(2425),
    [anon_sym_declare] = ACTIONS(2425),
    [anon_sym_public] = ACTIONS(2425),
    [anon_sym_private] = ACTIONS(2425),
    [anon_sym_protected] = ACTIONS(2425),
    [anon_sym_override] = ACTIONS(2425),
    [anon_sym_module] = ACTIONS(2425),
    [anon_sym_any] = ACTIONS(2425),
    [anon_sym_number] = ACTIONS(2425),
    [anon_sym_boolean] = ACTIONS(2425),
    [anon_sym_string] = ACTIONS(2425),
    [anon_sym_symbol] = ACTIONS(2425),
    [anon_sym_object] = ACTIONS(2425),
    [anon_sym_satisfies] = ACTIONS(120),
    [sym__ternary_qmark] = ACTIONS(154),
    [sym_html_comment] = ACTIONS(5),
  },
  [739] = {
    [sym__call_signature] = STATE(5814),
    [sym_formal_parameters] = STATE(3806),
    [sym_type_parameters] = STATE(5328),
    [sym_identifier] = ACTIONS(2439),
    [anon_sym_export] = ACTIONS(2441),
    [anon_sym_STAR] = ACTIONS(120),
    [anon_sym_type] = ACTIONS(2441),
    [anon_sym_EQ] = ACTIONS(880),
    [anon_sym_as] = ACTIONS(120),
    [anon_sym_namespace] = ACTIONS(2441),
    [anon_sym_COMMA] = ACTIONS(154),
    [anon_sym_let] = ACTIONS(2441),
    [anon_sym_BANG] = ACTIONS(120),
    [anon_sym_LPAREN] = ACTIONS(2415),
    [anon_sym_RPAREN] = ACTIONS(154),
    [anon_sym_in] = ACTIONS(120),
    [anon_sym_COLON] = ACTIONS(154),
    [anon_sym_LBRACK] = ACTIONS(154),
    [anon_sym_DOT] = ACTIONS(154),
    [anon_sym_async] = ACTIONS(2441),
    [anon_sym_function] = ACTIONS(2418),
    [anon_sym_EQ_GT] = ACTIONS(152),
    [anon_sym_QMARK_DOT] = ACTIONS(154),
    [anon_sym_new] = ACTIONS(2441),
    [anon_sym_PLUS_EQ] = ACTIONS(160),
    [anon_sym_DASH_EQ] = ACTIONS(160),
    [anon_sym_STAR_EQ] = ACTIONS(160),
    [anon_sym_SLASH_EQ] = ACTIONS(160),
    [anon_sym_PERCENT_EQ] = ACTIONS(160),
    [anon_sym_CARET_EQ] = ACTIONS(160),
    [anon_sym_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_LT_LT_EQ] = ACTIONS(160),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(160),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP] = ACTIONS(120),
    [anon_sym_PIPE_PIPE] = ACTIONS(120),
    [anon_sym_GT_GT] = ACTIONS(120),
    [anon_sym_GT_GT_GT] = ACTIONS(120),
    [anon_sym_LT_LT] = ACTIONS(120),
    [anon_sym_AMP] = ACTIONS(120),
    [anon_sym_CARET] = ACTIONS(120),
    [anon_sym_PIPE] = ACTIONS(120),
    [anon_sym_PLUS] = ACTIONS(120),
    [anon_sym_DASH] = ACTIONS(120),
    [anon_sym_SLASH] = ACTIONS(120),
    [anon_sym_PERCENT] = ACTIONS(120),
    [anon_sym_STAR_STAR] = ACTIONS(120),
    [anon_sym_LT] = ACTIONS(2420),
    [anon_sym_LT_EQ] = ACTIONS(154),
    [anon_sym_EQ_EQ] = ACTIONS(120),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(154),
    [anon_sym_BANG_EQ] = ACTIONS(120),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(154),
    [anon_sym_GT_EQ] = ACTIONS(154),
    [anon_sym_GT] = ACTIONS(120),
    [anon_sym_QMARK_QMARK] = ACTIONS(120),
    [anon_sym_instanceof] = ACTIONS(120),
    [anon_sym_PLUS_PLUS] = ACTIONS(154),
    [anon_sym_DASH_DASH] = ACTIONS(154),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(154),
    [anon_sym_static] = ACTIONS(2441),
    [anon_sym_readonly] = ACTIONS(2441),
    [anon_sym_get] = ACTIONS(2441),
    [anon_sym_set] = ACTIONS(2441),
    [anon_sym_declare] = ACTIONS(2441),
    [anon_sym_public] = ACTIONS(2441),
    [anon_sym_private] = ACTIONS(2441),
    [anon_sym_protected] = ACTIONS(2441),
    [anon_sym_override] = ACTIONS(2441),
    [anon_sym_module] = ACTIONS(2441),
    [anon_sym_any] = ACTIONS(2441),
    [anon_sym_number] = ACTIONS(2441),
    [anon_sym_boolean] = ACTIONS(2441),
    [anon_sym_string] = ACTIONS(2441),
    [anon_sym_symbol] = ACTIONS(2441),
    [anon_sym_object] = ACTIONS(2441),
    [anon_sym_satisfies] = ACTIONS(120),
    [sym__ternary_qmark] = ACTIONS(154),
    [sym_html_comment] = ACTIONS(5),
  },
  [740] = {
    [sym__call_signature] = STATE(5591),
    [sym_formal_parameters] = STATE(3806),
    [sym_type_parameters] = STATE(5328),
    [sym_identifier] = ACTIONS(2447),
    [anon_sym_export] = ACTIONS(2449),
    [anon_sym_STAR] = ACTIONS(120),
    [anon_sym_type] = ACTIONS(2449),
    [anon_sym_EQ] = ACTIONS(824),
    [anon_sym_as] = ACTIONS(120),
    [anon_sym_namespace] = ACTIONS(2449),
    [anon_sym_LBRACE] = ACTIONS(154),
    [anon_sym_COMMA] = ACTIONS(154),
    [anon_sym_let] = ACTIONS(2449),
    [anon_sym_BANG] = ACTIONS(120),
    [anon_sym_LPAREN] = ACTIONS(2415),
    [anon_sym_in] = ACTIONS(120),
    [anon_sym_LBRACK] = ACTIONS(154),
    [anon_sym_DOT] = ACTIONS(154),
    [anon_sym_async] = ACTIONS(2449),
    [anon_sym_function] = ACTIONS(2418),
    [anon_sym_EQ_GT] = ACTIONS(938),
    [anon_sym_QMARK_DOT] = ACTIONS(154),
    [anon_sym_new] = ACTIONS(2449),
    [anon_sym_PLUS_EQ] = ACTIONS(160),
    [anon_sym_DASH_EQ] = ACTIONS(160),
    [anon_sym_STAR_EQ] = ACTIONS(160),
    [anon_sym_SLASH_EQ] = ACTIONS(160),
    [anon_sym_PERCENT_EQ] = ACTIONS(160),
    [anon_sym_CARET_EQ] = ACTIONS(160),
    [anon_sym_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_LT_LT_EQ] = ACTIONS(160),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(160),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP] = ACTIONS(120),
    [anon_sym_PIPE_PIPE] = ACTIONS(120),
    [anon_sym_GT_GT] = ACTIONS(120),
    [anon_sym_GT_GT_GT] = ACTIONS(120),
    [anon_sym_LT_LT] = ACTIONS(120),
    [anon_sym_AMP] = ACTIONS(120),
    [anon_sym_CARET] = ACTIONS(120),
    [anon_sym_PIPE] = ACTIONS(120),
    [anon_sym_PLUS] = ACTIONS(120),
    [anon_sym_DASH] = ACTIONS(120),
    [anon_sym_SLASH] = ACTIONS(120),
    [anon_sym_PERCENT] = ACTIONS(120),
    [anon_sym_STAR_STAR] = ACTIONS(120),
    [anon_sym_LT] = ACTIONS(2420),
    [anon_sym_LT_EQ] = ACTIONS(154),
    [anon_sym_EQ_EQ] = ACTIONS(120),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(154),
    [anon_sym_BANG_EQ] = ACTIONS(120),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(154),
    [anon_sym_GT_EQ] = ACTIONS(154),
    [anon_sym_GT] = ACTIONS(120),
    [anon_sym_QMARK_QMARK] = ACTIONS(120),
    [anon_sym_instanceof] = ACTIONS(120),
    [anon_sym_PLUS_PLUS] = ACTIONS(154),
    [anon_sym_DASH_DASH] = ACTIONS(154),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(154),
    [anon_sym_static] = ACTIONS(2449),
    [anon_sym_readonly] = ACTIONS(2449),
    [anon_sym_get] = ACTIONS(2449),
    [anon_sym_set] = ACTIONS(2449),
    [anon_sym_declare] = ACTIONS(2449),
    [anon_sym_public] = ACTIONS(2449),
    [anon_sym_private] = ACTIONS(2449),
    [anon_sym_protected] = ACTIONS(2449),
    [anon_sym_override] = ACTIONS(2449),
    [anon_sym_module] = ACTIONS(2449),
    [anon_sym_any] = ACTIONS(2449),
    [anon_sym_number] = ACTIONS(2449),
    [anon_sym_boolean] = ACTIONS(2449),
    [anon_sym_string] = ACTIONS(2449),
    [anon_sym_symbol] = ACTIONS(2449),
    [anon_sym_object] = ACTIONS(2449),
    [anon_sym_satisfies] = ACTIONS(120),
    [anon_sym_implements] = ACTIONS(120),
    [sym__ternary_qmark] = ACTIONS(154),
    [sym_html_comment] = ACTIONS(5),
  },
  [741] = {
    [sym__call_signature] = STATE(5814),
    [sym_formal_parameters] = STATE(3806),
    [sym_type_parameters] = STATE(5328),
    [sym_identifier] = ACTIONS(2439),
    [anon_sym_export] = ACTIONS(2441),
    [anon_sym_STAR] = ACTIONS(120),
    [anon_sym_type] = ACTIONS(2441),
    [anon_sym_EQ] = ACTIONS(824),
    [anon_sym_as] = ACTIONS(120),
    [anon_sym_namespace] = ACTIONS(2441),
    [anon_sym_COMMA] = ACTIONS(154),
    [anon_sym_let] = ACTIONS(2441),
    [anon_sym_BANG] = ACTIONS(120),
    [anon_sym_LPAREN] = ACTIONS(2415),
    [anon_sym_RPAREN] = ACTIONS(154),
    [anon_sym_in] = ACTIONS(120),
    [anon_sym_COLON] = ACTIONS(154),
    [anon_sym_LBRACK] = ACTIONS(154),
    [anon_sym_DOT] = ACTIONS(154),
    [anon_sym_async] = ACTIONS(2441),
    [anon_sym_function] = ACTIONS(2418),
    [anon_sym_EQ_GT] = ACTIONS(152),
    [anon_sym_QMARK_DOT] = ACTIONS(154),
    [anon_sym_new] = ACTIONS(2441),
    [anon_sym_PLUS_EQ] = ACTIONS(160),
    [anon_sym_DASH_EQ] = ACTIONS(160),
    [anon_sym_STAR_EQ] = ACTIONS(160),
    [anon_sym_SLASH_EQ] = ACTIONS(160),
    [anon_sym_PERCENT_EQ] = ACTIONS(160),
    [anon_sym_CARET_EQ] = ACTIONS(160),
    [anon_sym_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_LT_LT_EQ] = ACTIONS(160),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(160),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP] = ACTIONS(120),
    [anon_sym_PIPE_PIPE] = ACTIONS(120),
    [anon_sym_GT_GT] = ACTIONS(120),
    [anon_sym_GT_GT_GT] = ACTIONS(120),
    [anon_sym_LT_LT] = ACTIONS(120),
    [anon_sym_AMP] = ACTIONS(120),
    [anon_sym_CARET] = ACTIONS(120),
    [anon_sym_PIPE] = ACTIONS(120),
    [anon_sym_PLUS] = ACTIONS(120),
    [anon_sym_DASH] = ACTIONS(120),
    [anon_sym_SLASH] = ACTIONS(120),
    [anon_sym_PERCENT] = ACTIONS(120),
    [anon_sym_STAR_STAR] = ACTIONS(120),
    [anon_sym_LT] = ACTIONS(2420),
    [anon_sym_LT_EQ] = ACTIONS(154),
    [anon_sym_EQ_EQ] = ACTIONS(120),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(154),
    [anon_sym_BANG_EQ] = ACTIONS(120),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(154),
    [anon_sym_GT_EQ] = ACTIONS(154),
    [anon_sym_GT] = ACTIONS(120),
    [anon_sym_QMARK_QMARK] = ACTIONS(120),
    [anon_sym_instanceof] = ACTIONS(120),
    [anon_sym_PLUS_PLUS] = ACTIONS(154),
    [anon_sym_DASH_DASH] = ACTIONS(154),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(154),
    [anon_sym_static] = ACTIONS(2441),
    [anon_sym_readonly] = ACTIONS(2441),
    [anon_sym_get] = ACTIONS(2441),
    [anon_sym_set] = ACTIONS(2441),
    [anon_sym_declare] = ACTIONS(2441),
    [anon_sym_public] = ACTIONS(2441),
    [anon_sym_private] = ACTIONS(2441),
    [anon_sym_protected] = ACTIONS(2441),
    [anon_sym_override] = ACTIONS(2441),
    [anon_sym_module] = ACTIONS(2441),
    [anon_sym_any] = ACTIONS(2441),
    [anon_sym_number] = ACTIONS(2441),
    [anon_sym_boolean] = ACTIONS(2441),
    [anon_sym_string] = ACTIONS(2441),
    [anon_sym_symbol] = ACTIONS(2441),
    [anon_sym_object] = ACTIONS(2441),
    [anon_sym_satisfies] = ACTIONS(120),
    [sym__ternary_qmark] = ACTIONS(154),
    [sym_html_comment] = ACTIONS(5),
  },
  [742] = {
    [sym__call_signature] = STATE(5594),
    [sym_formal_parameters] = STATE(3806),
    [sym_type_parameters] = STATE(5328),
    [sym_identifier] = ACTIONS(2423),
    [anon_sym_export] = ACTIONS(2425),
    [anon_sym_STAR] = ACTIONS(120),
    [anon_sym_type] = ACTIONS(2425),
    [anon_sym_EQ] = ACTIONS(834),
    [anon_sym_as] = ACTIONS(120),
    [anon_sym_namespace] = ACTIONS(2425),
    [anon_sym_COMMA] = ACTIONS(154),
    [anon_sym_let] = ACTIONS(2425),
    [anon_sym_BANG] = ACTIONS(120),
    [anon_sym_LPAREN] = ACTIONS(2415),
    [anon_sym_SEMI] = ACTIONS(154),
    [anon_sym_in] = ACTIONS(902),
    [anon_sym_of] = ACTIONS(905),
    [anon_sym_LBRACK] = ACTIONS(154),
    [anon_sym_DOT] = ACTIONS(154),
    [anon_sym_async] = ACTIONS(2425),
    [anon_sym_function] = ACTIONS(2418),
    [anon_sym_EQ_GT] = ACTIONS(844),
    [anon_sym_QMARK_DOT] = ACTIONS(154),
    [anon_sym_new] = ACTIONS(2425),
    [anon_sym_PLUS_EQ] = ACTIONS(160),
    [anon_sym_DASH_EQ] = ACTIONS(160),
    [anon_sym_STAR_EQ] = ACTIONS(160),
    [anon_sym_SLASH_EQ] = ACTIONS(160),
    [anon_sym_PERCENT_EQ] = ACTIONS(160),
    [anon_sym_CARET_EQ] = ACTIONS(160),
    [anon_sym_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_LT_LT_EQ] = ACTIONS(160),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(160),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP] = ACTIONS(120),
    [anon_sym_PIPE_PIPE] = ACTIONS(120),
    [anon_sym_GT_GT] = ACTIONS(120),
    [anon_sym_GT_GT_GT] = ACTIONS(120),
    [anon_sym_LT_LT] = ACTIONS(120),
    [anon_sym_AMP] = ACTIONS(120),
    [anon_sym_CARET] = ACTIONS(120),
    [anon_sym_PIPE] = ACTIONS(120),
    [anon_sym_PLUS] = ACTIONS(120),
    [anon_sym_DASH] = ACTIONS(120),
    [anon_sym_SLASH] = ACTIONS(120),
    [anon_sym_PERCENT] = ACTIONS(120),
    [anon_sym_STAR_STAR] = ACTIONS(120),
    [anon_sym_LT] = ACTIONS(2420),
    [anon_sym_LT_EQ] = ACTIONS(154),
    [anon_sym_EQ_EQ] = ACTIONS(120),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(154),
    [anon_sym_BANG_EQ] = ACTIONS(120),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(154),
    [anon_sym_GT_EQ] = ACTIONS(154),
    [anon_sym_GT] = ACTIONS(120),
    [anon_sym_QMARK_QMARK] = ACTIONS(120),
    [anon_sym_instanceof] = ACTIONS(120),
    [anon_sym_PLUS_PLUS] = ACTIONS(154),
    [anon_sym_DASH_DASH] = ACTIONS(154),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(154),
    [anon_sym_static] = ACTIONS(2425),
    [anon_sym_readonly] = ACTIONS(2425),
    [anon_sym_get] = ACTIONS(2425),
    [anon_sym_set] = ACTIONS(2425),
    [anon_sym_declare] = ACTIONS(2425),
    [anon_sym_public] = ACTIONS(2425),
    [anon_sym_private] = ACTIONS(2425),
    [anon_sym_protected] = ACTIONS(2425),
    [anon_sym_override] = ACTIONS(2425),
    [anon_sym_module] = ACTIONS(2425),
    [anon_sym_any] = ACTIONS(2425),
    [anon_sym_number] = ACTIONS(2425),
    [anon_sym_boolean] = ACTIONS(2425),
    [anon_sym_string] = ACTIONS(2425),
    [anon_sym_symbol] = ACTIONS(2425),
    [anon_sym_object] = ACTIONS(2425),
    [anon_sym_satisfies] = ACTIONS(120),
    [sym__ternary_qmark] = ACTIONS(154),
    [sym_html_comment] = ACTIONS(5),
  },
  [743] = {
    [sym__call_signature] = STATE(5601),
    [sym_formal_parameters] = STATE(3806),
    [sym_type_parameters] = STATE(5328),
    [sym_identifier] = ACTIONS(2451),
    [anon_sym_export] = ACTIONS(2453),
    [anon_sym_STAR] = ACTIONS(120),
    [anon_sym_type] = ACTIONS(2453),
    [anon_sym_EQ] = ACTIONS(918),
    [anon_sym_as] = ACTIONS(120),
    [anon_sym_namespace] = ACTIONS(2453),
    [anon_sym_let] = ACTIONS(2453),
    [anon_sym_BANG] = ACTIONS(120),
    [anon_sym_LPAREN] = ACTIONS(2415),
    [anon_sym_SEMI] = ACTIONS(154),
    [anon_sym_in] = ACTIONS(120),
    [anon_sym_LBRACK] = ACTIONS(154),
    [anon_sym_DOT] = ACTIONS(154),
    [anon_sym_async] = ACTIONS(2453),
    [anon_sym_function] = ACTIONS(2433),
    [anon_sym_EQ_GT] = ACTIONS(924),
    [anon_sym_QMARK_DOT] = ACTIONS(154),
    [anon_sym_new] = ACTIONS(2453),
    [anon_sym_PLUS_EQ] = ACTIONS(160),
    [anon_sym_DASH_EQ] = ACTIONS(160),
    [anon_sym_STAR_EQ] = ACTIONS(160),
    [anon_sym_SLASH_EQ] = ACTIONS(160),
    [anon_sym_PERCENT_EQ] = ACTIONS(160),
    [anon_sym_CARET_EQ] = ACTIONS(160),
    [anon_sym_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_LT_LT_EQ] = ACTIONS(160),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(160),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP] = ACTIONS(120),
    [anon_sym_PIPE_PIPE] = ACTIONS(120),
    [anon_sym_GT_GT] = ACTIONS(120),
    [anon_sym_GT_GT_GT] = ACTIONS(120),
    [anon_sym_LT_LT] = ACTIONS(120),
    [anon_sym_AMP] = ACTIONS(120),
    [anon_sym_CARET] = ACTIONS(120),
    [anon_sym_PIPE] = ACTIONS(120),
    [anon_sym_PLUS] = ACTIONS(120),
    [anon_sym_DASH] = ACTIONS(120),
    [anon_sym_SLASH] = ACTIONS(120),
    [anon_sym_PERCENT] = ACTIONS(120),
    [anon_sym_STAR_STAR] = ACTIONS(120),
    [anon_sym_LT] = ACTIONS(2420),
    [anon_sym_LT_EQ] = ACTIONS(154),
    [anon_sym_EQ_EQ] = ACTIONS(120),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(154),
    [anon_sym_BANG_EQ] = ACTIONS(120),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(154),
    [anon_sym_GT_EQ] = ACTIONS(154),
    [anon_sym_GT] = ACTIONS(120),
    [anon_sym_QMARK_QMARK] = ACTIONS(120),
    [anon_sym_instanceof] = ACTIONS(120),
    [anon_sym_PLUS_PLUS] = ACTIONS(154),
    [anon_sym_DASH_DASH] = ACTIONS(154),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(154),
    [anon_sym_static] = ACTIONS(2453),
    [anon_sym_readonly] = ACTIONS(2453),
    [anon_sym_get] = ACTIONS(2453),
    [anon_sym_set] = ACTIONS(2453),
    [anon_sym_declare] = ACTIONS(2453),
    [anon_sym_public] = ACTIONS(2453),
    [anon_sym_private] = ACTIONS(2453),
    [anon_sym_protected] = ACTIONS(2453),
    [anon_sym_override] = ACTIONS(2453),
    [anon_sym_module] = ACTIONS(2453),
    [anon_sym_any] = ACTIONS(2453),
    [anon_sym_number] = ACTIONS(2453),
    [anon_sym_boolean] = ACTIONS(2453),
    [anon_sym_string] = ACTIONS(2453),
    [anon_sym_symbol] = ACTIONS(2453),
    [anon_sym_object] = ACTIONS(2453),
    [anon_sym_satisfies] = ACTIONS(120),
    [sym__automatic_semicolon] = ACTIONS(154),
    [sym__ternary_qmark] = ACTIONS(154),
    [sym_html_comment] = ACTIONS(5),
  },
  [744] = {
    [sym__call_signature] = STATE(5481),
    [sym_formal_parameters] = STATE(3806),
    [sym_type_parameters] = STATE(5328),
    [sym_identifier] = ACTIONS(2443),
    [anon_sym_export] = ACTIONS(2445),
    [anon_sym_STAR] = ACTIONS(120),
    [anon_sym_type] = ACTIONS(2445),
    [anon_sym_EQ] = ACTIONS(910),
    [anon_sym_as] = ACTIONS(120),
    [anon_sym_namespace] = ACTIONS(2445),
    [anon_sym_let] = ACTIONS(2445),
    [anon_sym_BANG] = ACTIONS(120),
    [anon_sym_LPAREN] = ACTIONS(2415),
    [anon_sym_in] = ACTIONS(120),
    [anon_sym_COLON] = ACTIONS(891),
    [anon_sym_LBRACK] = ACTIONS(154),
    [anon_sym_RBRACK] = ACTIONS(154),
    [anon_sym_DOT] = ACTIONS(154),
    [anon_sym_async] = ACTIONS(2445),
    [anon_sym_function] = ACTIONS(2418),
    [anon_sym_EQ_GT] = ACTIONS(895),
    [anon_sym_QMARK_DOT] = ACTIONS(154),
    [anon_sym_new] = ACTIONS(2445),
    [anon_sym_PLUS_EQ] = ACTIONS(160),
    [anon_sym_DASH_EQ] = ACTIONS(160),
    [anon_sym_STAR_EQ] = ACTIONS(160),
    [anon_sym_SLASH_EQ] = ACTIONS(160),
    [anon_sym_PERCENT_EQ] = ACTIONS(160),
    [anon_sym_CARET_EQ] = ACTIONS(160),
    [anon_sym_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_LT_LT_EQ] = ACTIONS(160),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(160),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP] = ACTIONS(120),
    [anon_sym_PIPE_PIPE] = ACTIONS(120),
    [anon_sym_GT_GT] = ACTIONS(120),
    [anon_sym_GT_GT_GT] = ACTIONS(120),
    [anon_sym_LT_LT] = ACTIONS(120),
    [anon_sym_AMP] = ACTIONS(120),
    [anon_sym_CARET] = ACTIONS(120),
    [anon_sym_PIPE] = ACTIONS(120),
    [anon_sym_PLUS] = ACTIONS(120),
    [anon_sym_DASH] = ACTIONS(120),
    [anon_sym_SLASH] = ACTIONS(120),
    [anon_sym_PERCENT] = ACTIONS(120),
    [anon_sym_STAR_STAR] = ACTIONS(120),
    [anon_sym_LT] = ACTIONS(2420),
    [anon_sym_LT_EQ] = ACTIONS(154),
    [anon_sym_EQ_EQ] = ACTIONS(120),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(154),
    [anon_sym_BANG_EQ] = ACTIONS(120),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(154),
    [anon_sym_GT_EQ] = ACTIONS(154),
    [anon_sym_GT] = ACTIONS(120),
    [anon_sym_QMARK_QMARK] = ACTIONS(120),
    [anon_sym_instanceof] = ACTIONS(120),
    [anon_sym_PLUS_PLUS] = ACTIONS(154),
    [anon_sym_DASH_DASH] = ACTIONS(154),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(154),
    [anon_sym_static] = ACTIONS(2445),
    [anon_sym_readonly] = ACTIONS(2445),
    [anon_sym_get] = ACTIONS(2445),
    [anon_sym_set] = ACTIONS(2445),
    [anon_sym_declare] = ACTIONS(2445),
    [anon_sym_public] = ACTIONS(2445),
    [anon_sym_private] = ACTIONS(2445),
    [anon_sym_protected] = ACTIONS(2445),
    [anon_sym_override] = ACTIONS(2445),
    [anon_sym_module] = ACTIONS(2445),
    [anon_sym_any] = ACTIONS(2445),
    [anon_sym_number] = ACTIONS(2445),
    [anon_sym_boolean] = ACTIONS(2445),
    [anon_sym_string] = ACTIONS(2445),
    [anon_sym_symbol] = ACTIONS(2445),
    [anon_sym_object] = ACTIONS(2445),
    [anon_sym_satisfies] = ACTIONS(120),
    [sym__ternary_qmark] = ACTIONS(154),
    [sym_html_comment] = ACTIONS(5),
  },
  [745] = {
    [sym_catch_clause] = STATE(770),
    [sym_finally_clause] = STATE(914),
    [ts_builtin_sym_end] = ACTIONS(2455),
    [sym_identifier] = ACTIONS(2457),
    [anon_sym_export] = ACTIONS(2457),
    [anon_sym_default] = ACTIONS(2457),
    [anon_sym_type] = ACTIONS(2457),
    [anon_sym_namespace] = ACTIONS(2457),
    [anon_sym_LBRACE] = ACTIONS(2455),
    [anon_sym_RBRACE] = ACTIONS(2455),
    [anon_sym_typeof] = ACTIONS(2457),
    [anon_sym_import] = ACTIONS(2457),
    [anon_sym_with] = ACTIONS(2457),
    [anon_sym_var] = ACTIONS(2457),
    [anon_sym_let] = ACTIONS(2457),
    [anon_sym_const] = ACTIONS(2457),
    [anon_sym_BANG] = ACTIONS(2455),
    [anon_sym_else] = ACTIONS(2457),
    [anon_sym_if] = ACTIONS(2457),
    [anon_sym_switch] = ACTIONS(2457),
    [anon_sym_for] = ACTIONS(2457),
    [anon_sym_LPAREN] = ACTIONS(2455),
    [anon_sym_SEMI] = ACTIONS(2455),
    [anon_sym_await] = ACTIONS(2457),
    [anon_sym_while] = ACTIONS(2457),
    [anon_sym_do] = ACTIONS(2457),
    [anon_sym_try] = ACTIONS(2457),
    [anon_sym_break] = ACTIONS(2457),
    [anon_sym_continue] = ACTIONS(2457),
    [anon_sym_debugger] = ACTIONS(2457),
    [anon_sym_return] = ACTIONS(2457),
    [anon_sym_throw] = ACTIONS(2457),
    [anon_sym_case] = ACTIONS(2457),
    [anon_sym_catch] = ACTIONS(2459),
    [anon_sym_finally] = ACTIONS(2461),
    [anon_sym_yield] = ACTIONS(2457),
    [anon_sym_LBRACK] = ACTIONS(2455),
    [anon_sym_class] = ACTIONS(2457),
    [anon_sym_async] = ACTIONS(2457),
    [anon_sym_function] = ACTIONS(2457),
    [anon_sym_new] = ACTIONS(2457),
    [anon_sym_using] = ACTIONS(2457),
    [anon_sym_PLUS] = ACTIONS(2457),
    [anon_sym_DASH] = ACTIONS(2457),
    [anon_sym_SLASH] = ACTIONS(2457),
    [anon_sym_LT] = ACTIONS(2455),
    [anon_sym_TILDE] = ACTIONS(2455),
    [anon_sym_void] = ACTIONS(2457),
    [anon_sym_delete] = ACTIONS(2457),
    [anon_sym_PLUS_PLUS] = ACTIONS(2455),
    [anon_sym_DASH_DASH] = ACTIONS(2455),
    [anon_sym_DQUOTE] = ACTIONS(2455),
    [anon_sym_SQUOTE] = ACTIONS(2455),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(2455),
    [sym_number] = ACTIONS(2455),
    [sym_private_property_identifier] = ACTIONS(2455),
    [sym_this] = ACTIONS(2457),
    [sym_super] = ACTIONS(2457),
    [sym_true] = ACTIONS(2457),
    [sym_false] = ACTIONS(2457),
    [sym_null] = ACTIONS(2457),
    [sym_undefined] = ACTIONS(2457),
    [anon_sym_AT] = ACTIONS(2455),
    [anon_sym_static] = ACTIONS(2457),
    [anon_sym_readonly] = ACTIONS(2457),
    [anon_sym_get] = ACTIONS(2457),
    [anon_sym_set] = ACTIONS(2457),
    [anon_sym_declare] = ACTIONS(2457),
    [anon_sym_public] = ACTIONS(2457),
    [anon_sym_private] = ACTIONS(2457),
    [anon_sym_protected] = ACTIONS(2457),
    [anon_sym_override] = ACTIONS(2457),
    [anon_sym_module] = ACTIONS(2457),
    [anon_sym_any] = ACTIONS(2457),
    [anon_sym_number] = ACTIONS(2457),
    [anon_sym_boolean] = ACTIONS(2457),
    [anon_sym_string] = ACTIONS(2457),
    [anon_sym_symbol] = ACTIONS(2457),
    [anon_sym_object] = ACTIONS(2457),
    [anon_sym_abstract] = ACTIONS(2457),
    [anon_sym_interface] = ACTIONS(2457),
    [anon_sym_enum] = ACTIONS(2457),
    [sym_html_comment] = ACTIONS(5),
  },
  [746] = {
    [sym__call_signature] = STATE(5481),
    [sym_formal_parameters] = STATE(3806),
    [sym_type_parameters] = STATE(5328),
    [sym_identifier] = ACTIONS(2443),
    [anon_sym_export] = ACTIONS(2445),
    [anon_sym_STAR] = ACTIONS(120),
    [anon_sym_type] = ACTIONS(2445),
    [anon_sym_EQ] = ACTIONS(910),
    [anon_sym_as] = ACTIONS(120),
    [anon_sym_namespace] = ACTIONS(2445),
    [anon_sym_let] = ACTIONS(2445),
    [anon_sym_BANG] = ACTIONS(120),
    [anon_sym_LPAREN] = ACTIONS(2415),
    [anon_sym_in] = ACTIONS(120),
    [anon_sym_COLON] = ACTIONS(912),
    [anon_sym_LBRACK] = ACTIONS(154),
    [anon_sym_RBRACK] = ACTIONS(154),
    [anon_sym_DOT] = ACTIONS(154),
    [anon_sym_async] = ACTIONS(2445),
    [anon_sym_function] = ACTIONS(2418),
    [anon_sym_EQ_GT] = ACTIONS(895),
    [anon_sym_QMARK_DOT] = ACTIONS(154),
    [anon_sym_new] = ACTIONS(2445),
    [anon_sym_PLUS_EQ] = ACTIONS(160),
    [anon_sym_DASH_EQ] = ACTIONS(160),
    [anon_sym_STAR_EQ] = ACTIONS(160),
    [anon_sym_SLASH_EQ] = ACTIONS(160),
    [anon_sym_PERCENT_EQ] = ACTIONS(160),
    [anon_sym_CARET_EQ] = ACTIONS(160),
    [anon_sym_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_LT_LT_EQ] = ACTIONS(160),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(160),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP] = ACTIONS(120),
    [anon_sym_PIPE_PIPE] = ACTIONS(120),
    [anon_sym_GT_GT] = ACTIONS(120),
    [anon_sym_GT_GT_GT] = ACTIONS(120),
    [anon_sym_LT_LT] = ACTIONS(120),
    [anon_sym_AMP] = ACTIONS(120),
    [anon_sym_CARET] = ACTIONS(120),
    [anon_sym_PIPE] = ACTIONS(120),
    [anon_sym_PLUS] = ACTIONS(120),
    [anon_sym_DASH] = ACTIONS(120),
    [anon_sym_SLASH] = ACTIONS(120),
    [anon_sym_PERCENT] = ACTIONS(120),
    [anon_sym_STAR_STAR] = ACTIONS(120),
    [anon_sym_LT] = ACTIONS(2420),
    [anon_sym_LT_EQ] = ACTIONS(154),
    [anon_sym_EQ_EQ] = ACTIONS(120),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(154),
    [anon_sym_BANG_EQ] = ACTIONS(120),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(154),
    [anon_sym_GT_EQ] = ACTIONS(154),
    [anon_sym_GT] = ACTIONS(120),
    [anon_sym_QMARK_QMARK] = ACTIONS(120),
    [anon_sym_instanceof] = ACTIONS(120),
    [anon_sym_PLUS_PLUS] = ACTIONS(154),
    [anon_sym_DASH_DASH] = ACTIONS(154),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(154),
    [anon_sym_static] = ACTIONS(2445),
    [anon_sym_readonly] = ACTIONS(2445),
    [anon_sym_get] = ACTIONS(2445),
    [anon_sym_set] = ACTIONS(2445),
    [anon_sym_declare] = ACTIONS(2445),
    [anon_sym_public] = ACTIONS(2445),
    [anon_sym_private] = ACTIONS(2445),
    [anon_sym_protected] = ACTIONS(2445),
    [anon_sym_override] = ACTIONS(2445),
    [anon_sym_module] = ACTIONS(2445),
    [anon_sym_any] = ACTIONS(2445),
    [anon_sym_number] = ACTIONS(2445),
    [anon_sym_boolean] = ACTIONS(2445),
    [anon_sym_string] = ACTIONS(2445),
    [anon_sym_symbol] = ACTIONS(2445),
    [anon_sym_object] = ACTIONS(2445),
    [anon_sym_satisfies] = ACTIONS(120),
    [sym__ternary_qmark] = ACTIONS(154),
    [sym_html_comment] = ACTIONS(5),
  },
  [747] = {
    [ts_builtin_sym_end] = ACTIONS(1690),
    [sym_identifier] = ACTIONS(1692),
    [anon_sym_export] = ACTIONS(1692),
    [anon_sym_default] = ACTIONS(1692),
    [anon_sym_type] = ACTIONS(1692),
    [anon_sym_namespace] = ACTIONS(1692),
    [anon_sym_LBRACE] = ACTIONS(1690),
    [anon_sym_COMMA] = ACTIONS(1690),
    [anon_sym_RBRACE] = ACTIONS(1690),
    [anon_sym_typeof] = ACTIONS(1692),
    [anon_sym_import] = ACTIONS(1692),
    [anon_sym_with] = ACTIONS(1692),
    [anon_sym_var] = ACTIONS(1692),
    [anon_sym_let] = ACTIONS(1692),
    [anon_sym_const] = ACTIONS(1692),
    [anon_sym_BANG] = ACTIONS(1690),
    [anon_sym_else] = ACTIONS(1692),
    [anon_sym_if] = ACTIONS(1692),
    [anon_sym_switch] = ACTIONS(1692),
    [anon_sym_for] = ACTIONS(1692),
    [anon_sym_LPAREN] = ACTIONS(1690),
    [anon_sym_SEMI] = ACTIONS(1690),
    [anon_sym_await] = ACTIONS(1692),
    [anon_sym_while] = ACTIONS(1692),
    [anon_sym_do] = ACTIONS(1692),
    [anon_sym_try] = ACTIONS(1692),
    [anon_sym_break] = ACTIONS(1692),
    [anon_sym_continue] = ACTIONS(1692),
    [anon_sym_debugger] = ACTIONS(1692),
    [anon_sym_return] = ACTIONS(1692),
    [anon_sym_throw] = ACTIONS(1692),
    [anon_sym_case] = ACTIONS(1692),
    [anon_sym_catch] = ACTIONS(1692),
    [anon_sym_finally] = ACTIONS(1692),
    [anon_sym_yield] = ACTIONS(1692),
    [anon_sym_LBRACK] = ACTIONS(1690),
    [anon_sym_class] = ACTIONS(1692),
    [anon_sym_async] = ACTIONS(1692),
    [anon_sym_function] = ACTIONS(1692),
    [anon_sym_new] = ACTIONS(1692),
    [anon_sym_using] = ACTIONS(1692),
    [anon_sym_PLUS] = ACTIONS(1692),
    [anon_sym_DASH] = ACTIONS(1692),
    [anon_sym_SLASH] = ACTIONS(1692),
    [anon_sym_LT] = ACTIONS(1690),
    [anon_sym_TILDE] = ACTIONS(1690),
    [anon_sym_void] = ACTIONS(1692),
    [anon_sym_delete] = ACTIONS(1692),
    [anon_sym_PLUS_PLUS] = ACTIONS(1690),
    [anon_sym_DASH_DASH] = ACTIONS(1690),
    [anon_sym_DQUOTE] = ACTIONS(1690),
    [anon_sym_SQUOTE] = ACTIONS(1690),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1690),
    [sym_number] = ACTIONS(1690),
    [sym_private_property_identifier] = ACTIONS(1690),
    [sym_this] = ACTIONS(1692),
    [sym_super] = ACTIONS(1692),
    [sym_true] = ACTIONS(1692),
    [sym_false] = ACTIONS(1692),
    [sym_null] = ACTIONS(1692),
    [sym_undefined] = ACTIONS(1692),
    [anon_sym_AT] = ACTIONS(1690),
    [anon_sym_static] = ACTIONS(1692),
    [anon_sym_readonly] = ACTIONS(1692),
    [anon_sym_get] = ACTIONS(1692),
    [anon_sym_set] = ACTIONS(1692),
    [anon_sym_declare] = ACTIONS(1692),
    [anon_sym_public] = ACTIONS(1692),
    [anon_sym_private] = ACTIONS(1692),
    [anon_sym_protected] = ACTIONS(1692),
    [anon_sym_override] = ACTIONS(1692),
    [anon_sym_module] = ACTIONS(1692),
    [anon_sym_any] = ACTIONS(1692),
    [anon_sym_number] = ACTIONS(1692),
    [anon_sym_boolean] = ACTIONS(1692),
    [anon_sym_string] = ACTIONS(1692),
    [anon_sym_symbol] = ACTIONS(1692),
    [anon_sym_object] = ACTIONS(1692),
    [anon_sym_abstract] = ACTIONS(1692),
    [anon_sym_interface] = ACTIONS(1692),
    [anon_sym_enum] = ACTIONS(1692),
    [sym__automatic_semicolon] = ACTIONS(1700),
    [sym_html_comment] = ACTIONS(5),
  },
  [748] = {
    [sym__call_signature] = STATE(5601),
    [sym_formal_parameters] = STATE(3806),
    [sym_type_parameters] = STATE(5328),
    [sym_identifier] = ACTIONS(2451),
    [anon_sym_export] = ACTIONS(2453),
    [anon_sym_STAR] = ACTIONS(120),
    [anon_sym_type] = ACTIONS(2453),
    [anon_sym_EQ] = ACTIONS(824),
    [anon_sym_as] = ACTIONS(120),
    [anon_sym_namespace] = ACTIONS(2453),
    [anon_sym_let] = ACTIONS(2453),
    [anon_sym_BANG] = ACTIONS(120),
    [anon_sym_LPAREN] = ACTIONS(2415),
    [anon_sym_SEMI] = ACTIONS(154),
    [anon_sym_in] = ACTIONS(120),
    [anon_sym_LBRACK] = ACTIONS(154),
    [anon_sym_DOT] = ACTIONS(154),
    [anon_sym_async] = ACTIONS(2453),
    [anon_sym_function] = ACTIONS(2433),
    [anon_sym_EQ_GT] = ACTIONS(924),
    [anon_sym_QMARK_DOT] = ACTIONS(154),
    [anon_sym_new] = ACTIONS(2453),
    [anon_sym_PLUS_EQ] = ACTIONS(160),
    [anon_sym_DASH_EQ] = ACTIONS(160),
    [anon_sym_STAR_EQ] = ACTIONS(160),
    [anon_sym_SLASH_EQ] = ACTIONS(160),
    [anon_sym_PERCENT_EQ] = ACTIONS(160),
    [anon_sym_CARET_EQ] = ACTIONS(160),
    [anon_sym_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_LT_LT_EQ] = ACTIONS(160),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(160),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP] = ACTIONS(120),
    [anon_sym_PIPE_PIPE] = ACTIONS(120),
    [anon_sym_GT_GT] = ACTIONS(120),
    [anon_sym_GT_GT_GT] = ACTIONS(120),
    [anon_sym_LT_LT] = ACTIONS(120),
    [anon_sym_AMP] = ACTIONS(120),
    [anon_sym_CARET] = ACTIONS(120),
    [anon_sym_PIPE] = ACTIONS(120),
    [anon_sym_PLUS] = ACTIONS(120),
    [anon_sym_DASH] = ACTIONS(120),
    [anon_sym_SLASH] = ACTIONS(120),
    [anon_sym_PERCENT] = ACTIONS(120),
    [anon_sym_STAR_STAR] = ACTIONS(120),
    [anon_sym_LT] = ACTIONS(2420),
    [anon_sym_LT_EQ] = ACTIONS(154),
    [anon_sym_EQ_EQ] = ACTIONS(120),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(154),
    [anon_sym_BANG_EQ] = ACTIONS(120),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(154),
    [anon_sym_GT_EQ] = ACTIONS(154),
    [anon_sym_GT] = ACTIONS(120),
    [anon_sym_QMARK_QMARK] = ACTIONS(120),
    [anon_sym_instanceof] = ACTIONS(120),
    [anon_sym_PLUS_PLUS] = ACTIONS(154),
    [anon_sym_DASH_DASH] = ACTIONS(154),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(154),
    [anon_sym_static] = ACTIONS(2453),
    [anon_sym_readonly] = ACTIONS(2453),
    [anon_sym_get] = ACTIONS(2453),
    [anon_sym_set] = ACTIONS(2453),
    [anon_sym_declare] = ACTIONS(2453),
    [anon_sym_public] = ACTIONS(2453),
    [anon_sym_private] = ACTIONS(2453),
    [anon_sym_protected] = ACTIONS(2453),
    [anon_sym_override] = ACTIONS(2453),
    [anon_sym_module] = ACTIONS(2453),
    [anon_sym_any] = ACTIONS(2453),
    [anon_sym_number] = ACTIONS(2453),
    [anon_sym_boolean] = ACTIONS(2453),
    [anon_sym_string] = ACTIONS(2453),
    [anon_sym_symbol] = ACTIONS(2453),
    [anon_sym_object] = ACTIONS(2453),
    [anon_sym_satisfies] = ACTIONS(120),
    [sym__automatic_semicolon] = ACTIONS(154),
    [sym__ternary_qmark] = ACTIONS(154),
    [sym_html_comment] = ACTIONS(5),
  },
  [749] = {
    [sym__call_signature] = STATE(5601),
    [sym_formal_parameters] = STATE(3806),
    [sym_type_parameters] = STATE(5328),
    [sym_identifier] = ACTIONS(2451),
    [anon_sym_export] = ACTIONS(2453),
    [anon_sym_STAR] = ACTIONS(120),
    [anon_sym_type] = ACTIONS(2453),
    [anon_sym_EQ] = ACTIONS(918),
    [anon_sym_as] = ACTIONS(120),
    [anon_sym_namespace] = ACTIONS(2453),
    [anon_sym_let] = ACTIONS(2453),
    [anon_sym_BANG] = ACTIONS(120),
    [anon_sym_LPAREN] = ACTIONS(2415),
    [anon_sym_SEMI] = ACTIONS(154),
    [anon_sym_in] = ACTIONS(120),
    [anon_sym_LBRACK] = ACTIONS(154),
    [anon_sym_DOT] = ACTIONS(154),
    [anon_sym_async] = ACTIONS(2453),
    [anon_sym_function] = ACTIONS(2463),
    [anon_sym_EQ_GT] = ACTIONS(924),
    [anon_sym_QMARK_DOT] = ACTIONS(154),
    [anon_sym_new] = ACTIONS(2453),
    [anon_sym_PLUS_EQ] = ACTIONS(160),
    [anon_sym_DASH_EQ] = ACTIONS(160),
    [anon_sym_STAR_EQ] = ACTIONS(160),
    [anon_sym_SLASH_EQ] = ACTIONS(160),
    [anon_sym_PERCENT_EQ] = ACTIONS(160),
    [anon_sym_CARET_EQ] = ACTIONS(160),
    [anon_sym_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_LT_LT_EQ] = ACTIONS(160),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(160),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP] = ACTIONS(120),
    [anon_sym_PIPE_PIPE] = ACTIONS(120),
    [anon_sym_GT_GT] = ACTIONS(120),
    [anon_sym_GT_GT_GT] = ACTIONS(120),
    [anon_sym_LT_LT] = ACTIONS(120),
    [anon_sym_AMP] = ACTIONS(120),
    [anon_sym_CARET] = ACTIONS(120),
    [anon_sym_PIPE] = ACTIONS(120),
    [anon_sym_PLUS] = ACTIONS(120),
    [anon_sym_DASH] = ACTIONS(120),
    [anon_sym_SLASH] = ACTIONS(120),
    [anon_sym_PERCENT] = ACTIONS(120),
    [anon_sym_STAR_STAR] = ACTIONS(120),
    [anon_sym_LT] = ACTIONS(2420),
    [anon_sym_LT_EQ] = ACTIONS(154),
    [anon_sym_EQ_EQ] = ACTIONS(120),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(154),
    [anon_sym_BANG_EQ] = ACTIONS(120),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(154),
    [anon_sym_GT_EQ] = ACTIONS(154),
    [anon_sym_GT] = ACTIONS(120),
    [anon_sym_QMARK_QMARK] = ACTIONS(120),
    [anon_sym_instanceof] = ACTIONS(120),
    [anon_sym_PLUS_PLUS] = ACTIONS(154),
    [anon_sym_DASH_DASH] = ACTIONS(154),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(154),
    [anon_sym_static] = ACTIONS(2453),
    [anon_sym_readonly] = ACTIONS(2453),
    [anon_sym_get] = ACTIONS(2453),
    [anon_sym_set] = ACTIONS(2453),
    [anon_sym_declare] = ACTIONS(2453),
    [anon_sym_public] = ACTIONS(2453),
    [anon_sym_private] = ACTIONS(2453),
    [anon_sym_protected] = ACTIONS(2453),
    [anon_sym_override] = ACTIONS(2453),
    [anon_sym_module] = ACTIONS(2453),
    [anon_sym_any] = ACTIONS(2453),
    [anon_sym_number] = ACTIONS(2453),
    [anon_sym_boolean] = ACTIONS(2453),
    [anon_sym_string] = ACTIONS(2453),
    [anon_sym_symbol] = ACTIONS(2453),
    [anon_sym_object] = ACTIONS(2453),
    [anon_sym_satisfies] = ACTIONS(120),
    [sym__automatic_semicolon] = ACTIONS(154),
    [sym__ternary_qmark] = ACTIONS(154),
    [sym_html_comment] = ACTIONS(5),
  },
  [750] = {
    [sym__call_signature] = STATE(5601),
    [sym_formal_parameters] = STATE(3806),
    [sym_type_parameters] = STATE(5328),
    [sym_identifier] = ACTIONS(2451),
    [anon_sym_export] = ACTIONS(2453),
    [anon_sym_STAR] = ACTIONS(120),
    [anon_sym_type] = ACTIONS(2453),
    [anon_sym_EQ] = ACTIONS(918),
    [anon_sym_as] = ACTIONS(120),
    [anon_sym_namespace] = ACTIONS(2453),
    [anon_sym_let] = ACTIONS(2453),
    [anon_sym_BANG] = ACTIONS(120),
    [anon_sym_LPAREN] = ACTIONS(2415),
    [anon_sym_SEMI] = ACTIONS(154),
    [anon_sym_in] = ACTIONS(120),
    [anon_sym_LBRACK] = ACTIONS(154),
    [anon_sym_DOT] = ACTIONS(154),
    [anon_sym_async] = ACTIONS(2453),
    [anon_sym_function] = ACTIONS(2331),
    [anon_sym_EQ_GT] = ACTIONS(924),
    [anon_sym_QMARK_DOT] = ACTIONS(154),
    [anon_sym_new] = ACTIONS(2453),
    [anon_sym_PLUS_EQ] = ACTIONS(160),
    [anon_sym_DASH_EQ] = ACTIONS(160),
    [anon_sym_STAR_EQ] = ACTIONS(160),
    [anon_sym_SLASH_EQ] = ACTIONS(160),
    [anon_sym_PERCENT_EQ] = ACTIONS(160),
    [anon_sym_CARET_EQ] = ACTIONS(160),
    [anon_sym_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_LT_LT_EQ] = ACTIONS(160),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(160),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP] = ACTIONS(120),
    [anon_sym_PIPE_PIPE] = ACTIONS(120),
    [anon_sym_GT_GT] = ACTIONS(120),
    [anon_sym_GT_GT_GT] = ACTIONS(120),
    [anon_sym_LT_LT] = ACTIONS(120),
    [anon_sym_AMP] = ACTIONS(120),
    [anon_sym_CARET] = ACTIONS(120),
    [anon_sym_PIPE] = ACTIONS(120),
    [anon_sym_PLUS] = ACTIONS(120),
    [anon_sym_DASH] = ACTIONS(120),
    [anon_sym_SLASH] = ACTIONS(120),
    [anon_sym_PERCENT] = ACTIONS(120),
    [anon_sym_STAR_STAR] = ACTIONS(120),
    [anon_sym_LT] = ACTIONS(2420),
    [anon_sym_LT_EQ] = ACTIONS(154),
    [anon_sym_EQ_EQ] = ACTIONS(120),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(154),
    [anon_sym_BANG_EQ] = ACTIONS(120),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(154),
    [anon_sym_GT_EQ] = ACTIONS(154),
    [anon_sym_GT] = ACTIONS(120),
    [anon_sym_QMARK_QMARK] = ACTIONS(120),
    [anon_sym_instanceof] = ACTIONS(120),
    [anon_sym_PLUS_PLUS] = ACTIONS(154),
    [anon_sym_DASH_DASH] = ACTIONS(154),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(154),
    [anon_sym_static] = ACTIONS(2453),
    [anon_sym_readonly] = ACTIONS(2453),
    [anon_sym_get] = ACTIONS(2453),
    [anon_sym_set] = ACTIONS(2453),
    [anon_sym_declare] = ACTIONS(2453),
    [anon_sym_public] = ACTIONS(2453),
    [anon_sym_private] = ACTIONS(2453),
    [anon_sym_protected] = ACTIONS(2453),
    [anon_sym_override] = ACTIONS(2453),
    [anon_sym_module] = ACTIONS(2453),
    [anon_sym_any] = ACTIONS(2453),
    [anon_sym_number] = ACTIONS(2453),
    [anon_sym_boolean] = ACTIONS(2453),
    [anon_sym_string] = ACTIONS(2453),
    [anon_sym_symbol] = ACTIONS(2453),
    [anon_sym_object] = ACTIONS(2453),
    [anon_sym_satisfies] = ACTIONS(120),
    [sym__automatic_semicolon] = ACTIONS(154),
    [sym__ternary_qmark] = ACTIONS(154),
    [sym_html_comment] = ACTIONS(5),
  },
  [751] = {
    [sym__call_signature] = STATE(5481),
    [sym_formal_parameters] = STATE(3806),
    [sym_type_parameters] = STATE(5328),
    [sym_identifier] = ACTIONS(2443),
    [anon_sym_export] = ACTIONS(2445),
    [anon_sym_STAR] = ACTIONS(120),
    [anon_sym_type] = ACTIONS(2445),
    [anon_sym_EQ] = ACTIONS(886),
    [anon_sym_as] = ACTIONS(120),
    [anon_sym_namespace] = ACTIONS(2445),
    [anon_sym_COMMA] = ACTIONS(223),
    [anon_sym_let] = ACTIONS(2445),
    [anon_sym_BANG] = ACTIONS(120),
    [anon_sym_LPAREN] = ACTIONS(2415),
    [anon_sym_in] = ACTIONS(120),
    [anon_sym_LBRACK] = ACTIONS(154),
    [anon_sym_RBRACK] = ACTIONS(126),
    [anon_sym_DOT] = ACTIONS(154),
    [anon_sym_async] = ACTIONS(2445),
    [anon_sym_function] = ACTIONS(2418),
    [anon_sym_EQ_GT] = ACTIONS(895),
    [anon_sym_QMARK_DOT] = ACTIONS(154),
    [anon_sym_new] = ACTIONS(2445),
    [anon_sym_PLUS_EQ] = ACTIONS(160),
    [anon_sym_DASH_EQ] = ACTIONS(160),
    [anon_sym_STAR_EQ] = ACTIONS(160),
    [anon_sym_SLASH_EQ] = ACTIONS(160),
    [anon_sym_PERCENT_EQ] = ACTIONS(160),
    [anon_sym_CARET_EQ] = ACTIONS(160),
    [anon_sym_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_LT_LT_EQ] = ACTIONS(160),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(160),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP] = ACTIONS(120),
    [anon_sym_PIPE_PIPE] = ACTIONS(120),
    [anon_sym_GT_GT] = ACTIONS(120),
    [anon_sym_GT_GT_GT] = ACTIONS(120),
    [anon_sym_LT_LT] = ACTIONS(120),
    [anon_sym_AMP] = ACTIONS(120),
    [anon_sym_CARET] = ACTIONS(120),
    [anon_sym_PIPE] = ACTIONS(120),
    [anon_sym_PLUS] = ACTIONS(120),
    [anon_sym_DASH] = ACTIONS(120),
    [anon_sym_SLASH] = ACTIONS(120),
    [anon_sym_PERCENT] = ACTIONS(120),
    [anon_sym_STAR_STAR] = ACTIONS(120),
    [anon_sym_LT] = ACTIONS(2420),
    [anon_sym_LT_EQ] = ACTIONS(154),
    [anon_sym_EQ_EQ] = ACTIONS(120),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(154),
    [anon_sym_BANG_EQ] = ACTIONS(120),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(154),
    [anon_sym_GT_EQ] = ACTIONS(154),
    [anon_sym_GT] = ACTIONS(120),
    [anon_sym_QMARK_QMARK] = ACTIONS(120),
    [anon_sym_instanceof] = ACTIONS(120),
    [anon_sym_PLUS_PLUS] = ACTIONS(154),
    [anon_sym_DASH_DASH] = ACTIONS(154),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(154),
    [anon_sym_static] = ACTIONS(2445),
    [anon_sym_readonly] = ACTIONS(2445),
    [anon_sym_get] = ACTIONS(2445),
    [anon_sym_set] = ACTIONS(2445),
    [anon_sym_declare] = ACTIONS(2445),
    [anon_sym_public] = ACTIONS(2445),
    [anon_sym_private] = ACTIONS(2445),
    [anon_sym_protected] = ACTIONS(2445),
    [anon_sym_override] = ACTIONS(2445),
    [anon_sym_module] = ACTIONS(2445),
    [anon_sym_any] = ACTIONS(2445),
    [anon_sym_number] = ACTIONS(2445),
    [anon_sym_boolean] = ACTIONS(2445),
    [anon_sym_string] = ACTIONS(2445),
    [anon_sym_symbol] = ACTIONS(2445),
    [anon_sym_object] = ACTIONS(2445),
    [anon_sym_satisfies] = ACTIONS(120),
    [sym__ternary_qmark] = ACTIONS(154),
    [sym_html_comment] = ACTIONS(5),
  },
  [752] = {
    [sym__call_signature] = STATE(5601),
    [sym_formal_parameters] = STATE(3806),
    [sym_type_parameters] = STATE(5328),
    [sym_identifier] = ACTIONS(2451),
    [anon_sym_export] = ACTIONS(2453),
    [anon_sym_STAR] = ACTIONS(120),
    [anon_sym_type] = ACTIONS(2453),
    [anon_sym_EQ] = ACTIONS(918),
    [anon_sym_as] = ACTIONS(120),
    [anon_sym_namespace] = ACTIONS(2453),
    [anon_sym_let] = ACTIONS(2453),
    [anon_sym_BANG] = ACTIONS(120),
    [anon_sym_LPAREN] = ACTIONS(2415),
    [anon_sym_SEMI] = ACTIONS(154),
    [anon_sym_in] = ACTIONS(120),
    [anon_sym_LBRACK] = ACTIONS(154),
    [anon_sym_DOT] = ACTIONS(154),
    [anon_sym_async] = ACTIONS(2453),
    [anon_sym_function] = ACTIONS(2431),
    [anon_sym_EQ_GT] = ACTIONS(924),
    [anon_sym_QMARK_DOT] = ACTIONS(154),
    [anon_sym_new] = ACTIONS(2453),
    [anon_sym_PLUS_EQ] = ACTIONS(160),
    [anon_sym_DASH_EQ] = ACTIONS(160),
    [anon_sym_STAR_EQ] = ACTIONS(160),
    [anon_sym_SLASH_EQ] = ACTIONS(160),
    [anon_sym_PERCENT_EQ] = ACTIONS(160),
    [anon_sym_CARET_EQ] = ACTIONS(160),
    [anon_sym_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_LT_LT_EQ] = ACTIONS(160),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(160),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP] = ACTIONS(120),
    [anon_sym_PIPE_PIPE] = ACTIONS(120),
    [anon_sym_GT_GT] = ACTIONS(120),
    [anon_sym_GT_GT_GT] = ACTIONS(120),
    [anon_sym_LT_LT] = ACTIONS(120),
    [anon_sym_AMP] = ACTIONS(120),
    [anon_sym_CARET] = ACTIONS(120),
    [anon_sym_PIPE] = ACTIONS(120),
    [anon_sym_PLUS] = ACTIONS(120),
    [anon_sym_DASH] = ACTIONS(120),
    [anon_sym_SLASH] = ACTIONS(120),
    [anon_sym_PERCENT] = ACTIONS(120),
    [anon_sym_STAR_STAR] = ACTIONS(120),
    [anon_sym_LT] = ACTIONS(2420),
    [anon_sym_LT_EQ] = ACTIONS(154),
    [anon_sym_EQ_EQ] = ACTIONS(120),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(154),
    [anon_sym_BANG_EQ] = ACTIONS(120),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(154),
    [anon_sym_GT_EQ] = ACTIONS(154),
    [anon_sym_GT] = ACTIONS(120),
    [anon_sym_QMARK_QMARK] = ACTIONS(120),
    [anon_sym_instanceof] = ACTIONS(120),
    [anon_sym_PLUS_PLUS] = ACTIONS(154),
    [anon_sym_DASH_DASH] = ACTIONS(154),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(154),
    [anon_sym_static] = ACTIONS(2453),
    [anon_sym_readonly] = ACTIONS(2453),
    [anon_sym_get] = ACTIONS(2453),
    [anon_sym_set] = ACTIONS(2453),
    [anon_sym_declare] = ACTIONS(2453),
    [anon_sym_public] = ACTIONS(2453),
    [anon_sym_private] = ACTIONS(2453),
    [anon_sym_protected] = ACTIONS(2453),
    [anon_sym_override] = ACTIONS(2453),
    [anon_sym_module] = ACTIONS(2453),
    [anon_sym_any] = ACTIONS(2453),
    [anon_sym_number] = ACTIONS(2453),
    [anon_sym_boolean] = ACTIONS(2453),
    [anon_sym_string] = ACTIONS(2453),
    [anon_sym_symbol] = ACTIONS(2453),
    [anon_sym_object] = ACTIONS(2453),
    [anon_sym_satisfies] = ACTIONS(120),
    [sym__automatic_semicolon] = ACTIONS(154),
    [sym__ternary_qmark] = ACTIONS(154),
    [sym_html_comment] = ACTIONS(5),
  },
  [753] = {
    [ts_builtin_sym_end] = ACTIONS(1878),
    [sym_identifier] = ACTIONS(1880),
    [anon_sym_export] = ACTIONS(1880),
    [anon_sym_default] = ACTIONS(1880),
    [anon_sym_type] = ACTIONS(1880),
    [anon_sym_namespace] = ACTIONS(1880),
    [anon_sym_LBRACE] = ACTIONS(1878),
    [anon_sym_COMMA] = ACTIONS(1878),
    [anon_sym_RBRACE] = ACTIONS(1878),
    [anon_sym_typeof] = ACTIONS(1880),
    [anon_sym_import] = ACTIONS(1880),
    [anon_sym_with] = ACTIONS(1880),
    [anon_sym_var] = ACTIONS(1880),
    [anon_sym_let] = ACTIONS(1880),
    [anon_sym_const] = ACTIONS(1880),
    [anon_sym_BANG] = ACTIONS(1878),
    [anon_sym_else] = ACTIONS(1880),
    [anon_sym_if] = ACTIONS(1880),
    [anon_sym_switch] = ACTIONS(1880),
    [anon_sym_for] = ACTIONS(1880),
    [anon_sym_LPAREN] = ACTIONS(1878),
    [anon_sym_SEMI] = ACTIONS(1878),
    [anon_sym_await] = ACTIONS(1880),
    [anon_sym_while] = ACTIONS(1880),
    [anon_sym_do] = ACTIONS(1880),
    [anon_sym_try] = ACTIONS(1880),
    [anon_sym_break] = ACTIONS(1880),
    [anon_sym_continue] = ACTIONS(1880),
    [anon_sym_debugger] = ACTIONS(1880),
    [anon_sym_return] = ACTIONS(1880),
    [anon_sym_throw] = ACTIONS(1880),
    [anon_sym_case] = ACTIONS(1880),
    [anon_sym_catch] = ACTIONS(1880),
    [anon_sym_finally] = ACTIONS(1880),
    [anon_sym_yield] = ACTIONS(1880),
    [anon_sym_LBRACK] = ACTIONS(1878),
    [anon_sym_class] = ACTIONS(1880),
    [anon_sym_async] = ACTIONS(1880),
    [anon_sym_function] = ACTIONS(1880),
    [anon_sym_new] = ACTIONS(1880),
    [anon_sym_using] = ACTIONS(1880),
    [anon_sym_PLUS] = ACTIONS(1880),
    [anon_sym_DASH] = ACTIONS(1880),
    [anon_sym_SLASH] = ACTIONS(1880),
    [anon_sym_LT] = ACTIONS(1878),
    [anon_sym_TILDE] = ACTIONS(1878),
    [anon_sym_void] = ACTIONS(1880),
    [anon_sym_delete] = ACTIONS(1880),
    [anon_sym_PLUS_PLUS] = ACTIONS(1878),
    [anon_sym_DASH_DASH] = ACTIONS(1878),
    [anon_sym_DQUOTE] = ACTIONS(1878),
    [anon_sym_SQUOTE] = ACTIONS(1878),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1878),
    [sym_number] = ACTIONS(1878),
    [sym_private_property_identifier] = ACTIONS(1878),
    [sym_this] = ACTIONS(1880),
    [sym_super] = ACTIONS(1880),
    [sym_true] = ACTIONS(1880),
    [sym_false] = ACTIONS(1880),
    [sym_null] = ACTIONS(1880),
    [sym_undefined] = ACTIONS(1880),
    [anon_sym_AT] = ACTIONS(1878),
    [anon_sym_static] = ACTIONS(1880),
    [anon_sym_readonly] = ACTIONS(1880),
    [anon_sym_get] = ACTIONS(1880),
    [anon_sym_set] = ACTIONS(1880),
    [anon_sym_declare] = ACTIONS(1880),
    [anon_sym_public] = ACTIONS(1880),
    [anon_sym_private] = ACTIONS(1880),
    [anon_sym_protected] = ACTIONS(1880),
    [anon_sym_override] = ACTIONS(1880),
    [anon_sym_module] = ACTIONS(1880),
    [anon_sym_any] = ACTIONS(1880),
    [anon_sym_number] = ACTIONS(1880),
    [anon_sym_boolean] = ACTIONS(1880),
    [anon_sym_string] = ACTIONS(1880),
    [anon_sym_symbol] = ACTIONS(1880),
    [anon_sym_object] = ACTIONS(1880),
    [anon_sym_abstract] = ACTIONS(1880),
    [anon_sym_interface] = ACTIONS(1880),
    [anon_sym_enum] = ACTIONS(1880),
    [sym__automatic_semicolon] = ACTIONS(2465),
    [sym_html_comment] = ACTIONS(5),
  },
  [754] = {
    [ts_builtin_sym_end] = ACTIONS(1878),
    [sym_identifier] = ACTIONS(1880),
    [anon_sym_export] = ACTIONS(1880),
    [anon_sym_default] = ACTIONS(1880),
    [anon_sym_type] = ACTIONS(1880),
    [anon_sym_namespace] = ACTIONS(1880),
    [anon_sym_LBRACE] = ACTIONS(1878),
    [anon_sym_COMMA] = ACTIONS(1878),
    [anon_sym_RBRACE] = ACTIONS(1878),
    [anon_sym_typeof] = ACTIONS(1880),
    [anon_sym_import] = ACTIONS(1880),
    [anon_sym_with] = ACTIONS(1880),
    [anon_sym_var] = ACTIONS(1880),
    [anon_sym_let] = ACTIONS(1880),
    [anon_sym_const] = ACTIONS(1880),
    [anon_sym_BANG] = ACTIONS(1878),
    [anon_sym_else] = ACTIONS(1880),
    [anon_sym_if] = ACTIONS(1880),
    [anon_sym_switch] = ACTIONS(1880),
    [anon_sym_for] = ACTIONS(1880),
    [anon_sym_LPAREN] = ACTIONS(1878),
    [anon_sym_SEMI] = ACTIONS(1878),
    [anon_sym_await] = ACTIONS(1880),
    [anon_sym_while] = ACTIONS(1880),
    [anon_sym_do] = ACTIONS(1880),
    [anon_sym_try] = ACTIONS(1880),
    [anon_sym_break] = ACTIONS(1880),
    [anon_sym_continue] = ACTIONS(1880),
    [anon_sym_debugger] = ACTIONS(1880),
    [anon_sym_return] = ACTIONS(1880),
    [anon_sym_throw] = ACTIONS(1880),
    [anon_sym_case] = ACTIONS(1880),
    [anon_sym_yield] = ACTIONS(1880),
    [anon_sym_LBRACK] = ACTIONS(1878),
    [anon_sym_class] = ACTIONS(1880),
    [anon_sym_async] = ACTIONS(1880),
    [anon_sym_function] = ACTIONS(1880),
    [anon_sym_new] = ACTIONS(1880),
    [anon_sym_using] = ACTIONS(1880),
    [anon_sym_PLUS] = ACTIONS(1880),
    [anon_sym_DASH] = ACTIONS(1880),
    [anon_sym_SLASH] = ACTIONS(1880),
    [anon_sym_LT] = ACTIONS(1878),
    [anon_sym_TILDE] = ACTIONS(1878),
    [anon_sym_void] = ACTIONS(1880),
    [anon_sym_delete] = ACTIONS(1880),
    [anon_sym_PLUS_PLUS] = ACTIONS(1878),
    [anon_sym_DASH_DASH] = ACTIONS(1878),
    [anon_sym_DQUOTE] = ACTIONS(1878),
    [anon_sym_SQUOTE] = ACTIONS(1878),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1878),
    [sym_number] = ACTIONS(1878),
    [sym_private_property_identifier] = ACTIONS(1878),
    [sym_this] = ACTIONS(1880),
    [sym_super] = ACTIONS(1880),
    [sym_true] = ACTIONS(1880),
    [sym_false] = ACTIONS(1880),
    [sym_null] = ACTIONS(1880),
    [sym_undefined] = ACTIONS(1880),
    [anon_sym_AT] = ACTIONS(1878),
    [anon_sym_static] = ACTIONS(1880),
    [anon_sym_readonly] = ACTIONS(1880),
    [anon_sym_get] = ACTIONS(1880),
    [anon_sym_set] = ACTIONS(1880),
    [anon_sym_declare] = ACTIONS(1880),
    [anon_sym_public] = ACTIONS(1880),
    [anon_sym_private] = ACTIONS(1880),
    [anon_sym_protected] = ACTIONS(1880),
    [anon_sym_override] = ACTIONS(1880),
    [anon_sym_module] = ACTIONS(1880),
    [anon_sym_any] = ACTIONS(1880),
    [anon_sym_number] = ACTIONS(1880),
    [anon_sym_boolean] = ACTIONS(1880),
    [anon_sym_string] = ACTIONS(1880),
    [anon_sym_symbol] = ACTIONS(1880),
    [anon_sym_object] = ACTIONS(1880),
    [anon_sym_abstract] = ACTIONS(1880),
    [anon_sym_interface] = ACTIONS(1880),
    [anon_sym_enum] = ACTIONS(1880),
    [anon_sym_PIPE_RBRACE] = ACTIONS(1878),
    [sym__automatic_semicolon] = ACTIONS(2467),
    [sym_html_comment] = ACTIONS(5),
  },
  [755] = {
    [ts_builtin_sym_end] = ACTIONS(1878),
    [sym_identifier] = ACTIONS(1880),
    [anon_sym_export] = ACTIONS(1880),
    [anon_sym_default] = ACTIONS(1880),
    [anon_sym_type] = ACTIONS(1880),
    [anon_sym_namespace] = ACTIONS(1880),
    [anon_sym_LBRACE] = ACTIONS(1878),
    [anon_sym_COMMA] = ACTIONS(1878),
    [anon_sym_RBRACE] = ACTIONS(1878),
    [anon_sym_typeof] = ACTIONS(1880),
    [anon_sym_import] = ACTIONS(1880),
    [anon_sym_with] = ACTIONS(1880),
    [anon_sym_var] = ACTIONS(1880),
    [anon_sym_let] = ACTIONS(1880),
    [anon_sym_const] = ACTIONS(1880),
    [anon_sym_BANG] = ACTIONS(1878),
    [anon_sym_else] = ACTIONS(1880),
    [anon_sym_if] = ACTIONS(1880),
    [anon_sym_switch] = ACTIONS(1880),
    [anon_sym_for] = ACTIONS(1880),
    [anon_sym_LPAREN] = ACTIONS(1878),
    [anon_sym_SEMI] = ACTIONS(1878),
    [anon_sym_await] = ACTIONS(1880),
    [anon_sym_while] = ACTIONS(1880),
    [anon_sym_do] = ACTIONS(1880),
    [anon_sym_try] = ACTIONS(1880),
    [anon_sym_break] = ACTIONS(1880),
    [anon_sym_continue] = ACTIONS(1880),
    [anon_sym_debugger] = ACTIONS(1880),
    [anon_sym_return] = ACTIONS(1880),
    [anon_sym_throw] = ACTIONS(1880),
    [anon_sym_case] = ACTIONS(1880),
    [anon_sym_catch] = ACTIONS(1880),
    [anon_sym_finally] = ACTIONS(1880),
    [anon_sym_yield] = ACTIONS(1880),
    [anon_sym_LBRACK] = ACTIONS(1878),
    [anon_sym_class] = ACTIONS(1880),
    [anon_sym_async] = ACTIONS(1880),
    [anon_sym_function] = ACTIONS(1880),
    [anon_sym_new] = ACTIONS(1880),
    [anon_sym_using] = ACTIONS(1880),
    [anon_sym_PLUS] = ACTIONS(1880),
    [anon_sym_DASH] = ACTIONS(1880),
    [anon_sym_SLASH] = ACTIONS(1880),
    [anon_sym_LT] = ACTIONS(1878),
    [anon_sym_TILDE] = ACTIONS(1878),
    [anon_sym_void] = ACTIONS(1880),
    [anon_sym_delete] = ACTIONS(1880),
    [anon_sym_PLUS_PLUS] = ACTIONS(1878),
    [anon_sym_DASH_DASH] = ACTIONS(1878),
    [anon_sym_DQUOTE] = ACTIONS(1878),
    [anon_sym_SQUOTE] = ACTIONS(1878),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1878),
    [sym_number] = ACTIONS(1878),
    [sym_private_property_identifier] = ACTIONS(1878),
    [sym_this] = ACTIONS(1880),
    [sym_super] = ACTIONS(1880),
    [sym_true] = ACTIONS(1880),
    [sym_false] = ACTIONS(1880),
    [sym_null] = ACTIONS(1880),
    [sym_undefined] = ACTIONS(1880),
    [anon_sym_AT] = ACTIONS(1878),
    [anon_sym_static] = ACTIONS(1880),
    [anon_sym_readonly] = ACTIONS(1880),
    [anon_sym_get] = ACTIONS(1880),
    [anon_sym_set] = ACTIONS(1880),
    [anon_sym_declare] = ACTIONS(1880),
    [anon_sym_public] = ACTIONS(1880),
    [anon_sym_private] = ACTIONS(1880),
    [anon_sym_protected] = ACTIONS(1880),
    [anon_sym_override] = ACTIONS(1880),
    [anon_sym_module] = ACTIONS(1880),
    [anon_sym_any] = ACTIONS(1880),
    [anon_sym_number] = ACTIONS(1880),
    [anon_sym_boolean] = ACTIONS(1880),
    [anon_sym_string] = ACTIONS(1880),
    [anon_sym_symbol] = ACTIONS(1880),
    [anon_sym_object] = ACTIONS(1880),
    [anon_sym_abstract] = ACTIONS(1880),
    [anon_sym_interface] = ACTIONS(1880),
    [anon_sym_enum] = ACTIONS(1880),
    [sym_html_comment] = ACTIONS(5),
  },
  [756] = {
    [ts_builtin_sym_end] = ACTIONS(1884),
    [sym_identifier] = ACTIONS(1886),
    [anon_sym_export] = ACTIONS(1886),
    [anon_sym_default] = ACTIONS(1886),
    [anon_sym_type] = ACTIONS(1886),
    [anon_sym_namespace] = ACTIONS(1886),
    [anon_sym_LBRACE] = ACTIONS(1884),
    [anon_sym_COMMA] = ACTIONS(1884),
    [anon_sym_RBRACE] = ACTIONS(1884),
    [anon_sym_typeof] = ACTIONS(1886),
    [anon_sym_import] = ACTIONS(1886),
    [anon_sym_with] = ACTIONS(1886),
    [anon_sym_var] = ACTIONS(1886),
    [anon_sym_let] = ACTIONS(1886),
    [anon_sym_const] = ACTIONS(1886),
    [anon_sym_BANG] = ACTIONS(1884),
    [anon_sym_else] = ACTIONS(1886),
    [anon_sym_if] = ACTIONS(1886),
    [anon_sym_switch] = ACTIONS(1886),
    [anon_sym_for] = ACTIONS(1886),
    [anon_sym_LPAREN] = ACTIONS(1884),
    [anon_sym_SEMI] = ACTIONS(1884),
    [anon_sym_await] = ACTIONS(1886),
    [anon_sym_while] = ACTIONS(1886),
    [anon_sym_do] = ACTIONS(1886),
    [anon_sym_try] = ACTIONS(1886),
    [anon_sym_break] = ACTIONS(1886),
    [anon_sym_continue] = ACTIONS(1886),
    [anon_sym_debugger] = ACTIONS(1886),
    [anon_sym_return] = ACTIONS(1886),
    [anon_sym_throw] = ACTIONS(1886),
    [anon_sym_case] = ACTIONS(1886),
    [anon_sym_yield] = ACTIONS(1886),
    [anon_sym_LBRACK] = ACTIONS(1884),
    [anon_sym_class] = ACTIONS(1886),
    [anon_sym_async] = ACTIONS(1886),
    [anon_sym_function] = ACTIONS(1886),
    [anon_sym_new] = ACTIONS(1886),
    [anon_sym_using] = ACTIONS(1886),
    [anon_sym_PLUS] = ACTIONS(1886),
    [anon_sym_DASH] = ACTIONS(1886),
    [anon_sym_SLASH] = ACTIONS(1886),
    [anon_sym_LT] = ACTIONS(1884),
    [anon_sym_TILDE] = ACTIONS(1884),
    [anon_sym_void] = ACTIONS(1886),
    [anon_sym_delete] = ACTIONS(1886),
    [anon_sym_PLUS_PLUS] = ACTIONS(1884),
    [anon_sym_DASH_DASH] = ACTIONS(1884),
    [anon_sym_DQUOTE] = ACTIONS(1884),
    [anon_sym_SQUOTE] = ACTIONS(1884),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1884),
    [sym_number] = ACTIONS(1884),
    [sym_private_property_identifier] = ACTIONS(1884),
    [sym_this] = ACTIONS(1886),
    [sym_super] = ACTIONS(1886),
    [sym_true] = ACTIONS(1886),
    [sym_false] = ACTIONS(1886),
    [sym_null] = ACTIONS(1886),
    [sym_undefined] = ACTIONS(1886),
    [anon_sym_AT] = ACTIONS(1884),
    [anon_sym_static] = ACTIONS(1886),
    [anon_sym_readonly] = ACTIONS(1886),
    [anon_sym_get] = ACTIONS(1886),
    [anon_sym_set] = ACTIONS(1886),
    [anon_sym_declare] = ACTIONS(1886),
    [anon_sym_public] = ACTIONS(1886),
    [anon_sym_private] = ACTIONS(1886),
    [anon_sym_protected] = ACTIONS(1886),
    [anon_sym_override] = ACTIONS(1886),
    [anon_sym_module] = ACTIONS(1886),
    [anon_sym_any] = ACTIONS(1886),
    [anon_sym_number] = ACTIONS(1886),
    [anon_sym_boolean] = ACTIONS(1886),
    [anon_sym_string] = ACTIONS(1886),
    [anon_sym_symbol] = ACTIONS(1886),
    [anon_sym_object] = ACTIONS(1886),
    [anon_sym_abstract] = ACTIONS(1886),
    [anon_sym_interface] = ACTIONS(1886),
    [anon_sym_enum] = ACTIONS(1886),
    [anon_sym_PIPE_RBRACE] = ACTIONS(1884),
    [sym__automatic_semicolon] = ACTIONS(1884),
    [sym_html_comment] = ACTIONS(5),
  },
  [757] = {
    [ts_builtin_sym_end] = ACTIONS(1720),
    [sym_identifier] = ACTIONS(1722),
    [anon_sym_export] = ACTIONS(1722),
    [anon_sym_default] = ACTIONS(1722),
    [anon_sym_type] = ACTIONS(1722),
    [anon_sym_namespace] = ACTIONS(1722),
    [anon_sym_LBRACE] = ACTIONS(1720),
    [anon_sym_COMMA] = ACTIONS(1720),
    [anon_sym_RBRACE] = ACTIONS(1720),
    [anon_sym_typeof] = ACTIONS(1722),
    [anon_sym_import] = ACTIONS(1722),
    [anon_sym_with] = ACTIONS(1722),
    [anon_sym_var] = ACTIONS(1722),
    [anon_sym_let] = ACTIONS(1722),
    [anon_sym_const] = ACTIONS(1722),
    [anon_sym_BANG] = ACTIONS(1720),
    [anon_sym_else] = ACTIONS(1722),
    [anon_sym_if] = ACTIONS(1722),
    [anon_sym_switch] = ACTIONS(1722),
    [anon_sym_for] = ACTIONS(1722),
    [anon_sym_LPAREN] = ACTIONS(1720),
    [anon_sym_SEMI] = ACTIONS(1720),
    [anon_sym_await] = ACTIONS(1722),
    [anon_sym_while] = ACTIONS(1722),
    [anon_sym_do] = ACTIONS(1722),
    [anon_sym_try] = ACTIONS(1722),
    [anon_sym_break] = ACTIONS(1722),
    [anon_sym_continue] = ACTIONS(1722),
    [anon_sym_debugger] = ACTIONS(1722),
    [anon_sym_return] = ACTIONS(1722),
    [anon_sym_throw] = ACTIONS(1722),
    [anon_sym_case] = ACTIONS(1722),
    [anon_sym_yield] = ACTIONS(1722),
    [anon_sym_LBRACK] = ACTIONS(1720),
    [anon_sym_class] = ACTIONS(1722),
    [anon_sym_async] = ACTIONS(1722),
    [anon_sym_function] = ACTIONS(1722),
    [anon_sym_new] = ACTIONS(1722),
    [anon_sym_using] = ACTIONS(1722),
    [anon_sym_PLUS] = ACTIONS(1722),
    [anon_sym_DASH] = ACTIONS(1722),
    [anon_sym_SLASH] = ACTIONS(1722),
    [anon_sym_LT] = ACTIONS(1720),
    [anon_sym_TILDE] = ACTIONS(1720),
    [anon_sym_void] = ACTIONS(1722),
    [anon_sym_delete] = ACTIONS(1722),
    [anon_sym_PLUS_PLUS] = ACTIONS(1720),
    [anon_sym_DASH_DASH] = ACTIONS(1720),
    [anon_sym_DQUOTE] = ACTIONS(1720),
    [anon_sym_SQUOTE] = ACTIONS(1720),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1720),
    [sym_number] = ACTIONS(1720),
    [sym_private_property_identifier] = ACTIONS(1720),
    [sym_this] = ACTIONS(1722),
    [sym_super] = ACTIONS(1722),
    [sym_true] = ACTIONS(1722),
    [sym_false] = ACTIONS(1722),
    [sym_null] = ACTIONS(1722),
    [sym_undefined] = ACTIONS(1722),
    [anon_sym_AT] = ACTIONS(1720),
    [anon_sym_static] = ACTIONS(1722),
    [anon_sym_readonly] = ACTIONS(1722),
    [anon_sym_get] = ACTIONS(1722),
    [anon_sym_set] = ACTIONS(1722),
    [anon_sym_declare] = ACTIONS(1722),
    [anon_sym_public] = ACTIONS(1722),
    [anon_sym_private] = ACTIONS(1722),
    [anon_sym_protected] = ACTIONS(1722),
    [anon_sym_override] = ACTIONS(1722),
    [anon_sym_module] = ACTIONS(1722),
    [anon_sym_any] = ACTIONS(1722),
    [anon_sym_number] = ACTIONS(1722),
    [anon_sym_boolean] = ACTIONS(1722),
    [anon_sym_string] = ACTIONS(1722),
    [anon_sym_symbol] = ACTIONS(1722),
    [anon_sym_object] = ACTIONS(1722),
    [anon_sym_abstract] = ACTIONS(1722),
    [anon_sym_interface] = ACTIONS(1722),
    [anon_sym_enum] = ACTIONS(1722),
    [anon_sym_PIPE_RBRACE] = ACTIONS(1720),
    [sym__automatic_semicolon] = ACTIONS(1720),
    [sym_html_comment] = ACTIONS(5),
  },
  [758] = {
    [ts_builtin_sym_end] = ACTIONS(1878),
    [sym_identifier] = ACTIONS(1880),
    [anon_sym_export] = ACTIONS(1880),
    [anon_sym_default] = ACTIONS(1880),
    [anon_sym_type] = ACTIONS(1880),
    [anon_sym_namespace] = ACTIONS(1880),
    [anon_sym_LBRACE] = ACTIONS(1878),
    [anon_sym_COMMA] = ACTIONS(1878),
    [anon_sym_RBRACE] = ACTIONS(1878),
    [anon_sym_typeof] = ACTIONS(1880),
    [anon_sym_import] = ACTIONS(1880),
    [anon_sym_with] = ACTIONS(1880),
    [anon_sym_var] = ACTIONS(1880),
    [anon_sym_let] = ACTIONS(1880),
    [anon_sym_const] = ACTIONS(1880),
    [anon_sym_BANG] = ACTIONS(1878),
    [anon_sym_else] = ACTIONS(1880),
    [anon_sym_if] = ACTIONS(1880),
    [anon_sym_switch] = ACTIONS(1880),
    [anon_sym_for] = ACTIONS(1880),
    [anon_sym_LPAREN] = ACTIONS(1878),
    [anon_sym_SEMI] = ACTIONS(1878),
    [anon_sym_await] = ACTIONS(1880),
    [anon_sym_while] = ACTIONS(1880),
    [anon_sym_do] = ACTIONS(1880),
    [anon_sym_try] = ACTIONS(1880),
    [anon_sym_break] = ACTIONS(1880),
    [anon_sym_continue] = ACTIONS(1880),
    [anon_sym_debugger] = ACTIONS(1880),
    [anon_sym_return] = ACTIONS(1880),
    [anon_sym_throw] = ACTIONS(1880),
    [anon_sym_case] = ACTIONS(1880),
    [anon_sym_yield] = ACTIONS(1880),
    [anon_sym_LBRACK] = ACTIONS(1878),
    [anon_sym_class] = ACTIONS(1880),
    [anon_sym_async] = ACTIONS(1880),
    [anon_sym_function] = ACTIONS(1880),
    [anon_sym_new] = ACTIONS(1880),
    [anon_sym_using] = ACTIONS(1880),
    [anon_sym_PLUS] = ACTIONS(1880),
    [anon_sym_DASH] = ACTIONS(1880),
    [anon_sym_SLASH] = ACTIONS(1880),
    [anon_sym_LT] = ACTIONS(1878),
    [anon_sym_TILDE] = ACTIONS(1878),
    [anon_sym_void] = ACTIONS(1880),
    [anon_sym_delete] = ACTIONS(1880),
    [anon_sym_PLUS_PLUS] = ACTIONS(1878),
    [anon_sym_DASH_DASH] = ACTIONS(1878),
    [anon_sym_DQUOTE] = ACTIONS(1878),
    [anon_sym_SQUOTE] = ACTIONS(1878),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1878),
    [sym_number] = ACTIONS(1878),
    [sym_private_property_identifier] = ACTIONS(1878),
    [sym_this] = ACTIONS(1880),
    [sym_super] = ACTIONS(1880),
    [sym_true] = ACTIONS(1880),
    [sym_false] = ACTIONS(1880),
    [sym_null] = ACTIONS(1880),
    [sym_undefined] = ACTIONS(1880),
    [anon_sym_AT] = ACTIONS(1878),
    [anon_sym_static] = ACTIONS(1880),
    [anon_sym_readonly] = ACTIONS(1880),
    [anon_sym_get] = ACTIONS(1880),
    [anon_sym_set] = ACTIONS(1880),
    [anon_sym_declare] = ACTIONS(1880),
    [anon_sym_public] = ACTIONS(1880),
    [anon_sym_private] = ACTIONS(1880),
    [anon_sym_protected] = ACTIONS(1880),
    [anon_sym_override] = ACTIONS(1880),
    [anon_sym_module] = ACTIONS(1880),
    [anon_sym_any] = ACTIONS(1880),
    [anon_sym_number] = ACTIONS(1880),
    [anon_sym_boolean] = ACTIONS(1880),
    [anon_sym_string] = ACTIONS(1880),
    [anon_sym_symbol] = ACTIONS(1880),
    [anon_sym_object] = ACTIONS(1880),
    [anon_sym_abstract] = ACTIONS(1880),
    [anon_sym_interface] = ACTIONS(1880),
    [anon_sym_enum] = ACTIONS(1880),
    [anon_sym_PIPE_RBRACE] = ACTIONS(1878),
    [sym__automatic_semicolon] = ACTIONS(1878),
    [sym_html_comment] = ACTIONS(5),
  },
  [759] = {
    [ts_builtin_sym_end] = ACTIONS(1690),
    [sym_identifier] = ACTIONS(1692),
    [anon_sym_export] = ACTIONS(1692),
    [anon_sym_default] = ACTIONS(1692),
    [anon_sym_type] = ACTIONS(1692),
    [anon_sym_namespace] = ACTIONS(1692),
    [anon_sym_LBRACE] = ACTIONS(1690),
    [anon_sym_COMMA] = ACTIONS(1690),
    [anon_sym_RBRACE] = ACTIONS(1690),
    [anon_sym_typeof] = ACTIONS(1692),
    [anon_sym_import] = ACTIONS(1692),
    [anon_sym_with] = ACTIONS(1692),
    [anon_sym_var] = ACTIONS(1692),
    [anon_sym_let] = ACTIONS(1692),
    [anon_sym_const] = ACTIONS(1692),
    [anon_sym_BANG] = ACTIONS(1690),
    [anon_sym_else] = ACTIONS(1692),
    [anon_sym_if] = ACTIONS(1692),
    [anon_sym_switch] = ACTIONS(1692),
    [anon_sym_for] = ACTIONS(1692),
    [anon_sym_LPAREN] = ACTIONS(1690),
    [anon_sym_SEMI] = ACTIONS(1690),
    [anon_sym_await] = ACTIONS(1692),
    [anon_sym_while] = ACTIONS(1692),
    [anon_sym_do] = ACTIONS(1692),
    [anon_sym_try] = ACTIONS(1692),
    [anon_sym_break] = ACTIONS(1692),
    [anon_sym_continue] = ACTIONS(1692),
    [anon_sym_debugger] = ACTIONS(1692),
    [anon_sym_return] = ACTIONS(1692),
    [anon_sym_throw] = ACTIONS(1692),
    [anon_sym_case] = ACTIONS(1692),
    [anon_sym_yield] = ACTIONS(1692),
    [anon_sym_LBRACK] = ACTIONS(1690),
    [anon_sym_class] = ACTIONS(1692),
    [anon_sym_async] = ACTIONS(1692),
    [anon_sym_function] = ACTIONS(1692),
    [anon_sym_new] = ACTIONS(1692),
    [anon_sym_using] = ACTIONS(1692),
    [anon_sym_PLUS] = ACTIONS(1692),
    [anon_sym_DASH] = ACTIONS(1692),
    [anon_sym_SLASH] = ACTIONS(1692),
    [anon_sym_LT] = ACTIONS(1690),
    [anon_sym_TILDE] = ACTIONS(1690),
    [anon_sym_void] = ACTIONS(1692),
    [anon_sym_delete] = ACTIONS(1692),
    [anon_sym_PLUS_PLUS] = ACTIONS(1690),
    [anon_sym_DASH_DASH] = ACTIONS(1690),
    [anon_sym_DQUOTE] = ACTIONS(1690),
    [anon_sym_SQUOTE] = ACTIONS(1690),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1690),
    [sym_number] = ACTIONS(1690),
    [sym_private_property_identifier] = ACTIONS(1690),
    [sym_this] = ACTIONS(1692),
    [sym_super] = ACTIONS(1692),
    [sym_true] = ACTIONS(1692),
    [sym_false] = ACTIONS(1692),
    [sym_null] = ACTIONS(1692),
    [sym_undefined] = ACTIONS(1692),
    [anon_sym_AT] = ACTIONS(1690),
    [anon_sym_static] = ACTIONS(1692),
    [anon_sym_readonly] = ACTIONS(1692),
    [anon_sym_get] = ACTIONS(1692),
    [anon_sym_set] = ACTIONS(1692),
    [anon_sym_declare] = ACTIONS(1692),
    [anon_sym_public] = ACTIONS(1692),
    [anon_sym_private] = ACTIONS(1692),
    [anon_sym_protected] = ACTIONS(1692),
    [anon_sym_override] = ACTIONS(1692),
    [anon_sym_module] = ACTIONS(1692),
    [anon_sym_any] = ACTIONS(1692),
    [anon_sym_number] = ACTIONS(1692),
    [anon_sym_boolean] = ACTIONS(1692),
    [anon_sym_string] = ACTIONS(1692),
    [anon_sym_symbol] = ACTIONS(1692),
    [anon_sym_object] = ACTIONS(1692),
    [anon_sym_abstract] = ACTIONS(1692),
    [anon_sym_interface] = ACTIONS(1692),
    [anon_sym_enum] = ACTIONS(1692),
    [anon_sym_PIPE_RBRACE] = ACTIONS(1690),
    [sym__automatic_semicolon] = ACTIONS(2469),
    [sym_html_comment] = ACTIONS(5),
  },
  [760] = {
    [ts_builtin_sym_end] = ACTIONS(1716),
    [sym_identifier] = ACTIONS(1718),
    [anon_sym_export] = ACTIONS(1718),
    [anon_sym_default] = ACTIONS(1718),
    [anon_sym_type] = ACTIONS(1718),
    [anon_sym_namespace] = ACTIONS(1718),
    [anon_sym_LBRACE] = ACTIONS(1716),
    [anon_sym_COMMA] = ACTIONS(1716),
    [anon_sym_RBRACE] = ACTIONS(1716),
    [anon_sym_typeof] = ACTIONS(1718),
    [anon_sym_import] = ACTIONS(1718),
    [anon_sym_with] = ACTIONS(1718),
    [anon_sym_var] = ACTIONS(1718),
    [anon_sym_let] = ACTIONS(1718),
    [anon_sym_const] = ACTIONS(1718),
    [anon_sym_BANG] = ACTIONS(1716),
    [anon_sym_else] = ACTIONS(1718),
    [anon_sym_if] = ACTIONS(1718),
    [anon_sym_switch] = ACTIONS(1718),
    [anon_sym_for] = ACTIONS(1718),
    [anon_sym_LPAREN] = ACTIONS(1716),
    [anon_sym_SEMI] = ACTIONS(1716),
    [anon_sym_await] = ACTIONS(1718),
    [anon_sym_while] = ACTIONS(1718),
    [anon_sym_do] = ACTIONS(1718),
    [anon_sym_try] = ACTIONS(1718),
    [anon_sym_break] = ACTIONS(1718),
    [anon_sym_continue] = ACTIONS(1718),
    [anon_sym_debugger] = ACTIONS(1718),
    [anon_sym_return] = ACTIONS(1718),
    [anon_sym_throw] = ACTIONS(1718),
    [anon_sym_case] = ACTIONS(1718),
    [anon_sym_yield] = ACTIONS(1718),
    [anon_sym_LBRACK] = ACTIONS(1716),
    [anon_sym_class] = ACTIONS(1718),
    [anon_sym_async] = ACTIONS(1718),
    [anon_sym_function] = ACTIONS(1718),
    [anon_sym_new] = ACTIONS(1718),
    [anon_sym_using] = ACTIONS(1718),
    [anon_sym_PLUS] = ACTIONS(1718),
    [anon_sym_DASH] = ACTIONS(1718),
    [anon_sym_SLASH] = ACTIONS(1718),
    [anon_sym_LT] = ACTIONS(1716),
    [anon_sym_TILDE] = ACTIONS(1716),
    [anon_sym_void] = ACTIONS(1718),
    [anon_sym_delete] = ACTIONS(1718),
    [anon_sym_PLUS_PLUS] = ACTIONS(1716),
    [anon_sym_DASH_DASH] = ACTIONS(1716),
    [anon_sym_DQUOTE] = ACTIONS(1716),
    [anon_sym_SQUOTE] = ACTIONS(1716),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1716),
    [sym_number] = ACTIONS(1716),
    [sym_private_property_identifier] = ACTIONS(1716),
    [sym_this] = ACTIONS(1718),
    [sym_super] = ACTIONS(1718),
    [sym_true] = ACTIONS(1718),
    [sym_false] = ACTIONS(1718),
    [sym_null] = ACTIONS(1718),
    [sym_undefined] = ACTIONS(1718),
    [anon_sym_AT] = ACTIONS(1716),
    [anon_sym_static] = ACTIONS(1718),
    [anon_sym_readonly] = ACTIONS(1718),
    [anon_sym_get] = ACTIONS(1718),
    [anon_sym_set] = ACTIONS(1718),
    [anon_sym_declare] = ACTIONS(1718),
    [anon_sym_public] = ACTIONS(1718),
    [anon_sym_private] = ACTIONS(1718),
    [anon_sym_protected] = ACTIONS(1718),
    [anon_sym_override] = ACTIONS(1718),
    [anon_sym_module] = ACTIONS(1718),
    [anon_sym_any] = ACTIONS(1718),
    [anon_sym_number] = ACTIONS(1718),
    [anon_sym_boolean] = ACTIONS(1718),
    [anon_sym_string] = ACTIONS(1718),
    [anon_sym_symbol] = ACTIONS(1718),
    [anon_sym_object] = ACTIONS(1718),
    [anon_sym_abstract] = ACTIONS(1718),
    [anon_sym_interface] = ACTIONS(1718),
    [anon_sym_enum] = ACTIONS(1718),
    [anon_sym_PIPE_RBRACE] = ACTIONS(1716),
    [sym__automatic_semicolon] = ACTIONS(1716),
    [sym_html_comment] = ACTIONS(5),
  },
  [761] = {
    [sym__call_signature] = STATE(5764),
    [sym_formal_parameters] = STATE(3806),
    [sym_type_parameters] = STATE(5328),
    [sym_identifier] = ACTIONS(2471),
    [anon_sym_export] = ACTIONS(2473),
    [anon_sym_STAR] = ACTIONS(120),
    [anon_sym_type] = ACTIONS(2473),
    [anon_sym_EQ] = ACTIONS(964),
    [anon_sym_as] = ACTIONS(120),
    [anon_sym_namespace] = ACTIONS(2473),
    [anon_sym_let] = ACTIONS(2473),
    [anon_sym_BANG] = ACTIONS(120),
    [anon_sym_LPAREN] = ACTIONS(2415),
    [anon_sym_in] = ACTIONS(120),
    [anon_sym_COLON] = ACTIONS(154),
    [anon_sym_LBRACK] = ACTIONS(154),
    [anon_sym_DOT] = ACTIONS(154),
    [anon_sym_async] = ACTIONS(2473),
    [anon_sym_function] = ACTIONS(2418),
    [anon_sym_EQ_GT] = ACTIONS(970),
    [anon_sym_QMARK_DOT] = ACTIONS(154),
    [anon_sym_new] = ACTIONS(2473),
    [anon_sym_PLUS_EQ] = ACTIONS(160),
    [anon_sym_DASH_EQ] = ACTIONS(160),
    [anon_sym_STAR_EQ] = ACTIONS(160),
    [anon_sym_SLASH_EQ] = ACTIONS(160),
    [anon_sym_PERCENT_EQ] = ACTIONS(160),
    [anon_sym_CARET_EQ] = ACTIONS(160),
    [anon_sym_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_LT_LT_EQ] = ACTIONS(160),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(160),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP] = ACTIONS(120),
    [anon_sym_PIPE_PIPE] = ACTIONS(120),
    [anon_sym_GT_GT] = ACTIONS(120),
    [anon_sym_GT_GT_GT] = ACTIONS(120),
    [anon_sym_LT_LT] = ACTIONS(120),
    [anon_sym_AMP] = ACTIONS(120),
    [anon_sym_CARET] = ACTIONS(120),
    [anon_sym_PIPE] = ACTIONS(120),
    [anon_sym_PLUS] = ACTIONS(120),
    [anon_sym_DASH] = ACTIONS(120),
    [anon_sym_SLASH] = ACTIONS(120),
    [anon_sym_PERCENT] = ACTIONS(120),
    [anon_sym_STAR_STAR] = ACTIONS(120),
    [anon_sym_LT] = ACTIONS(2420),
    [anon_sym_LT_EQ] = ACTIONS(154),
    [anon_sym_EQ_EQ] = ACTIONS(120),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(154),
    [anon_sym_BANG_EQ] = ACTIONS(120),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(154),
    [anon_sym_GT_EQ] = ACTIONS(154),
    [anon_sym_GT] = ACTIONS(120),
    [anon_sym_QMARK_QMARK] = ACTIONS(120),
    [anon_sym_instanceof] = ACTIONS(120),
    [anon_sym_PLUS_PLUS] = ACTIONS(154),
    [anon_sym_DASH_DASH] = ACTIONS(154),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(154),
    [anon_sym_static] = ACTIONS(2473),
    [anon_sym_readonly] = ACTIONS(2473),
    [anon_sym_get] = ACTIONS(2473),
    [anon_sym_set] = ACTIONS(2473),
    [anon_sym_declare] = ACTIONS(2473),
    [anon_sym_public] = ACTIONS(2473),
    [anon_sym_private] = ACTIONS(2473),
    [anon_sym_protected] = ACTIONS(2473),
    [anon_sym_override] = ACTIONS(2473),
    [anon_sym_module] = ACTIONS(2473),
    [anon_sym_any] = ACTIONS(2473),
    [anon_sym_number] = ACTIONS(2473),
    [anon_sym_boolean] = ACTIONS(2473),
    [anon_sym_string] = ACTIONS(2473),
    [anon_sym_symbol] = ACTIONS(2473),
    [anon_sym_object] = ACTIONS(2473),
    [anon_sym_satisfies] = ACTIONS(120),
    [sym__ternary_qmark] = ACTIONS(154),
    [sym_html_comment] = ACTIONS(5),
  },
  [762] = {
    [sym__call_signature] = STATE(5481),
    [sym_formal_parameters] = STATE(3806),
    [sym_type_parameters] = STATE(5328),
    [sym_identifier] = ACTIONS(2443),
    [anon_sym_export] = ACTIONS(2445),
    [anon_sym_STAR] = ACTIONS(120),
    [anon_sym_type] = ACTIONS(2445),
    [anon_sym_EQ] = ACTIONS(910),
    [anon_sym_as] = ACTIONS(120),
    [anon_sym_namespace] = ACTIONS(2445),
    [anon_sym_let] = ACTIONS(2445),
    [anon_sym_BANG] = ACTIONS(120),
    [anon_sym_LPAREN] = ACTIONS(2415),
    [anon_sym_in] = ACTIONS(120),
    [anon_sym_LBRACK] = ACTIONS(154),
    [anon_sym_RBRACK] = ACTIONS(154),
    [anon_sym_DOT] = ACTIONS(154),
    [anon_sym_async] = ACTIONS(2445),
    [anon_sym_function] = ACTIONS(2418),
    [anon_sym_EQ_GT] = ACTIONS(895),
    [anon_sym_QMARK_DOT] = ACTIONS(154),
    [anon_sym_new] = ACTIONS(2445),
    [anon_sym_PLUS_EQ] = ACTIONS(160),
    [anon_sym_DASH_EQ] = ACTIONS(160),
    [anon_sym_STAR_EQ] = ACTIONS(160),
    [anon_sym_SLASH_EQ] = ACTIONS(160),
    [anon_sym_PERCENT_EQ] = ACTIONS(160),
    [anon_sym_CARET_EQ] = ACTIONS(160),
    [anon_sym_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_LT_LT_EQ] = ACTIONS(160),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(160),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP] = ACTIONS(120),
    [anon_sym_PIPE_PIPE] = ACTIONS(120),
    [anon_sym_GT_GT] = ACTIONS(120),
    [anon_sym_GT_GT_GT] = ACTIONS(120),
    [anon_sym_LT_LT] = ACTIONS(120),
    [anon_sym_AMP] = ACTIONS(120),
    [anon_sym_CARET] = ACTIONS(120),
    [anon_sym_PIPE] = ACTIONS(120),
    [anon_sym_PLUS] = ACTIONS(120),
    [anon_sym_DASH] = ACTIONS(120),
    [anon_sym_SLASH] = ACTIONS(120),
    [anon_sym_PERCENT] = ACTIONS(120),
    [anon_sym_STAR_STAR] = ACTIONS(120),
    [anon_sym_LT] = ACTIONS(2420),
    [anon_sym_LT_EQ] = ACTIONS(154),
    [anon_sym_EQ_EQ] = ACTIONS(120),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(154),
    [anon_sym_BANG_EQ] = ACTIONS(120),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(154),
    [anon_sym_GT_EQ] = ACTIONS(154),
    [anon_sym_GT] = ACTIONS(120),
    [anon_sym_QMARK_QMARK] = ACTIONS(120),
    [anon_sym_instanceof] = ACTIONS(120),
    [anon_sym_PLUS_PLUS] = ACTIONS(154),
    [anon_sym_DASH_DASH] = ACTIONS(154),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(154),
    [anon_sym_static] = ACTIONS(2445),
    [anon_sym_readonly] = ACTIONS(2445),
    [anon_sym_get] = ACTIONS(2445),
    [anon_sym_set] = ACTIONS(2445),
    [anon_sym_declare] = ACTIONS(2445),
    [anon_sym_public] = ACTIONS(2445),
    [anon_sym_private] = ACTIONS(2445),
    [anon_sym_protected] = ACTIONS(2445),
    [anon_sym_override] = ACTIONS(2445),
    [anon_sym_module] = ACTIONS(2445),
    [anon_sym_any] = ACTIONS(2445),
    [anon_sym_number] = ACTIONS(2445),
    [anon_sym_boolean] = ACTIONS(2445),
    [anon_sym_string] = ACTIONS(2445),
    [anon_sym_symbol] = ACTIONS(2445),
    [anon_sym_object] = ACTIONS(2445),
    [anon_sym_satisfies] = ACTIONS(120),
    [sym__ternary_qmark] = ACTIONS(154),
    [sym_html_comment] = ACTIONS(5),
  },
  [763] = {
    [sym__call_signature] = STATE(5764),
    [sym_formal_parameters] = STATE(3806),
    [sym_type_parameters] = STATE(5328),
    [sym_identifier] = ACTIONS(2471),
    [anon_sym_export] = ACTIONS(2473),
    [anon_sym_STAR] = ACTIONS(120),
    [anon_sym_type] = ACTIONS(2473),
    [anon_sym_EQ] = ACTIONS(824),
    [anon_sym_as] = ACTIONS(120),
    [anon_sym_namespace] = ACTIONS(2473),
    [anon_sym_let] = ACTIONS(2473),
    [anon_sym_BANG] = ACTIONS(120),
    [anon_sym_LPAREN] = ACTIONS(2415),
    [anon_sym_in] = ACTIONS(120),
    [anon_sym_COLON] = ACTIONS(154),
    [anon_sym_LBRACK] = ACTIONS(154),
    [anon_sym_DOT] = ACTIONS(154),
    [anon_sym_async] = ACTIONS(2473),
    [anon_sym_function] = ACTIONS(2418),
    [anon_sym_EQ_GT] = ACTIONS(970),
    [anon_sym_QMARK_DOT] = ACTIONS(154),
    [anon_sym_new] = ACTIONS(2473),
    [anon_sym_PLUS_EQ] = ACTIONS(160),
    [anon_sym_DASH_EQ] = ACTIONS(160),
    [anon_sym_STAR_EQ] = ACTIONS(160),
    [anon_sym_SLASH_EQ] = ACTIONS(160),
    [anon_sym_PERCENT_EQ] = ACTIONS(160),
    [anon_sym_CARET_EQ] = ACTIONS(160),
    [anon_sym_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_LT_LT_EQ] = ACTIONS(160),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(160),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP] = ACTIONS(120),
    [anon_sym_PIPE_PIPE] = ACTIONS(120),
    [anon_sym_GT_GT] = ACTIONS(120),
    [anon_sym_GT_GT_GT] = ACTIONS(120),
    [anon_sym_LT_LT] = ACTIONS(120),
    [anon_sym_AMP] = ACTIONS(120),
    [anon_sym_CARET] = ACTIONS(120),
    [anon_sym_PIPE] = ACTIONS(120),
    [anon_sym_PLUS] = ACTIONS(120),
    [anon_sym_DASH] = ACTIONS(120),
    [anon_sym_SLASH] = ACTIONS(120),
    [anon_sym_PERCENT] = ACTIONS(120),
    [anon_sym_STAR_STAR] = ACTIONS(120),
    [anon_sym_LT] = ACTIONS(2420),
    [anon_sym_LT_EQ] = ACTIONS(154),
    [anon_sym_EQ_EQ] = ACTIONS(120),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(154),
    [anon_sym_BANG_EQ] = ACTIONS(120),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(154),
    [anon_sym_GT_EQ] = ACTIONS(154),
    [anon_sym_GT] = ACTIONS(120),
    [anon_sym_QMARK_QMARK] = ACTIONS(120),
    [anon_sym_instanceof] = ACTIONS(120),
    [anon_sym_PLUS_PLUS] = ACTIONS(154),
    [anon_sym_DASH_DASH] = ACTIONS(154),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(154),
    [anon_sym_static] = ACTIONS(2473),
    [anon_sym_readonly] = ACTIONS(2473),
    [anon_sym_get] = ACTIONS(2473),
    [anon_sym_set] = ACTIONS(2473),
    [anon_sym_declare] = ACTIONS(2473),
    [anon_sym_public] = ACTIONS(2473),
    [anon_sym_private] = ACTIONS(2473),
    [anon_sym_protected] = ACTIONS(2473),
    [anon_sym_override] = ACTIONS(2473),
    [anon_sym_module] = ACTIONS(2473),
    [anon_sym_any] = ACTIONS(2473),
    [anon_sym_number] = ACTIONS(2473),
    [anon_sym_boolean] = ACTIONS(2473),
    [anon_sym_string] = ACTIONS(2473),
    [anon_sym_symbol] = ACTIONS(2473),
    [anon_sym_object] = ACTIONS(2473),
    [anon_sym_satisfies] = ACTIONS(120),
    [sym__ternary_qmark] = ACTIONS(154),
    [sym_html_comment] = ACTIONS(5),
  },
  [764] = {
    [sym__call_signature] = STATE(5533),
    [sym_formal_parameters] = STATE(3806),
    [sym_type_parameters] = STATE(5328),
    [sym_identifier] = ACTIONS(2475),
    [anon_sym_export] = ACTIONS(2477),
    [anon_sym_STAR] = ACTIONS(120),
    [anon_sym_type] = ACTIONS(2477),
    [anon_sym_EQ] = ACTIONS(824),
    [anon_sym_as] = ACTIONS(120),
    [anon_sym_namespace] = ACTIONS(2477),
    [anon_sym_let] = ACTIONS(2477),
    [anon_sym_BANG] = ACTIONS(120),
    [anon_sym_LPAREN] = ACTIONS(2415),
    [anon_sym_in] = ACTIONS(120),
    [anon_sym_of] = ACTIONS(120),
    [anon_sym_LBRACK] = ACTIONS(154),
    [anon_sym_DOT] = ACTIONS(154),
    [anon_sym_async] = ACTIONS(2477),
    [anon_sym_function] = ACTIONS(2418),
    [anon_sym_EQ_GT] = ACTIONS(954),
    [anon_sym_QMARK_DOT] = ACTIONS(154),
    [anon_sym_new] = ACTIONS(2477),
    [anon_sym_PLUS_EQ] = ACTIONS(160),
    [anon_sym_DASH_EQ] = ACTIONS(160),
    [anon_sym_STAR_EQ] = ACTIONS(160),
    [anon_sym_SLASH_EQ] = ACTIONS(160),
    [anon_sym_PERCENT_EQ] = ACTIONS(160),
    [anon_sym_CARET_EQ] = ACTIONS(160),
    [anon_sym_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_LT_LT_EQ] = ACTIONS(160),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(160),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP] = ACTIONS(120),
    [anon_sym_PIPE_PIPE] = ACTIONS(120),
    [anon_sym_GT_GT] = ACTIONS(120),
    [anon_sym_GT_GT_GT] = ACTIONS(120),
    [anon_sym_LT_LT] = ACTIONS(120),
    [anon_sym_AMP] = ACTIONS(120),
    [anon_sym_CARET] = ACTIONS(120),
    [anon_sym_PIPE] = ACTIONS(120),
    [anon_sym_PLUS] = ACTIONS(120),
    [anon_sym_DASH] = ACTIONS(120),
    [anon_sym_SLASH] = ACTIONS(120),
    [anon_sym_PERCENT] = ACTIONS(120),
    [anon_sym_STAR_STAR] = ACTIONS(120),
    [anon_sym_LT] = ACTIONS(2420),
    [anon_sym_LT_EQ] = ACTIONS(154),
    [anon_sym_EQ_EQ] = ACTIONS(120),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(154),
    [anon_sym_BANG_EQ] = ACTIONS(120),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(154),
    [anon_sym_GT_EQ] = ACTIONS(154),
    [anon_sym_GT] = ACTIONS(120),
    [anon_sym_QMARK_QMARK] = ACTIONS(120),
    [anon_sym_instanceof] = ACTIONS(120),
    [anon_sym_PLUS_PLUS] = ACTIONS(154),
    [anon_sym_DASH_DASH] = ACTIONS(154),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(154),
    [anon_sym_static] = ACTIONS(2477),
    [anon_sym_readonly] = ACTIONS(2477),
    [anon_sym_get] = ACTIONS(2477),
    [anon_sym_set] = ACTIONS(2477),
    [anon_sym_declare] = ACTIONS(2477),
    [anon_sym_public] = ACTIONS(2477),
    [anon_sym_private] = ACTIONS(2477),
    [anon_sym_protected] = ACTIONS(2477),
    [anon_sym_override] = ACTIONS(2477),
    [anon_sym_module] = ACTIONS(2477),
    [anon_sym_any] = ACTIONS(2477),
    [anon_sym_number] = ACTIONS(2477),
    [anon_sym_boolean] = ACTIONS(2477),
    [anon_sym_string] = ACTIONS(2477),
    [anon_sym_symbol] = ACTIONS(2477),
    [anon_sym_object] = ACTIONS(2477),
    [anon_sym_satisfies] = ACTIONS(120),
    [sym__ternary_qmark] = ACTIONS(154),
    [sym_html_comment] = ACTIONS(5),
  },
  [765] = {
    [sym__call_signature] = STATE(5834),
    [sym_formal_parameters] = STATE(3806),
    [sym_type_parameters] = STATE(5328),
    [sym_identifier] = ACTIONS(2411),
    [anon_sym_export] = ACTIONS(2413),
    [anon_sym_STAR] = ACTIONS(120),
    [anon_sym_type] = ACTIONS(2413),
    [anon_sym_EQ] = ACTIONS(824),
    [anon_sym_as] = ACTIONS(120),
    [anon_sym_namespace] = ACTIONS(2413),
    [anon_sym_let] = ACTIONS(2413),
    [anon_sym_BANG] = ACTIONS(120),
    [anon_sym_LPAREN] = ACTIONS(2415),
    [anon_sym_in] = ACTIONS(902),
    [anon_sym_of] = ACTIONS(905),
    [anon_sym_LBRACK] = ACTIONS(154),
    [anon_sym_DOT] = ACTIONS(154),
    [anon_sym_async] = ACTIONS(2413),
    [anon_sym_function] = ACTIONS(2418),
    [anon_sym_EQ_GT] = ACTIONS(225),
    [anon_sym_QMARK_DOT] = ACTIONS(154),
    [anon_sym_new] = ACTIONS(2413),
    [anon_sym_PLUS_EQ] = ACTIONS(160),
    [anon_sym_DASH_EQ] = ACTIONS(160),
    [anon_sym_STAR_EQ] = ACTIONS(160),
    [anon_sym_SLASH_EQ] = ACTIONS(160),
    [anon_sym_PERCENT_EQ] = ACTIONS(160),
    [anon_sym_CARET_EQ] = ACTIONS(160),
    [anon_sym_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_LT_LT_EQ] = ACTIONS(160),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(160),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP] = ACTIONS(120),
    [anon_sym_PIPE_PIPE] = ACTIONS(120),
    [anon_sym_GT_GT] = ACTIONS(120),
    [anon_sym_GT_GT_GT] = ACTIONS(120),
    [anon_sym_LT_LT] = ACTIONS(120),
    [anon_sym_AMP] = ACTIONS(120),
    [anon_sym_CARET] = ACTIONS(120),
    [anon_sym_PIPE] = ACTIONS(120),
    [anon_sym_PLUS] = ACTIONS(120),
    [anon_sym_DASH] = ACTIONS(120),
    [anon_sym_SLASH] = ACTIONS(120),
    [anon_sym_PERCENT] = ACTIONS(120),
    [anon_sym_STAR_STAR] = ACTIONS(120),
    [anon_sym_LT] = ACTIONS(2420),
    [anon_sym_LT_EQ] = ACTIONS(154),
    [anon_sym_EQ_EQ] = ACTIONS(120),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(154),
    [anon_sym_BANG_EQ] = ACTIONS(120),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(154),
    [anon_sym_GT_EQ] = ACTIONS(154),
    [anon_sym_GT] = ACTIONS(120),
    [anon_sym_QMARK_QMARK] = ACTIONS(120),
    [anon_sym_instanceof] = ACTIONS(120),
    [anon_sym_PLUS_PLUS] = ACTIONS(154),
    [anon_sym_DASH_DASH] = ACTIONS(154),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(154),
    [anon_sym_static] = ACTIONS(2413),
    [anon_sym_readonly] = ACTIONS(2413),
    [anon_sym_get] = ACTIONS(2413),
    [anon_sym_set] = ACTIONS(2413),
    [anon_sym_declare] = ACTIONS(2413),
    [anon_sym_public] = ACTIONS(2413),
    [anon_sym_private] = ACTIONS(2413),
    [anon_sym_protected] = ACTIONS(2413),
    [anon_sym_override] = ACTIONS(2413),
    [anon_sym_module] = ACTIONS(2413),
    [anon_sym_any] = ACTIONS(2413),
    [anon_sym_number] = ACTIONS(2413),
    [anon_sym_boolean] = ACTIONS(2413),
    [anon_sym_string] = ACTIONS(2413),
    [anon_sym_symbol] = ACTIONS(2413),
    [anon_sym_object] = ACTIONS(2413),
    [anon_sym_satisfies] = ACTIONS(120),
    [sym__ternary_qmark] = ACTIONS(154),
    [sym_html_comment] = ACTIONS(5),
  },
  [766] = {
    [sym__call_signature] = STATE(5533),
    [sym_formal_parameters] = STATE(3806),
    [sym_type_parameters] = STATE(5328),
    [sym_identifier] = ACTIONS(2475),
    [anon_sym_export] = ACTIONS(2477),
    [anon_sym_STAR] = ACTIONS(120),
    [anon_sym_type] = ACTIONS(2477),
    [anon_sym_EQ] = ACTIONS(948),
    [anon_sym_as] = ACTIONS(120),
    [anon_sym_namespace] = ACTIONS(2477),
    [anon_sym_let] = ACTIONS(2477),
    [anon_sym_BANG] = ACTIONS(120),
    [anon_sym_LPAREN] = ACTIONS(2415),
    [anon_sym_in] = ACTIONS(120),
    [anon_sym_of] = ACTIONS(120),
    [anon_sym_LBRACK] = ACTIONS(154),
    [anon_sym_DOT] = ACTIONS(154),
    [anon_sym_async] = ACTIONS(2477),
    [anon_sym_function] = ACTIONS(2418),
    [anon_sym_EQ_GT] = ACTIONS(954),
    [anon_sym_QMARK_DOT] = ACTIONS(154),
    [anon_sym_new] = ACTIONS(2477),
    [anon_sym_PLUS_EQ] = ACTIONS(160),
    [anon_sym_DASH_EQ] = ACTIONS(160),
    [anon_sym_STAR_EQ] = ACTIONS(160),
    [anon_sym_SLASH_EQ] = ACTIONS(160),
    [anon_sym_PERCENT_EQ] = ACTIONS(160),
    [anon_sym_CARET_EQ] = ACTIONS(160),
    [anon_sym_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_LT_LT_EQ] = ACTIONS(160),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(160),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP] = ACTIONS(120),
    [anon_sym_PIPE_PIPE] = ACTIONS(120),
    [anon_sym_GT_GT] = ACTIONS(120),
    [anon_sym_GT_GT_GT] = ACTIONS(120),
    [anon_sym_LT_LT] = ACTIONS(120),
    [anon_sym_AMP] = ACTIONS(120),
    [anon_sym_CARET] = ACTIONS(120),
    [anon_sym_PIPE] = ACTIONS(120),
    [anon_sym_PLUS] = ACTIONS(120),
    [anon_sym_DASH] = ACTIONS(120),
    [anon_sym_SLASH] = ACTIONS(120),
    [anon_sym_PERCENT] = ACTIONS(120),
    [anon_sym_STAR_STAR] = ACTIONS(120),
    [anon_sym_LT] = ACTIONS(2420),
    [anon_sym_LT_EQ] = ACTIONS(154),
    [anon_sym_EQ_EQ] = ACTIONS(120),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(154),
    [anon_sym_BANG_EQ] = ACTIONS(120),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(154),
    [anon_sym_GT_EQ] = ACTIONS(154),
    [anon_sym_GT] = ACTIONS(120),
    [anon_sym_QMARK_QMARK] = ACTIONS(120),
    [anon_sym_instanceof] = ACTIONS(120),
    [anon_sym_PLUS_PLUS] = ACTIONS(154),
    [anon_sym_DASH_DASH] = ACTIONS(154),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(154),
    [anon_sym_static] = ACTIONS(2477),
    [anon_sym_readonly] = ACTIONS(2477),
    [anon_sym_get] = ACTIONS(2477),
    [anon_sym_set] = ACTIONS(2477),
    [anon_sym_declare] = ACTIONS(2477),
    [anon_sym_public] = ACTIONS(2477),
    [anon_sym_private] = ACTIONS(2477),
    [anon_sym_protected] = ACTIONS(2477),
    [anon_sym_override] = ACTIONS(2477),
    [anon_sym_module] = ACTIONS(2477),
    [anon_sym_any] = ACTIONS(2477),
    [anon_sym_number] = ACTIONS(2477),
    [anon_sym_boolean] = ACTIONS(2477),
    [anon_sym_string] = ACTIONS(2477),
    [anon_sym_symbol] = ACTIONS(2477),
    [anon_sym_object] = ACTIONS(2477),
    [anon_sym_satisfies] = ACTIONS(120),
    [sym__ternary_qmark] = ACTIONS(154),
    [sym_html_comment] = ACTIONS(5),
  },
  [767] = {
    [sym__call_signature] = STATE(5481),
    [sym_formal_parameters] = STATE(3806),
    [sym_type_parameters] = STATE(5328),
    [sym_identifier] = ACTIONS(2443),
    [anon_sym_export] = ACTIONS(2445),
    [anon_sym_STAR] = ACTIONS(120),
    [anon_sym_type] = ACTIONS(2445),
    [anon_sym_EQ] = ACTIONS(824),
    [anon_sym_as] = ACTIONS(120),
    [anon_sym_namespace] = ACTIONS(2445),
    [anon_sym_let] = ACTIONS(2445),
    [anon_sym_BANG] = ACTIONS(120),
    [anon_sym_LPAREN] = ACTIONS(2415),
    [anon_sym_in] = ACTIONS(120),
    [anon_sym_LBRACK] = ACTIONS(154),
    [anon_sym_RBRACK] = ACTIONS(154),
    [anon_sym_DOT] = ACTIONS(154),
    [anon_sym_async] = ACTIONS(2445),
    [anon_sym_function] = ACTIONS(2418),
    [anon_sym_EQ_GT] = ACTIONS(895),
    [anon_sym_QMARK_DOT] = ACTIONS(154),
    [anon_sym_new] = ACTIONS(2445),
    [anon_sym_PLUS_EQ] = ACTIONS(160),
    [anon_sym_DASH_EQ] = ACTIONS(160),
    [anon_sym_STAR_EQ] = ACTIONS(160),
    [anon_sym_SLASH_EQ] = ACTIONS(160),
    [anon_sym_PERCENT_EQ] = ACTIONS(160),
    [anon_sym_CARET_EQ] = ACTIONS(160),
    [anon_sym_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_LT_LT_EQ] = ACTIONS(160),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(160),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP] = ACTIONS(120),
    [anon_sym_PIPE_PIPE] = ACTIONS(120),
    [anon_sym_GT_GT] = ACTIONS(120),
    [anon_sym_GT_GT_GT] = ACTIONS(120),
    [anon_sym_LT_LT] = ACTIONS(120),
    [anon_sym_AMP] = ACTIONS(120),
    [anon_sym_CARET] = ACTIONS(120),
    [anon_sym_PIPE] = ACTIONS(120),
    [anon_sym_PLUS] = ACTIONS(120),
    [anon_sym_DASH] = ACTIONS(120),
    [anon_sym_SLASH] = ACTIONS(120),
    [anon_sym_PERCENT] = ACTIONS(120),
    [anon_sym_STAR_STAR] = ACTIONS(120),
    [anon_sym_LT] = ACTIONS(2420),
    [anon_sym_LT_EQ] = ACTIONS(154),
    [anon_sym_EQ_EQ] = ACTIONS(120),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(154),
    [anon_sym_BANG_EQ] = ACTIONS(120),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(154),
    [anon_sym_GT_EQ] = ACTIONS(154),
    [anon_sym_GT] = ACTIONS(120),
    [anon_sym_QMARK_QMARK] = ACTIONS(120),
    [anon_sym_instanceof] = ACTIONS(120),
    [anon_sym_PLUS_PLUS] = ACTIONS(154),
    [anon_sym_DASH_DASH] = ACTIONS(154),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(154),
    [anon_sym_static] = ACTIONS(2445),
    [anon_sym_readonly] = ACTIONS(2445),
    [anon_sym_get] = ACTIONS(2445),
    [anon_sym_set] = ACTIONS(2445),
    [anon_sym_declare] = ACTIONS(2445),
    [anon_sym_public] = ACTIONS(2445),
    [anon_sym_private] = ACTIONS(2445),
    [anon_sym_protected] = ACTIONS(2445),
    [anon_sym_override] = ACTIONS(2445),
    [anon_sym_module] = ACTIONS(2445),
    [anon_sym_any] = ACTIONS(2445),
    [anon_sym_number] = ACTIONS(2445),
    [anon_sym_boolean] = ACTIONS(2445),
    [anon_sym_string] = ACTIONS(2445),
    [anon_sym_symbol] = ACTIONS(2445),
    [anon_sym_object] = ACTIONS(2445),
    [anon_sym_satisfies] = ACTIONS(120),
    [sym__ternary_qmark] = ACTIONS(154),
    [sym_html_comment] = ACTIONS(5),
  },
  [768] = {
    [sym__call_signature] = STATE(5834),
    [sym_formal_parameters] = STATE(3806),
    [sym_type_parameters] = STATE(5328),
    [sym_identifier] = ACTIONS(2411),
    [anon_sym_export] = ACTIONS(2413),
    [anon_sym_STAR] = ACTIONS(120),
    [anon_sym_type] = ACTIONS(2413),
    [anon_sym_EQ] = ACTIONS(824),
    [anon_sym_as] = ACTIONS(120),
    [anon_sym_namespace] = ACTIONS(2413),
    [anon_sym_let] = ACTIONS(2413),
    [anon_sym_BANG] = ACTIONS(120),
    [anon_sym_LPAREN] = ACTIONS(2415),
    [anon_sym_in] = ACTIONS(120),
    [anon_sym_COLON] = ACTIONS(826),
    [anon_sym_LBRACK] = ACTIONS(154),
    [anon_sym_DOT] = ACTIONS(154),
    [anon_sym_async] = ACTIONS(2413),
    [anon_sym_function] = ACTIONS(2418),
    [anon_sym_EQ_GT] = ACTIONS(225),
    [anon_sym_QMARK_DOT] = ACTIONS(154),
    [anon_sym_new] = ACTIONS(2413),
    [anon_sym_PLUS_EQ] = ACTIONS(160),
    [anon_sym_DASH_EQ] = ACTIONS(160),
    [anon_sym_STAR_EQ] = ACTIONS(160),
    [anon_sym_SLASH_EQ] = ACTIONS(160),
    [anon_sym_PERCENT_EQ] = ACTIONS(160),
    [anon_sym_CARET_EQ] = ACTIONS(160),
    [anon_sym_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_LT_LT_EQ] = ACTIONS(160),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(160),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP] = ACTIONS(120),
    [anon_sym_PIPE_PIPE] = ACTIONS(120),
    [anon_sym_GT_GT] = ACTIONS(120),
    [anon_sym_GT_GT_GT] = ACTIONS(120),
    [anon_sym_LT_LT] = ACTIONS(120),
    [anon_sym_AMP] = ACTIONS(120),
    [anon_sym_CARET] = ACTIONS(120),
    [anon_sym_PIPE] = ACTIONS(120),
    [anon_sym_PLUS] = ACTIONS(120),
    [anon_sym_DASH] = ACTIONS(120),
    [anon_sym_SLASH] = ACTIONS(120),
    [anon_sym_PERCENT] = ACTIONS(120),
    [anon_sym_STAR_STAR] = ACTIONS(120),
    [anon_sym_LT] = ACTIONS(2420),
    [anon_sym_LT_EQ] = ACTIONS(154),
    [anon_sym_EQ_EQ] = ACTIONS(120),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(154),
    [anon_sym_BANG_EQ] = ACTIONS(120),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(154),
    [anon_sym_GT_EQ] = ACTIONS(154),
    [anon_sym_GT] = ACTIONS(120),
    [anon_sym_QMARK_QMARK] = ACTIONS(120),
    [anon_sym_instanceof] = ACTIONS(120),
    [anon_sym_PLUS_PLUS] = ACTIONS(154),
    [anon_sym_DASH_DASH] = ACTIONS(154),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(154),
    [anon_sym_static] = ACTIONS(2413),
    [anon_sym_readonly] = ACTIONS(2413),
    [anon_sym_get] = ACTIONS(2413),
    [anon_sym_set] = ACTIONS(2413),
    [anon_sym_declare] = ACTIONS(2413),
    [anon_sym_public] = ACTIONS(2413),
    [anon_sym_private] = ACTIONS(2413),
    [anon_sym_protected] = ACTIONS(2413),
    [anon_sym_override] = ACTIONS(2413),
    [anon_sym_module] = ACTIONS(2413),
    [anon_sym_any] = ACTIONS(2413),
    [anon_sym_number] = ACTIONS(2413),
    [anon_sym_boolean] = ACTIONS(2413),
    [anon_sym_string] = ACTIONS(2413),
    [anon_sym_symbol] = ACTIONS(2413),
    [anon_sym_object] = ACTIONS(2413),
    [anon_sym_satisfies] = ACTIONS(120),
    [sym__ternary_qmark] = ACTIONS(154),
    [sym_html_comment] = ACTIONS(5),
  },
  [769] = {
    [ts_builtin_sym_end] = ACTIONS(1716),
    [sym_identifier] = ACTIONS(1718),
    [anon_sym_export] = ACTIONS(1718),
    [anon_sym_default] = ACTIONS(1718),
    [anon_sym_type] = ACTIONS(1718),
    [anon_sym_namespace] = ACTIONS(1718),
    [anon_sym_LBRACE] = ACTIONS(1716),
    [anon_sym_COMMA] = ACTIONS(1716),
    [anon_sym_RBRACE] = ACTIONS(1716),
    [anon_sym_typeof] = ACTIONS(1718),
    [anon_sym_import] = ACTIONS(1718),
    [anon_sym_with] = ACTIONS(1718),
    [anon_sym_var] = ACTIONS(1718),
    [anon_sym_let] = ACTIONS(1718),
    [anon_sym_const] = ACTIONS(1718),
    [anon_sym_BANG] = ACTIONS(1716),
    [anon_sym_else] = ACTIONS(1718),
    [anon_sym_if] = ACTIONS(1718),
    [anon_sym_switch] = ACTIONS(1718),
    [anon_sym_for] = ACTIONS(1718),
    [anon_sym_LPAREN] = ACTIONS(1716),
    [anon_sym_SEMI] = ACTIONS(1716),
    [anon_sym_await] = ACTIONS(1718),
    [anon_sym_while] = ACTIONS(1718),
    [anon_sym_do] = ACTIONS(1718),
    [anon_sym_try] = ACTIONS(1718),
    [anon_sym_break] = ACTIONS(1718),
    [anon_sym_continue] = ACTIONS(1718),
    [anon_sym_debugger] = ACTIONS(1718),
    [anon_sym_return] = ACTIONS(1718),
    [anon_sym_throw] = ACTIONS(1718),
    [anon_sym_case] = ACTIONS(1718),
    [anon_sym_catch] = ACTIONS(1718),
    [anon_sym_finally] = ACTIONS(1718),
    [anon_sym_yield] = ACTIONS(1718),
    [anon_sym_LBRACK] = ACTIONS(1716),
    [anon_sym_class] = ACTIONS(1718),
    [anon_sym_async] = ACTIONS(1718),
    [anon_sym_function] = ACTIONS(1718),
    [anon_sym_new] = ACTIONS(1718),
    [anon_sym_using] = ACTIONS(1718),
    [anon_sym_PLUS] = ACTIONS(1718),
    [anon_sym_DASH] = ACTIONS(1718),
    [anon_sym_SLASH] = ACTIONS(1718),
    [anon_sym_LT] = ACTIONS(1716),
    [anon_sym_TILDE] = ACTIONS(1716),
    [anon_sym_void] = ACTIONS(1718),
    [anon_sym_delete] = ACTIONS(1718),
    [anon_sym_PLUS_PLUS] = ACTIONS(1716),
    [anon_sym_DASH_DASH] = ACTIONS(1716),
    [anon_sym_DQUOTE] = ACTIONS(1716),
    [anon_sym_SQUOTE] = ACTIONS(1716),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1716),
    [sym_number] = ACTIONS(1716),
    [sym_private_property_identifier] = ACTIONS(1716),
    [sym_this] = ACTIONS(1718),
    [sym_super] = ACTIONS(1718),
    [sym_true] = ACTIONS(1718),
    [sym_false] = ACTIONS(1718),
    [sym_null] = ACTIONS(1718),
    [sym_undefined] = ACTIONS(1718),
    [anon_sym_AT] = ACTIONS(1716),
    [anon_sym_static] = ACTIONS(1718),
    [anon_sym_readonly] = ACTIONS(1718),
    [anon_sym_get] = ACTIONS(1718),
    [anon_sym_set] = ACTIONS(1718),
    [anon_sym_declare] = ACTIONS(1718),
    [anon_sym_public] = ACTIONS(1718),
    [anon_sym_private] = ACTIONS(1718),
    [anon_sym_protected] = ACTIONS(1718),
    [anon_sym_override] = ACTIONS(1718),
    [anon_sym_module] = ACTIONS(1718),
    [anon_sym_any] = ACTIONS(1718),
    [anon_sym_number] = ACTIONS(1718),
    [anon_sym_boolean] = ACTIONS(1718),
    [anon_sym_string] = ACTIONS(1718),
    [anon_sym_symbol] = ACTIONS(1718),
    [anon_sym_object] = ACTIONS(1718),
    [anon_sym_abstract] = ACTIONS(1718),
    [anon_sym_interface] = ACTIONS(1718),
    [anon_sym_enum] = ACTIONS(1718),
    [sym_html_comment] = ACTIONS(5),
  },
  [770] = {
    [sym_finally_clause] = STATE(826),
    [ts_builtin_sym_end] = ACTIONS(2479),
    [sym_identifier] = ACTIONS(2481),
    [anon_sym_export] = ACTIONS(2481),
    [anon_sym_default] = ACTIONS(2481),
    [anon_sym_type] = ACTIONS(2481),
    [anon_sym_namespace] = ACTIONS(2481),
    [anon_sym_LBRACE] = ACTIONS(2479),
    [anon_sym_RBRACE] = ACTIONS(2479),
    [anon_sym_typeof] = ACTIONS(2481),
    [anon_sym_import] = ACTIONS(2481),
    [anon_sym_with] = ACTIONS(2481),
    [anon_sym_var] = ACTIONS(2481),
    [anon_sym_let] = ACTIONS(2481),
    [anon_sym_const] = ACTIONS(2481),
    [anon_sym_BANG] = ACTIONS(2479),
    [anon_sym_else] = ACTIONS(2481),
    [anon_sym_if] = ACTIONS(2481),
    [anon_sym_switch] = ACTIONS(2481),
    [anon_sym_for] = ACTIONS(2481),
    [anon_sym_LPAREN] = ACTIONS(2479),
    [anon_sym_SEMI] = ACTIONS(2479),
    [anon_sym_await] = ACTIONS(2481),
    [anon_sym_while] = ACTIONS(2481),
    [anon_sym_do] = ACTIONS(2481),
    [anon_sym_try] = ACTIONS(2481),
    [anon_sym_break] = ACTIONS(2481),
    [anon_sym_continue] = ACTIONS(2481),
    [anon_sym_debugger] = ACTIONS(2481),
    [anon_sym_return] = ACTIONS(2481),
    [anon_sym_throw] = ACTIONS(2481),
    [anon_sym_case] = ACTIONS(2481),
    [anon_sym_finally] = ACTIONS(2461),
    [anon_sym_yield] = ACTIONS(2481),
    [anon_sym_LBRACK] = ACTIONS(2479),
    [anon_sym_class] = ACTIONS(2481),
    [anon_sym_async] = ACTIONS(2481),
    [anon_sym_function] = ACTIONS(2481),
    [anon_sym_new] = ACTIONS(2481),
    [anon_sym_using] = ACTIONS(2481),
    [anon_sym_PLUS] = ACTIONS(2481),
    [anon_sym_DASH] = ACTIONS(2481),
    [anon_sym_SLASH] = ACTIONS(2481),
    [anon_sym_LT] = ACTIONS(2479),
    [anon_sym_TILDE] = ACTIONS(2479),
    [anon_sym_void] = ACTIONS(2481),
    [anon_sym_delete] = ACTIONS(2481),
    [anon_sym_PLUS_PLUS] = ACTIONS(2479),
    [anon_sym_DASH_DASH] = ACTIONS(2479),
    [anon_sym_DQUOTE] = ACTIONS(2479),
    [anon_sym_SQUOTE] = ACTIONS(2479),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(2479),
    [sym_number] = ACTIONS(2479),
    [sym_private_property_identifier] = ACTIONS(2479),
    [sym_this] = ACTIONS(2481),
    [sym_super] = ACTIONS(2481),
    [sym_true] = ACTIONS(2481),
    [sym_false] = ACTIONS(2481),
    [sym_null] = ACTIONS(2481),
    [sym_undefined] = ACTIONS(2481),
    [anon_sym_AT] = ACTIONS(2479),
    [anon_sym_static] = ACTIONS(2481),
    [anon_sym_readonly] = ACTIONS(2481),
    [anon_sym_get] = ACTIONS(2481),
    [anon_sym_set] = ACTIONS(2481),
    [anon_sym_declare] = ACTIONS(2481),
    [anon_sym_public] = ACTIONS(2481),
    [anon_sym_private] = ACTIONS(2481),
    [anon_sym_protected] = ACTIONS(2481),
    [anon_sym_override] = ACTIONS(2481),
    [anon_sym_module] = ACTIONS(2481),
    [anon_sym_any] = ACTIONS(2481),
    [anon_sym_number] = ACTIONS(2481),
    [anon_sym_boolean] = ACTIONS(2481),
    [anon_sym_string] = ACTIONS(2481),
    [anon_sym_symbol] = ACTIONS(2481),
    [anon_sym_object] = ACTIONS(2481),
    [anon_sym_abstract] = ACTIONS(2481),
    [anon_sym_interface] = ACTIONS(2481),
    [anon_sym_enum] = ACTIONS(2481),
    [sym_html_comment] = ACTIONS(5),
  },
  [771] = {
    [sym__call_signature] = STATE(5834),
    [sym_formal_parameters] = STATE(3806),
    [sym_type_parameters] = STATE(5328),
    [sym_identifier] = ACTIONS(2411),
    [anon_sym_export] = ACTIONS(2413),
    [anon_sym_STAR] = ACTIONS(120),
    [anon_sym_type] = ACTIONS(2413),
    [anon_sym_EQ] = ACTIONS(980),
    [anon_sym_as] = ACTIONS(120),
    [anon_sym_namespace] = ACTIONS(2413),
    [anon_sym_let] = ACTIONS(2413),
    [anon_sym_BANG] = ACTIONS(120),
    [anon_sym_LPAREN] = ACTIONS(2415),
    [anon_sym_in] = ACTIONS(120),
    [anon_sym_LBRACK] = ACTIONS(154),
    [anon_sym_DOT] = ACTIONS(154),
    [anon_sym_async] = ACTIONS(2413),
    [anon_sym_function] = ACTIONS(2418),
    [anon_sym_EQ_GT] = ACTIONS(225),
    [anon_sym_QMARK_DOT] = ACTIONS(154),
    [anon_sym_new] = ACTIONS(2413),
    [anon_sym_PLUS_EQ] = ACTIONS(160),
    [anon_sym_DASH_EQ] = ACTIONS(160),
    [anon_sym_STAR_EQ] = ACTIONS(160),
    [anon_sym_SLASH_EQ] = ACTIONS(160),
    [anon_sym_PERCENT_EQ] = ACTIONS(160),
    [anon_sym_CARET_EQ] = ACTIONS(160),
    [anon_sym_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_LT_LT_EQ] = ACTIONS(160),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(160),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP] = ACTIONS(120),
    [anon_sym_PIPE_PIPE] = ACTIONS(120),
    [anon_sym_GT_GT] = ACTIONS(120),
    [anon_sym_GT_GT_GT] = ACTIONS(120),
    [anon_sym_LT_LT] = ACTIONS(120),
    [anon_sym_AMP] = ACTIONS(120),
    [anon_sym_CARET] = ACTIONS(120),
    [anon_sym_PIPE] = ACTIONS(120),
    [anon_sym_PLUS] = ACTIONS(120),
    [anon_sym_DASH] = ACTIONS(120),
    [anon_sym_SLASH] = ACTIONS(120),
    [anon_sym_PERCENT] = ACTIONS(120),
    [anon_sym_STAR_STAR] = ACTIONS(120),
    [anon_sym_LT] = ACTIONS(2420),
    [anon_sym_LT_EQ] = ACTIONS(154),
    [anon_sym_EQ_EQ] = ACTIONS(120),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(154),
    [anon_sym_BANG_EQ] = ACTIONS(120),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(154),
    [anon_sym_GT_EQ] = ACTIONS(154),
    [anon_sym_GT] = ACTIONS(120),
    [anon_sym_QMARK_QMARK] = ACTIONS(120),
    [anon_sym_instanceof] = ACTIONS(120),
    [anon_sym_PLUS_PLUS] = ACTIONS(154),
    [anon_sym_DASH_DASH] = ACTIONS(154),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(154),
    [anon_sym_static] = ACTIONS(2413),
    [anon_sym_readonly] = ACTIONS(2413),
    [anon_sym_get] = ACTIONS(2413),
    [anon_sym_set] = ACTIONS(2413),
    [anon_sym_declare] = ACTIONS(2413),
    [anon_sym_public] = ACTIONS(2413),
    [anon_sym_private] = ACTIONS(2413),
    [anon_sym_protected] = ACTIONS(2413),
    [anon_sym_override] = ACTIONS(2413),
    [anon_sym_module] = ACTIONS(2413),
    [anon_sym_any] = ACTIONS(2413),
    [anon_sym_number] = ACTIONS(2413),
    [anon_sym_boolean] = ACTIONS(2413),
    [anon_sym_string] = ACTIONS(2413),
    [anon_sym_symbol] = ACTIONS(2413),
    [anon_sym_object] = ACTIONS(2413),
    [anon_sym_satisfies] = ACTIONS(120),
    [sym__ternary_qmark] = ACTIONS(154),
    [sym_html_comment] = ACTIONS(5),
  },
  [772] = {
    [sym__call_signature] = STATE(5834),
    [sym_formal_parameters] = STATE(3806),
    [sym_type_parameters] = STATE(5328),
    [sym_identifier] = ACTIONS(2411),
    [anon_sym_export] = ACTIONS(2413),
    [anon_sym_STAR] = ACTIONS(120),
    [anon_sym_type] = ACTIONS(2413),
    [anon_sym_EQ] = ACTIONS(978),
    [anon_sym_as] = ACTIONS(120),
    [anon_sym_namespace] = ACTIONS(2413),
    [anon_sym_let] = ACTIONS(2413),
    [anon_sym_BANG] = ACTIONS(120),
    [anon_sym_LPAREN] = ACTIONS(2415),
    [anon_sym_in] = ACTIONS(120),
    [anon_sym_LBRACK] = ACTIONS(154),
    [anon_sym_DOT] = ACTIONS(154),
    [anon_sym_async] = ACTIONS(2413),
    [anon_sym_function] = ACTIONS(2418),
    [anon_sym_EQ_GT] = ACTIONS(225),
    [anon_sym_QMARK_DOT] = ACTIONS(154),
    [anon_sym_new] = ACTIONS(2413),
    [anon_sym_PLUS_EQ] = ACTIONS(160),
    [anon_sym_DASH_EQ] = ACTIONS(160),
    [anon_sym_STAR_EQ] = ACTIONS(160),
    [anon_sym_SLASH_EQ] = ACTIONS(160),
    [anon_sym_PERCENT_EQ] = ACTIONS(160),
    [anon_sym_CARET_EQ] = ACTIONS(160),
    [anon_sym_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_LT_LT_EQ] = ACTIONS(160),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(160),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP] = ACTIONS(120),
    [anon_sym_PIPE_PIPE] = ACTIONS(120),
    [anon_sym_GT_GT] = ACTIONS(120),
    [anon_sym_GT_GT_GT] = ACTIONS(120),
    [anon_sym_LT_LT] = ACTIONS(120),
    [anon_sym_AMP] = ACTIONS(120),
    [anon_sym_CARET] = ACTIONS(120),
    [anon_sym_PIPE] = ACTIONS(120),
    [anon_sym_PLUS] = ACTIONS(120),
    [anon_sym_DASH] = ACTIONS(120),
    [anon_sym_SLASH] = ACTIONS(120),
    [anon_sym_PERCENT] = ACTIONS(120),
    [anon_sym_STAR_STAR] = ACTIONS(120),
    [anon_sym_LT] = ACTIONS(2420),
    [anon_sym_LT_EQ] = ACTIONS(154),
    [anon_sym_EQ_EQ] = ACTIONS(120),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(154),
    [anon_sym_BANG_EQ] = ACTIONS(120),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(154),
    [anon_sym_GT_EQ] = ACTIONS(154),
    [anon_sym_GT] = ACTIONS(120),
    [anon_sym_QMARK_QMARK] = ACTIONS(120),
    [anon_sym_instanceof] = ACTIONS(120),
    [anon_sym_PLUS_PLUS] = ACTIONS(154),
    [anon_sym_DASH_DASH] = ACTIONS(154),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(154),
    [anon_sym_static] = ACTIONS(2413),
    [anon_sym_readonly] = ACTIONS(2413),
    [anon_sym_get] = ACTIONS(2413),
    [anon_sym_set] = ACTIONS(2413),
    [anon_sym_declare] = ACTIONS(2413),
    [anon_sym_public] = ACTIONS(2413),
    [anon_sym_private] = ACTIONS(2413),
    [anon_sym_protected] = ACTIONS(2413),
    [anon_sym_override] = ACTIONS(2413),
    [anon_sym_module] = ACTIONS(2413),
    [anon_sym_any] = ACTIONS(2413),
    [anon_sym_number] = ACTIONS(2413),
    [anon_sym_boolean] = ACTIONS(2413),
    [anon_sym_string] = ACTIONS(2413),
    [anon_sym_symbol] = ACTIONS(2413),
    [anon_sym_object] = ACTIONS(2413),
    [anon_sym_satisfies] = ACTIONS(120),
    [sym__ternary_qmark] = ACTIONS(154),
    [sym_html_comment] = ACTIONS(5),
  },
  [773] = {
    [sym__call_signature] = STATE(5834),
    [sym_formal_parameters] = STATE(3806),
    [sym_type_parameters] = STATE(5328),
    [sym_identifier] = ACTIONS(2411),
    [anon_sym_export] = ACTIONS(2413),
    [anon_sym_STAR] = ACTIONS(120),
    [anon_sym_type] = ACTIONS(2413),
    [anon_sym_EQ] = ACTIONS(974),
    [anon_sym_as] = ACTIONS(120),
    [anon_sym_namespace] = ACTIONS(2413),
    [anon_sym_let] = ACTIONS(2413),
    [anon_sym_BANG] = ACTIONS(120),
    [anon_sym_LPAREN] = ACTIONS(2415),
    [anon_sym_in] = ACTIONS(120),
    [anon_sym_LBRACK] = ACTIONS(154),
    [anon_sym_DOT] = ACTIONS(154),
    [anon_sym_async] = ACTIONS(2413),
    [anon_sym_function] = ACTIONS(2418),
    [anon_sym_EQ_GT] = ACTIONS(225),
    [anon_sym_QMARK_DOT] = ACTIONS(154),
    [anon_sym_new] = ACTIONS(2413),
    [anon_sym_PLUS_EQ] = ACTIONS(160),
    [anon_sym_DASH_EQ] = ACTIONS(160),
    [anon_sym_STAR_EQ] = ACTIONS(160),
    [anon_sym_SLASH_EQ] = ACTIONS(160),
    [anon_sym_PERCENT_EQ] = ACTIONS(160),
    [anon_sym_CARET_EQ] = ACTIONS(160),
    [anon_sym_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_LT_LT_EQ] = ACTIONS(160),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(160),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP] = ACTIONS(120),
    [anon_sym_PIPE_PIPE] = ACTIONS(120),
    [anon_sym_GT_GT] = ACTIONS(120),
    [anon_sym_GT_GT_GT] = ACTIONS(120),
    [anon_sym_LT_LT] = ACTIONS(120),
    [anon_sym_AMP] = ACTIONS(120),
    [anon_sym_CARET] = ACTIONS(120),
    [anon_sym_PIPE] = ACTIONS(120),
    [anon_sym_PLUS] = ACTIONS(120),
    [anon_sym_DASH] = ACTIONS(120),
    [anon_sym_SLASH] = ACTIONS(120),
    [anon_sym_PERCENT] = ACTIONS(120),
    [anon_sym_STAR_STAR] = ACTIONS(120),
    [anon_sym_LT] = ACTIONS(2420),
    [anon_sym_LT_EQ] = ACTIONS(154),
    [anon_sym_EQ_EQ] = ACTIONS(120),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(154),
    [anon_sym_BANG_EQ] = ACTIONS(120),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(154),
    [anon_sym_GT_EQ] = ACTIONS(154),
    [anon_sym_GT] = ACTIONS(120),
    [anon_sym_QMARK_QMARK] = ACTIONS(120),
    [anon_sym_instanceof] = ACTIONS(120),
    [anon_sym_PLUS_PLUS] = ACTIONS(154),
    [anon_sym_DASH_DASH] = ACTIONS(154),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(154),
    [anon_sym_static] = ACTIONS(2413),
    [anon_sym_readonly] = ACTIONS(2413),
    [anon_sym_get] = ACTIONS(2413),
    [anon_sym_set] = ACTIONS(2413),
    [anon_sym_declare] = ACTIONS(2413),
    [anon_sym_public] = ACTIONS(2413),
    [anon_sym_private] = ACTIONS(2413),
    [anon_sym_protected] = ACTIONS(2413),
    [anon_sym_override] = ACTIONS(2413),
    [anon_sym_module] = ACTIONS(2413),
    [anon_sym_any] = ACTIONS(2413),
    [anon_sym_number] = ACTIONS(2413),
    [anon_sym_boolean] = ACTIONS(2413),
    [anon_sym_string] = ACTIONS(2413),
    [anon_sym_symbol] = ACTIONS(2413),
    [anon_sym_object] = ACTIONS(2413),
    [anon_sym_satisfies] = ACTIONS(120),
    [sym__ternary_qmark] = ACTIONS(154),
    [sym_html_comment] = ACTIONS(5),
  },
  [774] = {
    [sym__call_signature] = STATE(5834),
    [sym_formal_parameters] = STATE(3806),
    [sym_type_parameters] = STATE(5328),
    [sym_identifier] = ACTIONS(2411),
    [anon_sym_export] = ACTIONS(2413),
    [anon_sym_STAR] = ACTIONS(120),
    [anon_sym_type] = ACTIONS(2413),
    [anon_sym_EQ] = ACTIONS(1036),
    [anon_sym_as] = ACTIONS(120),
    [anon_sym_namespace] = ACTIONS(2413),
    [anon_sym_let] = ACTIONS(2413),
    [anon_sym_BANG] = ACTIONS(120),
    [anon_sym_LPAREN] = ACTIONS(2415),
    [anon_sym_in] = ACTIONS(120),
    [anon_sym_LBRACK] = ACTIONS(154),
    [anon_sym_DOT] = ACTIONS(154),
    [anon_sym_async] = ACTIONS(2413),
    [anon_sym_function] = ACTIONS(2418),
    [anon_sym_EQ_GT] = ACTIONS(225),
    [anon_sym_QMARK_DOT] = ACTIONS(154),
    [anon_sym_new] = ACTIONS(2413),
    [anon_sym_PLUS_EQ] = ACTIONS(160),
    [anon_sym_DASH_EQ] = ACTIONS(160),
    [anon_sym_STAR_EQ] = ACTIONS(160),
    [anon_sym_SLASH_EQ] = ACTIONS(160),
    [anon_sym_PERCENT_EQ] = ACTIONS(160),
    [anon_sym_CARET_EQ] = ACTIONS(160),
    [anon_sym_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_LT_LT_EQ] = ACTIONS(160),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(160),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP] = ACTIONS(120),
    [anon_sym_PIPE_PIPE] = ACTIONS(120),
    [anon_sym_GT_GT] = ACTIONS(120),
    [anon_sym_GT_GT_GT] = ACTIONS(120),
    [anon_sym_LT_LT] = ACTIONS(120),
    [anon_sym_AMP] = ACTIONS(120),
    [anon_sym_CARET] = ACTIONS(120),
    [anon_sym_PIPE] = ACTIONS(120),
    [anon_sym_PLUS] = ACTIONS(120),
    [anon_sym_DASH] = ACTIONS(120),
    [anon_sym_SLASH] = ACTIONS(120),
    [anon_sym_PERCENT] = ACTIONS(120),
    [anon_sym_STAR_STAR] = ACTIONS(120),
    [anon_sym_LT] = ACTIONS(2420),
    [anon_sym_LT_EQ] = ACTIONS(154),
    [anon_sym_EQ_EQ] = ACTIONS(120),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(154),
    [anon_sym_BANG_EQ] = ACTIONS(120),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(154),
    [anon_sym_GT_EQ] = ACTIONS(154),
    [anon_sym_GT] = ACTIONS(120),
    [anon_sym_QMARK_QMARK] = ACTIONS(120),
    [anon_sym_instanceof] = ACTIONS(120),
    [anon_sym_PLUS_PLUS] = ACTIONS(154),
    [anon_sym_DASH_DASH] = ACTIONS(154),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(154),
    [anon_sym_static] = ACTIONS(2413),
    [anon_sym_readonly] = ACTIONS(2413),
    [anon_sym_get] = ACTIONS(2413),
    [anon_sym_set] = ACTIONS(2413),
    [anon_sym_declare] = ACTIONS(2413),
    [anon_sym_public] = ACTIONS(2413),
    [anon_sym_private] = ACTIONS(2413),
    [anon_sym_protected] = ACTIONS(2413),
    [anon_sym_override] = ACTIONS(2413),
    [anon_sym_module] = ACTIONS(2413),
    [anon_sym_any] = ACTIONS(2413),
    [anon_sym_number] = ACTIONS(2413),
    [anon_sym_boolean] = ACTIONS(2413),
    [anon_sym_string] = ACTIONS(2413),
    [anon_sym_symbol] = ACTIONS(2413),
    [anon_sym_object] = ACTIONS(2413),
    [anon_sym_satisfies] = ACTIONS(120),
    [sym__ternary_qmark] = ACTIONS(154),
    [sym_html_comment] = ACTIONS(5),
  },
  [775] = {
    [sym__call_signature] = STATE(5834),
    [sym_formal_parameters] = STATE(3806),
    [sym_type_parameters] = STATE(5328),
    [sym_identifier] = ACTIONS(2411),
    [anon_sym_export] = ACTIONS(2413),
    [anon_sym_STAR] = ACTIONS(120),
    [anon_sym_type] = ACTIONS(2413),
    [anon_sym_EQ] = ACTIONS(1040),
    [anon_sym_as] = ACTIONS(120),
    [anon_sym_namespace] = ACTIONS(2413),
    [anon_sym_let] = ACTIONS(2413),
    [anon_sym_BANG] = ACTIONS(120),
    [anon_sym_LPAREN] = ACTIONS(2415),
    [anon_sym_in] = ACTIONS(120),
    [anon_sym_LBRACK] = ACTIONS(154),
    [anon_sym_DOT] = ACTIONS(154),
    [anon_sym_async] = ACTIONS(2413),
    [anon_sym_function] = ACTIONS(2418),
    [anon_sym_EQ_GT] = ACTIONS(225),
    [anon_sym_QMARK_DOT] = ACTIONS(154),
    [anon_sym_new] = ACTIONS(2413),
    [anon_sym_PLUS_EQ] = ACTIONS(160),
    [anon_sym_DASH_EQ] = ACTIONS(160),
    [anon_sym_STAR_EQ] = ACTIONS(160),
    [anon_sym_SLASH_EQ] = ACTIONS(160),
    [anon_sym_PERCENT_EQ] = ACTIONS(160),
    [anon_sym_CARET_EQ] = ACTIONS(160),
    [anon_sym_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_LT_LT_EQ] = ACTIONS(160),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(160),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP] = ACTIONS(120),
    [anon_sym_PIPE_PIPE] = ACTIONS(120),
    [anon_sym_GT_GT] = ACTIONS(120),
    [anon_sym_GT_GT_GT] = ACTIONS(120),
    [anon_sym_LT_LT] = ACTIONS(120),
    [anon_sym_AMP] = ACTIONS(120),
    [anon_sym_CARET] = ACTIONS(120),
    [anon_sym_PIPE] = ACTIONS(120),
    [anon_sym_PLUS] = ACTIONS(120),
    [anon_sym_DASH] = ACTIONS(120),
    [anon_sym_SLASH] = ACTIONS(120),
    [anon_sym_PERCENT] = ACTIONS(120),
    [anon_sym_STAR_STAR] = ACTIONS(120),
    [anon_sym_LT] = ACTIONS(2420),
    [anon_sym_LT_EQ] = ACTIONS(154),
    [anon_sym_EQ_EQ] = ACTIONS(120),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(154),
    [anon_sym_BANG_EQ] = ACTIONS(120),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(154),
    [anon_sym_GT_EQ] = ACTIONS(154),
    [anon_sym_GT] = ACTIONS(120),
    [anon_sym_QMARK_QMARK] = ACTIONS(120),
    [anon_sym_instanceof] = ACTIONS(120),
    [anon_sym_PLUS_PLUS] = ACTIONS(154),
    [anon_sym_DASH_DASH] = ACTIONS(154),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(154),
    [anon_sym_static] = ACTIONS(2413),
    [anon_sym_readonly] = ACTIONS(2413),
    [anon_sym_get] = ACTIONS(2413),
    [anon_sym_set] = ACTIONS(2413),
    [anon_sym_declare] = ACTIONS(2413),
    [anon_sym_public] = ACTIONS(2413),
    [anon_sym_private] = ACTIONS(2413),
    [anon_sym_protected] = ACTIONS(2413),
    [anon_sym_override] = ACTIONS(2413),
    [anon_sym_module] = ACTIONS(2413),
    [anon_sym_any] = ACTIONS(2413),
    [anon_sym_number] = ACTIONS(2413),
    [anon_sym_boolean] = ACTIONS(2413),
    [anon_sym_string] = ACTIONS(2413),
    [anon_sym_symbol] = ACTIONS(2413),
    [anon_sym_object] = ACTIONS(2413),
    [anon_sym_satisfies] = ACTIONS(120),
    [sym__ternary_qmark] = ACTIONS(154),
    [sym_html_comment] = ACTIONS(5),
  },
  [776] = {
    [sym__call_signature] = STATE(5834),
    [sym_formal_parameters] = STATE(3806),
    [sym_type_parameters] = STATE(5328),
    [sym_identifier] = ACTIONS(2411),
    [anon_sym_export] = ACTIONS(2413),
    [anon_sym_STAR] = ACTIONS(120),
    [anon_sym_type] = ACTIONS(2413),
    [anon_sym_EQ] = ACTIONS(1044),
    [anon_sym_as] = ACTIONS(120),
    [anon_sym_namespace] = ACTIONS(2413),
    [anon_sym_let] = ACTIONS(2413),
    [anon_sym_BANG] = ACTIONS(120),
    [anon_sym_LPAREN] = ACTIONS(2415),
    [anon_sym_in] = ACTIONS(120),
    [anon_sym_LBRACK] = ACTIONS(154),
    [anon_sym_DOT] = ACTIONS(154),
    [anon_sym_async] = ACTIONS(2413),
    [anon_sym_function] = ACTIONS(2418),
    [anon_sym_EQ_GT] = ACTIONS(225),
    [anon_sym_QMARK_DOT] = ACTIONS(154),
    [anon_sym_new] = ACTIONS(2413),
    [anon_sym_PLUS_EQ] = ACTIONS(160),
    [anon_sym_DASH_EQ] = ACTIONS(160),
    [anon_sym_STAR_EQ] = ACTIONS(160),
    [anon_sym_SLASH_EQ] = ACTIONS(160),
    [anon_sym_PERCENT_EQ] = ACTIONS(160),
    [anon_sym_CARET_EQ] = ACTIONS(160),
    [anon_sym_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_LT_LT_EQ] = ACTIONS(160),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(160),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP] = ACTIONS(120),
    [anon_sym_PIPE_PIPE] = ACTIONS(120),
    [anon_sym_GT_GT] = ACTIONS(120),
    [anon_sym_GT_GT_GT] = ACTIONS(120),
    [anon_sym_LT_LT] = ACTIONS(120),
    [anon_sym_AMP] = ACTIONS(120),
    [anon_sym_CARET] = ACTIONS(120),
    [anon_sym_PIPE] = ACTIONS(120),
    [anon_sym_PLUS] = ACTIONS(120),
    [anon_sym_DASH] = ACTIONS(120),
    [anon_sym_SLASH] = ACTIONS(120),
    [anon_sym_PERCENT] = ACTIONS(120),
    [anon_sym_STAR_STAR] = ACTIONS(120),
    [anon_sym_LT] = ACTIONS(2420),
    [anon_sym_LT_EQ] = ACTIONS(154),
    [anon_sym_EQ_EQ] = ACTIONS(120),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(154),
    [anon_sym_BANG_EQ] = ACTIONS(120),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(154),
    [anon_sym_GT_EQ] = ACTIONS(154),
    [anon_sym_GT] = ACTIONS(120),
    [anon_sym_QMARK_QMARK] = ACTIONS(120),
    [anon_sym_instanceof] = ACTIONS(120),
    [anon_sym_PLUS_PLUS] = ACTIONS(154),
    [anon_sym_DASH_DASH] = ACTIONS(154),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(154),
    [anon_sym_static] = ACTIONS(2413),
    [anon_sym_readonly] = ACTIONS(2413),
    [anon_sym_get] = ACTIONS(2413),
    [anon_sym_set] = ACTIONS(2413),
    [anon_sym_declare] = ACTIONS(2413),
    [anon_sym_public] = ACTIONS(2413),
    [anon_sym_private] = ACTIONS(2413),
    [anon_sym_protected] = ACTIONS(2413),
    [anon_sym_override] = ACTIONS(2413),
    [anon_sym_module] = ACTIONS(2413),
    [anon_sym_any] = ACTIONS(2413),
    [anon_sym_number] = ACTIONS(2413),
    [anon_sym_boolean] = ACTIONS(2413),
    [anon_sym_string] = ACTIONS(2413),
    [anon_sym_symbol] = ACTIONS(2413),
    [anon_sym_object] = ACTIONS(2413),
    [anon_sym_satisfies] = ACTIONS(120),
    [sym__ternary_qmark] = ACTIONS(154),
    [sym_html_comment] = ACTIONS(5),
  },
  [777] = {
    [sym__call_signature] = STATE(5834),
    [sym_formal_parameters] = STATE(3806),
    [sym_type_parameters] = STATE(5328),
    [sym_identifier] = ACTIONS(2411),
    [anon_sym_export] = ACTIONS(2413),
    [anon_sym_STAR] = ACTIONS(120),
    [anon_sym_type] = ACTIONS(2413),
    [anon_sym_EQ] = ACTIONS(824),
    [anon_sym_as] = ACTIONS(120),
    [anon_sym_namespace] = ACTIONS(2413),
    [anon_sym_let] = ACTIONS(2413),
    [anon_sym_BANG] = ACTIONS(120),
    [anon_sym_LPAREN] = ACTIONS(2415),
    [anon_sym_in] = ACTIONS(120),
    [anon_sym_LBRACK] = ACTIONS(154),
    [anon_sym_DOT] = ACTIONS(154),
    [anon_sym_async] = ACTIONS(2413),
    [anon_sym_function] = ACTIONS(2418),
    [anon_sym_EQ_GT] = ACTIONS(225),
    [anon_sym_QMARK_DOT] = ACTIONS(154),
    [anon_sym_new] = ACTIONS(2413),
    [anon_sym_PLUS_EQ] = ACTIONS(160),
    [anon_sym_DASH_EQ] = ACTIONS(160),
    [anon_sym_STAR_EQ] = ACTIONS(160),
    [anon_sym_SLASH_EQ] = ACTIONS(160),
    [anon_sym_PERCENT_EQ] = ACTIONS(160),
    [anon_sym_CARET_EQ] = ACTIONS(160),
    [anon_sym_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_LT_LT_EQ] = ACTIONS(160),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(160),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP] = ACTIONS(120),
    [anon_sym_PIPE_PIPE] = ACTIONS(120),
    [anon_sym_GT_GT] = ACTIONS(120),
    [anon_sym_GT_GT_GT] = ACTIONS(120),
    [anon_sym_LT_LT] = ACTIONS(120),
    [anon_sym_AMP] = ACTIONS(120),
    [anon_sym_CARET] = ACTIONS(120),
    [anon_sym_PIPE] = ACTIONS(120),
    [anon_sym_PLUS] = ACTIONS(120),
    [anon_sym_DASH] = ACTIONS(120),
    [anon_sym_SLASH] = ACTIONS(120),
    [anon_sym_PERCENT] = ACTIONS(120),
    [anon_sym_STAR_STAR] = ACTIONS(120),
    [anon_sym_LT] = ACTIONS(2420),
    [anon_sym_LT_EQ] = ACTIONS(154),
    [anon_sym_EQ_EQ] = ACTIONS(120),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(154),
    [anon_sym_BANG_EQ] = ACTIONS(120),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(154),
    [anon_sym_GT_EQ] = ACTIONS(154),
    [anon_sym_GT] = ACTIONS(120),
    [anon_sym_QMARK_QMARK] = ACTIONS(120),
    [anon_sym_instanceof] = ACTIONS(120),
    [anon_sym_PLUS_PLUS] = ACTIONS(154),
    [anon_sym_DASH_DASH] = ACTIONS(154),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(154),
    [anon_sym_static] = ACTIONS(2413),
    [anon_sym_readonly] = ACTIONS(2413),
    [anon_sym_get] = ACTIONS(2413),
    [anon_sym_set] = ACTIONS(2413),
    [anon_sym_declare] = ACTIONS(2413),
    [anon_sym_public] = ACTIONS(2413),
    [anon_sym_private] = ACTIONS(2413),
    [anon_sym_protected] = ACTIONS(2413),
    [anon_sym_override] = ACTIONS(2413),
    [anon_sym_module] = ACTIONS(2413),
    [anon_sym_any] = ACTIONS(2413),
    [anon_sym_number] = ACTIONS(2413),
    [anon_sym_boolean] = ACTIONS(2413),
    [anon_sym_string] = ACTIONS(2413),
    [anon_sym_symbol] = ACTIONS(2413),
    [anon_sym_object] = ACTIONS(2413),
    [anon_sym_satisfies] = ACTIONS(120),
    [sym__ternary_qmark] = ACTIONS(154),
    [sym_html_comment] = ACTIONS(5),
  },
  [778] = {
    [sym__call_signature] = STATE(5834),
    [sym_formal_parameters] = STATE(3806),
    [sym_type_parameters] = STATE(5328),
    [sym_identifier] = ACTIONS(2411),
    [anon_sym_export] = ACTIONS(2413),
    [anon_sym_STAR] = ACTIONS(120),
    [anon_sym_type] = ACTIONS(2413),
    [anon_sym_EQ] = ACTIONS(1038),
    [anon_sym_as] = ACTIONS(120),
    [anon_sym_namespace] = ACTIONS(2413),
    [anon_sym_let] = ACTIONS(2413),
    [anon_sym_BANG] = ACTIONS(120),
    [anon_sym_LPAREN] = ACTIONS(2415),
    [anon_sym_in] = ACTIONS(120),
    [anon_sym_LBRACK] = ACTIONS(154),
    [anon_sym_DOT] = ACTIONS(154),
    [anon_sym_async] = ACTIONS(2413),
    [anon_sym_function] = ACTIONS(2418),
    [anon_sym_EQ_GT] = ACTIONS(225),
    [anon_sym_QMARK_DOT] = ACTIONS(154),
    [anon_sym_new] = ACTIONS(2413),
    [anon_sym_PLUS_EQ] = ACTIONS(160),
    [anon_sym_DASH_EQ] = ACTIONS(160),
    [anon_sym_STAR_EQ] = ACTIONS(160),
    [anon_sym_SLASH_EQ] = ACTIONS(160),
    [anon_sym_PERCENT_EQ] = ACTIONS(160),
    [anon_sym_CARET_EQ] = ACTIONS(160),
    [anon_sym_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_LT_LT_EQ] = ACTIONS(160),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(160),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP] = ACTIONS(120),
    [anon_sym_PIPE_PIPE] = ACTIONS(120),
    [anon_sym_GT_GT] = ACTIONS(120),
    [anon_sym_GT_GT_GT] = ACTIONS(120),
    [anon_sym_LT_LT] = ACTIONS(120),
    [anon_sym_AMP] = ACTIONS(120),
    [anon_sym_CARET] = ACTIONS(120),
    [anon_sym_PIPE] = ACTIONS(120),
    [anon_sym_PLUS] = ACTIONS(120),
    [anon_sym_DASH] = ACTIONS(120),
    [anon_sym_SLASH] = ACTIONS(120),
    [anon_sym_PERCENT] = ACTIONS(120),
    [anon_sym_STAR_STAR] = ACTIONS(120),
    [anon_sym_LT] = ACTIONS(2420),
    [anon_sym_LT_EQ] = ACTIONS(154),
    [anon_sym_EQ_EQ] = ACTIONS(120),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(154),
    [anon_sym_BANG_EQ] = ACTIONS(120),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(154),
    [anon_sym_GT_EQ] = ACTIONS(154),
    [anon_sym_GT] = ACTIONS(120),
    [anon_sym_QMARK_QMARK] = ACTIONS(120),
    [anon_sym_instanceof] = ACTIONS(120),
    [anon_sym_PLUS_PLUS] = ACTIONS(154),
    [anon_sym_DASH_DASH] = ACTIONS(154),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(154),
    [anon_sym_static] = ACTIONS(2413),
    [anon_sym_readonly] = ACTIONS(2413),
    [anon_sym_get] = ACTIONS(2413),
    [anon_sym_set] = ACTIONS(2413),
    [anon_sym_declare] = ACTIONS(2413),
    [anon_sym_public] = ACTIONS(2413),
    [anon_sym_private] = ACTIONS(2413),
    [anon_sym_protected] = ACTIONS(2413),
    [anon_sym_override] = ACTIONS(2413),
    [anon_sym_module] = ACTIONS(2413),
    [anon_sym_any] = ACTIONS(2413),
    [anon_sym_number] = ACTIONS(2413),
    [anon_sym_boolean] = ACTIONS(2413),
    [anon_sym_string] = ACTIONS(2413),
    [anon_sym_symbol] = ACTIONS(2413),
    [anon_sym_object] = ACTIONS(2413),
    [anon_sym_satisfies] = ACTIONS(120),
    [sym__ternary_qmark] = ACTIONS(154),
    [sym_html_comment] = ACTIONS(5),
  },
  [779] = {
    [sym__call_signature] = STATE(5834),
    [sym_formal_parameters] = STATE(3806),
    [sym_type_parameters] = STATE(5328),
    [sym_identifier] = ACTIONS(2411),
    [anon_sym_export] = ACTIONS(2413),
    [anon_sym_STAR] = ACTIONS(120),
    [anon_sym_type] = ACTIONS(2413),
    [anon_sym_EQ] = ACTIONS(982),
    [anon_sym_as] = ACTIONS(120),
    [anon_sym_namespace] = ACTIONS(2413),
    [anon_sym_let] = ACTIONS(2413),
    [anon_sym_BANG] = ACTIONS(120),
    [anon_sym_LPAREN] = ACTIONS(2415),
    [anon_sym_in] = ACTIONS(120),
    [anon_sym_LBRACK] = ACTIONS(154),
    [anon_sym_DOT] = ACTIONS(154),
    [anon_sym_async] = ACTIONS(2413),
    [anon_sym_function] = ACTIONS(2418),
    [anon_sym_EQ_GT] = ACTIONS(225),
    [anon_sym_QMARK_DOT] = ACTIONS(154),
    [anon_sym_new] = ACTIONS(2413),
    [anon_sym_PLUS_EQ] = ACTIONS(160),
    [anon_sym_DASH_EQ] = ACTIONS(160),
    [anon_sym_STAR_EQ] = ACTIONS(160),
    [anon_sym_SLASH_EQ] = ACTIONS(160),
    [anon_sym_PERCENT_EQ] = ACTIONS(160),
    [anon_sym_CARET_EQ] = ACTIONS(160),
    [anon_sym_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_LT_LT_EQ] = ACTIONS(160),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(160),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP] = ACTIONS(120),
    [anon_sym_PIPE_PIPE] = ACTIONS(120),
    [anon_sym_GT_GT] = ACTIONS(120),
    [anon_sym_GT_GT_GT] = ACTIONS(120),
    [anon_sym_LT_LT] = ACTIONS(120),
    [anon_sym_AMP] = ACTIONS(120),
    [anon_sym_CARET] = ACTIONS(120),
    [anon_sym_PIPE] = ACTIONS(120),
    [anon_sym_PLUS] = ACTIONS(120),
    [anon_sym_DASH] = ACTIONS(120),
    [anon_sym_SLASH] = ACTIONS(120),
    [anon_sym_PERCENT] = ACTIONS(120),
    [anon_sym_STAR_STAR] = ACTIONS(120),
    [anon_sym_LT] = ACTIONS(2420),
    [anon_sym_LT_EQ] = ACTIONS(154),
    [anon_sym_EQ_EQ] = ACTIONS(120),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(154),
    [anon_sym_BANG_EQ] = ACTIONS(120),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(154),
    [anon_sym_GT_EQ] = ACTIONS(154),
    [anon_sym_GT] = ACTIONS(120),
    [anon_sym_QMARK_QMARK] = ACTIONS(120),
    [anon_sym_instanceof] = ACTIONS(120),
    [anon_sym_PLUS_PLUS] = ACTIONS(154),
    [anon_sym_DASH_DASH] = ACTIONS(154),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(154),
    [anon_sym_static] = ACTIONS(2413),
    [anon_sym_readonly] = ACTIONS(2413),
    [anon_sym_get] = ACTIONS(2413),
    [anon_sym_set] = ACTIONS(2413),
    [anon_sym_declare] = ACTIONS(2413),
    [anon_sym_public] = ACTIONS(2413),
    [anon_sym_private] = ACTIONS(2413),
    [anon_sym_protected] = ACTIONS(2413),
    [anon_sym_override] = ACTIONS(2413),
    [anon_sym_module] = ACTIONS(2413),
    [anon_sym_any] = ACTIONS(2413),
    [anon_sym_number] = ACTIONS(2413),
    [anon_sym_boolean] = ACTIONS(2413),
    [anon_sym_string] = ACTIONS(2413),
    [anon_sym_symbol] = ACTIONS(2413),
    [anon_sym_object] = ACTIONS(2413),
    [anon_sym_satisfies] = ACTIONS(120),
    [sym__ternary_qmark] = ACTIONS(154),
    [sym_html_comment] = ACTIONS(5),
  },
  [780] = {
    [sym_statement_block] = STATE(882),
    [ts_builtin_sym_end] = ACTIONS(1674),
    [sym_identifier] = ACTIONS(1676),
    [anon_sym_export] = ACTIONS(1676),
    [anon_sym_default] = ACTIONS(1676),
    [anon_sym_type] = ACTIONS(1676),
    [anon_sym_namespace] = ACTIONS(1676),
    [anon_sym_LBRACE] = ACTIONS(2483),
    [anon_sym_RBRACE] = ACTIONS(1674),
    [anon_sym_typeof] = ACTIONS(1676),
    [anon_sym_import] = ACTIONS(1676),
    [anon_sym_with] = ACTIONS(1676),
    [anon_sym_var] = ACTIONS(1676),
    [anon_sym_let] = ACTIONS(1676),
    [anon_sym_const] = ACTIONS(1676),
    [anon_sym_BANG] = ACTIONS(1674),
    [anon_sym_else] = ACTIONS(1676),
    [anon_sym_if] = ACTIONS(1676),
    [anon_sym_switch] = ACTIONS(1676),
    [anon_sym_for] = ACTIONS(1676),
    [anon_sym_LPAREN] = ACTIONS(1674),
    [anon_sym_SEMI] = ACTIONS(1674),
    [anon_sym_await] = ACTIONS(1676),
    [anon_sym_while] = ACTIONS(1676),
    [anon_sym_do] = ACTIONS(1676),
    [anon_sym_try] = ACTIONS(1676),
    [anon_sym_break] = ACTIONS(1676),
    [anon_sym_continue] = ACTIONS(1676),
    [anon_sym_debugger] = ACTIONS(1676),
    [anon_sym_return] = ACTIONS(1676),
    [anon_sym_throw] = ACTIONS(1676),
    [anon_sym_case] = ACTIONS(1676),
    [anon_sym_yield] = ACTIONS(1676),
    [anon_sym_LBRACK] = ACTIONS(1674),
    [anon_sym_DOT] = ACTIONS(2485),
    [anon_sym_class] = ACTIONS(1676),
    [anon_sym_async] = ACTIONS(1676),
    [anon_sym_function] = ACTIONS(1676),
    [anon_sym_new] = ACTIONS(1676),
    [anon_sym_using] = ACTIONS(1676),
    [anon_sym_PLUS] = ACTIONS(1676),
    [anon_sym_DASH] = ACTIONS(1676),
    [anon_sym_SLASH] = ACTIONS(1676),
    [anon_sym_LT] = ACTIONS(1674),
    [anon_sym_TILDE] = ACTIONS(1674),
    [anon_sym_void] = ACTIONS(1676),
    [anon_sym_delete] = ACTIONS(1676),
    [anon_sym_PLUS_PLUS] = ACTIONS(1674),
    [anon_sym_DASH_DASH] = ACTIONS(1674),
    [anon_sym_DQUOTE] = ACTIONS(1674),
    [anon_sym_SQUOTE] = ACTIONS(1674),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1674),
    [sym_number] = ACTIONS(1674),
    [sym_private_property_identifier] = ACTIONS(1674),
    [sym_this] = ACTIONS(1676),
    [sym_super] = ACTIONS(1676),
    [sym_true] = ACTIONS(1676),
    [sym_false] = ACTIONS(1676),
    [sym_null] = ACTIONS(1676),
    [sym_undefined] = ACTIONS(1676),
    [anon_sym_AT] = ACTIONS(1674),
    [anon_sym_static] = ACTIONS(1676),
    [anon_sym_readonly] = ACTIONS(1676),
    [anon_sym_get] = ACTIONS(1676),
    [anon_sym_set] = ACTIONS(1676),
    [anon_sym_declare] = ACTIONS(1676),
    [anon_sym_public] = ACTIONS(1676),
    [anon_sym_private] = ACTIONS(1676),
    [anon_sym_protected] = ACTIONS(1676),
    [anon_sym_override] = ACTIONS(1676),
    [anon_sym_module] = ACTIONS(1676),
    [anon_sym_any] = ACTIONS(1676),
    [anon_sym_number] = ACTIONS(1676),
    [anon_sym_boolean] = ACTIONS(1676),
    [anon_sym_string] = ACTIONS(1676),
    [anon_sym_symbol] = ACTIONS(1676),
    [anon_sym_object] = ACTIONS(1676),
    [anon_sym_abstract] = ACTIONS(1676),
    [anon_sym_interface] = ACTIONS(1676),
    [anon_sym_enum] = ACTIONS(1676),
    [sym_html_comment] = ACTIONS(5),
  },
  [781] = {
    [sym__call_signature] = STATE(5834),
    [sym_formal_parameters] = STATE(3806),
    [sym_type_parameters] = STATE(5328),
    [sym_identifier] = ACTIONS(2411),
    [anon_sym_export] = ACTIONS(2413),
    [anon_sym_STAR] = ACTIONS(120),
    [anon_sym_type] = ACTIONS(2413),
    [anon_sym_EQ] = ACTIONS(1042),
    [anon_sym_as] = ACTIONS(120),
    [anon_sym_namespace] = ACTIONS(2413),
    [anon_sym_let] = ACTIONS(2413),
    [anon_sym_BANG] = ACTIONS(120),
    [anon_sym_LPAREN] = ACTIONS(2415),
    [anon_sym_in] = ACTIONS(120),
    [anon_sym_LBRACK] = ACTIONS(154),
    [anon_sym_DOT] = ACTIONS(154),
    [anon_sym_async] = ACTIONS(2413),
    [anon_sym_function] = ACTIONS(2418),
    [anon_sym_EQ_GT] = ACTIONS(225),
    [anon_sym_QMARK_DOT] = ACTIONS(154),
    [anon_sym_new] = ACTIONS(2413),
    [anon_sym_PLUS_EQ] = ACTIONS(160),
    [anon_sym_DASH_EQ] = ACTIONS(160),
    [anon_sym_STAR_EQ] = ACTIONS(160),
    [anon_sym_SLASH_EQ] = ACTIONS(160),
    [anon_sym_PERCENT_EQ] = ACTIONS(160),
    [anon_sym_CARET_EQ] = ACTIONS(160),
    [anon_sym_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_LT_LT_EQ] = ACTIONS(160),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(160),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP] = ACTIONS(120),
    [anon_sym_PIPE_PIPE] = ACTIONS(120),
    [anon_sym_GT_GT] = ACTIONS(120),
    [anon_sym_GT_GT_GT] = ACTIONS(120),
    [anon_sym_LT_LT] = ACTIONS(120),
    [anon_sym_AMP] = ACTIONS(120),
    [anon_sym_CARET] = ACTIONS(120),
    [anon_sym_PIPE] = ACTIONS(120),
    [anon_sym_PLUS] = ACTIONS(120),
    [anon_sym_DASH] = ACTIONS(120),
    [anon_sym_SLASH] = ACTIONS(120),
    [anon_sym_PERCENT] = ACTIONS(120),
    [anon_sym_STAR_STAR] = ACTIONS(120),
    [anon_sym_LT] = ACTIONS(2420),
    [anon_sym_LT_EQ] = ACTIONS(154),
    [anon_sym_EQ_EQ] = ACTIONS(120),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(154),
    [anon_sym_BANG_EQ] = ACTIONS(120),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(154),
    [anon_sym_GT_EQ] = ACTIONS(154),
    [anon_sym_GT] = ACTIONS(120),
    [anon_sym_QMARK_QMARK] = ACTIONS(120),
    [anon_sym_instanceof] = ACTIONS(120),
    [anon_sym_PLUS_PLUS] = ACTIONS(154),
    [anon_sym_DASH_DASH] = ACTIONS(154),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(154),
    [anon_sym_static] = ACTIONS(2413),
    [anon_sym_readonly] = ACTIONS(2413),
    [anon_sym_get] = ACTIONS(2413),
    [anon_sym_set] = ACTIONS(2413),
    [anon_sym_declare] = ACTIONS(2413),
    [anon_sym_public] = ACTIONS(2413),
    [anon_sym_private] = ACTIONS(2413),
    [anon_sym_protected] = ACTIONS(2413),
    [anon_sym_override] = ACTIONS(2413),
    [anon_sym_module] = ACTIONS(2413),
    [anon_sym_any] = ACTIONS(2413),
    [anon_sym_number] = ACTIONS(2413),
    [anon_sym_boolean] = ACTIONS(2413),
    [anon_sym_string] = ACTIONS(2413),
    [anon_sym_symbol] = ACTIONS(2413),
    [anon_sym_object] = ACTIONS(2413),
    [anon_sym_satisfies] = ACTIONS(120),
    [sym__ternary_qmark] = ACTIONS(154),
    [sym_html_comment] = ACTIONS(5),
  },
  [782] = {
    [sym__call_signature] = STATE(5834),
    [sym_formal_parameters] = STATE(3806),
    [sym_type_parameters] = STATE(5328),
    [sym_identifier] = ACTIONS(2411),
    [anon_sym_export] = ACTIONS(2413),
    [anon_sym_STAR] = ACTIONS(120),
    [anon_sym_type] = ACTIONS(2413),
    [anon_sym_EQ] = ACTIONS(976),
    [anon_sym_as] = ACTIONS(120),
    [anon_sym_namespace] = ACTIONS(2413),
    [anon_sym_let] = ACTIONS(2413),
    [anon_sym_BANG] = ACTIONS(120),
    [anon_sym_LPAREN] = ACTIONS(2415),
    [anon_sym_in] = ACTIONS(120),
    [anon_sym_LBRACK] = ACTIONS(154),
    [anon_sym_DOT] = ACTIONS(154),
    [anon_sym_async] = ACTIONS(2413),
    [anon_sym_function] = ACTIONS(2418),
    [anon_sym_EQ_GT] = ACTIONS(225),
    [anon_sym_QMARK_DOT] = ACTIONS(154),
    [anon_sym_new] = ACTIONS(2413),
    [anon_sym_PLUS_EQ] = ACTIONS(160),
    [anon_sym_DASH_EQ] = ACTIONS(160),
    [anon_sym_STAR_EQ] = ACTIONS(160),
    [anon_sym_SLASH_EQ] = ACTIONS(160),
    [anon_sym_PERCENT_EQ] = ACTIONS(160),
    [anon_sym_CARET_EQ] = ACTIONS(160),
    [anon_sym_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_LT_LT_EQ] = ACTIONS(160),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(160),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP] = ACTIONS(120),
    [anon_sym_PIPE_PIPE] = ACTIONS(120),
    [anon_sym_GT_GT] = ACTIONS(120),
    [anon_sym_GT_GT_GT] = ACTIONS(120),
    [anon_sym_LT_LT] = ACTIONS(120),
    [anon_sym_AMP] = ACTIONS(120),
    [anon_sym_CARET] = ACTIONS(120),
    [anon_sym_PIPE] = ACTIONS(120),
    [anon_sym_PLUS] = ACTIONS(120),
    [anon_sym_DASH] = ACTIONS(120),
    [anon_sym_SLASH] = ACTIONS(120),
    [anon_sym_PERCENT] = ACTIONS(120),
    [anon_sym_STAR_STAR] = ACTIONS(120),
    [anon_sym_LT] = ACTIONS(2420),
    [anon_sym_LT_EQ] = ACTIONS(154),
    [anon_sym_EQ_EQ] = ACTIONS(120),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(154),
    [anon_sym_BANG_EQ] = ACTIONS(120),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(154),
    [anon_sym_GT_EQ] = ACTIONS(154),
    [anon_sym_GT] = ACTIONS(120),
    [anon_sym_QMARK_QMARK] = ACTIONS(120),
    [anon_sym_instanceof] = ACTIONS(120),
    [anon_sym_PLUS_PLUS] = ACTIONS(154),
    [anon_sym_DASH_DASH] = ACTIONS(154),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(154),
    [anon_sym_static] = ACTIONS(2413),
    [anon_sym_readonly] = ACTIONS(2413),
    [anon_sym_get] = ACTIONS(2413),
    [anon_sym_set] = ACTIONS(2413),
    [anon_sym_declare] = ACTIONS(2413),
    [anon_sym_public] = ACTIONS(2413),
    [anon_sym_private] = ACTIONS(2413),
    [anon_sym_protected] = ACTIONS(2413),
    [anon_sym_override] = ACTIONS(2413),
    [anon_sym_module] = ACTIONS(2413),
    [anon_sym_any] = ACTIONS(2413),
    [anon_sym_number] = ACTIONS(2413),
    [anon_sym_boolean] = ACTIONS(2413),
    [anon_sym_string] = ACTIONS(2413),
    [anon_sym_symbol] = ACTIONS(2413),
    [anon_sym_object] = ACTIONS(2413),
    [anon_sym_satisfies] = ACTIONS(120),
    [sym__ternary_qmark] = ACTIONS(154),
    [sym_html_comment] = ACTIONS(5),
  },
  [783] = {
    [sym_statement_block] = STATE(882),
    [ts_builtin_sym_end] = ACTIONS(1674),
    [sym_identifier] = ACTIONS(1676),
    [anon_sym_export] = ACTIONS(1676),
    [anon_sym_default] = ACTIONS(1676),
    [anon_sym_type] = ACTIONS(1676),
    [anon_sym_namespace] = ACTIONS(1676),
    [anon_sym_LBRACE] = ACTIONS(2483),
    [anon_sym_RBRACE] = ACTIONS(1674),
    [anon_sym_typeof] = ACTIONS(1676),
    [anon_sym_import] = ACTIONS(1676),
    [anon_sym_with] = ACTIONS(1676),
    [anon_sym_var] = ACTIONS(1676),
    [anon_sym_let] = ACTIONS(1676),
    [anon_sym_const] = ACTIONS(1676),
    [anon_sym_BANG] = ACTIONS(1674),
    [anon_sym_else] = ACTIONS(1676),
    [anon_sym_if] = ACTIONS(1676),
    [anon_sym_switch] = ACTIONS(1676),
    [anon_sym_for] = ACTIONS(1676),
    [anon_sym_LPAREN] = ACTIONS(1674),
    [anon_sym_SEMI] = ACTIONS(1674),
    [anon_sym_await] = ACTIONS(1676),
    [anon_sym_while] = ACTIONS(1676),
    [anon_sym_do] = ACTIONS(1676),
    [anon_sym_try] = ACTIONS(1676),
    [anon_sym_break] = ACTIONS(1676),
    [anon_sym_continue] = ACTIONS(1676),
    [anon_sym_debugger] = ACTIONS(1676),
    [anon_sym_return] = ACTIONS(1676),
    [anon_sym_throw] = ACTIONS(1676),
    [anon_sym_case] = ACTIONS(1676),
    [anon_sym_yield] = ACTIONS(1676),
    [anon_sym_LBRACK] = ACTIONS(1674),
    [anon_sym_DOT] = ACTIONS(2487),
    [anon_sym_class] = ACTIONS(1676),
    [anon_sym_async] = ACTIONS(1676),
    [anon_sym_function] = ACTIONS(1676),
    [anon_sym_new] = ACTIONS(1676),
    [anon_sym_using] = ACTIONS(1676),
    [anon_sym_PLUS] = ACTIONS(1676),
    [anon_sym_DASH] = ACTIONS(1676),
    [anon_sym_SLASH] = ACTIONS(1676),
    [anon_sym_LT] = ACTIONS(1674),
    [anon_sym_TILDE] = ACTIONS(1674),
    [anon_sym_void] = ACTIONS(1676),
    [anon_sym_delete] = ACTIONS(1676),
    [anon_sym_PLUS_PLUS] = ACTIONS(1674),
    [anon_sym_DASH_DASH] = ACTIONS(1674),
    [anon_sym_DQUOTE] = ACTIONS(1674),
    [anon_sym_SQUOTE] = ACTIONS(1674),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1674),
    [sym_number] = ACTIONS(1674),
    [sym_private_property_identifier] = ACTIONS(1674),
    [sym_this] = ACTIONS(1676),
    [sym_super] = ACTIONS(1676),
    [sym_true] = ACTIONS(1676),
    [sym_false] = ACTIONS(1676),
    [sym_null] = ACTIONS(1676),
    [sym_undefined] = ACTIONS(1676),
    [anon_sym_AT] = ACTIONS(1674),
    [anon_sym_static] = ACTIONS(1676),
    [anon_sym_readonly] = ACTIONS(1676),
    [anon_sym_get] = ACTIONS(1676),
    [anon_sym_set] = ACTIONS(1676),
    [anon_sym_declare] = ACTIONS(1676),
    [anon_sym_public] = ACTIONS(1676),
    [anon_sym_private] = ACTIONS(1676),
    [anon_sym_protected] = ACTIONS(1676),
    [anon_sym_override] = ACTIONS(1676),
    [anon_sym_module] = ACTIONS(1676),
    [anon_sym_any] = ACTIONS(1676),
    [anon_sym_number] = ACTIONS(1676),
    [anon_sym_boolean] = ACTIONS(1676),
    [anon_sym_string] = ACTIONS(1676),
    [anon_sym_symbol] = ACTIONS(1676),
    [anon_sym_object] = ACTIONS(1676),
    [anon_sym_abstract] = ACTIONS(1676),
    [anon_sym_interface] = ACTIONS(1676),
    [anon_sym_enum] = ACTIONS(1676),
    [sym_html_comment] = ACTIONS(5),
  },
  [784] = {
    [sym_import] = STATE(4681),
    [sym_nested_identifier] = STATE(5474),
    [sym_string] = STATE(2994),
    [sym_formal_parameters] = STATE(5619),
    [sym_rest_pattern] = STATE(5165),
    [sym_nested_type_identifier] = STATE(2939),
    [sym__type_query_member_expression_in_type_annotation] = STATE(3303),
    [sym__type_query_call_expression_in_type_annotation] = STATE(2938),
    [sym_type] = STATE(3773),
    [sym_tuple_parameter] = STATE(4999),
    [sym_optional_tuple_parameter] = STATE(4999),
    [sym_optional_type] = STATE(4999),
    [sym_rest_type] = STATE(4999),
    [sym__tuple_type_member] = STATE(4999),
    [sym_constructor_type] = STATE(3007),
    [sym_primary_type] = STATE(2981),
    [sym_template_literal_type] = STATE(3039),
    [sym_infer_type] = STATE(3007),
    [sym_conditional_type] = STATE(3039),
    [sym_generic_type] = STATE(3039),
    [sym_type_query] = STATE(3039),
    [sym_index_type_query] = STATE(3039),
    [sym_lookup_type] = STATE(3039),
    [sym_literal_type] = STATE(3039),
    [sym__number] = STATE(3041),
    [sym_existential_type] = STATE(3039),
    [sym_flow_maybe_type] = STATE(3039),
    [sym_parenthesized_type] = STATE(3039),
    [sym_predefined_type] = STATE(3039),
    [sym_object_type] = STATE(3039),
    [sym_type_parameters] = STATE(5454),
    [sym_array_type] = STATE(3039),
    [sym_tuple_type] = STATE(3039),
    [sym_readonly_type] = STATE(3007),
    [sym_union_type] = STATE(3039),
    [sym_intersection_type] = STATE(3039),
    [sym_function_type] = STATE(3007),
    [sym_identifier] = ACTIONS(2489),
    [anon_sym_STAR] = ACTIONS(543),
    [anon_sym_LBRACE] = ACTIONS(1534),
    [anon_sym_COMMA] = ACTIONS(2491),
    [anon_sym_typeof] = ACTIONS(1536),
    [anon_sym_import] = ACTIONS(1538),
    [anon_sym_const] = ACTIONS(133),
    [anon_sym_LPAREN] = ACTIONS(1540),
    [anon_sym_LBRACK] = ACTIONS(1542),
    [anon_sym_RBRACK] = ACTIONS(2493),
    [anon_sym_new] = ACTIONS(1642),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(2495),
    [anon_sym_AMP] = ACTIONS(571),
    [anon_sym_PIPE] = ACTIONS(573),
    [anon_sym_PLUS] = ACTIONS(2497),
    [anon_sym_DASH] = ACTIONS(2497),
    [anon_sym_LT] = ACTIONS(2499),
    [anon_sym_void] = ACTIONS(216),
    [anon_sym_DQUOTE] = ACTIONS(1550),
    [anon_sym_SQUOTE] = ACTIONS(1552),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1554),
    [sym_number] = ACTIONS(1556),
    [sym_this] = ACTIONS(1558),
    [sym_true] = ACTIONS(1560),
    [sym_false] = ACTIONS(1560),
    [sym_null] = ACTIONS(1560),
    [sym_undefined] = ACTIONS(1560),
    [anon_sym_readonly] = ACTIONS(1648),
    [anon_sym_QMARK] = ACTIONS(593),
    [anon_sym_any] = ACTIONS(216),
    [anon_sym_number] = ACTIONS(216),
    [anon_sym_boolean] = ACTIONS(216),
    [anon_sym_string] = ACTIONS(216),
    [anon_sym_symbol] = ACTIONS(216),
    [anon_sym_object] = ACTIONS(216),
    [anon_sym_abstract] = ACTIONS(597),
    [anon_sym_infer] = ACTIONS(599),
    [anon_sym_keyof] = ACTIONS(601),
    [anon_sym_unique] = ACTIONS(214),
    [anon_sym_unknown] = ACTIONS(216),
    [anon_sym_never] = ACTIONS(216),
    [anon_sym_LBRACE_PIPE] = ACTIONS(218),
    [sym_html_comment] = ACTIONS(5),
  },
  [785] = {
    [ts_builtin_sym_end] = ACTIONS(2501),
    [sym_identifier] = ACTIONS(2503),
    [anon_sym_export] = ACTIONS(2503),
    [anon_sym_default] = ACTIONS(2503),
    [anon_sym_type] = ACTIONS(2503),
    [anon_sym_namespace] = ACTIONS(2503),
    [anon_sym_LBRACE] = ACTIONS(2501),
    [anon_sym_RBRACE] = ACTIONS(2501),
    [anon_sym_typeof] = ACTIONS(2503),
    [anon_sym_import] = ACTIONS(2503),
    [anon_sym_with] = ACTIONS(2503),
    [anon_sym_var] = ACTIONS(2503),
    [anon_sym_let] = ACTIONS(2503),
    [anon_sym_const] = ACTIONS(2503),
    [anon_sym_BANG] = ACTIONS(2501),
    [anon_sym_else] = ACTIONS(2503),
    [anon_sym_if] = ACTIONS(2503),
    [anon_sym_switch] = ACTIONS(2503),
    [anon_sym_for] = ACTIONS(2503),
    [anon_sym_LPAREN] = ACTIONS(2501),
    [anon_sym_SEMI] = ACTIONS(2505),
    [anon_sym_await] = ACTIONS(2503),
    [anon_sym_while] = ACTIONS(2503),
    [anon_sym_do] = ACTIONS(2503),
    [anon_sym_try] = ACTIONS(2503),
    [anon_sym_break] = ACTIONS(2503),
    [anon_sym_continue] = ACTIONS(2503),
    [anon_sym_debugger] = ACTIONS(2503),
    [anon_sym_return] = ACTIONS(2503),
    [anon_sym_throw] = ACTIONS(2503),
    [anon_sym_case] = ACTIONS(2503),
    [anon_sym_yield] = ACTIONS(2503),
    [anon_sym_LBRACK] = ACTIONS(2501),
    [anon_sym_class] = ACTIONS(2503),
    [anon_sym_async] = ACTIONS(2503),
    [anon_sym_function] = ACTIONS(2503),
    [anon_sym_new] = ACTIONS(2503),
    [anon_sym_using] = ACTIONS(2503),
    [anon_sym_PLUS] = ACTIONS(2503),
    [anon_sym_DASH] = ACTIONS(2503),
    [anon_sym_SLASH] = ACTIONS(2503),
    [anon_sym_LT] = ACTIONS(2501),
    [anon_sym_TILDE] = ACTIONS(2501),
    [anon_sym_void] = ACTIONS(2503),
    [anon_sym_delete] = ACTIONS(2503),
    [anon_sym_PLUS_PLUS] = ACTIONS(2501),
    [anon_sym_DASH_DASH] = ACTIONS(2501),
    [anon_sym_DQUOTE] = ACTIONS(2501),
    [anon_sym_SQUOTE] = ACTIONS(2501),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(2501),
    [sym_number] = ACTIONS(2501),
    [sym_private_property_identifier] = ACTIONS(2501),
    [sym_this] = ACTIONS(2503),
    [sym_super] = ACTIONS(2503),
    [sym_true] = ACTIONS(2503),
    [sym_false] = ACTIONS(2503),
    [sym_null] = ACTIONS(2503),
    [sym_undefined] = ACTIONS(2503),
    [anon_sym_AT] = ACTIONS(2501),
    [anon_sym_static] = ACTIONS(2503),
    [anon_sym_readonly] = ACTIONS(2503),
    [anon_sym_get] = ACTIONS(2503),
    [anon_sym_set] = ACTIONS(2503),
    [anon_sym_declare] = ACTIONS(2503),
    [anon_sym_public] = ACTIONS(2503),
    [anon_sym_private] = ACTIONS(2503),
    [anon_sym_protected] = ACTIONS(2503),
    [anon_sym_override] = ACTIONS(2503),
    [anon_sym_module] = ACTIONS(2503),
    [anon_sym_any] = ACTIONS(2503),
    [anon_sym_number] = ACTIONS(2503),
    [anon_sym_boolean] = ACTIONS(2503),
    [anon_sym_string] = ACTIONS(2503),
    [anon_sym_symbol] = ACTIONS(2503),
    [anon_sym_object] = ACTIONS(2503),
    [anon_sym_abstract] = ACTIONS(2503),
    [anon_sym_interface] = ACTIONS(2503),
    [anon_sym_enum] = ACTIONS(2503),
    [sym__automatic_semicolon] = ACTIONS(2505),
    [sym_html_comment] = ACTIONS(5),
  },
  [786] = {
    [ts_builtin_sym_end] = ACTIONS(1810),
    [sym_identifier] = ACTIONS(1812),
    [anon_sym_export] = ACTIONS(1812),
    [anon_sym_default] = ACTIONS(1812),
    [anon_sym_type] = ACTIONS(1812),
    [anon_sym_namespace] = ACTIONS(1812),
    [anon_sym_LBRACE] = ACTIONS(1810),
    [anon_sym_RBRACE] = ACTIONS(1810),
    [anon_sym_typeof] = ACTIONS(1812),
    [anon_sym_import] = ACTIONS(1812),
    [anon_sym_with] = ACTIONS(1812),
    [anon_sym_var] = ACTIONS(1812),
    [anon_sym_let] = ACTIONS(1812),
    [anon_sym_const] = ACTIONS(1812),
    [anon_sym_BANG] = ACTIONS(1810),
    [anon_sym_else] = ACTIONS(1812),
    [anon_sym_if] = ACTIONS(1812),
    [anon_sym_switch] = ACTIONS(1812),
    [anon_sym_for] = ACTIONS(1812),
    [anon_sym_LPAREN] = ACTIONS(1810),
    [anon_sym_SEMI] = ACTIONS(1810),
    [anon_sym_await] = ACTIONS(1812),
    [anon_sym_while] = ACTIONS(1812),
    [anon_sym_do] = ACTIONS(1812),
    [anon_sym_try] = ACTIONS(1812),
    [anon_sym_break] = ACTIONS(1812),
    [anon_sym_continue] = ACTIONS(1812),
    [anon_sym_debugger] = ACTIONS(1812),
    [anon_sym_return] = ACTIONS(1812),
    [anon_sym_throw] = ACTIONS(1812),
    [anon_sym_case] = ACTIONS(1812),
    [anon_sym_yield] = ACTIONS(1812),
    [anon_sym_LBRACK] = ACTIONS(1810),
    [anon_sym_class] = ACTIONS(1812),
    [anon_sym_async] = ACTIONS(1812),
    [anon_sym_function] = ACTIONS(1812),
    [anon_sym_new] = ACTIONS(1812),
    [anon_sym_using] = ACTIONS(1812),
    [anon_sym_PLUS] = ACTIONS(1812),
    [anon_sym_DASH] = ACTIONS(1812),
    [anon_sym_SLASH] = ACTIONS(1812),
    [anon_sym_LT] = ACTIONS(1810),
    [anon_sym_TILDE] = ACTIONS(1810),
    [anon_sym_void] = ACTIONS(1812),
    [anon_sym_delete] = ACTIONS(1812),
    [anon_sym_PLUS_PLUS] = ACTIONS(1810),
    [anon_sym_DASH_DASH] = ACTIONS(1810),
    [anon_sym_DQUOTE] = ACTIONS(1810),
    [anon_sym_SQUOTE] = ACTIONS(1810),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1810),
    [sym_number] = ACTIONS(1810),
    [sym_private_property_identifier] = ACTIONS(1810),
    [sym_this] = ACTIONS(1812),
    [sym_super] = ACTIONS(1812),
    [sym_true] = ACTIONS(1812),
    [sym_false] = ACTIONS(1812),
    [sym_null] = ACTIONS(1812),
    [sym_undefined] = ACTIONS(1812),
    [anon_sym_AT] = ACTIONS(1810),
    [anon_sym_static] = ACTIONS(1812),
    [anon_sym_readonly] = ACTIONS(1812),
    [anon_sym_get] = ACTIONS(1812),
    [anon_sym_set] = ACTIONS(1812),
    [anon_sym_declare] = ACTIONS(1812),
    [anon_sym_public] = ACTIONS(1812),
    [anon_sym_private] = ACTIONS(1812),
    [anon_sym_protected] = ACTIONS(1812),
    [anon_sym_override] = ACTIONS(1812),
    [anon_sym_module] = ACTIONS(1812),
    [anon_sym_any] = ACTIONS(1812),
    [anon_sym_number] = ACTIONS(1812),
    [anon_sym_boolean] = ACTIONS(1812),
    [anon_sym_string] = ACTIONS(1812),
    [anon_sym_symbol] = ACTIONS(1812),
    [anon_sym_object] = ACTIONS(1812),
    [anon_sym_abstract] = ACTIONS(1812),
    [anon_sym_interface] = ACTIONS(1812),
    [anon_sym_enum] = ACTIONS(1812),
    [sym__automatic_semicolon] = ACTIONS(1818),
    [sym_html_comment] = ACTIONS(5),
  },
  [787] = {
    [ts_builtin_sym_end] = ACTIONS(2507),
    [sym_identifier] = ACTIONS(2509),
    [anon_sym_export] = ACTIONS(2509),
    [anon_sym_default] = ACTIONS(2509),
    [anon_sym_type] = ACTIONS(2509),
    [anon_sym_namespace] = ACTIONS(2509),
    [anon_sym_LBRACE] = ACTIONS(2507),
    [anon_sym_RBRACE] = ACTIONS(2507),
    [anon_sym_typeof] = ACTIONS(2509),
    [anon_sym_import] = ACTIONS(2509),
    [anon_sym_with] = ACTIONS(2509),
    [anon_sym_var] = ACTIONS(2509),
    [anon_sym_let] = ACTIONS(2509),
    [anon_sym_const] = ACTIONS(2509),
    [anon_sym_BANG] = ACTIONS(2507),
    [anon_sym_else] = ACTIONS(2509),
    [anon_sym_if] = ACTIONS(2509),
    [anon_sym_switch] = ACTIONS(2509),
    [anon_sym_for] = ACTIONS(2509),
    [anon_sym_LPAREN] = ACTIONS(2507),
    [anon_sym_SEMI] = ACTIONS(2507),
    [anon_sym_await] = ACTIONS(2509),
    [anon_sym_while] = ACTIONS(2509),
    [anon_sym_do] = ACTIONS(2509),
    [anon_sym_try] = ACTIONS(2509),
    [anon_sym_break] = ACTIONS(2509),
    [anon_sym_continue] = ACTIONS(2509),
    [anon_sym_debugger] = ACTIONS(2509),
    [anon_sym_return] = ACTIONS(2509),
    [anon_sym_throw] = ACTIONS(2509),
    [anon_sym_case] = ACTIONS(2509),
    [anon_sym_yield] = ACTIONS(2509),
    [anon_sym_LBRACK] = ACTIONS(2507),
    [anon_sym_class] = ACTIONS(2509),
    [anon_sym_async] = ACTIONS(2509),
    [anon_sym_function] = ACTIONS(2509),
    [anon_sym_new] = ACTIONS(2509),
    [anon_sym_using] = ACTIONS(2509),
    [anon_sym_PLUS] = ACTIONS(2509),
    [anon_sym_DASH] = ACTIONS(2509),
    [anon_sym_SLASH] = ACTIONS(2509),
    [anon_sym_LT] = ACTIONS(2507),
    [anon_sym_TILDE] = ACTIONS(2507),
    [anon_sym_void] = ACTIONS(2509),
    [anon_sym_delete] = ACTIONS(2509),
    [anon_sym_PLUS_PLUS] = ACTIONS(2507),
    [anon_sym_DASH_DASH] = ACTIONS(2507),
    [anon_sym_DQUOTE] = ACTIONS(2507),
    [anon_sym_SQUOTE] = ACTIONS(2507),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(2507),
    [sym_number] = ACTIONS(2507),
    [sym_private_property_identifier] = ACTIONS(2507),
    [sym_this] = ACTIONS(2509),
    [sym_super] = ACTIONS(2509),
    [sym_true] = ACTIONS(2509),
    [sym_false] = ACTIONS(2509),
    [sym_null] = ACTIONS(2509),
    [sym_undefined] = ACTIONS(2509),
    [anon_sym_AT] = ACTIONS(2507),
    [anon_sym_static] = ACTIONS(2509),
    [anon_sym_readonly] = ACTIONS(2509),
    [anon_sym_get] = ACTIONS(2509),
    [anon_sym_set] = ACTIONS(2509),
    [anon_sym_declare] = ACTIONS(2509),
    [anon_sym_public] = ACTIONS(2509),
    [anon_sym_private] = ACTIONS(2509),
    [anon_sym_protected] = ACTIONS(2509),
    [anon_sym_override] = ACTIONS(2509),
    [anon_sym_module] = ACTIONS(2509),
    [anon_sym_any] = ACTIONS(2509),
    [anon_sym_number] = ACTIONS(2509),
    [anon_sym_boolean] = ACTIONS(2509),
    [anon_sym_string] = ACTIONS(2509),
    [anon_sym_symbol] = ACTIONS(2509),
    [anon_sym_object] = ACTIONS(2509),
    [anon_sym_abstract] = ACTIONS(2509),
    [anon_sym_interface] = ACTIONS(2509),
    [anon_sym_enum] = ACTIONS(2509),
    [sym__automatic_semicolon] = ACTIONS(2507),
    [sym_html_comment] = ACTIONS(5),
  },
  [788] = {
    [ts_builtin_sym_end] = ACTIONS(1706),
    [sym_identifier] = ACTIONS(1708),
    [anon_sym_export] = ACTIONS(1708),
    [anon_sym_default] = ACTIONS(1708),
    [anon_sym_type] = ACTIONS(1708),
    [anon_sym_namespace] = ACTIONS(1708),
    [anon_sym_LBRACE] = ACTIONS(1706),
    [anon_sym_RBRACE] = ACTIONS(1706),
    [anon_sym_typeof] = ACTIONS(1708),
    [anon_sym_import] = ACTIONS(1708),
    [anon_sym_with] = ACTIONS(1708),
    [anon_sym_var] = ACTIONS(1708),
    [anon_sym_let] = ACTIONS(1708),
    [anon_sym_const] = ACTIONS(1708),
    [anon_sym_BANG] = ACTIONS(1706),
    [anon_sym_else] = ACTIONS(1708),
    [anon_sym_if] = ACTIONS(1708),
    [anon_sym_switch] = ACTIONS(1708),
    [anon_sym_for] = ACTIONS(1708),
    [anon_sym_LPAREN] = ACTIONS(1706),
    [anon_sym_SEMI] = ACTIONS(1706),
    [anon_sym_await] = ACTIONS(1708),
    [anon_sym_while] = ACTIONS(1708),
    [anon_sym_do] = ACTIONS(1708),
    [anon_sym_try] = ACTIONS(1708),
    [anon_sym_break] = ACTIONS(1708),
    [anon_sym_continue] = ACTIONS(1708),
    [anon_sym_debugger] = ACTIONS(1708),
    [anon_sym_return] = ACTIONS(1708),
    [anon_sym_throw] = ACTIONS(1708),
    [anon_sym_case] = ACTIONS(1708),
    [anon_sym_yield] = ACTIONS(1708),
    [anon_sym_LBRACK] = ACTIONS(1706),
    [anon_sym_class] = ACTIONS(1708),
    [anon_sym_async] = ACTIONS(1708),
    [anon_sym_function] = ACTIONS(1708),
    [anon_sym_new] = ACTIONS(1708),
    [anon_sym_using] = ACTIONS(1708),
    [anon_sym_PLUS] = ACTIONS(1708),
    [anon_sym_DASH] = ACTIONS(1708),
    [anon_sym_SLASH] = ACTIONS(1708),
    [anon_sym_LT] = ACTIONS(1706),
    [anon_sym_TILDE] = ACTIONS(1706),
    [anon_sym_void] = ACTIONS(1708),
    [anon_sym_delete] = ACTIONS(1708),
    [anon_sym_PLUS_PLUS] = ACTIONS(1706),
    [anon_sym_DASH_DASH] = ACTIONS(1706),
    [anon_sym_DQUOTE] = ACTIONS(1706),
    [anon_sym_SQUOTE] = ACTIONS(1706),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1706),
    [sym_number] = ACTIONS(1706),
    [sym_private_property_identifier] = ACTIONS(1706),
    [sym_this] = ACTIONS(1708),
    [sym_super] = ACTIONS(1708),
    [sym_true] = ACTIONS(1708),
    [sym_false] = ACTIONS(1708),
    [sym_null] = ACTIONS(1708),
    [sym_undefined] = ACTIONS(1708),
    [anon_sym_AT] = ACTIONS(1706),
    [anon_sym_static] = ACTIONS(1708),
    [anon_sym_readonly] = ACTIONS(1708),
    [anon_sym_get] = ACTIONS(1708),
    [anon_sym_set] = ACTIONS(1708),
    [anon_sym_declare] = ACTIONS(1708),
    [anon_sym_public] = ACTIONS(1708),
    [anon_sym_private] = ACTIONS(1708),
    [anon_sym_protected] = ACTIONS(1708),
    [anon_sym_override] = ACTIONS(1708),
    [anon_sym_module] = ACTIONS(1708),
    [anon_sym_any] = ACTIONS(1708),
    [anon_sym_number] = ACTIONS(1708),
    [anon_sym_boolean] = ACTIONS(1708),
    [anon_sym_string] = ACTIONS(1708),
    [anon_sym_symbol] = ACTIONS(1708),
    [anon_sym_object] = ACTIONS(1708),
    [anon_sym_abstract] = ACTIONS(1708),
    [anon_sym_interface] = ACTIONS(1708),
    [anon_sym_enum] = ACTIONS(1708),
    [sym__automatic_semicolon] = ACTIONS(1714),
    [sym_html_comment] = ACTIONS(5),
  },
  [789] = {
    [ts_builtin_sym_end] = ACTIONS(1888),
    [sym_identifier] = ACTIONS(1890),
    [anon_sym_export] = ACTIONS(1890),
    [anon_sym_default] = ACTIONS(1890),
    [anon_sym_type] = ACTIONS(1890),
    [anon_sym_namespace] = ACTIONS(1890),
    [anon_sym_LBRACE] = ACTIONS(1888),
    [anon_sym_RBRACE] = ACTIONS(1888),
    [anon_sym_typeof] = ACTIONS(1890),
    [anon_sym_import] = ACTIONS(1890),
    [anon_sym_with] = ACTIONS(1890),
    [anon_sym_var] = ACTIONS(1890),
    [anon_sym_let] = ACTIONS(1890),
    [anon_sym_const] = ACTIONS(1890),
    [anon_sym_BANG] = ACTIONS(1888),
    [anon_sym_else] = ACTIONS(1890),
    [anon_sym_if] = ACTIONS(1890),
    [anon_sym_switch] = ACTIONS(1890),
    [anon_sym_for] = ACTIONS(1890),
    [anon_sym_LPAREN] = ACTIONS(1888),
    [anon_sym_SEMI] = ACTIONS(1888),
    [anon_sym_await] = ACTIONS(1890),
    [anon_sym_while] = ACTIONS(1890),
    [anon_sym_do] = ACTIONS(1890),
    [anon_sym_try] = ACTIONS(1890),
    [anon_sym_break] = ACTIONS(1890),
    [anon_sym_continue] = ACTIONS(1890),
    [anon_sym_debugger] = ACTIONS(1890),
    [anon_sym_return] = ACTIONS(1890),
    [anon_sym_throw] = ACTIONS(1890),
    [anon_sym_case] = ACTIONS(1890),
    [anon_sym_yield] = ACTIONS(1890),
    [anon_sym_LBRACK] = ACTIONS(1888),
    [anon_sym_DOT] = ACTIONS(1890),
    [anon_sym_class] = ACTIONS(1890),
    [anon_sym_async] = ACTIONS(1890),
    [anon_sym_function] = ACTIONS(1890),
    [anon_sym_new] = ACTIONS(1890),
    [anon_sym_using] = ACTIONS(1890),
    [anon_sym_PLUS] = ACTIONS(1890),
    [anon_sym_DASH] = ACTIONS(1890),
    [anon_sym_SLASH] = ACTIONS(1890),
    [anon_sym_LT] = ACTIONS(1888),
    [anon_sym_TILDE] = ACTIONS(1888),
    [anon_sym_void] = ACTIONS(1890),
    [anon_sym_delete] = ACTIONS(1890),
    [anon_sym_PLUS_PLUS] = ACTIONS(1888),
    [anon_sym_DASH_DASH] = ACTIONS(1888),
    [anon_sym_DQUOTE] = ACTIONS(1888),
    [anon_sym_SQUOTE] = ACTIONS(1888),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1888),
    [sym_number] = ACTIONS(1888),
    [sym_private_property_identifier] = ACTIONS(1888),
    [sym_this] = ACTIONS(1890),
    [sym_super] = ACTIONS(1890),
    [sym_true] = ACTIONS(1890),
    [sym_false] = ACTIONS(1890),
    [sym_null] = ACTIONS(1890),
    [sym_undefined] = ACTIONS(1890),
    [anon_sym_AT] = ACTIONS(1888),
    [anon_sym_static] = ACTIONS(1890),
    [anon_sym_readonly] = ACTIONS(1890),
    [anon_sym_get] = ACTIONS(1890),
    [anon_sym_set] = ACTIONS(1890),
    [anon_sym_declare] = ACTIONS(1890),
    [anon_sym_public] = ACTIONS(1890),
    [anon_sym_private] = ACTIONS(1890),
    [anon_sym_protected] = ACTIONS(1890),
    [anon_sym_override] = ACTIONS(1890),
    [anon_sym_module] = ACTIONS(1890),
    [anon_sym_any] = ACTIONS(1890),
    [anon_sym_number] = ACTIONS(1890),
    [anon_sym_boolean] = ACTIONS(1890),
    [anon_sym_string] = ACTIONS(1890),
    [anon_sym_symbol] = ACTIONS(1890),
    [anon_sym_object] = ACTIONS(1890),
    [anon_sym_abstract] = ACTIONS(1890),
    [anon_sym_interface] = ACTIONS(1890),
    [anon_sym_enum] = ACTIONS(1890),
    [sym_html_comment] = ACTIONS(5),
  },
  [790] = {
    [sym_else_clause] = STATE(854),
    [ts_builtin_sym_end] = ACTIONS(2511),
    [sym_identifier] = ACTIONS(2513),
    [anon_sym_export] = ACTIONS(2513),
    [anon_sym_default] = ACTIONS(2513),
    [anon_sym_type] = ACTIONS(2513),
    [anon_sym_namespace] = ACTIONS(2513),
    [anon_sym_LBRACE] = ACTIONS(2511),
    [anon_sym_RBRACE] = ACTIONS(2511),
    [anon_sym_typeof] = ACTIONS(2513),
    [anon_sym_import] = ACTIONS(2513),
    [anon_sym_with] = ACTIONS(2513),
    [anon_sym_var] = ACTIONS(2513),
    [anon_sym_let] = ACTIONS(2513),
    [anon_sym_const] = ACTIONS(2513),
    [anon_sym_BANG] = ACTIONS(2511),
    [anon_sym_else] = ACTIONS(2515),
    [anon_sym_if] = ACTIONS(2513),
    [anon_sym_switch] = ACTIONS(2513),
    [anon_sym_for] = ACTIONS(2513),
    [anon_sym_LPAREN] = ACTIONS(2511),
    [anon_sym_SEMI] = ACTIONS(2511),
    [anon_sym_await] = ACTIONS(2513),
    [anon_sym_while] = ACTIONS(2513),
    [anon_sym_do] = ACTIONS(2513),
    [anon_sym_try] = ACTIONS(2513),
    [anon_sym_break] = ACTIONS(2513),
    [anon_sym_continue] = ACTIONS(2513),
    [anon_sym_debugger] = ACTIONS(2513),
    [anon_sym_return] = ACTIONS(2513),
    [anon_sym_throw] = ACTIONS(2513),
    [anon_sym_case] = ACTIONS(2513),
    [anon_sym_yield] = ACTIONS(2513),
    [anon_sym_LBRACK] = ACTIONS(2511),
    [anon_sym_class] = ACTIONS(2513),
    [anon_sym_async] = ACTIONS(2513),
    [anon_sym_function] = ACTIONS(2513),
    [anon_sym_new] = ACTIONS(2513),
    [anon_sym_using] = ACTIONS(2513),
    [anon_sym_PLUS] = ACTIONS(2513),
    [anon_sym_DASH] = ACTIONS(2513),
    [anon_sym_SLASH] = ACTIONS(2513),
    [anon_sym_LT] = ACTIONS(2511),
    [anon_sym_TILDE] = ACTIONS(2511),
    [anon_sym_void] = ACTIONS(2513),
    [anon_sym_delete] = ACTIONS(2513),
    [anon_sym_PLUS_PLUS] = ACTIONS(2511),
    [anon_sym_DASH_DASH] = ACTIONS(2511),
    [anon_sym_DQUOTE] = ACTIONS(2511),
    [anon_sym_SQUOTE] = ACTIONS(2511),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(2511),
    [sym_number] = ACTIONS(2511),
    [sym_private_property_identifier] = ACTIONS(2511),
    [sym_this] = ACTIONS(2513),
    [sym_super] = ACTIONS(2513),
    [sym_true] = ACTIONS(2513),
    [sym_false] = ACTIONS(2513),
    [sym_null] = ACTIONS(2513),
    [sym_undefined] = ACTIONS(2513),
    [anon_sym_AT] = ACTIONS(2511),
    [anon_sym_static] = ACTIONS(2513),
    [anon_sym_readonly] = ACTIONS(2513),
    [anon_sym_get] = ACTIONS(2513),
    [anon_sym_set] = ACTIONS(2513),
    [anon_sym_declare] = ACTIONS(2513),
    [anon_sym_public] = ACTIONS(2513),
    [anon_sym_private] = ACTIONS(2513),
    [anon_sym_protected] = ACTIONS(2513),
    [anon_sym_override] = ACTIONS(2513),
    [anon_sym_module] = ACTIONS(2513),
    [anon_sym_any] = ACTIONS(2513),
    [anon_sym_number] = ACTIONS(2513),
    [anon_sym_boolean] = ACTIONS(2513),
    [anon_sym_string] = ACTIONS(2513),
    [anon_sym_symbol] = ACTIONS(2513),
    [anon_sym_object] = ACTIONS(2513),
    [anon_sym_abstract] = ACTIONS(2513),
    [anon_sym_interface] = ACTIONS(2513),
    [anon_sym_enum] = ACTIONS(2513),
    [sym_html_comment] = ACTIONS(5),
  },
  [791] = {
    [ts_builtin_sym_end] = ACTIONS(1830),
    [sym_identifier] = ACTIONS(1832),
    [anon_sym_export] = ACTIONS(1832),
    [anon_sym_default] = ACTIONS(1832),
    [anon_sym_type] = ACTIONS(1832),
    [anon_sym_namespace] = ACTIONS(1832),
    [anon_sym_LBRACE] = ACTIONS(1830),
    [anon_sym_RBRACE] = ACTIONS(1830),
    [anon_sym_typeof] = ACTIONS(1832),
    [anon_sym_import] = ACTIONS(1832),
    [anon_sym_with] = ACTIONS(1832),
    [anon_sym_var] = ACTIONS(1832),
    [anon_sym_let] = ACTIONS(1832),
    [anon_sym_const] = ACTIONS(1832),
    [anon_sym_BANG] = ACTIONS(1830),
    [anon_sym_else] = ACTIONS(1832),
    [anon_sym_if] = ACTIONS(1832),
    [anon_sym_switch] = ACTIONS(1832),
    [anon_sym_for] = ACTIONS(1832),
    [anon_sym_LPAREN] = ACTIONS(1830),
    [anon_sym_SEMI] = ACTIONS(1830),
    [anon_sym_await] = ACTIONS(1832),
    [anon_sym_while] = ACTIONS(1832),
    [anon_sym_do] = ACTIONS(1832),
    [anon_sym_try] = ACTIONS(1832),
    [anon_sym_break] = ACTIONS(1832),
    [anon_sym_continue] = ACTIONS(1832),
    [anon_sym_debugger] = ACTIONS(1832),
    [anon_sym_return] = ACTIONS(1832),
    [anon_sym_throw] = ACTIONS(1832),
    [anon_sym_case] = ACTIONS(1832),
    [anon_sym_yield] = ACTIONS(1832),
    [anon_sym_LBRACK] = ACTIONS(1830),
    [anon_sym_class] = ACTIONS(1832),
    [anon_sym_async] = ACTIONS(1832),
    [anon_sym_function] = ACTIONS(1832),
    [anon_sym_new] = ACTIONS(1832),
    [anon_sym_using] = ACTIONS(1832),
    [anon_sym_PLUS] = ACTIONS(1832),
    [anon_sym_DASH] = ACTIONS(1832),
    [anon_sym_SLASH] = ACTIONS(1832),
    [anon_sym_LT] = ACTIONS(1830),
    [anon_sym_TILDE] = ACTIONS(1830),
    [anon_sym_void] = ACTIONS(1832),
    [anon_sym_delete] = ACTIONS(1832),
    [anon_sym_PLUS_PLUS] = ACTIONS(1830),
    [anon_sym_DASH_DASH] = ACTIONS(1830),
    [anon_sym_DQUOTE] = ACTIONS(1830),
    [anon_sym_SQUOTE] = ACTIONS(1830),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1830),
    [sym_number] = ACTIONS(1830),
    [sym_private_property_identifier] = ACTIONS(1830),
    [sym_this] = ACTIONS(1832),
    [sym_super] = ACTIONS(1832),
    [sym_true] = ACTIONS(1832),
    [sym_false] = ACTIONS(1832),
    [sym_null] = ACTIONS(1832),
    [sym_undefined] = ACTIONS(1832),
    [anon_sym_AT] = ACTIONS(1830),
    [anon_sym_static] = ACTIONS(1832),
    [anon_sym_readonly] = ACTIONS(1832),
    [anon_sym_get] = ACTIONS(1832),
    [anon_sym_set] = ACTIONS(1832),
    [anon_sym_declare] = ACTIONS(1832),
    [anon_sym_public] = ACTIONS(1832),
    [anon_sym_private] = ACTIONS(1832),
    [anon_sym_protected] = ACTIONS(1832),
    [anon_sym_override] = ACTIONS(1832),
    [anon_sym_module] = ACTIONS(1832),
    [anon_sym_any] = ACTIONS(1832),
    [anon_sym_number] = ACTIONS(1832),
    [anon_sym_boolean] = ACTIONS(1832),
    [anon_sym_string] = ACTIONS(1832),
    [anon_sym_symbol] = ACTIONS(1832),
    [anon_sym_object] = ACTIONS(1832),
    [anon_sym_abstract] = ACTIONS(1832),
    [anon_sym_interface] = ACTIONS(1832),
    [anon_sym_enum] = ACTIONS(1832),
    [sym__automatic_semicolon] = ACTIONS(1838),
    [sym_html_comment] = ACTIONS(5),
  },
  [792] = {
    [ts_builtin_sym_end] = ACTIONS(1758),
    [sym_identifier] = ACTIONS(1760),
    [anon_sym_export] = ACTIONS(1760),
    [anon_sym_default] = ACTIONS(1760),
    [anon_sym_type] = ACTIONS(1760),
    [anon_sym_namespace] = ACTIONS(1760),
    [anon_sym_LBRACE] = ACTIONS(1758),
    [anon_sym_RBRACE] = ACTIONS(1758),
    [anon_sym_typeof] = ACTIONS(1760),
    [anon_sym_import] = ACTIONS(1760),
    [anon_sym_with] = ACTIONS(1760),
    [anon_sym_var] = ACTIONS(1760),
    [anon_sym_let] = ACTIONS(1760),
    [anon_sym_const] = ACTIONS(1760),
    [anon_sym_BANG] = ACTIONS(1758),
    [anon_sym_else] = ACTIONS(1760),
    [anon_sym_if] = ACTIONS(1760),
    [anon_sym_switch] = ACTIONS(1760),
    [anon_sym_for] = ACTIONS(1760),
    [anon_sym_LPAREN] = ACTIONS(1758),
    [anon_sym_SEMI] = ACTIONS(1758),
    [anon_sym_await] = ACTIONS(1760),
    [anon_sym_while] = ACTIONS(1760),
    [anon_sym_do] = ACTIONS(1760),
    [anon_sym_try] = ACTIONS(1760),
    [anon_sym_break] = ACTIONS(1760),
    [anon_sym_continue] = ACTIONS(1760),
    [anon_sym_debugger] = ACTIONS(1760),
    [anon_sym_return] = ACTIONS(1760),
    [anon_sym_throw] = ACTIONS(1760),
    [anon_sym_case] = ACTIONS(1760),
    [anon_sym_yield] = ACTIONS(1760),
    [anon_sym_LBRACK] = ACTIONS(1758),
    [anon_sym_class] = ACTIONS(1760),
    [anon_sym_async] = ACTIONS(1760),
    [anon_sym_function] = ACTIONS(1760),
    [anon_sym_new] = ACTIONS(1760),
    [anon_sym_using] = ACTIONS(1760),
    [anon_sym_PLUS] = ACTIONS(1760),
    [anon_sym_DASH] = ACTIONS(1760),
    [anon_sym_SLASH] = ACTIONS(1760),
    [anon_sym_LT] = ACTIONS(1758),
    [anon_sym_TILDE] = ACTIONS(1758),
    [anon_sym_void] = ACTIONS(1760),
    [anon_sym_delete] = ACTIONS(1760),
    [anon_sym_PLUS_PLUS] = ACTIONS(1758),
    [anon_sym_DASH_DASH] = ACTIONS(1758),
    [anon_sym_DQUOTE] = ACTIONS(1758),
    [anon_sym_SQUOTE] = ACTIONS(1758),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1758),
    [sym_number] = ACTIONS(1758),
    [sym_private_property_identifier] = ACTIONS(1758),
    [sym_this] = ACTIONS(1760),
    [sym_super] = ACTIONS(1760),
    [sym_true] = ACTIONS(1760),
    [sym_false] = ACTIONS(1760),
    [sym_null] = ACTIONS(1760),
    [sym_undefined] = ACTIONS(1760),
    [anon_sym_AT] = ACTIONS(1758),
    [anon_sym_static] = ACTIONS(1760),
    [anon_sym_readonly] = ACTIONS(1760),
    [anon_sym_get] = ACTIONS(1760),
    [anon_sym_set] = ACTIONS(1760),
    [anon_sym_declare] = ACTIONS(1760),
    [anon_sym_public] = ACTIONS(1760),
    [anon_sym_private] = ACTIONS(1760),
    [anon_sym_protected] = ACTIONS(1760),
    [anon_sym_override] = ACTIONS(1760),
    [anon_sym_module] = ACTIONS(1760),
    [anon_sym_any] = ACTIONS(1760),
    [anon_sym_number] = ACTIONS(1760),
    [anon_sym_boolean] = ACTIONS(1760),
    [anon_sym_string] = ACTIONS(1760),
    [anon_sym_symbol] = ACTIONS(1760),
    [anon_sym_object] = ACTIONS(1760),
    [anon_sym_abstract] = ACTIONS(1760),
    [anon_sym_interface] = ACTIONS(1760),
    [anon_sym_enum] = ACTIONS(1760),
    [sym__automatic_semicolon] = ACTIONS(1766),
    [sym_html_comment] = ACTIONS(5),
  },
  [793] = {
    [sym_import] = STATE(4681),
    [sym_nested_identifier] = STATE(5474),
    [sym_string] = STATE(2994),
    [sym_formal_parameters] = STATE(5619),
    [sym_rest_pattern] = STATE(5165),
    [sym_nested_type_identifier] = STATE(2939),
    [sym__type_query_member_expression_in_type_annotation] = STATE(3303),
    [sym__type_query_call_expression_in_type_annotation] = STATE(2938),
    [sym_type] = STATE(3773),
    [sym_tuple_parameter] = STATE(4540),
    [sym_optional_tuple_parameter] = STATE(4540),
    [sym_optional_type] = STATE(4540),
    [sym_rest_type] = STATE(4540),
    [sym__tuple_type_member] = STATE(4540),
    [sym_constructor_type] = STATE(3007),
    [sym_primary_type] = STATE(2981),
    [sym_template_literal_type] = STATE(3039),
    [sym_infer_type] = STATE(3007),
    [sym_conditional_type] = STATE(3039),
    [sym_generic_type] = STATE(3039),
    [sym_type_query] = STATE(3039),
    [sym_index_type_query] = STATE(3039),
    [sym_lookup_type] = STATE(3039),
    [sym_literal_type] = STATE(3039),
    [sym__number] = STATE(3041),
    [sym_existential_type] = STATE(3039),
    [sym_flow_maybe_type] = STATE(3039),
    [sym_parenthesized_type] = STATE(3039),
    [sym_predefined_type] = STATE(3039),
    [sym_object_type] = STATE(3039),
    [sym_type_parameters] = STATE(5454),
    [sym_array_type] = STATE(3039),
    [sym_tuple_type] = STATE(3039),
    [sym_readonly_type] = STATE(3007),
    [sym_union_type] = STATE(3039),
    [sym_intersection_type] = STATE(3039),
    [sym_function_type] = STATE(3007),
    [sym_identifier] = ACTIONS(2489),
    [anon_sym_STAR] = ACTIONS(543),
    [anon_sym_LBRACE] = ACTIONS(1534),
    [anon_sym_COMMA] = ACTIONS(2517),
    [anon_sym_typeof] = ACTIONS(1536),
    [anon_sym_import] = ACTIONS(1538),
    [anon_sym_const] = ACTIONS(133),
    [anon_sym_LPAREN] = ACTIONS(1540),
    [anon_sym_LBRACK] = ACTIONS(1542),
    [anon_sym_RBRACK] = ACTIONS(2519),
    [anon_sym_new] = ACTIONS(1642),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(2495),
    [anon_sym_AMP] = ACTIONS(571),
    [anon_sym_PIPE] = ACTIONS(573),
    [anon_sym_PLUS] = ACTIONS(2497),
    [anon_sym_DASH] = ACTIONS(2497),
    [anon_sym_LT] = ACTIONS(2499),
    [anon_sym_void] = ACTIONS(216),
    [anon_sym_DQUOTE] = ACTIONS(1550),
    [anon_sym_SQUOTE] = ACTIONS(1552),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1554),
    [sym_number] = ACTIONS(1556),
    [sym_this] = ACTIONS(1558),
    [sym_true] = ACTIONS(1560),
    [sym_false] = ACTIONS(1560),
    [sym_null] = ACTIONS(1560),
    [sym_undefined] = ACTIONS(1560),
    [anon_sym_readonly] = ACTIONS(1648),
    [anon_sym_QMARK] = ACTIONS(593),
    [anon_sym_any] = ACTIONS(216),
    [anon_sym_number] = ACTIONS(216),
    [anon_sym_boolean] = ACTIONS(216),
    [anon_sym_string] = ACTIONS(216),
    [anon_sym_symbol] = ACTIONS(216),
    [anon_sym_object] = ACTIONS(216),
    [anon_sym_abstract] = ACTIONS(597),
    [anon_sym_infer] = ACTIONS(599),
    [anon_sym_keyof] = ACTIONS(601),
    [anon_sym_unique] = ACTIONS(214),
    [anon_sym_unknown] = ACTIONS(216),
    [anon_sym_never] = ACTIONS(216),
    [anon_sym_LBRACE_PIPE] = ACTIONS(218),
    [sym_html_comment] = ACTIONS(5),
  },
  [794] = {
    [ts_builtin_sym_end] = ACTIONS(1842),
    [sym_identifier] = ACTIONS(1844),
    [anon_sym_export] = ACTIONS(1844),
    [anon_sym_default] = ACTIONS(1844),
    [anon_sym_type] = ACTIONS(1844),
    [anon_sym_namespace] = ACTIONS(1844),
    [anon_sym_LBRACE] = ACTIONS(1842),
    [anon_sym_RBRACE] = ACTIONS(1842),
    [anon_sym_typeof] = ACTIONS(1844),
    [anon_sym_import] = ACTIONS(1844),
    [anon_sym_with] = ACTIONS(1844),
    [anon_sym_var] = ACTIONS(1844),
    [anon_sym_let] = ACTIONS(1844),
    [anon_sym_const] = ACTIONS(1844),
    [anon_sym_BANG] = ACTIONS(1842),
    [anon_sym_else] = ACTIONS(1844),
    [anon_sym_if] = ACTIONS(1844),
    [anon_sym_switch] = ACTIONS(1844),
    [anon_sym_for] = ACTIONS(1844),
    [anon_sym_LPAREN] = ACTIONS(1842),
    [anon_sym_SEMI] = ACTIONS(1842),
    [anon_sym_await] = ACTIONS(1844),
    [anon_sym_while] = ACTIONS(1844),
    [anon_sym_do] = ACTIONS(1844),
    [anon_sym_try] = ACTIONS(1844),
    [anon_sym_break] = ACTIONS(1844),
    [anon_sym_continue] = ACTIONS(1844),
    [anon_sym_debugger] = ACTIONS(1844),
    [anon_sym_return] = ACTIONS(1844),
    [anon_sym_throw] = ACTIONS(1844),
    [anon_sym_case] = ACTIONS(1844),
    [anon_sym_yield] = ACTIONS(1844),
    [anon_sym_LBRACK] = ACTIONS(1842),
    [anon_sym_class] = ACTIONS(1844),
    [anon_sym_async] = ACTIONS(1844),
    [anon_sym_function] = ACTIONS(1844),
    [anon_sym_new] = ACTIONS(1844),
    [anon_sym_using] = ACTIONS(1844),
    [anon_sym_PLUS] = ACTIONS(1844),
    [anon_sym_DASH] = ACTIONS(1844),
    [anon_sym_SLASH] = ACTIONS(1844),
    [anon_sym_LT] = ACTIONS(1842),
    [anon_sym_TILDE] = ACTIONS(1842),
    [anon_sym_void] = ACTIONS(1844),
    [anon_sym_delete] = ACTIONS(1844),
    [anon_sym_PLUS_PLUS] = ACTIONS(1842),
    [anon_sym_DASH_DASH] = ACTIONS(1842),
    [anon_sym_DQUOTE] = ACTIONS(1842),
    [anon_sym_SQUOTE] = ACTIONS(1842),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1842),
    [sym_number] = ACTIONS(1842),
    [sym_private_property_identifier] = ACTIONS(1842),
    [sym_this] = ACTIONS(1844),
    [sym_super] = ACTIONS(1844),
    [sym_true] = ACTIONS(1844),
    [sym_false] = ACTIONS(1844),
    [sym_null] = ACTIONS(1844),
    [sym_undefined] = ACTIONS(1844),
    [anon_sym_AT] = ACTIONS(1842),
    [anon_sym_static] = ACTIONS(1844),
    [anon_sym_readonly] = ACTIONS(1844),
    [anon_sym_get] = ACTIONS(1844),
    [anon_sym_set] = ACTIONS(1844),
    [anon_sym_declare] = ACTIONS(1844),
    [anon_sym_public] = ACTIONS(1844),
    [anon_sym_private] = ACTIONS(1844),
    [anon_sym_protected] = ACTIONS(1844),
    [anon_sym_override] = ACTIONS(1844),
    [anon_sym_module] = ACTIONS(1844),
    [anon_sym_any] = ACTIONS(1844),
    [anon_sym_number] = ACTIONS(1844),
    [anon_sym_boolean] = ACTIONS(1844),
    [anon_sym_string] = ACTIONS(1844),
    [anon_sym_symbol] = ACTIONS(1844),
    [anon_sym_object] = ACTIONS(1844),
    [anon_sym_abstract] = ACTIONS(1844),
    [anon_sym_interface] = ACTIONS(1844),
    [anon_sym_enum] = ACTIONS(1844),
    [sym__automatic_semicolon] = ACTIONS(1850),
    [sym_html_comment] = ACTIONS(5),
  },
  [795] = {
    [sym_import] = STATE(4681),
    [sym_nested_identifier] = STATE(5474),
    [sym_string] = STATE(2994),
    [sym_formal_parameters] = STATE(5619),
    [sym_rest_pattern] = STATE(5165),
    [sym_nested_type_identifier] = STATE(2939),
    [sym__type_query_member_expression_in_type_annotation] = STATE(3303),
    [sym__type_query_call_expression_in_type_annotation] = STATE(2938),
    [sym_type] = STATE(3773),
    [sym_tuple_parameter] = STATE(4586),
    [sym_optional_tuple_parameter] = STATE(4586),
    [sym_optional_type] = STATE(4586),
    [sym_rest_type] = STATE(4586),
    [sym__tuple_type_member] = STATE(4586),
    [sym_constructor_type] = STATE(3007),
    [sym_primary_type] = STATE(2981),
    [sym_template_literal_type] = STATE(3039),
    [sym_infer_type] = STATE(3007),
    [sym_conditional_type] = STATE(3039),
    [sym_generic_type] = STATE(3039),
    [sym_type_query] = STATE(3039),
    [sym_index_type_query] = STATE(3039),
    [sym_lookup_type] = STATE(3039),
    [sym_literal_type] = STATE(3039),
    [sym__number] = STATE(3041),
    [sym_existential_type] = STATE(3039),
    [sym_flow_maybe_type] = STATE(3039),
    [sym_parenthesized_type] = STATE(3039),
    [sym_predefined_type] = STATE(3039),
    [sym_object_type] = STATE(3039),
    [sym_type_parameters] = STATE(5454),
    [sym_array_type] = STATE(3039),
    [sym_tuple_type] = STATE(3039),
    [sym_readonly_type] = STATE(3007),
    [sym_union_type] = STATE(3039),
    [sym_intersection_type] = STATE(3039),
    [sym_function_type] = STATE(3007),
    [sym_identifier] = ACTIONS(2489),
    [anon_sym_STAR] = ACTIONS(543),
    [anon_sym_LBRACE] = ACTIONS(1534),
    [anon_sym_COMMA] = ACTIONS(2521),
    [anon_sym_typeof] = ACTIONS(1536),
    [anon_sym_import] = ACTIONS(1538),
    [anon_sym_const] = ACTIONS(133),
    [anon_sym_LPAREN] = ACTIONS(1540),
    [anon_sym_LBRACK] = ACTIONS(1542),
    [anon_sym_RBRACK] = ACTIONS(2523),
    [anon_sym_new] = ACTIONS(1642),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(2495),
    [anon_sym_AMP] = ACTIONS(571),
    [anon_sym_PIPE] = ACTIONS(573),
    [anon_sym_PLUS] = ACTIONS(2497),
    [anon_sym_DASH] = ACTIONS(2497),
    [anon_sym_LT] = ACTIONS(2499),
    [anon_sym_void] = ACTIONS(216),
    [anon_sym_DQUOTE] = ACTIONS(1550),
    [anon_sym_SQUOTE] = ACTIONS(1552),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1554),
    [sym_number] = ACTIONS(1556),
    [sym_this] = ACTIONS(1558),
    [sym_true] = ACTIONS(1560),
    [sym_false] = ACTIONS(1560),
    [sym_null] = ACTIONS(1560),
    [sym_undefined] = ACTIONS(1560),
    [anon_sym_readonly] = ACTIONS(1648),
    [anon_sym_QMARK] = ACTIONS(593),
    [anon_sym_any] = ACTIONS(216),
    [anon_sym_number] = ACTIONS(216),
    [anon_sym_boolean] = ACTIONS(216),
    [anon_sym_string] = ACTIONS(216),
    [anon_sym_symbol] = ACTIONS(216),
    [anon_sym_object] = ACTIONS(216),
    [anon_sym_abstract] = ACTIONS(597),
    [anon_sym_infer] = ACTIONS(599),
    [anon_sym_keyof] = ACTIONS(601),
    [anon_sym_unique] = ACTIONS(214),
    [anon_sym_unknown] = ACTIONS(216),
    [anon_sym_never] = ACTIONS(216),
    [anon_sym_LBRACE_PIPE] = ACTIONS(218),
    [sym_html_comment] = ACTIONS(5),
  },
  [796] = {
    [ts_builtin_sym_end] = ACTIONS(1780),
    [sym_identifier] = ACTIONS(1782),
    [anon_sym_export] = ACTIONS(1782),
    [anon_sym_default] = ACTIONS(1782),
    [anon_sym_type] = ACTIONS(1782),
    [anon_sym_namespace] = ACTIONS(1782),
    [anon_sym_LBRACE] = ACTIONS(1780),
    [anon_sym_RBRACE] = ACTIONS(1780),
    [anon_sym_typeof] = ACTIONS(1782),
    [anon_sym_import] = ACTIONS(1782),
    [anon_sym_with] = ACTIONS(1782),
    [anon_sym_var] = ACTIONS(1782),
    [anon_sym_let] = ACTIONS(1782),
    [anon_sym_const] = ACTIONS(1782),
    [anon_sym_BANG] = ACTIONS(1780),
    [anon_sym_else] = ACTIONS(1782),
    [anon_sym_if] = ACTIONS(1782),
    [anon_sym_switch] = ACTIONS(1782),
    [anon_sym_for] = ACTIONS(1782),
    [anon_sym_LPAREN] = ACTIONS(1780),
    [anon_sym_SEMI] = ACTIONS(1780),
    [anon_sym_await] = ACTIONS(1782),
    [anon_sym_while] = ACTIONS(1782),
    [anon_sym_do] = ACTIONS(1782),
    [anon_sym_try] = ACTIONS(1782),
    [anon_sym_break] = ACTIONS(1782),
    [anon_sym_continue] = ACTIONS(1782),
    [anon_sym_debugger] = ACTIONS(1782),
    [anon_sym_return] = ACTIONS(1782),
    [anon_sym_throw] = ACTIONS(1782),
    [anon_sym_case] = ACTIONS(1782),
    [anon_sym_yield] = ACTIONS(1782),
    [anon_sym_LBRACK] = ACTIONS(1780),
    [anon_sym_class] = ACTIONS(1782),
    [anon_sym_async] = ACTIONS(1782),
    [anon_sym_function] = ACTIONS(1782),
    [anon_sym_new] = ACTIONS(1782),
    [anon_sym_using] = ACTIONS(1782),
    [anon_sym_PLUS] = ACTIONS(1782),
    [anon_sym_DASH] = ACTIONS(1782),
    [anon_sym_SLASH] = ACTIONS(1782),
    [anon_sym_LT] = ACTIONS(1780),
    [anon_sym_TILDE] = ACTIONS(1780),
    [anon_sym_void] = ACTIONS(1782),
    [anon_sym_delete] = ACTIONS(1782),
    [anon_sym_PLUS_PLUS] = ACTIONS(1780),
    [anon_sym_DASH_DASH] = ACTIONS(1780),
    [anon_sym_DQUOTE] = ACTIONS(1780),
    [anon_sym_SQUOTE] = ACTIONS(1780),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1780),
    [sym_number] = ACTIONS(1780),
    [sym_private_property_identifier] = ACTIONS(1780),
    [sym_this] = ACTIONS(1782),
    [sym_super] = ACTIONS(1782),
    [sym_true] = ACTIONS(1782),
    [sym_false] = ACTIONS(1782),
    [sym_null] = ACTIONS(1782),
    [sym_undefined] = ACTIONS(1782),
    [anon_sym_AT] = ACTIONS(1780),
    [anon_sym_static] = ACTIONS(1782),
    [anon_sym_readonly] = ACTIONS(1782),
    [anon_sym_get] = ACTIONS(1782),
    [anon_sym_set] = ACTIONS(1782),
    [anon_sym_declare] = ACTIONS(1782),
    [anon_sym_public] = ACTIONS(1782),
    [anon_sym_private] = ACTIONS(1782),
    [anon_sym_protected] = ACTIONS(1782),
    [anon_sym_override] = ACTIONS(1782),
    [anon_sym_module] = ACTIONS(1782),
    [anon_sym_any] = ACTIONS(1782),
    [anon_sym_number] = ACTIONS(1782),
    [anon_sym_boolean] = ACTIONS(1782),
    [anon_sym_string] = ACTIONS(1782),
    [anon_sym_symbol] = ACTIONS(1782),
    [anon_sym_object] = ACTIONS(1782),
    [anon_sym_abstract] = ACTIONS(1782),
    [anon_sym_interface] = ACTIONS(1782),
    [anon_sym_enum] = ACTIONS(1782),
    [sym__automatic_semicolon] = ACTIONS(1788),
    [sym_html_comment] = ACTIONS(5),
  },
  [797] = {
    [ts_builtin_sym_end] = ACTIONS(1820),
    [sym_identifier] = ACTIONS(1822),
    [anon_sym_export] = ACTIONS(1822),
    [anon_sym_default] = ACTIONS(1822),
    [anon_sym_type] = ACTIONS(1822),
    [anon_sym_namespace] = ACTIONS(1822),
    [anon_sym_LBRACE] = ACTIONS(1820),
    [anon_sym_RBRACE] = ACTIONS(1820),
    [anon_sym_typeof] = ACTIONS(1822),
    [anon_sym_import] = ACTIONS(1822),
    [anon_sym_with] = ACTIONS(1822),
    [anon_sym_var] = ACTIONS(1822),
    [anon_sym_let] = ACTIONS(1822),
    [anon_sym_const] = ACTIONS(1822),
    [anon_sym_BANG] = ACTIONS(1820),
    [anon_sym_else] = ACTIONS(1822),
    [anon_sym_if] = ACTIONS(1822),
    [anon_sym_switch] = ACTIONS(1822),
    [anon_sym_for] = ACTIONS(1822),
    [anon_sym_LPAREN] = ACTIONS(1820),
    [anon_sym_SEMI] = ACTIONS(1820),
    [anon_sym_await] = ACTIONS(1822),
    [anon_sym_while] = ACTIONS(1822),
    [anon_sym_do] = ACTIONS(1822),
    [anon_sym_try] = ACTIONS(1822),
    [anon_sym_break] = ACTIONS(1822),
    [anon_sym_continue] = ACTIONS(1822),
    [anon_sym_debugger] = ACTIONS(1822),
    [anon_sym_return] = ACTIONS(1822),
    [anon_sym_throw] = ACTIONS(1822),
    [anon_sym_case] = ACTIONS(1822),
    [anon_sym_yield] = ACTIONS(1822),
    [anon_sym_LBRACK] = ACTIONS(1820),
    [anon_sym_class] = ACTIONS(1822),
    [anon_sym_async] = ACTIONS(1822),
    [anon_sym_function] = ACTIONS(1822),
    [anon_sym_new] = ACTIONS(1822),
    [anon_sym_using] = ACTIONS(1822),
    [anon_sym_PLUS] = ACTIONS(1822),
    [anon_sym_DASH] = ACTIONS(1822),
    [anon_sym_SLASH] = ACTIONS(1822),
    [anon_sym_LT] = ACTIONS(1820),
    [anon_sym_TILDE] = ACTIONS(1820),
    [anon_sym_void] = ACTIONS(1822),
    [anon_sym_delete] = ACTIONS(1822),
    [anon_sym_PLUS_PLUS] = ACTIONS(1820),
    [anon_sym_DASH_DASH] = ACTIONS(1820),
    [anon_sym_DQUOTE] = ACTIONS(1820),
    [anon_sym_SQUOTE] = ACTIONS(1820),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1820),
    [sym_number] = ACTIONS(1820),
    [sym_private_property_identifier] = ACTIONS(1820),
    [sym_this] = ACTIONS(1822),
    [sym_super] = ACTIONS(1822),
    [sym_true] = ACTIONS(1822),
    [sym_false] = ACTIONS(1822),
    [sym_null] = ACTIONS(1822),
    [sym_undefined] = ACTIONS(1822),
    [anon_sym_AT] = ACTIONS(1820),
    [anon_sym_static] = ACTIONS(1822),
    [anon_sym_readonly] = ACTIONS(1822),
    [anon_sym_get] = ACTIONS(1822),
    [anon_sym_set] = ACTIONS(1822),
    [anon_sym_declare] = ACTIONS(1822),
    [anon_sym_public] = ACTIONS(1822),
    [anon_sym_private] = ACTIONS(1822),
    [anon_sym_protected] = ACTIONS(1822),
    [anon_sym_override] = ACTIONS(1822),
    [anon_sym_module] = ACTIONS(1822),
    [anon_sym_any] = ACTIONS(1822),
    [anon_sym_number] = ACTIONS(1822),
    [anon_sym_boolean] = ACTIONS(1822),
    [anon_sym_string] = ACTIONS(1822),
    [anon_sym_symbol] = ACTIONS(1822),
    [anon_sym_object] = ACTIONS(1822),
    [anon_sym_abstract] = ACTIONS(1822),
    [anon_sym_interface] = ACTIONS(1822),
    [anon_sym_enum] = ACTIONS(1822),
    [sym__automatic_semicolon] = ACTIONS(1828),
    [sym_html_comment] = ACTIONS(5),
  },
  [798] = {
    [sym_statement_block] = STATE(882),
    [ts_builtin_sym_end] = ACTIONS(1674),
    [sym_identifier] = ACTIONS(1676),
    [anon_sym_export] = ACTIONS(1676),
    [anon_sym_default] = ACTIONS(1676),
    [anon_sym_type] = ACTIONS(1676),
    [anon_sym_namespace] = ACTIONS(1676),
    [anon_sym_LBRACE] = ACTIONS(2483),
    [anon_sym_RBRACE] = ACTIONS(1674),
    [anon_sym_typeof] = ACTIONS(1676),
    [anon_sym_import] = ACTIONS(1676),
    [anon_sym_with] = ACTIONS(1676),
    [anon_sym_var] = ACTIONS(1676),
    [anon_sym_let] = ACTIONS(1676),
    [anon_sym_const] = ACTIONS(1676),
    [anon_sym_BANG] = ACTIONS(1674),
    [anon_sym_else] = ACTIONS(1676),
    [anon_sym_if] = ACTIONS(1676),
    [anon_sym_switch] = ACTIONS(1676),
    [anon_sym_for] = ACTIONS(1676),
    [anon_sym_LPAREN] = ACTIONS(1674),
    [anon_sym_SEMI] = ACTIONS(1674),
    [anon_sym_await] = ACTIONS(1676),
    [anon_sym_while] = ACTIONS(1676),
    [anon_sym_do] = ACTIONS(1676),
    [anon_sym_try] = ACTIONS(1676),
    [anon_sym_break] = ACTIONS(1676),
    [anon_sym_continue] = ACTIONS(1676),
    [anon_sym_debugger] = ACTIONS(1676),
    [anon_sym_return] = ACTIONS(1676),
    [anon_sym_throw] = ACTIONS(1676),
    [anon_sym_case] = ACTIONS(1676),
    [anon_sym_yield] = ACTIONS(1676),
    [anon_sym_LBRACK] = ACTIONS(1674),
    [anon_sym_class] = ACTIONS(1676),
    [anon_sym_async] = ACTIONS(1676),
    [anon_sym_function] = ACTIONS(1676),
    [anon_sym_new] = ACTIONS(1676),
    [anon_sym_using] = ACTIONS(1676),
    [anon_sym_PLUS] = ACTIONS(1676),
    [anon_sym_DASH] = ACTIONS(1676),
    [anon_sym_SLASH] = ACTIONS(1676),
    [anon_sym_LT] = ACTIONS(1674),
    [anon_sym_TILDE] = ACTIONS(1674),
    [anon_sym_void] = ACTIONS(1676),
    [anon_sym_delete] = ACTIONS(1676),
    [anon_sym_PLUS_PLUS] = ACTIONS(1674),
    [anon_sym_DASH_DASH] = ACTIONS(1674),
    [anon_sym_DQUOTE] = ACTIONS(1674),
    [anon_sym_SQUOTE] = ACTIONS(1674),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1674),
    [sym_number] = ACTIONS(1674),
    [sym_private_property_identifier] = ACTIONS(1674),
    [sym_this] = ACTIONS(1676),
    [sym_super] = ACTIONS(1676),
    [sym_true] = ACTIONS(1676),
    [sym_false] = ACTIONS(1676),
    [sym_null] = ACTIONS(1676),
    [sym_undefined] = ACTIONS(1676),
    [anon_sym_AT] = ACTIONS(1674),
    [anon_sym_static] = ACTIONS(1676),
    [anon_sym_readonly] = ACTIONS(1676),
    [anon_sym_get] = ACTIONS(1676),
    [anon_sym_set] = ACTIONS(1676),
    [anon_sym_declare] = ACTIONS(1676),
    [anon_sym_public] = ACTIONS(1676),
    [anon_sym_private] = ACTIONS(1676),
    [anon_sym_protected] = ACTIONS(1676),
    [anon_sym_override] = ACTIONS(1676),
    [anon_sym_module] = ACTIONS(1676),
    [anon_sym_any] = ACTIONS(1676),
    [anon_sym_number] = ACTIONS(1676),
    [anon_sym_boolean] = ACTIONS(1676),
    [anon_sym_string] = ACTIONS(1676),
    [anon_sym_symbol] = ACTIONS(1676),
    [anon_sym_object] = ACTIONS(1676),
    [anon_sym_abstract] = ACTIONS(1676),
    [anon_sym_interface] = ACTIONS(1676),
    [anon_sym_enum] = ACTIONS(1676),
    [sym_html_comment] = ACTIONS(5),
  },
  [799] = {
    [ts_builtin_sym_end] = ACTIONS(1770),
    [sym_identifier] = ACTIONS(1772),
    [anon_sym_export] = ACTIONS(1772),
    [anon_sym_default] = ACTIONS(1772),
    [anon_sym_type] = ACTIONS(1772),
    [anon_sym_namespace] = ACTIONS(1772),
    [anon_sym_LBRACE] = ACTIONS(1770),
    [anon_sym_RBRACE] = ACTIONS(1770),
    [anon_sym_typeof] = ACTIONS(1772),
    [anon_sym_import] = ACTIONS(1772),
    [anon_sym_with] = ACTIONS(1772),
    [anon_sym_var] = ACTIONS(1772),
    [anon_sym_let] = ACTIONS(1772),
    [anon_sym_const] = ACTIONS(1772),
    [anon_sym_BANG] = ACTIONS(1770),
    [anon_sym_else] = ACTIONS(1772),
    [anon_sym_if] = ACTIONS(1772),
    [anon_sym_switch] = ACTIONS(1772),
    [anon_sym_for] = ACTIONS(1772),
    [anon_sym_LPAREN] = ACTIONS(1770),
    [anon_sym_SEMI] = ACTIONS(1770),
    [anon_sym_await] = ACTIONS(1772),
    [anon_sym_while] = ACTIONS(1772),
    [anon_sym_do] = ACTIONS(1772),
    [anon_sym_try] = ACTIONS(1772),
    [anon_sym_break] = ACTIONS(1772),
    [anon_sym_continue] = ACTIONS(1772),
    [anon_sym_debugger] = ACTIONS(1772),
    [anon_sym_return] = ACTIONS(1772),
    [anon_sym_throw] = ACTIONS(1772),
    [anon_sym_case] = ACTIONS(1772),
    [anon_sym_yield] = ACTIONS(1772),
    [anon_sym_LBRACK] = ACTIONS(1770),
    [anon_sym_class] = ACTIONS(1772),
    [anon_sym_async] = ACTIONS(1772),
    [anon_sym_function] = ACTIONS(1772),
    [anon_sym_new] = ACTIONS(1772),
    [anon_sym_using] = ACTIONS(1772),
    [anon_sym_PLUS] = ACTIONS(1772),
    [anon_sym_DASH] = ACTIONS(1772),
    [anon_sym_SLASH] = ACTIONS(1772),
    [anon_sym_LT] = ACTIONS(1770),
    [anon_sym_TILDE] = ACTIONS(1770),
    [anon_sym_void] = ACTIONS(1772),
    [anon_sym_delete] = ACTIONS(1772),
    [anon_sym_PLUS_PLUS] = ACTIONS(1770),
    [anon_sym_DASH_DASH] = ACTIONS(1770),
    [anon_sym_DQUOTE] = ACTIONS(1770),
    [anon_sym_SQUOTE] = ACTIONS(1770),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1770),
    [sym_number] = ACTIONS(1770),
    [sym_private_property_identifier] = ACTIONS(1770),
    [sym_this] = ACTIONS(1772),
    [sym_super] = ACTIONS(1772),
    [sym_true] = ACTIONS(1772),
    [sym_false] = ACTIONS(1772),
    [sym_null] = ACTIONS(1772),
    [sym_undefined] = ACTIONS(1772),
    [anon_sym_AT] = ACTIONS(1770),
    [anon_sym_static] = ACTIONS(1772),
    [anon_sym_readonly] = ACTIONS(1772),
    [anon_sym_get] = ACTIONS(1772),
    [anon_sym_set] = ACTIONS(1772),
    [anon_sym_declare] = ACTIONS(1772),
    [anon_sym_public] = ACTIONS(1772),
    [anon_sym_private] = ACTIONS(1772),
    [anon_sym_protected] = ACTIONS(1772),
    [anon_sym_override] = ACTIONS(1772),
    [anon_sym_module] = ACTIONS(1772),
    [anon_sym_any] = ACTIONS(1772),
    [anon_sym_number] = ACTIONS(1772),
    [anon_sym_boolean] = ACTIONS(1772),
    [anon_sym_string] = ACTIONS(1772),
    [anon_sym_symbol] = ACTIONS(1772),
    [anon_sym_object] = ACTIONS(1772),
    [anon_sym_abstract] = ACTIONS(1772),
    [anon_sym_interface] = ACTIONS(1772),
    [anon_sym_enum] = ACTIONS(1772),
    [sym__automatic_semicolon] = ACTIONS(1778),
    [sym_html_comment] = ACTIONS(5),
  },
  [800] = {
    [sym_import] = STATE(4681),
    [sym_nested_identifier] = STATE(5474),
    [sym_string] = STATE(2994),
    [sym_formal_parameters] = STATE(5619),
    [sym_rest_pattern] = STATE(5165),
    [sym_nested_type_identifier] = STATE(2939),
    [sym__type_query_member_expression_in_type_annotation] = STATE(3303),
    [sym__type_query_call_expression_in_type_annotation] = STATE(2938),
    [sym_type] = STATE(3773),
    [sym_tuple_parameter] = STATE(4956),
    [sym_optional_tuple_parameter] = STATE(4956),
    [sym_optional_type] = STATE(4956),
    [sym_rest_type] = STATE(4956),
    [sym__tuple_type_member] = STATE(4956),
    [sym_constructor_type] = STATE(3007),
    [sym_primary_type] = STATE(2981),
    [sym_template_literal_type] = STATE(3039),
    [sym_infer_type] = STATE(3007),
    [sym_conditional_type] = STATE(3039),
    [sym_generic_type] = STATE(3039),
    [sym_type_query] = STATE(3039),
    [sym_index_type_query] = STATE(3039),
    [sym_lookup_type] = STATE(3039),
    [sym_literal_type] = STATE(3039),
    [sym__number] = STATE(3041),
    [sym_existential_type] = STATE(3039),
    [sym_flow_maybe_type] = STATE(3039),
    [sym_parenthesized_type] = STATE(3039),
    [sym_predefined_type] = STATE(3039),
    [sym_object_type] = STATE(3039),
    [sym_type_parameters] = STATE(5454),
    [sym_array_type] = STATE(3039),
    [sym_tuple_type] = STATE(3039),
    [sym_readonly_type] = STATE(3007),
    [sym_union_type] = STATE(3039),
    [sym_intersection_type] = STATE(3039),
    [sym_function_type] = STATE(3007),
    [sym_identifier] = ACTIONS(2489),
    [anon_sym_STAR] = ACTIONS(543),
    [anon_sym_LBRACE] = ACTIONS(1534),
    [anon_sym_COMMA] = ACTIONS(2525),
    [anon_sym_typeof] = ACTIONS(1536),
    [anon_sym_import] = ACTIONS(1538),
    [anon_sym_const] = ACTIONS(133),
    [anon_sym_LPAREN] = ACTIONS(1540),
    [anon_sym_LBRACK] = ACTIONS(1542),
    [anon_sym_RBRACK] = ACTIONS(2527),
    [anon_sym_new] = ACTIONS(1642),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(2495),
    [anon_sym_AMP] = ACTIONS(571),
    [anon_sym_PIPE] = ACTIONS(573),
    [anon_sym_PLUS] = ACTIONS(2497),
    [anon_sym_DASH] = ACTIONS(2497),
    [anon_sym_LT] = ACTIONS(2499),
    [anon_sym_void] = ACTIONS(216),
    [anon_sym_DQUOTE] = ACTIONS(1550),
    [anon_sym_SQUOTE] = ACTIONS(1552),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1554),
    [sym_number] = ACTIONS(1556),
    [sym_this] = ACTIONS(1558),
    [sym_true] = ACTIONS(1560),
    [sym_false] = ACTIONS(1560),
    [sym_null] = ACTIONS(1560),
    [sym_undefined] = ACTIONS(1560),
    [anon_sym_readonly] = ACTIONS(1648),
    [anon_sym_QMARK] = ACTIONS(593),
    [anon_sym_any] = ACTIONS(216),
    [anon_sym_number] = ACTIONS(216),
    [anon_sym_boolean] = ACTIONS(216),
    [anon_sym_string] = ACTIONS(216),
    [anon_sym_symbol] = ACTIONS(216),
    [anon_sym_object] = ACTIONS(216),
    [anon_sym_abstract] = ACTIONS(597),
    [anon_sym_infer] = ACTIONS(599),
    [anon_sym_keyof] = ACTIONS(601),
    [anon_sym_unique] = ACTIONS(214),
    [anon_sym_unknown] = ACTIONS(216),
    [anon_sym_never] = ACTIONS(216),
    [anon_sym_LBRACE_PIPE] = ACTIONS(218),
    [sym_html_comment] = ACTIONS(5),
  },
  [801] = {
    [ts_builtin_sym_end] = ACTIONS(1856),
    [sym_identifier] = ACTIONS(1858),
    [anon_sym_export] = ACTIONS(1858),
    [anon_sym_default] = ACTIONS(1858),
    [anon_sym_type] = ACTIONS(1858),
    [anon_sym_namespace] = ACTIONS(1858),
    [anon_sym_LBRACE] = ACTIONS(1856),
    [anon_sym_RBRACE] = ACTIONS(1856),
    [anon_sym_typeof] = ACTIONS(1858),
    [anon_sym_import] = ACTIONS(1858),
    [anon_sym_with] = ACTIONS(1858),
    [anon_sym_var] = ACTIONS(1858),
    [anon_sym_let] = ACTIONS(1858),
    [anon_sym_const] = ACTIONS(1858),
    [anon_sym_BANG] = ACTIONS(1856),
    [anon_sym_else] = ACTIONS(1858),
    [anon_sym_if] = ACTIONS(1858),
    [anon_sym_switch] = ACTIONS(1858),
    [anon_sym_for] = ACTIONS(1858),
    [anon_sym_LPAREN] = ACTIONS(1856),
    [anon_sym_SEMI] = ACTIONS(1856),
    [anon_sym_await] = ACTIONS(1858),
    [anon_sym_while] = ACTIONS(1858),
    [anon_sym_do] = ACTIONS(1858),
    [anon_sym_try] = ACTIONS(1858),
    [anon_sym_break] = ACTIONS(1858),
    [anon_sym_continue] = ACTIONS(1858),
    [anon_sym_debugger] = ACTIONS(1858),
    [anon_sym_return] = ACTIONS(1858),
    [anon_sym_throw] = ACTIONS(1858),
    [anon_sym_case] = ACTIONS(1858),
    [anon_sym_yield] = ACTIONS(1858),
    [anon_sym_LBRACK] = ACTIONS(1856),
    [anon_sym_class] = ACTIONS(1858),
    [anon_sym_async] = ACTIONS(1858),
    [anon_sym_function] = ACTIONS(1858),
    [anon_sym_new] = ACTIONS(1858),
    [anon_sym_using] = ACTIONS(1858),
    [anon_sym_PLUS] = ACTIONS(1858),
    [anon_sym_DASH] = ACTIONS(1858),
    [anon_sym_SLASH] = ACTIONS(1858),
    [anon_sym_LT] = ACTIONS(1856),
    [anon_sym_TILDE] = ACTIONS(1856),
    [anon_sym_void] = ACTIONS(1858),
    [anon_sym_delete] = ACTIONS(1858),
    [anon_sym_PLUS_PLUS] = ACTIONS(1856),
    [anon_sym_DASH_DASH] = ACTIONS(1856),
    [anon_sym_DQUOTE] = ACTIONS(1856),
    [anon_sym_SQUOTE] = ACTIONS(1856),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1856),
    [sym_number] = ACTIONS(1856),
    [sym_private_property_identifier] = ACTIONS(1856),
    [sym_this] = ACTIONS(1858),
    [sym_super] = ACTIONS(1858),
    [sym_true] = ACTIONS(1858),
    [sym_false] = ACTIONS(1858),
    [sym_null] = ACTIONS(1858),
    [sym_undefined] = ACTIONS(1858),
    [anon_sym_AT] = ACTIONS(1856),
    [anon_sym_static] = ACTIONS(1858),
    [anon_sym_readonly] = ACTIONS(1858),
    [anon_sym_get] = ACTIONS(1858),
    [anon_sym_set] = ACTIONS(1858),
    [anon_sym_declare] = ACTIONS(1858),
    [anon_sym_public] = ACTIONS(1858),
    [anon_sym_private] = ACTIONS(1858),
    [anon_sym_protected] = ACTIONS(1858),
    [anon_sym_override] = ACTIONS(1858),
    [anon_sym_module] = ACTIONS(1858),
    [anon_sym_any] = ACTIONS(1858),
    [anon_sym_number] = ACTIONS(1858),
    [anon_sym_boolean] = ACTIONS(1858),
    [anon_sym_string] = ACTIONS(1858),
    [anon_sym_symbol] = ACTIONS(1858),
    [anon_sym_object] = ACTIONS(1858),
    [anon_sym_abstract] = ACTIONS(1858),
    [anon_sym_interface] = ACTIONS(1858),
    [anon_sym_enum] = ACTIONS(1858),
    [sym__automatic_semicolon] = ACTIONS(1864),
    [sym_html_comment] = ACTIONS(5),
  },
  [802] = {
    [ts_builtin_sym_end] = ACTIONS(1892),
    [sym_identifier] = ACTIONS(1894),
    [anon_sym_export] = ACTIONS(1894),
    [anon_sym_default] = ACTIONS(1894),
    [anon_sym_type] = ACTIONS(1894),
    [anon_sym_namespace] = ACTIONS(1894),
    [anon_sym_LBRACE] = ACTIONS(1892),
    [anon_sym_RBRACE] = ACTIONS(1892),
    [anon_sym_typeof] = ACTIONS(1894),
    [anon_sym_import] = ACTIONS(1894),
    [anon_sym_with] = ACTIONS(1894),
    [anon_sym_var] = ACTIONS(1894),
    [anon_sym_let] = ACTIONS(1894),
    [anon_sym_const] = ACTIONS(1894),
    [anon_sym_BANG] = ACTIONS(1892),
    [anon_sym_else] = ACTIONS(1894),
    [anon_sym_if] = ACTIONS(1894),
    [anon_sym_switch] = ACTIONS(1894),
    [anon_sym_for] = ACTIONS(1894),
    [anon_sym_LPAREN] = ACTIONS(1892),
    [anon_sym_SEMI] = ACTIONS(1892),
    [anon_sym_await] = ACTIONS(1894),
    [anon_sym_while] = ACTIONS(1894),
    [anon_sym_do] = ACTIONS(1894),
    [anon_sym_try] = ACTIONS(1894),
    [anon_sym_break] = ACTIONS(1894),
    [anon_sym_continue] = ACTIONS(1894),
    [anon_sym_debugger] = ACTIONS(1894),
    [anon_sym_return] = ACTIONS(1894),
    [anon_sym_throw] = ACTIONS(1894),
    [anon_sym_case] = ACTIONS(1894),
    [anon_sym_yield] = ACTIONS(1894),
    [anon_sym_LBRACK] = ACTIONS(1892),
    [anon_sym_DOT] = ACTIONS(1894),
    [anon_sym_class] = ACTIONS(1894),
    [anon_sym_async] = ACTIONS(1894),
    [anon_sym_function] = ACTIONS(1894),
    [anon_sym_new] = ACTIONS(1894),
    [anon_sym_using] = ACTIONS(1894),
    [anon_sym_PLUS] = ACTIONS(1894),
    [anon_sym_DASH] = ACTIONS(1894),
    [anon_sym_SLASH] = ACTIONS(1894),
    [anon_sym_LT] = ACTIONS(1892),
    [anon_sym_TILDE] = ACTIONS(1892),
    [anon_sym_void] = ACTIONS(1894),
    [anon_sym_delete] = ACTIONS(1894),
    [anon_sym_PLUS_PLUS] = ACTIONS(1892),
    [anon_sym_DASH_DASH] = ACTIONS(1892),
    [anon_sym_DQUOTE] = ACTIONS(1892),
    [anon_sym_SQUOTE] = ACTIONS(1892),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1892),
    [sym_number] = ACTIONS(1892),
    [sym_private_property_identifier] = ACTIONS(1892),
    [sym_this] = ACTIONS(1894),
    [sym_super] = ACTIONS(1894),
    [sym_true] = ACTIONS(1894),
    [sym_false] = ACTIONS(1894),
    [sym_null] = ACTIONS(1894),
    [sym_undefined] = ACTIONS(1894),
    [anon_sym_AT] = ACTIONS(1892),
    [anon_sym_static] = ACTIONS(1894),
    [anon_sym_readonly] = ACTIONS(1894),
    [anon_sym_get] = ACTIONS(1894),
    [anon_sym_set] = ACTIONS(1894),
    [anon_sym_declare] = ACTIONS(1894),
    [anon_sym_public] = ACTIONS(1894),
    [anon_sym_private] = ACTIONS(1894),
    [anon_sym_protected] = ACTIONS(1894),
    [anon_sym_override] = ACTIONS(1894),
    [anon_sym_module] = ACTIONS(1894),
    [anon_sym_any] = ACTIONS(1894),
    [anon_sym_number] = ACTIONS(1894),
    [anon_sym_boolean] = ACTIONS(1894),
    [anon_sym_string] = ACTIONS(1894),
    [anon_sym_symbol] = ACTIONS(1894),
    [anon_sym_object] = ACTIONS(1894),
    [anon_sym_abstract] = ACTIONS(1894),
    [anon_sym_interface] = ACTIONS(1894),
    [anon_sym_enum] = ACTIONS(1894),
    [sym_html_comment] = ACTIONS(5),
  },
  [803] = {
    [ts_builtin_sym_end] = ACTIONS(2529),
    [sym_identifier] = ACTIONS(2531),
    [anon_sym_export] = ACTIONS(2531),
    [anon_sym_default] = ACTIONS(2531),
    [anon_sym_type] = ACTIONS(2531),
    [anon_sym_namespace] = ACTIONS(2531),
    [anon_sym_LBRACE] = ACTIONS(2529),
    [anon_sym_RBRACE] = ACTIONS(2529),
    [anon_sym_typeof] = ACTIONS(2531),
    [anon_sym_import] = ACTIONS(2531),
    [anon_sym_with] = ACTIONS(2531),
    [anon_sym_var] = ACTIONS(2531),
    [anon_sym_let] = ACTIONS(2531),
    [anon_sym_const] = ACTIONS(2531),
    [anon_sym_BANG] = ACTIONS(2529),
    [anon_sym_else] = ACTIONS(2531),
    [anon_sym_if] = ACTIONS(2531),
    [anon_sym_switch] = ACTIONS(2531),
    [anon_sym_for] = ACTIONS(2531),
    [anon_sym_LPAREN] = ACTIONS(2529),
    [anon_sym_SEMI] = ACTIONS(2529),
    [anon_sym_await] = ACTIONS(2531),
    [anon_sym_while] = ACTIONS(2531),
    [anon_sym_do] = ACTIONS(2531),
    [anon_sym_try] = ACTIONS(2531),
    [anon_sym_break] = ACTIONS(2531),
    [anon_sym_continue] = ACTIONS(2531),
    [anon_sym_debugger] = ACTIONS(2531),
    [anon_sym_return] = ACTIONS(2531),
    [anon_sym_throw] = ACTIONS(2531),
    [anon_sym_case] = ACTIONS(2531),
    [anon_sym_yield] = ACTIONS(2531),
    [anon_sym_LBRACK] = ACTIONS(2529),
    [anon_sym_class] = ACTIONS(2531),
    [anon_sym_async] = ACTIONS(2531),
    [anon_sym_function] = ACTIONS(2531),
    [anon_sym_new] = ACTIONS(2531),
    [anon_sym_using] = ACTIONS(2531),
    [anon_sym_PLUS] = ACTIONS(2531),
    [anon_sym_DASH] = ACTIONS(2531),
    [anon_sym_SLASH] = ACTIONS(2531),
    [anon_sym_LT] = ACTIONS(2529),
    [anon_sym_TILDE] = ACTIONS(2529),
    [anon_sym_void] = ACTIONS(2531),
    [anon_sym_delete] = ACTIONS(2531),
    [anon_sym_PLUS_PLUS] = ACTIONS(2529),
    [anon_sym_DASH_DASH] = ACTIONS(2529),
    [anon_sym_DQUOTE] = ACTIONS(2529),
    [anon_sym_SQUOTE] = ACTIONS(2529),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(2529),
    [sym_number] = ACTIONS(2529),
    [sym_private_property_identifier] = ACTIONS(2529),
    [sym_this] = ACTIONS(2531),
    [sym_super] = ACTIONS(2531),
    [sym_true] = ACTIONS(2531),
    [sym_false] = ACTIONS(2531),
    [sym_null] = ACTIONS(2531),
    [sym_undefined] = ACTIONS(2531),
    [anon_sym_AT] = ACTIONS(2529),
    [anon_sym_static] = ACTIONS(2531),
    [anon_sym_readonly] = ACTIONS(2531),
    [anon_sym_get] = ACTIONS(2531),
    [anon_sym_set] = ACTIONS(2531),
    [anon_sym_declare] = ACTIONS(2531),
    [anon_sym_public] = ACTIONS(2531),
    [anon_sym_private] = ACTIONS(2531),
    [anon_sym_protected] = ACTIONS(2531),
    [anon_sym_override] = ACTIONS(2531),
    [anon_sym_module] = ACTIONS(2531),
    [anon_sym_any] = ACTIONS(2531),
    [anon_sym_number] = ACTIONS(2531),
    [anon_sym_boolean] = ACTIONS(2531),
    [anon_sym_string] = ACTIONS(2531),
    [anon_sym_symbol] = ACTIONS(2531),
    [anon_sym_object] = ACTIONS(2531),
    [anon_sym_abstract] = ACTIONS(2531),
    [anon_sym_interface] = ACTIONS(2531),
    [anon_sym_enum] = ACTIONS(2531),
    [sym__automatic_semicolon] = ACTIONS(2529),
    [sym_html_comment] = ACTIONS(5),
  },
  [804] = {
    [ts_builtin_sym_end] = ACTIONS(1790),
    [sym_identifier] = ACTIONS(1792),
    [anon_sym_export] = ACTIONS(1792),
    [anon_sym_default] = ACTIONS(1792),
    [anon_sym_type] = ACTIONS(1792),
    [anon_sym_namespace] = ACTIONS(1792),
    [anon_sym_LBRACE] = ACTIONS(1790),
    [anon_sym_RBRACE] = ACTIONS(1790),
    [anon_sym_typeof] = ACTIONS(1792),
    [anon_sym_import] = ACTIONS(1792),
    [anon_sym_with] = ACTIONS(1792),
    [anon_sym_var] = ACTIONS(1792),
    [anon_sym_let] = ACTIONS(1792),
    [anon_sym_const] = ACTIONS(1792),
    [anon_sym_BANG] = ACTIONS(1790),
    [anon_sym_else] = ACTIONS(1792),
    [anon_sym_if] = ACTIONS(1792),
    [anon_sym_switch] = ACTIONS(1792),
    [anon_sym_for] = ACTIONS(1792),
    [anon_sym_LPAREN] = ACTIONS(1790),
    [anon_sym_SEMI] = ACTIONS(1790),
    [anon_sym_await] = ACTIONS(1792),
    [anon_sym_while] = ACTIONS(1792),
    [anon_sym_do] = ACTIONS(1792),
    [anon_sym_try] = ACTIONS(1792),
    [anon_sym_break] = ACTIONS(1792),
    [anon_sym_continue] = ACTIONS(1792),
    [anon_sym_debugger] = ACTIONS(1792),
    [anon_sym_return] = ACTIONS(1792),
    [anon_sym_throw] = ACTIONS(1792),
    [anon_sym_case] = ACTIONS(1792),
    [anon_sym_yield] = ACTIONS(1792),
    [anon_sym_LBRACK] = ACTIONS(1790),
    [anon_sym_class] = ACTIONS(1792),
    [anon_sym_async] = ACTIONS(1792),
    [anon_sym_function] = ACTIONS(1792),
    [anon_sym_new] = ACTIONS(1792),
    [anon_sym_using] = ACTIONS(1792),
    [anon_sym_PLUS] = ACTIONS(1792),
    [anon_sym_DASH] = ACTIONS(1792),
    [anon_sym_SLASH] = ACTIONS(1792),
    [anon_sym_LT] = ACTIONS(1790),
    [anon_sym_TILDE] = ACTIONS(1790),
    [anon_sym_void] = ACTIONS(1792),
    [anon_sym_delete] = ACTIONS(1792),
    [anon_sym_PLUS_PLUS] = ACTIONS(1790),
    [anon_sym_DASH_DASH] = ACTIONS(1790),
    [anon_sym_DQUOTE] = ACTIONS(1790),
    [anon_sym_SQUOTE] = ACTIONS(1790),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1790),
    [sym_number] = ACTIONS(1790),
    [sym_private_property_identifier] = ACTIONS(1790),
    [sym_this] = ACTIONS(1792),
    [sym_super] = ACTIONS(1792),
    [sym_true] = ACTIONS(1792),
    [sym_false] = ACTIONS(1792),
    [sym_null] = ACTIONS(1792),
    [sym_undefined] = ACTIONS(1792),
    [anon_sym_AT] = ACTIONS(1790),
    [anon_sym_static] = ACTIONS(1792),
    [anon_sym_readonly] = ACTIONS(1792),
    [anon_sym_get] = ACTIONS(1792),
    [anon_sym_set] = ACTIONS(1792),
    [anon_sym_declare] = ACTIONS(1792),
    [anon_sym_public] = ACTIONS(1792),
    [anon_sym_private] = ACTIONS(1792),
    [anon_sym_protected] = ACTIONS(1792),
    [anon_sym_override] = ACTIONS(1792),
    [anon_sym_module] = ACTIONS(1792),
    [anon_sym_any] = ACTIONS(1792),
    [anon_sym_number] = ACTIONS(1792),
    [anon_sym_boolean] = ACTIONS(1792),
    [anon_sym_string] = ACTIONS(1792),
    [anon_sym_symbol] = ACTIONS(1792),
    [anon_sym_object] = ACTIONS(1792),
    [anon_sym_abstract] = ACTIONS(1792),
    [anon_sym_interface] = ACTIONS(1792),
    [anon_sym_enum] = ACTIONS(1792),
    [sym__automatic_semicolon] = ACTIONS(1798),
    [sym_html_comment] = ACTIONS(5),
  },
  [805] = {
    [sym_import] = STATE(4681),
    [sym_nested_identifier] = STATE(5474),
    [sym_string] = STATE(2994),
    [sym_formal_parameters] = STATE(5619),
    [sym_rest_pattern] = STATE(5165),
    [sym_nested_type_identifier] = STATE(2939),
    [sym__type_query_member_expression_in_type_annotation] = STATE(3303),
    [sym__type_query_call_expression_in_type_annotation] = STATE(2938),
    [sym_type] = STATE(3773),
    [sym_tuple_parameter] = STATE(4568),
    [sym_optional_tuple_parameter] = STATE(4568),
    [sym_optional_type] = STATE(4568),
    [sym_rest_type] = STATE(4568),
    [sym__tuple_type_member] = STATE(4568),
    [sym_constructor_type] = STATE(3007),
    [sym_primary_type] = STATE(2981),
    [sym_template_literal_type] = STATE(3039),
    [sym_infer_type] = STATE(3007),
    [sym_conditional_type] = STATE(3039),
    [sym_generic_type] = STATE(3039),
    [sym_type_query] = STATE(3039),
    [sym_index_type_query] = STATE(3039),
    [sym_lookup_type] = STATE(3039),
    [sym_literal_type] = STATE(3039),
    [sym__number] = STATE(3041),
    [sym_existential_type] = STATE(3039),
    [sym_flow_maybe_type] = STATE(3039),
    [sym_parenthesized_type] = STATE(3039),
    [sym_predefined_type] = STATE(3039),
    [sym_object_type] = STATE(3039),
    [sym_type_parameters] = STATE(5454),
    [sym_array_type] = STATE(3039),
    [sym_tuple_type] = STATE(3039),
    [sym_readonly_type] = STATE(3007),
    [sym_union_type] = STATE(3039),
    [sym_intersection_type] = STATE(3039),
    [sym_function_type] = STATE(3007),
    [sym_identifier] = ACTIONS(2489),
    [anon_sym_STAR] = ACTIONS(543),
    [anon_sym_LBRACE] = ACTIONS(1534),
    [anon_sym_COMMA] = ACTIONS(2533),
    [anon_sym_typeof] = ACTIONS(1536),
    [anon_sym_import] = ACTIONS(1538),
    [anon_sym_const] = ACTIONS(133),
    [anon_sym_LPAREN] = ACTIONS(1540),
    [anon_sym_LBRACK] = ACTIONS(1542),
    [anon_sym_RBRACK] = ACTIONS(2535),
    [anon_sym_new] = ACTIONS(1642),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(2495),
    [anon_sym_AMP] = ACTIONS(571),
    [anon_sym_PIPE] = ACTIONS(573),
    [anon_sym_PLUS] = ACTIONS(2497),
    [anon_sym_DASH] = ACTIONS(2497),
    [anon_sym_LT] = ACTIONS(2499),
    [anon_sym_void] = ACTIONS(216),
    [anon_sym_DQUOTE] = ACTIONS(1550),
    [anon_sym_SQUOTE] = ACTIONS(1552),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1554),
    [sym_number] = ACTIONS(1556),
    [sym_this] = ACTIONS(1558),
    [sym_true] = ACTIONS(1560),
    [sym_false] = ACTIONS(1560),
    [sym_null] = ACTIONS(1560),
    [sym_undefined] = ACTIONS(1560),
    [anon_sym_readonly] = ACTIONS(1648),
    [anon_sym_QMARK] = ACTIONS(593),
    [anon_sym_any] = ACTIONS(216),
    [anon_sym_number] = ACTIONS(216),
    [anon_sym_boolean] = ACTIONS(216),
    [anon_sym_string] = ACTIONS(216),
    [anon_sym_symbol] = ACTIONS(216),
    [anon_sym_object] = ACTIONS(216),
    [anon_sym_abstract] = ACTIONS(597),
    [anon_sym_infer] = ACTIONS(599),
    [anon_sym_keyof] = ACTIONS(601),
    [anon_sym_unique] = ACTIONS(214),
    [anon_sym_unknown] = ACTIONS(216),
    [anon_sym_never] = ACTIONS(216),
    [anon_sym_LBRACE_PIPE] = ACTIONS(218),
    [sym_html_comment] = ACTIONS(5),
  },
  [806] = {
    [ts_builtin_sym_end] = ACTIONS(1866),
    [sym_identifier] = ACTIONS(1868),
    [anon_sym_export] = ACTIONS(1868),
    [anon_sym_default] = ACTIONS(1868),
    [anon_sym_type] = ACTIONS(1868),
    [anon_sym_namespace] = ACTIONS(1868),
    [anon_sym_LBRACE] = ACTIONS(1866),
    [anon_sym_RBRACE] = ACTIONS(1866),
    [anon_sym_typeof] = ACTIONS(1868),
    [anon_sym_import] = ACTIONS(1868),
    [anon_sym_with] = ACTIONS(1868),
    [anon_sym_var] = ACTIONS(1868),
    [anon_sym_let] = ACTIONS(1868),
    [anon_sym_const] = ACTIONS(1868),
    [anon_sym_BANG] = ACTIONS(1866),
    [anon_sym_else] = ACTIONS(1868),
    [anon_sym_if] = ACTIONS(1868),
    [anon_sym_switch] = ACTIONS(1868),
    [anon_sym_for] = ACTIONS(1868),
    [anon_sym_LPAREN] = ACTIONS(1866),
    [anon_sym_SEMI] = ACTIONS(1866),
    [anon_sym_await] = ACTIONS(1868),
    [anon_sym_while] = ACTIONS(1868),
    [anon_sym_do] = ACTIONS(1868),
    [anon_sym_try] = ACTIONS(1868),
    [anon_sym_break] = ACTIONS(1868),
    [anon_sym_continue] = ACTIONS(1868),
    [anon_sym_debugger] = ACTIONS(1868),
    [anon_sym_return] = ACTIONS(1868),
    [anon_sym_throw] = ACTIONS(1868),
    [anon_sym_case] = ACTIONS(1868),
    [anon_sym_yield] = ACTIONS(1868),
    [anon_sym_LBRACK] = ACTIONS(1866),
    [anon_sym_class] = ACTIONS(1868),
    [anon_sym_async] = ACTIONS(1868),
    [anon_sym_function] = ACTIONS(1868),
    [anon_sym_new] = ACTIONS(1868),
    [anon_sym_using] = ACTIONS(1868),
    [anon_sym_PLUS] = ACTIONS(1868),
    [anon_sym_DASH] = ACTIONS(1868),
    [anon_sym_SLASH] = ACTIONS(1868),
    [anon_sym_LT] = ACTIONS(1866),
    [anon_sym_TILDE] = ACTIONS(1866),
    [anon_sym_void] = ACTIONS(1868),
    [anon_sym_delete] = ACTIONS(1868),
    [anon_sym_PLUS_PLUS] = ACTIONS(1866),
    [anon_sym_DASH_DASH] = ACTIONS(1866),
    [anon_sym_DQUOTE] = ACTIONS(1866),
    [anon_sym_SQUOTE] = ACTIONS(1866),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1866),
    [sym_number] = ACTIONS(1866),
    [sym_private_property_identifier] = ACTIONS(1866),
    [sym_this] = ACTIONS(1868),
    [sym_super] = ACTIONS(1868),
    [sym_true] = ACTIONS(1868),
    [sym_false] = ACTIONS(1868),
    [sym_null] = ACTIONS(1868),
    [sym_undefined] = ACTIONS(1868),
    [anon_sym_AT] = ACTIONS(1866),
    [anon_sym_static] = ACTIONS(1868),
    [anon_sym_readonly] = ACTIONS(1868),
    [anon_sym_get] = ACTIONS(1868),
    [anon_sym_set] = ACTIONS(1868),
    [anon_sym_declare] = ACTIONS(1868),
    [anon_sym_public] = ACTIONS(1868),
    [anon_sym_private] = ACTIONS(1868),
    [anon_sym_protected] = ACTIONS(1868),
    [anon_sym_override] = ACTIONS(1868),
    [anon_sym_module] = ACTIONS(1868),
    [anon_sym_any] = ACTIONS(1868),
    [anon_sym_number] = ACTIONS(1868),
    [anon_sym_boolean] = ACTIONS(1868),
    [anon_sym_string] = ACTIONS(1868),
    [anon_sym_symbol] = ACTIONS(1868),
    [anon_sym_object] = ACTIONS(1868),
    [anon_sym_abstract] = ACTIONS(1868),
    [anon_sym_interface] = ACTIONS(1868),
    [anon_sym_enum] = ACTIONS(1868),
    [sym__automatic_semicolon] = ACTIONS(1874),
    [sym_html_comment] = ACTIONS(5),
  },
  [807] = {
    [ts_builtin_sym_end] = ACTIONS(2537),
    [sym_identifier] = ACTIONS(2539),
    [anon_sym_export] = ACTIONS(2539),
    [anon_sym_default] = ACTIONS(2539),
    [anon_sym_type] = ACTIONS(2539),
    [anon_sym_namespace] = ACTIONS(2539),
    [anon_sym_LBRACE] = ACTIONS(2537),
    [anon_sym_RBRACE] = ACTIONS(2537),
    [anon_sym_typeof] = ACTIONS(2539),
    [anon_sym_import] = ACTIONS(2539),
    [anon_sym_with] = ACTIONS(2539),
    [anon_sym_var] = ACTIONS(2539),
    [anon_sym_let] = ACTIONS(2539),
    [anon_sym_const] = ACTIONS(2539),
    [anon_sym_BANG] = ACTIONS(2537),
    [anon_sym_else] = ACTIONS(2539),
    [anon_sym_if] = ACTIONS(2539),
    [anon_sym_switch] = ACTIONS(2539),
    [anon_sym_for] = ACTIONS(2539),
    [anon_sym_LPAREN] = ACTIONS(2537),
    [anon_sym_SEMI] = ACTIONS(2537),
    [anon_sym_await] = ACTIONS(2539),
    [anon_sym_while] = ACTIONS(2539),
    [anon_sym_do] = ACTIONS(2539),
    [anon_sym_try] = ACTIONS(2539),
    [anon_sym_break] = ACTIONS(2539),
    [anon_sym_continue] = ACTIONS(2539),
    [anon_sym_debugger] = ACTIONS(2539),
    [anon_sym_return] = ACTIONS(2539),
    [anon_sym_throw] = ACTIONS(2539),
    [anon_sym_case] = ACTIONS(2539),
    [anon_sym_finally] = ACTIONS(2539),
    [anon_sym_yield] = ACTIONS(2539),
    [anon_sym_LBRACK] = ACTIONS(2537),
    [anon_sym_class] = ACTIONS(2539),
    [anon_sym_async] = ACTIONS(2539),
    [anon_sym_function] = ACTIONS(2539),
    [anon_sym_new] = ACTIONS(2539),
    [anon_sym_using] = ACTIONS(2539),
    [anon_sym_PLUS] = ACTIONS(2539),
    [anon_sym_DASH] = ACTIONS(2539),
    [anon_sym_SLASH] = ACTIONS(2539),
    [anon_sym_LT] = ACTIONS(2537),
    [anon_sym_TILDE] = ACTIONS(2537),
    [anon_sym_void] = ACTIONS(2539),
    [anon_sym_delete] = ACTIONS(2539),
    [anon_sym_PLUS_PLUS] = ACTIONS(2537),
    [anon_sym_DASH_DASH] = ACTIONS(2537),
    [anon_sym_DQUOTE] = ACTIONS(2537),
    [anon_sym_SQUOTE] = ACTIONS(2537),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(2537),
    [sym_number] = ACTIONS(2537),
    [sym_private_property_identifier] = ACTIONS(2537),
    [sym_this] = ACTIONS(2539),
    [sym_super] = ACTIONS(2539),
    [sym_true] = ACTIONS(2539),
    [sym_false] = ACTIONS(2539),
    [sym_null] = ACTIONS(2539),
    [sym_undefined] = ACTIONS(2539),
    [anon_sym_AT] = ACTIONS(2537),
    [anon_sym_static] = ACTIONS(2539),
    [anon_sym_readonly] = ACTIONS(2539),
    [anon_sym_get] = ACTIONS(2539),
    [anon_sym_set] = ACTIONS(2539),
    [anon_sym_declare] = ACTIONS(2539),
    [anon_sym_public] = ACTIONS(2539),
    [anon_sym_private] = ACTIONS(2539),
    [anon_sym_protected] = ACTIONS(2539),
    [anon_sym_override] = ACTIONS(2539),
    [anon_sym_module] = ACTIONS(2539),
    [anon_sym_any] = ACTIONS(2539),
    [anon_sym_number] = ACTIONS(2539),
    [anon_sym_boolean] = ACTIONS(2539),
    [anon_sym_string] = ACTIONS(2539),
    [anon_sym_symbol] = ACTIONS(2539),
    [anon_sym_object] = ACTIONS(2539),
    [anon_sym_abstract] = ACTIONS(2539),
    [anon_sym_interface] = ACTIONS(2539),
    [anon_sym_enum] = ACTIONS(2539),
    [sym_html_comment] = ACTIONS(5),
  },
  [808] = {
    [ts_builtin_sym_end] = ACTIONS(2541),
    [sym_identifier] = ACTIONS(2543),
    [anon_sym_export] = ACTIONS(2543),
    [anon_sym_default] = ACTIONS(2543),
    [anon_sym_type] = ACTIONS(2543),
    [anon_sym_namespace] = ACTIONS(2543),
    [anon_sym_LBRACE] = ACTIONS(2541),
    [anon_sym_RBRACE] = ACTIONS(2541),
    [anon_sym_typeof] = ACTIONS(2543),
    [anon_sym_import] = ACTIONS(2543),
    [anon_sym_with] = ACTIONS(2543),
    [anon_sym_var] = ACTIONS(2543),
    [anon_sym_let] = ACTIONS(2543),
    [anon_sym_const] = ACTIONS(2543),
    [anon_sym_BANG] = ACTIONS(2541),
    [anon_sym_else] = ACTIONS(2543),
    [anon_sym_if] = ACTIONS(2543),
    [anon_sym_switch] = ACTIONS(2543),
    [anon_sym_for] = ACTIONS(2543),
    [anon_sym_LPAREN] = ACTIONS(2541),
    [anon_sym_SEMI] = ACTIONS(2541),
    [anon_sym_await] = ACTIONS(2543),
    [anon_sym_while] = ACTIONS(2543),
    [anon_sym_do] = ACTIONS(2543),
    [anon_sym_try] = ACTIONS(2543),
    [anon_sym_break] = ACTIONS(2543),
    [anon_sym_continue] = ACTIONS(2543),
    [anon_sym_debugger] = ACTIONS(2543),
    [anon_sym_return] = ACTIONS(2543),
    [anon_sym_throw] = ACTIONS(2543),
    [anon_sym_case] = ACTIONS(2543),
    [anon_sym_finally] = ACTIONS(2543),
    [anon_sym_yield] = ACTIONS(2543),
    [anon_sym_LBRACK] = ACTIONS(2541),
    [anon_sym_class] = ACTIONS(2543),
    [anon_sym_async] = ACTIONS(2543),
    [anon_sym_function] = ACTIONS(2543),
    [anon_sym_new] = ACTIONS(2543),
    [anon_sym_using] = ACTIONS(2543),
    [anon_sym_PLUS] = ACTIONS(2543),
    [anon_sym_DASH] = ACTIONS(2543),
    [anon_sym_SLASH] = ACTIONS(2543),
    [anon_sym_LT] = ACTIONS(2541),
    [anon_sym_TILDE] = ACTIONS(2541),
    [anon_sym_void] = ACTIONS(2543),
    [anon_sym_delete] = ACTIONS(2543),
    [anon_sym_PLUS_PLUS] = ACTIONS(2541),
    [anon_sym_DASH_DASH] = ACTIONS(2541),
    [anon_sym_DQUOTE] = ACTIONS(2541),
    [anon_sym_SQUOTE] = ACTIONS(2541),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(2541),
    [sym_number] = ACTIONS(2541),
    [sym_private_property_identifier] = ACTIONS(2541),
    [sym_this] = ACTIONS(2543),
    [sym_super] = ACTIONS(2543),
    [sym_true] = ACTIONS(2543),
    [sym_false] = ACTIONS(2543),
    [sym_null] = ACTIONS(2543),
    [sym_undefined] = ACTIONS(2543),
    [anon_sym_AT] = ACTIONS(2541),
    [anon_sym_static] = ACTIONS(2543),
    [anon_sym_readonly] = ACTIONS(2543),
    [anon_sym_get] = ACTIONS(2543),
    [anon_sym_set] = ACTIONS(2543),
    [anon_sym_declare] = ACTIONS(2543),
    [anon_sym_public] = ACTIONS(2543),
    [anon_sym_private] = ACTIONS(2543),
    [anon_sym_protected] = ACTIONS(2543),
    [anon_sym_override] = ACTIONS(2543),
    [anon_sym_module] = ACTIONS(2543),
    [anon_sym_any] = ACTIONS(2543),
    [anon_sym_number] = ACTIONS(2543),
    [anon_sym_boolean] = ACTIONS(2543),
    [anon_sym_string] = ACTIONS(2543),
    [anon_sym_symbol] = ACTIONS(2543),
    [anon_sym_object] = ACTIONS(2543),
    [anon_sym_abstract] = ACTIONS(2543),
    [anon_sym_interface] = ACTIONS(2543),
    [anon_sym_enum] = ACTIONS(2543),
    [sym_html_comment] = ACTIONS(5),
  },
  [809] = {
    [ts_builtin_sym_end] = ACTIONS(2545),
    [sym_identifier] = ACTIONS(2547),
    [anon_sym_export] = ACTIONS(2547),
    [anon_sym_default] = ACTIONS(2547),
    [anon_sym_type] = ACTIONS(2547),
    [anon_sym_namespace] = ACTIONS(2547),
    [anon_sym_LBRACE] = ACTIONS(2545),
    [anon_sym_RBRACE] = ACTIONS(2545),
    [anon_sym_typeof] = ACTIONS(2547),
    [anon_sym_import] = ACTIONS(2547),
    [anon_sym_with] = ACTIONS(2547),
    [anon_sym_var] = ACTIONS(2547),
    [anon_sym_let] = ACTIONS(2547),
    [anon_sym_const] = ACTIONS(2547),
    [anon_sym_BANG] = ACTIONS(2545),
    [anon_sym_else] = ACTIONS(2547),
    [anon_sym_if] = ACTIONS(2547),
    [anon_sym_switch] = ACTIONS(2547),
    [anon_sym_for] = ACTIONS(2547),
    [anon_sym_LPAREN] = ACTIONS(2545),
    [anon_sym_SEMI] = ACTIONS(2545),
    [anon_sym_await] = ACTIONS(2547),
    [anon_sym_while] = ACTIONS(2547),
    [anon_sym_do] = ACTIONS(2547),
    [anon_sym_try] = ACTIONS(2547),
    [anon_sym_break] = ACTIONS(2547),
    [anon_sym_continue] = ACTIONS(2547),
    [anon_sym_debugger] = ACTIONS(2547),
    [anon_sym_return] = ACTIONS(2547),
    [anon_sym_throw] = ACTIONS(2547),
    [anon_sym_case] = ACTIONS(2547),
    [anon_sym_finally] = ACTIONS(2547),
    [anon_sym_yield] = ACTIONS(2547),
    [anon_sym_LBRACK] = ACTIONS(2545),
    [anon_sym_class] = ACTIONS(2547),
    [anon_sym_async] = ACTIONS(2547),
    [anon_sym_function] = ACTIONS(2547),
    [anon_sym_new] = ACTIONS(2547),
    [anon_sym_using] = ACTIONS(2547),
    [anon_sym_PLUS] = ACTIONS(2547),
    [anon_sym_DASH] = ACTIONS(2547),
    [anon_sym_SLASH] = ACTIONS(2547),
    [anon_sym_LT] = ACTIONS(2545),
    [anon_sym_TILDE] = ACTIONS(2545),
    [anon_sym_void] = ACTIONS(2547),
    [anon_sym_delete] = ACTIONS(2547),
    [anon_sym_PLUS_PLUS] = ACTIONS(2545),
    [anon_sym_DASH_DASH] = ACTIONS(2545),
    [anon_sym_DQUOTE] = ACTIONS(2545),
    [anon_sym_SQUOTE] = ACTIONS(2545),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(2545),
    [sym_number] = ACTIONS(2545),
    [sym_private_property_identifier] = ACTIONS(2545),
    [sym_this] = ACTIONS(2547),
    [sym_super] = ACTIONS(2547),
    [sym_true] = ACTIONS(2547),
    [sym_false] = ACTIONS(2547),
    [sym_null] = ACTIONS(2547),
    [sym_undefined] = ACTIONS(2547),
    [anon_sym_AT] = ACTIONS(2545),
    [anon_sym_static] = ACTIONS(2547),
    [anon_sym_readonly] = ACTIONS(2547),
    [anon_sym_get] = ACTIONS(2547),
    [anon_sym_set] = ACTIONS(2547),
    [anon_sym_declare] = ACTIONS(2547),
    [anon_sym_public] = ACTIONS(2547),
    [anon_sym_private] = ACTIONS(2547),
    [anon_sym_protected] = ACTIONS(2547),
    [anon_sym_override] = ACTIONS(2547),
    [anon_sym_module] = ACTIONS(2547),
    [anon_sym_any] = ACTIONS(2547),
    [anon_sym_number] = ACTIONS(2547),
    [anon_sym_boolean] = ACTIONS(2547),
    [anon_sym_string] = ACTIONS(2547),
    [anon_sym_symbol] = ACTIONS(2547),
    [anon_sym_object] = ACTIONS(2547),
    [anon_sym_abstract] = ACTIONS(2547),
    [anon_sym_interface] = ACTIONS(2547),
    [anon_sym_enum] = ACTIONS(2547),
    [sym_html_comment] = ACTIONS(5),
  },
  [810] = {
    [ts_builtin_sym_end] = ACTIONS(2549),
    [sym_identifier] = ACTIONS(2551),
    [anon_sym_export] = ACTIONS(2551),
    [anon_sym_default] = ACTIONS(2551),
    [anon_sym_type] = ACTIONS(2551),
    [anon_sym_namespace] = ACTIONS(2551),
    [anon_sym_LBRACE] = ACTIONS(2549),
    [anon_sym_RBRACE] = ACTIONS(2549),
    [anon_sym_typeof] = ACTIONS(2551),
    [anon_sym_import] = ACTIONS(2551),
    [anon_sym_with] = ACTIONS(2551),
    [anon_sym_var] = ACTIONS(2551),
    [anon_sym_let] = ACTIONS(2551),
    [anon_sym_const] = ACTIONS(2551),
    [anon_sym_BANG] = ACTIONS(2549),
    [anon_sym_else] = ACTIONS(2551),
    [anon_sym_if] = ACTIONS(2551),
    [anon_sym_switch] = ACTIONS(2551),
    [anon_sym_for] = ACTIONS(2551),
    [anon_sym_LPAREN] = ACTIONS(2549),
    [anon_sym_SEMI] = ACTIONS(2549),
    [anon_sym_RPAREN] = ACTIONS(2549),
    [anon_sym_await] = ACTIONS(2551),
    [anon_sym_while] = ACTIONS(2551),
    [anon_sym_do] = ACTIONS(2551),
    [anon_sym_try] = ACTIONS(2551),
    [anon_sym_break] = ACTIONS(2551),
    [anon_sym_continue] = ACTIONS(2551),
    [anon_sym_debugger] = ACTIONS(2551),
    [anon_sym_return] = ACTIONS(2551),
    [anon_sym_throw] = ACTIONS(2551),
    [anon_sym_case] = ACTIONS(2551),
    [anon_sym_yield] = ACTIONS(2551),
    [anon_sym_LBRACK] = ACTIONS(2549),
    [anon_sym_class] = ACTIONS(2551),
    [anon_sym_async] = ACTIONS(2551),
    [anon_sym_function] = ACTIONS(2551),
    [anon_sym_new] = ACTIONS(2551),
    [anon_sym_using] = ACTIONS(2551),
    [anon_sym_PLUS] = ACTIONS(2551),
    [anon_sym_DASH] = ACTIONS(2551),
    [anon_sym_SLASH] = ACTIONS(2551),
    [anon_sym_LT] = ACTIONS(2549),
    [anon_sym_TILDE] = ACTIONS(2549),
    [anon_sym_void] = ACTIONS(2551),
    [anon_sym_delete] = ACTIONS(2551),
    [anon_sym_PLUS_PLUS] = ACTIONS(2549),
    [anon_sym_DASH_DASH] = ACTIONS(2549),
    [anon_sym_DQUOTE] = ACTIONS(2549),
    [anon_sym_SQUOTE] = ACTIONS(2549),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(2549),
    [sym_number] = ACTIONS(2549),
    [sym_private_property_identifier] = ACTIONS(2549),
    [sym_this] = ACTIONS(2551),
    [sym_super] = ACTIONS(2551),
    [sym_true] = ACTIONS(2551),
    [sym_false] = ACTIONS(2551),
    [sym_null] = ACTIONS(2551),
    [sym_undefined] = ACTIONS(2551),
    [anon_sym_AT] = ACTIONS(2549),
    [anon_sym_static] = ACTIONS(2551),
    [anon_sym_readonly] = ACTIONS(2551),
    [anon_sym_get] = ACTIONS(2551),
    [anon_sym_set] = ACTIONS(2551),
    [anon_sym_declare] = ACTIONS(2551),
    [anon_sym_public] = ACTIONS(2551),
    [anon_sym_private] = ACTIONS(2551),
    [anon_sym_protected] = ACTIONS(2551),
    [anon_sym_override] = ACTIONS(2551),
    [anon_sym_module] = ACTIONS(2551),
    [anon_sym_any] = ACTIONS(2551),
    [anon_sym_number] = ACTIONS(2551),
    [anon_sym_boolean] = ACTIONS(2551),
    [anon_sym_string] = ACTIONS(2551),
    [anon_sym_symbol] = ACTIONS(2551),
    [anon_sym_object] = ACTIONS(2551),
    [anon_sym_abstract] = ACTIONS(2551),
    [anon_sym_interface] = ACTIONS(2551),
    [anon_sym_enum] = ACTIONS(2551),
    [sym_html_comment] = ACTIONS(5),
  },
  [811] = {
    [ts_builtin_sym_end] = ACTIONS(1800),
    [sym_identifier] = ACTIONS(1802),
    [anon_sym_export] = ACTIONS(1802),
    [anon_sym_default] = ACTIONS(1802),
    [anon_sym_type] = ACTIONS(1802),
    [anon_sym_namespace] = ACTIONS(1802),
    [anon_sym_LBRACE] = ACTIONS(1800),
    [anon_sym_RBRACE] = ACTIONS(1800),
    [anon_sym_typeof] = ACTIONS(1802),
    [anon_sym_import] = ACTIONS(1802),
    [anon_sym_with] = ACTIONS(1802),
    [anon_sym_var] = ACTIONS(1802),
    [anon_sym_let] = ACTIONS(1802),
    [anon_sym_const] = ACTIONS(1802),
    [anon_sym_BANG] = ACTIONS(1800),
    [anon_sym_else] = ACTIONS(1802),
    [anon_sym_if] = ACTIONS(1802),
    [anon_sym_switch] = ACTIONS(1802),
    [anon_sym_for] = ACTIONS(1802),
    [anon_sym_LPAREN] = ACTIONS(1800),
    [anon_sym_SEMI] = ACTIONS(1800),
    [anon_sym_await] = ACTIONS(1802),
    [anon_sym_while] = ACTIONS(1802),
    [anon_sym_do] = ACTIONS(1802),
    [anon_sym_try] = ACTIONS(1802),
    [anon_sym_break] = ACTIONS(1802),
    [anon_sym_continue] = ACTIONS(1802),
    [anon_sym_debugger] = ACTIONS(1802),
    [anon_sym_return] = ACTIONS(1802),
    [anon_sym_throw] = ACTIONS(1802),
    [anon_sym_case] = ACTIONS(1802),
    [anon_sym_yield] = ACTIONS(1802),
    [anon_sym_LBRACK] = ACTIONS(1800),
    [anon_sym_class] = ACTIONS(1802),
    [anon_sym_async] = ACTIONS(1802),
    [anon_sym_function] = ACTIONS(1802),
    [anon_sym_new] = ACTIONS(1802),
    [anon_sym_using] = ACTIONS(1802),
    [anon_sym_PLUS] = ACTIONS(1802),
    [anon_sym_DASH] = ACTIONS(1802),
    [anon_sym_SLASH] = ACTIONS(1802),
    [anon_sym_LT] = ACTIONS(1800),
    [anon_sym_TILDE] = ACTIONS(1800),
    [anon_sym_void] = ACTIONS(1802),
    [anon_sym_delete] = ACTIONS(1802),
    [anon_sym_PLUS_PLUS] = ACTIONS(1800),
    [anon_sym_DASH_DASH] = ACTIONS(1800),
    [anon_sym_DQUOTE] = ACTIONS(1800),
    [anon_sym_SQUOTE] = ACTIONS(1800),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1800),
    [sym_number] = ACTIONS(1800),
    [sym_private_property_identifier] = ACTIONS(1800),
    [sym_this] = ACTIONS(1802),
    [sym_super] = ACTIONS(1802),
    [sym_true] = ACTIONS(1802),
    [sym_false] = ACTIONS(1802),
    [sym_null] = ACTIONS(1802),
    [sym_undefined] = ACTIONS(1802),
    [anon_sym_AT] = ACTIONS(1800),
    [anon_sym_static] = ACTIONS(1802),
    [anon_sym_readonly] = ACTIONS(1802),
    [anon_sym_get] = ACTIONS(1802),
    [anon_sym_set] = ACTIONS(1802),
    [anon_sym_declare] = ACTIONS(1802),
    [anon_sym_public] = ACTIONS(1802),
    [anon_sym_private] = ACTIONS(1802),
    [anon_sym_protected] = ACTIONS(1802),
    [anon_sym_override] = ACTIONS(1802),
    [anon_sym_module] = ACTIONS(1802),
    [anon_sym_any] = ACTIONS(1802),
    [anon_sym_number] = ACTIONS(1802),
    [anon_sym_boolean] = ACTIONS(1802),
    [anon_sym_string] = ACTIONS(1802),
    [anon_sym_symbol] = ACTIONS(1802),
    [anon_sym_object] = ACTIONS(1802),
    [anon_sym_abstract] = ACTIONS(1802),
    [anon_sym_interface] = ACTIONS(1802),
    [anon_sym_enum] = ACTIONS(1802),
    [sym__automatic_semicolon] = ACTIONS(1808),
    [sym_html_comment] = ACTIONS(5),
  },
  [812] = {
    [ts_builtin_sym_end] = ACTIONS(2553),
    [sym_identifier] = ACTIONS(2555),
    [anon_sym_export] = ACTIONS(2555),
    [anon_sym_default] = ACTIONS(2555),
    [anon_sym_type] = ACTIONS(2555),
    [anon_sym_namespace] = ACTIONS(2555),
    [anon_sym_LBRACE] = ACTIONS(2553),
    [anon_sym_RBRACE] = ACTIONS(2553),
    [anon_sym_typeof] = ACTIONS(2555),
    [anon_sym_import] = ACTIONS(2555),
    [anon_sym_with] = ACTIONS(2555),
    [anon_sym_var] = ACTIONS(2555),
    [anon_sym_let] = ACTIONS(2555),
    [anon_sym_const] = ACTIONS(2555),
    [anon_sym_BANG] = ACTIONS(2553),
    [anon_sym_else] = ACTIONS(2555),
    [anon_sym_if] = ACTIONS(2555),
    [anon_sym_switch] = ACTIONS(2555),
    [anon_sym_for] = ACTIONS(2555),
    [anon_sym_LPAREN] = ACTIONS(2553),
    [anon_sym_SEMI] = ACTIONS(2553),
    [anon_sym_await] = ACTIONS(2555),
    [anon_sym_while] = ACTIONS(2555),
    [anon_sym_do] = ACTIONS(2555),
    [anon_sym_try] = ACTIONS(2555),
    [anon_sym_break] = ACTIONS(2555),
    [anon_sym_continue] = ACTIONS(2555),
    [anon_sym_debugger] = ACTIONS(2555),
    [anon_sym_return] = ACTIONS(2555),
    [anon_sym_throw] = ACTIONS(2555),
    [anon_sym_case] = ACTIONS(2555),
    [anon_sym_yield] = ACTIONS(2555),
    [anon_sym_LBRACK] = ACTIONS(2553),
    [anon_sym_class] = ACTIONS(2555),
    [anon_sym_async] = ACTIONS(2555),
    [anon_sym_function] = ACTIONS(2555),
    [anon_sym_new] = ACTIONS(2555),
    [anon_sym_using] = ACTIONS(2555),
    [anon_sym_PLUS] = ACTIONS(2555),
    [anon_sym_DASH] = ACTIONS(2555),
    [anon_sym_SLASH] = ACTIONS(2555),
    [anon_sym_LT] = ACTIONS(2553),
    [anon_sym_TILDE] = ACTIONS(2553),
    [anon_sym_void] = ACTIONS(2555),
    [anon_sym_delete] = ACTIONS(2555),
    [anon_sym_PLUS_PLUS] = ACTIONS(2553),
    [anon_sym_DASH_DASH] = ACTIONS(2553),
    [anon_sym_DQUOTE] = ACTIONS(2553),
    [anon_sym_SQUOTE] = ACTIONS(2553),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(2553),
    [sym_number] = ACTIONS(2553),
    [sym_private_property_identifier] = ACTIONS(2553),
    [sym_this] = ACTIONS(2555),
    [sym_super] = ACTIONS(2555),
    [sym_true] = ACTIONS(2555),
    [sym_false] = ACTIONS(2555),
    [sym_null] = ACTIONS(2555),
    [sym_undefined] = ACTIONS(2555),
    [anon_sym_AT] = ACTIONS(2553),
    [anon_sym_static] = ACTIONS(2555),
    [anon_sym_readonly] = ACTIONS(2555),
    [anon_sym_get] = ACTIONS(2555),
    [anon_sym_set] = ACTIONS(2555),
    [anon_sym_declare] = ACTIONS(2555),
    [anon_sym_public] = ACTIONS(2555),
    [anon_sym_private] = ACTIONS(2555),
    [anon_sym_protected] = ACTIONS(2555),
    [anon_sym_override] = ACTIONS(2555),
    [anon_sym_module] = ACTIONS(2555),
    [anon_sym_any] = ACTIONS(2555),
    [anon_sym_number] = ACTIONS(2555),
    [anon_sym_boolean] = ACTIONS(2555),
    [anon_sym_string] = ACTIONS(2555),
    [anon_sym_symbol] = ACTIONS(2555),
    [anon_sym_object] = ACTIONS(2555),
    [anon_sym_abstract] = ACTIONS(2555),
    [anon_sym_interface] = ACTIONS(2555),
    [anon_sym_enum] = ACTIONS(2555),
    [sym_html_comment] = ACTIONS(5),
  },
  [813] = {
    [ts_builtin_sym_end] = ACTIONS(2557),
    [sym_identifier] = ACTIONS(2559),
    [anon_sym_export] = ACTIONS(2559),
    [anon_sym_default] = ACTIONS(2559),
    [anon_sym_type] = ACTIONS(2559),
    [anon_sym_namespace] = ACTIONS(2559),
    [anon_sym_LBRACE] = ACTIONS(2557),
    [anon_sym_RBRACE] = ACTIONS(2557),
    [anon_sym_typeof] = ACTIONS(2559),
    [anon_sym_import] = ACTIONS(2559),
    [anon_sym_with] = ACTIONS(2559),
    [anon_sym_var] = ACTIONS(2559),
    [anon_sym_let] = ACTIONS(2559),
    [anon_sym_const] = ACTIONS(2559),
    [anon_sym_BANG] = ACTIONS(2557),
    [anon_sym_else] = ACTIONS(2559),
    [anon_sym_if] = ACTIONS(2559),
    [anon_sym_switch] = ACTIONS(2559),
    [anon_sym_for] = ACTIONS(2559),
    [anon_sym_LPAREN] = ACTIONS(2557),
    [anon_sym_SEMI] = ACTIONS(2557),
    [anon_sym_await] = ACTIONS(2559),
    [anon_sym_while] = ACTIONS(2559),
    [anon_sym_do] = ACTIONS(2559),
    [anon_sym_try] = ACTIONS(2559),
    [anon_sym_break] = ACTIONS(2559),
    [anon_sym_continue] = ACTIONS(2559),
    [anon_sym_debugger] = ACTIONS(2559),
    [anon_sym_return] = ACTIONS(2559),
    [anon_sym_throw] = ACTIONS(2559),
    [anon_sym_case] = ACTIONS(2559),
    [anon_sym_yield] = ACTIONS(2559),
    [anon_sym_LBRACK] = ACTIONS(2557),
    [anon_sym_class] = ACTIONS(2559),
    [anon_sym_async] = ACTIONS(2559),
    [anon_sym_function] = ACTIONS(2559),
    [anon_sym_new] = ACTIONS(2559),
    [anon_sym_using] = ACTIONS(2559),
    [anon_sym_PLUS] = ACTIONS(2559),
    [anon_sym_DASH] = ACTIONS(2559),
    [anon_sym_SLASH] = ACTIONS(2559),
    [anon_sym_LT] = ACTIONS(2557),
    [anon_sym_TILDE] = ACTIONS(2557),
    [anon_sym_void] = ACTIONS(2559),
    [anon_sym_delete] = ACTIONS(2559),
    [anon_sym_PLUS_PLUS] = ACTIONS(2557),
    [anon_sym_DASH_DASH] = ACTIONS(2557),
    [anon_sym_DQUOTE] = ACTIONS(2557),
    [anon_sym_SQUOTE] = ACTIONS(2557),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(2557),
    [sym_number] = ACTIONS(2557),
    [sym_private_property_identifier] = ACTIONS(2557),
    [sym_this] = ACTIONS(2559),
    [sym_super] = ACTIONS(2559),
    [sym_true] = ACTIONS(2559),
    [sym_false] = ACTIONS(2559),
    [sym_null] = ACTIONS(2559),
    [sym_undefined] = ACTIONS(2559),
    [anon_sym_AT] = ACTIONS(2557),
    [anon_sym_static] = ACTIONS(2559),
    [anon_sym_readonly] = ACTIONS(2559),
    [anon_sym_get] = ACTIONS(2559),
    [anon_sym_set] = ACTIONS(2559),
    [anon_sym_declare] = ACTIONS(2559),
    [anon_sym_public] = ACTIONS(2559),
    [anon_sym_private] = ACTIONS(2559),
    [anon_sym_protected] = ACTIONS(2559),
    [anon_sym_override] = ACTIONS(2559),
    [anon_sym_module] = ACTIONS(2559),
    [anon_sym_any] = ACTIONS(2559),
    [anon_sym_number] = ACTIONS(2559),
    [anon_sym_boolean] = ACTIONS(2559),
    [anon_sym_string] = ACTIONS(2559),
    [anon_sym_symbol] = ACTIONS(2559),
    [anon_sym_object] = ACTIONS(2559),
    [anon_sym_abstract] = ACTIONS(2559),
    [anon_sym_interface] = ACTIONS(2559),
    [anon_sym_enum] = ACTIONS(2559),
    [sym_html_comment] = ACTIONS(5),
  },
  [814] = {
    [ts_builtin_sym_end] = ACTIONS(2561),
    [sym_identifier] = ACTIONS(2563),
    [anon_sym_export] = ACTIONS(2563),
    [anon_sym_default] = ACTIONS(2563),
    [anon_sym_type] = ACTIONS(2563),
    [anon_sym_namespace] = ACTIONS(2563),
    [anon_sym_LBRACE] = ACTIONS(2561),
    [anon_sym_RBRACE] = ACTIONS(2561),
    [anon_sym_typeof] = ACTIONS(2563),
    [anon_sym_import] = ACTIONS(2563),
    [anon_sym_with] = ACTIONS(2563),
    [anon_sym_var] = ACTIONS(2563),
    [anon_sym_let] = ACTIONS(2563),
    [anon_sym_const] = ACTIONS(2563),
    [anon_sym_BANG] = ACTIONS(2561),
    [anon_sym_else] = ACTIONS(2563),
    [anon_sym_if] = ACTIONS(2563),
    [anon_sym_switch] = ACTIONS(2563),
    [anon_sym_for] = ACTIONS(2563),
    [anon_sym_LPAREN] = ACTIONS(2561),
    [anon_sym_SEMI] = ACTIONS(2561),
    [anon_sym_await] = ACTIONS(2563),
    [anon_sym_while] = ACTIONS(2563),
    [anon_sym_do] = ACTIONS(2563),
    [anon_sym_try] = ACTIONS(2563),
    [anon_sym_break] = ACTIONS(2563),
    [anon_sym_continue] = ACTIONS(2563),
    [anon_sym_debugger] = ACTIONS(2563),
    [anon_sym_return] = ACTIONS(2563),
    [anon_sym_throw] = ACTIONS(2563),
    [anon_sym_case] = ACTIONS(2563),
    [anon_sym_yield] = ACTIONS(2563),
    [anon_sym_LBRACK] = ACTIONS(2561),
    [anon_sym_class] = ACTIONS(2563),
    [anon_sym_async] = ACTIONS(2563),
    [anon_sym_function] = ACTIONS(2563),
    [anon_sym_new] = ACTIONS(2563),
    [anon_sym_using] = ACTIONS(2563),
    [anon_sym_PLUS] = ACTIONS(2563),
    [anon_sym_DASH] = ACTIONS(2563),
    [anon_sym_SLASH] = ACTIONS(2563),
    [anon_sym_LT] = ACTIONS(2561),
    [anon_sym_TILDE] = ACTIONS(2561),
    [anon_sym_void] = ACTIONS(2563),
    [anon_sym_delete] = ACTIONS(2563),
    [anon_sym_PLUS_PLUS] = ACTIONS(2561),
    [anon_sym_DASH_DASH] = ACTIONS(2561),
    [anon_sym_DQUOTE] = ACTIONS(2561),
    [anon_sym_SQUOTE] = ACTIONS(2561),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(2561),
    [sym_number] = ACTIONS(2561),
    [sym_private_property_identifier] = ACTIONS(2561),
    [sym_this] = ACTIONS(2563),
    [sym_super] = ACTIONS(2563),
    [sym_true] = ACTIONS(2563),
    [sym_false] = ACTIONS(2563),
    [sym_null] = ACTIONS(2563),
    [sym_undefined] = ACTIONS(2563),
    [anon_sym_AT] = ACTIONS(2561),
    [anon_sym_static] = ACTIONS(2563),
    [anon_sym_readonly] = ACTIONS(2563),
    [anon_sym_get] = ACTIONS(2563),
    [anon_sym_set] = ACTIONS(2563),
    [anon_sym_declare] = ACTIONS(2563),
    [anon_sym_public] = ACTIONS(2563),
    [anon_sym_private] = ACTIONS(2563),
    [anon_sym_protected] = ACTIONS(2563),
    [anon_sym_override] = ACTIONS(2563),
    [anon_sym_module] = ACTIONS(2563),
    [anon_sym_any] = ACTIONS(2563),
    [anon_sym_number] = ACTIONS(2563),
    [anon_sym_boolean] = ACTIONS(2563),
    [anon_sym_string] = ACTIONS(2563),
    [anon_sym_symbol] = ACTIONS(2563),
    [anon_sym_object] = ACTIONS(2563),
    [anon_sym_abstract] = ACTIONS(2563),
    [anon_sym_interface] = ACTIONS(2563),
    [anon_sym_enum] = ACTIONS(2563),
    [sym_html_comment] = ACTIONS(5),
  },
  [815] = {
    [ts_builtin_sym_end] = ACTIONS(2565),
    [sym_identifier] = ACTIONS(2567),
    [anon_sym_export] = ACTIONS(2567),
    [anon_sym_default] = ACTIONS(2567),
    [anon_sym_type] = ACTIONS(2567),
    [anon_sym_namespace] = ACTIONS(2567),
    [anon_sym_LBRACE] = ACTIONS(2565),
    [anon_sym_RBRACE] = ACTIONS(2565),
    [anon_sym_typeof] = ACTIONS(2567),
    [anon_sym_import] = ACTIONS(2567),
    [anon_sym_with] = ACTIONS(2567),
    [anon_sym_var] = ACTIONS(2567),
    [anon_sym_let] = ACTIONS(2567),
    [anon_sym_const] = ACTIONS(2567),
    [anon_sym_BANG] = ACTIONS(2565),
    [anon_sym_else] = ACTIONS(2567),
    [anon_sym_if] = ACTIONS(2567),
    [anon_sym_switch] = ACTIONS(2567),
    [anon_sym_for] = ACTIONS(2567),
    [anon_sym_LPAREN] = ACTIONS(2565),
    [anon_sym_SEMI] = ACTIONS(2565),
    [anon_sym_await] = ACTIONS(2567),
    [anon_sym_while] = ACTIONS(2567),
    [anon_sym_do] = ACTIONS(2567),
    [anon_sym_try] = ACTIONS(2567),
    [anon_sym_break] = ACTIONS(2567),
    [anon_sym_continue] = ACTIONS(2567),
    [anon_sym_debugger] = ACTIONS(2567),
    [anon_sym_return] = ACTIONS(2567),
    [anon_sym_throw] = ACTIONS(2567),
    [anon_sym_case] = ACTIONS(2567),
    [anon_sym_yield] = ACTIONS(2567),
    [anon_sym_LBRACK] = ACTIONS(2565),
    [anon_sym_class] = ACTIONS(2567),
    [anon_sym_async] = ACTIONS(2567),
    [anon_sym_function] = ACTIONS(2567),
    [anon_sym_new] = ACTIONS(2567),
    [anon_sym_using] = ACTIONS(2567),
    [anon_sym_PLUS] = ACTIONS(2567),
    [anon_sym_DASH] = ACTIONS(2567),
    [anon_sym_SLASH] = ACTIONS(2567),
    [anon_sym_LT] = ACTIONS(2565),
    [anon_sym_TILDE] = ACTIONS(2565),
    [anon_sym_void] = ACTIONS(2567),
    [anon_sym_delete] = ACTIONS(2567),
    [anon_sym_PLUS_PLUS] = ACTIONS(2565),
    [anon_sym_DASH_DASH] = ACTIONS(2565),
    [anon_sym_DQUOTE] = ACTIONS(2565),
    [anon_sym_SQUOTE] = ACTIONS(2565),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(2565),
    [sym_number] = ACTIONS(2565),
    [sym_private_property_identifier] = ACTIONS(2565),
    [sym_this] = ACTIONS(2567),
    [sym_super] = ACTIONS(2567),
    [sym_true] = ACTIONS(2567),
    [sym_false] = ACTIONS(2567),
    [sym_null] = ACTIONS(2567),
    [sym_undefined] = ACTIONS(2567),
    [anon_sym_AT] = ACTIONS(2565),
    [anon_sym_static] = ACTIONS(2567),
    [anon_sym_readonly] = ACTIONS(2567),
    [anon_sym_get] = ACTIONS(2567),
    [anon_sym_set] = ACTIONS(2567),
    [anon_sym_declare] = ACTIONS(2567),
    [anon_sym_public] = ACTIONS(2567),
    [anon_sym_private] = ACTIONS(2567),
    [anon_sym_protected] = ACTIONS(2567),
    [anon_sym_override] = ACTIONS(2567),
    [anon_sym_module] = ACTIONS(2567),
    [anon_sym_any] = ACTIONS(2567),
    [anon_sym_number] = ACTIONS(2567),
    [anon_sym_boolean] = ACTIONS(2567),
    [anon_sym_string] = ACTIONS(2567),
    [anon_sym_symbol] = ACTIONS(2567),
    [anon_sym_object] = ACTIONS(2567),
    [anon_sym_abstract] = ACTIONS(2567),
    [anon_sym_interface] = ACTIONS(2567),
    [anon_sym_enum] = ACTIONS(2567),
    [sym_html_comment] = ACTIONS(5),
  },
  [816] = {
    [ts_builtin_sym_end] = ACTIONS(2561),
    [sym_identifier] = ACTIONS(2563),
    [anon_sym_export] = ACTIONS(2563),
    [anon_sym_default] = ACTIONS(2563),
    [anon_sym_type] = ACTIONS(2563),
    [anon_sym_namespace] = ACTIONS(2563),
    [anon_sym_LBRACE] = ACTIONS(2561),
    [anon_sym_RBRACE] = ACTIONS(2561),
    [anon_sym_typeof] = ACTIONS(2563),
    [anon_sym_import] = ACTIONS(2563),
    [anon_sym_with] = ACTIONS(2563),
    [anon_sym_var] = ACTIONS(2563),
    [anon_sym_let] = ACTIONS(2563),
    [anon_sym_const] = ACTIONS(2563),
    [anon_sym_BANG] = ACTIONS(2561),
    [anon_sym_else] = ACTIONS(2563),
    [anon_sym_if] = ACTIONS(2563),
    [anon_sym_switch] = ACTIONS(2563),
    [anon_sym_for] = ACTIONS(2563),
    [anon_sym_LPAREN] = ACTIONS(2561),
    [anon_sym_SEMI] = ACTIONS(2561),
    [anon_sym_await] = ACTIONS(2563),
    [anon_sym_while] = ACTIONS(2563),
    [anon_sym_do] = ACTIONS(2563),
    [anon_sym_try] = ACTIONS(2563),
    [anon_sym_break] = ACTIONS(2563),
    [anon_sym_continue] = ACTIONS(2563),
    [anon_sym_debugger] = ACTIONS(2563),
    [anon_sym_return] = ACTIONS(2563),
    [anon_sym_throw] = ACTIONS(2563),
    [anon_sym_case] = ACTIONS(2563),
    [anon_sym_yield] = ACTIONS(2563),
    [anon_sym_LBRACK] = ACTIONS(2561),
    [anon_sym_class] = ACTIONS(2563),
    [anon_sym_async] = ACTIONS(2563),
    [anon_sym_function] = ACTIONS(2563),
    [anon_sym_new] = ACTIONS(2563),
    [anon_sym_using] = ACTIONS(2563),
    [anon_sym_PLUS] = ACTIONS(2563),
    [anon_sym_DASH] = ACTIONS(2563),
    [anon_sym_SLASH] = ACTIONS(2563),
    [anon_sym_LT] = ACTIONS(2561),
    [anon_sym_TILDE] = ACTIONS(2561),
    [anon_sym_void] = ACTIONS(2563),
    [anon_sym_delete] = ACTIONS(2563),
    [anon_sym_PLUS_PLUS] = ACTIONS(2561),
    [anon_sym_DASH_DASH] = ACTIONS(2561),
    [anon_sym_DQUOTE] = ACTIONS(2561),
    [anon_sym_SQUOTE] = ACTIONS(2561),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(2561),
    [sym_number] = ACTIONS(2561),
    [sym_private_property_identifier] = ACTIONS(2561),
    [sym_this] = ACTIONS(2563),
    [sym_super] = ACTIONS(2563),
    [sym_true] = ACTIONS(2563),
    [sym_false] = ACTIONS(2563),
    [sym_null] = ACTIONS(2563),
    [sym_undefined] = ACTIONS(2563),
    [anon_sym_AT] = ACTIONS(2561),
    [anon_sym_static] = ACTIONS(2563),
    [anon_sym_readonly] = ACTIONS(2563),
    [anon_sym_get] = ACTIONS(2563),
    [anon_sym_set] = ACTIONS(2563),
    [anon_sym_declare] = ACTIONS(2563),
    [anon_sym_public] = ACTIONS(2563),
    [anon_sym_private] = ACTIONS(2563),
    [anon_sym_protected] = ACTIONS(2563),
    [anon_sym_override] = ACTIONS(2563),
    [anon_sym_module] = ACTIONS(2563),
    [anon_sym_any] = ACTIONS(2563),
    [anon_sym_number] = ACTIONS(2563),
    [anon_sym_boolean] = ACTIONS(2563),
    [anon_sym_string] = ACTIONS(2563),
    [anon_sym_symbol] = ACTIONS(2563),
    [anon_sym_object] = ACTIONS(2563),
    [anon_sym_abstract] = ACTIONS(2563),
    [anon_sym_interface] = ACTIONS(2563),
    [anon_sym_enum] = ACTIONS(2563),
    [sym_html_comment] = ACTIONS(5),
  },
  [817] = {
    [ts_builtin_sym_end] = ACTIONS(2569),
    [sym_identifier] = ACTIONS(2571),
    [anon_sym_export] = ACTIONS(2571),
    [anon_sym_default] = ACTIONS(2571),
    [anon_sym_type] = ACTIONS(2571),
    [anon_sym_namespace] = ACTIONS(2571),
    [anon_sym_LBRACE] = ACTIONS(2569),
    [anon_sym_RBRACE] = ACTIONS(2569),
    [anon_sym_typeof] = ACTIONS(2571),
    [anon_sym_import] = ACTIONS(2571),
    [anon_sym_with] = ACTIONS(2571),
    [anon_sym_var] = ACTIONS(2571),
    [anon_sym_let] = ACTIONS(2571),
    [anon_sym_const] = ACTIONS(2571),
    [anon_sym_BANG] = ACTIONS(2569),
    [anon_sym_else] = ACTIONS(2571),
    [anon_sym_if] = ACTIONS(2571),
    [anon_sym_switch] = ACTIONS(2571),
    [anon_sym_for] = ACTIONS(2571),
    [anon_sym_LPAREN] = ACTIONS(2569),
    [anon_sym_SEMI] = ACTIONS(2569),
    [anon_sym_await] = ACTIONS(2571),
    [anon_sym_while] = ACTIONS(2571),
    [anon_sym_do] = ACTIONS(2571),
    [anon_sym_try] = ACTIONS(2571),
    [anon_sym_break] = ACTIONS(2571),
    [anon_sym_continue] = ACTIONS(2571),
    [anon_sym_debugger] = ACTIONS(2571),
    [anon_sym_return] = ACTIONS(2571),
    [anon_sym_throw] = ACTIONS(2571),
    [anon_sym_case] = ACTIONS(2571),
    [anon_sym_yield] = ACTIONS(2571),
    [anon_sym_LBRACK] = ACTIONS(2569),
    [anon_sym_class] = ACTIONS(2571),
    [anon_sym_async] = ACTIONS(2571),
    [anon_sym_function] = ACTIONS(2571),
    [anon_sym_new] = ACTIONS(2571),
    [anon_sym_using] = ACTIONS(2571),
    [anon_sym_PLUS] = ACTIONS(2571),
    [anon_sym_DASH] = ACTIONS(2571),
    [anon_sym_SLASH] = ACTIONS(2571),
    [anon_sym_LT] = ACTIONS(2569),
    [anon_sym_TILDE] = ACTIONS(2569),
    [anon_sym_void] = ACTIONS(2571),
    [anon_sym_delete] = ACTIONS(2571),
    [anon_sym_PLUS_PLUS] = ACTIONS(2569),
    [anon_sym_DASH_DASH] = ACTIONS(2569),
    [anon_sym_DQUOTE] = ACTIONS(2569),
    [anon_sym_SQUOTE] = ACTIONS(2569),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(2569),
    [sym_number] = ACTIONS(2569),
    [sym_private_property_identifier] = ACTIONS(2569),
    [sym_this] = ACTIONS(2571),
    [sym_super] = ACTIONS(2571),
    [sym_true] = ACTIONS(2571),
    [sym_false] = ACTIONS(2571),
    [sym_null] = ACTIONS(2571),
    [sym_undefined] = ACTIONS(2571),
    [anon_sym_AT] = ACTIONS(2569),
    [anon_sym_static] = ACTIONS(2571),
    [anon_sym_readonly] = ACTIONS(2571),
    [anon_sym_get] = ACTIONS(2571),
    [anon_sym_set] = ACTIONS(2571),
    [anon_sym_declare] = ACTIONS(2571),
    [anon_sym_public] = ACTIONS(2571),
    [anon_sym_private] = ACTIONS(2571),
    [anon_sym_protected] = ACTIONS(2571),
    [anon_sym_override] = ACTIONS(2571),
    [anon_sym_module] = ACTIONS(2571),
    [anon_sym_any] = ACTIONS(2571),
    [anon_sym_number] = ACTIONS(2571),
    [anon_sym_boolean] = ACTIONS(2571),
    [anon_sym_string] = ACTIONS(2571),
    [anon_sym_symbol] = ACTIONS(2571),
    [anon_sym_object] = ACTIONS(2571),
    [anon_sym_abstract] = ACTIONS(2571),
    [anon_sym_interface] = ACTIONS(2571),
    [anon_sym_enum] = ACTIONS(2571),
    [sym_html_comment] = ACTIONS(5),
  },
  [818] = {
    [ts_builtin_sym_end] = ACTIONS(2561),
    [sym_identifier] = ACTIONS(2563),
    [anon_sym_export] = ACTIONS(2563),
    [anon_sym_default] = ACTIONS(2563),
    [anon_sym_type] = ACTIONS(2563),
    [anon_sym_namespace] = ACTIONS(2563),
    [anon_sym_LBRACE] = ACTIONS(2561),
    [anon_sym_RBRACE] = ACTIONS(2561),
    [anon_sym_typeof] = ACTIONS(2563),
    [anon_sym_import] = ACTIONS(2563),
    [anon_sym_with] = ACTIONS(2563),
    [anon_sym_var] = ACTIONS(2563),
    [anon_sym_let] = ACTIONS(2563),
    [anon_sym_const] = ACTIONS(2563),
    [anon_sym_BANG] = ACTIONS(2561),
    [anon_sym_else] = ACTIONS(2563),
    [anon_sym_if] = ACTIONS(2563),
    [anon_sym_switch] = ACTIONS(2563),
    [anon_sym_for] = ACTIONS(2563),
    [anon_sym_LPAREN] = ACTIONS(2561),
    [anon_sym_SEMI] = ACTIONS(2561),
    [anon_sym_await] = ACTIONS(2563),
    [anon_sym_while] = ACTIONS(2563),
    [anon_sym_do] = ACTIONS(2563),
    [anon_sym_try] = ACTIONS(2563),
    [anon_sym_break] = ACTIONS(2563),
    [anon_sym_continue] = ACTIONS(2563),
    [anon_sym_debugger] = ACTIONS(2563),
    [anon_sym_return] = ACTIONS(2563),
    [anon_sym_throw] = ACTIONS(2563),
    [anon_sym_case] = ACTIONS(2563),
    [anon_sym_yield] = ACTIONS(2563),
    [anon_sym_LBRACK] = ACTIONS(2561),
    [anon_sym_class] = ACTIONS(2563),
    [anon_sym_async] = ACTIONS(2563),
    [anon_sym_function] = ACTIONS(2563),
    [anon_sym_new] = ACTIONS(2563),
    [anon_sym_using] = ACTIONS(2563),
    [anon_sym_PLUS] = ACTIONS(2563),
    [anon_sym_DASH] = ACTIONS(2563),
    [anon_sym_SLASH] = ACTIONS(2563),
    [anon_sym_LT] = ACTIONS(2561),
    [anon_sym_TILDE] = ACTIONS(2561),
    [anon_sym_void] = ACTIONS(2563),
    [anon_sym_delete] = ACTIONS(2563),
    [anon_sym_PLUS_PLUS] = ACTIONS(2561),
    [anon_sym_DASH_DASH] = ACTIONS(2561),
    [anon_sym_DQUOTE] = ACTIONS(2561),
    [anon_sym_SQUOTE] = ACTIONS(2561),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(2561),
    [sym_number] = ACTIONS(2561),
    [sym_private_property_identifier] = ACTIONS(2561),
    [sym_this] = ACTIONS(2563),
    [sym_super] = ACTIONS(2563),
    [sym_true] = ACTIONS(2563),
    [sym_false] = ACTIONS(2563),
    [sym_null] = ACTIONS(2563),
    [sym_undefined] = ACTIONS(2563),
    [anon_sym_AT] = ACTIONS(2561),
    [anon_sym_static] = ACTIONS(2563),
    [anon_sym_readonly] = ACTIONS(2563),
    [anon_sym_get] = ACTIONS(2563),
    [anon_sym_set] = ACTIONS(2563),
    [anon_sym_declare] = ACTIONS(2563),
    [anon_sym_public] = ACTIONS(2563),
    [anon_sym_private] = ACTIONS(2563),
    [anon_sym_protected] = ACTIONS(2563),
    [anon_sym_override] = ACTIONS(2563),
    [anon_sym_module] = ACTIONS(2563),
    [anon_sym_any] = ACTIONS(2563),
    [anon_sym_number] = ACTIONS(2563),
    [anon_sym_boolean] = ACTIONS(2563),
    [anon_sym_string] = ACTIONS(2563),
    [anon_sym_symbol] = ACTIONS(2563),
    [anon_sym_object] = ACTIONS(2563),
    [anon_sym_abstract] = ACTIONS(2563),
    [anon_sym_interface] = ACTIONS(2563),
    [anon_sym_enum] = ACTIONS(2563),
    [sym_html_comment] = ACTIONS(5),
  },
  [819] = {
    [ts_builtin_sym_end] = ACTIONS(2573),
    [sym_identifier] = ACTIONS(2575),
    [anon_sym_export] = ACTIONS(2575),
    [anon_sym_default] = ACTIONS(2575),
    [anon_sym_type] = ACTIONS(2575),
    [anon_sym_namespace] = ACTIONS(2575),
    [anon_sym_LBRACE] = ACTIONS(2573),
    [anon_sym_RBRACE] = ACTIONS(2573),
    [anon_sym_typeof] = ACTIONS(2575),
    [anon_sym_import] = ACTIONS(2575),
    [anon_sym_with] = ACTIONS(2575),
    [anon_sym_var] = ACTIONS(2575),
    [anon_sym_let] = ACTIONS(2575),
    [anon_sym_const] = ACTIONS(2575),
    [anon_sym_BANG] = ACTIONS(2573),
    [anon_sym_else] = ACTIONS(2575),
    [anon_sym_if] = ACTIONS(2575),
    [anon_sym_switch] = ACTIONS(2575),
    [anon_sym_for] = ACTIONS(2575),
    [anon_sym_LPAREN] = ACTIONS(2573),
    [anon_sym_SEMI] = ACTIONS(2573),
    [anon_sym_await] = ACTIONS(2575),
    [anon_sym_while] = ACTIONS(2575),
    [anon_sym_do] = ACTIONS(2575),
    [anon_sym_try] = ACTIONS(2575),
    [anon_sym_break] = ACTIONS(2575),
    [anon_sym_continue] = ACTIONS(2575),
    [anon_sym_debugger] = ACTIONS(2575),
    [anon_sym_return] = ACTIONS(2575),
    [anon_sym_throw] = ACTIONS(2575),
    [anon_sym_case] = ACTIONS(2575),
    [anon_sym_yield] = ACTIONS(2575),
    [anon_sym_LBRACK] = ACTIONS(2573),
    [anon_sym_class] = ACTIONS(2575),
    [anon_sym_async] = ACTIONS(2575),
    [anon_sym_function] = ACTIONS(2575),
    [anon_sym_new] = ACTIONS(2575),
    [anon_sym_using] = ACTIONS(2575),
    [anon_sym_PLUS] = ACTIONS(2575),
    [anon_sym_DASH] = ACTIONS(2575),
    [anon_sym_SLASH] = ACTIONS(2575),
    [anon_sym_LT] = ACTIONS(2573),
    [anon_sym_TILDE] = ACTIONS(2573),
    [anon_sym_void] = ACTIONS(2575),
    [anon_sym_delete] = ACTIONS(2575),
    [anon_sym_PLUS_PLUS] = ACTIONS(2573),
    [anon_sym_DASH_DASH] = ACTIONS(2573),
    [anon_sym_DQUOTE] = ACTIONS(2573),
    [anon_sym_SQUOTE] = ACTIONS(2573),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(2573),
    [sym_number] = ACTIONS(2573),
    [sym_private_property_identifier] = ACTIONS(2573),
    [sym_this] = ACTIONS(2575),
    [sym_super] = ACTIONS(2575),
    [sym_true] = ACTIONS(2575),
    [sym_false] = ACTIONS(2575),
    [sym_null] = ACTIONS(2575),
    [sym_undefined] = ACTIONS(2575),
    [anon_sym_AT] = ACTIONS(2573),
    [anon_sym_static] = ACTIONS(2575),
    [anon_sym_readonly] = ACTIONS(2575),
    [anon_sym_get] = ACTIONS(2575),
    [anon_sym_set] = ACTIONS(2575),
    [anon_sym_declare] = ACTIONS(2575),
    [anon_sym_public] = ACTIONS(2575),
    [anon_sym_private] = ACTIONS(2575),
    [anon_sym_protected] = ACTIONS(2575),
    [anon_sym_override] = ACTIONS(2575),
    [anon_sym_module] = ACTIONS(2575),
    [anon_sym_any] = ACTIONS(2575),
    [anon_sym_number] = ACTIONS(2575),
    [anon_sym_boolean] = ACTIONS(2575),
    [anon_sym_string] = ACTIONS(2575),
    [anon_sym_symbol] = ACTIONS(2575),
    [anon_sym_object] = ACTIONS(2575),
    [anon_sym_abstract] = ACTIONS(2575),
    [anon_sym_interface] = ACTIONS(2575),
    [anon_sym_enum] = ACTIONS(2575),
    [sym_html_comment] = ACTIONS(5),
  },
  [820] = {
    [sym_import] = STATE(4681),
    [sym_nested_identifier] = STATE(5474),
    [sym_string] = STATE(2994),
    [sym_formal_parameters] = STATE(5619),
    [sym_rest_pattern] = STATE(5165),
    [sym_nested_type_identifier] = STATE(2939),
    [sym__type_query_member_expression_in_type_annotation] = STATE(3303),
    [sym__type_query_call_expression_in_type_annotation] = STATE(2938),
    [sym_type] = STATE(3773),
    [sym_tuple_parameter] = STATE(5278),
    [sym_optional_tuple_parameter] = STATE(5278),
    [sym_optional_type] = STATE(5278),
    [sym_rest_type] = STATE(5278),
    [sym__tuple_type_member] = STATE(5278),
    [sym_constructor_type] = STATE(3007),
    [sym_primary_type] = STATE(2981),
    [sym_template_literal_type] = STATE(3039),
    [sym_infer_type] = STATE(3007),
    [sym_conditional_type] = STATE(3039),
    [sym_generic_type] = STATE(3039),
    [sym_type_query] = STATE(3039),
    [sym_index_type_query] = STATE(3039),
    [sym_lookup_type] = STATE(3039),
    [sym_literal_type] = STATE(3039),
    [sym__number] = STATE(3041),
    [sym_existential_type] = STATE(3039),
    [sym_flow_maybe_type] = STATE(3039),
    [sym_parenthesized_type] = STATE(3039),
    [sym_predefined_type] = STATE(3039),
    [sym_object_type] = STATE(3039),
    [sym_type_parameters] = STATE(5454),
    [sym_array_type] = STATE(3039),
    [sym_tuple_type] = STATE(3039),
    [sym_readonly_type] = STATE(3007),
    [sym_union_type] = STATE(3039),
    [sym_intersection_type] = STATE(3039),
    [sym_function_type] = STATE(3007),
    [sym_identifier] = ACTIONS(2489),
    [anon_sym_STAR] = ACTIONS(543),
    [anon_sym_LBRACE] = ACTIONS(1534),
    [anon_sym_typeof] = ACTIONS(1536),
    [anon_sym_import] = ACTIONS(1538),
    [anon_sym_const] = ACTIONS(133),
    [anon_sym_LPAREN] = ACTIONS(1540),
    [anon_sym_LBRACK] = ACTIONS(1542),
    [anon_sym_RBRACK] = ACTIONS(2577),
    [anon_sym_new] = ACTIONS(1642),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(2495),
    [anon_sym_AMP] = ACTIONS(571),
    [anon_sym_PIPE] = ACTIONS(573),
    [anon_sym_PLUS] = ACTIONS(2497),
    [anon_sym_DASH] = ACTIONS(2497),
    [anon_sym_LT] = ACTIONS(2499),
    [anon_sym_void] = ACTIONS(216),
    [anon_sym_DQUOTE] = ACTIONS(1550),
    [anon_sym_SQUOTE] = ACTIONS(1552),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1554),
    [sym_number] = ACTIONS(1556),
    [sym_this] = ACTIONS(1558),
    [sym_true] = ACTIONS(1560),
    [sym_false] = ACTIONS(1560),
    [sym_null] = ACTIONS(1560),
    [sym_undefined] = ACTIONS(1560),
    [anon_sym_readonly] = ACTIONS(1648),
    [anon_sym_QMARK] = ACTIONS(593),
    [anon_sym_any] = ACTIONS(216),
    [anon_sym_number] = ACTIONS(216),
    [anon_sym_boolean] = ACTIONS(216),
    [anon_sym_string] = ACTIONS(216),
    [anon_sym_symbol] = ACTIONS(216),
    [anon_sym_object] = ACTIONS(216),
    [anon_sym_abstract] = ACTIONS(597),
    [anon_sym_infer] = ACTIONS(599),
    [anon_sym_keyof] = ACTIONS(601),
    [anon_sym_unique] = ACTIONS(214),
    [anon_sym_unknown] = ACTIONS(216),
    [anon_sym_never] = ACTIONS(216),
    [anon_sym_LBRACE_PIPE] = ACTIONS(218),
    [sym_html_comment] = ACTIONS(5),
  },
  [821] = {
    [sym_import] = STATE(4681),
    [sym_nested_identifier] = STATE(5474),
    [sym_string] = STATE(2994),
    [sym_formal_parameters] = STATE(5619),
    [sym_rest_pattern] = STATE(5165),
    [sym_nested_type_identifier] = STATE(2939),
    [sym__type_query_member_expression_in_type_annotation] = STATE(3303),
    [sym__type_query_call_expression_in_type_annotation] = STATE(2938),
    [sym_type] = STATE(3773),
    [sym_tuple_parameter] = STATE(5278),
    [sym_optional_tuple_parameter] = STATE(5278),
    [sym_optional_type] = STATE(5278),
    [sym_rest_type] = STATE(5278),
    [sym__tuple_type_member] = STATE(5278),
    [sym_constructor_type] = STATE(3007),
    [sym_primary_type] = STATE(2981),
    [sym_template_literal_type] = STATE(3039),
    [sym_infer_type] = STATE(3007),
    [sym_conditional_type] = STATE(3039),
    [sym_generic_type] = STATE(3039),
    [sym_type_query] = STATE(3039),
    [sym_index_type_query] = STATE(3039),
    [sym_lookup_type] = STATE(3039),
    [sym_literal_type] = STATE(3039),
    [sym__number] = STATE(3041),
    [sym_existential_type] = STATE(3039),
    [sym_flow_maybe_type] = STATE(3039),
    [sym_parenthesized_type] = STATE(3039),
    [sym_predefined_type] = STATE(3039),
    [sym_object_type] = STATE(3039),
    [sym_type_parameters] = STATE(5454),
    [sym_array_type] = STATE(3039),
    [sym_tuple_type] = STATE(3039),
    [sym_readonly_type] = STATE(3007),
    [sym_union_type] = STATE(3039),
    [sym_intersection_type] = STATE(3039),
    [sym_function_type] = STATE(3007),
    [sym_identifier] = ACTIONS(2489),
    [anon_sym_STAR] = ACTIONS(543),
    [anon_sym_LBRACE] = ACTIONS(1534),
    [anon_sym_typeof] = ACTIONS(1536),
    [anon_sym_import] = ACTIONS(1538),
    [anon_sym_const] = ACTIONS(133),
    [anon_sym_LPAREN] = ACTIONS(1540),
    [anon_sym_LBRACK] = ACTIONS(1542),
    [anon_sym_RBRACK] = ACTIONS(2579),
    [anon_sym_new] = ACTIONS(1642),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(2495),
    [anon_sym_AMP] = ACTIONS(571),
    [anon_sym_PIPE] = ACTIONS(573),
    [anon_sym_PLUS] = ACTIONS(2497),
    [anon_sym_DASH] = ACTIONS(2497),
    [anon_sym_LT] = ACTIONS(2499),
    [anon_sym_void] = ACTIONS(216),
    [anon_sym_DQUOTE] = ACTIONS(1550),
    [anon_sym_SQUOTE] = ACTIONS(1552),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1554),
    [sym_number] = ACTIONS(1556),
    [sym_this] = ACTIONS(1558),
    [sym_true] = ACTIONS(1560),
    [sym_false] = ACTIONS(1560),
    [sym_null] = ACTIONS(1560),
    [sym_undefined] = ACTIONS(1560),
    [anon_sym_readonly] = ACTIONS(1648),
    [anon_sym_QMARK] = ACTIONS(593),
    [anon_sym_any] = ACTIONS(216),
    [anon_sym_number] = ACTIONS(216),
    [anon_sym_boolean] = ACTIONS(216),
    [anon_sym_string] = ACTIONS(216),
    [anon_sym_symbol] = ACTIONS(216),
    [anon_sym_object] = ACTIONS(216),
    [anon_sym_abstract] = ACTIONS(597),
    [anon_sym_infer] = ACTIONS(599),
    [anon_sym_keyof] = ACTIONS(601),
    [anon_sym_unique] = ACTIONS(214),
    [anon_sym_unknown] = ACTIONS(216),
    [anon_sym_never] = ACTIONS(216),
    [anon_sym_LBRACE_PIPE] = ACTIONS(218),
    [sym_html_comment] = ACTIONS(5),
  },
  [822] = {
    [ts_builtin_sym_end] = ACTIONS(2561),
    [sym_identifier] = ACTIONS(2563),
    [anon_sym_export] = ACTIONS(2563),
    [anon_sym_default] = ACTIONS(2563),
    [anon_sym_type] = ACTIONS(2563),
    [anon_sym_namespace] = ACTIONS(2563),
    [anon_sym_LBRACE] = ACTIONS(2561),
    [anon_sym_RBRACE] = ACTIONS(2561),
    [anon_sym_typeof] = ACTIONS(2563),
    [anon_sym_import] = ACTIONS(2563),
    [anon_sym_with] = ACTIONS(2563),
    [anon_sym_var] = ACTIONS(2563),
    [anon_sym_let] = ACTIONS(2563),
    [anon_sym_const] = ACTIONS(2563),
    [anon_sym_BANG] = ACTIONS(2561),
    [anon_sym_else] = ACTIONS(2563),
    [anon_sym_if] = ACTIONS(2563),
    [anon_sym_switch] = ACTIONS(2563),
    [anon_sym_for] = ACTIONS(2563),
    [anon_sym_LPAREN] = ACTIONS(2561),
    [anon_sym_SEMI] = ACTIONS(2561),
    [anon_sym_await] = ACTIONS(2563),
    [anon_sym_while] = ACTIONS(2563),
    [anon_sym_do] = ACTIONS(2563),
    [anon_sym_try] = ACTIONS(2563),
    [anon_sym_break] = ACTIONS(2563),
    [anon_sym_continue] = ACTIONS(2563),
    [anon_sym_debugger] = ACTIONS(2563),
    [anon_sym_return] = ACTIONS(2563),
    [anon_sym_throw] = ACTIONS(2563),
    [anon_sym_case] = ACTIONS(2563),
    [anon_sym_yield] = ACTIONS(2563),
    [anon_sym_LBRACK] = ACTIONS(2561),
    [anon_sym_class] = ACTIONS(2563),
    [anon_sym_async] = ACTIONS(2563),
    [anon_sym_function] = ACTIONS(2563),
    [anon_sym_new] = ACTIONS(2563),
    [anon_sym_using] = ACTIONS(2563),
    [anon_sym_PLUS] = ACTIONS(2563),
    [anon_sym_DASH] = ACTIONS(2563),
    [anon_sym_SLASH] = ACTIONS(2563),
    [anon_sym_LT] = ACTIONS(2561),
    [anon_sym_TILDE] = ACTIONS(2561),
    [anon_sym_void] = ACTIONS(2563),
    [anon_sym_delete] = ACTIONS(2563),
    [anon_sym_PLUS_PLUS] = ACTIONS(2561),
    [anon_sym_DASH_DASH] = ACTIONS(2561),
    [anon_sym_DQUOTE] = ACTIONS(2561),
    [anon_sym_SQUOTE] = ACTIONS(2561),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(2561),
    [sym_number] = ACTIONS(2561),
    [sym_private_property_identifier] = ACTIONS(2561),
    [sym_this] = ACTIONS(2563),
    [sym_super] = ACTIONS(2563),
    [sym_true] = ACTIONS(2563),
    [sym_false] = ACTIONS(2563),
    [sym_null] = ACTIONS(2563),
    [sym_undefined] = ACTIONS(2563),
    [anon_sym_AT] = ACTIONS(2561),
    [anon_sym_static] = ACTIONS(2563),
    [anon_sym_readonly] = ACTIONS(2563),
    [anon_sym_get] = ACTIONS(2563),
    [anon_sym_set] = ACTIONS(2563),
    [anon_sym_declare] = ACTIONS(2563),
    [anon_sym_public] = ACTIONS(2563),
    [anon_sym_private] = ACTIONS(2563),
    [anon_sym_protected] = ACTIONS(2563),
    [anon_sym_override] = ACTIONS(2563),
    [anon_sym_module] = ACTIONS(2563),
    [anon_sym_any] = ACTIONS(2563),
    [anon_sym_number] = ACTIONS(2563),
    [anon_sym_boolean] = ACTIONS(2563),
    [anon_sym_string] = ACTIONS(2563),
    [anon_sym_symbol] = ACTIONS(2563),
    [anon_sym_object] = ACTIONS(2563),
    [anon_sym_abstract] = ACTIONS(2563),
    [anon_sym_interface] = ACTIONS(2563),
    [anon_sym_enum] = ACTIONS(2563),
    [sym_html_comment] = ACTIONS(5),
  },
  [823] = {
    [ts_builtin_sym_end] = ACTIONS(2581),
    [sym_identifier] = ACTIONS(2583),
    [anon_sym_export] = ACTIONS(2583),
    [anon_sym_default] = ACTIONS(2583),
    [anon_sym_type] = ACTIONS(2583),
    [anon_sym_namespace] = ACTIONS(2583),
    [anon_sym_LBRACE] = ACTIONS(2581),
    [anon_sym_RBRACE] = ACTIONS(2581),
    [anon_sym_typeof] = ACTIONS(2583),
    [anon_sym_import] = ACTIONS(2583),
    [anon_sym_with] = ACTIONS(2583),
    [anon_sym_var] = ACTIONS(2583),
    [anon_sym_let] = ACTIONS(2583),
    [anon_sym_const] = ACTIONS(2583),
    [anon_sym_BANG] = ACTIONS(2581),
    [anon_sym_else] = ACTIONS(2583),
    [anon_sym_if] = ACTIONS(2583),
    [anon_sym_switch] = ACTIONS(2583),
    [anon_sym_for] = ACTIONS(2583),
    [anon_sym_LPAREN] = ACTIONS(2581),
    [anon_sym_SEMI] = ACTIONS(2581),
    [anon_sym_await] = ACTIONS(2583),
    [anon_sym_while] = ACTIONS(2583),
    [anon_sym_do] = ACTIONS(2583),
    [anon_sym_try] = ACTIONS(2583),
    [anon_sym_break] = ACTIONS(2583),
    [anon_sym_continue] = ACTIONS(2583),
    [anon_sym_debugger] = ACTIONS(2583),
    [anon_sym_return] = ACTIONS(2583),
    [anon_sym_throw] = ACTIONS(2583),
    [anon_sym_case] = ACTIONS(2583),
    [anon_sym_yield] = ACTIONS(2583),
    [anon_sym_LBRACK] = ACTIONS(2581),
    [anon_sym_class] = ACTIONS(2583),
    [anon_sym_async] = ACTIONS(2583),
    [anon_sym_function] = ACTIONS(2583),
    [anon_sym_new] = ACTIONS(2583),
    [anon_sym_using] = ACTIONS(2583),
    [anon_sym_PLUS] = ACTIONS(2583),
    [anon_sym_DASH] = ACTIONS(2583),
    [anon_sym_SLASH] = ACTIONS(2583),
    [anon_sym_LT] = ACTIONS(2581),
    [anon_sym_TILDE] = ACTIONS(2581),
    [anon_sym_void] = ACTIONS(2583),
    [anon_sym_delete] = ACTIONS(2583),
    [anon_sym_PLUS_PLUS] = ACTIONS(2581),
    [anon_sym_DASH_DASH] = ACTIONS(2581),
    [anon_sym_DQUOTE] = ACTIONS(2581),
    [anon_sym_SQUOTE] = ACTIONS(2581),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(2581),
    [sym_number] = ACTIONS(2581),
    [sym_private_property_identifier] = ACTIONS(2581),
    [sym_this] = ACTIONS(2583),
    [sym_super] = ACTIONS(2583),
    [sym_true] = ACTIONS(2583),
    [sym_false] = ACTIONS(2583),
    [sym_null] = ACTIONS(2583),
    [sym_undefined] = ACTIONS(2583),
    [anon_sym_AT] = ACTIONS(2581),
    [anon_sym_static] = ACTIONS(2583),
    [anon_sym_readonly] = ACTIONS(2583),
    [anon_sym_get] = ACTIONS(2583),
    [anon_sym_set] = ACTIONS(2583),
    [anon_sym_declare] = ACTIONS(2583),
    [anon_sym_public] = ACTIONS(2583),
    [anon_sym_private] = ACTIONS(2583),
    [anon_sym_protected] = ACTIONS(2583),
    [anon_sym_override] = ACTIONS(2583),
    [anon_sym_module] = ACTIONS(2583),
    [anon_sym_any] = ACTIONS(2583),
    [anon_sym_number] = ACTIONS(2583),
    [anon_sym_boolean] = ACTIONS(2583),
    [anon_sym_string] = ACTIONS(2583),
    [anon_sym_symbol] = ACTIONS(2583),
    [anon_sym_object] = ACTIONS(2583),
    [anon_sym_abstract] = ACTIONS(2583),
    [anon_sym_interface] = ACTIONS(2583),
    [anon_sym_enum] = ACTIONS(2583),
    [sym_html_comment] = ACTIONS(5),
  },
  [824] = {
    [ts_builtin_sym_end] = ACTIONS(1730),
    [sym_identifier] = ACTIONS(1732),
    [anon_sym_export] = ACTIONS(1732),
    [anon_sym_default] = ACTIONS(1732),
    [anon_sym_type] = ACTIONS(1732),
    [anon_sym_namespace] = ACTIONS(1732),
    [anon_sym_LBRACE] = ACTIONS(1730),
    [anon_sym_RBRACE] = ACTIONS(1730),
    [anon_sym_typeof] = ACTIONS(1732),
    [anon_sym_import] = ACTIONS(1732),
    [anon_sym_with] = ACTIONS(1732),
    [anon_sym_var] = ACTIONS(1732),
    [anon_sym_let] = ACTIONS(1732),
    [anon_sym_const] = ACTIONS(1732),
    [anon_sym_BANG] = ACTIONS(1730),
    [anon_sym_else] = ACTIONS(1732),
    [anon_sym_if] = ACTIONS(1732),
    [anon_sym_switch] = ACTIONS(1732),
    [anon_sym_for] = ACTIONS(1732),
    [anon_sym_LPAREN] = ACTIONS(1730),
    [anon_sym_SEMI] = ACTIONS(1730),
    [anon_sym_await] = ACTIONS(1732),
    [anon_sym_while] = ACTIONS(1732),
    [anon_sym_do] = ACTIONS(1732),
    [anon_sym_try] = ACTIONS(1732),
    [anon_sym_break] = ACTIONS(1732),
    [anon_sym_continue] = ACTIONS(1732),
    [anon_sym_debugger] = ACTIONS(1732),
    [anon_sym_return] = ACTIONS(1732),
    [anon_sym_throw] = ACTIONS(1732),
    [anon_sym_case] = ACTIONS(1732),
    [anon_sym_yield] = ACTIONS(1732),
    [anon_sym_LBRACK] = ACTIONS(1730),
    [anon_sym_class] = ACTIONS(1732),
    [anon_sym_async] = ACTIONS(1732),
    [anon_sym_function] = ACTIONS(1732),
    [anon_sym_new] = ACTIONS(1732),
    [anon_sym_using] = ACTIONS(1732),
    [anon_sym_PLUS] = ACTIONS(1732),
    [anon_sym_DASH] = ACTIONS(1732),
    [anon_sym_SLASH] = ACTIONS(1732),
    [anon_sym_LT] = ACTIONS(1730),
    [anon_sym_TILDE] = ACTIONS(1730),
    [anon_sym_void] = ACTIONS(1732),
    [anon_sym_delete] = ACTIONS(1732),
    [anon_sym_PLUS_PLUS] = ACTIONS(1730),
    [anon_sym_DASH_DASH] = ACTIONS(1730),
    [anon_sym_DQUOTE] = ACTIONS(1730),
    [anon_sym_SQUOTE] = ACTIONS(1730),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1730),
    [sym_number] = ACTIONS(1730),
    [sym_private_property_identifier] = ACTIONS(1730),
    [sym_this] = ACTIONS(1732),
    [sym_super] = ACTIONS(1732),
    [sym_true] = ACTIONS(1732),
    [sym_false] = ACTIONS(1732),
    [sym_null] = ACTIONS(1732),
    [sym_undefined] = ACTIONS(1732),
    [anon_sym_AT] = ACTIONS(1730),
    [anon_sym_static] = ACTIONS(1732),
    [anon_sym_readonly] = ACTIONS(1732),
    [anon_sym_get] = ACTIONS(1732),
    [anon_sym_set] = ACTIONS(1732),
    [anon_sym_declare] = ACTIONS(1732),
    [anon_sym_public] = ACTIONS(1732),
    [anon_sym_private] = ACTIONS(1732),
    [anon_sym_protected] = ACTIONS(1732),
    [anon_sym_override] = ACTIONS(1732),
    [anon_sym_module] = ACTIONS(1732),
    [anon_sym_any] = ACTIONS(1732),
    [anon_sym_number] = ACTIONS(1732),
    [anon_sym_boolean] = ACTIONS(1732),
    [anon_sym_string] = ACTIONS(1732),
    [anon_sym_symbol] = ACTIONS(1732),
    [anon_sym_object] = ACTIONS(1732),
    [anon_sym_abstract] = ACTIONS(1732),
    [anon_sym_interface] = ACTIONS(1732),
    [anon_sym_enum] = ACTIONS(1732),
    [sym_html_comment] = ACTIONS(5),
  },
  [825] = {
    [ts_builtin_sym_end] = ACTIONS(2585),
    [sym_identifier] = ACTIONS(2587),
    [anon_sym_export] = ACTIONS(2587),
    [anon_sym_default] = ACTIONS(2587),
    [anon_sym_type] = ACTIONS(2587),
    [anon_sym_namespace] = ACTIONS(2587),
    [anon_sym_LBRACE] = ACTIONS(2585),
    [anon_sym_RBRACE] = ACTIONS(2585),
    [anon_sym_typeof] = ACTIONS(2587),
    [anon_sym_import] = ACTIONS(2587),
    [anon_sym_with] = ACTIONS(2587),
    [anon_sym_var] = ACTIONS(2587),
    [anon_sym_let] = ACTIONS(2587),
    [anon_sym_const] = ACTIONS(2587),
    [anon_sym_BANG] = ACTIONS(2585),
    [anon_sym_else] = ACTIONS(2587),
    [anon_sym_if] = ACTIONS(2587),
    [anon_sym_switch] = ACTIONS(2587),
    [anon_sym_for] = ACTIONS(2587),
    [anon_sym_LPAREN] = ACTIONS(2585),
    [anon_sym_SEMI] = ACTIONS(2585),
    [anon_sym_await] = ACTIONS(2587),
    [anon_sym_while] = ACTIONS(2587),
    [anon_sym_do] = ACTIONS(2587),
    [anon_sym_try] = ACTIONS(2587),
    [anon_sym_break] = ACTIONS(2587),
    [anon_sym_continue] = ACTIONS(2587),
    [anon_sym_debugger] = ACTIONS(2587),
    [anon_sym_return] = ACTIONS(2587),
    [anon_sym_throw] = ACTIONS(2587),
    [anon_sym_case] = ACTIONS(2587),
    [anon_sym_yield] = ACTIONS(2587),
    [anon_sym_LBRACK] = ACTIONS(2585),
    [anon_sym_class] = ACTIONS(2587),
    [anon_sym_async] = ACTIONS(2587),
    [anon_sym_function] = ACTIONS(2587),
    [anon_sym_new] = ACTIONS(2587),
    [anon_sym_using] = ACTIONS(2587),
    [anon_sym_PLUS] = ACTIONS(2587),
    [anon_sym_DASH] = ACTIONS(2587),
    [anon_sym_SLASH] = ACTIONS(2587),
    [anon_sym_LT] = ACTIONS(2585),
    [anon_sym_TILDE] = ACTIONS(2585),
    [anon_sym_void] = ACTIONS(2587),
    [anon_sym_delete] = ACTIONS(2587),
    [anon_sym_PLUS_PLUS] = ACTIONS(2585),
    [anon_sym_DASH_DASH] = ACTIONS(2585),
    [anon_sym_DQUOTE] = ACTIONS(2585),
    [anon_sym_SQUOTE] = ACTIONS(2585),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(2585),
    [sym_number] = ACTIONS(2585),
    [sym_private_property_identifier] = ACTIONS(2585),
    [sym_this] = ACTIONS(2587),
    [sym_super] = ACTIONS(2587),
    [sym_true] = ACTIONS(2587),
    [sym_false] = ACTIONS(2587),
    [sym_null] = ACTIONS(2587),
    [sym_undefined] = ACTIONS(2587),
    [anon_sym_AT] = ACTIONS(2585),
    [anon_sym_static] = ACTIONS(2587),
    [anon_sym_readonly] = ACTIONS(2587),
    [anon_sym_get] = ACTIONS(2587),
    [anon_sym_set] = ACTIONS(2587),
    [anon_sym_declare] = ACTIONS(2587),
    [anon_sym_public] = ACTIONS(2587),
    [anon_sym_private] = ACTIONS(2587),
    [anon_sym_protected] = ACTIONS(2587),
    [anon_sym_override] = ACTIONS(2587),
    [anon_sym_module] = ACTIONS(2587),
    [anon_sym_any] = ACTIONS(2587),
    [anon_sym_number] = ACTIONS(2587),
    [anon_sym_boolean] = ACTIONS(2587),
    [anon_sym_string] = ACTIONS(2587),
    [anon_sym_symbol] = ACTIONS(2587),
    [anon_sym_object] = ACTIONS(2587),
    [anon_sym_abstract] = ACTIONS(2587),
    [anon_sym_interface] = ACTIONS(2587),
    [anon_sym_enum] = ACTIONS(2587),
    [sym_html_comment] = ACTIONS(5),
  },
  [826] = {
    [ts_builtin_sym_end] = ACTIONS(2589),
    [sym_identifier] = ACTIONS(2591),
    [anon_sym_export] = ACTIONS(2591),
    [anon_sym_default] = ACTIONS(2591),
    [anon_sym_type] = ACTIONS(2591),
    [anon_sym_namespace] = ACTIONS(2591),
    [anon_sym_LBRACE] = ACTIONS(2589),
    [anon_sym_RBRACE] = ACTIONS(2589),
    [anon_sym_typeof] = ACTIONS(2591),
    [anon_sym_import] = ACTIONS(2591),
    [anon_sym_with] = ACTIONS(2591),
    [anon_sym_var] = ACTIONS(2591),
    [anon_sym_let] = ACTIONS(2591),
    [anon_sym_const] = ACTIONS(2591),
    [anon_sym_BANG] = ACTIONS(2589),
    [anon_sym_else] = ACTIONS(2591),
    [anon_sym_if] = ACTIONS(2591),
    [anon_sym_switch] = ACTIONS(2591),
    [anon_sym_for] = ACTIONS(2591),
    [anon_sym_LPAREN] = ACTIONS(2589),
    [anon_sym_SEMI] = ACTIONS(2589),
    [anon_sym_await] = ACTIONS(2591),
    [anon_sym_while] = ACTIONS(2591),
    [anon_sym_do] = ACTIONS(2591),
    [anon_sym_try] = ACTIONS(2591),
    [anon_sym_break] = ACTIONS(2591),
    [anon_sym_continue] = ACTIONS(2591),
    [anon_sym_debugger] = ACTIONS(2591),
    [anon_sym_return] = ACTIONS(2591),
    [anon_sym_throw] = ACTIONS(2591),
    [anon_sym_case] = ACTIONS(2591),
    [anon_sym_yield] = ACTIONS(2591),
    [anon_sym_LBRACK] = ACTIONS(2589),
    [anon_sym_class] = ACTIONS(2591),
    [anon_sym_async] = ACTIONS(2591),
    [anon_sym_function] = ACTIONS(2591),
    [anon_sym_new] = ACTIONS(2591),
    [anon_sym_using] = ACTIONS(2591),
    [anon_sym_PLUS] = ACTIONS(2591),
    [anon_sym_DASH] = ACTIONS(2591),
    [anon_sym_SLASH] = ACTIONS(2591),
    [anon_sym_LT] = ACTIONS(2589),
    [anon_sym_TILDE] = ACTIONS(2589),
    [anon_sym_void] = ACTIONS(2591),
    [anon_sym_delete] = ACTIONS(2591),
    [anon_sym_PLUS_PLUS] = ACTIONS(2589),
    [anon_sym_DASH_DASH] = ACTIONS(2589),
    [anon_sym_DQUOTE] = ACTIONS(2589),
    [anon_sym_SQUOTE] = ACTIONS(2589),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(2589),
    [sym_number] = ACTIONS(2589),
    [sym_private_property_identifier] = ACTIONS(2589),
    [sym_this] = ACTIONS(2591),
    [sym_super] = ACTIONS(2591),
    [sym_true] = ACTIONS(2591),
    [sym_false] = ACTIONS(2591),
    [sym_null] = ACTIONS(2591),
    [sym_undefined] = ACTIONS(2591),
    [anon_sym_AT] = ACTIONS(2589),
    [anon_sym_static] = ACTIONS(2591),
    [anon_sym_readonly] = ACTIONS(2591),
    [anon_sym_get] = ACTIONS(2591),
    [anon_sym_set] = ACTIONS(2591),
    [anon_sym_declare] = ACTIONS(2591),
    [anon_sym_public] = ACTIONS(2591),
    [anon_sym_private] = ACTIONS(2591),
    [anon_sym_protected] = ACTIONS(2591),
    [anon_sym_override] = ACTIONS(2591),
    [anon_sym_module] = ACTIONS(2591),
    [anon_sym_any] = ACTIONS(2591),
    [anon_sym_number] = ACTIONS(2591),
    [anon_sym_boolean] = ACTIONS(2591),
    [anon_sym_string] = ACTIONS(2591),
    [anon_sym_symbol] = ACTIONS(2591),
    [anon_sym_object] = ACTIONS(2591),
    [anon_sym_abstract] = ACTIONS(2591),
    [anon_sym_interface] = ACTIONS(2591),
    [anon_sym_enum] = ACTIONS(2591),
    [sym_html_comment] = ACTIONS(5),
  },
  [827] = {
    [ts_builtin_sym_end] = ACTIONS(2593),
    [sym_identifier] = ACTIONS(2595),
    [anon_sym_export] = ACTIONS(2595),
    [anon_sym_default] = ACTIONS(2595),
    [anon_sym_type] = ACTIONS(2595),
    [anon_sym_namespace] = ACTIONS(2595),
    [anon_sym_LBRACE] = ACTIONS(2593),
    [anon_sym_RBRACE] = ACTIONS(2593),
    [anon_sym_typeof] = ACTIONS(2595),
    [anon_sym_import] = ACTIONS(2595),
    [anon_sym_with] = ACTIONS(2595),
    [anon_sym_var] = ACTIONS(2595),
    [anon_sym_let] = ACTIONS(2595),
    [anon_sym_const] = ACTIONS(2595),
    [anon_sym_BANG] = ACTIONS(2593),
    [anon_sym_else] = ACTIONS(2595),
    [anon_sym_if] = ACTIONS(2595),
    [anon_sym_switch] = ACTIONS(2595),
    [anon_sym_for] = ACTIONS(2595),
    [anon_sym_LPAREN] = ACTIONS(2593),
    [anon_sym_SEMI] = ACTIONS(2593),
    [anon_sym_await] = ACTIONS(2595),
    [anon_sym_while] = ACTIONS(2595),
    [anon_sym_do] = ACTIONS(2595),
    [anon_sym_try] = ACTIONS(2595),
    [anon_sym_break] = ACTIONS(2595),
    [anon_sym_continue] = ACTIONS(2595),
    [anon_sym_debugger] = ACTIONS(2595),
    [anon_sym_return] = ACTIONS(2595),
    [anon_sym_throw] = ACTIONS(2595),
    [anon_sym_case] = ACTIONS(2595),
    [anon_sym_yield] = ACTIONS(2595),
    [anon_sym_LBRACK] = ACTIONS(2593),
    [anon_sym_class] = ACTIONS(2595),
    [anon_sym_async] = ACTIONS(2595),
    [anon_sym_function] = ACTIONS(2595),
    [anon_sym_new] = ACTIONS(2595),
    [anon_sym_using] = ACTIONS(2595),
    [anon_sym_PLUS] = ACTIONS(2595),
    [anon_sym_DASH] = ACTIONS(2595),
    [anon_sym_SLASH] = ACTIONS(2595),
    [anon_sym_LT] = ACTIONS(2593),
    [anon_sym_TILDE] = ACTIONS(2593),
    [anon_sym_void] = ACTIONS(2595),
    [anon_sym_delete] = ACTIONS(2595),
    [anon_sym_PLUS_PLUS] = ACTIONS(2593),
    [anon_sym_DASH_DASH] = ACTIONS(2593),
    [anon_sym_DQUOTE] = ACTIONS(2593),
    [anon_sym_SQUOTE] = ACTIONS(2593),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(2593),
    [sym_number] = ACTIONS(2593),
    [sym_private_property_identifier] = ACTIONS(2593),
    [sym_this] = ACTIONS(2595),
    [sym_super] = ACTIONS(2595),
    [sym_true] = ACTIONS(2595),
    [sym_false] = ACTIONS(2595),
    [sym_null] = ACTIONS(2595),
    [sym_undefined] = ACTIONS(2595),
    [anon_sym_AT] = ACTIONS(2593),
    [anon_sym_static] = ACTIONS(2595),
    [anon_sym_readonly] = ACTIONS(2595),
    [anon_sym_get] = ACTIONS(2595),
    [anon_sym_set] = ACTIONS(2595),
    [anon_sym_declare] = ACTIONS(2595),
    [anon_sym_public] = ACTIONS(2595),
    [anon_sym_private] = ACTIONS(2595),
    [anon_sym_protected] = ACTIONS(2595),
    [anon_sym_override] = ACTIONS(2595),
    [anon_sym_module] = ACTIONS(2595),
    [anon_sym_any] = ACTIONS(2595),
    [anon_sym_number] = ACTIONS(2595),
    [anon_sym_boolean] = ACTIONS(2595),
    [anon_sym_string] = ACTIONS(2595),
    [anon_sym_symbol] = ACTIONS(2595),
    [anon_sym_object] = ACTIONS(2595),
    [anon_sym_abstract] = ACTIONS(2595),
    [anon_sym_interface] = ACTIONS(2595),
    [anon_sym_enum] = ACTIONS(2595),
    [sym_html_comment] = ACTIONS(5),
  },
  [828] = {
    [ts_builtin_sym_end] = ACTIONS(2597),
    [sym_identifier] = ACTIONS(2599),
    [anon_sym_export] = ACTIONS(2599),
    [anon_sym_default] = ACTIONS(2599),
    [anon_sym_type] = ACTIONS(2599),
    [anon_sym_namespace] = ACTIONS(2599),
    [anon_sym_LBRACE] = ACTIONS(2597),
    [anon_sym_RBRACE] = ACTIONS(2597),
    [anon_sym_typeof] = ACTIONS(2599),
    [anon_sym_import] = ACTIONS(2599),
    [anon_sym_with] = ACTIONS(2599),
    [anon_sym_var] = ACTIONS(2599),
    [anon_sym_let] = ACTIONS(2599),
    [anon_sym_const] = ACTIONS(2599),
    [anon_sym_BANG] = ACTIONS(2597),
    [anon_sym_else] = ACTIONS(2599),
    [anon_sym_if] = ACTIONS(2599),
    [anon_sym_switch] = ACTIONS(2599),
    [anon_sym_for] = ACTIONS(2599),
    [anon_sym_LPAREN] = ACTIONS(2597),
    [anon_sym_SEMI] = ACTIONS(2597),
    [anon_sym_await] = ACTIONS(2599),
    [anon_sym_while] = ACTIONS(2599),
    [anon_sym_do] = ACTIONS(2599),
    [anon_sym_try] = ACTIONS(2599),
    [anon_sym_break] = ACTIONS(2599),
    [anon_sym_continue] = ACTIONS(2599),
    [anon_sym_debugger] = ACTIONS(2599),
    [anon_sym_return] = ACTIONS(2599),
    [anon_sym_throw] = ACTIONS(2599),
    [anon_sym_case] = ACTIONS(2599),
    [anon_sym_yield] = ACTIONS(2599),
    [anon_sym_LBRACK] = ACTIONS(2597),
    [anon_sym_class] = ACTIONS(2599),
    [anon_sym_async] = ACTIONS(2599),
    [anon_sym_function] = ACTIONS(2599),
    [anon_sym_new] = ACTIONS(2599),
    [anon_sym_using] = ACTIONS(2599),
    [anon_sym_PLUS] = ACTIONS(2599),
    [anon_sym_DASH] = ACTIONS(2599),
    [anon_sym_SLASH] = ACTIONS(2599),
    [anon_sym_LT] = ACTIONS(2597),
    [anon_sym_TILDE] = ACTIONS(2597),
    [anon_sym_void] = ACTIONS(2599),
    [anon_sym_delete] = ACTIONS(2599),
    [anon_sym_PLUS_PLUS] = ACTIONS(2597),
    [anon_sym_DASH_DASH] = ACTIONS(2597),
    [anon_sym_DQUOTE] = ACTIONS(2597),
    [anon_sym_SQUOTE] = ACTIONS(2597),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(2597),
    [sym_number] = ACTIONS(2597),
    [sym_private_property_identifier] = ACTIONS(2597),
    [sym_this] = ACTIONS(2599),
    [sym_super] = ACTIONS(2599),
    [sym_true] = ACTIONS(2599),
    [sym_false] = ACTIONS(2599),
    [sym_null] = ACTIONS(2599),
    [sym_undefined] = ACTIONS(2599),
    [anon_sym_AT] = ACTIONS(2597),
    [anon_sym_static] = ACTIONS(2599),
    [anon_sym_readonly] = ACTIONS(2599),
    [anon_sym_get] = ACTIONS(2599),
    [anon_sym_set] = ACTIONS(2599),
    [anon_sym_declare] = ACTIONS(2599),
    [anon_sym_public] = ACTIONS(2599),
    [anon_sym_private] = ACTIONS(2599),
    [anon_sym_protected] = ACTIONS(2599),
    [anon_sym_override] = ACTIONS(2599),
    [anon_sym_module] = ACTIONS(2599),
    [anon_sym_any] = ACTIONS(2599),
    [anon_sym_number] = ACTIONS(2599),
    [anon_sym_boolean] = ACTIONS(2599),
    [anon_sym_string] = ACTIONS(2599),
    [anon_sym_symbol] = ACTIONS(2599),
    [anon_sym_object] = ACTIONS(2599),
    [anon_sym_abstract] = ACTIONS(2599),
    [anon_sym_interface] = ACTIONS(2599),
    [anon_sym_enum] = ACTIONS(2599),
    [sym_html_comment] = ACTIONS(5),
  },
  [829] = {
    [ts_builtin_sym_end] = ACTIONS(2569),
    [sym_identifier] = ACTIONS(2571),
    [anon_sym_export] = ACTIONS(2571),
    [anon_sym_default] = ACTIONS(2571),
    [anon_sym_type] = ACTIONS(2571),
    [anon_sym_namespace] = ACTIONS(2571),
    [anon_sym_LBRACE] = ACTIONS(2569),
    [anon_sym_RBRACE] = ACTIONS(2569),
    [anon_sym_typeof] = ACTIONS(2571),
    [anon_sym_import] = ACTIONS(2571),
    [anon_sym_with] = ACTIONS(2571),
    [anon_sym_var] = ACTIONS(2571),
    [anon_sym_let] = ACTIONS(2571),
    [anon_sym_const] = ACTIONS(2571),
    [anon_sym_BANG] = ACTIONS(2569),
    [anon_sym_else] = ACTIONS(2571),
    [anon_sym_if] = ACTIONS(2571),
    [anon_sym_switch] = ACTIONS(2571),
    [anon_sym_for] = ACTIONS(2571),
    [anon_sym_LPAREN] = ACTIONS(2569),
    [anon_sym_SEMI] = ACTIONS(2569),
    [anon_sym_await] = ACTIONS(2571),
    [anon_sym_while] = ACTIONS(2571),
    [anon_sym_do] = ACTIONS(2571),
    [anon_sym_try] = ACTIONS(2571),
    [anon_sym_break] = ACTIONS(2571),
    [anon_sym_continue] = ACTIONS(2571),
    [anon_sym_debugger] = ACTIONS(2571),
    [anon_sym_return] = ACTIONS(2571),
    [anon_sym_throw] = ACTIONS(2571),
    [anon_sym_case] = ACTIONS(2571),
    [anon_sym_yield] = ACTIONS(2571),
    [anon_sym_LBRACK] = ACTIONS(2569),
    [anon_sym_class] = ACTIONS(2571),
    [anon_sym_async] = ACTIONS(2571),
    [anon_sym_function] = ACTIONS(2571),
    [anon_sym_new] = ACTIONS(2571),
    [anon_sym_using] = ACTIONS(2571),
    [anon_sym_PLUS] = ACTIONS(2571),
    [anon_sym_DASH] = ACTIONS(2571),
    [anon_sym_SLASH] = ACTIONS(2571),
    [anon_sym_LT] = ACTIONS(2569),
    [anon_sym_TILDE] = ACTIONS(2569),
    [anon_sym_void] = ACTIONS(2571),
    [anon_sym_delete] = ACTIONS(2571),
    [anon_sym_PLUS_PLUS] = ACTIONS(2569),
    [anon_sym_DASH_DASH] = ACTIONS(2569),
    [anon_sym_DQUOTE] = ACTIONS(2569),
    [anon_sym_SQUOTE] = ACTIONS(2569),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(2569),
    [sym_number] = ACTIONS(2569),
    [sym_private_property_identifier] = ACTIONS(2569),
    [sym_this] = ACTIONS(2571),
    [sym_super] = ACTIONS(2571),
    [sym_true] = ACTIONS(2571),
    [sym_false] = ACTIONS(2571),
    [sym_null] = ACTIONS(2571),
    [sym_undefined] = ACTIONS(2571),
    [anon_sym_AT] = ACTIONS(2569),
    [anon_sym_static] = ACTIONS(2571),
    [anon_sym_readonly] = ACTIONS(2571),
    [anon_sym_get] = ACTIONS(2571),
    [anon_sym_set] = ACTIONS(2571),
    [anon_sym_declare] = ACTIONS(2571),
    [anon_sym_public] = ACTIONS(2571),
    [anon_sym_private] = ACTIONS(2571),
    [anon_sym_protected] = ACTIONS(2571),
    [anon_sym_override] = ACTIONS(2571),
    [anon_sym_module] = ACTIONS(2571),
    [anon_sym_any] = ACTIONS(2571),
    [anon_sym_number] = ACTIONS(2571),
    [anon_sym_boolean] = ACTIONS(2571),
    [anon_sym_string] = ACTIONS(2571),
    [anon_sym_symbol] = ACTIONS(2571),
    [anon_sym_object] = ACTIONS(2571),
    [anon_sym_abstract] = ACTIONS(2571),
    [anon_sym_interface] = ACTIONS(2571),
    [anon_sym_enum] = ACTIONS(2571),
    [sym_html_comment] = ACTIONS(5),
  },
  [830] = {
    [ts_builtin_sym_end] = ACTIONS(2601),
    [sym_identifier] = ACTIONS(2603),
    [anon_sym_export] = ACTIONS(2603),
    [anon_sym_default] = ACTIONS(2603),
    [anon_sym_type] = ACTIONS(2603),
    [anon_sym_namespace] = ACTIONS(2603),
    [anon_sym_LBRACE] = ACTIONS(2601),
    [anon_sym_RBRACE] = ACTIONS(2601),
    [anon_sym_typeof] = ACTIONS(2603),
    [anon_sym_import] = ACTIONS(2603),
    [anon_sym_with] = ACTIONS(2603),
    [anon_sym_var] = ACTIONS(2603),
    [anon_sym_let] = ACTIONS(2603),
    [anon_sym_const] = ACTIONS(2603),
    [anon_sym_BANG] = ACTIONS(2601),
    [anon_sym_else] = ACTIONS(2603),
    [anon_sym_if] = ACTIONS(2603),
    [anon_sym_switch] = ACTIONS(2603),
    [anon_sym_for] = ACTIONS(2603),
    [anon_sym_LPAREN] = ACTIONS(2601),
    [anon_sym_SEMI] = ACTIONS(2601),
    [anon_sym_await] = ACTIONS(2603),
    [anon_sym_while] = ACTIONS(2603),
    [anon_sym_do] = ACTIONS(2603),
    [anon_sym_try] = ACTIONS(2603),
    [anon_sym_break] = ACTIONS(2603),
    [anon_sym_continue] = ACTIONS(2603),
    [anon_sym_debugger] = ACTIONS(2603),
    [anon_sym_return] = ACTIONS(2603),
    [anon_sym_throw] = ACTIONS(2603),
    [anon_sym_case] = ACTIONS(2603),
    [anon_sym_yield] = ACTIONS(2603),
    [anon_sym_LBRACK] = ACTIONS(2601),
    [anon_sym_class] = ACTIONS(2603),
    [anon_sym_async] = ACTIONS(2603),
    [anon_sym_function] = ACTIONS(2603),
    [anon_sym_new] = ACTIONS(2603),
    [anon_sym_using] = ACTIONS(2603),
    [anon_sym_PLUS] = ACTIONS(2603),
    [anon_sym_DASH] = ACTIONS(2603),
    [anon_sym_SLASH] = ACTIONS(2603),
    [anon_sym_LT] = ACTIONS(2601),
    [anon_sym_TILDE] = ACTIONS(2601),
    [anon_sym_void] = ACTIONS(2603),
    [anon_sym_delete] = ACTIONS(2603),
    [anon_sym_PLUS_PLUS] = ACTIONS(2601),
    [anon_sym_DASH_DASH] = ACTIONS(2601),
    [anon_sym_DQUOTE] = ACTIONS(2601),
    [anon_sym_SQUOTE] = ACTIONS(2601),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(2601),
    [sym_number] = ACTIONS(2601),
    [sym_private_property_identifier] = ACTIONS(2601),
    [sym_this] = ACTIONS(2603),
    [sym_super] = ACTIONS(2603),
    [sym_true] = ACTIONS(2603),
    [sym_false] = ACTIONS(2603),
    [sym_null] = ACTIONS(2603),
    [sym_undefined] = ACTIONS(2603),
    [anon_sym_AT] = ACTIONS(2601),
    [anon_sym_static] = ACTIONS(2603),
    [anon_sym_readonly] = ACTIONS(2603),
    [anon_sym_get] = ACTIONS(2603),
    [anon_sym_set] = ACTIONS(2603),
    [anon_sym_declare] = ACTIONS(2603),
    [anon_sym_public] = ACTIONS(2603),
    [anon_sym_private] = ACTIONS(2603),
    [anon_sym_protected] = ACTIONS(2603),
    [anon_sym_override] = ACTIONS(2603),
    [anon_sym_module] = ACTIONS(2603),
    [anon_sym_any] = ACTIONS(2603),
    [anon_sym_number] = ACTIONS(2603),
    [anon_sym_boolean] = ACTIONS(2603),
    [anon_sym_string] = ACTIONS(2603),
    [anon_sym_symbol] = ACTIONS(2603),
    [anon_sym_object] = ACTIONS(2603),
    [anon_sym_abstract] = ACTIONS(2603),
    [anon_sym_interface] = ACTIONS(2603),
    [anon_sym_enum] = ACTIONS(2603),
    [sym_html_comment] = ACTIONS(5),
  },
  [831] = {
    [ts_builtin_sym_end] = ACTIONS(1730),
    [sym_identifier] = ACTIONS(1732),
    [anon_sym_export] = ACTIONS(1732),
    [anon_sym_default] = ACTIONS(1732),
    [anon_sym_type] = ACTIONS(1732),
    [anon_sym_namespace] = ACTIONS(1732),
    [anon_sym_LBRACE] = ACTIONS(1730),
    [anon_sym_RBRACE] = ACTIONS(1730),
    [anon_sym_typeof] = ACTIONS(1732),
    [anon_sym_import] = ACTIONS(1732),
    [anon_sym_with] = ACTIONS(1732),
    [anon_sym_var] = ACTIONS(1732),
    [anon_sym_let] = ACTIONS(1732),
    [anon_sym_const] = ACTIONS(1732),
    [anon_sym_BANG] = ACTIONS(1730),
    [anon_sym_else] = ACTIONS(1732),
    [anon_sym_if] = ACTIONS(1732),
    [anon_sym_switch] = ACTIONS(1732),
    [anon_sym_for] = ACTIONS(1732),
    [anon_sym_LPAREN] = ACTIONS(1730),
    [anon_sym_SEMI] = ACTIONS(1730),
    [anon_sym_await] = ACTIONS(1732),
    [anon_sym_while] = ACTIONS(1732),
    [anon_sym_do] = ACTIONS(1732),
    [anon_sym_try] = ACTIONS(1732),
    [anon_sym_break] = ACTIONS(1732),
    [anon_sym_continue] = ACTIONS(1732),
    [anon_sym_debugger] = ACTIONS(1732),
    [anon_sym_return] = ACTIONS(1732),
    [anon_sym_throw] = ACTIONS(1732),
    [anon_sym_case] = ACTIONS(1732),
    [anon_sym_yield] = ACTIONS(1732),
    [anon_sym_LBRACK] = ACTIONS(1730),
    [anon_sym_class] = ACTIONS(1732),
    [anon_sym_async] = ACTIONS(1732),
    [anon_sym_function] = ACTIONS(1732),
    [anon_sym_new] = ACTIONS(1732),
    [anon_sym_using] = ACTIONS(1732),
    [anon_sym_PLUS] = ACTIONS(1732),
    [anon_sym_DASH] = ACTIONS(1732),
    [anon_sym_SLASH] = ACTIONS(1732),
    [anon_sym_LT] = ACTIONS(1730),
    [anon_sym_TILDE] = ACTIONS(1730),
    [anon_sym_void] = ACTIONS(1732),
    [anon_sym_delete] = ACTIONS(1732),
    [anon_sym_PLUS_PLUS] = ACTIONS(1730),
    [anon_sym_DASH_DASH] = ACTIONS(1730),
    [anon_sym_DQUOTE] = ACTIONS(1730),
    [anon_sym_SQUOTE] = ACTIONS(1730),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1730),
    [sym_number] = ACTIONS(1730),
    [sym_private_property_identifier] = ACTIONS(1730),
    [sym_this] = ACTIONS(1732),
    [sym_super] = ACTIONS(1732),
    [sym_true] = ACTIONS(1732),
    [sym_false] = ACTIONS(1732),
    [sym_null] = ACTIONS(1732),
    [sym_undefined] = ACTIONS(1732),
    [anon_sym_AT] = ACTIONS(1730),
    [anon_sym_static] = ACTIONS(1732),
    [anon_sym_readonly] = ACTIONS(1732),
    [anon_sym_get] = ACTIONS(1732),
    [anon_sym_set] = ACTIONS(1732),
    [anon_sym_declare] = ACTIONS(1732),
    [anon_sym_public] = ACTIONS(1732),
    [anon_sym_private] = ACTIONS(1732),
    [anon_sym_protected] = ACTIONS(1732),
    [anon_sym_override] = ACTIONS(1732),
    [anon_sym_module] = ACTIONS(1732),
    [anon_sym_any] = ACTIONS(1732),
    [anon_sym_number] = ACTIONS(1732),
    [anon_sym_boolean] = ACTIONS(1732),
    [anon_sym_string] = ACTIONS(1732),
    [anon_sym_symbol] = ACTIONS(1732),
    [anon_sym_object] = ACTIONS(1732),
    [anon_sym_abstract] = ACTIONS(1732),
    [anon_sym_interface] = ACTIONS(1732),
    [anon_sym_enum] = ACTIONS(1732),
    [sym_html_comment] = ACTIONS(5),
  },
  [832] = {
    [ts_builtin_sym_end] = ACTIONS(2605),
    [sym_identifier] = ACTIONS(2607),
    [anon_sym_export] = ACTIONS(2607),
    [anon_sym_default] = ACTIONS(2607),
    [anon_sym_type] = ACTIONS(2607),
    [anon_sym_namespace] = ACTIONS(2607),
    [anon_sym_LBRACE] = ACTIONS(2605),
    [anon_sym_RBRACE] = ACTIONS(2605),
    [anon_sym_typeof] = ACTIONS(2607),
    [anon_sym_import] = ACTIONS(2607),
    [anon_sym_with] = ACTIONS(2607),
    [anon_sym_var] = ACTIONS(2607),
    [anon_sym_let] = ACTIONS(2607),
    [anon_sym_const] = ACTIONS(2607),
    [anon_sym_BANG] = ACTIONS(2605),
    [anon_sym_else] = ACTIONS(2607),
    [anon_sym_if] = ACTIONS(2607),
    [anon_sym_switch] = ACTIONS(2607),
    [anon_sym_for] = ACTIONS(2607),
    [anon_sym_LPAREN] = ACTIONS(2605),
    [anon_sym_SEMI] = ACTIONS(2605),
    [anon_sym_await] = ACTIONS(2607),
    [anon_sym_while] = ACTIONS(2607),
    [anon_sym_do] = ACTIONS(2607),
    [anon_sym_try] = ACTIONS(2607),
    [anon_sym_break] = ACTIONS(2607),
    [anon_sym_continue] = ACTIONS(2607),
    [anon_sym_debugger] = ACTIONS(2607),
    [anon_sym_return] = ACTIONS(2607),
    [anon_sym_throw] = ACTIONS(2607),
    [anon_sym_case] = ACTIONS(2607),
    [anon_sym_yield] = ACTIONS(2607),
    [anon_sym_LBRACK] = ACTIONS(2605),
    [anon_sym_class] = ACTIONS(2607),
    [anon_sym_async] = ACTIONS(2607),
    [anon_sym_function] = ACTIONS(2607),
    [anon_sym_new] = ACTIONS(2607),
    [anon_sym_using] = ACTIONS(2607),
    [anon_sym_PLUS] = ACTIONS(2607),
    [anon_sym_DASH] = ACTIONS(2607),
    [anon_sym_SLASH] = ACTIONS(2607),
    [anon_sym_LT] = ACTIONS(2605),
    [anon_sym_TILDE] = ACTIONS(2605),
    [anon_sym_void] = ACTIONS(2607),
    [anon_sym_delete] = ACTIONS(2607),
    [anon_sym_PLUS_PLUS] = ACTIONS(2605),
    [anon_sym_DASH_DASH] = ACTIONS(2605),
    [anon_sym_DQUOTE] = ACTIONS(2605),
    [anon_sym_SQUOTE] = ACTIONS(2605),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(2605),
    [sym_number] = ACTIONS(2605),
    [sym_private_property_identifier] = ACTIONS(2605),
    [sym_this] = ACTIONS(2607),
    [sym_super] = ACTIONS(2607),
    [sym_true] = ACTIONS(2607),
    [sym_false] = ACTIONS(2607),
    [sym_null] = ACTIONS(2607),
    [sym_undefined] = ACTIONS(2607),
    [anon_sym_AT] = ACTIONS(2605),
    [anon_sym_static] = ACTIONS(2607),
    [anon_sym_readonly] = ACTIONS(2607),
    [anon_sym_get] = ACTIONS(2607),
    [anon_sym_set] = ACTIONS(2607),
    [anon_sym_declare] = ACTIONS(2607),
    [anon_sym_public] = ACTIONS(2607),
    [anon_sym_private] = ACTIONS(2607),
    [anon_sym_protected] = ACTIONS(2607),
    [anon_sym_override] = ACTIONS(2607),
    [anon_sym_module] = ACTIONS(2607),
    [anon_sym_any] = ACTIONS(2607),
    [anon_sym_number] = ACTIONS(2607),
    [anon_sym_boolean] = ACTIONS(2607),
    [anon_sym_string] = ACTIONS(2607),
    [anon_sym_symbol] = ACTIONS(2607),
    [anon_sym_object] = ACTIONS(2607),
    [anon_sym_abstract] = ACTIONS(2607),
    [anon_sym_interface] = ACTIONS(2607),
    [anon_sym_enum] = ACTIONS(2607),
    [sym_html_comment] = ACTIONS(5),
  },
  [833] = {
    [ts_builtin_sym_end] = ACTIONS(2609),
    [sym_identifier] = ACTIONS(2611),
    [anon_sym_export] = ACTIONS(2611),
    [anon_sym_default] = ACTIONS(2611),
    [anon_sym_type] = ACTIONS(2611),
    [anon_sym_namespace] = ACTIONS(2611),
    [anon_sym_LBRACE] = ACTIONS(2609),
    [anon_sym_RBRACE] = ACTIONS(2609),
    [anon_sym_typeof] = ACTIONS(2611),
    [anon_sym_import] = ACTIONS(2611),
    [anon_sym_with] = ACTIONS(2611),
    [anon_sym_var] = ACTIONS(2611),
    [anon_sym_let] = ACTIONS(2611),
    [anon_sym_const] = ACTIONS(2611),
    [anon_sym_BANG] = ACTIONS(2609),
    [anon_sym_else] = ACTIONS(2611),
    [anon_sym_if] = ACTIONS(2611),
    [anon_sym_switch] = ACTIONS(2611),
    [anon_sym_for] = ACTIONS(2611),
    [anon_sym_LPAREN] = ACTIONS(2609),
    [anon_sym_SEMI] = ACTIONS(2609),
    [anon_sym_await] = ACTIONS(2611),
    [anon_sym_while] = ACTIONS(2611),
    [anon_sym_do] = ACTIONS(2611),
    [anon_sym_try] = ACTIONS(2611),
    [anon_sym_break] = ACTIONS(2611),
    [anon_sym_continue] = ACTIONS(2611),
    [anon_sym_debugger] = ACTIONS(2611),
    [anon_sym_return] = ACTIONS(2611),
    [anon_sym_throw] = ACTIONS(2611),
    [anon_sym_case] = ACTIONS(2611),
    [anon_sym_yield] = ACTIONS(2611),
    [anon_sym_LBRACK] = ACTIONS(2609),
    [anon_sym_class] = ACTIONS(2611),
    [anon_sym_async] = ACTIONS(2611),
    [anon_sym_function] = ACTIONS(2611),
    [anon_sym_new] = ACTIONS(2611),
    [anon_sym_using] = ACTIONS(2611),
    [anon_sym_PLUS] = ACTIONS(2611),
    [anon_sym_DASH] = ACTIONS(2611),
    [anon_sym_SLASH] = ACTIONS(2611),
    [anon_sym_LT] = ACTIONS(2609),
    [anon_sym_TILDE] = ACTIONS(2609),
    [anon_sym_void] = ACTIONS(2611),
    [anon_sym_delete] = ACTIONS(2611),
    [anon_sym_PLUS_PLUS] = ACTIONS(2609),
    [anon_sym_DASH_DASH] = ACTIONS(2609),
    [anon_sym_DQUOTE] = ACTIONS(2609),
    [anon_sym_SQUOTE] = ACTIONS(2609),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(2609),
    [sym_number] = ACTIONS(2609),
    [sym_private_property_identifier] = ACTIONS(2609),
    [sym_this] = ACTIONS(2611),
    [sym_super] = ACTIONS(2611),
    [sym_true] = ACTIONS(2611),
    [sym_false] = ACTIONS(2611),
    [sym_null] = ACTIONS(2611),
    [sym_undefined] = ACTIONS(2611),
    [anon_sym_AT] = ACTIONS(2609),
    [anon_sym_static] = ACTIONS(2611),
    [anon_sym_readonly] = ACTIONS(2611),
    [anon_sym_get] = ACTIONS(2611),
    [anon_sym_set] = ACTIONS(2611),
    [anon_sym_declare] = ACTIONS(2611),
    [anon_sym_public] = ACTIONS(2611),
    [anon_sym_private] = ACTIONS(2611),
    [anon_sym_protected] = ACTIONS(2611),
    [anon_sym_override] = ACTIONS(2611),
    [anon_sym_module] = ACTIONS(2611),
    [anon_sym_any] = ACTIONS(2611),
    [anon_sym_number] = ACTIONS(2611),
    [anon_sym_boolean] = ACTIONS(2611),
    [anon_sym_string] = ACTIONS(2611),
    [anon_sym_symbol] = ACTIONS(2611),
    [anon_sym_object] = ACTIONS(2611),
    [anon_sym_abstract] = ACTIONS(2611),
    [anon_sym_interface] = ACTIONS(2611),
    [anon_sym_enum] = ACTIONS(2611),
    [sym_html_comment] = ACTIONS(5),
  },
  [834] = {
    [ts_builtin_sym_end] = ACTIONS(2613),
    [sym_identifier] = ACTIONS(2615),
    [anon_sym_export] = ACTIONS(2615),
    [anon_sym_default] = ACTIONS(2615),
    [anon_sym_type] = ACTIONS(2615),
    [anon_sym_namespace] = ACTIONS(2615),
    [anon_sym_LBRACE] = ACTIONS(2613),
    [anon_sym_RBRACE] = ACTIONS(2613),
    [anon_sym_typeof] = ACTIONS(2615),
    [anon_sym_import] = ACTIONS(2615),
    [anon_sym_with] = ACTIONS(2615),
    [anon_sym_var] = ACTIONS(2615),
    [anon_sym_let] = ACTIONS(2615),
    [anon_sym_const] = ACTIONS(2615),
    [anon_sym_BANG] = ACTIONS(2613),
    [anon_sym_else] = ACTIONS(2615),
    [anon_sym_if] = ACTIONS(2615),
    [anon_sym_switch] = ACTIONS(2615),
    [anon_sym_for] = ACTIONS(2615),
    [anon_sym_LPAREN] = ACTIONS(2613),
    [anon_sym_SEMI] = ACTIONS(2613),
    [anon_sym_await] = ACTIONS(2615),
    [anon_sym_while] = ACTIONS(2615),
    [anon_sym_do] = ACTIONS(2615),
    [anon_sym_try] = ACTIONS(2615),
    [anon_sym_break] = ACTIONS(2615),
    [anon_sym_continue] = ACTIONS(2615),
    [anon_sym_debugger] = ACTIONS(2615),
    [anon_sym_return] = ACTIONS(2615),
    [anon_sym_throw] = ACTIONS(2615),
    [anon_sym_case] = ACTIONS(2615),
    [anon_sym_yield] = ACTIONS(2615),
    [anon_sym_LBRACK] = ACTIONS(2613),
    [anon_sym_class] = ACTIONS(2615),
    [anon_sym_async] = ACTIONS(2615),
    [anon_sym_function] = ACTIONS(2615),
    [anon_sym_new] = ACTIONS(2615),
    [anon_sym_using] = ACTIONS(2615),
    [anon_sym_PLUS] = ACTIONS(2615),
    [anon_sym_DASH] = ACTIONS(2615),
    [anon_sym_SLASH] = ACTIONS(2615),
    [anon_sym_LT] = ACTIONS(2613),
    [anon_sym_TILDE] = ACTIONS(2613),
    [anon_sym_void] = ACTIONS(2615),
    [anon_sym_delete] = ACTIONS(2615),
    [anon_sym_PLUS_PLUS] = ACTIONS(2613),
    [anon_sym_DASH_DASH] = ACTIONS(2613),
    [anon_sym_DQUOTE] = ACTIONS(2613),
    [anon_sym_SQUOTE] = ACTIONS(2613),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(2613),
    [sym_number] = ACTIONS(2613),
    [sym_private_property_identifier] = ACTIONS(2613),
    [sym_this] = ACTIONS(2615),
    [sym_super] = ACTIONS(2615),
    [sym_true] = ACTIONS(2615),
    [sym_false] = ACTIONS(2615),
    [sym_null] = ACTIONS(2615),
    [sym_undefined] = ACTIONS(2615),
    [anon_sym_AT] = ACTIONS(2613),
    [anon_sym_static] = ACTIONS(2615),
    [anon_sym_readonly] = ACTIONS(2615),
    [anon_sym_get] = ACTIONS(2615),
    [anon_sym_set] = ACTIONS(2615),
    [anon_sym_declare] = ACTIONS(2615),
    [anon_sym_public] = ACTIONS(2615),
    [anon_sym_private] = ACTIONS(2615),
    [anon_sym_protected] = ACTIONS(2615),
    [anon_sym_override] = ACTIONS(2615),
    [anon_sym_module] = ACTIONS(2615),
    [anon_sym_any] = ACTIONS(2615),
    [anon_sym_number] = ACTIONS(2615),
    [anon_sym_boolean] = ACTIONS(2615),
    [anon_sym_string] = ACTIONS(2615),
    [anon_sym_symbol] = ACTIONS(2615),
    [anon_sym_object] = ACTIONS(2615),
    [anon_sym_abstract] = ACTIONS(2615),
    [anon_sym_interface] = ACTIONS(2615),
    [anon_sym_enum] = ACTIONS(2615),
    [sym_html_comment] = ACTIONS(5),
  },
  [835] = {
    [ts_builtin_sym_end] = ACTIONS(2617),
    [sym_identifier] = ACTIONS(2619),
    [anon_sym_export] = ACTIONS(2619),
    [anon_sym_default] = ACTIONS(2619),
    [anon_sym_type] = ACTIONS(2619),
    [anon_sym_namespace] = ACTIONS(2619),
    [anon_sym_LBRACE] = ACTIONS(2617),
    [anon_sym_RBRACE] = ACTIONS(2617),
    [anon_sym_typeof] = ACTIONS(2619),
    [anon_sym_import] = ACTIONS(2619),
    [anon_sym_with] = ACTIONS(2619),
    [anon_sym_var] = ACTIONS(2619),
    [anon_sym_let] = ACTIONS(2619),
    [anon_sym_const] = ACTIONS(2619),
    [anon_sym_BANG] = ACTIONS(2617),
    [anon_sym_else] = ACTIONS(2619),
    [anon_sym_if] = ACTIONS(2619),
    [anon_sym_switch] = ACTIONS(2619),
    [anon_sym_for] = ACTIONS(2619),
    [anon_sym_LPAREN] = ACTIONS(2617),
    [anon_sym_SEMI] = ACTIONS(2617),
    [anon_sym_await] = ACTIONS(2619),
    [anon_sym_while] = ACTIONS(2619),
    [anon_sym_do] = ACTIONS(2619),
    [anon_sym_try] = ACTIONS(2619),
    [anon_sym_break] = ACTIONS(2619),
    [anon_sym_continue] = ACTIONS(2619),
    [anon_sym_debugger] = ACTIONS(2619),
    [anon_sym_return] = ACTIONS(2619),
    [anon_sym_throw] = ACTIONS(2619),
    [anon_sym_case] = ACTIONS(2619),
    [anon_sym_yield] = ACTIONS(2619),
    [anon_sym_LBRACK] = ACTIONS(2617),
    [anon_sym_class] = ACTIONS(2619),
    [anon_sym_async] = ACTIONS(2619),
    [anon_sym_function] = ACTIONS(2619),
    [anon_sym_new] = ACTIONS(2619),
    [anon_sym_using] = ACTIONS(2619),
    [anon_sym_PLUS] = ACTIONS(2619),
    [anon_sym_DASH] = ACTIONS(2619),
    [anon_sym_SLASH] = ACTIONS(2619),
    [anon_sym_LT] = ACTIONS(2617),
    [anon_sym_TILDE] = ACTIONS(2617),
    [anon_sym_void] = ACTIONS(2619),
    [anon_sym_delete] = ACTIONS(2619),
    [anon_sym_PLUS_PLUS] = ACTIONS(2617),
    [anon_sym_DASH_DASH] = ACTIONS(2617),
    [anon_sym_DQUOTE] = ACTIONS(2617),
    [anon_sym_SQUOTE] = ACTIONS(2617),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(2617),
    [sym_number] = ACTIONS(2617),
    [sym_private_property_identifier] = ACTIONS(2617),
    [sym_this] = ACTIONS(2619),
    [sym_super] = ACTIONS(2619),
    [sym_true] = ACTIONS(2619),
    [sym_false] = ACTIONS(2619),
    [sym_null] = ACTIONS(2619),
    [sym_undefined] = ACTIONS(2619),
    [anon_sym_AT] = ACTIONS(2617),
    [anon_sym_static] = ACTIONS(2619),
    [anon_sym_readonly] = ACTIONS(2619),
    [anon_sym_get] = ACTIONS(2619),
    [anon_sym_set] = ACTIONS(2619),
    [anon_sym_declare] = ACTIONS(2619),
    [anon_sym_public] = ACTIONS(2619),
    [anon_sym_private] = ACTIONS(2619),
    [anon_sym_protected] = ACTIONS(2619),
    [anon_sym_override] = ACTIONS(2619),
    [anon_sym_module] = ACTIONS(2619),
    [anon_sym_any] = ACTIONS(2619),
    [anon_sym_number] = ACTIONS(2619),
    [anon_sym_boolean] = ACTIONS(2619),
    [anon_sym_string] = ACTIONS(2619),
    [anon_sym_symbol] = ACTIONS(2619),
    [anon_sym_object] = ACTIONS(2619),
    [anon_sym_abstract] = ACTIONS(2619),
    [anon_sym_interface] = ACTIONS(2619),
    [anon_sym_enum] = ACTIONS(2619),
    [sym_html_comment] = ACTIONS(5),
  },
  [836] = {
    [ts_builtin_sym_end] = ACTIONS(2617),
    [sym_identifier] = ACTIONS(2619),
    [anon_sym_export] = ACTIONS(2619),
    [anon_sym_default] = ACTIONS(2619),
    [anon_sym_type] = ACTIONS(2619),
    [anon_sym_namespace] = ACTIONS(2619),
    [anon_sym_LBRACE] = ACTIONS(2617),
    [anon_sym_RBRACE] = ACTIONS(2617),
    [anon_sym_typeof] = ACTIONS(2619),
    [anon_sym_import] = ACTIONS(2619),
    [anon_sym_with] = ACTIONS(2619),
    [anon_sym_var] = ACTIONS(2619),
    [anon_sym_let] = ACTIONS(2619),
    [anon_sym_const] = ACTIONS(2619),
    [anon_sym_BANG] = ACTIONS(2617),
    [anon_sym_else] = ACTIONS(2619),
    [anon_sym_if] = ACTIONS(2619),
    [anon_sym_switch] = ACTIONS(2619),
    [anon_sym_for] = ACTIONS(2619),
    [anon_sym_LPAREN] = ACTIONS(2617),
    [anon_sym_SEMI] = ACTIONS(2617),
    [anon_sym_await] = ACTIONS(2619),
    [anon_sym_while] = ACTIONS(2619),
    [anon_sym_do] = ACTIONS(2619),
    [anon_sym_try] = ACTIONS(2619),
    [anon_sym_break] = ACTIONS(2619),
    [anon_sym_continue] = ACTIONS(2619),
    [anon_sym_debugger] = ACTIONS(2619),
    [anon_sym_return] = ACTIONS(2619),
    [anon_sym_throw] = ACTIONS(2619),
    [anon_sym_case] = ACTIONS(2619),
    [anon_sym_yield] = ACTIONS(2619),
    [anon_sym_LBRACK] = ACTIONS(2617),
    [anon_sym_class] = ACTIONS(2619),
    [anon_sym_async] = ACTIONS(2619),
    [anon_sym_function] = ACTIONS(2619),
    [anon_sym_new] = ACTIONS(2619),
    [anon_sym_using] = ACTIONS(2619),
    [anon_sym_PLUS] = ACTIONS(2619),
    [anon_sym_DASH] = ACTIONS(2619),
    [anon_sym_SLASH] = ACTIONS(2619),
    [anon_sym_LT] = ACTIONS(2617),
    [anon_sym_TILDE] = ACTIONS(2617),
    [anon_sym_void] = ACTIONS(2619),
    [anon_sym_delete] = ACTIONS(2619),
    [anon_sym_PLUS_PLUS] = ACTIONS(2617),
    [anon_sym_DASH_DASH] = ACTIONS(2617),
    [anon_sym_DQUOTE] = ACTIONS(2617),
    [anon_sym_SQUOTE] = ACTIONS(2617),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(2617),
    [sym_number] = ACTIONS(2617),
    [sym_private_property_identifier] = ACTIONS(2617),
    [sym_this] = ACTIONS(2619),
    [sym_super] = ACTIONS(2619),
    [sym_true] = ACTIONS(2619),
    [sym_false] = ACTIONS(2619),
    [sym_null] = ACTIONS(2619),
    [sym_undefined] = ACTIONS(2619),
    [anon_sym_AT] = ACTIONS(2617),
    [anon_sym_static] = ACTIONS(2619),
    [anon_sym_readonly] = ACTIONS(2619),
    [anon_sym_get] = ACTIONS(2619),
    [anon_sym_set] = ACTIONS(2619),
    [anon_sym_declare] = ACTIONS(2619),
    [anon_sym_public] = ACTIONS(2619),
    [anon_sym_private] = ACTIONS(2619),
    [anon_sym_protected] = ACTIONS(2619),
    [anon_sym_override] = ACTIONS(2619),
    [anon_sym_module] = ACTIONS(2619),
    [anon_sym_any] = ACTIONS(2619),
    [anon_sym_number] = ACTIONS(2619),
    [anon_sym_boolean] = ACTIONS(2619),
    [anon_sym_string] = ACTIONS(2619),
    [anon_sym_symbol] = ACTIONS(2619),
    [anon_sym_object] = ACTIONS(2619),
    [anon_sym_abstract] = ACTIONS(2619),
    [anon_sym_interface] = ACTIONS(2619),
    [anon_sym_enum] = ACTIONS(2619),
    [sym_html_comment] = ACTIONS(5),
  },
  [837] = {
    [ts_builtin_sym_end] = ACTIONS(2621),
    [sym_identifier] = ACTIONS(2623),
    [anon_sym_export] = ACTIONS(2623),
    [anon_sym_default] = ACTIONS(2623),
    [anon_sym_type] = ACTIONS(2623),
    [anon_sym_namespace] = ACTIONS(2623),
    [anon_sym_LBRACE] = ACTIONS(2621),
    [anon_sym_RBRACE] = ACTIONS(2621),
    [anon_sym_typeof] = ACTIONS(2623),
    [anon_sym_import] = ACTIONS(2623),
    [anon_sym_with] = ACTIONS(2623),
    [anon_sym_var] = ACTIONS(2623),
    [anon_sym_let] = ACTIONS(2623),
    [anon_sym_const] = ACTIONS(2623),
    [anon_sym_BANG] = ACTIONS(2621),
    [anon_sym_else] = ACTIONS(2623),
    [anon_sym_if] = ACTIONS(2623),
    [anon_sym_switch] = ACTIONS(2623),
    [anon_sym_for] = ACTIONS(2623),
    [anon_sym_LPAREN] = ACTIONS(2621),
    [anon_sym_SEMI] = ACTIONS(2621),
    [anon_sym_await] = ACTIONS(2623),
    [anon_sym_while] = ACTIONS(2623),
    [anon_sym_do] = ACTIONS(2623),
    [anon_sym_try] = ACTIONS(2623),
    [anon_sym_break] = ACTIONS(2623),
    [anon_sym_continue] = ACTIONS(2623),
    [anon_sym_debugger] = ACTIONS(2623),
    [anon_sym_return] = ACTIONS(2623),
    [anon_sym_throw] = ACTIONS(2623),
    [anon_sym_case] = ACTIONS(2623),
    [anon_sym_yield] = ACTIONS(2623),
    [anon_sym_LBRACK] = ACTIONS(2621),
    [anon_sym_class] = ACTIONS(2623),
    [anon_sym_async] = ACTIONS(2623),
    [anon_sym_function] = ACTIONS(2623),
    [anon_sym_new] = ACTIONS(2623),
    [anon_sym_using] = ACTIONS(2623),
    [anon_sym_PLUS] = ACTIONS(2623),
    [anon_sym_DASH] = ACTIONS(2623),
    [anon_sym_SLASH] = ACTIONS(2623),
    [anon_sym_LT] = ACTIONS(2621),
    [anon_sym_TILDE] = ACTIONS(2621),
    [anon_sym_void] = ACTIONS(2623),
    [anon_sym_delete] = ACTIONS(2623),
    [anon_sym_PLUS_PLUS] = ACTIONS(2621),
    [anon_sym_DASH_DASH] = ACTIONS(2621),
    [anon_sym_DQUOTE] = ACTIONS(2621),
    [anon_sym_SQUOTE] = ACTIONS(2621),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(2621),
    [sym_number] = ACTIONS(2621),
    [sym_private_property_identifier] = ACTIONS(2621),
    [sym_this] = ACTIONS(2623),
    [sym_super] = ACTIONS(2623),
    [sym_true] = ACTIONS(2623),
    [sym_false] = ACTIONS(2623),
    [sym_null] = ACTIONS(2623),
    [sym_undefined] = ACTIONS(2623),
    [anon_sym_AT] = ACTIONS(2621),
    [anon_sym_static] = ACTIONS(2623),
    [anon_sym_readonly] = ACTIONS(2623),
    [anon_sym_get] = ACTIONS(2623),
    [anon_sym_set] = ACTIONS(2623),
    [anon_sym_declare] = ACTIONS(2623),
    [anon_sym_public] = ACTIONS(2623),
    [anon_sym_private] = ACTIONS(2623),
    [anon_sym_protected] = ACTIONS(2623),
    [anon_sym_override] = ACTIONS(2623),
    [anon_sym_module] = ACTIONS(2623),
    [anon_sym_any] = ACTIONS(2623),
    [anon_sym_number] = ACTIONS(2623),
    [anon_sym_boolean] = ACTIONS(2623),
    [anon_sym_string] = ACTIONS(2623),
    [anon_sym_symbol] = ACTIONS(2623),
    [anon_sym_object] = ACTIONS(2623),
    [anon_sym_abstract] = ACTIONS(2623),
    [anon_sym_interface] = ACTIONS(2623),
    [anon_sym_enum] = ACTIONS(2623),
    [sym_html_comment] = ACTIONS(5),
  },
  [838] = {
    [ts_builtin_sym_end] = ACTIONS(2625),
    [sym_identifier] = ACTIONS(2627),
    [anon_sym_export] = ACTIONS(2627),
    [anon_sym_default] = ACTIONS(2627),
    [anon_sym_type] = ACTIONS(2627),
    [anon_sym_namespace] = ACTIONS(2627),
    [anon_sym_LBRACE] = ACTIONS(2625),
    [anon_sym_RBRACE] = ACTIONS(2625),
    [anon_sym_typeof] = ACTIONS(2627),
    [anon_sym_import] = ACTIONS(2627),
    [anon_sym_with] = ACTIONS(2627),
    [anon_sym_var] = ACTIONS(2627),
    [anon_sym_let] = ACTIONS(2627),
    [anon_sym_const] = ACTIONS(2627),
    [anon_sym_BANG] = ACTIONS(2625),
    [anon_sym_else] = ACTIONS(2627),
    [anon_sym_if] = ACTIONS(2627),
    [anon_sym_switch] = ACTIONS(2627),
    [anon_sym_for] = ACTIONS(2627),
    [anon_sym_LPAREN] = ACTIONS(2625),
    [anon_sym_SEMI] = ACTIONS(2625),
    [anon_sym_await] = ACTIONS(2627),
    [anon_sym_while] = ACTIONS(2627),
    [anon_sym_do] = ACTIONS(2627),
    [anon_sym_try] = ACTIONS(2627),
    [anon_sym_break] = ACTIONS(2627),
    [anon_sym_continue] = ACTIONS(2627),
    [anon_sym_debugger] = ACTIONS(2627),
    [anon_sym_return] = ACTIONS(2627),
    [anon_sym_throw] = ACTIONS(2627),
    [anon_sym_case] = ACTIONS(2627),
    [anon_sym_yield] = ACTIONS(2627),
    [anon_sym_LBRACK] = ACTIONS(2625),
    [anon_sym_class] = ACTIONS(2627),
    [anon_sym_async] = ACTIONS(2627),
    [anon_sym_function] = ACTIONS(2627),
    [anon_sym_new] = ACTIONS(2627),
    [anon_sym_using] = ACTIONS(2627),
    [anon_sym_PLUS] = ACTIONS(2627),
    [anon_sym_DASH] = ACTIONS(2627),
    [anon_sym_SLASH] = ACTIONS(2627),
    [anon_sym_LT] = ACTIONS(2625),
    [anon_sym_TILDE] = ACTIONS(2625),
    [anon_sym_void] = ACTIONS(2627),
    [anon_sym_delete] = ACTIONS(2627),
    [anon_sym_PLUS_PLUS] = ACTIONS(2625),
    [anon_sym_DASH_DASH] = ACTIONS(2625),
    [anon_sym_DQUOTE] = ACTIONS(2625),
    [anon_sym_SQUOTE] = ACTIONS(2625),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(2625),
    [sym_number] = ACTIONS(2625),
    [sym_private_property_identifier] = ACTIONS(2625),
    [sym_this] = ACTIONS(2627),
    [sym_super] = ACTIONS(2627),
    [sym_true] = ACTIONS(2627),
    [sym_false] = ACTIONS(2627),
    [sym_null] = ACTIONS(2627),
    [sym_undefined] = ACTIONS(2627),
    [anon_sym_AT] = ACTIONS(2625),
    [anon_sym_static] = ACTIONS(2627),
    [anon_sym_readonly] = ACTIONS(2627),
    [anon_sym_get] = ACTIONS(2627),
    [anon_sym_set] = ACTIONS(2627),
    [anon_sym_declare] = ACTIONS(2627),
    [anon_sym_public] = ACTIONS(2627),
    [anon_sym_private] = ACTIONS(2627),
    [anon_sym_protected] = ACTIONS(2627),
    [anon_sym_override] = ACTIONS(2627),
    [anon_sym_module] = ACTIONS(2627),
    [anon_sym_any] = ACTIONS(2627),
    [anon_sym_number] = ACTIONS(2627),
    [anon_sym_boolean] = ACTIONS(2627),
    [anon_sym_string] = ACTIONS(2627),
    [anon_sym_symbol] = ACTIONS(2627),
    [anon_sym_object] = ACTIONS(2627),
    [anon_sym_abstract] = ACTIONS(2627),
    [anon_sym_interface] = ACTIONS(2627),
    [anon_sym_enum] = ACTIONS(2627),
    [sym_html_comment] = ACTIONS(5),
  },
  [839] = {
    [ts_builtin_sym_end] = ACTIONS(2629),
    [sym_identifier] = ACTIONS(2631),
    [anon_sym_export] = ACTIONS(2631),
    [anon_sym_default] = ACTIONS(2631),
    [anon_sym_type] = ACTIONS(2631),
    [anon_sym_namespace] = ACTIONS(2631),
    [anon_sym_LBRACE] = ACTIONS(2629),
    [anon_sym_RBRACE] = ACTIONS(2629),
    [anon_sym_typeof] = ACTIONS(2631),
    [anon_sym_import] = ACTIONS(2631),
    [anon_sym_with] = ACTIONS(2631),
    [anon_sym_var] = ACTIONS(2631),
    [anon_sym_let] = ACTIONS(2631),
    [anon_sym_const] = ACTIONS(2631),
    [anon_sym_BANG] = ACTIONS(2629),
    [anon_sym_else] = ACTIONS(2631),
    [anon_sym_if] = ACTIONS(2631),
    [anon_sym_switch] = ACTIONS(2631),
    [anon_sym_for] = ACTIONS(2631),
    [anon_sym_LPAREN] = ACTIONS(2629),
    [anon_sym_SEMI] = ACTIONS(2629),
    [anon_sym_await] = ACTIONS(2631),
    [anon_sym_while] = ACTIONS(2631),
    [anon_sym_do] = ACTIONS(2631),
    [anon_sym_try] = ACTIONS(2631),
    [anon_sym_break] = ACTIONS(2631),
    [anon_sym_continue] = ACTIONS(2631),
    [anon_sym_debugger] = ACTIONS(2631),
    [anon_sym_return] = ACTIONS(2631),
    [anon_sym_throw] = ACTIONS(2631),
    [anon_sym_case] = ACTIONS(2631),
    [anon_sym_yield] = ACTIONS(2631),
    [anon_sym_LBRACK] = ACTIONS(2629),
    [anon_sym_class] = ACTIONS(2631),
    [anon_sym_async] = ACTIONS(2631),
    [anon_sym_function] = ACTIONS(2631),
    [anon_sym_new] = ACTIONS(2631),
    [anon_sym_using] = ACTIONS(2631),
    [anon_sym_PLUS] = ACTIONS(2631),
    [anon_sym_DASH] = ACTIONS(2631),
    [anon_sym_SLASH] = ACTIONS(2631),
    [anon_sym_LT] = ACTIONS(2629),
    [anon_sym_TILDE] = ACTIONS(2629),
    [anon_sym_void] = ACTIONS(2631),
    [anon_sym_delete] = ACTIONS(2631),
    [anon_sym_PLUS_PLUS] = ACTIONS(2629),
    [anon_sym_DASH_DASH] = ACTIONS(2629),
    [anon_sym_DQUOTE] = ACTIONS(2629),
    [anon_sym_SQUOTE] = ACTIONS(2629),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(2629),
    [sym_number] = ACTIONS(2629),
    [sym_private_property_identifier] = ACTIONS(2629),
    [sym_this] = ACTIONS(2631),
    [sym_super] = ACTIONS(2631),
    [sym_true] = ACTIONS(2631),
    [sym_false] = ACTIONS(2631),
    [sym_null] = ACTIONS(2631),
    [sym_undefined] = ACTIONS(2631),
    [anon_sym_AT] = ACTIONS(2629),
    [anon_sym_static] = ACTIONS(2631),
    [anon_sym_readonly] = ACTIONS(2631),
    [anon_sym_get] = ACTIONS(2631),
    [anon_sym_set] = ACTIONS(2631),
    [anon_sym_declare] = ACTIONS(2631),
    [anon_sym_public] = ACTIONS(2631),
    [anon_sym_private] = ACTIONS(2631),
    [anon_sym_protected] = ACTIONS(2631),
    [anon_sym_override] = ACTIONS(2631),
    [anon_sym_module] = ACTIONS(2631),
    [anon_sym_any] = ACTIONS(2631),
    [anon_sym_number] = ACTIONS(2631),
    [anon_sym_boolean] = ACTIONS(2631),
    [anon_sym_string] = ACTIONS(2631),
    [anon_sym_symbol] = ACTIONS(2631),
    [anon_sym_object] = ACTIONS(2631),
    [anon_sym_abstract] = ACTIONS(2631),
    [anon_sym_interface] = ACTIONS(2631),
    [anon_sym_enum] = ACTIONS(2631),
    [sym_html_comment] = ACTIONS(5),
  },
  [840] = {
    [ts_builtin_sym_end] = ACTIONS(2633),
    [sym_identifier] = ACTIONS(2635),
    [anon_sym_export] = ACTIONS(2635),
    [anon_sym_default] = ACTIONS(2635),
    [anon_sym_type] = ACTIONS(2635),
    [anon_sym_namespace] = ACTIONS(2635),
    [anon_sym_LBRACE] = ACTIONS(2633),
    [anon_sym_RBRACE] = ACTIONS(2633),
    [anon_sym_typeof] = ACTIONS(2635),
    [anon_sym_import] = ACTIONS(2635),
    [anon_sym_with] = ACTIONS(2635),
    [anon_sym_var] = ACTIONS(2635),
    [anon_sym_let] = ACTIONS(2635),
    [anon_sym_const] = ACTIONS(2635),
    [anon_sym_BANG] = ACTIONS(2633),
    [anon_sym_else] = ACTIONS(2635),
    [anon_sym_if] = ACTIONS(2635),
    [anon_sym_switch] = ACTIONS(2635),
    [anon_sym_for] = ACTIONS(2635),
    [anon_sym_LPAREN] = ACTIONS(2633),
    [anon_sym_SEMI] = ACTIONS(2633),
    [anon_sym_await] = ACTIONS(2635),
    [anon_sym_while] = ACTIONS(2635),
    [anon_sym_do] = ACTIONS(2635),
    [anon_sym_try] = ACTIONS(2635),
    [anon_sym_break] = ACTIONS(2635),
    [anon_sym_continue] = ACTIONS(2635),
    [anon_sym_debugger] = ACTIONS(2635),
    [anon_sym_return] = ACTIONS(2635),
    [anon_sym_throw] = ACTIONS(2635),
    [anon_sym_case] = ACTIONS(2635),
    [anon_sym_yield] = ACTIONS(2635),
    [anon_sym_LBRACK] = ACTIONS(2633),
    [anon_sym_class] = ACTIONS(2635),
    [anon_sym_async] = ACTIONS(2635),
    [anon_sym_function] = ACTIONS(2635),
    [anon_sym_new] = ACTIONS(2635),
    [anon_sym_using] = ACTIONS(2635),
    [anon_sym_PLUS] = ACTIONS(2635),
    [anon_sym_DASH] = ACTIONS(2635),
    [anon_sym_SLASH] = ACTIONS(2635),
    [anon_sym_LT] = ACTIONS(2633),
    [anon_sym_TILDE] = ACTIONS(2633),
    [anon_sym_void] = ACTIONS(2635),
    [anon_sym_delete] = ACTIONS(2635),
    [anon_sym_PLUS_PLUS] = ACTIONS(2633),
    [anon_sym_DASH_DASH] = ACTIONS(2633),
    [anon_sym_DQUOTE] = ACTIONS(2633),
    [anon_sym_SQUOTE] = ACTIONS(2633),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(2633),
    [sym_number] = ACTIONS(2633),
    [sym_private_property_identifier] = ACTIONS(2633),
    [sym_this] = ACTIONS(2635),
    [sym_super] = ACTIONS(2635),
    [sym_true] = ACTIONS(2635),
    [sym_false] = ACTIONS(2635),
    [sym_null] = ACTIONS(2635),
    [sym_undefined] = ACTIONS(2635),
    [anon_sym_AT] = ACTIONS(2633),
    [anon_sym_static] = ACTIONS(2635),
    [anon_sym_readonly] = ACTIONS(2635),
    [anon_sym_get] = ACTIONS(2635),
    [anon_sym_set] = ACTIONS(2635),
    [anon_sym_declare] = ACTIONS(2635),
    [anon_sym_public] = ACTIONS(2635),
    [anon_sym_private] = ACTIONS(2635),
    [anon_sym_protected] = ACTIONS(2635),
    [anon_sym_override] = ACTIONS(2635),
    [anon_sym_module] = ACTIONS(2635),
    [anon_sym_any] = ACTIONS(2635),
    [anon_sym_number] = ACTIONS(2635),
    [anon_sym_boolean] = ACTIONS(2635),
    [anon_sym_string] = ACTIONS(2635),
    [anon_sym_symbol] = ACTIONS(2635),
    [anon_sym_object] = ACTIONS(2635),
    [anon_sym_abstract] = ACTIONS(2635),
    [anon_sym_interface] = ACTIONS(2635),
    [anon_sym_enum] = ACTIONS(2635),
    [sym_html_comment] = ACTIONS(5),
  },
  [841] = {
    [ts_builtin_sym_end] = ACTIONS(2637),
    [sym_identifier] = ACTIONS(2639),
    [anon_sym_export] = ACTIONS(2639),
    [anon_sym_default] = ACTIONS(2639),
    [anon_sym_type] = ACTIONS(2639),
    [anon_sym_namespace] = ACTIONS(2639),
    [anon_sym_LBRACE] = ACTIONS(2637),
    [anon_sym_RBRACE] = ACTIONS(2637),
    [anon_sym_typeof] = ACTIONS(2639),
    [anon_sym_import] = ACTIONS(2639),
    [anon_sym_with] = ACTIONS(2639),
    [anon_sym_var] = ACTIONS(2639),
    [anon_sym_let] = ACTIONS(2639),
    [anon_sym_const] = ACTIONS(2639),
    [anon_sym_BANG] = ACTIONS(2637),
    [anon_sym_else] = ACTIONS(2639),
    [anon_sym_if] = ACTIONS(2639),
    [anon_sym_switch] = ACTIONS(2639),
    [anon_sym_for] = ACTIONS(2639),
    [anon_sym_LPAREN] = ACTIONS(2637),
    [anon_sym_SEMI] = ACTIONS(2637),
    [anon_sym_await] = ACTIONS(2639),
    [anon_sym_while] = ACTIONS(2639),
    [anon_sym_do] = ACTIONS(2639),
    [anon_sym_try] = ACTIONS(2639),
    [anon_sym_break] = ACTIONS(2639),
    [anon_sym_continue] = ACTIONS(2639),
    [anon_sym_debugger] = ACTIONS(2639),
    [anon_sym_return] = ACTIONS(2639),
    [anon_sym_throw] = ACTIONS(2639),
    [anon_sym_case] = ACTIONS(2639),
    [anon_sym_yield] = ACTIONS(2639),
    [anon_sym_LBRACK] = ACTIONS(2637),
    [anon_sym_class] = ACTIONS(2639),
    [anon_sym_async] = ACTIONS(2639),
    [anon_sym_function] = ACTIONS(2639),
    [anon_sym_new] = ACTIONS(2639),
    [anon_sym_using] = ACTIONS(2639),
    [anon_sym_PLUS] = ACTIONS(2639),
    [anon_sym_DASH] = ACTIONS(2639),
    [anon_sym_SLASH] = ACTIONS(2639),
    [anon_sym_LT] = ACTIONS(2637),
    [anon_sym_TILDE] = ACTIONS(2637),
    [anon_sym_void] = ACTIONS(2639),
    [anon_sym_delete] = ACTIONS(2639),
    [anon_sym_PLUS_PLUS] = ACTIONS(2637),
    [anon_sym_DASH_DASH] = ACTIONS(2637),
    [anon_sym_DQUOTE] = ACTIONS(2637),
    [anon_sym_SQUOTE] = ACTIONS(2637),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(2637),
    [sym_number] = ACTIONS(2637),
    [sym_private_property_identifier] = ACTIONS(2637),
    [sym_this] = ACTIONS(2639),
    [sym_super] = ACTIONS(2639),
    [sym_true] = ACTIONS(2639),
    [sym_false] = ACTIONS(2639),
    [sym_null] = ACTIONS(2639),
    [sym_undefined] = ACTIONS(2639),
    [anon_sym_AT] = ACTIONS(2637),
    [anon_sym_static] = ACTIONS(2639),
    [anon_sym_readonly] = ACTIONS(2639),
    [anon_sym_get] = ACTIONS(2639),
    [anon_sym_set] = ACTIONS(2639),
    [anon_sym_declare] = ACTIONS(2639),
    [anon_sym_public] = ACTIONS(2639),
    [anon_sym_private] = ACTIONS(2639),
    [anon_sym_protected] = ACTIONS(2639),
    [anon_sym_override] = ACTIONS(2639),
    [anon_sym_module] = ACTIONS(2639),
    [anon_sym_any] = ACTIONS(2639),
    [anon_sym_number] = ACTIONS(2639),
    [anon_sym_boolean] = ACTIONS(2639),
    [anon_sym_string] = ACTIONS(2639),
    [anon_sym_symbol] = ACTIONS(2639),
    [anon_sym_object] = ACTIONS(2639),
    [anon_sym_abstract] = ACTIONS(2639),
    [anon_sym_interface] = ACTIONS(2639),
    [anon_sym_enum] = ACTIONS(2639),
    [sym_html_comment] = ACTIONS(5),
  },
  [842] = {
    [ts_builtin_sym_end] = ACTIONS(2641),
    [sym_identifier] = ACTIONS(2643),
    [anon_sym_export] = ACTIONS(2643),
    [anon_sym_default] = ACTIONS(2643),
    [anon_sym_type] = ACTIONS(2643),
    [anon_sym_namespace] = ACTIONS(2643),
    [anon_sym_LBRACE] = ACTIONS(2641),
    [anon_sym_RBRACE] = ACTIONS(2641),
    [anon_sym_typeof] = ACTIONS(2643),
    [anon_sym_import] = ACTIONS(2643),
    [anon_sym_with] = ACTIONS(2643),
    [anon_sym_var] = ACTIONS(2643),
    [anon_sym_let] = ACTIONS(2643),
    [anon_sym_const] = ACTIONS(2643),
    [anon_sym_BANG] = ACTIONS(2641),
    [anon_sym_else] = ACTIONS(2643),
    [anon_sym_if] = ACTIONS(2643),
    [anon_sym_switch] = ACTIONS(2643),
    [anon_sym_for] = ACTIONS(2643),
    [anon_sym_LPAREN] = ACTIONS(2641),
    [anon_sym_SEMI] = ACTIONS(2641),
    [anon_sym_await] = ACTIONS(2643),
    [anon_sym_while] = ACTIONS(2643),
    [anon_sym_do] = ACTIONS(2643),
    [anon_sym_try] = ACTIONS(2643),
    [anon_sym_break] = ACTIONS(2643),
    [anon_sym_continue] = ACTIONS(2643),
    [anon_sym_debugger] = ACTIONS(2643),
    [anon_sym_return] = ACTIONS(2643),
    [anon_sym_throw] = ACTIONS(2643),
    [anon_sym_case] = ACTIONS(2643),
    [anon_sym_yield] = ACTIONS(2643),
    [anon_sym_LBRACK] = ACTIONS(2641),
    [anon_sym_class] = ACTIONS(2643),
    [anon_sym_async] = ACTIONS(2643),
    [anon_sym_function] = ACTIONS(2643),
    [anon_sym_new] = ACTIONS(2643),
    [anon_sym_using] = ACTIONS(2643),
    [anon_sym_PLUS] = ACTIONS(2643),
    [anon_sym_DASH] = ACTIONS(2643),
    [anon_sym_SLASH] = ACTIONS(2643),
    [anon_sym_LT] = ACTIONS(2641),
    [anon_sym_TILDE] = ACTIONS(2641),
    [anon_sym_void] = ACTIONS(2643),
    [anon_sym_delete] = ACTIONS(2643),
    [anon_sym_PLUS_PLUS] = ACTIONS(2641),
    [anon_sym_DASH_DASH] = ACTIONS(2641),
    [anon_sym_DQUOTE] = ACTIONS(2641),
    [anon_sym_SQUOTE] = ACTIONS(2641),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(2641),
    [sym_number] = ACTIONS(2641),
    [sym_private_property_identifier] = ACTIONS(2641),
    [sym_this] = ACTIONS(2643),
    [sym_super] = ACTIONS(2643),
    [sym_true] = ACTIONS(2643),
    [sym_false] = ACTIONS(2643),
    [sym_null] = ACTIONS(2643),
    [sym_undefined] = ACTIONS(2643),
    [anon_sym_AT] = ACTIONS(2641),
    [anon_sym_static] = ACTIONS(2643),
    [anon_sym_readonly] = ACTIONS(2643),
    [anon_sym_get] = ACTIONS(2643),
    [anon_sym_set] = ACTIONS(2643),
    [anon_sym_declare] = ACTIONS(2643),
    [anon_sym_public] = ACTIONS(2643),
    [anon_sym_private] = ACTIONS(2643),
    [anon_sym_protected] = ACTIONS(2643),
    [anon_sym_override] = ACTIONS(2643),
    [anon_sym_module] = ACTIONS(2643),
    [anon_sym_any] = ACTIONS(2643),
    [anon_sym_number] = ACTIONS(2643),
    [anon_sym_boolean] = ACTIONS(2643),
    [anon_sym_string] = ACTIONS(2643),
    [anon_sym_symbol] = ACTIONS(2643),
    [anon_sym_object] = ACTIONS(2643),
    [anon_sym_abstract] = ACTIONS(2643),
    [anon_sym_interface] = ACTIONS(2643),
    [anon_sym_enum] = ACTIONS(2643),
    [sym_html_comment] = ACTIONS(5),
  },
  [843] = {
    [ts_builtin_sym_end] = ACTIONS(2645),
    [sym_identifier] = ACTIONS(2647),
    [anon_sym_export] = ACTIONS(2647),
    [anon_sym_default] = ACTIONS(2647),
    [anon_sym_type] = ACTIONS(2647),
    [anon_sym_namespace] = ACTIONS(2647),
    [anon_sym_LBRACE] = ACTIONS(2645),
    [anon_sym_RBRACE] = ACTIONS(2645),
    [anon_sym_typeof] = ACTIONS(2647),
    [anon_sym_import] = ACTIONS(2647),
    [anon_sym_with] = ACTIONS(2647),
    [anon_sym_var] = ACTIONS(2647),
    [anon_sym_let] = ACTIONS(2647),
    [anon_sym_const] = ACTIONS(2647),
    [anon_sym_BANG] = ACTIONS(2645),
    [anon_sym_else] = ACTIONS(2647),
    [anon_sym_if] = ACTIONS(2647),
    [anon_sym_switch] = ACTIONS(2647),
    [anon_sym_for] = ACTIONS(2647),
    [anon_sym_LPAREN] = ACTIONS(2645),
    [anon_sym_SEMI] = ACTIONS(2645),
    [anon_sym_await] = ACTIONS(2647),
    [anon_sym_while] = ACTIONS(2647),
    [anon_sym_do] = ACTIONS(2647),
    [anon_sym_try] = ACTIONS(2647),
    [anon_sym_break] = ACTIONS(2647),
    [anon_sym_continue] = ACTIONS(2647),
    [anon_sym_debugger] = ACTIONS(2647),
    [anon_sym_return] = ACTIONS(2647),
    [anon_sym_throw] = ACTIONS(2647),
    [anon_sym_case] = ACTIONS(2647),
    [anon_sym_yield] = ACTIONS(2647),
    [anon_sym_LBRACK] = ACTIONS(2645),
    [anon_sym_class] = ACTIONS(2647),
    [anon_sym_async] = ACTIONS(2647),
    [anon_sym_function] = ACTIONS(2647),
    [anon_sym_new] = ACTIONS(2647),
    [anon_sym_using] = ACTIONS(2647),
    [anon_sym_PLUS] = ACTIONS(2647),
    [anon_sym_DASH] = ACTIONS(2647),
    [anon_sym_SLASH] = ACTIONS(2647),
    [anon_sym_LT] = ACTIONS(2645),
    [anon_sym_TILDE] = ACTIONS(2645),
    [anon_sym_void] = ACTIONS(2647),
    [anon_sym_delete] = ACTIONS(2647),
    [anon_sym_PLUS_PLUS] = ACTIONS(2645),
    [anon_sym_DASH_DASH] = ACTIONS(2645),
    [anon_sym_DQUOTE] = ACTIONS(2645),
    [anon_sym_SQUOTE] = ACTIONS(2645),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(2645),
    [sym_number] = ACTIONS(2645),
    [sym_private_property_identifier] = ACTIONS(2645),
    [sym_this] = ACTIONS(2647),
    [sym_super] = ACTIONS(2647),
    [sym_true] = ACTIONS(2647),
    [sym_false] = ACTIONS(2647),
    [sym_null] = ACTIONS(2647),
    [sym_undefined] = ACTIONS(2647),
    [anon_sym_AT] = ACTIONS(2645),
    [anon_sym_static] = ACTIONS(2647),
    [anon_sym_readonly] = ACTIONS(2647),
    [anon_sym_get] = ACTIONS(2647),
    [anon_sym_set] = ACTIONS(2647),
    [anon_sym_declare] = ACTIONS(2647),
    [anon_sym_public] = ACTIONS(2647),
    [anon_sym_private] = ACTIONS(2647),
    [anon_sym_protected] = ACTIONS(2647),
    [anon_sym_override] = ACTIONS(2647),
    [anon_sym_module] = ACTIONS(2647),
    [anon_sym_any] = ACTIONS(2647),
    [anon_sym_number] = ACTIONS(2647),
    [anon_sym_boolean] = ACTIONS(2647),
    [anon_sym_string] = ACTIONS(2647),
    [anon_sym_symbol] = ACTIONS(2647),
    [anon_sym_object] = ACTIONS(2647),
    [anon_sym_abstract] = ACTIONS(2647),
    [anon_sym_interface] = ACTIONS(2647),
    [anon_sym_enum] = ACTIONS(2647),
    [sym_html_comment] = ACTIONS(5),
  },
  [844] = {
    [ts_builtin_sym_end] = ACTIONS(2649),
    [sym_identifier] = ACTIONS(2651),
    [anon_sym_export] = ACTIONS(2651),
    [anon_sym_default] = ACTIONS(2651),
    [anon_sym_type] = ACTIONS(2651),
    [anon_sym_namespace] = ACTIONS(2651),
    [anon_sym_LBRACE] = ACTIONS(2649),
    [anon_sym_RBRACE] = ACTIONS(2649),
    [anon_sym_typeof] = ACTIONS(2651),
    [anon_sym_import] = ACTIONS(2651),
    [anon_sym_with] = ACTIONS(2651),
    [anon_sym_var] = ACTIONS(2651),
    [anon_sym_let] = ACTIONS(2651),
    [anon_sym_const] = ACTIONS(2651),
    [anon_sym_BANG] = ACTIONS(2649),
    [anon_sym_else] = ACTIONS(2651),
    [anon_sym_if] = ACTIONS(2651),
    [anon_sym_switch] = ACTIONS(2651),
    [anon_sym_for] = ACTIONS(2651),
    [anon_sym_LPAREN] = ACTIONS(2649),
    [anon_sym_SEMI] = ACTIONS(2649),
    [anon_sym_await] = ACTIONS(2651),
    [anon_sym_while] = ACTIONS(2651),
    [anon_sym_do] = ACTIONS(2651),
    [anon_sym_try] = ACTIONS(2651),
    [anon_sym_break] = ACTIONS(2651),
    [anon_sym_continue] = ACTIONS(2651),
    [anon_sym_debugger] = ACTIONS(2651),
    [anon_sym_return] = ACTIONS(2651),
    [anon_sym_throw] = ACTIONS(2651),
    [anon_sym_case] = ACTIONS(2651),
    [anon_sym_yield] = ACTIONS(2651),
    [anon_sym_LBRACK] = ACTIONS(2649),
    [anon_sym_class] = ACTIONS(2651),
    [anon_sym_async] = ACTIONS(2651),
    [anon_sym_function] = ACTIONS(2651),
    [anon_sym_new] = ACTIONS(2651),
    [anon_sym_using] = ACTIONS(2651),
    [anon_sym_PLUS] = ACTIONS(2651),
    [anon_sym_DASH] = ACTIONS(2651),
    [anon_sym_SLASH] = ACTIONS(2651),
    [anon_sym_LT] = ACTIONS(2649),
    [anon_sym_TILDE] = ACTIONS(2649),
    [anon_sym_void] = ACTIONS(2651),
    [anon_sym_delete] = ACTIONS(2651),
    [anon_sym_PLUS_PLUS] = ACTIONS(2649),
    [anon_sym_DASH_DASH] = ACTIONS(2649),
    [anon_sym_DQUOTE] = ACTIONS(2649),
    [anon_sym_SQUOTE] = ACTIONS(2649),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(2649),
    [sym_number] = ACTIONS(2649),
    [sym_private_property_identifier] = ACTIONS(2649),
    [sym_this] = ACTIONS(2651),
    [sym_super] = ACTIONS(2651),
    [sym_true] = ACTIONS(2651),
    [sym_false] = ACTIONS(2651),
    [sym_null] = ACTIONS(2651),
    [sym_undefined] = ACTIONS(2651),
    [anon_sym_AT] = ACTIONS(2649),
    [anon_sym_static] = ACTIONS(2651),
    [anon_sym_readonly] = ACTIONS(2651),
    [anon_sym_get] = ACTIONS(2651),
    [anon_sym_set] = ACTIONS(2651),
    [anon_sym_declare] = ACTIONS(2651),
    [anon_sym_public] = ACTIONS(2651),
    [anon_sym_private] = ACTIONS(2651),
    [anon_sym_protected] = ACTIONS(2651),
    [anon_sym_override] = ACTIONS(2651),
    [anon_sym_module] = ACTIONS(2651),
    [anon_sym_any] = ACTIONS(2651),
    [anon_sym_number] = ACTIONS(2651),
    [anon_sym_boolean] = ACTIONS(2651),
    [anon_sym_string] = ACTIONS(2651),
    [anon_sym_symbol] = ACTIONS(2651),
    [anon_sym_object] = ACTIONS(2651),
    [anon_sym_abstract] = ACTIONS(2651),
    [anon_sym_interface] = ACTIONS(2651),
    [anon_sym_enum] = ACTIONS(2651),
    [sym_html_comment] = ACTIONS(5),
  },
  [845] = {
    [ts_builtin_sym_end] = ACTIONS(2653),
    [sym_identifier] = ACTIONS(2655),
    [anon_sym_export] = ACTIONS(2655),
    [anon_sym_default] = ACTIONS(2655),
    [anon_sym_type] = ACTIONS(2655),
    [anon_sym_namespace] = ACTIONS(2655),
    [anon_sym_LBRACE] = ACTIONS(2653),
    [anon_sym_RBRACE] = ACTIONS(2653),
    [anon_sym_typeof] = ACTIONS(2655),
    [anon_sym_import] = ACTIONS(2655),
    [anon_sym_with] = ACTIONS(2655),
    [anon_sym_var] = ACTIONS(2655),
    [anon_sym_let] = ACTIONS(2655),
    [anon_sym_const] = ACTIONS(2655),
    [anon_sym_BANG] = ACTIONS(2653),
    [anon_sym_else] = ACTIONS(2655),
    [anon_sym_if] = ACTIONS(2655),
    [anon_sym_switch] = ACTIONS(2655),
    [anon_sym_for] = ACTIONS(2655),
    [anon_sym_LPAREN] = ACTIONS(2653),
    [anon_sym_SEMI] = ACTIONS(2653),
    [anon_sym_await] = ACTIONS(2655),
    [anon_sym_while] = ACTIONS(2655),
    [anon_sym_do] = ACTIONS(2655),
    [anon_sym_try] = ACTIONS(2655),
    [anon_sym_break] = ACTIONS(2655),
    [anon_sym_continue] = ACTIONS(2655),
    [anon_sym_debugger] = ACTIONS(2655),
    [anon_sym_return] = ACTIONS(2655),
    [anon_sym_throw] = ACTIONS(2655),
    [anon_sym_case] = ACTIONS(2655),
    [anon_sym_yield] = ACTIONS(2655),
    [anon_sym_LBRACK] = ACTIONS(2653),
    [anon_sym_class] = ACTIONS(2655),
    [anon_sym_async] = ACTIONS(2655),
    [anon_sym_function] = ACTIONS(2655),
    [anon_sym_new] = ACTIONS(2655),
    [anon_sym_using] = ACTIONS(2655),
    [anon_sym_PLUS] = ACTIONS(2655),
    [anon_sym_DASH] = ACTIONS(2655),
    [anon_sym_SLASH] = ACTIONS(2655),
    [anon_sym_LT] = ACTIONS(2653),
    [anon_sym_TILDE] = ACTIONS(2653),
    [anon_sym_void] = ACTIONS(2655),
    [anon_sym_delete] = ACTIONS(2655),
    [anon_sym_PLUS_PLUS] = ACTIONS(2653),
    [anon_sym_DASH_DASH] = ACTIONS(2653),
    [anon_sym_DQUOTE] = ACTIONS(2653),
    [anon_sym_SQUOTE] = ACTIONS(2653),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(2653),
    [sym_number] = ACTIONS(2653),
    [sym_private_property_identifier] = ACTIONS(2653),
    [sym_this] = ACTIONS(2655),
    [sym_super] = ACTIONS(2655),
    [sym_true] = ACTIONS(2655),
    [sym_false] = ACTIONS(2655),
    [sym_null] = ACTIONS(2655),
    [sym_undefined] = ACTIONS(2655),
    [anon_sym_AT] = ACTIONS(2653),
    [anon_sym_static] = ACTIONS(2655),
    [anon_sym_readonly] = ACTIONS(2655),
    [anon_sym_get] = ACTIONS(2655),
    [anon_sym_set] = ACTIONS(2655),
    [anon_sym_declare] = ACTIONS(2655),
    [anon_sym_public] = ACTIONS(2655),
    [anon_sym_private] = ACTIONS(2655),
    [anon_sym_protected] = ACTIONS(2655),
    [anon_sym_override] = ACTIONS(2655),
    [anon_sym_module] = ACTIONS(2655),
    [anon_sym_any] = ACTIONS(2655),
    [anon_sym_number] = ACTIONS(2655),
    [anon_sym_boolean] = ACTIONS(2655),
    [anon_sym_string] = ACTIONS(2655),
    [anon_sym_symbol] = ACTIONS(2655),
    [anon_sym_object] = ACTIONS(2655),
    [anon_sym_abstract] = ACTIONS(2655),
    [anon_sym_interface] = ACTIONS(2655),
    [anon_sym_enum] = ACTIONS(2655),
    [sym_html_comment] = ACTIONS(5),
  },
  [846] = {
    [ts_builtin_sym_end] = ACTIONS(2657),
    [sym_identifier] = ACTIONS(2659),
    [anon_sym_export] = ACTIONS(2659),
    [anon_sym_default] = ACTIONS(2659),
    [anon_sym_type] = ACTIONS(2659),
    [anon_sym_namespace] = ACTIONS(2659),
    [anon_sym_LBRACE] = ACTIONS(2657),
    [anon_sym_RBRACE] = ACTIONS(2657),
    [anon_sym_typeof] = ACTIONS(2659),
    [anon_sym_import] = ACTIONS(2659),
    [anon_sym_with] = ACTIONS(2659),
    [anon_sym_var] = ACTIONS(2659),
    [anon_sym_let] = ACTIONS(2659),
    [anon_sym_const] = ACTIONS(2659),
    [anon_sym_BANG] = ACTIONS(2657),
    [anon_sym_else] = ACTIONS(2659),
    [anon_sym_if] = ACTIONS(2659),
    [anon_sym_switch] = ACTIONS(2659),
    [anon_sym_for] = ACTIONS(2659),
    [anon_sym_LPAREN] = ACTIONS(2657),
    [anon_sym_SEMI] = ACTIONS(2657),
    [anon_sym_await] = ACTIONS(2659),
    [anon_sym_while] = ACTIONS(2659),
    [anon_sym_do] = ACTIONS(2659),
    [anon_sym_try] = ACTIONS(2659),
    [anon_sym_break] = ACTIONS(2659),
    [anon_sym_continue] = ACTIONS(2659),
    [anon_sym_debugger] = ACTIONS(2659),
    [anon_sym_return] = ACTIONS(2659),
    [anon_sym_throw] = ACTIONS(2659),
    [anon_sym_case] = ACTIONS(2659),
    [anon_sym_yield] = ACTIONS(2659),
    [anon_sym_LBRACK] = ACTIONS(2657),
    [anon_sym_class] = ACTIONS(2659),
    [anon_sym_async] = ACTIONS(2659),
    [anon_sym_function] = ACTIONS(2659),
    [anon_sym_new] = ACTIONS(2659),
    [anon_sym_using] = ACTIONS(2659),
    [anon_sym_PLUS] = ACTIONS(2659),
    [anon_sym_DASH] = ACTIONS(2659),
    [anon_sym_SLASH] = ACTIONS(2659),
    [anon_sym_LT] = ACTIONS(2657),
    [anon_sym_TILDE] = ACTIONS(2657),
    [anon_sym_void] = ACTIONS(2659),
    [anon_sym_delete] = ACTIONS(2659),
    [anon_sym_PLUS_PLUS] = ACTIONS(2657),
    [anon_sym_DASH_DASH] = ACTIONS(2657),
    [anon_sym_DQUOTE] = ACTIONS(2657),
    [anon_sym_SQUOTE] = ACTIONS(2657),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(2657),
    [sym_number] = ACTIONS(2657),
    [sym_private_property_identifier] = ACTIONS(2657),
    [sym_this] = ACTIONS(2659),
    [sym_super] = ACTIONS(2659),
    [sym_true] = ACTIONS(2659),
    [sym_false] = ACTIONS(2659),
    [sym_null] = ACTIONS(2659),
    [sym_undefined] = ACTIONS(2659),
    [anon_sym_AT] = ACTIONS(2657),
    [anon_sym_static] = ACTIONS(2659),
    [anon_sym_readonly] = ACTIONS(2659),
    [anon_sym_get] = ACTIONS(2659),
    [anon_sym_set] = ACTIONS(2659),
    [anon_sym_declare] = ACTIONS(2659),
    [anon_sym_public] = ACTIONS(2659),
    [anon_sym_private] = ACTIONS(2659),
    [anon_sym_protected] = ACTIONS(2659),
    [anon_sym_override] = ACTIONS(2659),
    [anon_sym_module] = ACTIONS(2659),
    [anon_sym_any] = ACTIONS(2659),
    [anon_sym_number] = ACTIONS(2659),
    [anon_sym_boolean] = ACTIONS(2659),
    [anon_sym_string] = ACTIONS(2659),
    [anon_sym_symbol] = ACTIONS(2659),
    [anon_sym_object] = ACTIONS(2659),
    [anon_sym_abstract] = ACTIONS(2659),
    [anon_sym_interface] = ACTIONS(2659),
    [anon_sym_enum] = ACTIONS(2659),
    [sym_html_comment] = ACTIONS(5),
  },
  [847] = {
    [ts_builtin_sym_end] = ACTIONS(2661),
    [sym_identifier] = ACTIONS(2663),
    [anon_sym_export] = ACTIONS(2663),
    [anon_sym_default] = ACTIONS(2663),
    [anon_sym_type] = ACTIONS(2663),
    [anon_sym_namespace] = ACTIONS(2663),
    [anon_sym_LBRACE] = ACTIONS(2661),
    [anon_sym_RBRACE] = ACTIONS(2661),
    [anon_sym_typeof] = ACTIONS(2663),
    [anon_sym_import] = ACTIONS(2663),
    [anon_sym_with] = ACTIONS(2663),
    [anon_sym_var] = ACTIONS(2663),
    [anon_sym_let] = ACTIONS(2663),
    [anon_sym_const] = ACTIONS(2663),
    [anon_sym_BANG] = ACTIONS(2661),
    [anon_sym_else] = ACTIONS(2663),
    [anon_sym_if] = ACTIONS(2663),
    [anon_sym_switch] = ACTIONS(2663),
    [anon_sym_for] = ACTIONS(2663),
    [anon_sym_LPAREN] = ACTIONS(2661),
    [anon_sym_SEMI] = ACTIONS(2661),
    [anon_sym_await] = ACTIONS(2663),
    [anon_sym_while] = ACTIONS(2663),
    [anon_sym_do] = ACTIONS(2663),
    [anon_sym_try] = ACTIONS(2663),
    [anon_sym_break] = ACTIONS(2663),
    [anon_sym_continue] = ACTIONS(2663),
    [anon_sym_debugger] = ACTIONS(2663),
    [anon_sym_return] = ACTIONS(2663),
    [anon_sym_throw] = ACTIONS(2663),
    [anon_sym_case] = ACTIONS(2663),
    [anon_sym_yield] = ACTIONS(2663),
    [anon_sym_LBRACK] = ACTIONS(2661),
    [anon_sym_class] = ACTIONS(2663),
    [anon_sym_async] = ACTIONS(2663),
    [anon_sym_function] = ACTIONS(2663),
    [anon_sym_new] = ACTIONS(2663),
    [anon_sym_using] = ACTIONS(2663),
    [anon_sym_PLUS] = ACTIONS(2663),
    [anon_sym_DASH] = ACTIONS(2663),
    [anon_sym_SLASH] = ACTIONS(2663),
    [anon_sym_LT] = ACTIONS(2661),
    [anon_sym_TILDE] = ACTIONS(2661),
    [anon_sym_void] = ACTIONS(2663),
    [anon_sym_delete] = ACTIONS(2663),
    [anon_sym_PLUS_PLUS] = ACTIONS(2661),
    [anon_sym_DASH_DASH] = ACTIONS(2661),
    [anon_sym_DQUOTE] = ACTIONS(2661),
    [anon_sym_SQUOTE] = ACTIONS(2661),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(2661),
    [sym_number] = ACTIONS(2661),
    [sym_private_property_identifier] = ACTIONS(2661),
    [sym_this] = ACTIONS(2663),
    [sym_super] = ACTIONS(2663),
    [sym_true] = ACTIONS(2663),
    [sym_false] = ACTIONS(2663),
    [sym_null] = ACTIONS(2663),
    [sym_undefined] = ACTIONS(2663),
    [anon_sym_AT] = ACTIONS(2661),
    [anon_sym_static] = ACTIONS(2663),
    [anon_sym_readonly] = ACTIONS(2663),
    [anon_sym_get] = ACTIONS(2663),
    [anon_sym_set] = ACTIONS(2663),
    [anon_sym_declare] = ACTIONS(2663),
    [anon_sym_public] = ACTIONS(2663),
    [anon_sym_private] = ACTIONS(2663),
    [anon_sym_protected] = ACTIONS(2663),
    [anon_sym_override] = ACTIONS(2663),
    [anon_sym_module] = ACTIONS(2663),
    [anon_sym_any] = ACTIONS(2663),
    [anon_sym_number] = ACTIONS(2663),
    [anon_sym_boolean] = ACTIONS(2663),
    [anon_sym_string] = ACTIONS(2663),
    [anon_sym_symbol] = ACTIONS(2663),
    [anon_sym_object] = ACTIONS(2663),
    [anon_sym_abstract] = ACTIONS(2663),
    [anon_sym_interface] = ACTIONS(2663),
    [anon_sym_enum] = ACTIONS(2663),
    [sym_html_comment] = ACTIONS(5),
  },
  [848] = {
    [sym_import] = STATE(4681),
    [sym_nested_identifier] = STATE(5474),
    [sym_string] = STATE(2994),
    [sym_formal_parameters] = STATE(5619),
    [sym_rest_pattern] = STATE(5165),
    [sym_nested_type_identifier] = STATE(2939),
    [sym__type_query_member_expression_in_type_annotation] = STATE(3303),
    [sym__type_query_call_expression_in_type_annotation] = STATE(2938),
    [sym_type] = STATE(3773),
    [sym_tuple_parameter] = STATE(5278),
    [sym_optional_tuple_parameter] = STATE(5278),
    [sym_optional_type] = STATE(5278),
    [sym_rest_type] = STATE(5278),
    [sym__tuple_type_member] = STATE(5278),
    [sym_constructor_type] = STATE(3007),
    [sym_primary_type] = STATE(2981),
    [sym_template_literal_type] = STATE(3039),
    [sym_infer_type] = STATE(3007),
    [sym_conditional_type] = STATE(3039),
    [sym_generic_type] = STATE(3039),
    [sym_type_query] = STATE(3039),
    [sym_index_type_query] = STATE(3039),
    [sym_lookup_type] = STATE(3039),
    [sym_literal_type] = STATE(3039),
    [sym__number] = STATE(3041),
    [sym_existential_type] = STATE(3039),
    [sym_flow_maybe_type] = STATE(3039),
    [sym_parenthesized_type] = STATE(3039),
    [sym_predefined_type] = STATE(3039),
    [sym_object_type] = STATE(3039),
    [sym_type_parameters] = STATE(5454),
    [sym_array_type] = STATE(3039),
    [sym_tuple_type] = STATE(3039),
    [sym_readonly_type] = STATE(3007),
    [sym_union_type] = STATE(3039),
    [sym_intersection_type] = STATE(3039),
    [sym_function_type] = STATE(3007),
    [sym_identifier] = ACTIONS(2489),
    [anon_sym_STAR] = ACTIONS(543),
    [anon_sym_LBRACE] = ACTIONS(1534),
    [anon_sym_typeof] = ACTIONS(1536),
    [anon_sym_import] = ACTIONS(1538),
    [anon_sym_const] = ACTIONS(133),
    [anon_sym_LPAREN] = ACTIONS(1540),
    [anon_sym_LBRACK] = ACTIONS(1542),
    [anon_sym_RBRACK] = ACTIONS(2665),
    [anon_sym_new] = ACTIONS(1642),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(2495),
    [anon_sym_AMP] = ACTIONS(571),
    [anon_sym_PIPE] = ACTIONS(573),
    [anon_sym_PLUS] = ACTIONS(2497),
    [anon_sym_DASH] = ACTIONS(2497),
    [anon_sym_LT] = ACTIONS(2499),
    [anon_sym_void] = ACTIONS(216),
    [anon_sym_DQUOTE] = ACTIONS(1550),
    [anon_sym_SQUOTE] = ACTIONS(1552),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1554),
    [sym_number] = ACTIONS(1556),
    [sym_this] = ACTIONS(1558),
    [sym_true] = ACTIONS(1560),
    [sym_false] = ACTIONS(1560),
    [sym_null] = ACTIONS(1560),
    [sym_undefined] = ACTIONS(1560),
    [anon_sym_readonly] = ACTIONS(1648),
    [anon_sym_QMARK] = ACTIONS(593),
    [anon_sym_any] = ACTIONS(216),
    [anon_sym_number] = ACTIONS(216),
    [anon_sym_boolean] = ACTIONS(216),
    [anon_sym_string] = ACTIONS(216),
    [anon_sym_symbol] = ACTIONS(216),
    [anon_sym_object] = ACTIONS(216),
    [anon_sym_abstract] = ACTIONS(597),
    [anon_sym_infer] = ACTIONS(599),
    [anon_sym_keyof] = ACTIONS(601),
    [anon_sym_unique] = ACTIONS(214),
    [anon_sym_unknown] = ACTIONS(216),
    [anon_sym_never] = ACTIONS(216),
    [anon_sym_LBRACE_PIPE] = ACTIONS(218),
    [sym_html_comment] = ACTIONS(5),
  },
  [849] = {
    [ts_builtin_sym_end] = ACTIONS(2667),
    [sym_identifier] = ACTIONS(2669),
    [anon_sym_export] = ACTIONS(2669),
    [anon_sym_default] = ACTIONS(2669),
    [anon_sym_type] = ACTIONS(2669),
    [anon_sym_namespace] = ACTIONS(2669),
    [anon_sym_LBRACE] = ACTIONS(2667),
    [anon_sym_RBRACE] = ACTIONS(2667),
    [anon_sym_typeof] = ACTIONS(2669),
    [anon_sym_import] = ACTIONS(2669),
    [anon_sym_with] = ACTIONS(2669),
    [anon_sym_var] = ACTIONS(2669),
    [anon_sym_let] = ACTIONS(2669),
    [anon_sym_const] = ACTIONS(2669),
    [anon_sym_BANG] = ACTIONS(2667),
    [anon_sym_else] = ACTIONS(2669),
    [anon_sym_if] = ACTIONS(2669),
    [anon_sym_switch] = ACTIONS(2669),
    [anon_sym_for] = ACTIONS(2669),
    [anon_sym_LPAREN] = ACTIONS(2667),
    [anon_sym_SEMI] = ACTIONS(2667),
    [anon_sym_await] = ACTIONS(2669),
    [anon_sym_while] = ACTIONS(2669),
    [anon_sym_do] = ACTIONS(2669),
    [anon_sym_try] = ACTIONS(2669),
    [anon_sym_break] = ACTIONS(2669),
    [anon_sym_continue] = ACTIONS(2669),
    [anon_sym_debugger] = ACTIONS(2669),
    [anon_sym_return] = ACTIONS(2669),
    [anon_sym_throw] = ACTIONS(2669),
    [anon_sym_case] = ACTIONS(2669),
    [anon_sym_yield] = ACTIONS(2669),
    [anon_sym_LBRACK] = ACTIONS(2667),
    [anon_sym_class] = ACTIONS(2669),
    [anon_sym_async] = ACTIONS(2669),
    [anon_sym_function] = ACTIONS(2669),
    [anon_sym_new] = ACTIONS(2669),
    [anon_sym_using] = ACTIONS(2669),
    [anon_sym_PLUS] = ACTIONS(2669),
    [anon_sym_DASH] = ACTIONS(2669),
    [anon_sym_SLASH] = ACTIONS(2669),
    [anon_sym_LT] = ACTIONS(2667),
    [anon_sym_TILDE] = ACTIONS(2667),
    [anon_sym_void] = ACTIONS(2669),
    [anon_sym_delete] = ACTIONS(2669),
    [anon_sym_PLUS_PLUS] = ACTIONS(2667),
    [anon_sym_DASH_DASH] = ACTIONS(2667),
    [anon_sym_DQUOTE] = ACTIONS(2667),
    [anon_sym_SQUOTE] = ACTIONS(2667),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(2667),
    [sym_number] = ACTIONS(2667),
    [sym_private_property_identifier] = ACTIONS(2667),
    [sym_this] = ACTIONS(2669),
    [sym_super] = ACTIONS(2669),
    [sym_true] = ACTIONS(2669),
    [sym_false] = ACTIONS(2669),
    [sym_null] = ACTIONS(2669),
    [sym_undefined] = ACTIONS(2669),
    [anon_sym_AT] = ACTIONS(2667),
    [anon_sym_static] = ACTIONS(2669),
    [anon_sym_readonly] = ACTIONS(2669),
    [anon_sym_get] = ACTIONS(2669),
    [anon_sym_set] = ACTIONS(2669),
    [anon_sym_declare] = ACTIONS(2669),
    [anon_sym_public] = ACTIONS(2669),
    [anon_sym_private] = ACTIONS(2669),
    [anon_sym_protected] = ACTIONS(2669),
    [anon_sym_override] = ACTIONS(2669),
    [anon_sym_module] = ACTIONS(2669),
    [anon_sym_any] = ACTIONS(2669),
    [anon_sym_number] = ACTIONS(2669),
    [anon_sym_boolean] = ACTIONS(2669),
    [anon_sym_string] = ACTIONS(2669),
    [anon_sym_symbol] = ACTIONS(2669),
    [anon_sym_object] = ACTIONS(2669),
    [anon_sym_abstract] = ACTIONS(2669),
    [anon_sym_interface] = ACTIONS(2669),
    [anon_sym_enum] = ACTIONS(2669),
    [sym_html_comment] = ACTIONS(5),
  },
  [850] = {
    [ts_builtin_sym_end] = ACTIONS(2671),
    [sym_identifier] = ACTIONS(2673),
    [anon_sym_export] = ACTIONS(2673),
    [anon_sym_default] = ACTIONS(2673),
    [anon_sym_type] = ACTIONS(2673),
    [anon_sym_namespace] = ACTIONS(2673),
    [anon_sym_LBRACE] = ACTIONS(2671),
    [anon_sym_RBRACE] = ACTIONS(2671),
    [anon_sym_typeof] = ACTIONS(2673),
    [anon_sym_import] = ACTIONS(2673),
    [anon_sym_with] = ACTIONS(2673),
    [anon_sym_var] = ACTIONS(2673),
    [anon_sym_let] = ACTIONS(2673),
    [anon_sym_const] = ACTIONS(2673),
    [anon_sym_BANG] = ACTIONS(2671),
    [anon_sym_else] = ACTIONS(2673),
    [anon_sym_if] = ACTIONS(2673),
    [anon_sym_switch] = ACTIONS(2673),
    [anon_sym_for] = ACTIONS(2673),
    [anon_sym_LPAREN] = ACTIONS(2671),
    [anon_sym_SEMI] = ACTIONS(2671),
    [anon_sym_await] = ACTIONS(2673),
    [anon_sym_while] = ACTIONS(2673),
    [anon_sym_do] = ACTIONS(2673),
    [anon_sym_try] = ACTIONS(2673),
    [anon_sym_break] = ACTIONS(2673),
    [anon_sym_continue] = ACTIONS(2673),
    [anon_sym_debugger] = ACTIONS(2673),
    [anon_sym_return] = ACTIONS(2673),
    [anon_sym_throw] = ACTIONS(2673),
    [anon_sym_case] = ACTIONS(2673),
    [anon_sym_yield] = ACTIONS(2673),
    [anon_sym_LBRACK] = ACTIONS(2671),
    [anon_sym_class] = ACTIONS(2673),
    [anon_sym_async] = ACTIONS(2673),
    [anon_sym_function] = ACTIONS(2673),
    [anon_sym_new] = ACTIONS(2673),
    [anon_sym_using] = ACTIONS(2673),
    [anon_sym_PLUS] = ACTIONS(2673),
    [anon_sym_DASH] = ACTIONS(2673),
    [anon_sym_SLASH] = ACTIONS(2673),
    [anon_sym_LT] = ACTIONS(2671),
    [anon_sym_TILDE] = ACTIONS(2671),
    [anon_sym_void] = ACTIONS(2673),
    [anon_sym_delete] = ACTIONS(2673),
    [anon_sym_PLUS_PLUS] = ACTIONS(2671),
    [anon_sym_DASH_DASH] = ACTIONS(2671),
    [anon_sym_DQUOTE] = ACTIONS(2671),
    [anon_sym_SQUOTE] = ACTIONS(2671),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(2671),
    [sym_number] = ACTIONS(2671),
    [sym_private_property_identifier] = ACTIONS(2671),
    [sym_this] = ACTIONS(2673),
    [sym_super] = ACTIONS(2673),
    [sym_true] = ACTIONS(2673),
    [sym_false] = ACTIONS(2673),
    [sym_null] = ACTIONS(2673),
    [sym_undefined] = ACTIONS(2673),
    [anon_sym_AT] = ACTIONS(2671),
    [anon_sym_static] = ACTIONS(2673),
    [anon_sym_readonly] = ACTIONS(2673),
    [anon_sym_get] = ACTIONS(2673),
    [anon_sym_set] = ACTIONS(2673),
    [anon_sym_declare] = ACTIONS(2673),
    [anon_sym_public] = ACTIONS(2673),
    [anon_sym_private] = ACTIONS(2673),
    [anon_sym_protected] = ACTIONS(2673),
    [anon_sym_override] = ACTIONS(2673),
    [anon_sym_module] = ACTIONS(2673),
    [anon_sym_any] = ACTIONS(2673),
    [anon_sym_number] = ACTIONS(2673),
    [anon_sym_boolean] = ACTIONS(2673),
    [anon_sym_string] = ACTIONS(2673),
    [anon_sym_symbol] = ACTIONS(2673),
    [anon_sym_object] = ACTIONS(2673),
    [anon_sym_abstract] = ACTIONS(2673),
    [anon_sym_interface] = ACTIONS(2673),
    [anon_sym_enum] = ACTIONS(2673),
    [sym_html_comment] = ACTIONS(5),
  },
  [851] = {
    [ts_builtin_sym_end] = ACTIONS(2675),
    [sym_identifier] = ACTIONS(2677),
    [anon_sym_export] = ACTIONS(2677),
    [anon_sym_default] = ACTIONS(2677),
    [anon_sym_type] = ACTIONS(2677),
    [anon_sym_namespace] = ACTIONS(2677),
    [anon_sym_LBRACE] = ACTIONS(2675),
    [anon_sym_RBRACE] = ACTIONS(2675),
    [anon_sym_typeof] = ACTIONS(2677),
    [anon_sym_import] = ACTIONS(2677),
    [anon_sym_with] = ACTIONS(2677),
    [anon_sym_var] = ACTIONS(2677),
    [anon_sym_let] = ACTIONS(2677),
    [anon_sym_const] = ACTIONS(2677),
    [anon_sym_BANG] = ACTIONS(2675),
    [anon_sym_else] = ACTIONS(2677),
    [anon_sym_if] = ACTIONS(2677),
    [anon_sym_switch] = ACTIONS(2677),
    [anon_sym_for] = ACTIONS(2677),
    [anon_sym_LPAREN] = ACTIONS(2675),
    [anon_sym_SEMI] = ACTIONS(2675),
    [anon_sym_await] = ACTIONS(2677),
    [anon_sym_while] = ACTIONS(2677),
    [anon_sym_do] = ACTIONS(2677),
    [anon_sym_try] = ACTIONS(2677),
    [anon_sym_break] = ACTIONS(2677),
    [anon_sym_continue] = ACTIONS(2677),
    [anon_sym_debugger] = ACTIONS(2677),
    [anon_sym_return] = ACTIONS(2677),
    [anon_sym_throw] = ACTIONS(2677),
    [anon_sym_case] = ACTIONS(2677),
    [anon_sym_yield] = ACTIONS(2677),
    [anon_sym_LBRACK] = ACTIONS(2675),
    [anon_sym_class] = ACTIONS(2677),
    [anon_sym_async] = ACTIONS(2677),
    [anon_sym_function] = ACTIONS(2677),
    [anon_sym_new] = ACTIONS(2677),
    [anon_sym_using] = ACTIONS(2677),
    [anon_sym_PLUS] = ACTIONS(2677),
    [anon_sym_DASH] = ACTIONS(2677),
    [anon_sym_SLASH] = ACTIONS(2677),
    [anon_sym_LT] = ACTIONS(2675),
    [anon_sym_TILDE] = ACTIONS(2675),
    [anon_sym_void] = ACTIONS(2677),
    [anon_sym_delete] = ACTIONS(2677),
    [anon_sym_PLUS_PLUS] = ACTIONS(2675),
    [anon_sym_DASH_DASH] = ACTIONS(2675),
    [anon_sym_DQUOTE] = ACTIONS(2675),
    [anon_sym_SQUOTE] = ACTIONS(2675),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(2675),
    [sym_number] = ACTIONS(2675),
    [sym_private_property_identifier] = ACTIONS(2675),
    [sym_this] = ACTIONS(2677),
    [sym_super] = ACTIONS(2677),
    [sym_true] = ACTIONS(2677),
    [sym_false] = ACTIONS(2677),
    [sym_null] = ACTIONS(2677),
    [sym_undefined] = ACTIONS(2677),
    [anon_sym_AT] = ACTIONS(2675),
    [anon_sym_static] = ACTIONS(2677),
    [anon_sym_readonly] = ACTIONS(2677),
    [anon_sym_get] = ACTIONS(2677),
    [anon_sym_set] = ACTIONS(2677),
    [anon_sym_declare] = ACTIONS(2677),
    [anon_sym_public] = ACTIONS(2677),
    [anon_sym_private] = ACTIONS(2677),
    [anon_sym_protected] = ACTIONS(2677),
    [anon_sym_override] = ACTIONS(2677),
    [anon_sym_module] = ACTIONS(2677),
    [anon_sym_any] = ACTIONS(2677),
    [anon_sym_number] = ACTIONS(2677),
    [anon_sym_boolean] = ACTIONS(2677),
    [anon_sym_string] = ACTIONS(2677),
    [anon_sym_symbol] = ACTIONS(2677),
    [anon_sym_object] = ACTIONS(2677),
    [anon_sym_abstract] = ACTIONS(2677),
    [anon_sym_interface] = ACTIONS(2677),
    [anon_sym_enum] = ACTIONS(2677),
    [sym_html_comment] = ACTIONS(5),
  },
  [852] = {
    [ts_builtin_sym_end] = ACTIONS(2679),
    [sym_identifier] = ACTIONS(2681),
    [anon_sym_export] = ACTIONS(2681),
    [anon_sym_default] = ACTIONS(2681),
    [anon_sym_type] = ACTIONS(2681),
    [anon_sym_namespace] = ACTIONS(2681),
    [anon_sym_LBRACE] = ACTIONS(2679),
    [anon_sym_RBRACE] = ACTIONS(2679),
    [anon_sym_typeof] = ACTIONS(2681),
    [anon_sym_import] = ACTIONS(2681),
    [anon_sym_with] = ACTIONS(2681),
    [anon_sym_var] = ACTIONS(2681),
    [anon_sym_let] = ACTIONS(2681),
    [anon_sym_const] = ACTIONS(2681),
    [anon_sym_BANG] = ACTIONS(2679),
    [anon_sym_else] = ACTIONS(2681),
    [anon_sym_if] = ACTIONS(2681),
    [anon_sym_switch] = ACTIONS(2681),
    [anon_sym_for] = ACTIONS(2681),
    [anon_sym_LPAREN] = ACTIONS(2679),
    [anon_sym_SEMI] = ACTIONS(2679),
    [anon_sym_await] = ACTIONS(2681),
    [anon_sym_while] = ACTIONS(2681),
    [anon_sym_do] = ACTIONS(2681),
    [anon_sym_try] = ACTIONS(2681),
    [anon_sym_break] = ACTIONS(2681),
    [anon_sym_continue] = ACTIONS(2681),
    [anon_sym_debugger] = ACTIONS(2681),
    [anon_sym_return] = ACTIONS(2681),
    [anon_sym_throw] = ACTIONS(2681),
    [anon_sym_case] = ACTIONS(2681),
    [anon_sym_yield] = ACTIONS(2681),
    [anon_sym_LBRACK] = ACTIONS(2679),
    [anon_sym_class] = ACTIONS(2681),
    [anon_sym_async] = ACTIONS(2681),
    [anon_sym_function] = ACTIONS(2681),
    [anon_sym_new] = ACTIONS(2681),
    [anon_sym_using] = ACTIONS(2681),
    [anon_sym_PLUS] = ACTIONS(2681),
    [anon_sym_DASH] = ACTIONS(2681),
    [anon_sym_SLASH] = ACTIONS(2681),
    [anon_sym_LT] = ACTIONS(2679),
    [anon_sym_TILDE] = ACTIONS(2679),
    [anon_sym_void] = ACTIONS(2681),
    [anon_sym_delete] = ACTIONS(2681),
    [anon_sym_PLUS_PLUS] = ACTIONS(2679),
    [anon_sym_DASH_DASH] = ACTIONS(2679),
    [anon_sym_DQUOTE] = ACTIONS(2679),
    [anon_sym_SQUOTE] = ACTIONS(2679),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(2679),
    [sym_number] = ACTIONS(2679),
    [sym_private_property_identifier] = ACTIONS(2679),
    [sym_this] = ACTIONS(2681),
    [sym_super] = ACTIONS(2681),
    [sym_true] = ACTIONS(2681),
    [sym_false] = ACTIONS(2681),
    [sym_null] = ACTIONS(2681),
    [sym_undefined] = ACTIONS(2681),
    [anon_sym_AT] = ACTIONS(2679),
    [anon_sym_static] = ACTIONS(2681),
    [anon_sym_readonly] = ACTIONS(2681),
    [anon_sym_get] = ACTIONS(2681),
    [anon_sym_set] = ACTIONS(2681),
    [anon_sym_declare] = ACTIONS(2681),
    [anon_sym_public] = ACTIONS(2681),
    [anon_sym_private] = ACTIONS(2681),
    [anon_sym_protected] = ACTIONS(2681),
    [anon_sym_override] = ACTIONS(2681),
    [anon_sym_module] = ACTIONS(2681),
    [anon_sym_any] = ACTIONS(2681),
    [anon_sym_number] = ACTIONS(2681),
    [anon_sym_boolean] = ACTIONS(2681),
    [anon_sym_string] = ACTIONS(2681),
    [anon_sym_symbol] = ACTIONS(2681),
    [anon_sym_object] = ACTIONS(2681),
    [anon_sym_abstract] = ACTIONS(2681),
    [anon_sym_interface] = ACTIONS(2681),
    [anon_sym_enum] = ACTIONS(2681),
    [sym_html_comment] = ACTIONS(5),
  },
  [853] = {
    [ts_builtin_sym_end] = ACTIONS(2683),
    [sym_identifier] = ACTIONS(2685),
    [anon_sym_export] = ACTIONS(2685),
    [anon_sym_default] = ACTIONS(2685),
    [anon_sym_type] = ACTIONS(2685),
    [anon_sym_namespace] = ACTIONS(2685),
    [anon_sym_LBRACE] = ACTIONS(2683),
    [anon_sym_RBRACE] = ACTIONS(2683),
    [anon_sym_typeof] = ACTIONS(2685),
    [anon_sym_import] = ACTIONS(2685),
    [anon_sym_with] = ACTIONS(2685),
    [anon_sym_var] = ACTIONS(2685),
    [anon_sym_let] = ACTIONS(2685),
    [anon_sym_const] = ACTIONS(2685),
    [anon_sym_BANG] = ACTIONS(2683),
    [anon_sym_else] = ACTIONS(2685),
    [anon_sym_if] = ACTIONS(2685),
    [anon_sym_switch] = ACTIONS(2685),
    [anon_sym_for] = ACTIONS(2685),
    [anon_sym_LPAREN] = ACTIONS(2683),
    [anon_sym_SEMI] = ACTIONS(2683),
    [anon_sym_await] = ACTIONS(2685),
    [anon_sym_while] = ACTIONS(2685),
    [anon_sym_do] = ACTIONS(2685),
    [anon_sym_try] = ACTIONS(2685),
    [anon_sym_break] = ACTIONS(2685),
    [anon_sym_continue] = ACTIONS(2685),
    [anon_sym_debugger] = ACTIONS(2685),
    [anon_sym_return] = ACTIONS(2685),
    [anon_sym_throw] = ACTIONS(2685),
    [anon_sym_case] = ACTIONS(2685),
    [anon_sym_yield] = ACTIONS(2685),
    [anon_sym_LBRACK] = ACTIONS(2683),
    [anon_sym_class] = ACTIONS(2685),
    [anon_sym_async] = ACTIONS(2685),
    [anon_sym_function] = ACTIONS(2685),
    [anon_sym_new] = ACTIONS(2685),
    [anon_sym_using] = ACTIONS(2685),
    [anon_sym_PLUS] = ACTIONS(2685),
    [anon_sym_DASH] = ACTIONS(2685),
    [anon_sym_SLASH] = ACTIONS(2685),
    [anon_sym_LT] = ACTIONS(2683),
    [anon_sym_TILDE] = ACTIONS(2683),
    [anon_sym_void] = ACTIONS(2685),
    [anon_sym_delete] = ACTIONS(2685),
    [anon_sym_PLUS_PLUS] = ACTIONS(2683),
    [anon_sym_DASH_DASH] = ACTIONS(2683),
    [anon_sym_DQUOTE] = ACTIONS(2683),
    [anon_sym_SQUOTE] = ACTIONS(2683),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(2683),
    [sym_number] = ACTIONS(2683),
    [sym_private_property_identifier] = ACTIONS(2683),
    [sym_this] = ACTIONS(2685),
    [sym_super] = ACTIONS(2685),
    [sym_true] = ACTIONS(2685),
    [sym_false] = ACTIONS(2685),
    [sym_null] = ACTIONS(2685),
    [sym_undefined] = ACTIONS(2685),
    [anon_sym_AT] = ACTIONS(2683),
    [anon_sym_static] = ACTIONS(2685),
    [anon_sym_readonly] = ACTIONS(2685),
    [anon_sym_get] = ACTIONS(2685),
    [anon_sym_set] = ACTIONS(2685),
    [anon_sym_declare] = ACTIONS(2685),
    [anon_sym_public] = ACTIONS(2685),
    [anon_sym_private] = ACTIONS(2685),
    [anon_sym_protected] = ACTIONS(2685),
    [anon_sym_override] = ACTIONS(2685),
    [anon_sym_module] = ACTIONS(2685),
    [anon_sym_any] = ACTIONS(2685),
    [anon_sym_number] = ACTIONS(2685),
    [anon_sym_boolean] = ACTIONS(2685),
    [anon_sym_string] = ACTIONS(2685),
    [anon_sym_symbol] = ACTIONS(2685),
    [anon_sym_object] = ACTIONS(2685),
    [anon_sym_abstract] = ACTIONS(2685),
    [anon_sym_interface] = ACTIONS(2685),
    [anon_sym_enum] = ACTIONS(2685),
    [sym_html_comment] = ACTIONS(5),
  },
  [854] = {
    [ts_builtin_sym_end] = ACTIONS(2687),
    [sym_identifier] = ACTIONS(2689),
    [anon_sym_export] = ACTIONS(2689),
    [anon_sym_default] = ACTIONS(2689),
    [anon_sym_type] = ACTIONS(2689),
    [anon_sym_namespace] = ACTIONS(2689),
    [anon_sym_LBRACE] = ACTIONS(2687),
    [anon_sym_RBRACE] = ACTIONS(2687),
    [anon_sym_typeof] = ACTIONS(2689),
    [anon_sym_import] = ACTIONS(2689),
    [anon_sym_with] = ACTIONS(2689),
    [anon_sym_var] = ACTIONS(2689),
    [anon_sym_let] = ACTIONS(2689),
    [anon_sym_const] = ACTIONS(2689),
    [anon_sym_BANG] = ACTIONS(2687),
    [anon_sym_else] = ACTIONS(2689),
    [anon_sym_if] = ACTIONS(2689),
    [anon_sym_switch] = ACTIONS(2689),
    [anon_sym_for] = ACTIONS(2689),
    [anon_sym_LPAREN] = ACTIONS(2687),
    [anon_sym_SEMI] = ACTIONS(2687),
    [anon_sym_await] = ACTIONS(2689),
    [anon_sym_while] = ACTIONS(2689),
    [anon_sym_do] = ACTIONS(2689),
    [anon_sym_try] = ACTIONS(2689),
    [anon_sym_break] = ACTIONS(2689),
    [anon_sym_continue] = ACTIONS(2689),
    [anon_sym_debugger] = ACTIONS(2689),
    [anon_sym_return] = ACTIONS(2689),
    [anon_sym_throw] = ACTIONS(2689),
    [anon_sym_case] = ACTIONS(2689),
    [anon_sym_yield] = ACTIONS(2689),
    [anon_sym_LBRACK] = ACTIONS(2687),
    [anon_sym_class] = ACTIONS(2689),
    [anon_sym_async] = ACTIONS(2689),
    [anon_sym_function] = ACTIONS(2689),
    [anon_sym_new] = ACTIONS(2689),
    [anon_sym_using] = ACTIONS(2689),
    [anon_sym_PLUS] = ACTIONS(2689),
    [anon_sym_DASH] = ACTIONS(2689),
    [anon_sym_SLASH] = ACTIONS(2689),
    [anon_sym_LT] = ACTIONS(2687),
    [anon_sym_TILDE] = ACTIONS(2687),
    [anon_sym_void] = ACTIONS(2689),
    [anon_sym_delete] = ACTIONS(2689),
    [anon_sym_PLUS_PLUS] = ACTIONS(2687),
    [anon_sym_DASH_DASH] = ACTIONS(2687),
    [anon_sym_DQUOTE] = ACTIONS(2687),
    [anon_sym_SQUOTE] = ACTIONS(2687),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(2687),
    [sym_number] = ACTIONS(2687),
    [sym_private_property_identifier] = ACTIONS(2687),
    [sym_this] = ACTIONS(2689),
    [sym_super] = ACTIONS(2689),
    [sym_true] = ACTIONS(2689),
    [sym_false] = ACTIONS(2689),
    [sym_null] = ACTIONS(2689),
    [sym_undefined] = ACTIONS(2689),
    [anon_sym_AT] = ACTIONS(2687),
    [anon_sym_static] = ACTIONS(2689),
    [anon_sym_readonly] = ACTIONS(2689),
    [anon_sym_get] = ACTIONS(2689),
    [anon_sym_set] = ACTIONS(2689),
    [anon_sym_declare] = ACTIONS(2689),
    [anon_sym_public] = ACTIONS(2689),
    [anon_sym_private] = ACTIONS(2689),
    [anon_sym_protected] = ACTIONS(2689),
    [anon_sym_override] = ACTIONS(2689),
    [anon_sym_module] = ACTIONS(2689),
    [anon_sym_any] = ACTIONS(2689),
    [anon_sym_number] = ACTIONS(2689),
    [anon_sym_boolean] = ACTIONS(2689),
    [anon_sym_string] = ACTIONS(2689),
    [anon_sym_symbol] = ACTIONS(2689),
    [anon_sym_object] = ACTIONS(2689),
    [anon_sym_abstract] = ACTIONS(2689),
    [anon_sym_interface] = ACTIONS(2689),
    [anon_sym_enum] = ACTIONS(2689),
    [sym_html_comment] = ACTIONS(5),
  },
  [855] = {
    [ts_builtin_sym_end] = ACTIONS(2691),
    [sym_identifier] = ACTIONS(2693),
    [anon_sym_export] = ACTIONS(2693),
    [anon_sym_default] = ACTIONS(2693),
    [anon_sym_type] = ACTIONS(2693),
    [anon_sym_namespace] = ACTIONS(2693),
    [anon_sym_LBRACE] = ACTIONS(2691),
    [anon_sym_RBRACE] = ACTIONS(2691),
    [anon_sym_typeof] = ACTIONS(2693),
    [anon_sym_import] = ACTIONS(2693),
    [anon_sym_with] = ACTIONS(2693),
    [anon_sym_var] = ACTIONS(2693),
    [anon_sym_let] = ACTIONS(2693),
    [anon_sym_const] = ACTIONS(2693),
    [anon_sym_BANG] = ACTIONS(2691),
    [anon_sym_else] = ACTIONS(2693),
    [anon_sym_if] = ACTIONS(2693),
    [anon_sym_switch] = ACTIONS(2693),
    [anon_sym_for] = ACTIONS(2693),
    [anon_sym_LPAREN] = ACTIONS(2691),
    [anon_sym_SEMI] = ACTIONS(2691),
    [anon_sym_await] = ACTIONS(2693),
    [anon_sym_while] = ACTIONS(2693),
    [anon_sym_do] = ACTIONS(2693),
    [anon_sym_try] = ACTIONS(2693),
    [anon_sym_break] = ACTIONS(2693),
    [anon_sym_continue] = ACTIONS(2693),
    [anon_sym_debugger] = ACTIONS(2693),
    [anon_sym_return] = ACTIONS(2693),
    [anon_sym_throw] = ACTIONS(2693),
    [anon_sym_case] = ACTIONS(2693),
    [anon_sym_yield] = ACTIONS(2693),
    [anon_sym_LBRACK] = ACTIONS(2691),
    [anon_sym_class] = ACTIONS(2693),
    [anon_sym_async] = ACTIONS(2693),
    [anon_sym_function] = ACTIONS(2693),
    [anon_sym_new] = ACTIONS(2693),
    [anon_sym_using] = ACTIONS(2693),
    [anon_sym_PLUS] = ACTIONS(2693),
    [anon_sym_DASH] = ACTIONS(2693),
    [anon_sym_SLASH] = ACTIONS(2693),
    [anon_sym_LT] = ACTIONS(2691),
    [anon_sym_TILDE] = ACTIONS(2691),
    [anon_sym_void] = ACTIONS(2693),
    [anon_sym_delete] = ACTIONS(2693),
    [anon_sym_PLUS_PLUS] = ACTIONS(2691),
    [anon_sym_DASH_DASH] = ACTIONS(2691),
    [anon_sym_DQUOTE] = ACTIONS(2691),
    [anon_sym_SQUOTE] = ACTIONS(2691),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(2691),
    [sym_number] = ACTIONS(2691),
    [sym_private_property_identifier] = ACTIONS(2691),
    [sym_this] = ACTIONS(2693),
    [sym_super] = ACTIONS(2693),
    [sym_true] = ACTIONS(2693),
    [sym_false] = ACTIONS(2693),
    [sym_null] = ACTIONS(2693),
    [sym_undefined] = ACTIONS(2693),
    [anon_sym_AT] = ACTIONS(2691),
    [anon_sym_static] = ACTIONS(2693),
    [anon_sym_readonly] = ACTIONS(2693),
    [anon_sym_get] = ACTIONS(2693),
    [anon_sym_set] = ACTIONS(2693),
    [anon_sym_declare] = ACTIONS(2693),
    [anon_sym_public] = ACTIONS(2693),
    [anon_sym_private] = ACTIONS(2693),
    [anon_sym_protected] = ACTIONS(2693),
    [anon_sym_override] = ACTIONS(2693),
    [anon_sym_module] = ACTIONS(2693),
    [anon_sym_any] = ACTIONS(2693),
    [anon_sym_number] = ACTIONS(2693),
    [anon_sym_boolean] = ACTIONS(2693),
    [anon_sym_string] = ACTIONS(2693),
    [anon_sym_symbol] = ACTIONS(2693),
    [anon_sym_object] = ACTIONS(2693),
    [anon_sym_abstract] = ACTIONS(2693),
    [anon_sym_interface] = ACTIONS(2693),
    [anon_sym_enum] = ACTIONS(2693),
    [sym_html_comment] = ACTIONS(5),
  },
  [856] = {
    [ts_builtin_sym_end] = ACTIONS(2695),
    [sym_identifier] = ACTIONS(2697),
    [anon_sym_export] = ACTIONS(2697),
    [anon_sym_default] = ACTIONS(2697),
    [anon_sym_type] = ACTIONS(2697),
    [anon_sym_namespace] = ACTIONS(2697),
    [anon_sym_LBRACE] = ACTIONS(2695),
    [anon_sym_RBRACE] = ACTIONS(2695),
    [anon_sym_typeof] = ACTIONS(2697),
    [anon_sym_import] = ACTIONS(2697),
    [anon_sym_with] = ACTIONS(2697),
    [anon_sym_var] = ACTIONS(2697),
    [anon_sym_let] = ACTIONS(2697),
    [anon_sym_const] = ACTIONS(2697),
    [anon_sym_BANG] = ACTIONS(2695),
    [anon_sym_else] = ACTIONS(2697),
    [anon_sym_if] = ACTIONS(2697),
    [anon_sym_switch] = ACTIONS(2697),
    [anon_sym_for] = ACTIONS(2697),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_SEMI] = ACTIONS(2695),
    [anon_sym_await] = ACTIONS(2697),
    [anon_sym_while] = ACTIONS(2697),
    [anon_sym_do] = ACTIONS(2697),
    [anon_sym_try] = ACTIONS(2697),
    [anon_sym_break] = ACTIONS(2697),
    [anon_sym_continue] = ACTIONS(2697),
    [anon_sym_debugger] = ACTIONS(2697),
    [anon_sym_return] = ACTIONS(2697),
    [anon_sym_throw] = ACTIONS(2697),
    [anon_sym_case] = ACTIONS(2697),
    [anon_sym_yield] = ACTIONS(2697),
    [anon_sym_LBRACK] = ACTIONS(2695),
    [anon_sym_class] = ACTIONS(2697),
    [anon_sym_async] = ACTIONS(2697),
    [anon_sym_function] = ACTIONS(2697),
    [anon_sym_new] = ACTIONS(2697),
    [anon_sym_using] = ACTIONS(2697),
    [anon_sym_PLUS] = ACTIONS(2697),
    [anon_sym_DASH] = ACTIONS(2697),
    [anon_sym_SLASH] = ACTIONS(2697),
    [anon_sym_LT] = ACTIONS(2695),
    [anon_sym_TILDE] = ACTIONS(2695),
    [anon_sym_void] = ACTIONS(2697),
    [anon_sym_delete] = ACTIONS(2697),
    [anon_sym_PLUS_PLUS] = ACTIONS(2695),
    [anon_sym_DASH_DASH] = ACTIONS(2695),
    [anon_sym_DQUOTE] = ACTIONS(2695),
    [anon_sym_SQUOTE] = ACTIONS(2695),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(2695),
    [sym_number] = ACTIONS(2695),
    [sym_private_property_identifier] = ACTIONS(2695),
    [sym_this] = ACTIONS(2697),
    [sym_super] = ACTIONS(2697),
    [sym_true] = ACTIONS(2697),
    [sym_false] = ACTIONS(2697),
    [sym_null] = ACTIONS(2697),
    [sym_undefined] = ACTIONS(2697),
    [anon_sym_AT] = ACTIONS(2695),
    [anon_sym_static] = ACTIONS(2697),
    [anon_sym_readonly] = ACTIONS(2697),
    [anon_sym_get] = ACTIONS(2697),
    [anon_sym_set] = ACTIONS(2697),
    [anon_sym_declare] = ACTIONS(2697),
    [anon_sym_public] = ACTIONS(2697),
    [anon_sym_private] = ACTIONS(2697),
    [anon_sym_protected] = ACTIONS(2697),
    [anon_sym_override] = ACTIONS(2697),
    [anon_sym_module] = ACTIONS(2697),
    [anon_sym_any] = ACTIONS(2697),
    [anon_sym_number] = ACTIONS(2697),
    [anon_sym_boolean] = ACTIONS(2697),
    [anon_sym_string] = ACTIONS(2697),
    [anon_sym_symbol] = ACTIONS(2697),
    [anon_sym_object] = ACTIONS(2697),
    [anon_sym_abstract] = ACTIONS(2697),
    [anon_sym_interface] = ACTIONS(2697),
    [anon_sym_enum] = ACTIONS(2697),
    [sym_html_comment] = ACTIONS(5),
  },
  [857] = {
    [ts_builtin_sym_end] = ACTIONS(2699),
    [sym_identifier] = ACTIONS(2701),
    [anon_sym_export] = ACTIONS(2701),
    [anon_sym_default] = ACTIONS(2701),
    [anon_sym_type] = ACTIONS(2701),
    [anon_sym_namespace] = ACTIONS(2701),
    [anon_sym_LBRACE] = ACTIONS(2699),
    [anon_sym_RBRACE] = ACTIONS(2699),
    [anon_sym_typeof] = ACTIONS(2701),
    [anon_sym_import] = ACTIONS(2701),
    [anon_sym_with] = ACTIONS(2701),
    [anon_sym_var] = ACTIONS(2701),
    [anon_sym_let] = ACTIONS(2701),
    [anon_sym_const] = ACTIONS(2701),
    [anon_sym_BANG] = ACTIONS(2699),
    [anon_sym_else] = ACTIONS(2701),
    [anon_sym_if] = ACTIONS(2701),
    [anon_sym_switch] = ACTIONS(2701),
    [anon_sym_for] = ACTIONS(2701),
    [anon_sym_LPAREN] = ACTIONS(2699),
    [anon_sym_SEMI] = ACTIONS(2699),
    [anon_sym_await] = ACTIONS(2701),
    [anon_sym_while] = ACTIONS(2701),
    [anon_sym_do] = ACTIONS(2701),
    [anon_sym_try] = ACTIONS(2701),
    [anon_sym_break] = ACTIONS(2701),
    [anon_sym_continue] = ACTIONS(2701),
    [anon_sym_debugger] = ACTIONS(2701),
    [anon_sym_return] = ACTIONS(2701),
    [anon_sym_throw] = ACTIONS(2701),
    [anon_sym_case] = ACTIONS(2701),
    [anon_sym_yield] = ACTIONS(2701),
    [anon_sym_LBRACK] = ACTIONS(2699),
    [anon_sym_class] = ACTIONS(2701),
    [anon_sym_async] = ACTIONS(2701),
    [anon_sym_function] = ACTIONS(2701),
    [anon_sym_new] = ACTIONS(2701),
    [anon_sym_using] = ACTIONS(2701),
    [anon_sym_PLUS] = ACTIONS(2701),
    [anon_sym_DASH] = ACTIONS(2701),
    [anon_sym_SLASH] = ACTIONS(2701),
    [anon_sym_LT] = ACTIONS(2699),
    [anon_sym_TILDE] = ACTIONS(2699),
    [anon_sym_void] = ACTIONS(2701),
    [anon_sym_delete] = ACTIONS(2701),
    [anon_sym_PLUS_PLUS] = ACTIONS(2699),
    [anon_sym_DASH_DASH] = ACTIONS(2699),
    [anon_sym_DQUOTE] = ACTIONS(2699),
    [anon_sym_SQUOTE] = ACTIONS(2699),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(2699),
    [sym_number] = ACTIONS(2699),
    [sym_private_property_identifier] = ACTIONS(2699),
    [sym_this] = ACTIONS(2701),
    [sym_super] = ACTIONS(2701),
    [sym_true] = ACTIONS(2701),
    [sym_false] = ACTIONS(2701),
    [sym_null] = ACTIONS(2701),
    [sym_undefined] = ACTIONS(2701),
    [anon_sym_AT] = ACTIONS(2699),
    [anon_sym_static] = ACTIONS(2701),
    [anon_sym_readonly] = ACTIONS(2701),
    [anon_sym_get] = ACTIONS(2701),
    [anon_sym_set] = ACTIONS(2701),
    [anon_sym_declare] = ACTIONS(2701),
    [anon_sym_public] = ACTIONS(2701),
    [anon_sym_private] = ACTIONS(2701),
    [anon_sym_protected] = ACTIONS(2701),
    [anon_sym_override] = ACTIONS(2701),
    [anon_sym_module] = ACTIONS(2701),
    [anon_sym_any] = ACTIONS(2701),
    [anon_sym_number] = ACTIONS(2701),
    [anon_sym_boolean] = ACTIONS(2701),
    [anon_sym_string] = ACTIONS(2701),
    [anon_sym_symbol] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2701),
    [anon_sym_abstract] = ACTIONS(2701),
    [anon_sym_interface] = ACTIONS(2701),
    [anon_sym_enum] = ACTIONS(2701),
    [sym_html_comment] = ACTIONS(5),
  },
  [858] = {
    [ts_builtin_sym_end] = ACTIONS(2703),
    [sym_identifier] = ACTIONS(2705),
    [anon_sym_export] = ACTIONS(2705),
    [anon_sym_default] = ACTIONS(2705),
    [anon_sym_type] = ACTIONS(2705),
    [anon_sym_namespace] = ACTIONS(2705),
    [anon_sym_LBRACE] = ACTIONS(2703),
    [anon_sym_RBRACE] = ACTIONS(2703),
    [anon_sym_typeof] = ACTIONS(2705),
    [anon_sym_import] = ACTIONS(2705),
    [anon_sym_with] = ACTIONS(2705),
    [anon_sym_var] = ACTIONS(2705),
    [anon_sym_let] = ACTIONS(2705),
    [anon_sym_const] = ACTIONS(2705),
    [anon_sym_BANG] = ACTIONS(2703),
    [anon_sym_else] = ACTIONS(2705),
    [anon_sym_if] = ACTIONS(2705),
    [anon_sym_switch] = ACTIONS(2705),
    [anon_sym_for] = ACTIONS(2705),
    [anon_sym_LPAREN] = ACTIONS(2703),
    [anon_sym_SEMI] = ACTIONS(2703),
    [anon_sym_await] = ACTIONS(2705),
    [anon_sym_while] = ACTIONS(2705),
    [anon_sym_do] = ACTIONS(2705),
    [anon_sym_try] = ACTIONS(2705),
    [anon_sym_break] = ACTIONS(2705),
    [anon_sym_continue] = ACTIONS(2705),
    [anon_sym_debugger] = ACTIONS(2705),
    [anon_sym_return] = ACTIONS(2705),
    [anon_sym_throw] = ACTIONS(2705),
    [anon_sym_case] = ACTIONS(2705),
    [anon_sym_yield] = ACTIONS(2705),
    [anon_sym_LBRACK] = ACTIONS(2703),
    [anon_sym_class] = ACTIONS(2705),
    [anon_sym_async] = ACTIONS(2705),
    [anon_sym_function] = ACTIONS(2705),
    [anon_sym_new] = ACTIONS(2705),
    [anon_sym_using] = ACTIONS(2705),
    [anon_sym_PLUS] = ACTIONS(2705),
    [anon_sym_DASH] = ACTIONS(2705),
    [anon_sym_SLASH] = ACTIONS(2705),
    [anon_sym_LT] = ACTIONS(2703),
    [anon_sym_TILDE] = ACTIONS(2703),
    [anon_sym_void] = ACTIONS(2705),
    [anon_sym_delete] = ACTIONS(2705),
    [anon_sym_PLUS_PLUS] = ACTIONS(2703),
    [anon_sym_DASH_DASH] = ACTIONS(2703),
    [anon_sym_DQUOTE] = ACTIONS(2703),
    [anon_sym_SQUOTE] = ACTIONS(2703),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(2703),
    [sym_number] = ACTIONS(2703),
    [sym_private_property_identifier] = ACTIONS(2703),
    [sym_this] = ACTIONS(2705),
    [sym_super] = ACTIONS(2705),
    [sym_true] = ACTIONS(2705),
    [sym_false] = ACTIONS(2705),
    [sym_null] = ACTIONS(2705),
    [sym_undefined] = ACTIONS(2705),
    [anon_sym_AT] = ACTIONS(2703),
    [anon_sym_static] = ACTIONS(2705),
    [anon_sym_readonly] = ACTIONS(2705),
    [anon_sym_get] = ACTIONS(2705),
    [anon_sym_set] = ACTIONS(2705),
    [anon_sym_declare] = ACTIONS(2705),
    [anon_sym_public] = ACTIONS(2705),
    [anon_sym_private] = ACTIONS(2705),
    [anon_sym_protected] = ACTIONS(2705),
    [anon_sym_override] = ACTIONS(2705),
    [anon_sym_module] = ACTIONS(2705),
    [anon_sym_any] = ACTIONS(2705),
    [anon_sym_number] = ACTIONS(2705),
    [anon_sym_boolean] = ACTIONS(2705),
    [anon_sym_string] = ACTIONS(2705),
    [anon_sym_symbol] = ACTIONS(2705),
    [anon_sym_object] = ACTIONS(2705),
    [anon_sym_abstract] = ACTIONS(2705),
    [anon_sym_interface] = ACTIONS(2705),
    [anon_sym_enum] = ACTIONS(2705),
    [sym_html_comment] = ACTIONS(5),
  },
  [859] = {
    [ts_builtin_sym_end] = ACTIONS(2707),
    [sym_identifier] = ACTIONS(2709),
    [anon_sym_export] = ACTIONS(2709),
    [anon_sym_default] = ACTIONS(2709),
    [anon_sym_type] = ACTIONS(2709),
    [anon_sym_namespace] = ACTIONS(2709),
    [anon_sym_LBRACE] = ACTIONS(2707),
    [anon_sym_RBRACE] = ACTIONS(2707),
    [anon_sym_typeof] = ACTIONS(2709),
    [anon_sym_import] = ACTIONS(2709),
    [anon_sym_with] = ACTIONS(2709),
    [anon_sym_var] = ACTIONS(2709),
    [anon_sym_let] = ACTIONS(2709),
    [anon_sym_const] = ACTIONS(2709),
    [anon_sym_BANG] = ACTIONS(2707),
    [anon_sym_else] = ACTIONS(2709),
    [anon_sym_if] = ACTIONS(2709),
    [anon_sym_switch] = ACTIONS(2709),
    [anon_sym_for] = ACTIONS(2709),
    [anon_sym_LPAREN] = ACTIONS(2707),
    [anon_sym_SEMI] = ACTIONS(2707),
    [anon_sym_await] = ACTIONS(2709),
    [anon_sym_while] = ACTIONS(2709),
    [anon_sym_do] = ACTIONS(2709),
    [anon_sym_try] = ACTIONS(2709),
    [anon_sym_break] = ACTIONS(2709),
    [anon_sym_continue] = ACTIONS(2709),
    [anon_sym_debugger] = ACTIONS(2709),
    [anon_sym_return] = ACTIONS(2709),
    [anon_sym_throw] = ACTIONS(2709),
    [anon_sym_case] = ACTIONS(2709),
    [anon_sym_yield] = ACTIONS(2709),
    [anon_sym_LBRACK] = ACTIONS(2707),
    [anon_sym_class] = ACTIONS(2709),
    [anon_sym_async] = ACTIONS(2709),
    [anon_sym_function] = ACTIONS(2709),
    [anon_sym_new] = ACTIONS(2709),
    [anon_sym_using] = ACTIONS(2709),
    [anon_sym_PLUS] = ACTIONS(2709),
    [anon_sym_DASH] = ACTIONS(2709),
    [anon_sym_SLASH] = ACTIONS(2709),
    [anon_sym_LT] = ACTIONS(2707),
    [anon_sym_TILDE] = ACTIONS(2707),
    [anon_sym_void] = ACTIONS(2709),
    [anon_sym_delete] = ACTIONS(2709),
    [anon_sym_PLUS_PLUS] = ACTIONS(2707),
    [anon_sym_DASH_DASH] = ACTIONS(2707),
    [anon_sym_DQUOTE] = ACTIONS(2707),
    [anon_sym_SQUOTE] = ACTIONS(2707),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(2707),
    [sym_number] = ACTIONS(2707),
    [sym_private_property_identifier] = ACTIONS(2707),
    [sym_this] = ACTIONS(2709),
    [sym_super] = ACTIONS(2709),
    [sym_true] = ACTIONS(2709),
    [sym_false] = ACTIONS(2709),
    [sym_null] = ACTIONS(2709),
    [sym_undefined] = ACTIONS(2709),
    [anon_sym_AT] = ACTIONS(2707),
    [anon_sym_static] = ACTIONS(2709),
    [anon_sym_readonly] = ACTIONS(2709),
    [anon_sym_get] = ACTIONS(2709),
    [anon_sym_set] = ACTIONS(2709),
    [anon_sym_declare] = ACTIONS(2709),
    [anon_sym_public] = ACTIONS(2709),
    [anon_sym_private] = ACTIONS(2709),
    [anon_sym_protected] = ACTIONS(2709),
    [anon_sym_override] = ACTIONS(2709),
    [anon_sym_module] = ACTIONS(2709),
    [anon_sym_any] = ACTIONS(2709),
    [anon_sym_number] = ACTIONS(2709),
    [anon_sym_boolean] = ACTIONS(2709),
    [anon_sym_string] = ACTIONS(2709),
    [anon_sym_symbol] = ACTIONS(2709),
    [anon_sym_object] = ACTIONS(2709),
    [anon_sym_abstract] = ACTIONS(2709),
    [anon_sym_interface] = ACTIONS(2709),
    [anon_sym_enum] = ACTIONS(2709),
    [sym_html_comment] = ACTIONS(5),
  },
  [860] = {
    [ts_builtin_sym_end] = ACTIONS(2711),
    [sym_identifier] = ACTIONS(2713),
    [anon_sym_export] = ACTIONS(2713),
    [anon_sym_default] = ACTIONS(2713),
    [anon_sym_type] = ACTIONS(2713),
    [anon_sym_namespace] = ACTIONS(2713),
    [anon_sym_LBRACE] = ACTIONS(2711),
    [anon_sym_RBRACE] = ACTIONS(2711),
    [anon_sym_typeof] = ACTIONS(2713),
    [anon_sym_import] = ACTIONS(2713),
    [anon_sym_with] = ACTIONS(2713),
    [anon_sym_var] = ACTIONS(2713),
    [anon_sym_let] = ACTIONS(2713),
    [anon_sym_const] = ACTIONS(2713),
    [anon_sym_BANG] = ACTIONS(2711),
    [anon_sym_else] = ACTIONS(2713),
    [anon_sym_if] = ACTIONS(2713),
    [anon_sym_switch] = ACTIONS(2713),
    [anon_sym_for] = ACTIONS(2713),
    [anon_sym_LPAREN] = ACTIONS(2711),
    [anon_sym_SEMI] = ACTIONS(2711),
    [anon_sym_await] = ACTIONS(2713),
    [anon_sym_while] = ACTIONS(2713),
    [anon_sym_do] = ACTIONS(2713),
    [anon_sym_try] = ACTIONS(2713),
    [anon_sym_break] = ACTIONS(2713),
    [anon_sym_continue] = ACTIONS(2713),
    [anon_sym_debugger] = ACTIONS(2713),
    [anon_sym_return] = ACTIONS(2713),
    [anon_sym_throw] = ACTIONS(2713),
    [anon_sym_case] = ACTIONS(2713),
    [anon_sym_yield] = ACTIONS(2713),
    [anon_sym_LBRACK] = ACTIONS(2711),
    [anon_sym_class] = ACTIONS(2713),
    [anon_sym_async] = ACTIONS(2713),
    [anon_sym_function] = ACTIONS(2713),
    [anon_sym_new] = ACTIONS(2713),
    [anon_sym_using] = ACTIONS(2713),
    [anon_sym_PLUS] = ACTIONS(2713),
    [anon_sym_DASH] = ACTIONS(2713),
    [anon_sym_SLASH] = ACTIONS(2713),
    [anon_sym_LT] = ACTIONS(2711),
    [anon_sym_TILDE] = ACTIONS(2711),
    [anon_sym_void] = ACTIONS(2713),
    [anon_sym_delete] = ACTIONS(2713),
    [anon_sym_PLUS_PLUS] = ACTIONS(2711),
    [anon_sym_DASH_DASH] = ACTIONS(2711),
    [anon_sym_DQUOTE] = ACTIONS(2711),
    [anon_sym_SQUOTE] = ACTIONS(2711),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(2711),
    [sym_number] = ACTIONS(2711),
    [sym_private_property_identifier] = ACTIONS(2711),
    [sym_this] = ACTIONS(2713),
    [sym_super] = ACTIONS(2713),
    [sym_true] = ACTIONS(2713),
    [sym_false] = ACTIONS(2713),
    [sym_null] = ACTIONS(2713),
    [sym_undefined] = ACTIONS(2713),
    [anon_sym_AT] = ACTIONS(2711),
    [anon_sym_static] = ACTIONS(2713),
    [anon_sym_readonly] = ACTIONS(2713),
    [anon_sym_get] = ACTIONS(2713),
    [anon_sym_set] = ACTIONS(2713),
    [anon_sym_declare] = ACTIONS(2713),
    [anon_sym_public] = ACTIONS(2713),
    [anon_sym_private] = ACTIONS(2713),
    [anon_sym_protected] = ACTIONS(2713),
    [anon_sym_override] = ACTIONS(2713),
    [anon_sym_module] = ACTIONS(2713),
    [anon_sym_any] = ACTIONS(2713),
    [anon_sym_number] = ACTIONS(2713),
    [anon_sym_boolean] = ACTIONS(2713),
    [anon_sym_string] = ACTIONS(2713),
    [anon_sym_symbol] = ACTIONS(2713),
    [anon_sym_object] = ACTIONS(2713),
    [anon_sym_abstract] = ACTIONS(2713),
    [anon_sym_interface] = ACTIONS(2713),
    [anon_sym_enum] = ACTIONS(2713),
    [sym_html_comment] = ACTIONS(5),
  },
  [861] = {
    [ts_builtin_sym_end] = ACTIONS(2715),
    [sym_identifier] = ACTIONS(2717),
    [anon_sym_export] = ACTIONS(2717),
    [anon_sym_default] = ACTIONS(2717),
    [anon_sym_type] = ACTIONS(2717),
    [anon_sym_namespace] = ACTIONS(2717),
    [anon_sym_LBRACE] = ACTIONS(2715),
    [anon_sym_RBRACE] = ACTIONS(2715),
    [anon_sym_typeof] = ACTIONS(2717),
    [anon_sym_import] = ACTIONS(2717),
    [anon_sym_with] = ACTIONS(2717),
    [anon_sym_var] = ACTIONS(2717),
    [anon_sym_let] = ACTIONS(2717),
    [anon_sym_const] = ACTIONS(2717),
    [anon_sym_BANG] = ACTIONS(2715),
    [anon_sym_else] = ACTIONS(2717),
    [anon_sym_if] = ACTIONS(2717),
    [anon_sym_switch] = ACTIONS(2717),
    [anon_sym_for] = ACTIONS(2717),
    [anon_sym_LPAREN] = ACTIONS(2715),
    [anon_sym_SEMI] = ACTIONS(2715),
    [anon_sym_await] = ACTIONS(2717),
    [anon_sym_while] = ACTIONS(2717),
    [anon_sym_do] = ACTIONS(2717),
    [anon_sym_try] = ACTIONS(2717),
    [anon_sym_break] = ACTIONS(2717),
    [anon_sym_continue] = ACTIONS(2717),
    [anon_sym_debugger] = ACTIONS(2717),
    [anon_sym_return] = ACTIONS(2717),
    [anon_sym_throw] = ACTIONS(2717),
    [anon_sym_case] = ACTIONS(2717),
    [anon_sym_yield] = ACTIONS(2717),
    [anon_sym_LBRACK] = ACTIONS(2715),
    [anon_sym_class] = ACTIONS(2717),
    [anon_sym_async] = ACTIONS(2717),
    [anon_sym_function] = ACTIONS(2717),
    [anon_sym_new] = ACTIONS(2717),
    [anon_sym_using] = ACTIONS(2717),
    [anon_sym_PLUS] = ACTIONS(2717),
    [anon_sym_DASH] = ACTIONS(2717),
    [anon_sym_SLASH] = ACTIONS(2717),
    [anon_sym_LT] = ACTIONS(2715),
    [anon_sym_TILDE] = ACTIONS(2715),
    [anon_sym_void] = ACTIONS(2717),
    [anon_sym_delete] = ACTIONS(2717),
    [anon_sym_PLUS_PLUS] = ACTIONS(2715),
    [anon_sym_DASH_DASH] = ACTIONS(2715),
    [anon_sym_DQUOTE] = ACTIONS(2715),
    [anon_sym_SQUOTE] = ACTIONS(2715),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(2715),
    [sym_number] = ACTIONS(2715),
    [sym_private_property_identifier] = ACTIONS(2715),
    [sym_this] = ACTIONS(2717),
    [sym_super] = ACTIONS(2717),
    [sym_true] = ACTIONS(2717),
    [sym_false] = ACTIONS(2717),
    [sym_null] = ACTIONS(2717),
    [sym_undefined] = ACTIONS(2717),
    [anon_sym_AT] = ACTIONS(2715),
    [anon_sym_static] = ACTIONS(2717),
    [anon_sym_readonly] = ACTIONS(2717),
    [anon_sym_get] = ACTIONS(2717),
    [anon_sym_set] = ACTIONS(2717),
    [anon_sym_declare] = ACTIONS(2717),
    [anon_sym_public] = ACTIONS(2717),
    [anon_sym_private] = ACTIONS(2717),
    [anon_sym_protected] = ACTIONS(2717),
    [anon_sym_override] = ACTIONS(2717),
    [anon_sym_module] = ACTIONS(2717),
    [anon_sym_any] = ACTIONS(2717),
    [anon_sym_number] = ACTIONS(2717),
    [anon_sym_boolean] = ACTIONS(2717),
    [anon_sym_string] = ACTIONS(2717),
    [anon_sym_symbol] = ACTIONS(2717),
    [anon_sym_object] = ACTIONS(2717),
    [anon_sym_abstract] = ACTIONS(2717),
    [anon_sym_interface] = ACTIONS(2717),
    [anon_sym_enum] = ACTIONS(2717),
    [sym_html_comment] = ACTIONS(5),
  },
  [862] = {
    [ts_builtin_sym_end] = ACTIONS(2719),
    [sym_identifier] = ACTIONS(2721),
    [anon_sym_export] = ACTIONS(2721),
    [anon_sym_default] = ACTIONS(2721),
    [anon_sym_type] = ACTIONS(2721),
    [anon_sym_namespace] = ACTIONS(2721),
    [anon_sym_LBRACE] = ACTIONS(2719),
    [anon_sym_RBRACE] = ACTIONS(2719),
    [anon_sym_typeof] = ACTIONS(2721),
    [anon_sym_import] = ACTIONS(2721),
    [anon_sym_with] = ACTIONS(2721),
    [anon_sym_var] = ACTIONS(2721),
    [anon_sym_let] = ACTIONS(2721),
    [anon_sym_const] = ACTIONS(2721),
    [anon_sym_BANG] = ACTIONS(2719),
    [anon_sym_else] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2721),
    [anon_sym_switch] = ACTIONS(2721),
    [anon_sym_for] = ACTIONS(2721),
    [anon_sym_LPAREN] = ACTIONS(2719),
    [anon_sym_SEMI] = ACTIONS(2719),
    [anon_sym_await] = ACTIONS(2721),
    [anon_sym_while] = ACTIONS(2721),
    [anon_sym_do] = ACTIONS(2721),
    [anon_sym_try] = ACTIONS(2721),
    [anon_sym_break] = ACTIONS(2721),
    [anon_sym_continue] = ACTIONS(2721),
    [anon_sym_debugger] = ACTIONS(2721),
    [anon_sym_return] = ACTIONS(2721),
    [anon_sym_throw] = ACTIONS(2721),
    [anon_sym_case] = ACTIONS(2721),
    [anon_sym_yield] = ACTIONS(2721),
    [anon_sym_LBRACK] = ACTIONS(2719),
    [anon_sym_class] = ACTIONS(2721),
    [anon_sym_async] = ACTIONS(2721),
    [anon_sym_function] = ACTIONS(2721),
    [anon_sym_new] = ACTIONS(2721),
    [anon_sym_using] = ACTIONS(2721),
    [anon_sym_PLUS] = ACTIONS(2721),
    [anon_sym_DASH] = ACTIONS(2721),
    [anon_sym_SLASH] = ACTIONS(2721),
    [anon_sym_LT] = ACTIONS(2719),
    [anon_sym_TILDE] = ACTIONS(2719),
    [anon_sym_void] = ACTIONS(2721),
    [anon_sym_delete] = ACTIONS(2721),
    [anon_sym_PLUS_PLUS] = ACTIONS(2719),
    [anon_sym_DASH_DASH] = ACTIONS(2719),
    [anon_sym_DQUOTE] = ACTIONS(2719),
    [anon_sym_SQUOTE] = ACTIONS(2719),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(2719),
    [sym_number] = ACTIONS(2719),
    [sym_private_property_identifier] = ACTIONS(2719),
    [sym_this] = ACTIONS(2721),
    [sym_super] = ACTIONS(2721),
    [sym_true] = ACTIONS(2721),
    [sym_false] = ACTIONS(2721),
    [sym_null] = ACTIONS(2721),
    [sym_undefined] = ACTIONS(2721),
    [anon_sym_AT] = ACTIONS(2719),
    [anon_sym_static] = ACTIONS(2721),
    [anon_sym_readonly] = ACTIONS(2721),
    [anon_sym_get] = ACTIONS(2721),
    [anon_sym_set] = ACTIONS(2721),
    [anon_sym_declare] = ACTIONS(2721),
    [anon_sym_public] = ACTIONS(2721),
    [anon_sym_private] = ACTIONS(2721),
    [anon_sym_protected] = ACTIONS(2721),
    [anon_sym_override] = ACTIONS(2721),
    [anon_sym_module] = ACTIONS(2721),
    [anon_sym_any] = ACTIONS(2721),
    [anon_sym_number] = ACTIONS(2721),
    [anon_sym_boolean] = ACTIONS(2721),
    [anon_sym_string] = ACTIONS(2721),
    [anon_sym_symbol] = ACTIONS(2721),
    [anon_sym_object] = ACTIONS(2721),
    [anon_sym_abstract] = ACTIONS(2721),
    [anon_sym_interface] = ACTIONS(2721),
    [anon_sym_enum] = ACTIONS(2721),
    [sym_html_comment] = ACTIONS(5),
  },
  [863] = {
    [ts_builtin_sym_end] = ACTIONS(2723),
    [sym_identifier] = ACTIONS(2725),
    [anon_sym_export] = ACTIONS(2725),
    [anon_sym_default] = ACTIONS(2725),
    [anon_sym_type] = ACTIONS(2725),
    [anon_sym_namespace] = ACTIONS(2725),
    [anon_sym_LBRACE] = ACTIONS(2723),
    [anon_sym_RBRACE] = ACTIONS(2723),
    [anon_sym_typeof] = ACTIONS(2725),
    [anon_sym_import] = ACTIONS(2725),
    [anon_sym_with] = ACTIONS(2725),
    [anon_sym_var] = ACTIONS(2725),
    [anon_sym_let] = ACTIONS(2725),
    [anon_sym_const] = ACTIONS(2725),
    [anon_sym_BANG] = ACTIONS(2723),
    [anon_sym_else] = ACTIONS(2725),
    [anon_sym_if] = ACTIONS(2725),
    [anon_sym_switch] = ACTIONS(2725),
    [anon_sym_for] = ACTIONS(2725),
    [anon_sym_LPAREN] = ACTIONS(2723),
    [anon_sym_SEMI] = ACTIONS(2723),
    [anon_sym_await] = ACTIONS(2725),
    [anon_sym_while] = ACTIONS(2725),
    [anon_sym_do] = ACTIONS(2725),
    [anon_sym_try] = ACTIONS(2725),
    [anon_sym_break] = ACTIONS(2725),
    [anon_sym_continue] = ACTIONS(2725),
    [anon_sym_debugger] = ACTIONS(2725),
    [anon_sym_return] = ACTIONS(2725),
    [anon_sym_throw] = ACTIONS(2725),
    [anon_sym_case] = ACTIONS(2725),
    [anon_sym_yield] = ACTIONS(2725),
    [anon_sym_LBRACK] = ACTIONS(2723),
    [anon_sym_class] = ACTIONS(2725),
    [anon_sym_async] = ACTIONS(2725),
    [anon_sym_function] = ACTIONS(2725),
    [anon_sym_new] = ACTIONS(2725),
    [anon_sym_using] = ACTIONS(2725),
    [anon_sym_PLUS] = ACTIONS(2725),
    [anon_sym_DASH] = ACTIONS(2725),
    [anon_sym_SLASH] = ACTIONS(2725),
    [anon_sym_LT] = ACTIONS(2723),
    [anon_sym_TILDE] = ACTIONS(2723),
    [anon_sym_void] = ACTIONS(2725),
    [anon_sym_delete] = ACTIONS(2725),
    [anon_sym_PLUS_PLUS] = ACTIONS(2723),
    [anon_sym_DASH_DASH] = ACTIONS(2723),
    [anon_sym_DQUOTE] = ACTIONS(2723),
    [anon_sym_SQUOTE] = ACTIONS(2723),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(2723),
    [sym_number] = ACTIONS(2723),
    [sym_private_property_identifier] = ACTIONS(2723),
    [sym_this] = ACTIONS(2725),
    [sym_super] = ACTIONS(2725),
    [sym_true] = ACTIONS(2725),
    [sym_false] = ACTIONS(2725),
    [sym_null] = ACTIONS(2725),
    [sym_undefined] = ACTIONS(2725),
    [anon_sym_AT] = ACTIONS(2723),
    [anon_sym_static] = ACTIONS(2725),
    [anon_sym_readonly] = ACTIONS(2725),
    [anon_sym_get] = ACTIONS(2725),
    [anon_sym_set] = ACTIONS(2725),
    [anon_sym_declare] = ACTIONS(2725),
    [anon_sym_public] = ACTIONS(2725),
    [anon_sym_private] = ACTIONS(2725),
    [anon_sym_protected] = ACTIONS(2725),
    [anon_sym_override] = ACTIONS(2725),
    [anon_sym_module] = ACTIONS(2725),
    [anon_sym_any] = ACTIONS(2725),
    [anon_sym_number] = ACTIONS(2725),
    [anon_sym_boolean] = ACTIONS(2725),
    [anon_sym_string] = ACTIONS(2725),
    [anon_sym_symbol] = ACTIONS(2725),
    [anon_sym_object] = ACTIONS(2725),
    [anon_sym_abstract] = ACTIONS(2725),
    [anon_sym_interface] = ACTIONS(2725),
    [anon_sym_enum] = ACTIONS(2725),
    [sym_html_comment] = ACTIONS(5),
  },
  [864] = {
    [ts_builtin_sym_end] = ACTIONS(2727),
    [sym_identifier] = ACTIONS(2729),
    [anon_sym_export] = ACTIONS(2729),
    [anon_sym_default] = ACTIONS(2729),
    [anon_sym_type] = ACTIONS(2729),
    [anon_sym_namespace] = ACTIONS(2729),
    [anon_sym_LBRACE] = ACTIONS(2727),
    [anon_sym_RBRACE] = ACTIONS(2727),
    [anon_sym_typeof] = ACTIONS(2729),
    [anon_sym_import] = ACTIONS(2729),
    [anon_sym_with] = ACTIONS(2729),
    [anon_sym_var] = ACTIONS(2729),
    [anon_sym_let] = ACTIONS(2729),
    [anon_sym_const] = ACTIONS(2729),
    [anon_sym_BANG] = ACTIONS(2727),
    [anon_sym_else] = ACTIONS(2729),
    [anon_sym_if] = ACTIONS(2729),
    [anon_sym_switch] = ACTIONS(2729),
    [anon_sym_for] = ACTIONS(2729),
    [anon_sym_LPAREN] = ACTIONS(2727),
    [anon_sym_SEMI] = ACTIONS(2727),
    [anon_sym_await] = ACTIONS(2729),
    [anon_sym_while] = ACTIONS(2729),
    [anon_sym_do] = ACTIONS(2729),
    [anon_sym_try] = ACTIONS(2729),
    [anon_sym_break] = ACTIONS(2729),
    [anon_sym_continue] = ACTIONS(2729),
    [anon_sym_debugger] = ACTIONS(2729),
    [anon_sym_return] = ACTIONS(2729),
    [anon_sym_throw] = ACTIONS(2729),
    [anon_sym_case] = ACTIONS(2729),
    [anon_sym_yield] = ACTIONS(2729),
    [anon_sym_LBRACK] = ACTIONS(2727),
    [anon_sym_class] = ACTIONS(2729),
    [anon_sym_async] = ACTIONS(2729),
    [anon_sym_function] = ACTIONS(2729),
    [anon_sym_new] = ACTIONS(2729),
    [anon_sym_using] = ACTIONS(2729),
    [anon_sym_PLUS] = ACTIONS(2729),
    [anon_sym_DASH] = ACTIONS(2729),
    [anon_sym_SLASH] = ACTIONS(2729),
    [anon_sym_LT] = ACTIONS(2727),
    [anon_sym_TILDE] = ACTIONS(2727),
    [anon_sym_void] = ACTIONS(2729),
    [anon_sym_delete] = ACTIONS(2729),
    [anon_sym_PLUS_PLUS] = ACTIONS(2727),
    [anon_sym_DASH_DASH] = ACTIONS(2727),
    [anon_sym_DQUOTE] = ACTIONS(2727),
    [anon_sym_SQUOTE] = ACTIONS(2727),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(2727),
    [sym_number] = ACTIONS(2727),
    [sym_private_property_identifier] = ACTIONS(2727),
    [sym_this] = ACTIONS(2729),
    [sym_super] = ACTIONS(2729),
    [sym_true] = ACTIONS(2729),
    [sym_false] = ACTIONS(2729),
    [sym_null] = ACTIONS(2729),
    [sym_undefined] = ACTIONS(2729),
    [anon_sym_AT] = ACTIONS(2727),
    [anon_sym_static] = ACTIONS(2729),
    [anon_sym_readonly] = ACTIONS(2729),
    [anon_sym_get] = ACTIONS(2729),
    [anon_sym_set] = ACTIONS(2729),
    [anon_sym_declare] = ACTIONS(2729),
    [anon_sym_public] = ACTIONS(2729),
    [anon_sym_private] = ACTIONS(2729),
    [anon_sym_protected] = ACTIONS(2729),
    [anon_sym_override] = ACTIONS(2729),
    [anon_sym_module] = ACTIONS(2729),
    [anon_sym_any] = ACTIONS(2729),
    [anon_sym_number] = ACTIONS(2729),
    [anon_sym_boolean] = ACTIONS(2729),
    [anon_sym_string] = ACTIONS(2729),
    [anon_sym_symbol] = ACTIONS(2729),
    [anon_sym_object] = ACTIONS(2729),
    [anon_sym_abstract] = ACTIONS(2729),
    [anon_sym_interface] = ACTIONS(2729),
    [anon_sym_enum] = ACTIONS(2729),
    [sym_html_comment] = ACTIONS(5),
  },
  [865] = {
    [ts_builtin_sym_end] = ACTIONS(1884),
    [sym_identifier] = ACTIONS(1886),
    [anon_sym_export] = ACTIONS(1886),
    [anon_sym_default] = ACTIONS(1886),
    [anon_sym_type] = ACTIONS(1886),
    [anon_sym_namespace] = ACTIONS(1886),
    [anon_sym_LBRACE] = ACTIONS(1884),
    [anon_sym_RBRACE] = ACTIONS(1884),
    [anon_sym_typeof] = ACTIONS(1886),
    [anon_sym_import] = ACTIONS(1886),
    [anon_sym_with] = ACTIONS(1886),
    [anon_sym_var] = ACTIONS(1886),
    [anon_sym_let] = ACTIONS(1886),
    [anon_sym_const] = ACTIONS(1886),
    [anon_sym_BANG] = ACTIONS(1884),
    [anon_sym_else] = ACTIONS(1886),
    [anon_sym_if] = ACTIONS(1886),
    [anon_sym_switch] = ACTIONS(1886),
    [anon_sym_for] = ACTIONS(1886),
    [anon_sym_LPAREN] = ACTIONS(1884),
    [anon_sym_SEMI] = ACTIONS(1884),
    [anon_sym_await] = ACTIONS(1886),
    [anon_sym_while] = ACTIONS(1886),
    [anon_sym_do] = ACTIONS(1886),
    [anon_sym_try] = ACTIONS(1886),
    [anon_sym_break] = ACTIONS(1886),
    [anon_sym_continue] = ACTIONS(1886),
    [anon_sym_debugger] = ACTIONS(1886),
    [anon_sym_return] = ACTIONS(1886),
    [anon_sym_throw] = ACTIONS(1886),
    [anon_sym_case] = ACTIONS(1886),
    [anon_sym_yield] = ACTIONS(1886),
    [anon_sym_LBRACK] = ACTIONS(1884),
    [anon_sym_class] = ACTIONS(1886),
    [anon_sym_async] = ACTIONS(1886),
    [anon_sym_function] = ACTIONS(1886),
    [anon_sym_new] = ACTIONS(1886),
    [anon_sym_using] = ACTIONS(1886),
    [anon_sym_PLUS] = ACTIONS(1886),
    [anon_sym_DASH] = ACTIONS(1886),
    [anon_sym_SLASH] = ACTIONS(1886),
    [anon_sym_LT] = ACTIONS(1884),
    [anon_sym_TILDE] = ACTIONS(1884),
    [anon_sym_void] = ACTIONS(1886),
    [anon_sym_delete] = ACTIONS(1886),
    [anon_sym_PLUS_PLUS] = ACTIONS(1884),
    [anon_sym_DASH_DASH] = ACTIONS(1884),
    [anon_sym_DQUOTE] = ACTIONS(1884),
    [anon_sym_SQUOTE] = ACTIONS(1884),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1884),
    [sym_number] = ACTIONS(1884),
    [sym_private_property_identifier] = ACTIONS(1884),
    [sym_this] = ACTIONS(1886),
    [sym_super] = ACTIONS(1886),
    [sym_true] = ACTIONS(1886),
    [sym_false] = ACTIONS(1886),
    [sym_null] = ACTIONS(1886),
    [sym_undefined] = ACTIONS(1886),
    [anon_sym_AT] = ACTIONS(1884),
    [anon_sym_static] = ACTIONS(1886),
    [anon_sym_readonly] = ACTIONS(1886),
    [anon_sym_get] = ACTIONS(1886),
    [anon_sym_set] = ACTIONS(1886),
    [anon_sym_declare] = ACTIONS(1886),
    [anon_sym_public] = ACTIONS(1886),
    [anon_sym_private] = ACTIONS(1886),
    [anon_sym_protected] = ACTIONS(1886),
    [anon_sym_override] = ACTIONS(1886),
    [anon_sym_module] = ACTIONS(1886),
    [anon_sym_any] = ACTIONS(1886),
    [anon_sym_number] = ACTIONS(1886),
    [anon_sym_boolean] = ACTIONS(1886),
    [anon_sym_string] = ACTIONS(1886),
    [anon_sym_symbol] = ACTIONS(1886),
    [anon_sym_object] = ACTIONS(1886),
    [anon_sym_abstract] = ACTIONS(1886),
    [anon_sym_interface] = ACTIONS(1886),
    [anon_sym_enum] = ACTIONS(1886),
    [sym_html_comment] = ACTIONS(5),
  },
  [866] = {
    [ts_builtin_sym_end] = ACTIONS(2699),
    [sym_identifier] = ACTIONS(2701),
    [anon_sym_export] = ACTIONS(2701),
    [anon_sym_default] = ACTIONS(2701),
    [anon_sym_type] = ACTIONS(2701),
    [anon_sym_namespace] = ACTIONS(2701),
    [anon_sym_LBRACE] = ACTIONS(2699),
    [anon_sym_RBRACE] = ACTIONS(2699),
    [anon_sym_typeof] = ACTIONS(2701),
    [anon_sym_import] = ACTIONS(2701),
    [anon_sym_with] = ACTIONS(2701),
    [anon_sym_var] = ACTIONS(2701),
    [anon_sym_let] = ACTIONS(2701),
    [anon_sym_const] = ACTIONS(2701),
    [anon_sym_BANG] = ACTIONS(2699),
    [anon_sym_else] = ACTIONS(2701),
    [anon_sym_if] = ACTIONS(2701),
    [anon_sym_switch] = ACTIONS(2701),
    [anon_sym_for] = ACTIONS(2701),
    [anon_sym_LPAREN] = ACTIONS(2699),
    [anon_sym_SEMI] = ACTIONS(2699),
    [anon_sym_await] = ACTIONS(2701),
    [anon_sym_while] = ACTIONS(2701),
    [anon_sym_do] = ACTIONS(2701),
    [anon_sym_try] = ACTIONS(2701),
    [anon_sym_break] = ACTIONS(2701),
    [anon_sym_continue] = ACTIONS(2701),
    [anon_sym_debugger] = ACTIONS(2701),
    [anon_sym_return] = ACTIONS(2701),
    [anon_sym_throw] = ACTIONS(2701),
    [anon_sym_case] = ACTIONS(2701),
    [anon_sym_yield] = ACTIONS(2701),
    [anon_sym_LBRACK] = ACTIONS(2699),
    [anon_sym_class] = ACTIONS(2701),
    [anon_sym_async] = ACTIONS(2701),
    [anon_sym_function] = ACTIONS(2701),
    [anon_sym_new] = ACTIONS(2701),
    [anon_sym_using] = ACTIONS(2701),
    [anon_sym_PLUS] = ACTIONS(2701),
    [anon_sym_DASH] = ACTIONS(2701),
    [anon_sym_SLASH] = ACTIONS(2701),
    [anon_sym_LT] = ACTIONS(2699),
    [anon_sym_TILDE] = ACTIONS(2699),
    [anon_sym_void] = ACTIONS(2701),
    [anon_sym_delete] = ACTIONS(2701),
    [anon_sym_PLUS_PLUS] = ACTIONS(2699),
    [anon_sym_DASH_DASH] = ACTIONS(2699),
    [anon_sym_DQUOTE] = ACTIONS(2699),
    [anon_sym_SQUOTE] = ACTIONS(2699),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(2699),
    [sym_number] = ACTIONS(2699),
    [sym_private_property_identifier] = ACTIONS(2699),
    [sym_this] = ACTIONS(2701),
    [sym_super] = ACTIONS(2701),
    [sym_true] = ACTIONS(2701),
    [sym_false] = ACTIONS(2701),
    [sym_null] = ACTIONS(2701),
    [sym_undefined] = ACTIONS(2701),
    [anon_sym_AT] = ACTIONS(2699),
    [anon_sym_static] = ACTIONS(2701),
    [anon_sym_readonly] = ACTIONS(2701),
    [anon_sym_get] = ACTIONS(2701),
    [anon_sym_set] = ACTIONS(2701),
    [anon_sym_declare] = ACTIONS(2701),
    [anon_sym_public] = ACTIONS(2701),
    [anon_sym_private] = ACTIONS(2701),
    [anon_sym_protected] = ACTIONS(2701),
    [anon_sym_override] = ACTIONS(2701),
    [anon_sym_module] = ACTIONS(2701),
    [anon_sym_any] = ACTIONS(2701),
    [anon_sym_number] = ACTIONS(2701),
    [anon_sym_boolean] = ACTIONS(2701),
    [anon_sym_string] = ACTIONS(2701),
    [anon_sym_symbol] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2701),
    [anon_sym_abstract] = ACTIONS(2701),
    [anon_sym_interface] = ACTIONS(2701),
    [anon_sym_enum] = ACTIONS(2701),
    [sym_html_comment] = ACTIONS(5),
  },
  [867] = {
    [ts_builtin_sym_end] = ACTIONS(2731),
    [sym_identifier] = ACTIONS(2733),
    [anon_sym_export] = ACTIONS(2733),
    [anon_sym_default] = ACTIONS(2733),
    [anon_sym_type] = ACTIONS(2733),
    [anon_sym_namespace] = ACTIONS(2733),
    [anon_sym_LBRACE] = ACTIONS(2731),
    [anon_sym_RBRACE] = ACTIONS(2731),
    [anon_sym_typeof] = ACTIONS(2733),
    [anon_sym_import] = ACTIONS(2733),
    [anon_sym_with] = ACTIONS(2733),
    [anon_sym_var] = ACTIONS(2733),
    [anon_sym_let] = ACTIONS(2733),
    [anon_sym_const] = ACTIONS(2733),
    [anon_sym_BANG] = ACTIONS(2731),
    [anon_sym_else] = ACTIONS(2733),
    [anon_sym_if] = ACTIONS(2733),
    [anon_sym_switch] = ACTIONS(2733),
    [anon_sym_for] = ACTIONS(2733),
    [anon_sym_LPAREN] = ACTIONS(2731),
    [anon_sym_SEMI] = ACTIONS(2731),
    [anon_sym_await] = ACTIONS(2733),
    [anon_sym_while] = ACTIONS(2733),
    [anon_sym_do] = ACTIONS(2733),
    [anon_sym_try] = ACTIONS(2733),
    [anon_sym_break] = ACTIONS(2733),
    [anon_sym_continue] = ACTIONS(2733),
    [anon_sym_debugger] = ACTIONS(2733),
    [anon_sym_return] = ACTIONS(2733),
    [anon_sym_throw] = ACTIONS(2733),
    [anon_sym_case] = ACTIONS(2733),
    [anon_sym_yield] = ACTIONS(2733),
    [anon_sym_LBRACK] = ACTIONS(2731),
    [anon_sym_class] = ACTIONS(2733),
    [anon_sym_async] = ACTIONS(2733),
    [anon_sym_function] = ACTIONS(2733),
    [anon_sym_new] = ACTIONS(2733),
    [anon_sym_using] = ACTIONS(2733),
    [anon_sym_PLUS] = ACTIONS(2733),
    [anon_sym_DASH] = ACTIONS(2733),
    [anon_sym_SLASH] = ACTIONS(2733),
    [anon_sym_LT] = ACTIONS(2731),
    [anon_sym_TILDE] = ACTIONS(2731),
    [anon_sym_void] = ACTIONS(2733),
    [anon_sym_delete] = ACTIONS(2733),
    [anon_sym_PLUS_PLUS] = ACTIONS(2731),
    [anon_sym_DASH_DASH] = ACTIONS(2731),
    [anon_sym_DQUOTE] = ACTIONS(2731),
    [anon_sym_SQUOTE] = ACTIONS(2731),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(2731),
    [sym_number] = ACTIONS(2731),
    [sym_private_property_identifier] = ACTIONS(2731),
    [sym_this] = ACTIONS(2733),
    [sym_super] = ACTIONS(2733),
    [sym_true] = ACTIONS(2733),
    [sym_false] = ACTIONS(2733),
    [sym_null] = ACTIONS(2733),
    [sym_undefined] = ACTIONS(2733),
    [anon_sym_AT] = ACTIONS(2731),
    [anon_sym_static] = ACTIONS(2733),
    [anon_sym_readonly] = ACTIONS(2733),
    [anon_sym_get] = ACTIONS(2733),
    [anon_sym_set] = ACTIONS(2733),
    [anon_sym_declare] = ACTIONS(2733),
    [anon_sym_public] = ACTIONS(2733),
    [anon_sym_private] = ACTIONS(2733),
    [anon_sym_protected] = ACTIONS(2733),
    [anon_sym_override] = ACTIONS(2733),
    [anon_sym_module] = ACTIONS(2733),
    [anon_sym_any] = ACTIONS(2733),
    [anon_sym_number] = ACTIONS(2733),
    [anon_sym_boolean] = ACTIONS(2733),
    [anon_sym_string] = ACTIONS(2733),
    [anon_sym_symbol] = ACTIONS(2733),
    [anon_sym_object] = ACTIONS(2733),
    [anon_sym_abstract] = ACTIONS(2733),
    [anon_sym_interface] = ACTIONS(2733),
    [anon_sym_enum] = ACTIONS(2733),
    [sym_html_comment] = ACTIONS(5),
  },
  [868] = {
    [sym_import] = STATE(4681),
    [sym_nested_identifier] = STATE(5474),
    [sym_string] = STATE(2994),
    [sym_formal_parameters] = STATE(5619),
    [sym_rest_pattern] = STATE(5165),
    [sym_nested_type_identifier] = STATE(2939),
    [sym__type_query_member_expression_in_type_annotation] = STATE(3303),
    [sym__type_query_call_expression_in_type_annotation] = STATE(2938),
    [sym_type] = STATE(3773),
    [sym_tuple_parameter] = STATE(5278),
    [sym_optional_tuple_parameter] = STATE(5278),
    [sym_optional_type] = STATE(5278),
    [sym_rest_type] = STATE(5278),
    [sym__tuple_type_member] = STATE(5278),
    [sym_constructor_type] = STATE(3007),
    [sym_primary_type] = STATE(2981),
    [sym_template_literal_type] = STATE(3039),
    [sym_infer_type] = STATE(3007),
    [sym_conditional_type] = STATE(3039),
    [sym_generic_type] = STATE(3039),
    [sym_type_query] = STATE(3039),
    [sym_index_type_query] = STATE(3039),
    [sym_lookup_type] = STATE(3039),
    [sym_literal_type] = STATE(3039),
    [sym__number] = STATE(3041),
    [sym_existential_type] = STATE(3039),
    [sym_flow_maybe_type] = STATE(3039),
    [sym_parenthesized_type] = STATE(3039),
    [sym_predefined_type] = STATE(3039),
    [sym_object_type] = STATE(3039),
    [sym_type_parameters] = STATE(5454),
    [sym_array_type] = STATE(3039),
    [sym_tuple_type] = STATE(3039),
    [sym_readonly_type] = STATE(3007),
    [sym_union_type] = STATE(3039),
    [sym_intersection_type] = STATE(3039),
    [sym_function_type] = STATE(3007),
    [sym_identifier] = ACTIONS(2489),
    [anon_sym_STAR] = ACTIONS(543),
    [anon_sym_LBRACE] = ACTIONS(1534),
    [anon_sym_typeof] = ACTIONS(1536),
    [anon_sym_import] = ACTIONS(1538),
    [anon_sym_const] = ACTIONS(133),
    [anon_sym_LPAREN] = ACTIONS(1540),
    [anon_sym_LBRACK] = ACTIONS(1542),
    [anon_sym_RBRACK] = ACTIONS(2735),
    [anon_sym_new] = ACTIONS(1642),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(2495),
    [anon_sym_AMP] = ACTIONS(571),
    [anon_sym_PIPE] = ACTIONS(573),
    [anon_sym_PLUS] = ACTIONS(2497),
    [anon_sym_DASH] = ACTIONS(2497),
    [anon_sym_LT] = ACTIONS(2499),
    [anon_sym_void] = ACTIONS(216),
    [anon_sym_DQUOTE] = ACTIONS(1550),
    [anon_sym_SQUOTE] = ACTIONS(1552),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1554),
    [sym_number] = ACTIONS(1556),
    [sym_this] = ACTIONS(1558),
    [sym_true] = ACTIONS(1560),
    [sym_false] = ACTIONS(1560),
    [sym_null] = ACTIONS(1560),
    [sym_undefined] = ACTIONS(1560),
    [anon_sym_readonly] = ACTIONS(1648),
    [anon_sym_QMARK] = ACTIONS(593),
    [anon_sym_any] = ACTIONS(216),
    [anon_sym_number] = ACTIONS(216),
    [anon_sym_boolean] = ACTIONS(216),
    [anon_sym_string] = ACTIONS(216),
    [anon_sym_symbol] = ACTIONS(216),
    [anon_sym_object] = ACTIONS(216),
    [anon_sym_abstract] = ACTIONS(597),
    [anon_sym_infer] = ACTIONS(599),
    [anon_sym_keyof] = ACTIONS(601),
    [anon_sym_unique] = ACTIONS(214),
    [anon_sym_unknown] = ACTIONS(216),
    [anon_sym_never] = ACTIONS(216),
    [anon_sym_LBRACE_PIPE] = ACTIONS(218),
    [sym_html_comment] = ACTIONS(5),
  },
  [869] = {
    [ts_builtin_sym_end] = ACTIONS(2737),
    [sym_identifier] = ACTIONS(2739),
    [anon_sym_export] = ACTIONS(2739),
    [anon_sym_default] = ACTIONS(2739),
    [anon_sym_type] = ACTIONS(2739),
    [anon_sym_namespace] = ACTIONS(2739),
    [anon_sym_LBRACE] = ACTIONS(2737),
    [anon_sym_RBRACE] = ACTIONS(2737),
    [anon_sym_typeof] = ACTIONS(2739),
    [anon_sym_import] = ACTIONS(2739),
    [anon_sym_with] = ACTIONS(2739),
    [anon_sym_var] = ACTIONS(2739),
    [anon_sym_let] = ACTIONS(2739),
    [anon_sym_const] = ACTIONS(2739),
    [anon_sym_BANG] = ACTIONS(2737),
    [anon_sym_else] = ACTIONS(2739),
    [anon_sym_if] = ACTIONS(2739),
    [anon_sym_switch] = ACTIONS(2739),
    [anon_sym_for] = ACTIONS(2739),
    [anon_sym_LPAREN] = ACTIONS(2737),
    [anon_sym_SEMI] = ACTIONS(2737),
    [anon_sym_await] = ACTIONS(2739),
    [anon_sym_while] = ACTIONS(2739),
    [anon_sym_do] = ACTIONS(2739),
    [anon_sym_try] = ACTIONS(2739),
    [anon_sym_break] = ACTIONS(2739),
    [anon_sym_continue] = ACTIONS(2739),
    [anon_sym_debugger] = ACTIONS(2739),
    [anon_sym_return] = ACTIONS(2739),
    [anon_sym_throw] = ACTIONS(2739),
    [anon_sym_case] = ACTIONS(2739),
    [anon_sym_yield] = ACTIONS(2739),
    [anon_sym_LBRACK] = ACTIONS(2737),
    [anon_sym_class] = ACTIONS(2739),
    [anon_sym_async] = ACTIONS(2739),
    [anon_sym_function] = ACTIONS(2739),
    [anon_sym_new] = ACTIONS(2739),
    [anon_sym_using] = ACTIONS(2739),
    [anon_sym_PLUS] = ACTIONS(2739),
    [anon_sym_DASH] = ACTIONS(2739),
    [anon_sym_SLASH] = ACTIONS(2739),
    [anon_sym_LT] = ACTIONS(2737),
    [anon_sym_TILDE] = ACTIONS(2737),
    [anon_sym_void] = ACTIONS(2739),
    [anon_sym_delete] = ACTIONS(2739),
    [anon_sym_PLUS_PLUS] = ACTIONS(2737),
    [anon_sym_DASH_DASH] = ACTIONS(2737),
    [anon_sym_DQUOTE] = ACTIONS(2737),
    [anon_sym_SQUOTE] = ACTIONS(2737),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(2737),
    [sym_number] = ACTIONS(2737),
    [sym_private_property_identifier] = ACTIONS(2737),
    [sym_this] = ACTIONS(2739),
    [sym_super] = ACTIONS(2739),
    [sym_true] = ACTIONS(2739),
    [sym_false] = ACTIONS(2739),
    [sym_null] = ACTIONS(2739),
    [sym_undefined] = ACTIONS(2739),
    [anon_sym_AT] = ACTIONS(2737),
    [anon_sym_static] = ACTIONS(2739),
    [anon_sym_readonly] = ACTIONS(2739),
    [anon_sym_get] = ACTIONS(2739),
    [anon_sym_set] = ACTIONS(2739),
    [anon_sym_declare] = ACTIONS(2739),
    [anon_sym_public] = ACTIONS(2739),
    [anon_sym_private] = ACTIONS(2739),
    [anon_sym_protected] = ACTIONS(2739),
    [anon_sym_override] = ACTIONS(2739),
    [anon_sym_module] = ACTIONS(2739),
    [anon_sym_any] = ACTIONS(2739),
    [anon_sym_number] = ACTIONS(2739),
    [anon_sym_boolean] = ACTIONS(2739),
    [anon_sym_string] = ACTIONS(2739),
    [anon_sym_symbol] = ACTIONS(2739),
    [anon_sym_object] = ACTIONS(2739),
    [anon_sym_abstract] = ACTIONS(2739),
    [anon_sym_interface] = ACTIONS(2739),
    [anon_sym_enum] = ACTIONS(2739),
    [sym_html_comment] = ACTIONS(5),
  },
  [870] = {
    [ts_builtin_sym_end] = ACTIONS(2741),
    [sym_identifier] = ACTIONS(2743),
    [anon_sym_export] = ACTIONS(2743),
    [anon_sym_default] = ACTIONS(2743),
    [anon_sym_type] = ACTIONS(2743),
    [anon_sym_namespace] = ACTIONS(2743),
    [anon_sym_LBRACE] = ACTIONS(2741),
    [anon_sym_RBRACE] = ACTIONS(2741),
    [anon_sym_typeof] = ACTIONS(2743),
    [anon_sym_import] = ACTIONS(2743),
    [anon_sym_with] = ACTIONS(2743),
    [anon_sym_var] = ACTIONS(2743),
    [anon_sym_let] = ACTIONS(2743),
    [anon_sym_const] = ACTIONS(2743),
    [anon_sym_BANG] = ACTIONS(2741),
    [anon_sym_else] = ACTIONS(2743),
    [anon_sym_if] = ACTIONS(2743),
    [anon_sym_switch] = ACTIONS(2743),
    [anon_sym_for] = ACTIONS(2743),
    [anon_sym_LPAREN] = ACTIONS(2741),
    [anon_sym_SEMI] = ACTIONS(2741),
    [anon_sym_await] = ACTIONS(2743),
    [anon_sym_while] = ACTIONS(2743),
    [anon_sym_do] = ACTIONS(2743),
    [anon_sym_try] = ACTIONS(2743),
    [anon_sym_break] = ACTIONS(2743),
    [anon_sym_continue] = ACTIONS(2743),
    [anon_sym_debugger] = ACTIONS(2743),
    [anon_sym_return] = ACTIONS(2743),
    [anon_sym_throw] = ACTIONS(2743),
    [anon_sym_case] = ACTIONS(2743),
    [anon_sym_yield] = ACTIONS(2743),
    [anon_sym_LBRACK] = ACTIONS(2741),
    [anon_sym_class] = ACTIONS(2743),
    [anon_sym_async] = ACTIONS(2743),
    [anon_sym_function] = ACTIONS(2743),
    [anon_sym_new] = ACTIONS(2743),
    [anon_sym_using] = ACTIONS(2743),
    [anon_sym_PLUS] = ACTIONS(2743),
    [anon_sym_DASH] = ACTIONS(2743),
    [anon_sym_SLASH] = ACTIONS(2743),
    [anon_sym_LT] = ACTIONS(2741),
    [anon_sym_TILDE] = ACTIONS(2741),
    [anon_sym_void] = ACTIONS(2743),
    [anon_sym_delete] = ACTIONS(2743),
    [anon_sym_PLUS_PLUS] = ACTIONS(2741),
    [anon_sym_DASH_DASH] = ACTIONS(2741),
    [anon_sym_DQUOTE] = ACTIONS(2741),
    [anon_sym_SQUOTE] = ACTIONS(2741),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(2741),
    [sym_number] = ACTIONS(2741),
    [sym_private_property_identifier] = ACTIONS(2741),
    [sym_this] = ACTIONS(2743),
    [sym_super] = ACTIONS(2743),
    [sym_true] = ACTIONS(2743),
    [sym_false] = ACTIONS(2743),
    [sym_null] = ACTIONS(2743),
    [sym_undefined] = ACTIONS(2743),
    [anon_sym_AT] = ACTIONS(2741),
    [anon_sym_static] = ACTIONS(2743),
    [anon_sym_readonly] = ACTIONS(2743),
    [anon_sym_get] = ACTIONS(2743),
    [anon_sym_set] = ACTIONS(2743),
    [anon_sym_declare] = ACTIONS(2743),
    [anon_sym_public] = ACTIONS(2743),
    [anon_sym_private] = ACTIONS(2743),
    [anon_sym_protected] = ACTIONS(2743),
    [anon_sym_override] = ACTIONS(2743),
    [anon_sym_module] = ACTIONS(2743),
    [anon_sym_any] = ACTIONS(2743),
    [anon_sym_number] = ACTIONS(2743),
    [anon_sym_boolean] = ACTIONS(2743),
    [anon_sym_string] = ACTIONS(2743),
    [anon_sym_symbol] = ACTIONS(2743),
    [anon_sym_object] = ACTIONS(2743),
    [anon_sym_abstract] = ACTIONS(2743),
    [anon_sym_interface] = ACTIONS(2743),
    [anon_sym_enum] = ACTIONS(2743),
    [sym_html_comment] = ACTIONS(5),
  },
  [871] = {
    [ts_builtin_sym_end] = ACTIONS(2745),
    [sym_identifier] = ACTIONS(2747),
    [anon_sym_export] = ACTIONS(2747),
    [anon_sym_default] = ACTIONS(2747),
    [anon_sym_type] = ACTIONS(2747),
    [anon_sym_namespace] = ACTIONS(2747),
    [anon_sym_LBRACE] = ACTIONS(2745),
    [anon_sym_RBRACE] = ACTIONS(2745),
    [anon_sym_typeof] = ACTIONS(2747),
    [anon_sym_import] = ACTIONS(2747),
    [anon_sym_with] = ACTIONS(2747),
    [anon_sym_var] = ACTIONS(2747),
    [anon_sym_let] = ACTIONS(2747),
    [anon_sym_const] = ACTIONS(2747),
    [anon_sym_BANG] = ACTIONS(2745),
    [anon_sym_else] = ACTIONS(2747),
    [anon_sym_if] = ACTIONS(2747),
    [anon_sym_switch] = ACTIONS(2747),
    [anon_sym_for] = ACTIONS(2747),
    [anon_sym_LPAREN] = ACTIONS(2745),
    [anon_sym_SEMI] = ACTIONS(2745),
    [anon_sym_await] = ACTIONS(2747),
    [anon_sym_while] = ACTIONS(2747),
    [anon_sym_do] = ACTIONS(2747),
    [anon_sym_try] = ACTIONS(2747),
    [anon_sym_break] = ACTIONS(2747),
    [anon_sym_continue] = ACTIONS(2747),
    [anon_sym_debugger] = ACTIONS(2747),
    [anon_sym_return] = ACTIONS(2747),
    [anon_sym_throw] = ACTIONS(2747),
    [anon_sym_case] = ACTIONS(2747),
    [anon_sym_yield] = ACTIONS(2747),
    [anon_sym_LBRACK] = ACTIONS(2745),
    [anon_sym_class] = ACTIONS(2747),
    [anon_sym_async] = ACTIONS(2747),
    [anon_sym_function] = ACTIONS(2747),
    [anon_sym_new] = ACTIONS(2747),
    [anon_sym_using] = ACTIONS(2747),
    [anon_sym_PLUS] = ACTIONS(2747),
    [anon_sym_DASH] = ACTIONS(2747),
    [anon_sym_SLASH] = ACTIONS(2747),
    [anon_sym_LT] = ACTIONS(2745),
    [anon_sym_TILDE] = ACTIONS(2745),
    [anon_sym_void] = ACTIONS(2747),
    [anon_sym_delete] = ACTIONS(2747),
    [anon_sym_PLUS_PLUS] = ACTIONS(2745),
    [anon_sym_DASH_DASH] = ACTIONS(2745),
    [anon_sym_DQUOTE] = ACTIONS(2745),
    [anon_sym_SQUOTE] = ACTIONS(2745),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(2745),
    [sym_number] = ACTIONS(2745),
    [sym_private_property_identifier] = ACTIONS(2745),
    [sym_this] = ACTIONS(2747),
    [sym_super] = ACTIONS(2747),
    [sym_true] = ACTIONS(2747),
    [sym_false] = ACTIONS(2747),
    [sym_null] = ACTIONS(2747),
    [sym_undefined] = ACTIONS(2747),
    [anon_sym_AT] = ACTIONS(2745),
    [anon_sym_static] = ACTIONS(2747),
    [anon_sym_readonly] = ACTIONS(2747),
    [anon_sym_get] = ACTIONS(2747),
    [anon_sym_set] = ACTIONS(2747),
    [anon_sym_declare] = ACTIONS(2747),
    [anon_sym_public] = ACTIONS(2747),
    [anon_sym_private] = ACTIONS(2747),
    [anon_sym_protected] = ACTIONS(2747),
    [anon_sym_override] = ACTIONS(2747),
    [anon_sym_module] = ACTIONS(2747),
    [anon_sym_any] = ACTIONS(2747),
    [anon_sym_number] = ACTIONS(2747),
    [anon_sym_boolean] = ACTIONS(2747),
    [anon_sym_string] = ACTIONS(2747),
    [anon_sym_symbol] = ACTIONS(2747),
    [anon_sym_object] = ACTIONS(2747),
    [anon_sym_abstract] = ACTIONS(2747),
    [anon_sym_interface] = ACTIONS(2747),
    [anon_sym_enum] = ACTIONS(2747),
    [sym_html_comment] = ACTIONS(5),
  },
  [872] = {
    [ts_builtin_sym_end] = ACTIONS(1720),
    [sym_identifier] = ACTIONS(1722),
    [anon_sym_export] = ACTIONS(1722),
    [anon_sym_default] = ACTIONS(1722),
    [anon_sym_type] = ACTIONS(1722),
    [anon_sym_namespace] = ACTIONS(1722),
    [anon_sym_LBRACE] = ACTIONS(1720),
    [anon_sym_RBRACE] = ACTIONS(1720),
    [anon_sym_typeof] = ACTIONS(1722),
    [anon_sym_import] = ACTIONS(1722),
    [anon_sym_with] = ACTIONS(1722),
    [anon_sym_var] = ACTIONS(1722),
    [anon_sym_let] = ACTIONS(1722),
    [anon_sym_const] = ACTIONS(1722),
    [anon_sym_BANG] = ACTIONS(1720),
    [anon_sym_else] = ACTIONS(1722),
    [anon_sym_if] = ACTIONS(1722),
    [anon_sym_switch] = ACTIONS(1722),
    [anon_sym_for] = ACTIONS(1722),
    [anon_sym_LPAREN] = ACTIONS(1720),
    [anon_sym_SEMI] = ACTIONS(1720),
    [anon_sym_await] = ACTIONS(1722),
    [anon_sym_while] = ACTIONS(1722),
    [anon_sym_do] = ACTIONS(1722),
    [anon_sym_try] = ACTIONS(1722),
    [anon_sym_break] = ACTIONS(1722),
    [anon_sym_continue] = ACTIONS(1722),
    [anon_sym_debugger] = ACTIONS(1722),
    [anon_sym_return] = ACTIONS(1722),
    [anon_sym_throw] = ACTIONS(1722),
    [anon_sym_case] = ACTIONS(1722),
    [anon_sym_yield] = ACTIONS(1722),
    [anon_sym_LBRACK] = ACTIONS(1720),
    [anon_sym_class] = ACTIONS(1722),
    [anon_sym_async] = ACTIONS(1722),
    [anon_sym_function] = ACTIONS(1722),
    [anon_sym_new] = ACTIONS(1722),
    [anon_sym_using] = ACTIONS(1722),
    [anon_sym_PLUS] = ACTIONS(1722),
    [anon_sym_DASH] = ACTIONS(1722),
    [anon_sym_SLASH] = ACTIONS(1722),
    [anon_sym_LT] = ACTIONS(1720),
    [anon_sym_TILDE] = ACTIONS(1720),
    [anon_sym_void] = ACTIONS(1722),
    [anon_sym_delete] = ACTIONS(1722),
    [anon_sym_PLUS_PLUS] = ACTIONS(1720),
    [anon_sym_DASH_DASH] = ACTIONS(1720),
    [anon_sym_DQUOTE] = ACTIONS(1720),
    [anon_sym_SQUOTE] = ACTIONS(1720),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1720),
    [sym_number] = ACTIONS(1720),
    [sym_private_property_identifier] = ACTIONS(1720),
    [sym_this] = ACTIONS(1722),
    [sym_super] = ACTIONS(1722),
    [sym_true] = ACTIONS(1722),
    [sym_false] = ACTIONS(1722),
    [sym_null] = ACTIONS(1722),
    [sym_undefined] = ACTIONS(1722),
    [anon_sym_AT] = ACTIONS(1720),
    [anon_sym_static] = ACTIONS(1722),
    [anon_sym_readonly] = ACTIONS(1722),
    [anon_sym_get] = ACTIONS(1722),
    [anon_sym_set] = ACTIONS(1722),
    [anon_sym_declare] = ACTIONS(1722),
    [anon_sym_public] = ACTIONS(1722),
    [anon_sym_private] = ACTIONS(1722),
    [anon_sym_protected] = ACTIONS(1722),
    [anon_sym_override] = ACTIONS(1722),
    [anon_sym_module] = ACTIONS(1722),
    [anon_sym_any] = ACTIONS(1722),
    [anon_sym_number] = ACTIONS(1722),
    [anon_sym_boolean] = ACTIONS(1722),
    [anon_sym_string] = ACTIONS(1722),
    [anon_sym_symbol] = ACTIONS(1722),
    [anon_sym_object] = ACTIONS(1722),
    [anon_sym_abstract] = ACTIONS(1722),
    [anon_sym_interface] = ACTIONS(1722),
    [anon_sym_enum] = ACTIONS(1722),
    [sym_html_comment] = ACTIONS(5),
  },
  [873] = {
    [ts_builtin_sym_end] = ACTIONS(2749),
    [sym_identifier] = ACTIONS(2751),
    [anon_sym_export] = ACTIONS(2751),
    [anon_sym_default] = ACTIONS(2751),
    [anon_sym_type] = ACTIONS(2751),
    [anon_sym_namespace] = ACTIONS(2751),
    [anon_sym_LBRACE] = ACTIONS(2749),
    [anon_sym_RBRACE] = ACTIONS(2749),
    [anon_sym_typeof] = ACTIONS(2751),
    [anon_sym_import] = ACTIONS(2751),
    [anon_sym_with] = ACTIONS(2751),
    [anon_sym_var] = ACTIONS(2751),
    [anon_sym_let] = ACTIONS(2751),
    [anon_sym_const] = ACTIONS(2751),
    [anon_sym_BANG] = ACTIONS(2749),
    [anon_sym_else] = ACTIONS(2751),
    [anon_sym_if] = ACTIONS(2751),
    [anon_sym_switch] = ACTIONS(2751),
    [anon_sym_for] = ACTIONS(2751),
    [anon_sym_LPAREN] = ACTIONS(2749),
    [anon_sym_SEMI] = ACTIONS(2749),
    [anon_sym_await] = ACTIONS(2751),
    [anon_sym_while] = ACTIONS(2751),
    [anon_sym_do] = ACTIONS(2751),
    [anon_sym_try] = ACTIONS(2751),
    [anon_sym_break] = ACTIONS(2751),
    [anon_sym_continue] = ACTIONS(2751),
    [anon_sym_debugger] = ACTIONS(2751),
    [anon_sym_return] = ACTIONS(2751),
    [anon_sym_throw] = ACTIONS(2751),
    [anon_sym_case] = ACTIONS(2751),
    [anon_sym_yield] = ACTIONS(2751),
    [anon_sym_LBRACK] = ACTIONS(2749),
    [anon_sym_class] = ACTIONS(2751),
    [anon_sym_async] = ACTIONS(2751),
    [anon_sym_function] = ACTIONS(2751),
    [anon_sym_new] = ACTIONS(2751),
    [anon_sym_using] = ACTIONS(2751),
    [anon_sym_PLUS] = ACTIONS(2751),
    [anon_sym_DASH] = ACTIONS(2751),
    [anon_sym_SLASH] = ACTIONS(2751),
    [anon_sym_LT] = ACTIONS(2749),
    [anon_sym_TILDE] = ACTIONS(2749),
    [anon_sym_void] = ACTIONS(2751),
    [anon_sym_delete] = ACTIONS(2751),
    [anon_sym_PLUS_PLUS] = ACTIONS(2749),
    [anon_sym_DASH_DASH] = ACTIONS(2749),
    [anon_sym_DQUOTE] = ACTIONS(2749),
    [anon_sym_SQUOTE] = ACTIONS(2749),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(2749),
    [sym_number] = ACTIONS(2749),
    [sym_private_property_identifier] = ACTIONS(2749),
    [sym_this] = ACTIONS(2751),
    [sym_super] = ACTIONS(2751),
    [sym_true] = ACTIONS(2751),
    [sym_false] = ACTIONS(2751),
    [sym_null] = ACTIONS(2751),
    [sym_undefined] = ACTIONS(2751),
    [anon_sym_AT] = ACTIONS(2749),
    [anon_sym_static] = ACTIONS(2751),
    [anon_sym_readonly] = ACTIONS(2751),
    [anon_sym_get] = ACTIONS(2751),
    [anon_sym_set] = ACTIONS(2751),
    [anon_sym_declare] = ACTIONS(2751),
    [anon_sym_public] = ACTIONS(2751),
    [anon_sym_private] = ACTIONS(2751),
    [anon_sym_protected] = ACTIONS(2751),
    [anon_sym_override] = ACTIONS(2751),
    [anon_sym_module] = ACTIONS(2751),
    [anon_sym_any] = ACTIONS(2751),
    [anon_sym_number] = ACTIONS(2751),
    [anon_sym_boolean] = ACTIONS(2751),
    [anon_sym_string] = ACTIONS(2751),
    [anon_sym_symbol] = ACTIONS(2751),
    [anon_sym_object] = ACTIONS(2751),
    [anon_sym_abstract] = ACTIONS(2751),
    [anon_sym_interface] = ACTIONS(2751),
    [anon_sym_enum] = ACTIONS(2751),
    [sym_html_comment] = ACTIONS(5),
  },
  [874] = {
    [ts_builtin_sym_end] = ACTIONS(2753),
    [sym_identifier] = ACTIONS(2755),
    [anon_sym_export] = ACTIONS(2755),
    [anon_sym_default] = ACTIONS(2755),
    [anon_sym_type] = ACTIONS(2755),
    [anon_sym_namespace] = ACTIONS(2755),
    [anon_sym_LBRACE] = ACTIONS(2753),
    [anon_sym_RBRACE] = ACTIONS(2753),
    [anon_sym_typeof] = ACTIONS(2755),
    [anon_sym_import] = ACTIONS(2755),
    [anon_sym_with] = ACTIONS(2755),
    [anon_sym_var] = ACTIONS(2755),
    [anon_sym_let] = ACTIONS(2755),
    [anon_sym_const] = ACTIONS(2755),
    [anon_sym_BANG] = ACTIONS(2753),
    [anon_sym_else] = ACTIONS(2755),
    [anon_sym_if] = ACTIONS(2755),
    [anon_sym_switch] = ACTIONS(2755),
    [anon_sym_for] = ACTIONS(2755),
    [anon_sym_LPAREN] = ACTIONS(2753),
    [anon_sym_SEMI] = ACTIONS(2753),
    [anon_sym_await] = ACTIONS(2755),
    [anon_sym_while] = ACTIONS(2755),
    [anon_sym_do] = ACTIONS(2755),
    [anon_sym_try] = ACTIONS(2755),
    [anon_sym_break] = ACTIONS(2755),
    [anon_sym_continue] = ACTIONS(2755),
    [anon_sym_debugger] = ACTIONS(2755),
    [anon_sym_return] = ACTIONS(2755),
    [anon_sym_throw] = ACTIONS(2755),
    [anon_sym_case] = ACTIONS(2755),
    [anon_sym_yield] = ACTIONS(2755),
    [anon_sym_LBRACK] = ACTIONS(2753),
    [anon_sym_class] = ACTIONS(2755),
    [anon_sym_async] = ACTIONS(2755),
    [anon_sym_function] = ACTIONS(2755),
    [anon_sym_new] = ACTIONS(2755),
    [anon_sym_using] = ACTIONS(2755),
    [anon_sym_PLUS] = ACTIONS(2755),
    [anon_sym_DASH] = ACTIONS(2755),
    [anon_sym_SLASH] = ACTIONS(2755),
    [anon_sym_LT] = ACTIONS(2753),
    [anon_sym_TILDE] = ACTIONS(2753),
    [anon_sym_void] = ACTIONS(2755),
    [anon_sym_delete] = ACTIONS(2755),
    [anon_sym_PLUS_PLUS] = ACTIONS(2753),
    [anon_sym_DASH_DASH] = ACTIONS(2753),
    [anon_sym_DQUOTE] = ACTIONS(2753),
    [anon_sym_SQUOTE] = ACTIONS(2753),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(2753),
    [sym_number] = ACTIONS(2753),
    [sym_private_property_identifier] = ACTIONS(2753),
    [sym_this] = ACTIONS(2755),
    [sym_super] = ACTIONS(2755),
    [sym_true] = ACTIONS(2755),
    [sym_false] = ACTIONS(2755),
    [sym_null] = ACTIONS(2755),
    [sym_undefined] = ACTIONS(2755),
    [anon_sym_AT] = ACTIONS(2753),
    [anon_sym_static] = ACTIONS(2755),
    [anon_sym_readonly] = ACTIONS(2755),
    [anon_sym_get] = ACTIONS(2755),
    [anon_sym_set] = ACTIONS(2755),
    [anon_sym_declare] = ACTIONS(2755),
    [anon_sym_public] = ACTIONS(2755),
    [anon_sym_private] = ACTIONS(2755),
    [anon_sym_protected] = ACTIONS(2755),
    [anon_sym_override] = ACTIONS(2755),
    [anon_sym_module] = ACTIONS(2755),
    [anon_sym_any] = ACTIONS(2755),
    [anon_sym_number] = ACTIONS(2755),
    [anon_sym_boolean] = ACTIONS(2755),
    [anon_sym_string] = ACTIONS(2755),
    [anon_sym_symbol] = ACTIONS(2755),
    [anon_sym_object] = ACTIONS(2755),
    [anon_sym_abstract] = ACTIONS(2755),
    [anon_sym_interface] = ACTIONS(2755),
    [anon_sym_enum] = ACTIONS(2755),
    [sym_html_comment] = ACTIONS(5),
  },
  [875] = {
    [ts_builtin_sym_end] = ACTIONS(2719),
    [sym_identifier] = ACTIONS(2721),
    [anon_sym_export] = ACTIONS(2721),
    [anon_sym_default] = ACTIONS(2721),
    [anon_sym_type] = ACTIONS(2721),
    [anon_sym_namespace] = ACTIONS(2721),
    [anon_sym_LBRACE] = ACTIONS(2719),
    [anon_sym_RBRACE] = ACTIONS(2719),
    [anon_sym_typeof] = ACTIONS(2721),
    [anon_sym_import] = ACTIONS(2721),
    [anon_sym_with] = ACTIONS(2721),
    [anon_sym_var] = ACTIONS(2721),
    [anon_sym_let] = ACTIONS(2721),
    [anon_sym_const] = ACTIONS(2721),
    [anon_sym_BANG] = ACTIONS(2719),
    [anon_sym_else] = ACTIONS(2721),
    [anon_sym_if] = ACTIONS(2721),
    [anon_sym_switch] = ACTIONS(2721),
    [anon_sym_for] = ACTIONS(2721),
    [anon_sym_LPAREN] = ACTIONS(2719),
    [anon_sym_SEMI] = ACTIONS(2719),
    [anon_sym_await] = ACTIONS(2721),
    [anon_sym_while] = ACTIONS(2721),
    [anon_sym_do] = ACTIONS(2721),
    [anon_sym_try] = ACTIONS(2721),
    [anon_sym_break] = ACTIONS(2721),
    [anon_sym_continue] = ACTIONS(2721),
    [anon_sym_debugger] = ACTIONS(2721),
    [anon_sym_return] = ACTIONS(2721),
    [anon_sym_throw] = ACTIONS(2721),
    [anon_sym_case] = ACTIONS(2721),
    [anon_sym_yield] = ACTIONS(2721),
    [anon_sym_LBRACK] = ACTIONS(2719),
    [anon_sym_class] = ACTIONS(2721),
    [anon_sym_async] = ACTIONS(2721),
    [anon_sym_function] = ACTIONS(2721),
    [anon_sym_new] = ACTIONS(2721),
    [anon_sym_using] = ACTIONS(2721),
    [anon_sym_PLUS] = ACTIONS(2721),
    [anon_sym_DASH] = ACTIONS(2721),
    [anon_sym_SLASH] = ACTIONS(2721),
    [anon_sym_LT] = ACTIONS(2719),
    [anon_sym_TILDE] = ACTIONS(2719),
    [anon_sym_void] = ACTIONS(2721),
    [anon_sym_delete] = ACTIONS(2721),
    [anon_sym_PLUS_PLUS] = ACTIONS(2719),
    [anon_sym_DASH_DASH] = ACTIONS(2719),
    [anon_sym_DQUOTE] = ACTIONS(2719),
    [anon_sym_SQUOTE] = ACTIONS(2719),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(2719),
    [sym_number] = ACTIONS(2719),
    [sym_private_property_identifier] = ACTIONS(2719),
    [sym_this] = ACTIONS(2721),
    [sym_super] = ACTIONS(2721),
    [sym_true] = ACTIONS(2721),
    [sym_false] = ACTIONS(2721),
    [sym_null] = ACTIONS(2721),
    [sym_undefined] = ACTIONS(2721),
    [anon_sym_AT] = ACTIONS(2719),
    [anon_sym_static] = ACTIONS(2721),
    [anon_sym_readonly] = ACTIONS(2721),
    [anon_sym_get] = ACTIONS(2721),
    [anon_sym_set] = ACTIONS(2721),
    [anon_sym_declare] = ACTIONS(2721),
    [anon_sym_public] = ACTIONS(2721),
    [anon_sym_private] = ACTIONS(2721),
    [anon_sym_protected] = ACTIONS(2721),
    [anon_sym_override] = ACTIONS(2721),
    [anon_sym_module] = ACTIONS(2721),
    [anon_sym_any] = ACTIONS(2721),
    [anon_sym_number] = ACTIONS(2721),
    [anon_sym_boolean] = ACTIONS(2721),
    [anon_sym_string] = ACTIONS(2721),
    [anon_sym_symbol] = ACTIONS(2721),
    [anon_sym_object] = ACTIONS(2721),
    [anon_sym_abstract] = ACTIONS(2721),
    [anon_sym_interface] = ACTIONS(2721),
    [anon_sym_enum] = ACTIONS(2721),
    [sym_html_comment] = ACTIONS(5),
  },
  [876] = {
    [sym_import] = STATE(4681),
    [sym_nested_identifier] = STATE(5474),
    [sym_string] = STATE(2994),
    [sym_formal_parameters] = STATE(5619),
    [sym_rest_pattern] = STATE(5165),
    [sym_nested_type_identifier] = STATE(2939),
    [sym__type_query_member_expression_in_type_annotation] = STATE(3303),
    [sym__type_query_call_expression_in_type_annotation] = STATE(2938),
    [sym_type] = STATE(3773),
    [sym_tuple_parameter] = STATE(5278),
    [sym_optional_tuple_parameter] = STATE(5278),
    [sym_optional_type] = STATE(5278),
    [sym_rest_type] = STATE(5278),
    [sym__tuple_type_member] = STATE(5278),
    [sym_constructor_type] = STATE(3007),
    [sym_primary_type] = STATE(2981),
    [sym_template_literal_type] = STATE(3039),
    [sym_infer_type] = STATE(3007),
    [sym_conditional_type] = STATE(3039),
    [sym_generic_type] = STATE(3039),
    [sym_type_query] = STATE(3039),
    [sym_index_type_query] = STATE(3039),
    [sym_lookup_type] = STATE(3039),
    [sym_literal_type] = STATE(3039),
    [sym__number] = STATE(3041),
    [sym_existential_type] = STATE(3039),
    [sym_flow_maybe_type] = STATE(3039),
    [sym_parenthesized_type] = STATE(3039),
    [sym_predefined_type] = STATE(3039),
    [sym_object_type] = STATE(3039),
    [sym_type_parameters] = STATE(5454),
    [sym_array_type] = STATE(3039),
    [sym_tuple_type] = STATE(3039),
    [sym_readonly_type] = STATE(3007),
    [sym_union_type] = STATE(3039),
    [sym_intersection_type] = STATE(3039),
    [sym_function_type] = STATE(3007),
    [sym_identifier] = ACTIONS(2489),
    [anon_sym_STAR] = ACTIONS(543),
    [anon_sym_LBRACE] = ACTIONS(1534),
    [anon_sym_typeof] = ACTIONS(1536),
    [anon_sym_import] = ACTIONS(1538),
    [anon_sym_const] = ACTIONS(133),
    [anon_sym_LPAREN] = ACTIONS(1540),
    [anon_sym_LBRACK] = ACTIONS(1542),
    [anon_sym_RBRACK] = ACTIONS(2757),
    [anon_sym_new] = ACTIONS(1642),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(2495),
    [anon_sym_AMP] = ACTIONS(571),
    [anon_sym_PIPE] = ACTIONS(573),
    [anon_sym_PLUS] = ACTIONS(2497),
    [anon_sym_DASH] = ACTIONS(2497),
    [anon_sym_LT] = ACTIONS(2499),
    [anon_sym_void] = ACTIONS(216),
    [anon_sym_DQUOTE] = ACTIONS(1550),
    [anon_sym_SQUOTE] = ACTIONS(1552),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1554),
    [sym_number] = ACTIONS(1556),
    [sym_this] = ACTIONS(1558),
    [sym_true] = ACTIONS(1560),
    [sym_false] = ACTIONS(1560),
    [sym_null] = ACTIONS(1560),
    [sym_undefined] = ACTIONS(1560),
    [anon_sym_readonly] = ACTIONS(1648),
    [anon_sym_QMARK] = ACTIONS(593),
    [anon_sym_any] = ACTIONS(216),
    [anon_sym_number] = ACTIONS(216),
    [anon_sym_boolean] = ACTIONS(216),
    [anon_sym_string] = ACTIONS(216),
    [anon_sym_symbol] = ACTIONS(216),
    [anon_sym_object] = ACTIONS(216),
    [anon_sym_abstract] = ACTIONS(597),
    [anon_sym_infer] = ACTIONS(599),
    [anon_sym_keyof] = ACTIONS(601),
    [anon_sym_unique] = ACTIONS(214),
    [anon_sym_unknown] = ACTIONS(216),
    [anon_sym_never] = ACTIONS(216),
    [anon_sym_LBRACE_PIPE] = ACTIONS(218),
    [sym_html_comment] = ACTIONS(5),
  },
  [877] = {
    [ts_builtin_sym_end] = ACTIONS(2759),
    [sym_identifier] = ACTIONS(2761),
    [anon_sym_export] = ACTIONS(2761),
    [anon_sym_default] = ACTIONS(2761),
    [anon_sym_type] = ACTIONS(2761),
    [anon_sym_namespace] = ACTIONS(2761),
    [anon_sym_LBRACE] = ACTIONS(2759),
    [anon_sym_RBRACE] = ACTIONS(2759),
    [anon_sym_typeof] = ACTIONS(2761),
    [anon_sym_import] = ACTIONS(2761),
    [anon_sym_with] = ACTIONS(2761),
    [anon_sym_var] = ACTIONS(2761),
    [anon_sym_let] = ACTIONS(2761),
    [anon_sym_const] = ACTIONS(2761),
    [anon_sym_BANG] = ACTIONS(2759),
    [anon_sym_else] = ACTIONS(2761),
    [anon_sym_if] = ACTIONS(2761),
    [anon_sym_switch] = ACTIONS(2761),
    [anon_sym_for] = ACTIONS(2761),
    [anon_sym_LPAREN] = ACTIONS(2759),
    [anon_sym_SEMI] = ACTIONS(2759),
    [anon_sym_await] = ACTIONS(2761),
    [anon_sym_while] = ACTIONS(2761),
    [anon_sym_do] = ACTIONS(2761),
    [anon_sym_try] = ACTIONS(2761),
    [anon_sym_break] = ACTIONS(2761),
    [anon_sym_continue] = ACTIONS(2761),
    [anon_sym_debugger] = ACTIONS(2761),
    [anon_sym_return] = ACTIONS(2761),
    [anon_sym_throw] = ACTIONS(2761),
    [anon_sym_case] = ACTIONS(2761),
    [anon_sym_yield] = ACTIONS(2761),
    [anon_sym_LBRACK] = ACTIONS(2759),
    [anon_sym_class] = ACTIONS(2761),
    [anon_sym_async] = ACTIONS(2761),
    [anon_sym_function] = ACTIONS(2761),
    [anon_sym_new] = ACTIONS(2761),
    [anon_sym_using] = ACTIONS(2761),
    [anon_sym_PLUS] = ACTIONS(2761),
    [anon_sym_DASH] = ACTIONS(2761),
    [anon_sym_SLASH] = ACTIONS(2761),
    [anon_sym_LT] = ACTIONS(2759),
    [anon_sym_TILDE] = ACTIONS(2759),
    [anon_sym_void] = ACTIONS(2761),
    [anon_sym_delete] = ACTIONS(2761),
    [anon_sym_PLUS_PLUS] = ACTIONS(2759),
    [anon_sym_DASH_DASH] = ACTIONS(2759),
    [anon_sym_DQUOTE] = ACTIONS(2759),
    [anon_sym_SQUOTE] = ACTIONS(2759),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(2759),
    [sym_number] = ACTIONS(2759),
    [sym_private_property_identifier] = ACTIONS(2759),
    [sym_this] = ACTIONS(2761),
    [sym_super] = ACTIONS(2761),
    [sym_true] = ACTIONS(2761),
    [sym_false] = ACTIONS(2761),
    [sym_null] = ACTIONS(2761),
    [sym_undefined] = ACTIONS(2761),
    [anon_sym_AT] = ACTIONS(2759),
    [anon_sym_static] = ACTIONS(2761),
    [anon_sym_readonly] = ACTIONS(2761),
    [anon_sym_get] = ACTIONS(2761),
    [anon_sym_set] = ACTIONS(2761),
    [anon_sym_declare] = ACTIONS(2761),
    [anon_sym_public] = ACTIONS(2761),
    [anon_sym_private] = ACTIONS(2761),
    [anon_sym_protected] = ACTIONS(2761),
    [anon_sym_override] = ACTIONS(2761),
    [anon_sym_module] = ACTIONS(2761),
    [anon_sym_any] = ACTIONS(2761),
    [anon_sym_number] = ACTIONS(2761),
    [anon_sym_boolean] = ACTIONS(2761),
    [anon_sym_string] = ACTIONS(2761),
    [anon_sym_symbol] = ACTIONS(2761),
    [anon_sym_object] = ACTIONS(2761),
    [anon_sym_abstract] = ACTIONS(2761),
    [anon_sym_interface] = ACTIONS(2761),
    [anon_sym_enum] = ACTIONS(2761),
    [sym_html_comment] = ACTIONS(5),
  },
  [878] = {
    [ts_builtin_sym_end] = ACTIONS(2763),
    [sym_identifier] = ACTIONS(2765),
    [anon_sym_export] = ACTIONS(2765),
    [anon_sym_default] = ACTIONS(2765),
    [anon_sym_type] = ACTIONS(2765),
    [anon_sym_namespace] = ACTIONS(2765),
    [anon_sym_LBRACE] = ACTIONS(2763),
    [anon_sym_RBRACE] = ACTIONS(2763),
    [anon_sym_typeof] = ACTIONS(2765),
    [anon_sym_import] = ACTIONS(2765),
    [anon_sym_with] = ACTIONS(2765),
    [anon_sym_var] = ACTIONS(2765),
    [anon_sym_let] = ACTIONS(2765),
    [anon_sym_const] = ACTIONS(2765),
    [anon_sym_BANG] = ACTIONS(2763),
    [anon_sym_else] = ACTIONS(2765),
    [anon_sym_if] = ACTIONS(2765),
    [anon_sym_switch] = ACTIONS(2765),
    [anon_sym_for] = ACTIONS(2765),
    [anon_sym_LPAREN] = ACTIONS(2763),
    [anon_sym_SEMI] = ACTIONS(2763),
    [anon_sym_await] = ACTIONS(2765),
    [anon_sym_while] = ACTIONS(2765),
    [anon_sym_do] = ACTIONS(2765),
    [anon_sym_try] = ACTIONS(2765),
    [anon_sym_break] = ACTIONS(2765),
    [anon_sym_continue] = ACTIONS(2765),
    [anon_sym_debugger] = ACTIONS(2765),
    [anon_sym_return] = ACTIONS(2765),
    [anon_sym_throw] = ACTIONS(2765),
    [anon_sym_case] = ACTIONS(2765),
    [anon_sym_yield] = ACTIONS(2765),
    [anon_sym_LBRACK] = ACTIONS(2763),
    [anon_sym_class] = ACTIONS(2765),
    [anon_sym_async] = ACTIONS(2765),
    [anon_sym_function] = ACTIONS(2765),
    [anon_sym_new] = ACTIONS(2765),
    [anon_sym_using] = ACTIONS(2765),
    [anon_sym_PLUS] = ACTIONS(2765),
    [anon_sym_DASH] = ACTIONS(2765),
    [anon_sym_SLASH] = ACTIONS(2765),
    [anon_sym_LT] = ACTIONS(2763),
    [anon_sym_TILDE] = ACTIONS(2763),
    [anon_sym_void] = ACTIONS(2765),
    [anon_sym_delete] = ACTIONS(2765),
    [anon_sym_PLUS_PLUS] = ACTIONS(2763),
    [anon_sym_DASH_DASH] = ACTIONS(2763),
    [anon_sym_DQUOTE] = ACTIONS(2763),
    [anon_sym_SQUOTE] = ACTIONS(2763),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(2763),
    [sym_number] = ACTIONS(2763),
    [sym_private_property_identifier] = ACTIONS(2763),
    [sym_this] = ACTIONS(2765),
    [sym_super] = ACTIONS(2765),
    [sym_true] = ACTIONS(2765),
    [sym_false] = ACTIONS(2765),
    [sym_null] = ACTIONS(2765),
    [sym_undefined] = ACTIONS(2765),
    [anon_sym_AT] = ACTIONS(2763),
    [anon_sym_static] = ACTIONS(2765),
    [anon_sym_readonly] = ACTIONS(2765),
    [anon_sym_get] = ACTIONS(2765),
    [anon_sym_set] = ACTIONS(2765),
    [anon_sym_declare] = ACTIONS(2765),
    [anon_sym_public] = ACTIONS(2765),
    [anon_sym_private] = ACTIONS(2765),
    [anon_sym_protected] = ACTIONS(2765),
    [anon_sym_override] = ACTIONS(2765),
    [anon_sym_module] = ACTIONS(2765),
    [anon_sym_any] = ACTIONS(2765),
    [anon_sym_number] = ACTIONS(2765),
    [anon_sym_boolean] = ACTIONS(2765),
    [anon_sym_string] = ACTIONS(2765),
    [anon_sym_symbol] = ACTIONS(2765),
    [anon_sym_object] = ACTIONS(2765),
    [anon_sym_abstract] = ACTIONS(2765),
    [anon_sym_interface] = ACTIONS(2765),
    [anon_sym_enum] = ACTIONS(2765),
    [sym_html_comment] = ACTIONS(5),
  },
  [879] = {
    [ts_builtin_sym_end] = ACTIONS(2699),
    [sym_identifier] = ACTIONS(2701),
    [anon_sym_export] = ACTIONS(2701),
    [anon_sym_default] = ACTIONS(2701),
    [anon_sym_type] = ACTIONS(2701),
    [anon_sym_namespace] = ACTIONS(2701),
    [anon_sym_LBRACE] = ACTIONS(2699),
    [anon_sym_RBRACE] = ACTIONS(2699),
    [anon_sym_typeof] = ACTIONS(2701),
    [anon_sym_import] = ACTIONS(2701),
    [anon_sym_with] = ACTIONS(2701),
    [anon_sym_var] = ACTIONS(2701),
    [anon_sym_let] = ACTIONS(2701),
    [anon_sym_const] = ACTIONS(2701),
    [anon_sym_BANG] = ACTIONS(2699),
    [anon_sym_else] = ACTIONS(2701),
    [anon_sym_if] = ACTIONS(2701),
    [anon_sym_switch] = ACTIONS(2701),
    [anon_sym_for] = ACTIONS(2701),
    [anon_sym_LPAREN] = ACTIONS(2699),
    [anon_sym_SEMI] = ACTIONS(2699),
    [anon_sym_await] = ACTIONS(2701),
    [anon_sym_while] = ACTIONS(2701),
    [anon_sym_do] = ACTIONS(2701),
    [anon_sym_try] = ACTIONS(2701),
    [anon_sym_break] = ACTIONS(2701),
    [anon_sym_continue] = ACTIONS(2701),
    [anon_sym_debugger] = ACTIONS(2701),
    [anon_sym_return] = ACTIONS(2701),
    [anon_sym_throw] = ACTIONS(2701),
    [anon_sym_case] = ACTIONS(2701),
    [anon_sym_yield] = ACTIONS(2701),
    [anon_sym_LBRACK] = ACTIONS(2699),
    [anon_sym_class] = ACTIONS(2701),
    [anon_sym_async] = ACTIONS(2701),
    [anon_sym_function] = ACTIONS(2701),
    [anon_sym_new] = ACTIONS(2701),
    [anon_sym_using] = ACTIONS(2701),
    [anon_sym_PLUS] = ACTIONS(2701),
    [anon_sym_DASH] = ACTIONS(2701),
    [anon_sym_SLASH] = ACTIONS(2701),
    [anon_sym_LT] = ACTIONS(2699),
    [anon_sym_TILDE] = ACTIONS(2699),
    [anon_sym_void] = ACTIONS(2701),
    [anon_sym_delete] = ACTIONS(2701),
    [anon_sym_PLUS_PLUS] = ACTIONS(2699),
    [anon_sym_DASH_DASH] = ACTIONS(2699),
    [anon_sym_DQUOTE] = ACTIONS(2699),
    [anon_sym_SQUOTE] = ACTIONS(2699),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(2699),
    [sym_number] = ACTIONS(2699),
    [sym_private_property_identifier] = ACTIONS(2699),
    [sym_this] = ACTIONS(2701),
    [sym_super] = ACTIONS(2701),
    [sym_true] = ACTIONS(2701),
    [sym_false] = ACTIONS(2701),
    [sym_null] = ACTIONS(2701),
    [sym_undefined] = ACTIONS(2701),
    [anon_sym_AT] = ACTIONS(2699),
    [anon_sym_static] = ACTIONS(2701),
    [anon_sym_readonly] = ACTIONS(2701),
    [anon_sym_get] = ACTIONS(2701),
    [anon_sym_set] = ACTIONS(2701),
    [anon_sym_declare] = ACTIONS(2701),
    [anon_sym_public] = ACTIONS(2701),
    [anon_sym_private] = ACTIONS(2701),
    [anon_sym_protected] = ACTIONS(2701),
    [anon_sym_override] = ACTIONS(2701),
    [anon_sym_module] = ACTIONS(2701),
    [anon_sym_any] = ACTIONS(2701),
    [anon_sym_number] = ACTIONS(2701),
    [anon_sym_boolean] = ACTIONS(2701),
    [anon_sym_string] = ACTIONS(2701),
    [anon_sym_symbol] = ACTIONS(2701),
    [anon_sym_object] = ACTIONS(2701),
    [anon_sym_abstract] = ACTIONS(2701),
    [anon_sym_interface] = ACTIONS(2701),
    [anon_sym_enum] = ACTIONS(2701),
    [sym_html_comment] = ACTIONS(5),
  },
  [880] = {
    [ts_builtin_sym_end] = ACTIONS(2767),
    [sym_identifier] = ACTIONS(2769),
    [anon_sym_export] = ACTIONS(2769),
    [anon_sym_default] = ACTIONS(2769),
    [anon_sym_type] = ACTIONS(2769),
    [anon_sym_namespace] = ACTIONS(2769),
    [anon_sym_LBRACE] = ACTIONS(2767),
    [anon_sym_RBRACE] = ACTIONS(2767),
    [anon_sym_typeof] = ACTIONS(2769),
    [anon_sym_import] = ACTIONS(2769),
    [anon_sym_with] = ACTIONS(2769),
    [anon_sym_var] = ACTIONS(2769),
    [anon_sym_let] = ACTIONS(2769),
    [anon_sym_const] = ACTIONS(2769),
    [anon_sym_BANG] = ACTIONS(2767),
    [anon_sym_else] = ACTIONS(2769),
    [anon_sym_if] = ACTIONS(2769),
    [anon_sym_switch] = ACTIONS(2769),
    [anon_sym_for] = ACTIONS(2769),
    [anon_sym_LPAREN] = ACTIONS(2767),
    [anon_sym_SEMI] = ACTIONS(2767),
    [anon_sym_await] = ACTIONS(2769),
    [anon_sym_while] = ACTIONS(2769),
    [anon_sym_do] = ACTIONS(2769),
    [anon_sym_try] = ACTIONS(2769),
    [anon_sym_break] = ACTIONS(2769),
    [anon_sym_continue] = ACTIONS(2769),
    [anon_sym_debugger] = ACTIONS(2769),
    [anon_sym_return] = ACTIONS(2769),
    [anon_sym_throw] = ACTIONS(2769),
    [anon_sym_case] = ACTIONS(2769),
    [anon_sym_yield] = ACTIONS(2769),
    [anon_sym_LBRACK] = ACTIONS(2767),
    [anon_sym_class] = ACTIONS(2769),
    [anon_sym_async] = ACTIONS(2769),
    [anon_sym_function] = ACTIONS(2769),
    [anon_sym_new] = ACTIONS(2769),
    [anon_sym_using] = ACTIONS(2769),
    [anon_sym_PLUS] = ACTIONS(2769),
    [anon_sym_DASH] = ACTIONS(2769),
    [anon_sym_SLASH] = ACTIONS(2769),
    [anon_sym_LT] = ACTIONS(2767),
    [anon_sym_TILDE] = ACTIONS(2767),
    [anon_sym_void] = ACTIONS(2769),
    [anon_sym_delete] = ACTIONS(2769),
    [anon_sym_PLUS_PLUS] = ACTIONS(2767),
    [anon_sym_DASH_DASH] = ACTIONS(2767),
    [anon_sym_DQUOTE] = ACTIONS(2767),
    [anon_sym_SQUOTE] = ACTIONS(2767),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(2767),
    [sym_number] = ACTIONS(2767),
    [sym_private_property_identifier] = ACTIONS(2767),
    [sym_this] = ACTIONS(2769),
    [sym_super] = ACTIONS(2769),
    [sym_true] = ACTIONS(2769),
    [sym_false] = ACTIONS(2769),
    [sym_null] = ACTIONS(2769),
    [sym_undefined] = ACTIONS(2769),
    [anon_sym_AT] = ACTIONS(2767),
    [anon_sym_static] = ACTIONS(2769),
    [anon_sym_readonly] = ACTIONS(2769),
    [anon_sym_get] = ACTIONS(2769),
    [anon_sym_set] = ACTIONS(2769),
    [anon_sym_declare] = ACTIONS(2769),
    [anon_sym_public] = ACTIONS(2769),
    [anon_sym_private] = ACTIONS(2769),
    [anon_sym_protected] = ACTIONS(2769),
    [anon_sym_override] = ACTIONS(2769),
    [anon_sym_module] = ACTIONS(2769),
    [anon_sym_any] = ACTIONS(2769),
    [anon_sym_number] = ACTIONS(2769),
    [anon_sym_boolean] = ACTIONS(2769),
    [anon_sym_string] = ACTIONS(2769),
    [anon_sym_symbol] = ACTIONS(2769),
    [anon_sym_object] = ACTIONS(2769),
    [anon_sym_abstract] = ACTIONS(2769),
    [anon_sym_interface] = ACTIONS(2769),
    [anon_sym_enum] = ACTIONS(2769),
    [sym_html_comment] = ACTIONS(5),
  },
  [881] = {
    [ts_builtin_sym_end] = ACTIONS(2771),
    [sym_identifier] = ACTIONS(2773),
    [anon_sym_export] = ACTIONS(2773),
    [anon_sym_default] = ACTIONS(2773),
    [anon_sym_type] = ACTIONS(2773),
    [anon_sym_namespace] = ACTIONS(2773),
    [anon_sym_LBRACE] = ACTIONS(2771),
    [anon_sym_RBRACE] = ACTIONS(2771),
    [anon_sym_typeof] = ACTIONS(2773),
    [anon_sym_import] = ACTIONS(2773),
    [anon_sym_with] = ACTIONS(2773),
    [anon_sym_var] = ACTIONS(2773),
    [anon_sym_let] = ACTIONS(2773),
    [anon_sym_const] = ACTIONS(2773),
    [anon_sym_BANG] = ACTIONS(2771),
    [anon_sym_else] = ACTIONS(2773),
    [anon_sym_if] = ACTIONS(2773),
    [anon_sym_switch] = ACTIONS(2773),
    [anon_sym_for] = ACTIONS(2773),
    [anon_sym_LPAREN] = ACTIONS(2771),
    [anon_sym_SEMI] = ACTIONS(2771),
    [anon_sym_await] = ACTIONS(2773),
    [anon_sym_while] = ACTIONS(2773),
    [anon_sym_do] = ACTIONS(2773),
    [anon_sym_try] = ACTIONS(2773),
    [anon_sym_break] = ACTIONS(2773),
    [anon_sym_continue] = ACTIONS(2773),
    [anon_sym_debugger] = ACTIONS(2773),
    [anon_sym_return] = ACTIONS(2773),
    [anon_sym_throw] = ACTIONS(2773),
    [anon_sym_case] = ACTIONS(2773),
    [anon_sym_yield] = ACTIONS(2773),
    [anon_sym_LBRACK] = ACTIONS(2771),
    [anon_sym_class] = ACTIONS(2773),
    [anon_sym_async] = ACTIONS(2773),
    [anon_sym_function] = ACTIONS(2773),
    [anon_sym_new] = ACTIONS(2773),
    [anon_sym_using] = ACTIONS(2773),
    [anon_sym_PLUS] = ACTIONS(2773),
    [anon_sym_DASH] = ACTIONS(2773),
    [anon_sym_SLASH] = ACTIONS(2773),
    [anon_sym_LT] = ACTIONS(2771),
    [anon_sym_TILDE] = ACTIONS(2771),
    [anon_sym_void] = ACTIONS(2773),
    [anon_sym_delete] = ACTIONS(2773),
    [anon_sym_PLUS_PLUS] = ACTIONS(2771),
    [anon_sym_DASH_DASH] = ACTIONS(2771),
    [anon_sym_DQUOTE] = ACTIONS(2771),
    [anon_sym_SQUOTE] = ACTIONS(2771),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(2771),
    [sym_number] = ACTIONS(2771),
    [sym_private_property_identifier] = ACTIONS(2771),
    [sym_this] = ACTIONS(2773),
    [sym_super] = ACTIONS(2773),
    [sym_true] = ACTIONS(2773),
    [sym_false] = ACTIONS(2773),
    [sym_null] = ACTIONS(2773),
    [sym_undefined] = ACTIONS(2773),
    [anon_sym_AT] = ACTIONS(2771),
    [anon_sym_static] = ACTIONS(2773),
    [anon_sym_readonly] = ACTIONS(2773),
    [anon_sym_get] = ACTIONS(2773),
    [anon_sym_set] = ACTIONS(2773),
    [anon_sym_declare] = ACTIONS(2773),
    [anon_sym_public] = ACTIONS(2773),
    [anon_sym_private] = ACTIONS(2773),
    [anon_sym_protected] = ACTIONS(2773),
    [anon_sym_override] = ACTIONS(2773),
    [anon_sym_module] = ACTIONS(2773),
    [anon_sym_any] = ACTIONS(2773),
    [anon_sym_number] = ACTIONS(2773),
    [anon_sym_boolean] = ACTIONS(2773),
    [anon_sym_string] = ACTIONS(2773),
    [anon_sym_symbol] = ACTIONS(2773),
    [anon_sym_object] = ACTIONS(2773),
    [anon_sym_abstract] = ACTIONS(2773),
    [anon_sym_interface] = ACTIONS(2773),
    [anon_sym_enum] = ACTIONS(2773),
    [sym_html_comment] = ACTIONS(5),
  },
  [882] = {
    [ts_builtin_sym_end] = ACTIONS(1750),
    [sym_identifier] = ACTIONS(1752),
    [anon_sym_export] = ACTIONS(1752),
    [anon_sym_default] = ACTIONS(1752),
    [anon_sym_type] = ACTIONS(1752),
    [anon_sym_namespace] = ACTIONS(1752),
    [anon_sym_LBRACE] = ACTIONS(1750),
    [anon_sym_RBRACE] = ACTIONS(1750),
    [anon_sym_typeof] = ACTIONS(1752),
    [anon_sym_import] = ACTIONS(1752),
    [anon_sym_with] = ACTIONS(1752),
    [anon_sym_var] = ACTIONS(1752),
    [anon_sym_let] = ACTIONS(1752),
    [anon_sym_const] = ACTIONS(1752),
    [anon_sym_BANG] = ACTIONS(1750),
    [anon_sym_else] = ACTIONS(1752),
    [anon_sym_if] = ACTIONS(1752),
    [anon_sym_switch] = ACTIONS(1752),
    [anon_sym_for] = ACTIONS(1752),
    [anon_sym_LPAREN] = ACTIONS(1750),
    [anon_sym_SEMI] = ACTIONS(1750),
    [anon_sym_await] = ACTIONS(1752),
    [anon_sym_while] = ACTIONS(1752),
    [anon_sym_do] = ACTIONS(1752),
    [anon_sym_try] = ACTIONS(1752),
    [anon_sym_break] = ACTIONS(1752),
    [anon_sym_continue] = ACTIONS(1752),
    [anon_sym_debugger] = ACTIONS(1752),
    [anon_sym_return] = ACTIONS(1752),
    [anon_sym_throw] = ACTIONS(1752),
    [anon_sym_case] = ACTIONS(1752),
    [anon_sym_yield] = ACTIONS(1752),
    [anon_sym_LBRACK] = ACTIONS(1750),
    [anon_sym_class] = ACTIONS(1752),
    [anon_sym_async] = ACTIONS(1752),
    [anon_sym_function] = ACTIONS(1752),
    [anon_sym_new] = ACTIONS(1752),
    [anon_sym_using] = ACTIONS(1752),
    [anon_sym_PLUS] = ACTIONS(1752),
    [anon_sym_DASH] = ACTIONS(1752),
    [anon_sym_SLASH] = ACTIONS(1752),
    [anon_sym_LT] = ACTIONS(1750),
    [anon_sym_TILDE] = ACTIONS(1750),
    [anon_sym_void] = ACTIONS(1752),
    [anon_sym_delete] = ACTIONS(1752),
    [anon_sym_PLUS_PLUS] = ACTIONS(1750),
    [anon_sym_DASH_DASH] = ACTIONS(1750),
    [anon_sym_DQUOTE] = ACTIONS(1750),
    [anon_sym_SQUOTE] = ACTIONS(1750),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1750),
    [sym_number] = ACTIONS(1750),
    [sym_private_property_identifier] = ACTIONS(1750),
    [sym_this] = ACTIONS(1752),
    [sym_super] = ACTIONS(1752),
    [sym_true] = ACTIONS(1752),
    [sym_false] = ACTIONS(1752),
    [sym_null] = ACTIONS(1752),
    [sym_undefined] = ACTIONS(1752),
    [anon_sym_AT] = ACTIONS(1750),
    [anon_sym_static] = ACTIONS(1752),
    [anon_sym_readonly] = ACTIONS(1752),
    [anon_sym_get] = ACTIONS(1752),
    [anon_sym_set] = ACTIONS(1752),
    [anon_sym_declare] = ACTIONS(1752),
    [anon_sym_public] = ACTIONS(1752),
    [anon_sym_private] = ACTIONS(1752),
    [anon_sym_protected] = ACTIONS(1752),
    [anon_sym_override] = ACTIONS(1752),
    [anon_sym_module] = ACTIONS(1752),
    [anon_sym_any] = ACTIONS(1752),
    [anon_sym_number] = ACTIONS(1752),
    [anon_sym_boolean] = ACTIONS(1752),
    [anon_sym_string] = ACTIONS(1752),
    [anon_sym_symbol] = ACTIONS(1752),
    [anon_sym_object] = ACTIONS(1752),
    [anon_sym_abstract] = ACTIONS(1752),
    [anon_sym_interface] = ACTIONS(1752),
    [anon_sym_enum] = ACTIONS(1752),
    [sym_html_comment] = ACTIONS(5),
  },
  [883] = {
    [ts_builtin_sym_end] = ACTIONS(2775),
    [sym_identifier] = ACTIONS(2777),
    [anon_sym_export] = ACTIONS(2777),
    [anon_sym_default] = ACTIONS(2777),
    [anon_sym_type] = ACTIONS(2777),
    [anon_sym_namespace] = ACTIONS(2777),
    [anon_sym_LBRACE] = ACTIONS(2775),
    [anon_sym_RBRACE] = ACTIONS(2775),
    [anon_sym_typeof] = ACTIONS(2777),
    [anon_sym_import] = ACTIONS(2777),
    [anon_sym_with] = ACTIONS(2777),
    [anon_sym_var] = ACTIONS(2777),
    [anon_sym_let] = ACTIONS(2777),
    [anon_sym_const] = ACTIONS(2777),
    [anon_sym_BANG] = ACTIONS(2775),
    [anon_sym_else] = ACTIONS(2777),
    [anon_sym_if] = ACTIONS(2777),
    [anon_sym_switch] = ACTIONS(2777),
    [anon_sym_for] = ACTIONS(2777),
    [anon_sym_LPAREN] = ACTIONS(2775),
    [anon_sym_SEMI] = ACTIONS(2775),
    [anon_sym_await] = ACTIONS(2777),
    [anon_sym_while] = ACTIONS(2777),
    [anon_sym_do] = ACTIONS(2777),
    [anon_sym_try] = ACTIONS(2777),
    [anon_sym_break] = ACTIONS(2777),
    [anon_sym_continue] = ACTIONS(2777),
    [anon_sym_debugger] = ACTIONS(2777),
    [anon_sym_return] = ACTIONS(2777),
    [anon_sym_throw] = ACTIONS(2777),
    [anon_sym_case] = ACTIONS(2777),
    [anon_sym_yield] = ACTIONS(2777),
    [anon_sym_LBRACK] = ACTIONS(2775),
    [anon_sym_class] = ACTIONS(2777),
    [anon_sym_async] = ACTIONS(2777),
    [anon_sym_function] = ACTIONS(2777),
    [anon_sym_new] = ACTIONS(2777),
    [anon_sym_using] = ACTIONS(2777),
    [anon_sym_PLUS] = ACTIONS(2777),
    [anon_sym_DASH] = ACTIONS(2777),
    [anon_sym_SLASH] = ACTIONS(2777),
    [anon_sym_LT] = ACTIONS(2775),
    [anon_sym_TILDE] = ACTIONS(2775),
    [anon_sym_void] = ACTIONS(2777),
    [anon_sym_delete] = ACTIONS(2777),
    [anon_sym_PLUS_PLUS] = ACTIONS(2775),
    [anon_sym_DASH_DASH] = ACTIONS(2775),
    [anon_sym_DQUOTE] = ACTIONS(2775),
    [anon_sym_SQUOTE] = ACTIONS(2775),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(2775),
    [sym_number] = ACTIONS(2775),
    [sym_private_property_identifier] = ACTIONS(2775),
    [sym_this] = ACTIONS(2777),
    [sym_super] = ACTIONS(2777),
    [sym_true] = ACTIONS(2777),
    [sym_false] = ACTIONS(2777),
    [sym_null] = ACTIONS(2777),
    [sym_undefined] = ACTIONS(2777),
    [anon_sym_AT] = ACTIONS(2775),
    [anon_sym_static] = ACTIONS(2777),
    [anon_sym_readonly] = ACTIONS(2777),
    [anon_sym_get] = ACTIONS(2777),
    [anon_sym_set] = ACTIONS(2777),
    [anon_sym_declare] = ACTIONS(2777),
    [anon_sym_public] = ACTIONS(2777),
    [anon_sym_private] = ACTIONS(2777),
    [anon_sym_protected] = ACTIONS(2777),
    [anon_sym_override] = ACTIONS(2777),
    [anon_sym_module] = ACTIONS(2777),
    [anon_sym_any] = ACTIONS(2777),
    [anon_sym_number] = ACTIONS(2777),
    [anon_sym_boolean] = ACTIONS(2777),
    [anon_sym_string] = ACTIONS(2777),
    [anon_sym_symbol] = ACTIONS(2777),
    [anon_sym_object] = ACTIONS(2777),
    [anon_sym_abstract] = ACTIONS(2777),
    [anon_sym_interface] = ACTIONS(2777),
    [anon_sym_enum] = ACTIONS(2777),
    [sym_html_comment] = ACTIONS(5),
  },
  [884] = {
    [ts_builtin_sym_end] = ACTIONS(2779),
    [sym_identifier] = ACTIONS(2781),
    [anon_sym_export] = ACTIONS(2781),
    [anon_sym_default] = ACTIONS(2781),
    [anon_sym_type] = ACTIONS(2781),
    [anon_sym_namespace] = ACTIONS(2781),
    [anon_sym_LBRACE] = ACTIONS(2779),
    [anon_sym_RBRACE] = ACTIONS(2779),
    [anon_sym_typeof] = ACTIONS(2781),
    [anon_sym_import] = ACTIONS(2781),
    [anon_sym_with] = ACTIONS(2781),
    [anon_sym_var] = ACTIONS(2781),
    [anon_sym_let] = ACTIONS(2781),
    [anon_sym_const] = ACTIONS(2781),
    [anon_sym_BANG] = ACTIONS(2779),
    [anon_sym_else] = ACTIONS(2781),
    [anon_sym_if] = ACTIONS(2781),
    [anon_sym_switch] = ACTIONS(2781),
    [anon_sym_for] = ACTIONS(2781),
    [anon_sym_LPAREN] = ACTIONS(2779),
    [anon_sym_SEMI] = ACTIONS(2779),
    [anon_sym_await] = ACTIONS(2781),
    [anon_sym_while] = ACTIONS(2781),
    [anon_sym_do] = ACTIONS(2781),
    [anon_sym_try] = ACTIONS(2781),
    [anon_sym_break] = ACTIONS(2781),
    [anon_sym_continue] = ACTIONS(2781),
    [anon_sym_debugger] = ACTIONS(2781),
    [anon_sym_return] = ACTIONS(2781),
    [anon_sym_throw] = ACTIONS(2781),
    [anon_sym_case] = ACTIONS(2781),
    [anon_sym_yield] = ACTIONS(2781),
    [anon_sym_LBRACK] = ACTIONS(2779),
    [anon_sym_class] = ACTIONS(2781),
    [anon_sym_async] = ACTIONS(2781),
    [anon_sym_function] = ACTIONS(2781),
    [anon_sym_new] = ACTIONS(2781),
    [anon_sym_using] = ACTIONS(2781),
    [anon_sym_PLUS] = ACTIONS(2781),
    [anon_sym_DASH] = ACTIONS(2781),
    [anon_sym_SLASH] = ACTIONS(2781),
    [anon_sym_LT] = ACTIONS(2779),
    [anon_sym_TILDE] = ACTIONS(2779),
    [anon_sym_void] = ACTIONS(2781),
    [anon_sym_delete] = ACTIONS(2781),
    [anon_sym_PLUS_PLUS] = ACTIONS(2779),
    [anon_sym_DASH_DASH] = ACTIONS(2779),
    [anon_sym_DQUOTE] = ACTIONS(2779),
    [anon_sym_SQUOTE] = ACTIONS(2779),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(2779),
    [sym_number] = ACTIONS(2779),
    [sym_private_property_identifier] = ACTIONS(2779),
    [sym_this] = ACTIONS(2781),
    [sym_super] = ACTIONS(2781),
    [sym_true] = ACTIONS(2781),
    [sym_false] = ACTIONS(2781),
    [sym_null] = ACTIONS(2781),
    [sym_undefined] = ACTIONS(2781),
    [anon_sym_AT] = ACTIONS(2779),
    [anon_sym_static] = ACTIONS(2781),
    [anon_sym_readonly] = ACTIONS(2781),
    [anon_sym_get] = ACTIONS(2781),
    [anon_sym_set] = ACTIONS(2781),
    [anon_sym_declare] = ACTIONS(2781),
    [anon_sym_public] = ACTIONS(2781),
    [anon_sym_private] = ACTIONS(2781),
    [anon_sym_protected] = ACTIONS(2781),
    [anon_sym_override] = ACTIONS(2781),
    [anon_sym_module] = ACTIONS(2781),
    [anon_sym_any] = ACTIONS(2781),
    [anon_sym_number] = ACTIONS(2781),
    [anon_sym_boolean] = ACTIONS(2781),
    [anon_sym_string] = ACTIONS(2781),
    [anon_sym_symbol] = ACTIONS(2781),
    [anon_sym_object] = ACTIONS(2781),
    [anon_sym_abstract] = ACTIONS(2781),
    [anon_sym_interface] = ACTIONS(2781),
    [anon_sym_enum] = ACTIONS(2781),
    [sym_html_comment] = ACTIONS(5),
  },
  [885] = {
    [ts_builtin_sym_end] = ACTIONS(2783),
    [sym_identifier] = ACTIONS(2785),
    [anon_sym_export] = ACTIONS(2785),
    [anon_sym_default] = ACTIONS(2785),
    [anon_sym_type] = ACTIONS(2785),
    [anon_sym_namespace] = ACTIONS(2785),
    [anon_sym_LBRACE] = ACTIONS(2783),
    [anon_sym_RBRACE] = ACTIONS(2783),
    [anon_sym_typeof] = ACTIONS(2785),
    [anon_sym_import] = ACTIONS(2785),
    [anon_sym_with] = ACTIONS(2785),
    [anon_sym_var] = ACTIONS(2785),
    [anon_sym_let] = ACTIONS(2785),
    [anon_sym_const] = ACTIONS(2785),
    [anon_sym_BANG] = ACTIONS(2783),
    [anon_sym_else] = ACTIONS(2785),
    [anon_sym_if] = ACTIONS(2785),
    [anon_sym_switch] = ACTIONS(2785),
    [anon_sym_for] = ACTIONS(2785),
    [anon_sym_LPAREN] = ACTIONS(2783),
    [anon_sym_SEMI] = ACTIONS(2783),
    [anon_sym_await] = ACTIONS(2785),
    [anon_sym_while] = ACTIONS(2785),
    [anon_sym_do] = ACTIONS(2785),
    [anon_sym_try] = ACTIONS(2785),
    [anon_sym_break] = ACTIONS(2785),
    [anon_sym_continue] = ACTIONS(2785),
    [anon_sym_debugger] = ACTIONS(2785),
    [anon_sym_return] = ACTIONS(2785),
    [anon_sym_throw] = ACTIONS(2785),
    [anon_sym_case] = ACTIONS(2785),
    [anon_sym_yield] = ACTIONS(2785),
    [anon_sym_LBRACK] = ACTIONS(2783),
    [anon_sym_class] = ACTIONS(2785),
    [anon_sym_async] = ACTIONS(2785),
    [anon_sym_function] = ACTIONS(2785),
    [anon_sym_new] = ACTIONS(2785),
    [anon_sym_using] = ACTIONS(2785),
    [anon_sym_PLUS] = ACTIONS(2785),
    [anon_sym_DASH] = ACTIONS(2785),
    [anon_sym_SLASH] = ACTIONS(2785),
    [anon_sym_LT] = ACTIONS(2783),
    [anon_sym_TILDE] = ACTIONS(2783),
    [anon_sym_void] = ACTIONS(2785),
    [anon_sym_delete] = ACTIONS(2785),
    [anon_sym_PLUS_PLUS] = ACTIONS(2783),
    [anon_sym_DASH_DASH] = ACTIONS(2783),
    [anon_sym_DQUOTE] = ACTIONS(2783),
    [anon_sym_SQUOTE] = ACTIONS(2783),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(2783),
    [sym_number] = ACTIONS(2783),
    [sym_private_property_identifier] = ACTIONS(2783),
    [sym_this] = ACTIONS(2785),
    [sym_super] = ACTIONS(2785),
    [sym_true] = ACTIONS(2785),
    [sym_false] = ACTIONS(2785),
    [sym_null] = ACTIONS(2785),
    [sym_undefined] = ACTIONS(2785),
    [anon_sym_AT] = ACTIONS(2783),
    [anon_sym_static] = ACTIONS(2785),
    [anon_sym_readonly] = ACTIONS(2785),
    [anon_sym_get] = ACTIONS(2785),
    [anon_sym_set] = ACTIONS(2785),
    [anon_sym_declare] = ACTIONS(2785),
    [anon_sym_public] = ACTIONS(2785),
    [anon_sym_private] = ACTIONS(2785),
    [anon_sym_protected] = ACTIONS(2785),
    [anon_sym_override] = ACTIONS(2785),
    [anon_sym_module] = ACTIONS(2785),
    [anon_sym_any] = ACTIONS(2785),
    [anon_sym_number] = ACTIONS(2785),
    [anon_sym_boolean] = ACTIONS(2785),
    [anon_sym_string] = ACTIONS(2785),
    [anon_sym_symbol] = ACTIONS(2785),
    [anon_sym_object] = ACTIONS(2785),
    [anon_sym_abstract] = ACTIONS(2785),
    [anon_sym_interface] = ACTIONS(2785),
    [anon_sym_enum] = ACTIONS(2785),
    [sym_html_comment] = ACTIONS(5),
  },
  [886] = {
    [ts_builtin_sym_end] = ACTIONS(2787),
    [sym_identifier] = ACTIONS(2789),
    [anon_sym_export] = ACTIONS(2789),
    [anon_sym_default] = ACTIONS(2789),
    [anon_sym_type] = ACTIONS(2789),
    [anon_sym_namespace] = ACTIONS(2789),
    [anon_sym_LBRACE] = ACTIONS(2787),
    [anon_sym_RBRACE] = ACTIONS(2787),
    [anon_sym_typeof] = ACTIONS(2789),
    [anon_sym_import] = ACTIONS(2789),
    [anon_sym_with] = ACTIONS(2789),
    [anon_sym_var] = ACTIONS(2789),
    [anon_sym_let] = ACTIONS(2789),
    [anon_sym_const] = ACTIONS(2789),
    [anon_sym_BANG] = ACTIONS(2787),
    [anon_sym_else] = ACTIONS(2789),
    [anon_sym_if] = ACTIONS(2789),
    [anon_sym_switch] = ACTIONS(2789),
    [anon_sym_for] = ACTIONS(2789),
    [anon_sym_LPAREN] = ACTIONS(2787),
    [anon_sym_SEMI] = ACTIONS(2787),
    [anon_sym_await] = ACTIONS(2789),
    [anon_sym_while] = ACTIONS(2789),
    [anon_sym_do] = ACTIONS(2789),
    [anon_sym_try] = ACTIONS(2789),
    [anon_sym_break] = ACTIONS(2789),
    [anon_sym_continue] = ACTIONS(2789),
    [anon_sym_debugger] = ACTIONS(2789),
    [anon_sym_return] = ACTIONS(2789),
    [anon_sym_throw] = ACTIONS(2789),
    [anon_sym_case] = ACTIONS(2789),
    [anon_sym_yield] = ACTIONS(2789),
    [anon_sym_LBRACK] = ACTIONS(2787),
    [anon_sym_class] = ACTIONS(2789),
    [anon_sym_async] = ACTIONS(2789),
    [anon_sym_function] = ACTIONS(2789),
    [anon_sym_new] = ACTIONS(2789),
    [anon_sym_using] = ACTIONS(2789),
    [anon_sym_PLUS] = ACTIONS(2789),
    [anon_sym_DASH] = ACTIONS(2789),
    [anon_sym_SLASH] = ACTIONS(2789),
    [anon_sym_LT] = ACTIONS(2787),
    [anon_sym_TILDE] = ACTIONS(2787),
    [anon_sym_void] = ACTIONS(2789),
    [anon_sym_delete] = ACTIONS(2789),
    [anon_sym_PLUS_PLUS] = ACTIONS(2787),
    [anon_sym_DASH_DASH] = ACTIONS(2787),
    [anon_sym_DQUOTE] = ACTIONS(2787),
    [anon_sym_SQUOTE] = ACTIONS(2787),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(2787),
    [sym_number] = ACTIONS(2787),
    [sym_private_property_identifier] = ACTIONS(2787),
    [sym_this] = ACTIONS(2789),
    [sym_super] = ACTIONS(2789),
    [sym_true] = ACTIONS(2789),
    [sym_false] = ACTIONS(2789),
    [sym_null] = ACTIONS(2789),
    [sym_undefined] = ACTIONS(2789),
    [anon_sym_AT] = ACTIONS(2787),
    [anon_sym_static] = ACTIONS(2789),
    [anon_sym_readonly] = ACTIONS(2789),
    [anon_sym_get] = ACTIONS(2789),
    [anon_sym_set] = ACTIONS(2789),
    [anon_sym_declare] = ACTIONS(2789),
    [anon_sym_public] = ACTIONS(2789),
    [anon_sym_private] = ACTIONS(2789),
    [anon_sym_protected] = ACTIONS(2789),
    [anon_sym_override] = ACTIONS(2789),
    [anon_sym_module] = ACTIONS(2789),
    [anon_sym_any] = ACTIONS(2789),
    [anon_sym_number] = ACTIONS(2789),
    [anon_sym_boolean] = ACTIONS(2789),
    [anon_sym_string] = ACTIONS(2789),
    [anon_sym_symbol] = ACTIONS(2789),
    [anon_sym_object] = ACTIONS(2789),
    [anon_sym_abstract] = ACTIONS(2789),
    [anon_sym_interface] = ACTIONS(2789),
    [anon_sym_enum] = ACTIONS(2789),
    [sym_html_comment] = ACTIONS(5),
  },
  [887] = {
    [ts_builtin_sym_end] = ACTIONS(1852),
    [sym_identifier] = ACTIONS(1854),
    [anon_sym_export] = ACTIONS(1854),
    [anon_sym_default] = ACTIONS(1854),
    [anon_sym_type] = ACTIONS(1854),
    [anon_sym_namespace] = ACTIONS(1854),
    [anon_sym_LBRACE] = ACTIONS(1852),
    [anon_sym_RBRACE] = ACTIONS(1852),
    [anon_sym_typeof] = ACTIONS(1854),
    [anon_sym_import] = ACTIONS(1854),
    [anon_sym_with] = ACTIONS(1854),
    [anon_sym_var] = ACTIONS(1854),
    [anon_sym_let] = ACTIONS(1854),
    [anon_sym_const] = ACTIONS(1854),
    [anon_sym_BANG] = ACTIONS(1852),
    [anon_sym_else] = ACTIONS(1854),
    [anon_sym_if] = ACTIONS(1854),
    [anon_sym_switch] = ACTIONS(1854),
    [anon_sym_for] = ACTIONS(1854),
    [anon_sym_LPAREN] = ACTIONS(1852),
    [anon_sym_SEMI] = ACTIONS(1852),
    [anon_sym_await] = ACTIONS(1854),
    [anon_sym_while] = ACTIONS(1854),
    [anon_sym_do] = ACTIONS(1854),
    [anon_sym_try] = ACTIONS(1854),
    [anon_sym_break] = ACTIONS(1854),
    [anon_sym_continue] = ACTIONS(1854),
    [anon_sym_debugger] = ACTIONS(1854),
    [anon_sym_return] = ACTIONS(1854),
    [anon_sym_throw] = ACTIONS(1854),
    [anon_sym_case] = ACTIONS(1854),
    [anon_sym_yield] = ACTIONS(1854),
    [anon_sym_LBRACK] = ACTIONS(1852),
    [anon_sym_class] = ACTIONS(1854),
    [anon_sym_async] = ACTIONS(1854),
    [anon_sym_function] = ACTIONS(1854),
    [anon_sym_new] = ACTIONS(1854),
    [anon_sym_using] = ACTIONS(1854),
    [anon_sym_PLUS] = ACTIONS(1854),
    [anon_sym_DASH] = ACTIONS(1854),
    [anon_sym_SLASH] = ACTIONS(1854),
    [anon_sym_LT] = ACTIONS(1852),
    [anon_sym_TILDE] = ACTIONS(1852),
    [anon_sym_void] = ACTIONS(1854),
    [anon_sym_delete] = ACTIONS(1854),
    [anon_sym_PLUS_PLUS] = ACTIONS(1852),
    [anon_sym_DASH_DASH] = ACTIONS(1852),
    [anon_sym_DQUOTE] = ACTIONS(1852),
    [anon_sym_SQUOTE] = ACTIONS(1852),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1852),
    [sym_number] = ACTIONS(1852),
    [sym_private_property_identifier] = ACTIONS(1852),
    [sym_this] = ACTIONS(1854),
    [sym_super] = ACTIONS(1854),
    [sym_true] = ACTIONS(1854),
    [sym_false] = ACTIONS(1854),
    [sym_null] = ACTIONS(1854),
    [sym_undefined] = ACTIONS(1854),
    [anon_sym_AT] = ACTIONS(1852),
    [anon_sym_static] = ACTIONS(1854),
    [anon_sym_readonly] = ACTIONS(1854),
    [anon_sym_get] = ACTIONS(1854),
    [anon_sym_set] = ACTIONS(1854),
    [anon_sym_declare] = ACTIONS(1854),
    [anon_sym_public] = ACTIONS(1854),
    [anon_sym_private] = ACTIONS(1854),
    [anon_sym_protected] = ACTIONS(1854),
    [anon_sym_override] = ACTIONS(1854),
    [anon_sym_module] = ACTIONS(1854),
    [anon_sym_any] = ACTIONS(1854),
    [anon_sym_number] = ACTIONS(1854),
    [anon_sym_boolean] = ACTIONS(1854),
    [anon_sym_string] = ACTIONS(1854),
    [anon_sym_symbol] = ACTIONS(1854),
    [anon_sym_object] = ACTIONS(1854),
    [anon_sym_abstract] = ACTIONS(1854),
    [anon_sym_interface] = ACTIONS(1854),
    [anon_sym_enum] = ACTIONS(1854),
    [sym_html_comment] = ACTIONS(5),
  },
  [888] = {
    [ts_builtin_sym_end] = ACTIONS(2791),
    [sym_identifier] = ACTIONS(2793),
    [anon_sym_export] = ACTIONS(2793),
    [anon_sym_default] = ACTIONS(2793),
    [anon_sym_type] = ACTIONS(2793),
    [anon_sym_namespace] = ACTIONS(2793),
    [anon_sym_LBRACE] = ACTIONS(2791),
    [anon_sym_RBRACE] = ACTIONS(2791),
    [anon_sym_typeof] = ACTIONS(2793),
    [anon_sym_import] = ACTIONS(2793),
    [anon_sym_with] = ACTIONS(2793),
    [anon_sym_var] = ACTIONS(2793),
    [anon_sym_let] = ACTIONS(2793),
    [anon_sym_const] = ACTIONS(2793),
    [anon_sym_BANG] = ACTIONS(2791),
    [anon_sym_else] = ACTIONS(2793),
    [anon_sym_if] = ACTIONS(2793),
    [anon_sym_switch] = ACTIONS(2793),
    [anon_sym_for] = ACTIONS(2793),
    [anon_sym_LPAREN] = ACTIONS(2791),
    [anon_sym_SEMI] = ACTIONS(2791),
    [anon_sym_await] = ACTIONS(2793),
    [anon_sym_while] = ACTIONS(2793),
    [anon_sym_do] = ACTIONS(2793),
    [anon_sym_try] = ACTIONS(2793),
    [anon_sym_break] = ACTIONS(2793),
    [anon_sym_continue] = ACTIONS(2793),
    [anon_sym_debugger] = ACTIONS(2793),
    [anon_sym_return] = ACTIONS(2793),
    [anon_sym_throw] = ACTIONS(2793),
    [anon_sym_case] = ACTIONS(2793),
    [anon_sym_yield] = ACTIONS(2793),
    [anon_sym_LBRACK] = ACTIONS(2791),
    [anon_sym_class] = ACTIONS(2793),
    [anon_sym_async] = ACTIONS(2793),
    [anon_sym_function] = ACTIONS(2793),
    [anon_sym_new] = ACTIONS(2793),
    [anon_sym_using] = ACTIONS(2793),
    [anon_sym_PLUS] = ACTIONS(2793),
    [anon_sym_DASH] = ACTIONS(2793),
    [anon_sym_SLASH] = ACTIONS(2793),
    [anon_sym_LT] = ACTIONS(2791),
    [anon_sym_TILDE] = ACTIONS(2791),
    [anon_sym_void] = ACTIONS(2793),
    [anon_sym_delete] = ACTIONS(2793),
    [anon_sym_PLUS_PLUS] = ACTIONS(2791),
    [anon_sym_DASH_DASH] = ACTIONS(2791),
    [anon_sym_DQUOTE] = ACTIONS(2791),
    [anon_sym_SQUOTE] = ACTIONS(2791),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(2791),
    [sym_number] = ACTIONS(2791),
    [sym_private_property_identifier] = ACTIONS(2791),
    [sym_this] = ACTIONS(2793),
    [sym_super] = ACTIONS(2793),
    [sym_true] = ACTIONS(2793),
    [sym_false] = ACTIONS(2793),
    [sym_null] = ACTIONS(2793),
    [sym_undefined] = ACTIONS(2793),
    [anon_sym_AT] = ACTIONS(2791),
    [anon_sym_static] = ACTIONS(2793),
    [anon_sym_readonly] = ACTIONS(2793),
    [anon_sym_get] = ACTIONS(2793),
    [anon_sym_set] = ACTIONS(2793),
    [anon_sym_declare] = ACTIONS(2793),
    [anon_sym_public] = ACTIONS(2793),
    [anon_sym_private] = ACTIONS(2793),
    [anon_sym_protected] = ACTIONS(2793),
    [anon_sym_override] = ACTIONS(2793),
    [anon_sym_module] = ACTIONS(2793),
    [anon_sym_any] = ACTIONS(2793),
    [anon_sym_number] = ACTIONS(2793),
    [anon_sym_boolean] = ACTIONS(2793),
    [anon_sym_string] = ACTIONS(2793),
    [anon_sym_symbol] = ACTIONS(2793),
    [anon_sym_object] = ACTIONS(2793),
    [anon_sym_abstract] = ACTIONS(2793),
    [anon_sym_interface] = ACTIONS(2793),
    [anon_sym_enum] = ACTIONS(2793),
    [sym_html_comment] = ACTIONS(5),
  },
  [889] = {
    [sym_import] = STATE(4681),
    [sym_nested_identifier] = STATE(5474),
    [sym_string] = STATE(2994),
    [sym_formal_parameters] = STATE(5619),
    [sym_rest_pattern] = STATE(5165),
    [sym_nested_type_identifier] = STATE(2939),
    [sym__type_query_member_expression_in_type_annotation] = STATE(3303),
    [sym__type_query_call_expression_in_type_annotation] = STATE(2938),
    [sym_type] = STATE(3773),
    [sym_tuple_parameter] = STATE(5278),
    [sym_optional_tuple_parameter] = STATE(5278),
    [sym_optional_type] = STATE(5278),
    [sym_rest_type] = STATE(5278),
    [sym__tuple_type_member] = STATE(5278),
    [sym_constructor_type] = STATE(3007),
    [sym_primary_type] = STATE(2981),
    [sym_template_literal_type] = STATE(3039),
    [sym_infer_type] = STATE(3007),
    [sym_conditional_type] = STATE(3039),
    [sym_generic_type] = STATE(3039),
    [sym_type_query] = STATE(3039),
    [sym_index_type_query] = STATE(3039),
    [sym_lookup_type] = STATE(3039),
    [sym_literal_type] = STATE(3039),
    [sym__number] = STATE(3041),
    [sym_existential_type] = STATE(3039),
    [sym_flow_maybe_type] = STATE(3039),
    [sym_parenthesized_type] = STATE(3039),
    [sym_predefined_type] = STATE(3039),
    [sym_object_type] = STATE(3039),
    [sym_type_parameters] = STATE(5454),
    [sym_array_type] = STATE(3039),
    [sym_tuple_type] = STATE(3039),
    [sym_readonly_type] = STATE(3007),
    [sym_union_type] = STATE(3039),
    [sym_intersection_type] = STATE(3039),
    [sym_function_type] = STATE(3007),
    [sym_identifier] = ACTIONS(2489),
    [anon_sym_STAR] = ACTIONS(543),
    [anon_sym_LBRACE] = ACTIONS(1534),
    [anon_sym_typeof] = ACTIONS(1536),
    [anon_sym_import] = ACTIONS(1538),
    [anon_sym_const] = ACTIONS(133),
    [anon_sym_LPAREN] = ACTIONS(1540),
    [anon_sym_LBRACK] = ACTIONS(1542),
    [anon_sym_RBRACK] = ACTIONS(2795),
    [anon_sym_new] = ACTIONS(1642),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(2495),
    [anon_sym_AMP] = ACTIONS(571),
    [anon_sym_PIPE] = ACTIONS(573),
    [anon_sym_PLUS] = ACTIONS(2497),
    [anon_sym_DASH] = ACTIONS(2497),
    [anon_sym_LT] = ACTIONS(2499),
    [anon_sym_void] = ACTIONS(216),
    [anon_sym_DQUOTE] = ACTIONS(1550),
    [anon_sym_SQUOTE] = ACTIONS(1552),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1554),
    [sym_number] = ACTIONS(1556),
    [sym_this] = ACTIONS(1558),
    [sym_true] = ACTIONS(1560),
    [sym_false] = ACTIONS(1560),
    [sym_null] = ACTIONS(1560),
    [sym_undefined] = ACTIONS(1560),
    [anon_sym_readonly] = ACTIONS(1648),
    [anon_sym_QMARK] = ACTIONS(593),
    [anon_sym_any] = ACTIONS(216),
    [anon_sym_number] = ACTIONS(216),
    [anon_sym_boolean] = ACTIONS(216),
    [anon_sym_string] = ACTIONS(216),
    [anon_sym_symbol] = ACTIONS(216),
    [anon_sym_object] = ACTIONS(216),
    [anon_sym_abstract] = ACTIONS(597),
    [anon_sym_infer] = ACTIONS(599),
    [anon_sym_keyof] = ACTIONS(601),
    [anon_sym_unique] = ACTIONS(214),
    [anon_sym_unknown] = ACTIONS(216),
    [anon_sym_never] = ACTIONS(216),
    [anon_sym_LBRACE_PIPE] = ACTIONS(218),
    [sym_html_comment] = ACTIONS(5),
  },
  [890] = {
    [ts_builtin_sym_end] = ACTIONS(2797),
    [sym_identifier] = ACTIONS(2799),
    [anon_sym_export] = ACTIONS(2799),
    [anon_sym_default] = ACTIONS(2799),
    [anon_sym_type] = ACTIONS(2799),
    [anon_sym_namespace] = ACTIONS(2799),
    [anon_sym_LBRACE] = ACTIONS(2797),
    [anon_sym_RBRACE] = ACTIONS(2797),
    [anon_sym_typeof] = ACTIONS(2799),
    [anon_sym_import] = ACTIONS(2799),
    [anon_sym_with] = ACTIONS(2799),
    [anon_sym_var] = ACTIONS(2799),
    [anon_sym_let] = ACTIONS(2799),
    [anon_sym_const] = ACTIONS(2799),
    [anon_sym_BANG] = ACTIONS(2797),
    [anon_sym_else] = ACTIONS(2799),
    [anon_sym_if] = ACTIONS(2799),
    [anon_sym_switch] = ACTIONS(2799),
    [anon_sym_for] = ACTIONS(2799),
    [anon_sym_LPAREN] = ACTIONS(2797),
    [anon_sym_SEMI] = ACTIONS(2797),
    [anon_sym_await] = ACTIONS(2799),
    [anon_sym_while] = ACTIONS(2799),
    [anon_sym_do] = ACTIONS(2799),
    [anon_sym_try] = ACTIONS(2799),
    [anon_sym_break] = ACTIONS(2799),
    [anon_sym_continue] = ACTIONS(2799),
    [anon_sym_debugger] = ACTIONS(2799),
    [anon_sym_return] = ACTIONS(2799),
    [anon_sym_throw] = ACTIONS(2799),
    [anon_sym_case] = ACTIONS(2799),
    [anon_sym_yield] = ACTIONS(2799),
    [anon_sym_LBRACK] = ACTIONS(2797),
    [anon_sym_class] = ACTIONS(2799),
    [anon_sym_async] = ACTIONS(2799),
    [anon_sym_function] = ACTIONS(2799),
    [anon_sym_new] = ACTIONS(2799),
    [anon_sym_using] = ACTIONS(2799),
    [anon_sym_PLUS] = ACTIONS(2799),
    [anon_sym_DASH] = ACTIONS(2799),
    [anon_sym_SLASH] = ACTIONS(2799),
    [anon_sym_LT] = ACTIONS(2797),
    [anon_sym_TILDE] = ACTIONS(2797),
    [anon_sym_void] = ACTIONS(2799),
    [anon_sym_delete] = ACTIONS(2799),
    [anon_sym_PLUS_PLUS] = ACTIONS(2797),
    [anon_sym_DASH_DASH] = ACTIONS(2797),
    [anon_sym_DQUOTE] = ACTIONS(2797),
    [anon_sym_SQUOTE] = ACTIONS(2797),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(2797),
    [sym_number] = ACTIONS(2797),
    [sym_private_property_identifier] = ACTIONS(2797),
    [sym_this] = ACTIONS(2799),
    [sym_super] = ACTIONS(2799),
    [sym_true] = ACTIONS(2799),
    [sym_false] = ACTIONS(2799),
    [sym_null] = ACTIONS(2799),
    [sym_undefined] = ACTIONS(2799),
    [anon_sym_AT] = ACTIONS(2797),
    [anon_sym_static] = ACTIONS(2799),
    [anon_sym_readonly] = ACTIONS(2799),
    [anon_sym_get] = ACTIONS(2799),
    [anon_sym_set] = ACTIONS(2799),
    [anon_sym_declare] = ACTIONS(2799),
    [anon_sym_public] = ACTIONS(2799),
    [anon_sym_private] = ACTIONS(2799),
    [anon_sym_protected] = ACTIONS(2799),
    [anon_sym_override] = ACTIONS(2799),
    [anon_sym_module] = ACTIONS(2799),
    [anon_sym_any] = ACTIONS(2799),
    [anon_sym_number] = ACTIONS(2799),
    [anon_sym_boolean] = ACTIONS(2799),
    [anon_sym_string] = ACTIONS(2799),
    [anon_sym_symbol] = ACTIONS(2799),
    [anon_sym_object] = ACTIONS(2799),
    [anon_sym_abstract] = ACTIONS(2799),
    [anon_sym_interface] = ACTIONS(2799),
    [anon_sym_enum] = ACTIONS(2799),
    [sym_html_comment] = ACTIONS(5),
  },
  [891] = {
    [ts_builtin_sym_end] = ACTIONS(2801),
    [sym_identifier] = ACTIONS(2803),
    [anon_sym_export] = ACTIONS(2803),
    [anon_sym_default] = ACTIONS(2803),
    [anon_sym_type] = ACTIONS(2803),
    [anon_sym_namespace] = ACTIONS(2803),
    [anon_sym_LBRACE] = ACTIONS(2801),
    [anon_sym_RBRACE] = ACTIONS(2801),
    [anon_sym_typeof] = ACTIONS(2803),
    [anon_sym_import] = ACTIONS(2803),
    [anon_sym_with] = ACTIONS(2803),
    [anon_sym_var] = ACTIONS(2803),
    [anon_sym_let] = ACTIONS(2803),
    [anon_sym_const] = ACTIONS(2803),
    [anon_sym_BANG] = ACTIONS(2801),
    [anon_sym_else] = ACTIONS(2803),
    [anon_sym_if] = ACTIONS(2803),
    [anon_sym_switch] = ACTIONS(2803),
    [anon_sym_for] = ACTIONS(2803),
    [anon_sym_LPAREN] = ACTIONS(2801),
    [anon_sym_SEMI] = ACTIONS(2801),
    [anon_sym_await] = ACTIONS(2803),
    [anon_sym_while] = ACTIONS(2803),
    [anon_sym_do] = ACTIONS(2803),
    [anon_sym_try] = ACTIONS(2803),
    [anon_sym_break] = ACTIONS(2803),
    [anon_sym_continue] = ACTIONS(2803),
    [anon_sym_debugger] = ACTIONS(2803),
    [anon_sym_return] = ACTIONS(2803),
    [anon_sym_throw] = ACTIONS(2803),
    [anon_sym_case] = ACTIONS(2803),
    [anon_sym_yield] = ACTIONS(2803),
    [anon_sym_LBRACK] = ACTIONS(2801),
    [anon_sym_class] = ACTIONS(2803),
    [anon_sym_async] = ACTIONS(2803),
    [anon_sym_function] = ACTIONS(2803),
    [anon_sym_new] = ACTIONS(2803),
    [anon_sym_using] = ACTIONS(2803),
    [anon_sym_PLUS] = ACTIONS(2803),
    [anon_sym_DASH] = ACTIONS(2803),
    [anon_sym_SLASH] = ACTIONS(2803),
    [anon_sym_LT] = ACTIONS(2801),
    [anon_sym_TILDE] = ACTIONS(2801),
    [anon_sym_void] = ACTIONS(2803),
    [anon_sym_delete] = ACTIONS(2803),
    [anon_sym_PLUS_PLUS] = ACTIONS(2801),
    [anon_sym_DASH_DASH] = ACTIONS(2801),
    [anon_sym_DQUOTE] = ACTIONS(2801),
    [anon_sym_SQUOTE] = ACTIONS(2801),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(2801),
    [sym_number] = ACTIONS(2801),
    [sym_private_property_identifier] = ACTIONS(2801),
    [sym_this] = ACTIONS(2803),
    [sym_super] = ACTIONS(2803),
    [sym_true] = ACTIONS(2803),
    [sym_false] = ACTIONS(2803),
    [sym_null] = ACTIONS(2803),
    [sym_undefined] = ACTIONS(2803),
    [anon_sym_AT] = ACTIONS(2801),
    [anon_sym_static] = ACTIONS(2803),
    [anon_sym_readonly] = ACTIONS(2803),
    [anon_sym_get] = ACTIONS(2803),
    [anon_sym_set] = ACTIONS(2803),
    [anon_sym_declare] = ACTIONS(2803),
    [anon_sym_public] = ACTIONS(2803),
    [anon_sym_private] = ACTIONS(2803),
    [anon_sym_protected] = ACTIONS(2803),
    [anon_sym_override] = ACTIONS(2803),
    [anon_sym_module] = ACTIONS(2803),
    [anon_sym_any] = ACTIONS(2803),
    [anon_sym_number] = ACTIONS(2803),
    [anon_sym_boolean] = ACTIONS(2803),
    [anon_sym_string] = ACTIONS(2803),
    [anon_sym_symbol] = ACTIONS(2803),
    [anon_sym_object] = ACTIONS(2803),
    [anon_sym_abstract] = ACTIONS(2803),
    [anon_sym_interface] = ACTIONS(2803),
    [anon_sym_enum] = ACTIONS(2803),
    [sym_html_comment] = ACTIONS(5),
  },
  [892] = {
    [ts_builtin_sym_end] = ACTIONS(2805),
    [sym_identifier] = ACTIONS(2807),
    [anon_sym_export] = ACTIONS(2807),
    [anon_sym_default] = ACTIONS(2807),
    [anon_sym_type] = ACTIONS(2807),
    [anon_sym_namespace] = ACTIONS(2807),
    [anon_sym_LBRACE] = ACTIONS(2805),
    [anon_sym_RBRACE] = ACTIONS(2805),
    [anon_sym_typeof] = ACTIONS(2807),
    [anon_sym_import] = ACTIONS(2807),
    [anon_sym_with] = ACTIONS(2807),
    [anon_sym_var] = ACTIONS(2807),
    [anon_sym_let] = ACTIONS(2807),
    [anon_sym_const] = ACTIONS(2807),
    [anon_sym_BANG] = ACTIONS(2805),
    [anon_sym_else] = ACTIONS(2807),
    [anon_sym_if] = ACTIONS(2807),
    [anon_sym_switch] = ACTIONS(2807),
    [anon_sym_for] = ACTIONS(2807),
    [anon_sym_LPAREN] = ACTIONS(2805),
    [anon_sym_SEMI] = ACTIONS(2805),
    [anon_sym_await] = ACTIONS(2807),
    [anon_sym_while] = ACTIONS(2807),
    [anon_sym_do] = ACTIONS(2807),
    [anon_sym_try] = ACTIONS(2807),
    [anon_sym_break] = ACTIONS(2807),
    [anon_sym_continue] = ACTIONS(2807),
    [anon_sym_debugger] = ACTIONS(2807),
    [anon_sym_return] = ACTIONS(2807),
    [anon_sym_throw] = ACTIONS(2807),
    [anon_sym_case] = ACTIONS(2807),
    [anon_sym_yield] = ACTIONS(2807),
    [anon_sym_LBRACK] = ACTIONS(2805),
    [anon_sym_class] = ACTIONS(2807),
    [anon_sym_async] = ACTIONS(2807),
    [anon_sym_function] = ACTIONS(2807),
    [anon_sym_new] = ACTIONS(2807),
    [anon_sym_using] = ACTIONS(2807),
    [anon_sym_PLUS] = ACTIONS(2807),
    [anon_sym_DASH] = ACTIONS(2807),
    [anon_sym_SLASH] = ACTIONS(2807),
    [anon_sym_LT] = ACTIONS(2805),
    [anon_sym_TILDE] = ACTIONS(2805),
    [anon_sym_void] = ACTIONS(2807),
    [anon_sym_delete] = ACTIONS(2807),
    [anon_sym_PLUS_PLUS] = ACTIONS(2805),
    [anon_sym_DASH_DASH] = ACTIONS(2805),
    [anon_sym_DQUOTE] = ACTIONS(2805),
    [anon_sym_SQUOTE] = ACTIONS(2805),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(2805),
    [sym_number] = ACTIONS(2805),
    [sym_private_property_identifier] = ACTIONS(2805),
    [sym_this] = ACTIONS(2807),
    [sym_super] = ACTIONS(2807),
    [sym_true] = ACTIONS(2807),
    [sym_false] = ACTIONS(2807),
    [sym_null] = ACTIONS(2807),
    [sym_undefined] = ACTIONS(2807),
    [anon_sym_AT] = ACTIONS(2805),
    [anon_sym_static] = ACTIONS(2807),
    [anon_sym_readonly] = ACTIONS(2807),
    [anon_sym_get] = ACTIONS(2807),
    [anon_sym_set] = ACTIONS(2807),
    [anon_sym_declare] = ACTIONS(2807),
    [anon_sym_public] = ACTIONS(2807),
    [anon_sym_private] = ACTIONS(2807),
    [anon_sym_protected] = ACTIONS(2807),
    [anon_sym_override] = ACTIONS(2807),
    [anon_sym_module] = ACTIONS(2807),
    [anon_sym_any] = ACTIONS(2807),
    [anon_sym_number] = ACTIONS(2807),
    [anon_sym_boolean] = ACTIONS(2807),
    [anon_sym_string] = ACTIONS(2807),
    [anon_sym_symbol] = ACTIONS(2807),
    [anon_sym_object] = ACTIONS(2807),
    [anon_sym_abstract] = ACTIONS(2807),
    [anon_sym_interface] = ACTIONS(2807),
    [anon_sym_enum] = ACTIONS(2807),
    [sym_html_comment] = ACTIONS(5),
  },
  [893] = {
    [ts_builtin_sym_end] = ACTIONS(2809),
    [sym_identifier] = ACTIONS(2811),
    [anon_sym_export] = ACTIONS(2811),
    [anon_sym_default] = ACTIONS(2811),
    [anon_sym_type] = ACTIONS(2811),
    [anon_sym_namespace] = ACTIONS(2811),
    [anon_sym_LBRACE] = ACTIONS(2809),
    [anon_sym_RBRACE] = ACTIONS(2809),
    [anon_sym_typeof] = ACTIONS(2811),
    [anon_sym_import] = ACTIONS(2811),
    [anon_sym_with] = ACTIONS(2811),
    [anon_sym_var] = ACTIONS(2811),
    [anon_sym_let] = ACTIONS(2811),
    [anon_sym_const] = ACTIONS(2811),
    [anon_sym_BANG] = ACTIONS(2809),
    [anon_sym_else] = ACTIONS(2811),
    [anon_sym_if] = ACTIONS(2811),
    [anon_sym_switch] = ACTIONS(2811),
    [anon_sym_for] = ACTIONS(2811),
    [anon_sym_LPAREN] = ACTIONS(2809),
    [anon_sym_SEMI] = ACTIONS(2809),
    [anon_sym_await] = ACTIONS(2811),
    [anon_sym_while] = ACTIONS(2811),
    [anon_sym_do] = ACTIONS(2811),
    [anon_sym_try] = ACTIONS(2811),
    [anon_sym_break] = ACTIONS(2811),
    [anon_sym_continue] = ACTIONS(2811),
    [anon_sym_debugger] = ACTIONS(2811),
    [anon_sym_return] = ACTIONS(2811),
    [anon_sym_throw] = ACTIONS(2811),
    [anon_sym_case] = ACTIONS(2811),
    [anon_sym_yield] = ACTIONS(2811),
    [anon_sym_LBRACK] = ACTIONS(2809),
    [anon_sym_class] = ACTIONS(2811),
    [anon_sym_async] = ACTIONS(2811),
    [anon_sym_function] = ACTIONS(2811),
    [anon_sym_new] = ACTIONS(2811),
    [anon_sym_using] = ACTIONS(2811),
    [anon_sym_PLUS] = ACTIONS(2811),
    [anon_sym_DASH] = ACTIONS(2811),
    [anon_sym_SLASH] = ACTIONS(2811),
    [anon_sym_LT] = ACTIONS(2809),
    [anon_sym_TILDE] = ACTIONS(2809),
    [anon_sym_void] = ACTIONS(2811),
    [anon_sym_delete] = ACTIONS(2811),
    [anon_sym_PLUS_PLUS] = ACTIONS(2809),
    [anon_sym_DASH_DASH] = ACTIONS(2809),
    [anon_sym_DQUOTE] = ACTIONS(2809),
    [anon_sym_SQUOTE] = ACTIONS(2809),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(2809),
    [sym_number] = ACTIONS(2809),
    [sym_private_property_identifier] = ACTIONS(2809),
    [sym_this] = ACTIONS(2811),
    [sym_super] = ACTIONS(2811),
    [sym_true] = ACTIONS(2811),
    [sym_false] = ACTIONS(2811),
    [sym_null] = ACTIONS(2811),
    [sym_undefined] = ACTIONS(2811),
    [anon_sym_AT] = ACTIONS(2809),
    [anon_sym_static] = ACTIONS(2811),
    [anon_sym_readonly] = ACTIONS(2811),
    [anon_sym_get] = ACTIONS(2811),
    [anon_sym_set] = ACTIONS(2811),
    [anon_sym_declare] = ACTIONS(2811),
    [anon_sym_public] = ACTIONS(2811),
    [anon_sym_private] = ACTIONS(2811),
    [anon_sym_protected] = ACTIONS(2811),
    [anon_sym_override] = ACTIONS(2811),
    [anon_sym_module] = ACTIONS(2811),
    [anon_sym_any] = ACTIONS(2811),
    [anon_sym_number] = ACTIONS(2811),
    [anon_sym_boolean] = ACTIONS(2811),
    [anon_sym_string] = ACTIONS(2811),
    [anon_sym_symbol] = ACTIONS(2811),
    [anon_sym_object] = ACTIONS(2811),
    [anon_sym_abstract] = ACTIONS(2811),
    [anon_sym_interface] = ACTIONS(2811),
    [anon_sym_enum] = ACTIONS(2811),
    [sym_html_comment] = ACTIONS(5),
  },
  [894] = {
    [ts_builtin_sym_end] = ACTIONS(2813),
    [sym_identifier] = ACTIONS(2815),
    [anon_sym_export] = ACTIONS(2815),
    [anon_sym_default] = ACTIONS(2815),
    [anon_sym_type] = ACTIONS(2815),
    [anon_sym_namespace] = ACTIONS(2815),
    [anon_sym_LBRACE] = ACTIONS(2813),
    [anon_sym_RBRACE] = ACTIONS(2813),
    [anon_sym_typeof] = ACTIONS(2815),
    [anon_sym_import] = ACTIONS(2815),
    [anon_sym_with] = ACTIONS(2815),
    [anon_sym_var] = ACTIONS(2815),
    [anon_sym_let] = ACTIONS(2815),
    [anon_sym_const] = ACTIONS(2815),
    [anon_sym_BANG] = ACTIONS(2813),
    [anon_sym_else] = ACTIONS(2815),
    [anon_sym_if] = ACTIONS(2815),
    [anon_sym_switch] = ACTIONS(2815),
    [anon_sym_for] = ACTIONS(2815),
    [anon_sym_LPAREN] = ACTIONS(2813),
    [anon_sym_SEMI] = ACTIONS(2813),
    [anon_sym_await] = ACTIONS(2815),
    [anon_sym_while] = ACTIONS(2815),
    [anon_sym_do] = ACTIONS(2815),
    [anon_sym_try] = ACTIONS(2815),
    [anon_sym_break] = ACTIONS(2815),
    [anon_sym_continue] = ACTIONS(2815),
    [anon_sym_debugger] = ACTIONS(2815),
    [anon_sym_return] = ACTIONS(2815),
    [anon_sym_throw] = ACTIONS(2815),
    [anon_sym_case] = ACTIONS(2815),
    [anon_sym_yield] = ACTIONS(2815),
    [anon_sym_LBRACK] = ACTIONS(2813),
    [anon_sym_class] = ACTIONS(2815),
    [anon_sym_async] = ACTIONS(2815),
    [anon_sym_function] = ACTIONS(2815),
    [anon_sym_new] = ACTIONS(2815),
    [anon_sym_using] = ACTIONS(2815),
    [anon_sym_PLUS] = ACTIONS(2815),
    [anon_sym_DASH] = ACTIONS(2815),
    [anon_sym_SLASH] = ACTIONS(2815),
    [anon_sym_LT] = ACTIONS(2813),
    [anon_sym_TILDE] = ACTIONS(2813),
    [anon_sym_void] = ACTIONS(2815),
    [anon_sym_delete] = ACTIONS(2815),
    [anon_sym_PLUS_PLUS] = ACTIONS(2813),
    [anon_sym_DASH_DASH] = ACTIONS(2813),
    [anon_sym_DQUOTE] = ACTIONS(2813),
    [anon_sym_SQUOTE] = ACTIONS(2813),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(2813),
    [sym_number] = ACTIONS(2813),
    [sym_private_property_identifier] = ACTIONS(2813),
    [sym_this] = ACTIONS(2815),
    [sym_super] = ACTIONS(2815),
    [sym_true] = ACTIONS(2815),
    [sym_false] = ACTIONS(2815),
    [sym_null] = ACTIONS(2815),
    [sym_undefined] = ACTIONS(2815),
    [anon_sym_AT] = ACTIONS(2813),
    [anon_sym_static] = ACTIONS(2815),
    [anon_sym_readonly] = ACTIONS(2815),
    [anon_sym_get] = ACTIONS(2815),
    [anon_sym_set] = ACTIONS(2815),
    [anon_sym_declare] = ACTIONS(2815),
    [anon_sym_public] = ACTIONS(2815),
    [anon_sym_private] = ACTIONS(2815),
    [anon_sym_protected] = ACTIONS(2815),
    [anon_sym_override] = ACTIONS(2815),
    [anon_sym_module] = ACTIONS(2815),
    [anon_sym_any] = ACTIONS(2815),
    [anon_sym_number] = ACTIONS(2815),
    [anon_sym_boolean] = ACTIONS(2815),
    [anon_sym_string] = ACTIONS(2815),
    [anon_sym_symbol] = ACTIONS(2815),
    [anon_sym_object] = ACTIONS(2815),
    [anon_sym_abstract] = ACTIONS(2815),
    [anon_sym_interface] = ACTIONS(2815),
    [anon_sym_enum] = ACTIONS(2815),
    [sym_html_comment] = ACTIONS(5),
  },
  [895] = {
    [ts_builtin_sym_end] = ACTIONS(2817),
    [sym_identifier] = ACTIONS(2819),
    [anon_sym_export] = ACTIONS(2819),
    [anon_sym_default] = ACTIONS(2819),
    [anon_sym_type] = ACTIONS(2819),
    [anon_sym_namespace] = ACTIONS(2819),
    [anon_sym_LBRACE] = ACTIONS(2817),
    [anon_sym_RBRACE] = ACTIONS(2817),
    [anon_sym_typeof] = ACTIONS(2819),
    [anon_sym_import] = ACTIONS(2819),
    [anon_sym_with] = ACTIONS(2819),
    [anon_sym_var] = ACTIONS(2819),
    [anon_sym_let] = ACTIONS(2819),
    [anon_sym_const] = ACTIONS(2819),
    [anon_sym_BANG] = ACTIONS(2817),
    [anon_sym_else] = ACTIONS(2819),
    [anon_sym_if] = ACTIONS(2819),
    [anon_sym_switch] = ACTIONS(2819),
    [anon_sym_for] = ACTIONS(2819),
    [anon_sym_LPAREN] = ACTIONS(2817),
    [anon_sym_SEMI] = ACTIONS(2817),
    [anon_sym_await] = ACTIONS(2819),
    [anon_sym_while] = ACTIONS(2819),
    [anon_sym_do] = ACTIONS(2819),
    [anon_sym_try] = ACTIONS(2819),
    [anon_sym_break] = ACTIONS(2819),
    [anon_sym_continue] = ACTIONS(2819),
    [anon_sym_debugger] = ACTIONS(2819),
    [anon_sym_return] = ACTIONS(2819),
    [anon_sym_throw] = ACTIONS(2819),
    [anon_sym_case] = ACTIONS(2819),
    [anon_sym_yield] = ACTIONS(2819),
    [anon_sym_LBRACK] = ACTIONS(2817),
    [anon_sym_class] = ACTIONS(2819),
    [anon_sym_async] = ACTIONS(2819),
    [anon_sym_function] = ACTIONS(2819),
    [anon_sym_new] = ACTIONS(2819),
    [anon_sym_using] = ACTIONS(2819),
    [anon_sym_PLUS] = ACTIONS(2819),
    [anon_sym_DASH] = ACTIONS(2819),
    [anon_sym_SLASH] = ACTIONS(2819),
    [anon_sym_LT] = ACTIONS(2817),
    [anon_sym_TILDE] = ACTIONS(2817),
    [anon_sym_void] = ACTIONS(2819),
    [anon_sym_delete] = ACTIONS(2819),
    [anon_sym_PLUS_PLUS] = ACTIONS(2817),
    [anon_sym_DASH_DASH] = ACTIONS(2817),
    [anon_sym_DQUOTE] = ACTIONS(2817),
    [anon_sym_SQUOTE] = ACTIONS(2817),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(2817),
    [sym_number] = ACTIONS(2817),
    [sym_private_property_identifier] = ACTIONS(2817),
    [sym_this] = ACTIONS(2819),
    [sym_super] = ACTIONS(2819),
    [sym_true] = ACTIONS(2819),
    [sym_false] = ACTIONS(2819),
    [sym_null] = ACTIONS(2819),
    [sym_undefined] = ACTIONS(2819),
    [anon_sym_AT] = ACTIONS(2817),
    [anon_sym_static] = ACTIONS(2819),
    [anon_sym_readonly] = ACTIONS(2819),
    [anon_sym_get] = ACTIONS(2819),
    [anon_sym_set] = ACTIONS(2819),
    [anon_sym_declare] = ACTIONS(2819),
    [anon_sym_public] = ACTIONS(2819),
    [anon_sym_private] = ACTIONS(2819),
    [anon_sym_protected] = ACTIONS(2819),
    [anon_sym_override] = ACTIONS(2819),
    [anon_sym_module] = ACTIONS(2819),
    [anon_sym_any] = ACTIONS(2819),
    [anon_sym_number] = ACTIONS(2819),
    [anon_sym_boolean] = ACTIONS(2819),
    [anon_sym_string] = ACTIONS(2819),
    [anon_sym_symbol] = ACTIONS(2819),
    [anon_sym_object] = ACTIONS(2819),
    [anon_sym_abstract] = ACTIONS(2819),
    [anon_sym_interface] = ACTIONS(2819),
    [anon_sym_enum] = ACTIONS(2819),
    [sym_html_comment] = ACTIONS(5),
  },
  [896] = {
    [ts_builtin_sym_end] = ACTIONS(2809),
    [sym_identifier] = ACTIONS(2811),
    [anon_sym_export] = ACTIONS(2811),
    [anon_sym_default] = ACTIONS(2811),
    [anon_sym_type] = ACTIONS(2811),
    [anon_sym_namespace] = ACTIONS(2811),
    [anon_sym_LBRACE] = ACTIONS(2809),
    [anon_sym_RBRACE] = ACTIONS(2809),
    [anon_sym_typeof] = ACTIONS(2811),
    [anon_sym_import] = ACTIONS(2811),
    [anon_sym_with] = ACTIONS(2811),
    [anon_sym_var] = ACTIONS(2811),
    [anon_sym_let] = ACTIONS(2811),
    [anon_sym_const] = ACTIONS(2811),
    [anon_sym_BANG] = ACTIONS(2809),
    [anon_sym_else] = ACTIONS(2811),
    [anon_sym_if] = ACTIONS(2811),
    [anon_sym_switch] = ACTIONS(2811),
    [anon_sym_for] = ACTIONS(2811),
    [anon_sym_LPAREN] = ACTIONS(2809),
    [anon_sym_SEMI] = ACTIONS(2809),
    [anon_sym_await] = ACTIONS(2811),
    [anon_sym_while] = ACTIONS(2811),
    [anon_sym_do] = ACTIONS(2811),
    [anon_sym_try] = ACTIONS(2811),
    [anon_sym_break] = ACTIONS(2811),
    [anon_sym_continue] = ACTIONS(2811),
    [anon_sym_debugger] = ACTIONS(2811),
    [anon_sym_return] = ACTIONS(2811),
    [anon_sym_throw] = ACTIONS(2811),
    [anon_sym_case] = ACTIONS(2811),
    [anon_sym_yield] = ACTIONS(2811),
    [anon_sym_LBRACK] = ACTIONS(2809),
    [anon_sym_class] = ACTIONS(2811),
    [anon_sym_async] = ACTIONS(2811),
    [anon_sym_function] = ACTIONS(2811),
    [anon_sym_new] = ACTIONS(2811),
    [anon_sym_using] = ACTIONS(2811),
    [anon_sym_PLUS] = ACTIONS(2811),
    [anon_sym_DASH] = ACTIONS(2811),
    [anon_sym_SLASH] = ACTIONS(2811),
    [anon_sym_LT] = ACTIONS(2809),
    [anon_sym_TILDE] = ACTIONS(2809),
    [anon_sym_void] = ACTIONS(2811),
    [anon_sym_delete] = ACTIONS(2811),
    [anon_sym_PLUS_PLUS] = ACTIONS(2809),
    [anon_sym_DASH_DASH] = ACTIONS(2809),
    [anon_sym_DQUOTE] = ACTIONS(2809),
    [anon_sym_SQUOTE] = ACTIONS(2809),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(2809),
    [sym_number] = ACTIONS(2809),
    [sym_private_property_identifier] = ACTIONS(2809),
    [sym_this] = ACTIONS(2811),
    [sym_super] = ACTIONS(2811),
    [sym_true] = ACTIONS(2811),
    [sym_false] = ACTIONS(2811),
    [sym_null] = ACTIONS(2811),
    [sym_undefined] = ACTIONS(2811),
    [anon_sym_AT] = ACTIONS(2809),
    [anon_sym_static] = ACTIONS(2811),
    [anon_sym_readonly] = ACTIONS(2811),
    [anon_sym_get] = ACTIONS(2811),
    [anon_sym_set] = ACTIONS(2811),
    [anon_sym_declare] = ACTIONS(2811),
    [anon_sym_public] = ACTIONS(2811),
    [anon_sym_private] = ACTIONS(2811),
    [anon_sym_protected] = ACTIONS(2811),
    [anon_sym_override] = ACTIONS(2811),
    [anon_sym_module] = ACTIONS(2811),
    [anon_sym_any] = ACTIONS(2811),
    [anon_sym_number] = ACTIONS(2811),
    [anon_sym_boolean] = ACTIONS(2811),
    [anon_sym_string] = ACTIONS(2811),
    [anon_sym_symbol] = ACTIONS(2811),
    [anon_sym_object] = ACTIONS(2811),
    [anon_sym_abstract] = ACTIONS(2811),
    [anon_sym_interface] = ACTIONS(2811),
    [anon_sym_enum] = ACTIONS(2811),
    [sym_html_comment] = ACTIONS(5),
  },
  [897] = {
    [ts_builtin_sym_end] = ACTIONS(2821),
    [sym_identifier] = ACTIONS(2823),
    [anon_sym_export] = ACTIONS(2823),
    [anon_sym_default] = ACTIONS(2823),
    [anon_sym_type] = ACTIONS(2823),
    [anon_sym_namespace] = ACTIONS(2823),
    [anon_sym_LBRACE] = ACTIONS(2821),
    [anon_sym_RBRACE] = ACTIONS(2821),
    [anon_sym_typeof] = ACTIONS(2823),
    [anon_sym_import] = ACTIONS(2823),
    [anon_sym_with] = ACTIONS(2823),
    [anon_sym_var] = ACTIONS(2823),
    [anon_sym_let] = ACTIONS(2823),
    [anon_sym_const] = ACTIONS(2823),
    [anon_sym_BANG] = ACTIONS(2821),
    [anon_sym_else] = ACTIONS(2823),
    [anon_sym_if] = ACTIONS(2823),
    [anon_sym_switch] = ACTIONS(2823),
    [anon_sym_for] = ACTIONS(2823),
    [anon_sym_LPAREN] = ACTIONS(2821),
    [anon_sym_SEMI] = ACTIONS(2821),
    [anon_sym_await] = ACTIONS(2823),
    [anon_sym_while] = ACTIONS(2823),
    [anon_sym_do] = ACTIONS(2823),
    [anon_sym_try] = ACTIONS(2823),
    [anon_sym_break] = ACTIONS(2823),
    [anon_sym_continue] = ACTIONS(2823),
    [anon_sym_debugger] = ACTIONS(2823),
    [anon_sym_return] = ACTIONS(2823),
    [anon_sym_throw] = ACTIONS(2823),
    [anon_sym_case] = ACTIONS(2823),
    [anon_sym_yield] = ACTIONS(2823),
    [anon_sym_LBRACK] = ACTIONS(2821),
    [anon_sym_class] = ACTIONS(2823),
    [anon_sym_async] = ACTIONS(2823),
    [anon_sym_function] = ACTIONS(2823),
    [anon_sym_new] = ACTIONS(2823),
    [anon_sym_using] = ACTIONS(2823),
    [anon_sym_PLUS] = ACTIONS(2823),
    [anon_sym_DASH] = ACTIONS(2823),
    [anon_sym_SLASH] = ACTIONS(2823),
    [anon_sym_LT] = ACTIONS(2821),
    [anon_sym_TILDE] = ACTIONS(2821),
    [anon_sym_void] = ACTIONS(2823),
    [anon_sym_delete] = ACTIONS(2823),
    [anon_sym_PLUS_PLUS] = ACTIONS(2821),
    [anon_sym_DASH_DASH] = ACTIONS(2821),
    [anon_sym_DQUOTE] = ACTIONS(2821),
    [anon_sym_SQUOTE] = ACTIONS(2821),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(2821),
    [sym_number] = ACTIONS(2821),
    [sym_private_property_identifier] = ACTIONS(2821),
    [sym_this] = ACTIONS(2823),
    [sym_super] = ACTIONS(2823),
    [sym_true] = ACTIONS(2823),
    [sym_false] = ACTIONS(2823),
    [sym_null] = ACTIONS(2823),
    [sym_undefined] = ACTIONS(2823),
    [anon_sym_AT] = ACTIONS(2821),
    [anon_sym_static] = ACTIONS(2823),
    [anon_sym_readonly] = ACTIONS(2823),
    [anon_sym_get] = ACTIONS(2823),
    [anon_sym_set] = ACTIONS(2823),
    [anon_sym_declare] = ACTIONS(2823),
    [anon_sym_public] = ACTIONS(2823),
    [anon_sym_private] = ACTIONS(2823),
    [anon_sym_protected] = ACTIONS(2823),
    [anon_sym_override] = ACTIONS(2823),
    [anon_sym_module] = ACTIONS(2823),
    [anon_sym_any] = ACTIONS(2823),
    [anon_sym_number] = ACTIONS(2823),
    [anon_sym_boolean] = ACTIONS(2823),
    [anon_sym_string] = ACTIONS(2823),
    [anon_sym_symbol] = ACTIONS(2823),
    [anon_sym_object] = ACTIONS(2823),
    [anon_sym_abstract] = ACTIONS(2823),
    [anon_sym_interface] = ACTIONS(2823),
    [anon_sym_enum] = ACTIONS(2823),
    [sym_html_comment] = ACTIONS(5),
  },
  [898] = {
    [ts_builtin_sym_end] = ACTIONS(2825),
    [sym_identifier] = ACTIONS(2827),
    [anon_sym_export] = ACTIONS(2827),
    [anon_sym_default] = ACTIONS(2827),
    [anon_sym_type] = ACTIONS(2827),
    [anon_sym_namespace] = ACTIONS(2827),
    [anon_sym_LBRACE] = ACTIONS(2825),
    [anon_sym_RBRACE] = ACTIONS(2825),
    [anon_sym_typeof] = ACTIONS(2827),
    [anon_sym_import] = ACTIONS(2827),
    [anon_sym_with] = ACTIONS(2827),
    [anon_sym_var] = ACTIONS(2827),
    [anon_sym_let] = ACTIONS(2827),
    [anon_sym_const] = ACTIONS(2827),
    [anon_sym_BANG] = ACTIONS(2825),
    [anon_sym_else] = ACTIONS(2827),
    [anon_sym_if] = ACTIONS(2827),
    [anon_sym_switch] = ACTIONS(2827),
    [anon_sym_for] = ACTIONS(2827),
    [anon_sym_LPAREN] = ACTIONS(2825),
    [anon_sym_SEMI] = ACTIONS(2825),
    [anon_sym_await] = ACTIONS(2827),
    [anon_sym_while] = ACTIONS(2827),
    [anon_sym_do] = ACTIONS(2827),
    [anon_sym_try] = ACTIONS(2827),
    [anon_sym_break] = ACTIONS(2827),
    [anon_sym_continue] = ACTIONS(2827),
    [anon_sym_debugger] = ACTIONS(2827),
    [anon_sym_return] = ACTIONS(2827),
    [anon_sym_throw] = ACTIONS(2827),
    [anon_sym_case] = ACTIONS(2827),
    [anon_sym_yield] = ACTIONS(2827),
    [anon_sym_LBRACK] = ACTIONS(2825),
    [anon_sym_class] = ACTIONS(2827),
    [anon_sym_async] = ACTIONS(2827),
    [anon_sym_function] = ACTIONS(2827),
    [anon_sym_new] = ACTIONS(2827),
    [anon_sym_using] = ACTIONS(2827),
    [anon_sym_PLUS] = ACTIONS(2827),
    [anon_sym_DASH] = ACTIONS(2827),
    [anon_sym_SLASH] = ACTIONS(2827),
    [anon_sym_LT] = ACTIONS(2825),
    [anon_sym_TILDE] = ACTIONS(2825),
    [anon_sym_void] = ACTIONS(2827),
    [anon_sym_delete] = ACTIONS(2827),
    [anon_sym_PLUS_PLUS] = ACTIONS(2825),
    [anon_sym_DASH_DASH] = ACTIONS(2825),
    [anon_sym_DQUOTE] = ACTIONS(2825),
    [anon_sym_SQUOTE] = ACTIONS(2825),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(2825),
    [sym_number] = ACTIONS(2825),
    [sym_private_property_identifier] = ACTIONS(2825),
    [sym_this] = ACTIONS(2827),
    [sym_super] = ACTIONS(2827),
    [sym_true] = ACTIONS(2827),
    [sym_false] = ACTIONS(2827),
    [sym_null] = ACTIONS(2827),
    [sym_undefined] = ACTIONS(2827),
    [anon_sym_AT] = ACTIONS(2825),
    [anon_sym_static] = ACTIONS(2827),
    [anon_sym_readonly] = ACTIONS(2827),
    [anon_sym_get] = ACTIONS(2827),
    [anon_sym_set] = ACTIONS(2827),
    [anon_sym_declare] = ACTIONS(2827),
    [anon_sym_public] = ACTIONS(2827),
    [anon_sym_private] = ACTIONS(2827),
    [anon_sym_protected] = ACTIONS(2827),
    [anon_sym_override] = ACTIONS(2827),
    [anon_sym_module] = ACTIONS(2827),
    [anon_sym_any] = ACTIONS(2827),
    [anon_sym_number] = ACTIONS(2827),
    [anon_sym_boolean] = ACTIONS(2827),
    [anon_sym_string] = ACTIONS(2827),
    [anon_sym_symbol] = ACTIONS(2827),
    [anon_sym_object] = ACTIONS(2827),
    [anon_sym_abstract] = ACTIONS(2827),
    [anon_sym_interface] = ACTIONS(2827),
    [anon_sym_enum] = ACTIONS(2827),
    [sym_html_comment] = ACTIONS(5),
  },
  [899] = {
    [ts_builtin_sym_end] = ACTIONS(2829),
    [sym_identifier] = ACTIONS(2831),
    [anon_sym_export] = ACTIONS(2831),
    [anon_sym_default] = ACTIONS(2831),
    [anon_sym_type] = ACTIONS(2831),
    [anon_sym_namespace] = ACTIONS(2831),
    [anon_sym_LBRACE] = ACTIONS(2829),
    [anon_sym_RBRACE] = ACTIONS(2829),
    [anon_sym_typeof] = ACTIONS(2831),
    [anon_sym_import] = ACTIONS(2831),
    [anon_sym_with] = ACTIONS(2831),
    [anon_sym_var] = ACTIONS(2831),
    [anon_sym_let] = ACTIONS(2831),
    [anon_sym_const] = ACTIONS(2831),
    [anon_sym_BANG] = ACTIONS(2829),
    [anon_sym_else] = ACTIONS(2831),
    [anon_sym_if] = ACTIONS(2831),
    [anon_sym_switch] = ACTIONS(2831),
    [anon_sym_for] = ACTIONS(2831),
    [anon_sym_LPAREN] = ACTIONS(2829),
    [anon_sym_SEMI] = ACTIONS(2829),
    [anon_sym_await] = ACTIONS(2831),
    [anon_sym_while] = ACTIONS(2831),
    [anon_sym_do] = ACTIONS(2831),
    [anon_sym_try] = ACTIONS(2831),
    [anon_sym_break] = ACTIONS(2831),
    [anon_sym_continue] = ACTIONS(2831),
    [anon_sym_debugger] = ACTIONS(2831),
    [anon_sym_return] = ACTIONS(2831),
    [anon_sym_throw] = ACTIONS(2831),
    [anon_sym_case] = ACTIONS(2831),
    [anon_sym_yield] = ACTIONS(2831),
    [anon_sym_LBRACK] = ACTIONS(2829),
    [anon_sym_class] = ACTIONS(2831),
    [anon_sym_async] = ACTIONS(2831),
    [anon_sym_function] = ACTIONS(2831),
    [anon_sym_new] = ACTIONS(2831),
    [anon_sym_using] = ACTIONS(2831),
    [anon_sym_PLUS] = ACTIONS(2831),
    [anon_sym_DASH] = ACTIONS(2831),
    [anon_sym_SLASH] = ACTIONS(2831),
    [anon_sym_LT] = ACTIONS(2829),
    [anon_sym_TILDE] = ACTIONS(2829),
    [anon_sym_void] = ACTIONS(2831),
    [anon_sym_delete] = ACTIONS(2831),
    [anon_sym_PLUS_PLUS] = ACTIONS(2829),
    [anon_sym_DASH_DASH] = ACTIONS(2829),
    [anon_sym_DQUOTE] = ACTIONS(2829),
    [anon_sym_SQUOTE] = ACTIONS(2829),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(2829),
    [sym_number] = ACTIONS(2829),
    [sym_private_property_identifier] = ACTIONS(2829),
    [sym_this] = ACTIONS(2831),
    [sym_super] = ACTIONS(2831),
    [sym_true] = ACTIONS(2831),
    [sym_false] = ACTIONS(2831),
    [sym_null] = ACTIONS(2831),
    [sym_undefined] = ACTIONS(2831),
    [anon_sym_AT] = ACTIONS(2829),
    [anon_sym_static] = ACTIONS(2831),
    [anon_sym_readonly] = ACTIONS(2831),
    [anon_sym_get] = ACTIONS(2831),
    [anon_sym_set] = ACTIONS(2831),
    [anon_sym_declare] = ACTIONS(2831),
    [anon_sym_public] = ACTIONS(2831),
    [anon_sym_private] = ACTIONS(2831),
    [anon_sym_protected] = ACTIONS(2831),
    [anon_sym_override] = ACTIONS(2831),
    [anon_sym_module] = ACTIONS(2831),
    [anon_sym_any] = ACTIONS(2831),
    [anon_sym_number] = ACTIONS(2831),
    [anon_sym_boolean] = ACTIONS(2831),
    [anon_sym_string] = ACTIONS(2831),
    [anon_sym_symbol] = ACTIONS(2831),
    [anon_sym_object] = ACTIONS(2831),
    [anon_sym_abstract] = ACTIONS(2831),
    [anon_sym_interface] = ACTIONS(2831),
    [anon_sym_enum] = ACTIONS(2831),
    [sym_html_comment] = ACTIONS(5),
  },
  [900] = {
    [sym_import] = STATE(4681),
    [sym_nested_identifier] = STATE(5474),
    [sym_string] = STATE(2994),
    [sym_formal_parameters] = STATE(5619),
    [sym_rest_pattern] = STATE(5165),
    [sym_nested_type_identifier] = STATE(2939),
    [sym__type_query_member_expression_in_type_annotation] = STATE(3303),
    [sym__type_query_call_expression_in_type_annotation] = STATE(2938),
    [sym_type] = STATE(3773),
    [sym_tuple_parameter] = STATE(5278),
    [sym_optional_tuple_parameter] = STATE(5278),
    [sym_optional_type] = STATE(5278),
    [sym_rest_type] = STATE(5278),
    [sym__tuple_type_member] = STATE(5278),
    [sym_constructor_type] = STATE(3007),
    [sym_primary_type] = STATE(2981),
    [sym_template_literal_type] = STATE(3039),
    [sym_infer_type] = STATE(3007),
    [sym_conditional_type] = STATE(3039),
    [sym_generic_type] = STATE(3039),
    [sym_type_query] = STATE(3039),
    [sym_index_type_query] = STATE(3039),
    [sym_lookup_type] = STATE(3039),
    [sym_literal_type] = STATE(3039),
    [sym__number] = STATE(3041),
    [sym_existential_type] = STATE(3039),
    [sym_flow_maybe_type] = STATE(3039),
    [sym_parenthesized_type] = STATE(3039),
    [sym_predefined_type] = STATE(3039),
    [sym_object_type] = STATE(3039),
    [sym_type_parameters] = STATE(5454),
    [sym_array_type] = STATE(3039),
    [sym_tuple_type] = STATE(3039),
    [sym_readonly_type] = STATE(3007),
    [sym_union_type] = STATE(3039),
    [sym_intersection_type] = STATE(3039),
    [sym_function_type] = STATE(3007),
    [sym_identifier] = ACTIONS(2489),
    [anon_sym_STAR] = ACTIONS(543),
    [anon_sym_LBRACE] = ACTIONS(1534),
    [anon_sym_typeof] = ACTIONS(1536),
    [anon_sym_import] = ACTIONS(1538),
    [anon_sym_const] = ACTIONS(133),
    [anon_sym_LPAREN] = ACTIONS(1540),
    [anon_sym_LBRACK] = ACTIONS(1542),
    [anon_sym_RBRACK] = ACTIONS(2833),
    [anon_sym_new] = ACTIONS(1642),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(2495),
    [anon_sym_AMP] = ACTIONS(571),
    [anon_sym_PIPE] = ACTIONS(573),
    [anon_sym_PLUS] = ACTIONS(2497),
    [anon_sym_DASH] = ACTIONS(2497),
    [anon_sym_LT] = ACTIONS(2499),
    [anon_sym_void] = ACTIONS(216),
    [anon_sym_DQUOTE] = ACTIONS(1550),
    [anon_sym_SQUOTE] = ACTIONS(1552),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1554),
    [sym_number] = ACTIONS(1556),
    [sym_this] = ACTIONS(1558),
    [sym_true] = ACTIONS(1560),
    [sym_false] = ACTIONS(1560),
    [sym_null] = ACTIONS(1560),
    [sym_undefined] = ACTIONS(1560),
    [anon_sym_readonly] = ACTIONS(1648),
    [anon_sym_QMARK] = ACTIONS(593),
    [anon_sym_any] = ACTIONS(216),
    [anon_sym_number] = ACTIONS(216),
    [anon_sym_boolean] = ACTIONS(216),
    [anon_sym_string] = ACTIONS(216),
    [anon_sym_symbol] = ACTIONS(216),
    [anon_sym_object] = ACTIONS(216),
    [anon_sym_abstract] = ACTIONS(597),
    [anon_sym_infer] = ACTIONS(599),
    [anon_sym_keyof] = ACTIONS(601),
    [anon_sym_unique] = ACTIONS(214),
    [anon_sym_unknown] = ACTIONS(216),
    [anon_sym_never] = ACTIONS(216),
    [anon_sym_LBRACE_PIPE] = ACTIONS(218),
    [sym_html_comment] = ACTIONS(5),
  },
  [901] = {
    [ts_builtin_sym_end] = ACTIONS(2835),
    [sym_identifier] = ACTIONS(2837),
    [anon_sym_export] = ACTIONS(2837),
    [anon_sym_default] = ACTIONS(2837),
    [anon_sym_type] = ACTIONS(2837),
    [anon_sym_namespace] = ACTIONS(2837),
    [anon_sym_LBRACE] = ACTIONS(2835),
    [anon_sym_RBRACE] = ACTIONS(2835),
    [anon_sym_typeof] = ACTIONS(2837),
    [anon_sym_import] = ACTIONS(2837),
    [anon_sym_with] = ACTIONS(2837),
    [anon_sym_var] = ACTIONS(2837),
    [anon_sym_let] = ACTIONS(2837),
    [anon_sym_const] = ACTIONS(2837),
    [anon_sym_BANG] = ACTIONS(2835),
    [anon_sym_else] = ACTIONS(2837),
    [anon_sym_if] = ACTIONS(2837),
    [anon_sym_switch] = ACTIONS(2837),
    [anon_sym_for] = ACTIONS(2837),
    [anon_sym_LPAREN] = ACTIONS(2835),
    [anon_sym_SEMI] = ACTIONS(2835),
    [anon_sym_await] = ACTIONS(2837),
    [anon_sym_while] = ACTIONS(2837),
    [anon_sym_do] = ACTIONS(2837),
    [anon_sym_try] = ACTIONS(2837),
    [anon_sym_break] = ACTIONS(2837),
    [anon_sym_continue] = ACTIONS(2837),
    [anon_sym_debugger] = ACTIONS(2837),
    [anon_sym_return] = ACTIONS(2837),
    [anon_sym_throw] = ACTIONS(2837),
    [anon_sym_case] = ACTIONS(2837),
    [anon_sym_yield] = ACTIONS(2837),
    [anon_sym_LBRACK] = ACTIONS(2835),
    [anon_sym_class] = ACTIONS(2837),
    [anon_sym_async] = ACTIONS(2837),
    [anon_sym_function] = ACTIONS(2837),
    [anon_sym_new] = ACTIONS(2837),
    [anon_sym_using] = ACTIONS(2837),
    [anon_sym_PLUS] = ACTIONS(2837),
    [anon_sym_DASH] = ACTIONS(2837),
    [anon_sym_SLASH] = ACTIONS(2837),
    [anon_sym_LT] = ACTIONS(2835),
    [anon_sym_TILDE] = ACTIONS(2835),
    [anon_sym_void] = ACTIONS(2837),
    [anon_sym_delete] = ACTIONS(2837),
    [anon_sym_PLUS_PLUS] = ACTIONS(2835),
    [anon_sym_DASH_DASH] = ACTIONS(2835),
    [anon_sym_DQUOTE] = ACTIONS(2835),
    [anon_sym_SQUOTE] = ACTIONS(2835),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(2835),
    [sym_number] = ACTIONS(2835),
    [sym_private_property_identifier] = ACTIONS(2835),
    [sym_this] = ACTIONS(2837),
    [sym_super] = ACTIONS(2837),
    [sym_true] = ACTIONS(2837),
    [sym_false] = ACTIONS(2837),
    [sym_null] = ACTIONS(2837),
    [sym_undefined] = ACTIONS(2837),
    [anon_sym_AT] = ACTIONS(2835),
    [anon_sym_static] = ACTIONS(2837),
    [anon_sym_readonly] = ACTIONS(2837),
    [anon_sym_get] = ACTIONS(2837),
    [anon_sym_set] = ACTIONS(2837),
    [anon_sym_declare] = ACTIONS(2837),
    [anon_sym_public] = ACTIONS(2837),
    [anon_sym_private] = ACTIONS(2837),
    [anon_sym_protected] = ACTIONS(2837),
    [anon_sym_override] = ACTIONS(2837),
    [anon_sym_module] = ACTIONS(2837),
    [anon_sym_any] = ACTIONS(2837),
    [anon_sym_number] = ACTIONS(2837),
    [anon_sym_boolean] = ACTIONS(2837),
    [anon_sym_string] = ACTIONS(2837),
    [anon_sym_symbol] = ACTIONS(2837),
    [anon_sym_object] = ACTIONS(2837),
    [anon_sym_abstract] = ACTIONS(2837),
    [anon_sym_interface] = ACTIONS(2837),
    [anon_sym_enum] = ACTIONS(2837),
    [sym_html_comment] = ACTIONS(5),
  },
  [902] = {
    [ts_builtin_sym_end] = ACTIONS(2839),
    [sym_identifier] = ACTIONS(2841),
    [anon_sym_export] = ACTIONS(2841),
    [anon_sym_default] = ACTIONS(2841),
    [anon_sym_type] = ACTIONS(2841),
    [anon_sym_namespace] = ACTIONS(2841),
    [anon_sym_LBRACE] = ACTIONS(2839),
    [anon_sym_RBRACE] = ACTIONS(2839),
    [anon_sym_typeof] = ACTIONS(2841),
    [anon_sym_import] = ACTIONS(2841),
    [anon_sym_with] = ACTIONS(2841),
    [anon_sym_var] = ACTIONS(2841),
    [anon_sym_let] = ACTIONS(2841),
    [anon_sym_const] = ACTIONS(2841),
    [anon_sym_BANG] = ACTIONS(2839),
    [anon_sym_else] = ACTIONS(2841),
    [anon_sym_if] = ACTIONS(2841),
    [anon_sym_switch] = ACTIONS(2841),
    [anon_sym_for] = ACTIONS(2841),
    [anon_sym_LPAREN] = ACTIONS(2839),
    [anon_sym_SEMI] = ACTIONS(2839),
    [anon_sym_await] = ACTIONS(2841),
    [anon_sym_while] = ACTIONS(2841),
    [anon_sym_do] = ACTIONS(2841),
    [anon_sym_try] = ACTIONS(2841),
    [anon_sym_break] = ACTIONS(2841),
    [anon_sym_continue] = ACTIONS(2841),
    [anon_sym_debugger] = ACTIONS(2841),
    [anon_sym_return] = ACTIONS(2841),
    [anon_sym_throw] = ACTIONS(2841),
    [anon_sym_case] = ACTIONS(2841),
    [anon_sym_yield] = ACTIONS(2841),
    [anon_sym_LBRACK] = ACTIONS(2839),
    [anon_sym_class] = ACTIONS(2841),
    [anon_sym_async] = ACTIONS(2841),
    [anon_sym_function] = ACTIONS(2841),
    [anon_sym_new] = ACTIONS(2841),
    [anon_sym_using] = ACTIONS(2841),
    [anon_sym_PLUS] = ACTIONS(2841),
    [anon_sym_DASH] = ACTIONS(2841),
    [anon_sym_SLASH] = ACTIONS(2841),
    [anon_sym_LT] = ACTIONS(2839),
    [anon_sym_TILDE] = ACTIONS(2839),
    [anon_sym_void] = ACTIONS(2841),
    [anon_sym_delete] = ACTIONS(2841),
    [anon_sym_PLUS_PLUS] = ACTIONS(2839),
    [anon_sym_DASH_DASH] = ACTIONS(2839),
    [anon_sym_DQUOTE] = ACTIONS(2839),
    [anon_sym_SQUOTE] = ACTIONS(2839),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(2839),
    [sym_number] = ACTIONS(2839),
    [sym_private_property_identifier] = ACTIONS(2839),
    [sym_this] = ACTIONS(2841),
    [sym_super] = ACTIONS(2841),
    [sym_true] = ACTIONS(2841),
    [sym_false] = ACTIONS(2841),
    [sym_null] = ACTIONS(2841),
    [sym_undefined] = ACTIONS(2841),
    [anon_sym_AT] = ACTIONS(2839),
    [anon_sym_static] = ACTIONS(2841),
    [anon_sym_readonly] = ACTIONS(2841),
    [anon_sym_get] = ACTIONS(2841),
    [anon_sym_set] = ACTIONS(2841),
    [anon_sym_declare] = ACTIONS(2841),
    [anon_sym_public] = ACTIONS(2841),
    [anon_sym_private] = ACTIONS(2841),
    [anon_sym_protected] = ACTIONS(2841),
    [anon_sym_override] = ACTIONS(2841),
    [anon_sym_module] = ACTIONS(2841),
    [anon_sym_any] = ACTIONS(2841),
    [anon_sym_number] = ACTIONS(2841),
    [anon_sym_boolean] = ACTIONS(2841),
    [anon_sym_string] = ACTIONS(2841),
    [anon_sym_symbol] = ACTIONS(2841),
    [anon_sym_object] = ACTIONS(2841),
    [anon_sym_abstract] = ACTIONS(2841),
    [anon_sym_interface] = ACTIONS(2841),
    [anon_sym_enum] = ACTIONS(2841),
    [sym_html_comment] = ACTIONS(5),
  },
  [903] = {
    [ts_builtin_sym_end] = ACTIONS(2839),
    [sym_identifier] = ACTIONS(2841),
    [anon_sym_export] = ACTIONS(2841),
    [anon_sym_default] = ACTIONS(2841),
    [anon_sym_type] = ACTIONS(2841),
    [anon_sym_namespace] = ACTIONS(2841),
    [anon_sym_LBRACE] = ACTIONS(2839),
    [anon_sym_RBRACE] = ACTIONS(2839),
    [anon_sym_typeof] = ACTIONS(2841),
    [anon_sym_import] = ACTIONS(2841),
    [anon_sym_with] = ACTIONS(2841),
    [anon_sym_var] = ACTIONS(2841),
    [anon_sym_let] = ACTIONS(2841),
    [anon_sym_const] = ACTIONS(2841),
    [anon_sym_BANG] = ACTIONS(2839),
    [anon_sym_else] = ACTIONS(2841),
    [anon_sym_if] = ACTIONS(2841),
    [anon_sym_switch] = ACTIONS(2841),
    [anon_sym_for] = ACTIONS(2841),
    [anon_sym_LPAREN] = ACTIONS(2839),
    [anon_sym_SEMI] = ACTIONS(2839),
    [anon_sym_await] = ACTIONS(2841),
    [anon_sym_while] = ACTIONS(2841),
    [anon_sym_do] = ACTIONS(2841),
    [anon_sym_try] = ACTIONS(2841),
    [anon_sym_break] = ACTIONS(2841),
    [anon_sym_continue] = ACTIONS(2841),
    [anon_sym_debugger] = ACTIONS(2841),
    [anon_sym_return] = ACTIONS(2841),
    [anon_sym_throw] = ACTIONS(2841),
    [anon_sym_case] = ACTIONS(2841),
    [anon_sym_yield] = ACTIONS(2841),
    [anon_sym_LBRACK] = ACTIONS(2839),
    [anon_sym_class] = ACTIONS(2841),
    [anon_sym_async] = ACTIONS(2841),
    [anon_sym_function] = ACTIONS(2841),
    [anon_sym_new] = ACTIONS(2841),
    [anon_sym_using] = ACTIONS(2841),
    [anon_sym_PLUS] = ACTIONS(2841),
    [anon_sym_DASH] = ACTIONS(2841),
    [anon_sym_SLASH] = ACTIONS(2841),
    [anon_sym_LT] = ACTIONS(2839),
    [anon_sym_TILDE] = ACTIONS(2839),
    [anon_sym_void] = ACTIONS(2841),
    [anon_sym_delete] = ACTIONS(2841),
    [anon_sym_PLUS_PLUS] = ACTIONS(2839),
    [anon_sym_DASH_DASH] = ACTIONS(2839),
    [anon_sym_DQUOTE] = ACTIONS(2839),
    [anon_sym_SQUOTE] = ACTIONS(2839),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(2839),
    [sym_number] = ACTIONS(2839),
    [sym_private_property_identifier] = ACTIONS(2839),
    [sym_this] = ACTIONS(2841),
    [sym_super] = ACTIONS(2841),
    [sym_true] = ACTIONS(2841),
    [sym_false] = ACTIONS(2841),
    [sym_null] = ACTIONS(2841),
    [sym_undefined] = ACTIONS(2841),
    [anon_sym_AT] = ACTIONS(2839),
    [anon_sym_static] = ACTIONS(2841),
    [anon_sym_readonly] = ACTIONS(2841),
    [anon_sym_get] = ACTIONS(2841),
    [anon_sym_set] = ACTIONS(2841),
    [anon_sym_declare] = ACTIONS(2841),
    [anon_sym_public] = ACTIONS(2841),
    [anon_sym_private] = ACTIONS(2841),
    [anon_sym_protected] = ACTIONS(2841),
    [anon_sym_override] = ACTIONS(2841),
    [anon_sym_module] = ACTIONS(2841),
    [anon_sym_any] = ACTIONS(2841),
    [anon_sym_number] = ACTIONS(2841),
    [anon_sym_boolean] = ACTIONS(2841),
    [anon_sym_string] = ACTIONS(2841),
    [anon_sym_symbol] = ACTIONS(2841),
    [anon_sym_object] = ACTIONS(2841),
    [anon_sym_abstract] = ACTIONS(2841),
    [anon_sym_interface] = ACTIONS(2841),
    [anon_sym_enum] = ACTIONS(2841),
    [sym_html_comment] = ACTIONS(5),
  },
  [904] = {
    [ts_builtin_sym_end] = ACTIONS(2839),
    [sym_identifier] = ACTIONS(2841),
    [anon_sym_export] = ACTIONS(2841),
    [anon_sym_default] = ACTIONS(2841),
    [anon_sym_type] = ACTIONS(2841),
    [anon_sym_namespace] = ACTIONS(2841),
    [anon_sym_LBRACE] = ACTIONS(2839),
    [anon_sym_RBRACE] = ACTIONS(2839),
    [anon_sym_typeof] = ACTIONS(2841),
    [anon_sym_import] = ACTIONS(2841),
    [anon_sym_with] = ACTIONS(2841),
    [anon_sym_var] = ACTIONS(2841),
    [anon_sym_let] = ACTIONS(2841),
    [anon_sym_const] = ACTIONS(2841),
    [anon_sym_BANG] = ACTIONS(2839),
    [anon_sym_else] = ACTIONS(2841),
    [anon_sym_if] = ACTIONS(2841),
    [anon_sym_switch] = ACTIONS(2841),
    [anon_sym_for] = ACTIONS(2841),
    [anon_sym_LPAREN] = ACTIONS(2839),
    [anon_sym_SEMI] = ACTIONS(2839),
    [anon_sym_await] = ACTIONS(2841),
    [anon_sym_while] = ACTIONS(2841),
    [anon_sym_do] = ACTIONS(2841),
    [anon_sym_try] = ACTIONS(2841),
    [anon_sym_break] = ACTIONS(2841),
    [anon_sym_continue] = ACTIONS(2841),
    [anon_sym_debugger] = ACTIONS(2841),
    [anon_sym_return] = ACTIONS(2841),
    [anon_sym_throw] = ACTIONS(2841),
    [anon_sym_case] = ACTIONS(2841),
    [anon_sym_yield] = ACTIONS(2841),
    [anon_sym_LBRACK] = ACTIONS(2839),
    [anon_sym_class] = ACTIONS(2841),
    [anon_sym_async] = ACTIONS(2841),
    [anon_sym_function] = ACTIONS(2841),
    [anon_sym_new] = ACTIONS(2841),
    [anon_sym_using] = ACTIONS(2841),
    [anon_sym_PLUS] = ACTIONS(2841),
    [anon_sym_DASH] = ACTIONS(2841),
    [anon_sym_SLASH] = ACTIONS(2841),
    [anon_sym_LT] = ACTIONS(2839),
    [anon_sym_TILDE] = ACTIONS(2839),
    [anon_sym_void] = ACTIONS(2841),
    [anon_sym_delete] = ACTIONS(2841),
    [anon_sym_PLUS_PLUS] = ACTIONS(2839),
    [anon_sym_DASH_DASH] = ACTIONS(2839),
    [anon_sym_DQUOTE] = ACTIONS(2839),
    [anon_sym_SQUOTE] = ACTIONS(2839),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(2839),
    [sym_number] = ACTIONS(2839),
    [sym_private_property_identifier] = ACTIONS(2839),
    [sym_this] = ACTIONS(2841),
    [sym_super] = ACTIONS(2841),
    [sym_true] = ACTIONS(2841),
    [sym_false] = ACTIONS(2841),
    [sym_null] = ACTIONS(2841),
    [sym_undefined] = ACTIONS(2841),
    [anon_sym_AT] = ACTIONS(2839),
    [anon_sym_static] = ACTIONS(2841),
    [anon_sym_readonly] = ACTIONS(2841),
    [anon_sym_get] = ACTIONS(2841),
    [anon_sym_set] = ACTIONS(2841),
    [anon_sym_declare] = ACTIONS(2841),
    [anon_sym_public] = ACTIONS(2841),
    [anon_sym_private] = ACTIONS(2841),
    [anon_sym_protected] = ACTIONS(2841),
    [anon_sym_override] = ACTIONS(2841),
    [anon_sym_module] = ACTIONS(2841),
    [anon_sym_any] = ACTIONS(2841),
    [anon_sym_number] = ACTIONS(2841),
    [anon_sym_boolean] = ACTIONS(2841),
    [anon_sym_string] = ACTIONS(2841),
    [anon_sym_symbol] = ACTIONS(2841),
    [anon_sym_object] = ACTIONS(2841),
    [anon_sym_abstract] = ACTIONS(2841),
    [anon_sym_interface] = ACTIONS(2841),
    [anon_sym_enum] = ACTIONS(2841),
    [sym_html_comment] = ACTIONS(5),
  },
  [905] = {
    [ts_builtin_sym_end] = ACTIONS(2843),
    [sym_identifier] = ACTIONS(2845),
    [anon_sym_export] = ACTIONS(2845),
    [anon_sym_default] = ACTIONS(2845),
    [anon_sym_type] = ACTIONS(2845),
    [anon_sym_namespace] = ACTIONS(2845),
    [anon_sym_LBRACE] = ACTIONS(2843),
    [anon_sym_RBRACE] = ACTIONS(2843),
    [anon_sym_typeof] = ACTIONS(2845),
    [anon_sym_import] = ACTIONS(2845),
    [anon_sym_with] = ACTIONS(2845),
    [anon_sym_var] = ACTIONS(2845),
    [anon_sym_let] = ACTIONS(2845),
    [anon_sym_const] = ACTIONS(2845),
    [anon_sym_BANG] = ACTIONS(2843),
    [anon_sym_else] = ACTIONS(2845),
    [anon_sym_if] = ACTIONS(2845),
    [anon_sym_switch] = ACTIONS(2845),
    [anon_sym_for] = ACTIONS(2845),
    [anon_sym_LPAREN] = ACTIONS(2843),
    [anon_sym_SEMI] = ACTIONS(2843),
    [anon_sym_await] = ACTIONS(2845),
    [anon_sym_while] = ACTIONS(2845),
    [anon_sym_do] = ACTIONS(2845),
    [anon_sym_try] = ACTIONS(2845),
    [anon_sym_break] = ACTIONS(2845),
    [anon_sym_continue] = ACTIONS(2845),
    [anon_sym_debugger] = ACTIONS(2845),
    [anon_sym_return] = ACTIONS(2845),
    [anon_sym_throw] = ACTIONS(2845),
    [anon_sym_case] = ACTIONS(2845),
    [anon_sym_yield] = ACTIONS(2845),
    [anon_sym_LBRACK] = ACTIONS(2843),
    [anon_sym_class] = ACTIONS(2845),
    [anon_sym_async] = ACTIONS(2845),
    [anon_sym_function] = ACTIONS(2845),
    [anon_sym_new] = ACTIONS(2845),
    [anon_sym_using] = ACTIONS(2845),
    [anon_sym_PLUS] = ACTIONS(2845),
    [anon_sym_DASH] = ACTIONS(2845),
    [anon_sym_SLASH] = ACTIONS(2845),
    [anon_sym_LT] = ACTIONS(2843),
    [anon_sym_TILDE] = ACTIONS(2843),
    [anon_sym_void] = ACTIONS(2845),
    [anon_sym_delete] = ACTIONS(2845),
    [anon_sym_PLUS_PLUS] = ACTIONS(2843),
    [anon_sym_DASH_DASH] = ACTIONS(2843),
    [anon_sym_DQUOTE] = ACTIONS(2843),
    [anon_sym_SQUOTE] = ACTIONS(2843),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(2843),
    [sym_number] = ACTIONS(2843),
    [sym_private_property_identifier] = ACTIONS(2843),
    [sym_this] = ACTIONS(2845),
    [sym_super] = ACTIONS(2845),
    [sym_true] = ACTIONS(2845),
    [sym_false] = ACTIONS(2845),
    [sym_null] = ACTIONS(2845),
    [sym_undefined] = ACTIONS(2845),
    [anon_sym_AT] = ACTIONS(2843),
    [anon_sym_static] = ACTIONS(2845),
    [anon_sym_readonly] = ACTIONS(2845),
    [anon_sym_get] = ACTIONS(2845),
    [anon_sym_set] = ACTIONS(2845),
    [anon_sym_declare] = ACTIONS(2845),
    [anon_sym_public] = ACTIONS(2845),
    [anon_sym_private] = ACTIONS(2845),
    [anon_sym_protected] = ACTIONS(2845),
    [anon_sym_override] = ACTIONS(2845),
    [anon_sym_module] = ACTIONS(2845),
    [anon_sym_any] = ACTIONS(2845),
    [anon_sym_number] = ACTIONS(2845),
    [anon_sym_boolean] = ACTIONS(2845),
    [anon_sym_string] = ACTIONS(2845),
    [anon_sym_symbol] = ACTIONS(2845),
    [anon_sym_object] = ACTIONS(2845),
    [anon_sym_abstract] = ACTIONS(2845),
    [anon_sym_interface] = ACTIONS(2845),
    [anon_sym_enum] = ACTIONS(2845),
    [sym_html_comment] = ACTIONS(5),
  },
  [906] = {
    [sym_import] = STATE(4681),
    [sym_nested_identifier] = STATE(5474),
    [sym_string] = STATE(2994),
    [sym_formal_parameters] = STATE(5619),
    [sym_rest_pattern] = STATE(5165),
    [sym_nested_type_identifier] = STATE(2939),
    [sym__type_query_member_expression_in_type_annotation] = STATE(3303),
    [sym__type_query_call_expression_in_type_annotation] = STATE(2938),
    [sym_type] = STATE(3773),
    [sym_tuple_parameter] = STATE(5278),
    [sym_optional_tuple_parameter] = STATE(5278),
    [sym_optional_type] = STATE(5278),
    [sym_rest_type] = STATE(5278),
    [sym__tuple_type_member] = STATE(5278),
    [sym_constructor_type] = STATE(3007),
    [sym_primary_type] = STATE(2981),
    [sym_template_literal_type] = STATE(3039),
    [sym_infer_type] = STATE(3007),
    [sym_conditional_type] = STATE(3039),
    [sym_generic_type] = STATE(3039),
    [sym_type_query] = STATE(3039),
    [sym_index_type_query] = STATE(3039),
    [sym_lookup_type] = STATE(3039),
    [sym_literal_type] = STATE(3039),
    [sym__number] = STATE(3041),
    [sym_existential_type] = STATE(3039),
    [sym_flow_maybe_type] = STATE(3039),
    [sym_parenthesized_type] = STATE(3039),
    [sym_predefined_type] = STATE(3039),
    [sym_object_type] = STATE(3039),
    [sym_type_parameters] = STATE(5454),
    [sym_array_type] = STATE(3039),
    [sym_tuple_type] = STATE(3039),
    [sym_readonly_type] = STATE(3007),
    [sym_union_type] = STATE(3039),
    [sym_intersection_type] = STATE(3039),
    [sym_function_type] = STATE(3007),
    [sym_identifier] = ACTIONS(2489),
    [anon_sym_STAR] = ACTIONS(543),
    [anon_sym_LBRACE] = ACTIONS(1534),
    [anon_sym_typeof] = ACTIONS(1536),
    [anon_sym_import] = ACTIONS(1538),
    [anon_sym_const] = ACTIONS(133),
    [anon_sym_LPAREN] = ACTIONS(1540),
    [anon_sym_LBRACK] = ACTIONS(1542),
    [anon_sym_RBRACK] = ACTIONS(2847),
    [anon_sym_new] = ACTIONS(1642),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(2495),
    [anon_sym_AMP] = ACTIONS(571),
    [anon_sym_PIPE] = ACTIONS(573),
    [anon_sym_PLUS] = ACTIONS(2497),
    [anon_sym_DASH] = ACTIONS(2497),
    [anon_sym_LT] = ACTIONS(2499),
    [anon_sym_void] = ACTIONS(216),
    [anon_sym_DQUOTE] = ACTIONS(1550),
    [anon_sym_SQUOTE] = ACTIONS(1552),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1554),
    [sym_number] = ACTIONS(1556),
    [sym_this] = ACTIONS(1558),
    [sym_true] = ACTIONS(1560),
    [sym_false] = ACTIONS(1560),
    [sym_null] = ACTIONS(1560),
    [sym_undefined] = ACTIONS(1560),
    [anon_sym_readonly] = ACTIONS(1648),
    [anon_sym_QMARK] = ACTIONS(593),
    [anon_sym_any] = ACTIONS(216),
    [anon_sym_number] = ACTIONS(216),
    [anon_sym_boolean] = ACTIONS(216),
    [anon_sym_string] = ACTIONS(216),
    [anon_sym_symbol] = ACTIONS(216),
    [anon_sym_object] = ACTIONS(216),
    [anon_sym_abstract] = ACTIONS(597),
    [anon_sym_infer] = ACTIONS(599),
    [anon_sym_keyof] = ACTIONS(601),
    [anon_sym_unique] = ACTIONS(214),
    [anon_sym_unknown] = ACTIONS(216),
    [anon_sym_never] = ACTIONS(216),
    [anon_sym_LBRACE_PIPE] = ACTIONS(218),
    [sym_html_comment] = ACTIONS(5),
  },
  [907] = {
    [ts_builtin_sym_end] = ACTIONS(2849),
    [sym_identifier] = ACTIONS(2851),
    [anon_sym_export] = ACTIONS(2851),
    [anon_sym_default] = ACTIONS(2851),
    [anon_sym_type] = ACTIONS(2851),
    [anon_sym_namespace] = ACTIONS(2851),
    [anon_sym_LBRACE] = ACTIONS(2849),
    [anon_sym_RBRACE] = ACTIONS(2849),
    [anon_sym_typeof] = ACTIONS(2851),
    [anon_sym_import] = ACTIONS(2851),
    [anon_sym_with] = ACTIONS(2851),
    [anon_sym_var] = ACTIONS(2851),
    [anon_sym_let] = ACTIONS(2851),
    [anon_sym_const] = ACTIONS(2851),
    [anon_sym_BANG] = ACTIONS(2849),
    [anon_sym_else] = ACTIONS(2851),
    [anon_sym_if] = ACTIONS(2851),
    [anon_sym_switch] = ACTIONS(2851),
    [anon_sym_for] = ACTIONS(2851),
    [anon_sym_LPAREN] = ACTIONS(2849),
    [anon_sym_SEMI] = ACTIONS(2849),
    [anon_sym_await] = ACTIONS(2851),
    [anon_sym_while] = ACTIONS(2851),
    [anon_sym_do] = ACTIONS(2851),
    [anon_sym_try] = ACTIONS(2851),
    [anon_sym_break] = ACTIONS(2851),
    [anon_sym_continue] = ACTIONS(2851),
    [anon_sym_debugger] = ACTIONS(2851),
    [anon_sym_return] = ACTIONS(2851),
    [anon_sym_throw] = ACTIONS(2851),
    [anon_sym_case] = ACTIONS(2851),
    [anon_sym_yield] = ACTIONS(2851),
    [anon_sym_LBRACK] = ACTIONS(2849),
    [anon_sym_class] = ACTIONS(2851),
    [anon_sym_async] = ACTIONS(2851),
    [anon_sym_function] = ACTIONS(2851),
    [anon_sym_new] = ACTIONS(2851),
    [anon_sym_using] = ACTIONS(2851),
    [anon_sym_PLUS] = ACTIONS(2851),
    [anon_sym_DASH] = ACTIONS(2851),
    [anon_sym_SLASH] = ACTIONS(2851),
    [anon_sym_LT] = ACTIONS(2849),
    [anon_sym_TILDE] = ACTIONS(2849),
    [anon_sym_void] = ACTIONS(2851),
    [anon_sym_delete] = ACTIONS(2851),
    [anon_sym_PLUS_PLUS] = ACTIONS(2849),
    [anon_sym_DASH_DASH] = ACTIONS(2849),
    [anon_sym_DQUOTE] = ACTIONS(2849),
    [anon_sym_SQUOTE] = ACTIONS(2849),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(2849),
    [sym_number] = ACTIONS(2849),
    [sym_private_property_identifier] = ACTIONS(2849),
    [sym_this] = ACTIONS(2851),
    [sym_super] = ACTIONS(2851),
    [sym_true] = ACTIONS(2851),
    [sym_false] = ACTIONS(2851),
    [sym_null] = ACTIONS(2851),
    [sym_undefined] = ACTIONS(2851),
    [anon_sym_AT] = ACTIONS(2849),
    [anon_sym_static] = ACTIONS(2851),
    [anon_sym_readonly] = ACTIONS(2851),
    [anon_sym_get] = ACTIONS(2851),
    [anon_sym_set] = ACTIONS(2851),
    [anon_sym_declare] = ACTIONS(2851),
    [anon_sym_public] = ACTIONS(2851),
    [anon_sym_private] = ACTIONS(2851),
    [anon_sym_protected] = ACTIONS(2851),
    [anon_sym_override] = ACTIONS(2851),
    [anon_sym_module] = ACTIONS(2851),
    [anon_sym_any] = ACTIONS(2851),
    [anon_sym_number] = ACTIONS(2851),
    [anon_sym_boolean] = ACTIONS(2851),
    [anon_sym_string] = ACTIONS(2851),
    [anon_sym_symbol] = ACTIONS(2851),
    [anon_sym_object] = ACTIONS(2851),
    [anon_sym_abstract] = ACTIONS(2851),
    [anon_sym_interface] = ACTIONS(2851),
    [anon_sym_enum] = ACTIONS(2851),
    [sym_html_comment] = ACTIONS(5),
  },
  [908] = {
    [ts_builtin_sym_end] = ACTIONS(2853),
    [sym_identifier] = ACTIONS(2855),
    [anon_sym_export] = ACTIONS(2855),
    [anon_sym_default] = ACTIONS(2855),
    [anon_sym_type] = ACTIONS(2855),
    [anon_sym_namespace] = ACTIONS(2855),
    [anon_sym_LBRACE] = ACTIONS(2853),
    [anon_sym_RBRACE] = ACTIONS(2853),
    [anon_sym_typeof] = ACTIONS(2855),
    [anon_sym_import] = ACTIONS(2855),
    [anon_sym_with] = ACTIONS(2855),
    [anon_sym_var] = ACTIONS(2855),
    [anon_sym_let] = ACTIONS(2855),
    [anon_sym_const] = ACTIONS(2855),
    [anon_sym_BANG] = ACTIONS(2853),
    [anon_sym_else] = ACTIONS(2855),
    [anon_sym_if] = ACTIONS(2855),
    [anon_sym_switch] = ACTIONS(2855),
    [anon_sym_for] = ACTIONS(2855),
    [anon_sym_LPAREN] = ACTIONS(2853),
    [anon_sym_SEMI] = ACTIONS(2853),
    [anon_sym_await] = ACTIONS(2855),
    [anon_sym_while] = ACTIONS(2855),
    [anon_sym_do] = ACTIONS(2855),
    [anon_sym_try] = ACTIONS(2855),
    [anon_sym_break] = ACTIONS(2855),
    [anon_sym_continue] = ACTIONS(2855),
    [anon_sym_debugger] = ACTIONS(2855),
    [anon_sym_return] = ACTIONS(2855),
    [anon_sym_throw] = ACTIONS(2855),
    [anon_sym_case] = ACTIONS(2855),
    [anon_sym_yield] = ACTIONS(2855),
    [anon_sym_LBRACK] = ACTIONS(2853),
    [anon_sym_class] = ACTIONS(2855),
    [anon_sym_async] = ACTIONS(2855),
    [anon_sym_function] = ACTIONS(2855),
    [anon_sym_new] = ACTIONS(2855),
    [anon_sym_using] = ACTIONS(2855),
    [anon_sym_PLUS] = ACTIONS(2855),
    [anon_sym_DASH] = ACTIONS(2855),
    [anon_sym_SLASH] = ACTIONS(2855),
    [anon_sym_LT] = ACTIONS(2853),
    [anon_sym_TILDE] = ACTIONS(2853),
    [anon_sym_void] = ACTIONS(2855),
    [anon_sym_delete] = ACTIONS(2855),
    [anon_sym_PLUS_PLUS] = ACTIONS(2853),
    [anon_sym_DASH_DASH] = ACTIONS(2853),
    [anon_sym_DQUOTE] = ACTIONS(2853),
    [anon_sym_SQUOTE] = ACTIONS(2853),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(2853),
    [sym_number] = ACTIONS(2853),
    [sym_private_property_identifier] = ACTIONS(2853),
    [sym_this] = ACTIONS(2855),
    [sym_super] = ACTIONS(2855),
    [sym_true] = ACTIONS(2855),
    [sym_false] = ACTIONS(2855),
    [sym_null] = ACTIONS(2855),
    [sym_undefined] = ACTIONS(2855),
    [anon_sym_AT] = ACTIONS(2853),
    [anon_sym_static] = ACTIONS(2855),
    [anon_sym_readonly] = ACTIONS(2855),
    [anon_sym_get] = ACTIONS(2855),
    [anon_sym_set] = ACTIONS(2855),
    [anon_sym_declare] = ACTIONS(2855),
    [anon_sym_public] = ACTIONS(2855),
    [anon_sym_private] = ACTIONS(2855),
    [anon_sym_protected] = ACTIONS(2855),
    [anon_sym_override] = ACTIONS(2855),
    [anon_sym_module] = ACTIONS(2855),
    [anon_sym_any] = ACTIONS(2855),
    [anon_sym_number] = ACTIONS(2855),
    [anon_sym_boolean] = ACTIONS(2855),
    [anon_sym_string] = ACTIONS(2855),
    [anon_sym_symbol] = ACTIONS(2855),
    [anon_sym_object] = ACTIONS(2855),
    [anon_sym_abstract] = ACTIONS(2855),
    [anon_sym_interface] = ACTIONS(2855),
    [anon_sym_enum] = ACTIONS(2855),
    [sym_html_comment] = ACTIONS(5),
  },
  [909] = {
    [ts_builtin_sym_end] = ACTIONS(2857),
    [sym_identifier] = ACTIONS(2859),
    [anon_sym_export] = ACTIONS(2859),
    [anon_sym_default] = ACTIONS(2859),
    [anon_sym_type] = ACTIONS(2859),
    [anon_sym_namespace] = ACTIONS(2859),
    [anon_sym_LBRACE] = ACTIONS(2857),
    [anon_sym_RBRACE] = ACTIONS(2857),
    [anon_sym_typeof] = ACTIONS(2859),
    [anon_sym_import] = ACTIONS(2859),
    [anon_sym_with] = ACTIONS(2859),
    [anon_sym_var] = ACTIONS(2859),
    [anon_sym_let] = ACTIONS(2859),
    [anon_sym_const] = ACTIONS(2859),
    [anon_sym_BANG] = ACTIONS(2857),
    [anon_sym_else] = ACTIONS(2859),
    [anon_sym_if] = ACTIONS(2859),
    [anon_sym_switch] = ACTIONS(2859),
    [anon_sym_for] = ACTIONS(2859),
    [anon_sym_LPAREN] = ACTIONS(2857),
    [anon_sym_SEMI] = ACTIONS(2857),
    [anon_sym_await] = ACTIONS(2859),
    [anon_sym_while] = ACTIONS(2859),
    [anon_sym_do] = ACTIONS(2859),
    [anon_sym_try] = ACTIONS(2859),
    [anon_sym_break] = ACTIONS(2859),
    [anon_sym_continue] = ACTIONS(2859),
    [anon_sym_debugger] = ACTIONS(2859),
    [anon_sym_return] = ACTIONS(2859),
    [anon_sym_throw] = ACTIONS(2859),
    [anon_sym_case] = ACTIONS(2859),
    [anon_sym_yield] = ACTIONS(2859),
    [anon_sym_LBRACK] = ACTIONS(2857),
    [anon_sym_class] = ACTIONS(2859),
    [anon_sym_async] = ACTIONS(2859),
    [anon_sym_function] = ACTIONS(2859),
    [anon_sym_new] = ACTIONS(2859),
    [anon_sym_using] = ACTIONS(2859),
    [anon_sym_PLUS] = ACTIONS(2859),
    [anon_sym_DASH] = ACTIONS(2859),
    [anon_sym_SLASH] = ACTIONS(2859),
    [anon_sym_LT] = ACTIONS(2857),
    [anon_sym_TILDE] = ACTIONS(2857),
    [anon_sym_void] = ACTIONS(2859),
    [anon_sym_delete] = ACTIONS(2859),
    [anon_sym_PLUS_PLUS] = ACTIONS(2857),
    [anon_sym_DASH_DASH] = ACTIONS(2857),
    [anon_sym_DQUOTE] = ACTIONS(2857),
    [anon_sym_SQUOTE] = ACTIONS(2857),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(2857),
    [sym_number] = ACTIONS(2857),
    [sym_private_property_identifier] = ACTIONS(2857),
    [sym_this] = ACTIONS(2859),
    [sym_super] = ACTIONS(2859),
    [sym_true] = ACTIONS(2859),
    [sym_false] = ACTIONS(2859),
    [sym_null] = ACTIONS(2859),
    [sym_undefined] = ACTIONS(2859),
    [anon_sym_AT] = ACTIONS(2857),
    [anon_sym_static] = ACTIONS(2859),
    [anon_sym_readonly] = ACTIONS(2859),
    [anon_sym_get] = ACTIONS(2859),
    [anon_sym_set] = ACTIONS(2859),
    [anon_sym_declare] = ACTIONS(2859),
    [anon_sym_public] = ACTIONS(2859),
    [anon_sym_private] = ACTIONS(2859),
    [anon_sym_protected] = ACTIONS(2859),
    [anon_sym_override] = ACTIONS(2859),
    [anon_sym_module] = ACTIONS(2859),
    [anon_sym_any] = ACTIONS(2859),
    [anon_sym_number] = ACTIONS(2859),
    [anon_sym_boolean] = ACTIONS(2859),
    [anon_sym_string] = ACTIONS(2859),
    [anon_sym_symbol] = ACTIONS(2859),
    [anon_sym_object] = ACTIONS(2859),
    [anon_sym_abstract] = ACTIONS(2859),
    [anon_sym_interface] = ACTIONS(2859),
    [anon_sym_enum] = ACTIONS(2859),
    [sym_html_comment] = ACTIONS(5),
  },
  [910] = {
    [ts_builtin_sym_end] = ACTIONS(2861),
    [sym_identifier] = ACTIONS(2863),
    [anon_sym_export] = ACTIONS(2863),
    [anon_sym_default] = ACTIONS(2863),
    [anon_sym_type] = ACTIONS(2863),
    [anon_sym_namespace] = ACTIONS(2863),
    [anon_sym_LBRACE] = ACTIONS(2861),
    [anon_sym_RBRACE] = ACTIONS(2861),
    [anon_sym_typeof] = ACTIONS(2863),
    [anon_sym_import] = ACTIONS(2863),
    [anon_sym_with] = ACTIONS(2863),
    [anon_sym_var] = ACTIONS(2863),
    [anon_sym_let] = ACTIONS(2863),
    [anon_sym_const] = ACTIONS(2863),
    [anon_sym_BANG] = ACTIONS(2861),
    [anon_sym_else] = ACTIONS(2863),
    [anon_sym_if] = ACTIONS(2863),
    [anon_sym_switch] = ACTIONS(2863),
    [anon_sym_for] = ACTIONS(2863),
    [anon_sym_LPAREN] = ACTIONS(2861),
    [anon_sym_SEMI] = ACTIONS(2861),
    [anon_sym_await] = ACTIONS(2863),
    [anon_sym_while] = ACTIONS(2863),
    [anon_sym_do] = ACTIONS(2863),
    [anon_sym_try] = ACTIONS(2863),
    [anon_sym_break] = ACTIONS(2863),
    [anon_sym_continue] = ACTIONS(2863),
    [anon_sym_debugger] = ACTIONS(2863),
    [anon_sym_return] = ACTIONS(2863),
    [anon_sym_throw] = ACTIONS(2863),
    [anon_sym_case] = ACTIONS(2863),
    [anon_sym_yield] = ACTIONS(2863),
    [anon_sym_LBRACK] = ACTIONS(2861),
    [anon_sym_class] = ACTIONS(2863),
    [anon_sym_async] = ACTIONS(2863),
    [anon_sym_function] = ACTIONS(2863),
    [anon_sym_new] = ACTIONS(2863),
    [anon_sym_using] = ACTIONS(2863),
    [anon_sym_PLUS] = ACTIONS(2863),
    [anon_sym_DASH] = ACTIONS(2863),
    [anon_sym_SLASH] = ACTIONS(2863),
    [anon_sym_LT] = ACTIONS(2861),
    [anon_sym_TILDE] = ACTIONS(2861),
    [anon_sym_void] = ACTIONS(2863),
    [anon_sym_delete] = ACTIONS(2863),
    [anon_sym_PLUS_PLUS] = ACTIONS(2861),
    [anon_sym_DASH_DASH] = ACTIONS(2861),
    [anon_sym_DQUOTE] = ACTIONS(2861),
    [anon_sym_SQUOTE] = ACTIONS(2861),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(2861),
    [sym_number] = ACTIONS(2861),
    [sym_private_property_identifier] = ACTIONS(2861),
    [sym_this] = ACTIONS(2863),
    [sym_super] = ACTIONS(2863),
    [sym_true] = ACTIONS(2863),
    [sym_false] = ACTIONS(2863),
    [sym_null] = ACTIONS(2863),
    [sym_undefined] = ACTIONS(2863),
    [anon_sym_AT] = ACTIONS(2861),
    [anon_sym_static] = ACTIONS(2863),
    [anon_sym_readonly] = ACTIONS(2863),
    [anon_sym_get] = ACTIONS(2863),
    [anon_sym_set] = ACTIONS(2863),
    [anon_sym_declare] = ACTIONS(2863),
    [anon_sym_public] = ACTIONS(2863),
    [anon_sym_private] = ACTIONS(2863),
    [anon_sym_protected] = ACTIONS(2863),
    [anon_sym_override] = ACTIONS(2863),
    [anon_sym_module] = ACTIONS(2863),
    [anon_sym_any] = ACTIONS(2863),
    [anon_sym_number] = ACTIONS(2863),
    [anon_sym_boolean] = ACTIONS(2863),
    [anon_sym_string] = ACTIONS(2863),
    [anon_sym_symbol] = ACTIONS(2863),
    [anon_sym_object] = ACTIONS(2863),
    [anon_sym_abstract] = ACTIONS(2863),
    [anon_sym_interface] = ACTIONS(2863),
    [anon_sym_enum] = ACTIONS(2863),
    [sym_html_comment] = ACTIONS(5),
  },
  [911] = {
    [ts_builtin_sym_end] = ACTIONS(2865),
    [sym_identifier] = ACTIONS(2867),
    [anon_sym_export] = ACTIONS(2867),
    [anon_sym_default] = ACTIONS(2867),
    [anon_sym_type] = ACTIONS(2867),
    [anon_sym_namespace] = ACTIONS(2867),
    [anon_sym_LBRACE] = ACTIONS(2865),
    [anon_sym_RBRACE] = ACTIONS(2865),
    [anon_sym_typeof] = ACTIONS(2867),
    [anon_sym_import] = ACTIONS(2867),
    [anon_sym_with] = ACTIONS(2867),
    [anon_sym_var] = ACTIONS(2867),
    [anon_sym_let] = ACTIONS(2867),
    [anon_sym_const] = ACTIONS(2867),
    [anon_sym_BANG] = ACTIONS(2865),
    [anon_sym_else] = ACTIONS(2867),
    [anon_sym_if] = ACTIONS(2867),
    [anon_sym_switch] = ACTIONS(2867),
    [anon_sym_for] = ACTIONS(2867),
    [anon_sym_LPAREN] = ACTIONS(2865),
    [anon_sym_SEMI] = ACTIONS(2865),
    [anon_sym_await] = ACTIONS(2867),
    [anon_sym_while] = ACTIONS(2867),
    [anon_sym_do] = ACTIONS(2867),
    [anon_sym_try] = ACTIONS(2867),
    [anon_sym_break] = ACTIONS(2867),
    [anon_sym_continue] = ACTIONS(2867),
    [anon_sym_debugger] = ACTIONS(2867),
    [anon_sym_return] = ACTIONS(2867),
    [anon_sym_throw] = ACTIONS(2867),
    [anon_sym_case] = ACTIONS(2867),
    [anon_sym_yield] = ACTIONS(2867),
    [anon_sym_LBRACK] = ACTIONS(2865),
    [anon_sym_class] = ACTIONS(2867),
    [anon_sym_async] = ACTIONS(2867),
    [anon_sym_function] = ACTIONS(2867),
    [anon_sym_new] = ACTIONS(2867),
    [anon_sym_using] = ACTIONS(2867),
    [anon_sym_PLUS] = ACTIONS(2867),
    [anon_sym_DASH] = ACTIONS(2867),
    [anon_sym_SLASH] = ACTIONS(2867),
    [anon_sym_LT] = ACTIONS(2865),
    [anon_sym_TILDE] = ACTIONS(2865),
    [anon_sym_void] = ACTIONS(2867),
    [anon_sym_delete] = ACTIONS(2867),
    [anon_sym_PLUS_PLUS] = ACTIONS(2865),
    [anon_sym_DASH_DASH] = ACTIONS(2865),
    [anon_sym_DQUOTE] = ACTIONS(2865),
    [anon_sym_SQUOTE] = ACTIONS(2865),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(2865),
    [sym_number] = ACTIONS(2865),
    [sym_private_property_identifier] = ACTIONS(2865),
    [sym_this] = ACTIONS(2867),
    [sym_super] = ACTIONS(2867),
    [sym_true] = ACTIONS(2867),
    [sym_false] = ACTIONS(2867),
    [sym_null] = ACTIONS(2867),
    [sym_undefined] = ACTIONS(2867),
    [anon_sym_AT] = ACTIONS(2865),
    [anon_sym_static] = ACTIONS(2867),
    [anon_sym_readonly] = ACTIONS(2867),
    [anon_sym_get] = ACTIONS(2867),
    [anon_sym_set] = ACTIONS(2867),
    [anon_sym_declare] = ACTIONS(2867),
    [anon_sym_public] = ACTIONS(2867),
    [anon_sym_private] = ACTIONS(2867),
    [anon_sym_protected] = ACTIONS(2867),
    [anon_sym_override] = ACTIONS(2867),
    [anon_sym_module] = ACTIONS(2867),
    [anon_sym_any] = ACTIONS(2867),
    [anon_sym_number] = ACTIONS(2867),
    [anon_sym_boolean] = ACTIONS(2867),
    [anon_sym_string] = ACTIONS(2867),
    [anon_sym_symbol] = ACTIONS(2867),
    [anon_sym_object] = ACTIONS(2867),
    [anon_sym_abstract] = ACTIONS(2867),
    [anon_sym_interface] = ACTIONS(2867),
    [anon_sym_enum] = ACTIONS(2867),
    [sym_html_comment] = ACTIONS(5),
  },
  [912] = {
    [ts_builtin_sym_end] = ACTIONS(2869),
    [sym_identifier] = ACTIONS(2871),
    [anon_sym_export] = ACTIONS(2871),
    [anon_sym_default] = ACTIONS(2871),
    [anon_sym_type] = ACTIONS(2871),
    [anon_sym_namespace] = ACTIONS(2871),
    [anon_sym_LBRACE] = ACTIONS(2869),
    [anon_sym_RBRACE] = ACTIONS(2869),
    [anon_sym_typeof] = ACTIONS(2871),
    [anon_sym_import] = ACTIONS(2871),
    [anon_sym_with] = ACTIONS(2871),
    [anon_sym_var] = ACTIONS(2871),
    [anon_sym_let] = ACTIONS(2871),
    [anon_sym_const] = ACTIONS(2871),
    [anon_sym_BANG] = ACTIONS(2869),
    [anon_sym_else] = ACTIONS(2871),
    [anon_sym_if] = ACTIONS(2871),
    [anon_sym_switch] = ACTIONS(2871),
    [anon_sym_for] = ACTIONS(2871),
    [anon_sym_LPAREN] = ACTIONS(2869),
    [anon_sym_SEMI] = ACTIONS(2869),
    [anon_sym_await] = ACTIONS(2871),
    [anon_sym_while] = ACTIONS(2871),
    [anon_sym_do] = ACTIONS(2871),
    [anon_sym_try] = ACTIONS(2871),
    [anon_sym_break] = ACTIONS(2871),
    [anon_sym_continue] = ACTIONS(2871),
    [anon_sym_debugger] = ACTIONS(2871),
    [anon_sym_return] = ACTIONS(2871),
    [anon_sym_throw] = ACTIONS(2871),
    [anon_sym_case] = ACTIONS(2871),
    [anon_sym_yield] = ACTIONS(2871),
    [anon_sym_LBRACK] = ACTIONS(2869),
    [anon_sym_class] = ACTIONS(2871),
    [anon_sym_async] = ACTIONS(2871),
    [anon_sym_function] = ACTIONS(2871),
    [anon_sym_new] = ACTIONS(2871),
    [anon_sym_using] = ACTIONS(2871),
    [anon_sym_PLUS] = ACTIONS(2871),
    [anon_sym_DASH] = ACTIONS(2871),
    [anon_sym_SLASH] = ACTIONS(2871),
    [anon_sym_LT] = ACTIONS(2869),
    [anon_sym_TILDE] = ACTIONS(2869),
    [anon_sym_void] = ACTIONS(2871),
    [anon_sym_delete] = ACTIONS(2871),
    [anon_sym_PLUS_PLUS] = ACTIONS(2869),
    [anon_sym_DASH_DASH] = ACTIONS(2869),
    [anon_sym_DQUOTE] = ACTIONS(2869),
    [anon_sym_SQUOTE] = ACTIONS(2869),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(2869),
    [sym_number] = ACTIONS(2869),
    [sym_private_property_identifier] = ACTIONS(2869),
    [sym_this] = ACTIONS(2871),
    [sym_super] = ACTIONS(2871),
    [sym_true] = ACTIONS(2871),
    [sym_false] = ACTIONS(2871),
    [sym_null] = ACTIONS(2871),
    [sym_undefined] = ACTIONS(2871),
    [anon_sym_AT] = ACTIONS(2869),
    [anon_sym_static] = ACTIONS(2871),
    [anon_sym_readonly] = ACTIONS(2871),
    [anon_sym_get] = ACTIONS(2871),
    [anon_sym_set] = ACTIONS(2871),
    [anon_sym_declare] = ACTIONS(2871),
    [anon_sym_public] = ACTIONS(2871),
    [anon_sym_private] = ACTIONS(2871),
    [anon_sym_protected] = ACTIONS(2871),
    [anon_sym_override] = ACTIONS(2871),
    [anon_sym_module] = ACTIONS(2871),
    [anon_sym_any] = ACTIONS(2871),
    [anon_sym_number] = ACTIONS(2871),
    [anon_sym_boolean] = ACTIONS(2871),
    [anon_sym_string] = ACTIONS(2871),
    [anon_sym_symbol] = ACTIONS(2871),
    [anon_sym_object] = ACTIONS(2871),
    [anon_sym_abstract] = ACTIONS(2871),
    [anon_sym_interface] = ACTIONS(2871),
    [anon_sym_enum] = ACTIONS(2871),
    [sym_html_comment] = ACTIONS(5),
  },
  [913] = {
    [ts_builtin_sym_end] = ACTIONS(2873),
    [sym_identifier] = ACTIONS(2875),
    [anon_sym_export] = ACTIONS(2875),
    [anon_sym_default] = ACTIONS(2875),
    [anon_sym_type] = ACTIONS(2875),
    [anon_sym_namespace] = ACTIONS(2875),
    [anon_sym_LBRACE] = ACTIONS(2873),
    [anon_sym_RBRACE] = ACTIONS(2873),
    [anon_sym_typeof] = ACTIONS(2875),
    [anon_sym_import] = ACTIONS(2875),
    [anon_sym_with] = ACTIONS(2875),
    [anon_sym_var] = ACTIONS(2875),
    [anon_sym_let] = ACTIONS(2875),
    [anon_sym_const] = ACTIONS(2875),
    [anon_sym_BANG] = ACTIONS(2873),
    [anon_sym_else] = ACTIONS(2875),
    [anon_sym_if] = ACTIONS(2875),
    [anon_sym_switch] = ACTIONS(2875),
    [anon_sym_for] = ACTIONS(2875),
    [anon_sym_LPAREN] = ACTIONS(2873),
    [anon_sym_SEMI] = ACTIONS(2873),
    [anon_sym_await] = ACTIONS(2875),
    [anon_sym_while] = ACTIONS(2875),
    [anon_sym_do] = ACTIONS(2875),
    [anon_sym_try] = ACTIONS(2875),
    [anon_sym_break] = ACTIONS(2875),
    [anon_sym_continue] = ACTIONS(2875),
    [anon_sym_debugger] = ACTIONS(2875),
    [anon_sym_return] = ACTIONS(2875),
    [anon_sym_throw] = ACTIONS(2875),
    [anon_sym_case] = ACTIONS(2875),
    [anon_sym_yield] = ACTIONS(2875),
    [anon_sym_LBRACK] = ACTIONS(2873),
    [anon_sym_class] = ACTIONS(2875),
    [anon_sym_async] = ACTIONS(2875),
    [anon_sym_function] = ACTIONS(2875),
    [anon_sym_new] = ACTIONS(2875),
    [anon_sym_using] = ACTIONS(2875),
    [anon_sym_PLUS] = ACTIONS(2875),
    [anon_sym_DASH] = ACTIONS(2875),
    [anon_sym_SLASH] = ACTIONS(2875),
    [anon_sym_LT] = ACTIONS(2873),
    [anon_sym_TILDE] = ACTIONS(2873),
    [anon_sym_void] = ACTIONS(2875),
    [anon_sym_delete] = ACTIONS(2875),
    [anon_sym_PLUS_PLUS] = ACTIONS(2873),
    [anon_sym_DASH_DASH] = ACTIONS(2873),
    [anon_sym_DQUOTE] = ACTIONS(2873),
    [anon_sym_SQUOTE] = ACTIONS(2873),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(2873),
    [sym_number] = ACTIONS(2873),
    [sym_private_property_identifier] = ACTIONS(2873),
    [sym_this] = ACTIONS(2875),
    [sym_super] = ACTIONS(2875),
    [sym_true] = ACTIONS(2875),
    [sym_false] = ACTIONS(2875),
    [sym_null] = ACTIONS(2875),
    [sym_undefined] = ACTIONS(2875),
    [anon_sym_AT] = ACTIONS(2873),
    [anon_sym_static] = ACTIONS(2875),
    [anon_sym_readonly] = ACTIONS(2875),
    [anon_sym_get] = ACTIONS(2875),
    [anon_sym_set] = ACTIONS(2875),
    [anon_sym_declare] = ACTIONS(2875),
    [anon_sym_public] = ACTIONS(2875),
    [anon_sym_private] = ACTIONS(2875),
    [anon_sym_protected] = ACTIONS(2875),
    [anon_sym_override] = ACTIONS(2875),
    [anon_sym_module] = ACTIONS(2875),
    [anon_sym_any] = ACTIONS(2875),
    [anon_sym_number] = ACTIONS(2875),
    [anon_sym_boolean] = ACTIONS(2875),
    [anon_sym_string] = ACTIONS(2875),
    [anon_sym_symbol] = ACTIONS(2875),
    [anon_sym_object] = ACTIONS(2875),
    [anon_sym_abstract] = ACTIONS(2875),
    [anon_sym_interface] = ACTIONS(2875),
    [anon_sym_enum] = ACTIONS(2875),
    [sym_html_comment] = ACTIONS(5),
  },
  [914] = {
    [ts_builtin_sym_end] = ACTIONS(2877),
    [sym_identifier] = ACTIONS(2879),
    [anon_sym_export] = ACTIONS(2879),
    [anon_sym_default] = ACTIONS(2879),
    [anon_sym_type] = ACTIONS(2879),
    [anon_sym_namespace] = ACTIONS(2879),
    [anon_sym_LBRACE] = ACTIONS(2877),
    [anon_sym_RBRACE] = ACTIONS(2877),
    [anon_sym_typeof] = ACTIONS(2879),
    [anon_sym_import] = ACTIONS(2879),
    [anon_sym_with] = ACTIONS(2879),
    [anon_sym_var] = ACTIONS(2879),
    [anon_sym_let] = ACTIONS(2879),
    [anon_sym_const] = ACTIONS(2879),
    [anon_sym_BANG] = ACTIONS(2877),
    [anon_sym_else] = ACTIONS(2879),
    [anon_sym_if] = ACTIONS(2879),
    [anon_sym_switch] = ACTIONS(2879),
    [anon_sym_for] = ACTIONS(2879),
    [anon_sym_LPAREN] = ACTIONS(2877),
    [anon_sym_SEMI] = ACTIONS(2877),
    [anon_sym_await] = ACTIONS(2879),
    [anon_sym_while] = ACTIONS(2879),
    [anon_sym_do] = ACTIONS(2879),
    [anon_sym_try] = ACTIONS(2879),
    [anon_sym_break] = ACTIONS(2879),
    [anon_sym_continue] = ACTIONS(2879),
    [anon_sym_debugger] = ACTIONS(2879),
    [anon_sym_return] = ACTIONS(2879),
    [anon_sym_throw] = ACTIONS(2879),
    [anon_sym_case] = ACTIONS(2879),
    [anon_sym_yield] = ACTIONS(2879),
    [anon_sym_LBRACK] = ACTIONS(2877),
    [anon_sym_class] = ACTIONS(2879),
    [anon_sym_async] = ACTIONS(2879),
    [anon_sym_function] = ACTIONS(2879),
    [anon_sym_new] = ACTIONS(2879),
    [anon_sym_using] = ACTIONS(2879),
    [anon_sym_PLUS] = ACTIONS(2879),
    [anon_sym_DASH] = ACTIONS(2879),
    [anon_sym_SLASH] = ACTIONS(2879),
    [anon_sym_LT] = ACTIONS(2877),
    [anon_sym_TILDE] = ACTIONS(2877),
    [anon_sym_void] = ACTIONS(2879),
    [anon_sym_delete] = ACTIONS(2879),
    [anon_sym_PLUS_PLUS] = ACTIONS(2877),
    [anon_sym_DASH_DASH] = ACTIONS(2877),
    [anon_sym_DQUOTE] = ACTIONS(2877),
    [anon_sym_SQUOTE] = ACTIONS(2877),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(2877),
    [sym_number] = ACTIONS(2877),
    [sym_private_property_identifier] = ACTIONS(2877),
    [sym_this] = ACTIONS(2879),
    [sym_super] = ACTIONS(2879),
    [sym_true] = ACTIONS(2879),
    [sym_false] = ACTIONS(2879),
    [sym_null] = ACTIONS(2879),
    [sym_undefined] = ACTIONS(2879),
    [anon_sym_AT] = ACTIONS(2877),
    [anon_sym_static] = ACTIONS(2879),
    [anon_sym_readonly] = ACTIONS(2879),
    [anon_sym_get] = ACTIONS(2879),
    [anon_sym_set] = ACTIONS(2879),
    [anon_sym_declare] = ACTIONS(2879),
    [anon_sym_public] = ACTIONS(2879),
    [anon_sym_private] = ACTIONS(2879),
    [anon_sym_protected] = ACTIONS(2879),
    [anon_sym_override] = ACTIONS(2879),
    [anon_sym_module] = ACTIONS(2879),
    [anon_sym_any] = ACTIONS(2879),
    [anon_sym_number] = ACTIONS(2879),
    [anon_sym_boolean] = ACTIONS(2879),
    [anon_sym_string] = ACTIONS(2879),
    [anon_sym_symbol] = ACTIONS(2879),
    [anon_sym_object] = ACTIONS(2879),
    [anon_sym_abstract] = ACTIONS(2879),
    [anon_sym_interface] = ACTIONS(2879),
    [anon_sym_enum] = ACTIONS(2879),
    [sym_html_comment] = ACTIONS(5),
  },
  [915] = {
    [ts_builtin_sym_end] = ACTIONS(2881),
    [sym_identifier] = ACTIONS(2883),
    [anon_sym_export] = ACTIONS(2883),
    [anon_sym_default] = ACTIONS(2883),
    [anon_sym_type] = ACTIONS(2883),
    [anon_sym_namespace] = ACTIONS(2883),
    [anon_sym_LBRACE] = ACTIONS(2881),
    [anon_sym_RBRACE] = ACTIONS(2881),
    [anon_sym_typeof] = ACTIONS(2883),
    [anon_sym_import] = ACTIONS(2883),
    [anon_sym_with] = ACTIONS(2883),
    [anon_sym_var] = ACTIONS(2883),
    [anon_sym_let] = ACTIONS(2883),
    [anon_sym_const] = ACTIONS(2883),
    [anon_sym_BANG] = ACTIONS(2881),
    [anon_sym_else] = ACTIONS(2883),
    [anon_sym_if] = ACTIONS(2883),
    [anon_sym_switch] = ACTIONS(2883),
    [anon_sym_for] = ACTIONS(2883),
    [anon_sym_LPAREN] = ACTIONS(2881),
    [anon_sym_SEMI] = ACTIONS(2881),
    [anon_sym_await] = ACTIONS(2883),
    [anon_sym_while] = ACTIONS(2883),
    [anon_sym_do] = ACTIONS(2883),
    [anon_sym_try] = ACTIONS(2883),
    [anon_sym_break] = ACTIONS(2883),
    [anon_sym_continue] = ACTIONS(2883),
    [anon_sym_debugger] = ACTIONS(2883),
    [anon_sym_return] = ACTIONS(2883),
    [anon_sym_throw] = ACTIONS(2883),
    [anon_sym_case] = ACTIONS(2883),
    [anon_sym_yield] = ACTIONS(2883),
    [anon_sym_LBRACK] = ACTIONS(2881),
    [anon_sym_class] = ACTIONS(2883),
    [anon_sym_async] = ACTIONS(2883),
    [anon_sym_function] = ACTIONS(2883),
    [anon_sym_new] = ACTIONS(2883),
    [anon_sym_using] = ACTIONS(2883),
    [anon_sym_PLUS] = ACTIONS(2883),
    [anon_sym_DASH] = ACTIONS(2883),
    [anon_sym_SLASH] = ACTIONS(2883),
    [anon_sym_LT] = ACTIONS(2881),
    [anon_sym_TILDE] = ACTIONS(2881),
    [anon_sym_void] = ACTIONS(2883),
    [anon_sym_delete] = ACTIONS(2883),
    [anon_sym_PLUS_PLUS] = ACTIONS(2881),
    [anon_sym_DASH_DASH] = ACTIONS(2881),
    [anon_sym_DQUOTE] = ACTIONS(2881),
    [anon_sym_SQUOTE] = ACTIONS(2881),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(2881),
    [sym_number] = ACTIONS(2881),
    [sym_private_property_identifier] = ACTIONS(2881),
    [sym_this] = ACTIONS(2883),
    [sym_super] = ACTIONS(2883),
    [sym_true] = ACTIONS(2883),
    [sym_false] = ACTIONS(2883),
    [sym_null] = ACTIONS(2883),
    [sym_undefined] = ACTIONS(2883),
    [anon_sym_AT] = ACTIONS(2881),
    [anon_sym_static] = ACTIONS(2883),
    [anon_sym_readonly] = ACTIONS(2883),
    [anon_sym_get] = ACTIONS(2883),
    [anon_sym_set] = ACTIONS(2883),
    [anon_sym_declare] = ACTIONS(2883),
    [anon_sym_public] = ACTIONS(2883),
    [anon_sym_private] = ACTIONS(2883),
    [anon_sym_protected] = ACTIONS(2883),
    [anon_sym_override] = ACTIONS(2883),
    [anon_sym_module] = ACTIONS(2883),
    [anon_sym_any] = ACTIONS(2883),
    [anon_sym_number] = ACTIONS(2883),
    [anon_sym_boolean] = ACTIONS(2883),
    [anon_sym_string] = ACTIONS(2883),
    [anon_sym_symbol] = ACTIONS(2883),
    [anon_sym_object] = ACTIONS(2883),
    [anon_sym_abstract] = ACTIONS(2883),
    [anon_sym_interface] = ACTIONS(2883),
    [anon_sym_enum] = ACTIONS(2883),
    [sym_html_comment] = ACTIONS(5),
  },
  [916] = {
    [ts_builtin_sym_end] = ACTIONS(2873),
    [sym_identifier] = ACTIONS(2875),
    [anon_sym_export] = ACTIONS(2875),
    [anon_sym_default] = ACTIONS(2875),
    [anon_sym_type] = ACTIONS(2875),
    [anon_sym_namespace] = ACTIONS(2875),
    [anon_sym_LBRACE] = ACTIONS(2873),
    [anon_sym_RBRACE] = ACTIONS(2873),
    [anon_sym_typeof] = ACTIONS(2875),
    [anon_sym_import] = ACTIONS(2875),
    [anon_sym_with] = ACTIONS(2875),
    [anon_sym_var] = ACTIONS(2875),
    [anon_sym_let] = ACTIONS(2875),
    [anon_sym_const] = ACTIONS(2875),
    [anon_sym_BANG] = ACTIONS(2873),
    [anon_sym_else] = ACTIONS(2875),
    [anon_sym_if] = ACTIONS(2875),
    [anon_sym_switch] = ACTIONS(2875),
    [anon_sym_for] = ACTIONS(2875),
    [anon_sym_LPAREN] = ACTIONS(2873),
    [anon_sym_SEMI] = ACTIONS(2873),
    [anon_sym_await] = ACTIONS(2875),
    [anon_sym_while] = ACTIONS(2875),
    [anon_sym_do] = ACTIONS(2875),
    [anon_sym_try] = ACTIONS(2875),
    [anon_sym_break] = ACTIONS(2875),
    [anon_sym_continue] = ACTIONS(2875),
    [anon_sym_debugger] = ACTIONS(2875),
    [anon_sym_return] = ACTIONS(2875),
    [anon_sym_throw] = ACTIONS(2875),
    [anon_sym_case] = ACTIONS(2875),
    [anon_sym_yield] = ACTIONS(2875),
    [anon_sym_LBRACK] = ACTIONS(2873),
    [anon_sym_class] = ACTIONS(2875),
    [anon_sym_async] = ACTIONS(2875),
    [anon_sym_function] = ACTIONS(2875),
    [anon_sym_new] = ACTIONS(2875),
    [anon_sym_using] = ACTIONS(2875),
    [anon_sym_PLUS] = ACTIONS(2875),
    [anon_sym_DASH] = ACTIONS(2875),
    [anon_sym_SLASH] = ACTIONS(2875),
    [anon_sym_LT] = ACTIONS(2873),
    [anon_sym_TILDE] = ACTIONS(2873),
    [anon_sym_void] = ACTIONS(2875),
    [anon_sym_delete] = ACTIONS(2875),
    [anon_sym_PLUS_PLUS] = ACTIONS(2873),
    [anon_sym_DASH_DASH] = ACTIONS(2873),
    [anon_sym_DQUOTE] = ACTIONS(2873),
    [anon_sym_SQUOTE] = ACTIONS(2873),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(2873),
    [sym_number] = ACTIONS(2873),
    [sym_private_property_identifier] = ACTIONS(2873),
    [sym_this] = ACTIONS(2875),
    [sym_super] = ACTIONS(2875),
    [sym_true] = ACTIONS(2875),
    [sym_false] = ACTIONS(2875),
    [sym_null] = ACTIONS(2875),
    [sym_undefined] = ACTIONS(2875),
    [anon_sym_AT] = ACTIONS(2873),
    [anon_sym_static] = ACTIONS(2875),
    [anon_sym_readonly] = ACTIONS(2875),
    [anon_sym_get] = ACTIONS(2875),
    [anon_sym_set] = ACTIONS(2875),
    [anon_sym_declare] = ACTIONS(2875),
    [anon_sym_public] = ACTIONS(2875),
    [anon_sym_private] = ACTIONS(2875),
    [anon_sym_protected] = ACTIONS(2875),
    [anon_sym_override] = ACTIONS(2875),
    [anon_sym_module] = ACTIONS(2875),
    [anon_sym_any] = ACTIONS(2875),
    [anon_sym_number] = ACTIONS(2875),
    [anon_sym_boolean] = ACTIONS(2875),
    [anon_sym_string] = ACTIONS(2875),
    [anon_sym_symbol] = ACTIONS(2875),
    [anon_sym_object] = ACTIONS(2875),
    [anon_sym_abstract] = ACTIONS(2875),
    [anon_sym_interface] = ACTIONS(2875),
    [anon_sym_enum] = ACTIONS(2875),
    [sym_html_comment] = ACTIONS(5),
  },
  [917] = {
    [ts_builtin_sym_end] = ACTIONS(2885),
    [sym_identifier] = ACTIONS(2887),
    [anon_sym_export] = ACTIONS(2887),
    [anon_sym_default] = ACTIONS(2887),
    [anon_sym_type] = ACTIONS(2887),
    [anon_sym_namespace] = ACTIONS(2887),
    [anon_sym_LBRACE] = ACTIONS(2885),
    [anon_sym_RBRACE] = ACTIONS(2885),
    [anon_sym_typeof] = ACTIONS(2887),
    [anon_sym_import] = ACTIONS(2887),
    [anon_sym_with] = ACTIONS(2887),
    [anon_sym_var] = ACTIONS(2887),
    [anon_sym_let] = ACTIONS(2887),
    [anon_sym_const] = ACTIONS(2887),
    [anon_sym_BANG] = ACTIONS(2885),
    [anon_sym_else] = ACTIONS(2887),
    [anon_sym_if] = ACTIONS(2887),
    [anon_sym_switch] = ACTIONS(2887),
    [anon_sym_for] = ACTIONS(2887),
    [anon_sym_LPAREN] = ACTIONS(2885),
    [anon_sym_SEMI] = ACTIONS(2885),
    [anon_sym_await] = ACTIONS(2887),
    [anon_sym_while] = ACTIONS(2887),
    [anon_sym_do] = ACTIONS(2887),
    [anon_sym_try] = ACTIONS(2887),
    [anon_sym_break] = ACTIONS(2887),
    [anon_sym_continue] = ACTIONS(2887),
    [anon_sym_debugger] = ACTIONS(2887),
    [anon_sym_return] = ACTIONS(2887),
    [anon_sym_throw] = ACTIONS(2887),
    [anon_sym_case] = ACTIONS(2887),
    [anon_sym_yield] = ACTIONS(2887),
    [anon_sym_LBRACK] = ACTIONS(2885),
    [anon_sym_class] = ACTIONS(2887),
    [anon_sym_async] = ACTIONS(2887),
    [anon_sym_function] = ACTIONS(2887),
    [anon_sym_new] = ACTIONS(2887),
    [anon_sym_using] = ACTIONS(2887),
    [anon_sym_PLUS] = ACTIONS(2887),
    [anon_sym_DASH] = ACTIONS(2887),
    [anon_sym_SLASH] = ACTIONS(2887),
    [anon_sym_LT] = ACTIONS(2885),
    [anon_sym_TILDE] = ACTIONS(2885),
    [anon_sym_void] = ACTIONS(2887),
    [anon_sym_delete] = ACTIONS(2887),
    [anon_sym_PLUS_PLUS] = ACTIONS(2885),
    [anon_sym_DASH_DASH] = ACTIONS(2885),
    [anon_sym_DQUOTE] = ACTIONS(2885),
    [anon_sym_SQUOTE] = ACTIONS(2885),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(2885),
    [sym_number] = ACTIONS(2885),
    [sym_private_property_identifier] = ACTIONS(2885),
    [sym_this] = ACTIONS(2887),
    [sym_super] = ACTIONS(2887),
    [sym_true] = ACTIONS(2887),
    [sym_false] = ACTIONS(2887),
    [sym_null] = ACTIONS(2887),
    [sym_undefined] = ACTIONS(2887),
    [anon_sym_AT] = ACTIONS(2885),
    [anon_sym_static] = ACTIONS(2887),
    [anon_sym_readonly] = ACTIONS(2887),
    [anon_sym_get] = ACTIONS(2887),
    [anon_sym_set] = ACTIONS(2887),
    [anon_sym_declare] = ACTIONS(2887),
    [anon_sym_public] = ACTIONS(2887),
    [anon_sym_private] = ACTIONS(2887),
    [anon_sym_protected] = ACTIONS(2887),
    [anon_sym_override] = ACTIONS(2887),
    [anon_sym_module] = ACTIONS(2887),
    [anon_sym_any] = ACTIONS(2887),
    [anon_sym_number] = ACTIONS(2887),
    [anon_sym_boolean] = ACTIONS(2887),
    [anon_sym_string] = ACTIONS(2887),
    [anon_sym_symbol] = ACTIONS(2887),
    [anon_sym_object] = ACTIONS(2887),
    [anon_sym_abstract] = ACTIONS(2887),
    [anon_sym_interface] = ACTIONS(2887),
    [anon_sym_enum] = ACTIONS(2887),
    [sym_html_comment] = ACTIONS(5),
  },
  [918] = {
    [ts_builtin_sym_end] = ACTIONS(2889),
    [sym_identifier] = ACTIONS(2891),
    [anon_sym_export] = ACTIONS(2891),
    [anon_sym_default] = ACTIONS(2891),
    [anon_sym_type] = ACTIONS(2891),
    [anon_sym_namespace] = ACTIONS(2891),
    [anon_sym_LBRACE] = ACTIONS(2889),
    [anon_sym_RBRACE] = ACTIONS(2889),
    [anon_sym_typeof] = ACTIONS(2891),
    [anon_sym_import] = ACTIONS(2891),
    [anon_sym_with] = ACTIONS(2891),
    [anon_sym_var] = ACTIONS(2891),
    [anon_sym_let] = ACTIONS(2891),
    [anon_sym_const] = ACTIONS(2891),
    [anon_sym_BANG] = ACTIONS(2889),
    [anon_sym_else] = ACTIONS(2891),
    [anon_sym_if] = ACTIONS(2891),
    [anon_sym_switch] = ACTIONS(2891),
    [anon_sym_for] = ACTIONS(2891),
    [anon_sym_LPAREN] = ACTIONS(2889),
    [anon_sym_SEMI] = ACTIONS(2889),
    [anon_sym_await] = ACTIONS(2891),
    [anon_sym_while] = ACTIONS(2891),
    [anon_sym_do] = ACTIONS(2891),
    [anon_sym_try] = ACTIONS(2891),
    [anon_sym_break] = ACTIONS(2891),
    [anon_sym_continue] = ACTIONS(2891),
    [anon_sym_debugger] = ACTIONS(2891),
    [anon_sym_return] = ACTIONS(2891),
    [anon_sym_throw] = ACTIONS(2891),
    [anon_sym_case] = ACTIONS(2891),
    [anon_sym_yield] = ACTIONS(2891),
    [anon_sym_LBRACK] = ACTIONS(2889),
    [anon_sym_class] = ACTIONS(2891),
    [anon_sym_async] = ACTIONS(2891),
    [anon_sym_function] = ACTIONS(2891),
    [anon_sym_new] = ACTIONS(2891),
    [anon_sym_using] = ACTIONS(2891),
    [anon_sym_PLUS] = ACTIONS(2891),
    [anon_sym_DASH] = ACTIONS(2891),
    [anon_sym_SLASH] = ACTIONS(2891),
    [anon_sym_LT] = ACTIONS(2889),
    [anon_sym_TILDE] = ACTIONS(2889),
    [anon_sym_void] = ACTIONS(2891),
    [anon_sym_delete] = ACTIONS(2891),
    [anon_sym_PLUS_PLUS] = ACTIONS(2889),
    [anon_sym_DASH_DASH] = ACTIONS(2889),
    [anon_sym_DQUOTE] = ACTIONS(2889),
    [anon_sym_SQUOTE] = ACTIONS(2889),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(2889),
    [sym_number] = ACTIONS(2889),
    [sym_private_property_identifier] = ACTIONS(2889),
    [sym_this] = ACTIONS(2891),
    [sym_super] = ACTIONS(2891),
    [sym_true] = ACTIONS(2891),
    [sym_false] = ACTIONS(2891),
    [sym_null] = ACTIONS(2891),
    [sym_undefined] = ACTIONS(2891),
    [anon_sym_AT] = ACTIONS(2889),
    [anon_sym_static] = ACTIONS(2891),
    [anon_sym_readonly] = ACTIONS(2891),
    [anon_sym_get] = ACTIONS(2891),
    [anon_sym_set] = ACTIONS(2891),
    [anon_sym_declare] = ACTIONS(2891),
    [anon_sym_public] = ACTIONS(2891),
    [anon_sym_private] = ACTIONS(2891),
    [anon_sym_protected] = ACTIONS(2891),
    [anon_sym_override] = ACTIONS(2891),
    [anon_sym_module] = ACTIONS(2891),
    [anon_sym_any] = ACTIONS(2891),
    [anon_sym_number] = ACTIONS(2891),
    [anon_sym_boolean] = ACTIONS(2891),
    [anon_sym_string] = ACTIONS(2891),
    [anon_sym_symbol] = ACTIONS(2891),
    [anon_sym_object] = ACTIONS(2891),
    [anon_sym_abstract] = ACTIONS(2891),
    [anon_sym_interface] = ACTIONS(2891),
    [anon_sym_enum] = ACTIONS(2891),
    [sym_html_comment] = ACTIONS(5),
  },
  [919] = {
    [ts_builtin_sym_end] = ACTIONS(2893),
    [sym_identifier] = ACTIONS(2895),
    [anon_sym_export] = ACTIONS(2895),
    [anon_sym_default] = ACTIONS(2895),
    [anon_sym_type] = ACTIONS(2895),
    [anon_sym_namespace] = ACTIONS(2895),
    [anon_sym_LBRACE] = ACTIONS(2893),
    [anon_sym_RBRACE] = ACTIONS(2893),
    [anon_sym_typeof] = ACTIONS(2895),
    [anon_sym_import] = ACTIONS(2895),
    [anon_sym_with] = ACTIONS(2895),
    [anon_sym_var] = ACTIONS(2895),
    [anon_sym_let] = ACTIONS(2895),
    [anon_sym_const] = ACTIONS(2895),
    [anon_sym_BANG] = ACTIONS(2893),
    [anon_sym_else] = ACTIONS(2895),
    [anon_sym_if] = ACTIONS(2895),
    [anon_sym_switch] = ACTIONS(2895),
    [anon_sym_for] = ACTIONS(2895),
    [anon_sym_LPAREN] = ACTIONS(2893),
    [anon_sym_SEMI] = ACTIONS(2893),
    [anon_sym_await] = ACTIONS(2895),
    [anon_sym_while] = ACTIONS(2895),
    [anon_sym_do] = ACTIONS(2895),
    [anon_sym_try] = ACTIONS(2895),
    [anon_sym_break] = ACTIONS(2895),
    [anon_sym_continue] = ACTIONS(2895),
    [anon_sym_debugger] = ACTIONS(2895),
    [anon_sym_return] = ACTIONS(2895),
    [anon_sym_throw] = ACTIONS(2895),
    [anon_sym_case] = ACTIONS(2895),
    [anon_sym_yield] = ACTIONS(2895),
    [anon_sym_LBRACK] = ACTIONS(2893),
    [anon_sym_class] = ACTIONS(2895),
    [anon_sym_async] = ACTIONS(2895),
    [anon_sym_function] = ACTIONS(2895),
    [anon_sym_new] = ACTIONS(2895),
    [anon_sym_using] = ACTIONS(2895),
    [anon_sym_PLUS] = ACTIONS(2895),
    [anon_sym_DASH] = ACTIONS(2895),
    [anon_sym_SLASH] = ACTIONS(2895),
    [anon_sym_LT] = ACTIONS(2893),
    [anon_sym_TILDE] = ACTIONS(2893),
    [anon_sym_void] = ACTIONS(2895),
    [anon_sym_delete] = ACTIONS(2895),
    [anon_sym_PLUS_PLUS] = ACTIONS(2893),
    [anon_sym_DASH_DASH] = ACTIONS(2893),
    [anon_sym_DQUOTE] = ACTIONS(2893),
    [anon_sym_SQUOTE] = ACTIONS(2893),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(2893),
    [sym_number] = ACTIONS(2893),
    [sym_private_property_identifier] = ACTIONS(2893),
    [sym_this] = ACTIONS(2895),
    [sym_super] = ACTIONS(2895),
    [sym_true] = ACTIONS(2895),
    [sym_false] = ACTIONS(2895),
    [sym_null] = ACTIONS(2895),
    [sym_undefined] = ACTIONS(2895),
    [anon_sym_AT] = ACTIONS(2893),
    [anon_sym_static] = ACTIONS(2895),
    [anon_sym_readonly] = ACTIONS(2895),
    [anon_sym_get] = ACTIONS(2895),
    [anon_sym_set] = ACTIONS(2895),
    [anon_sym_declare] = ACTIONS(2895),
    [anon_sym_public] = ACTIONS(2895),
    [anon_sym_private] = ACTIONS(2895),
    [anon_sym_protected] = ACTIONS(2895),
    [anon_sym_override] = ACTIONS(2895),
    [anon_sym_module] = ACTIONS(2895),
    [anon_sym_any] = ACTIONS(2895),
    [anon_sym_number] = ACTIONS(2895),
    [anon_sym_boolean] = ACTIONS(2895),
    [anon_sym_string] = ACTIONS(2895),
    [anon_sym_symbol] = ACTIONS(2895),
    [anon_sym_object] = ACTIONS(2895),
    [anon_sym_abstract] = ACTIONS(2895),
    [anon_sym_interface] = ACTIONS(2895),
    [anon_sym_enum] = ACTIONS(2895),
    [sym_html_comment] = ACTIONS(5),
  },
  [920] = {
    [ts_builtin_sym_end] = ACTIONS(2897),
    [sym_identifier] = ACTIONS(2899),
    [anon_sym_export] = ACTIONS(2899),
    [anon_sym_default] = ACTIONS(2899),
    [anon_sym_type] = ACTIONS(2899),
    [anon_sym_namespace] = ACTIONS(2899),
    [anon_sym_LBRACE] = ACTIONS(2897),
    [anon_sym_RBRACE] = ACTIONS(2897),
    [anon_sym_typeof] = ACTIONS(2899),
    [anon_sym_import] = ACTIONS(2899),
    [anon_sym_with] = ACTIONS(2899),
    [anon_sym_var] = ACTIONS(2899),
    [anon_sym_let] = ACTIONS(2899),
    [anon_sym_const] = ACTIONS(2899),
    [anon_sym_BANG] = ACTIONS(2897),
    [anon_sym_else] = ACTIONS(2899),
    [anon_sym_if] = ACTIONS(2899),
    [anon_sym_switch] = ACTIONS(2899),
    [anon_sym_for] = ACTIONS(2899),
    [anon_sym_LPAREN] = ACTIONS(2897),
    [anon_sym_SEMI] = ACTIONS(2897),
    [anon_sym_await] = ACTIONS(2899),
    [anon_sym_while] = ACTIONS(2899),
    [anon_sym_do] = ACTIONS(2899),
    [anon_sym_try] = ACTIONS(2899),
    [anon_sym_break] = ACTIONS(2899),
    [anon_sym_continue] = ACTIONS(2899),
    [anon_sym_debugger] = ACTIONS(2899),
    [anon_sym_return] = ACTIONS(2899),
    [anon_sym_throw] = ACTIONS(2899),
    [anon_sym_case] = ACTIONS(2899),
    [anon_sym_yield] = ACTIONS(2899),
    [anon_sym_LBRACK] = ACTIONS(2897),
    [anon_sym_class] = ACTIONS(2899),
    [anon_sym_async] = ACTIONS(2899),
    [anon_sym_function] = ACTIONS(2899),
    [anon_sym_new] = ACTIONS(2899),
    [anon_sym_using] = ACTIONS(2899),
    [anon_sym_PLUS] = ACTIONS(2899),
    [anon_sym_DASH] = ACTIONS(2899),
    [anon_sym_SLASH] = ACTIONS(2899),
    [anon_sym_LT] = ACTIONS(2897),
    [anon_sym_TILDE] = ACTIONS(2897),
    [anon_sym_void] = ACTIONS(2899),
    [anon_sym_delete] = ACTIONS(2899),
    [anon_sym_PLUS_PLUS] = ACTIONS(2897),
    [anon_sym_DASH_DASH] = ACTIONS(2897),
    [anon_sym_DQUOTE] = ACTIONS(2897),
    [anon_sym_SQUOTE] = ACTIONS(2897),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(2897),
    [sym_number] = ACTIONS(2897),
    [sym_private_property_identifier] = ACTIONS(2897),
    [sym_this] = ACTIONS(2899),
    [sym_super] = ACTIONS(2899),
    [sym_true] = ACTIONS(2899),
    [sym_false] = ACTIONS(2899),
    [sym_null] = ACTIONS(2899),
    [sym_undefined] = ACTIONS(2899),
    [anon_sym_AT] = ACTIONS(2897),
    [anon_sym_static] = ACTIONS(2899),
    [anon_sym_readonly] = ACTIONS(2899),
    [anon_sym_get] = ACTIONS(2899),
    [anon_sym_set] = ACTIONS(2899),
    [anon_sym_declare] = ACTIONS(2899),
    [anon_sym_public] = ACTIONS(2899),
    [anon_sym_private] = ACTIONS(2899),
    [anon_sym_protected] = ACTIONS(2899),
    [anon_sym_override] = ACTIONS(2899),
    [anon_sym_module] = ACTIONS(2899),
    [anon_sym_any] = ACTIONS(2899),
    [anon_sym_number] = ACTIONS(2899),
    [anon_sym_boolean] = ACTIONS(2899),
    [anon_sym_string] = ACTIONS(2899),
    [anon_sym_symbol] = ACTIONS(2899),
    [anon_sym_object] = ACTIONS(2899),
    [anon_sym_abstract] = ACTIONS(2899),
    [anon_sym_interface] = ACTIONS(2899),
    [anon_sym_enum] = ACTIONS(2899),
    [sym_html_comment] = ACTIONS(5),
  },
  [921] = {
    [ts_builtin_sym_end] = ACTIONS(2901),
    [sym_identifier] = ACTIONS(2903),
    [anon_sym_export] = ACTIONS(2903),
    [anon_sym_default] = ACTIONS(2903),
    [anon_sym_type] = ACTIONS(2903),
    [anon_sym_namespace] = ACTIONS(2903),
    [anon_sym_LBRACE] = ACTIONS(2901),
    [anon_sym_RBRACE] = ACTIONS(2901),
    [anon_sym_typeof] = ACTIONS(2903),
    [anon_sym_import] = ACTIONS(2903),
    [anon_sym_with] = ACTIONS(2903),
    [anon_sym_var] = ACTIONS(2903),
    [anon_sym_let] = ACTIONS(2903),
    [anon_sym_const] = ACTIONS(2903),
    [anon_sym_BANG] = ACTIONS(2901),
    [anon_sym_else] = ACTIONS(2903),
    [anon_sym_if] = ACTIONS(2903),
    [anon_sym_switch] = ACTIONS(2903),
    [anon_sym_for] = ACTIONS(2903),
    [anon_sym_LPAREN] = ACTIONS(2901),
    [anon_sym_SEMI] = ACTIONS(2901),
    [anon_sym_await] = ACTIONS(2903),
    [anon_sym_while] = ACTIONS(2903),
    [anon_sym_do] = ACTIONS(2903),
    [anon_sym_try] = ACTIONS(2903),
    [anon_sym_break] = ACTIONS(2903),
    [anon_sym_continue] = ACTIONS(2903),
    [anon_sym_debugger] = ACTIONS(2903),
    [anon_sym_return] = ACTIONS(2903),
    [anon_sym_throw] = ACTIONS(2903),
    [anon_sym_case] = ACTIONS(2903),
    [anon_sym_yield] = ACTIONS(2903),
    [anon_sym_LBRACK] = ACTIONS(2901),
    [anon_sym_class] = ACTIONS(2903),
    [anon_sym_async] = ACTIONS(2903),
    [anon_sym_function] = ACTIONS(2903),
    [anon_sym_new] = ACTIONS(2903),
    [anon_sym_using] = ACTIONS(2903),
    [anon_sym_PLUS] = ACTIONS(2903),
    [anon_sym_DASH] = ACTIONS(2903),
    [anon_sym_SLASH] = ACTIONS(2903),
    [anon_sym_LT] = ACTIONS(2901),
    [anon_sym_TILDE] = ACTIONS(2901),
    [anon_sym_void] = ACTIONS(2903),
    [anon_sym_delete] = ACTIONS(2903),
    [anon_sym_PLUS_PLUS] = ACTIONS(2901),
    [anon_sym_DASH_DASH] = ACTIONS(2901),
    [anon_sym_DQUOTE] = ACTIONS(2901),
    [anon_sym_SQUOTE] = ACTIONS(2901),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(2901),
    [sym_number] = ACTIONS(2901),
    [sym_private_property_identifier] = ACTIONS(2901),
    [sym_this] = ACTIONS(2903),
    [sym_super] = ACTIONS(2903),
    [sym_true] = ACTIONS(2903),
    [sym_false] = ACTIONS(2903),
    [sym_null] = ACTIONS(2903),
    [sym_undefined] = ACTIONS(2903),
    [anon_sym_AT] = ACTIONS(2901),
    [anon_sym_static] = ACTIONS(2903),
    [anon_sym_readonly] = ACTIONS(2903),
    [anon_sym_get] = ACTIONS(2903),
    [anon_sym_set] = ACTIONS(2903),
    [anon_sym_declare] = ACTIONS(2903),
    [anon_sym_public] = ACTIONS(2903),
    [anon_sym_private] = ACTIONS(2903),
    [anon_sym_protected] = ACTIONS(2903),
    [anon_sym_override] = ACTIONS(2903),
    [anon_sym_module] = ACTIONS(2903),
    [anon_sym_any] = ACTIONS(2903),
    [anon_sym_number] = ACTIONS(2903),
    [anon_sym_boolean] = ACTIONS(2903),
    [anon_sym_string] = ACTIONS(2903),
    [anon_sym_symbol] = ACTIONS(2903),
    [anon_sym_object] = ACTIONS(2903),
    [anon_sym_abstract] = ACTIONS(2903),
    [anon_sym_interface] = ACTIONS(2903),
    [anon_sym_enum] = ACTIONS(2903),
    [sym_html_comment] = ACTIONS(5),
  },
  [922] = {
    [ts_builtin_sym_end] = ACTIONS(2905),
    [sym_identifier] = ACTIONS(2907),
    [anon_sym_export] = ACTIONS(2907),
    [anon_sym_default] = ACTIONS(2907),
    [anon_sym_type] = ACTIONS(2907),
    [anon_sym_namespace] = ACTIONS(2907),
    [anon_sym_LBRACE] = ACTIONS(2905),
    [anon_sym_RBRACE] = ACTIONS(2905),
    [anon_sym_typeof] = ACTIONS(2907),
    [anon_sym_import] = ACTIONS(2907),
    [anon_sym_with] = ACTIONS(2907),
    [anon_sym_var] = ACTIONS(2907),
    [anon_sym_let] = ACTIONS(2907),
    [anon_sym_const] = ACTIONS(2907),
    [anon_sym_BANG] = ACTIONS(2905),
    [anon_sym_else] = ACTIONS(2907),
    [anon_sym_if] = ACTIONS(2907),
    [anon_sym_switch] = ACTIONS(2907),
    [anon_sym_for] = ACTIONS(2907),
    [anon_sym_LPAREN] = ACTIONS(2905),
    [anon_sym_SEMI] = ACTIONS(2905),
    [anon_sym_await] = ACTIONS(2907),
    [anon_sym_while] = ACTIONS(2907),
    [anon_sym_do] = ACTIONS(2907),
    [anon_sym_try] = ACTIONS(2907),
    [anon_sym_break] = ACTIONS(2907),
    [anon_sym_continue] = ACTIONS(2907),
    [anon_sym_debugger] = ACTIONS(2907),
    [anon_sym_return] = ACTIONS(2907),
    [anon_sym_throw] = ACTIONS(2907),
    [anon_sym_case] = ACTIONS(2907),
    [anon_sym_yield] = ACTIONS(2907),
    [anon_sym_LBRACK] = ACTIONS(2905),
    [anon_sym_class] = ACTIONS(2907),
    [anon_sym_async] = ACTIONS(2907),
    [anon_sym_function] = ACTIONS(2907),
    [anon_sym_new] = ACTIONS(2907),
    [anon_sym_using] = ACTIONS(2907),
    [anon_sym_PLUS] = ACTIONS(2907),
    [anon_sym_DASH] = ACTIONS(2907),
    [anon_sym_SLASH] = ACTIONS(2907),
    [anon_sym_LT] = ACTIONS(2905),
    [anon_sym_TILDE] = ACTIONS(2905),
    [anon_sym_void] = ACTIONS(2907),
    [anon_sym_delete] = ACTIONS(2907),
    [anon_sym_PLUS_PLUS] = ACTIONS(2905),
    [anon_sym_DASH_DASH] = ACTIONS(2905),
    [anon_sym_DQUOTE] = ACTIONS(2905),
    [anon_sym_SQUOTE] = ACTIONS(2905),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(2905),
    [sym_number] = ACTIONS(2905),
    [sym_private_property_identifier] = ACTIONS(2905),
    [sym_this] = ACTIONS(2907),
    [sym_super] = ACTIONS(2907),
    [sym_true] = ACTIONS(2907),
    [sym_false] = ACTIONS(2907),
    [sym_null] = ACTIONS(2907),
    [sym_undefined] = ACTIONS(2907),
    [anon_sym_AT] = ACTIONS(2905),
    [anon_sym_static] = ACTIONS(2907),
    [anon_sym_readonly] = ACTIONS(2907),
    [anon_sym_get] = ACTIONS(2907),
    [anon_sym_set] = ACTIONS(2907),
    [anon_sym_declare] = ACTIONS(2907),
    [anon_sym_public] = ACTIONS(2907),
    [anon_sym_private] = ACTIONS(2907),
    [anon_sym_protected] = ACTIONS(2907),
    [anon_sym_override] = ACTIONS(2907),
    [anon_sym_module] = ACTIONS(2907),
    [anon_sym_any] = ACTIONS(2907),
    [anon_sym_number] = ACTIONS(2907),
    [anon_sym_boolean] = ACTIONS(2907),
    [anon_sym_string] = ACTIONS(2907),
    [anon_sym_symbol] = ACTIONS(2907),
    [anon_sym_object] = ACTIONS(2907),
    [anon_sym_abstract] = ACTIONS(2907),
    [anon_sym_interface] = ACTIONS(2907),
    [anon_sym_enum] = ACTIONS(2907),
    [sym_html_comment] = ACTIONS(5),
  },
  [923] = {
    [ts_builtin_sym_end] = ACTIONS(2909),
    [sym_identifier] = ACTIONS(2911),
    [anon_sym_export] = ACTIONS(2911),
    [anon_sym_default] = ACTIONS(2911),
    [anon_sym_type] = ACTIONS(2911),
    [anon_sym_namespace] = ACTIONS(2911),
    [anon_sym_LBRACE] = ACTIONS(2909),
    [anon_sym_RBRACE] = ACTIONS(2909),
    [anon_sym_typeof] = ACTIONS(2911),
    [anon_sym_import] = ACTIONS(2911),
    [anon_sym_with] = ACTIONS(2911),
    [anon_sym_var] = ACTIONS(2911),
    [anon_sym_let] = ACTIONS(2911),
    [anon_sym_const] = ACTIONS(2911),
    [anon_sym_BANG] = ACTIONS(2909),
    [anon_sym_else] = ACTIONS(2911),
    [anon_sym_if] = ACTIONS(2911),
    [anon_sym_switch] = ACTIONS(2911),
    [anon_sym_for] = ACTIONS(2911),
    [anon_sym_LPAREN] = ACTIONS(2909),
    [anon_sym_SEMI] = ACTIONS(2909),
    [anon_sym_await] = ACTIONS(2911),
    [anon_sym_while] = ACTIONS(2911),
    [anon_sym_do] = ACTIONS(2911),
    [anon_sym_try] = ACTIONS(2911),
    [anon_sym_break] = ACTIONS(2911),
    [anon_sym_continue] = ACTIONS(2911),
    [anon_sym_debugger] = ACTIONS(2911),
    [anon_sym_return] = ACTIONS(2911),
    [anon_sym_throw] = ACTIONS(2911),
    [anon_sym_case] = ACTIONS(2911),
    [anon_sym_yield] = ACTIONS(2911),
    [anon_sym_LBRACK] = ACTIONS(2909),
    [anon_sym_class] = ACTIONS(2911),
    [anon_sym_async] = ACTIONS(2911),
    [anon_sym_function] = ACTIONS(2911),
    [anon_sym_new] = ACTIONS(2911),
    [anon_sym_using] = ACTIONS(2911),
    [anon_sym_PLUS] = ACTIONS(2911),
    [anon_sym_DASH] = ACTIONS(2911),
    [anon_sym_SLASH] = ACTIONS(2911),
    [anon_sym_LT] = ACTIONS(2909),
    [anon_sym_TILDE] = ACTIONS(2909),
    [anon_sym_void] = ACTIONS(2911),
    [anon_sym_delete] = ACTIONS(2911),
    [anon_sym_PLUS_PLUS] = ACTIONS(2909),
    [anon_sym_DASH_DASH] = ACTIONS(2909),
    [anon_sym_DQUOTE] = ACTIONS(2909),
    [anon_sym_SQUOTE] = ACTIONS(2909),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(2909),
    [sym_number] = ACTIONS(2909),
    [sym_private_property_identifier] = ACTIONS(2909),
    [sym_this] = ACTIONS(2911),
    [sym_super] = ACTIONS(2911),
    [sym_true] = ACTIONS(2911),
    [sym_false] = ACTIONS(2911),
    [sym_null] = ACTIONS(2911),
    [sym_undefined] = ACTIONS(2911),
    [anon_sym_AT] = ACTIONS(2909),
    [anon_sym_static] = ACTIONS(2911),
    [anon_sym_readonly] = ACTIONS(2911),
    [anon_sym_get] = ACTIONS(2911),
    [anon_sym_set] = ACTIONS(2911),
    [anon_sym_declare] = ACTIONS(2911),
    [anon_sym_public] = ACTIONS(2911),
    [anon_sym_private] = ACTIONS(2911),
    [anon_sym_protected] = ACTIONS(2911),
    [anon_sym_override] = ACTIONS(2911),
    [anon_sym_module] = ACTIONS(2911),
    [anon_sym_any] = ACTIONS(2911),
    [anon_sym_number] = ACTIONS(2911),
    [anon_sym_boolean] = ACTIONS(2911),
    [anon_sym_string] = ACTIONS(2911),
    [anon_sym_symbol] = ACTIONS(2911),
    [anon_sym_object] = ACTIONS(2911),
    [anon_sym_abstract] = ACTIONS(2911),
    [anon_sym_interface] = ACTIONS(2911),
    [anon_sym_enum] = ACTIONS(2911),
    [sym_html_comment] = ACTIONS(5),
  },
  [924] = {
    [ts_builtin_sym_end] = ACTIONS(2913),
    [sym_identifier] = ACTIONS(2915),
    [anon_sym_export] = ACTIONS(2915),
    [anon_sym_default] = ACTIONS(2915),
    [anon_sym_type] = ACTIONS(2915),
    [anon_sym_namespace] = ACTIONS(2915),
    [anon_sym_LBRACE] = ACTIONS(2913),
    [anon_sym_RBRACE] = ACTIONS(2913),
    [anon_sym_typeof] = ACTIONS(2915),
    [anon_sym_import] = ACTIONS(2915),
    [anon_sym_with] = ACTIONS(2915),
    [anon_sym_var] = ACTIONS(2915),
    [anon_sym_let] = ACTIONS(2915),
    [anon_sym_const] = ACTIONS(2915),
    [anon_sym_BANG] = ACTIONS(2913),
    [anon_sym_else] = ACTIONS(2915),
    [anon_sym_if] = ACTIONS(2915),
    [anon_sym_switch] = ACTIONS(2915),
    [anon_sym_for] = ACTIONS(2915),
    [anon_sym_LPAREN] = ACTIONS(2913),
    [anon_sym_SEMI] = ACTIONS(2913),
    [anon_sym_await] = ACTIONS(2915),
    [anon_sym_while] = ACTIONS(2915),
    [anon_sym_do] = ACTIONS(2915),
    [anon_sym_try] = ACTIONS(2915),
    [anon_sym_break] = ACTIONS(2915),
    [anon_sym_continue] = ACTIONS(2915),
    [anon_sym_debugger] = ACTIONS(2915),
    [anon_sym_return] = ACTIONS(2915),
    [anon_sym_throw] = ACTIONS(2915),
    [anon_sym_case] = ACTIONS(2915),
    [anon_sym_yield] = ACTIONS(2915),
    [anon_sym_LBRACK] = ACTIONS(2913),
    [anon_sym_class] = ACTIONS(2915),
    [anon_sym_async] = ACTIONS(2915),
    [anon_sym_function] = ACTIONS(2915),
    [anon_sym_new] = ACTIONS(2915),
    [anon_sym_using] = ACTIONS(2915),
    [anon_sym_PLUS] = ACTIONS(2915),
    [anon_sym_DASH] = ACTIONS(2915),
    [anon_sym_SLASH] = ACTIONS(2915),
    [anon_sym_LT] = ACTIONS(2913),
    [anon_sym_TILDE] = ACTIONS(2913),
    [anon_sym_void] = ACTIONS(2915),
    [anon_sym_delete] = ACTIONS(2915),
    [anon_sym_PLUS_PLUS] = ACTIONS(2913),
    [anon_sym_DASH_DASH] = ACTIONS(2913),
    [anon_sym_DQUOTE] = ACTIONS(2913),
    [anon_sym_SQUOTE] = ACTIONS(2913),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(2913),
    [sym_number] = ACTIONS(2913),
    [sym_private_property_identifier] = ACTIONS(2913),
    [sym_this] = ACTIONS(2915),
    [sym_super] = ACTIONS(2915),
    [sym_true] = ACTIONS(2915),
    [sym_false] = ACTIONS(2915),
    [sym_null] = ACTIONS(2915),
    [sym_undefined] = ACTIONS(2915),
    [anon_sym_AT] = ACTIONS(2913),
    [anon_sym_static] = ACTIONS(2915),
    [anon_sym_readonly] = ACTIONS(2915),
    [anon_sym_get] = ACTIONS(2915),
    [anon_sym_set] = ACTIONS(2915),
    [anon_sym_declare] = ACTIONS(2915),
    [anon_sym_public] = ACTIONS(2915),
    [anon_sym_private] = ACTIONS(2915),
    [anon_sym_protected] = ACTIONS(2915),
    [anon_sym_override] = ACTIONS(2915),
    [anon_sym_module] = ACTIONS(2915),
    [anon_sym_any] = ACTIONS(2915),
    [anon_sym_number] = ACTIONS(2915),
    [anon_sym_boolean] = ACTIONS(2915),
    [anon_sym_string] = ACTIONS(2915),
    [anon_sym_symbol] = ACTIONS(2915),
    [anon_sym_object] = ACTIONS(2915),
    [anon_sym_abstract] = ACTIONS(2915),
    [anon_sym_interface] = ACTIONS(2915),
    [anon_sym_enum] = ACTIONS(2915),
    [sym_html_comment] = ACTIONS(5),
  },
  [925] = {
    [ts_builtin_sym_end] = ACTIONS(2917),
    [sym_identifier] = ACTIONS(2919),
    [anon_sym_export] = ACTIONS(2919),
    [anon_sym_default] = ACTIONS(2919),
    [anon_sym_type] = ACTIONS(2919),
    [anon_sym_namespace] = ACTIONS(2919),
    [anon_sym_LBRACE] = ACTIONS(2917),
    [anon_sym_RBRACE] = ACTIONS(2917),
    [anon_sym_typeof] = ACTIONS(2919),
    [anon_sym_import] = ACTIONS(2919),
    [anon_sym_with] = ACTIONS(2919),
    [anon_sym_var] = ACTIONS(2919),
    [anon_sym_let] = ACTIONS(2919),
    [anon_sym_const] = ACTIONS(2919),
    [anon_sym_BANG] = ACTIONS(2917),
    [anon_sym_else] = ACTIONS(2919),
    [anon_sym_if] = ACTIONS(2919),
    [anon_sym_switch] = ACTIONS(2919),
    [anon_sym_for] = ACTIONS(2919),
    [anon_sym_LPAREN] = ACTIONS(2917),
    [anon_sym_SEMI] = ACTIONS(2917),
    [anon_sym_await] = ACTIONS(2919),
    [anon_sym_while] = ACTIONS(2919),
    [anon_sym_do] = ACTIONS(2919),
    [anon_sym_try] = ACTIONS(2919),
    [anon_sym_break] = ACTIONS(2919),
    [anon_sym_continue] = ACTIONS(2919),
    [anon_sym_debugger] = ACTIONS(2919),
    [anon_sym_return] = ACTIONS(2919),
    [anon_sym_throw] = ACTIONS(2919),
    [anon_sym_case] = ACTIONS(2919),
    [anon_sym_yield] = ACTIONS(2919),
    [anon_sym_LBRACK] = ACTIONS(2917),
    [anon_sym_class] = ACTIONS(2919),
    [anon_sym_async] = ACTIONS(2919),
    [anon_sym_function] = ACTIONS(2919),
    [anon_sym_new] = ACTIONS(2919),
    [anon_sym_using] = ACTIONS(2919),
    [anon_sym_PLUS] = ACTIONS(2919),
    [anon_sym_DASH] = ACTIONS(2919),
    [anon_sym_SLASH] = ACTIONS(2919),
    [anon_sym_LT] = ACTIONS(2917),
    [anon_sym_TILDE] = ACTIONS(2917),
    [anon_sym_void] = ACTIONS(2919),
    [anon_sym_delete] = ACTIONS(2919),
    [anon_sym_PLUS_PLUS] = ACTIONS(2917),
    [anon_sym_DASH_DASH] = ACTIONS(2917),
    [anon_sym_DQUOTE] = ACTIONS(2917),
    [anon_sym_SQUOTE] = ACTIONS(2917),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(2917),
    [sym_number] = ACTIONS(2917),
    [sym_private_property_identifier] = ACTIONS(2917),
    [sym_this] = ACTIONS(2919),
    [sym_super] = ACTIONS(2919),
    [sym_true] = ACTIONS(2919),
    [sym_false] = ACTIONS(2919),
    [sym_null] = ACTIONS(2919),
    [sym_undefined] = ACTIONS(2919),
    [anon_sym_AT] = ACTIONS(2917),
    [anon_sym_static] = ACTIONS(2919),
    [anon_sym_readonly] = ACTIONS(2919),
    [anon_sym_get] = ACTIONS(2919),
    [anon_sym_set] = ACTIONS(2919),
    [anon_sym_declare] = ACTIONS(2919),
    [anon_sym_public] = ACTIONS(2919),
    [anon_sym_private] = ACTIONS(2919),
    [anon_sym_protected] = ACTIONS(2919),
    [anon_sym_override] = ACTIONS(2919),
    [anon_sym_module] = ACTIONS(2919),
    [anon_sym_any] = ACTIONS(2919),
    [anon_sym_number] = ACTIONS(2919),
    [anon_sym_boolean] = ACTIONS(2919),
    [anon_sym_string] = ACTIONS(2919),
    [anon_sym_symbol] = ACTIONS(2919),
    [anon_sym_object] = ACTIONS(2919),
    [anon_sym_abstract] = ACTIONS(2919),
    [anon_sym_interface] = ACTIONS(2919),
    [anon_sym_enum] = ACTIONS(2919),
    [sym_html_comment] = ACTIONS(5),
  },
  [926] = {
    [ts_builtin_sym_end] = ACTIONS(2913),
    [sym_identifier] = ACTIONS(2915),
    [anon_sym_export] = ACTIONS(2915),
    [anon_sym_default] = ACTIONS(2915),
    [anon_sym_type] = ACTIONS(2915),
    [anon_sym_namespace] = ACTIONS(2915),
    [anon_sym_LBRACE] = ACTIONS(2913),
    [anon_sym_RBRACE] = ACTIONS(2913),
    [anon_sym_typeof] = ACTIONS(2915),
    [anon_sym_import] = ACTIONS(2915),
    [anon_sym_with] = ACTIONS(2915),
    [anon_sym_var] = ACTIONS(2915),
    [anon_sym_let] = ACTIONS(2915),
    [anon_sym_const] = ACTIONS(2915),
    [anon_sym_BANG] = ACTIONS(2913),
    [anon_sym_else] = ACTIONS(2915),
    [anon_sym_if] = ACTIONS(2915),
    [anon_sym_switch] = ACTIONS(2915),
    [anon_sym_for] = ACTIONS(2915),
    [anon_sym_LPAREN] = ACTIONS(2913),
    [anon_sym_SEMI] = ACTIONS(2913),
    [anon_sym_await] = ACTIONS(2915),
    [anon_sym_while] = ACTIONS(2915),
    [anon_sym_do] = ACTIONS(2915),
    [anon_sym_try] = ACTIONS(2915),
    [anon_sym_break] = ACTIONS(2915),
    [anon_sym_continue] = ACTIONS(2915),
    [anon_sym_debugger] = ACTIONS(2915),
    [anon_sym_return] = ACTIONS(2915),
    [anon_sym_throw] = ACTIONS(2915),
    [anon_sym_case] = ACTIONS(2915),
    [anon_sym_yield] = ACTIONS(2915),
    [anon_sym_LBRACK] = ACTIONS(2913),
    [anon_sym_class] = ACTIONS(2915),
    [anon_sym_async] = ACTIONS(2915),
    [anon_sym_function] = ACTIONS(2915),
    [anon_sym_new] = ACTIONS(2915),
    [anon_sym_using] = ACTIONS(2915),
    [anon_sym_PLUS] = ACTIONS(2915),
    [anon_sym_DASH] = ACTIONS(2915),
    [anon_sym_SLASH] = ACTIONS(2915),
    [anon_sym_LT] = ACTIONS(2913),
    [anon_sym_TILDE] = ACTIONS(2913),
    [anon_sym_void] = ACTIONS(2915),
    [anon_sym_delete] = ACTIONS(2915),
    [anon_sym_PLUS_PLUS] = ACTIONS(2913),
    [anon_sym_DASH_DASH] = ACTIONS(2913),
    [anon_sym_DQUOTE] = ACTIONS(2913),
    [anon_sym_SQUOTE] = ACTIONS(2913),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(2913),
    [sym_number] = ACTIONS(2913),
    [sym_private_property_identifier] = ACTIONS(2913),
    [sym_this] = ACTIONS(2915),
    [sym_super] = ACTIONS(2915),
    [sym_true] = ACTIONS(2915),
    [sym_false] = ACTIONS(2915),
    [sym_null] = ACTIONS(2915),
    [sym_undefined] = ACTIONS(2915),
    [anon_sym_AT] = ACTIONS(2913),
    [anon_sym_static] = ACTIONS(2915),
    [anon_sym_readonly] = ACTIONS(2915),
    [anon_sym_get] = ACTIONS(2915),
    [anon_sym_set] = ACTIONS(2915),
    [anon_sym_declare] = ACTIONS(2915),
    [anon_sym_public] = ACTIONS(2915),
    [anon_sym_private] = ACTIONS(2915),
    [anon_sym_protected] = ACTIONS(2915),
    [anon_sym_override] = ACTIONS(2915),
    [anon_sym_module] = ACTIONS(2915),
    [anon_sym_any] = ACTIONS(2915),
    [anon_sym_number] = ACTIONS(2915),
    [anon_sym_boolean] = ACTIONS(2915),
    [anon_sym_string] = ACTIONS(2915),
    [anon_sym_symbol] = ACTIONS(2915),
    [anon_sym_object] = ACTIONS(2915),
    [anon_sym_abstract] = ACTIONS(2915),
    [anon_sym_interface] = ACTIONS(2915),
    [anon_sym_enum] = ACTIONS(2915),
    [sym_html_comment] = ACTIONS(5),
  },
  [927] = {
    [ts_builtin_sym_end] = ACTIONS(2921),
    [sym_identifier] = ACTIONS(2923),
    [anon_sym_export] = ACTIONS(2923),
    [anon_sym_default] = ACTIONS(2923),
    [anon_sym_type] = ACTIONS(2923),
    [anon_sym_namespace] = ACTIONS(2923),
    [anon_sym_LBRACE] = ACTIONS(2921),
    [anon_sym_RBRACE] = ACTIONS(2921),
    [anon_sym_typeof] = ACTIONS(2923),
    [anon_sym_import] = ACTIONS(2923),
    [anon_sym_with] = ACTIONS(2923),
    [anon_sym_var] = ACTIONS(2923),
    [anon_sym_let] = ACTIONS(2923),
    [anon_sym_const] = ACTIONS(2923),
    [anon_sym_BANG] = ACTIONS(2921),
    [anon_sym_else] = ACTIONS(2923),
    [anon_sym_if] = ACTIONS(2923),
    [anon_sym_switch] = ACTIONS(2923),
    [anon_sym_for] = ACTIONS(2923),
    [anon_sym_LPAREN] = ACTIONS(2921),
    [anon_sym_SEMI] = ACTIONS(2921),
    [anon_sym_await] = ACTIONS(2923),
    [anon_sym_while] = ACTIONS(2923),
    [anon_sym_do] = ACTIONS(2923),
    [anon_sym_try] = ACTIONS(2923),
    [anon_sym_break] = ACTIONS(2923),
    [anon_sym_continue] = ACTIONS(2923),
    [anon_sym_debugger] = ACTIONS(2923),
    [anon_sym_return] = ACTIONS(2923),
    [anon_sym_throw] = ACTIONS(2923),
    [anon_sym_case] = ACTIONS(2923),
    [anon_sym_yield] = ACTIONS(2923),
    [anon_sym_LBRACK] = ACTIONS(2921),
    [anon_sym_class] = ACTIONS(2923),
    [anon_sym_async] = ACTIONS(2923),
    [anon_sym_function] = ACTIONS(2923),
    [anon_sym_new] = ACTIONS(2923),
    [anon_sym_using] = ACTIONS(2923),
    [anon_sym_PLUS] = ACTIONS(2923),
    [anon_sym_DASH] = ACTIONS(2923),
    [anon_sym_SLASH] = ACTIONS(2923),
    [anon_sym_LT] = ACTIONS(2921),
    [anon_sym_TILDE] = ACTIONS(2921),
    [anon_sym_void] = ACTIONS(2923),
    [anon_sym_delete] = ACTIONS(2923),
    [anon_sym_PLUS_PLUS] = ACTIONS(2921),
    [anon_sym_DASH_DASH] = ACTIONS(2921),
    [anon_sym_DQUOTE] = ACTIONS(2921),
    [anon_sym_SQUOTE] = ACTIONS(2921),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(2921),
    [sym_number] = ACTIONS(2921),
    [sym_private_property_identifier] = ACTIONS(2921),
    [sym_this] = ACTIONS(2923),
    [sym_super] = ACTIONS(2923),
    [sym_true] = ACTIONS(2923),
    [sym_false] = ACTIONS(2923),
    [sym_null] = ACTIONS(2923),
    [sym_undefined] = ACTIONS(2923),
    [anon_sym_AT] = ACTIONS(2921),
    [anon_sym_static] = ACTIONS(2923),
    [anon_sym_readonly] = ACTIONS(2923),
    [anon_sym_get] = ACTIONS(2923),
    [anon_sym_set] = ACTIONS(2923),
    [anon_sym_declare] = ACTIONS(2923),
    [anon_sym_public] = ACTIONS(2923),
    [anon_sym_private] = ACTIONS(2923),
    [anon_sym_protected] = ACTIONS(2923),
    [anon_sym_override] = ACTIONS(2923),
    [anon_sym_module] = ACTIONS(2923),
    [anon_sym_any] = ACTIONS(2923),
    [anon_sym_number] = ACTIONS(2923),
    [anon_sym_boolean] = ACTIONS(2923),
    [anon_sym_string] = ACTIONS(2923),
    [anon_sym_symbol] = ACTIONS(2923),
    [anon_sym_object] = ACTIONS(2923),
    [anon_sym_abstract] = ACTIONS(2923),
    [anon_sym_interface] = ACTIONS(2923),
    [anon_sym_enum] = ACTIONS(2923),
    [sym_html_comment] = ACTIONS(5),
  },
  [928] = {
    [ts_builtin_sym_end] = ACTIONS(2925),
    [sym_identifier] = ACTIONS(2927),
    [anon_sym_export] = ACTIONS(2927),
    [anon_sym_default] = ACTIONS(2927),
    [anon_sym_type] = ACTIONS(2927),
    [anon_sym_namespace] = ACTIONS(2927),
    [anon_sym_LBRACE] = ACTIONS(2925),
    [anon_sym_RBRACE] = ACTIONS(2925),
    [anon_sym_typeof] = ACTIONS(2927),
    [anon_sym_import] = ACTIONS(2927),
    [anon_sym_with] = ACTIONS(2927),
    [anon_sym_var] = ACTIONS(2927),
    [anon_sym_let] = ACTIONS(2927),
    [anon_sym_const] = ACTIONS(2927),
    [anon_sym_BANG] = ACTIONS(2925),
    [anon_sym_else] = ACTIONS(2927),
    [anon_sym_if] = ACTIONS(2927),
    [anon_sym_switch] = ACTIONS(2927),
    [anon_sym_for] = ACTIONS(2927),
    [anon_sym_LPAREN] = ACTIONS(2925),
    [anon_sym_SEMI] = ACTIONS(2925),
    [anon_sym_await] = ACTIONS(2927),
    [anon_sym_while] = ACTIONS(2927),
    [anon_sym_do] = ACTIONS(2927),
    [anon_sym_try] = ACTIONS(2927),
    [anon_sym_break] = ACTIONS(2927),
    [anon_sym_continue] = ACTIONS(2927),
    [anon_sym_debugger] = ACTIONS(2927),
    [anon_sym_return] = ACTIONS(2927),
    [anon_sym_throw] = ACTIONS(2927),
    [anon_sym_case] = ACTIONS(2927),
    [anon_sym_yield] = ACTIONS(2927),
    [anon_sym_LBRACK] = ACTIONS(2925),
    [anon_sym_class] = ACTIONS(2927),
    [anon_sym_async] = ACTIONS(2927),
    [anon_sym_function] = ACTIONS(2927),
    [anon_sym_new] = ACTIONS(2927),
    [anon_sym_using] = ACTIONS(2927),
    [anon_sym_PLUS] = ACTIONS(2927),
    [anon_sym_DASH] = ACTIONS(2927),
    [anon_sym_SLASH] = ACTIONS(2927),
    [anon_sym_LT] = ACTIONS(2925),
    [anon_sym_TILDE] = ACTIONS(2925),
    [anon_sym_void] = ACTIONS(2927),
    [anon_sym_delete] = ACTIONS(2927),
    [anon_sym_PLUS_PLUS] = ACTIONS(2925),
    [anon_sym_DASH_DASH] = ACTIONS(2925),
    [anon_sym_DQUOTE] = ACTIONS(2925),
    [anon_sym_SQUOTE] = ACTIONS(2925),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(2925),
    [sym_number] = ACTIONS(2925),
    [sym_private_property_identifier] = ACTIONS(2925),
    [sym_this] = ACTIONS(2927),
    [sym_super] = ACTIONS(2927),
    [sym_true] = ACTIONS(2927),
    [sym_false] = ACTIONS(2927),
    [sym_null] = ACTIONS(2927),
    [sym_undefined] = ACTIONS(2927),
    [anon_sym_AT] = ACTIONS(2925),
    [anon_sym_static] = ACTIONS(2927),
    [anon_sym_readonly] = ACTIONS(2927),
    [anon_sym_get] = ACTIONS(2927),
    [anon_sym_set] = ACTIONS(2927),
    [anon_sym_declare] = ACTIONS(2927),
    [anon_sym_public] = ACTIONS(2927),
    [anon_sym_private] = ACTIONS(2927),
    [anon_sym_protected] = ACTIONS(2927),
    [anon_sym_override] = ACTIONS(2927),
    [anon_sym_module] = ACTIONS(2927),
    [anon_sym_any] = ACTIONS(2927),
    [anon_sym_number] = ACTIONS(2927),
    [anon_sym_boolean] = ACTIONS(2927),
    [anon_sym_string] = ACTIONS(2927),
    [anon_sym_symbol] = ACTIONS(2927),
    [anon_sym_object] = ACTIONS(2927),
    [anon_sym_abstract] = ACTIONS(2927),
    [anon_sym_interface] = ACTIONS(2927),
    [anon_sym_enum] = ACTIONS(2927),
    [sym_html_comment] = ACTIONS(5),
  },
  [929] = {
    [ts_builtin_sym_end] = ACTIONS(2561),
    [sym_identifier] = ACTIONS(2563),
    [anon_sym_export] = ACTIONS(2563),
    [anon_sym_default] = ACTIONS(2563),
    [anon_sym_type] = ACTIONS(2563),
    [anon_sym_namespace] = ACTIONS(2563),
    [anon_sym_LBRACE] = ACTIONS(2561),
    [anon_sym_RBRACE] = ACTIONS(2561),
    [anon_sym_typeof] = ACTIONS(2563),
    [anon_sym_import] = ACTIONS(2563),
    [anon_sym_with] = ACTIONS(2563),
    [anon_sym_var] = ACTIONS(2563),
    [anon_sym_let] = ACTIONS(2563),
    [anon_sym_const] = ACTIONS(2563),
    [anon_sym_BANG] = ACTIONS(2561),
    [anon_sym_else] = ACTIONS(2563),
    [anon_sym_if] = ACTIONS(2563),
    [anon_sym_switch] = ACTIONS(2563),
    [anon_sym_for] = ACTIONS(2563),
    [anon_sym_LPAREN] = ACTIONS(2561),
    [anon_sym_SEMI] = ACTIONS(2561),
    [anon_sym_await] = ACTIONS(2563),
    [anon_sym_while] = ACTIONS(2563),
    [anon_sym_do] = ACTIONS(2563),
    [anon_sym_try] = ACTIONS(2563),
    [anon_sym_break] = ACTIONS(2563),
    [anon_sym_continue] = ACTIONS(2563),
    [anon_sym_debugger] = ACTIONS(2563),
    [anon_sym_return] = ACTIONS(2563),
    [anon_sym_throw] = ACTIONS(2563),
    [anon_sym_case] = ACTIONS(2563),
    [anon_sym_yield] = ACTIONS(2563),
    [anon_sym_LBRACK] = ACTIONS(2561),
    [anon_sym_class] = ACTIONS(2563),
    [anon_sym_async] = ACTIONS(2563),
    [anon_sym_function] = ACTIONS(2563),
    [anon_sym_new] = ACTIONS(2563),
    [anon_sym_using] = ACTIONS(2563),
    [anon_sym_PLUS] = ACTIONS(2563),
    [anon_sym_DASH] = ACTIONS(2563),
    [anon_sym_SLASH] = ACTIONS(2563),
    [anon_sym_LT] = ACTIONS(2561),
    [anon_sym_TILDE] = ACTIONS(2561),
    [anon_sym_void] = ACTIONS(2563),
    [anon_sym_delete] = ACTIONS(2563),
    [anon_sym_PLUS_PLUS] = ACTIONS(2561),
    [anon_sym_DASH_DASH] = ACTIONS(2561),
    [anon_sym_DQUOTE] = ACTIONS(2561),
    [anon_sym_SQUOTE] = ACTIONS(2561),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(2561),
    [sym_number] = ACTIONS(2561),
    [sym_private_property_identifier] = ACTIONS(2561),
    [sym_this] = ACTIONS(2563),
    [sym_super] = ACTIONS(2563),
    [sym_true] = ACTIONS(2563),
    [sym_false] = ACTIONS(2563),
    [sym_null] = ACTIONS(2563),
    [sym_undefined] = ACTIONS(2563),
    [anon_sym_AT] = ACTIONS(2561),
    [anon_sym_static] = ACTIONS(2563),
    [anon_sym_readonly] = ACTIONS(2563),
    [anon_sym_get] = ACTIONS(2563),
    [anon_sym_set] = ACTIONS(2563),
    [anon_sym_declare] = ACTIONS(2563),
    [anon_sym_public] = ACTIONS(2563),
    [anon_sym_private] = ACTIONS(2563),
    [anon_sym_protected] = ACTIONS(2563),
    [anon_sym_override] = ACTIONS(2563),
    [anon_sym_module] = ACTIONS(2563),
    [anon_sym_any] = ACTIONS(2563),
    [anon_sym_number] = ACTIONS(2563),
    [anon_sym_boolean] = ACTIONS(2563),
    [anon_sym_string] = ACTIONS(2563),
    [anon_sym_symbol] = ACTIONS(2563),
    [anon_sym_object] = ACTIONS(2563),
    [anon_sym_abstract] = ACTIONS(2563),
    [anon_sym_interface] = ACTIONS(2563),
    [anon_sym_enum] = ACTIONS(2563),
    [sym_html_comment] = ACTIONS(5),
  },
  [930] = {
    [ts_builtin_sym_end] = ACTIONS(2929),
    [sym_identifier] = ACTIONS(2931),
    [anon_sym_export] = ACTIONS(2931),
    [anon_sym_default] = ACTIONS(2931),
    [anon_sym_type] = ACTIONS(2931),
    [anon_sym_namespace] = ACTIONS(2931),
    [anon_sym_LBRACE] = ACTIONS(2929),
    [anon_sym_RBRACE] = ACTIONS(2929),
    [anon_sym_typeof] = ACTIONS(2931),
    [anon_sym_import] = ACTIONS(2931),
    [anon_sym_with] = ACTIONS(2931),
    [anon_sym_var] = ACTIONS(2931),
    [anon_sym_let] = ACTIONS(2931),
    [anon_sym_const] = ACTIONS(2931),
    [anon_sym_BANG] = ACTIONS(2929),
    [anon_sym_else] = ACTIONS(2931),
    [anon_sym_if] = ACTIONS(2931),
    [anon_sym_switch] = ACTIONS(2931),
    [anon_sym_for] = ACTIONS(2931),
    [anon_sym_LPAREN] = ACTIONS(2929),
    [anon_sym_SEMI] = ACTIONS(2929),
    [anon_sym_await] = ACTIONS(2931),
    [anon_sym_while] = ACTIONS(2931),
    [anon_sym_do] = ACTIONS(2931),
    [anon_sym_try] = ACTIONS(2931),
    [anon_sym_break] = ACTIONS(2931),
    [anon_sym_continue] = ACTIONS(2931),
    [anon_sym_debugger] = ACTIONS(2931),
    [anon_sym_return] = ACTIONS(2931),
    [anon_sym_throw] = ACTIONS(2931),
    [anon_sym_case] = ACTIONS(2931),
    [anon_sym_yield] = ACTIONS(2931),
    [anon_sym_LBRACK] = ACTIONS(2929),
    [anon_sym_class] = ACTIONS(2931),
    [anon_sym_async] = ACTIONS(2931),
    [anon_sym_function] = ACTIONS(2931),
    [anon_sym_new] = ACTIONS(2931),
    [anon_sym_using] = ACTIONS(2931),
    [anon_sym_PLUS] = ACTIONS(2931),
    [anon_sym_DASH] = ACTIONS(2931),
    [anon_sym_SLASH] = ACTIONS(2931),
    [anon_sym_LT] = ACTIONS(2929),
    [anon_sym_TILDE] = ACTIONS(2929),
    [anon_sym_void] = ACTIONS(2931),
    [anon_sym_delete] = ACTIONS(2931),
    [anon_sym_PLUS_PLUS] = ACTIONS(2929),
    [anon_sym_DASH_DASH] = ACTIONS(2929),
    [anon_sym_DQUOTE] = ACTIONS(2929),
    [anon_sym_SQUOTE] = ACTIONS(2929),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(2929),
    [sym_number] = ACTIONS(2929),
    [sym_private_property_identifier] = ACTIONS(2929),
    [sym_this] = ACTIONS(2931),
    [sym_super] = ACTIONS(2931),
    [sym_true] = ACTIONS(2931),
    [sym_false] = ACTIONS(2931),
    [sym_null] = ACTIONS(2931),
    [sym_undefined] = ACTIONS(2931),
    [anon_sym_AT] = ACTIONS(2929),
    [anon_sym_static] = ACTIONS(2931),
    [anon_sym_readonly] = ACTIONS(2931),
    [anon_sym_get] = ACTIONS(2931),
    [anon_sym_set] = ACTIONS(2931),
    [anon_sym_declare] = ACTIONS(2931),
    [anon_sym_public] = ACTIONS(2931),
    [anon_sym_private] = ACTIONS(2931),
    [anon_sym_protected] = ACTIONS(2931),
    [anon_sym_override] = ACTIONS(2931),
    [anon_sym_module] = ACTIONS(2931),
    [anon_sym_any] = ACTIONS(2931),
    [anon_sym_number] = ACTIONS(2931),
    [anon_sym_boolean] = ACTIONS(2931),
    [anon_sym_string] = ACTIONS(2931),
    [anon_sym_symbol] = ACTIONS(2931),
    [anon_sym_object] = ACTIONS(2931),
    [anon_sym_abstract] = ACTIONS(2931),
    [anon_sym_interface] = ACTIONS(2931),
    [anon_sym_enum] = ACTIONS(2931),
    [sym_html_comment] = ACTIONS(5),
  },
  [931] = {
    [ts_builtin_sym_end] = ACTIONS(2933),
    [sym_identifier] = ACTIONS(2935),
    [anon_sym_export] = ACTIONS(2935),
    [anon_sym_default] = ACTIONS(2935),
    [anon_sym_type] = ACTIONS(2935),
    [anon_sym_namespace] = ACTIONS(2935),
    [anon_sym_LBRACE] = ACTIONS(2933),
    [anon_sym_RBRACE] = ACTIONS(2933),
    [anon_sym_typeof] = ACTIONS(2935),
    [anon_sym_import] = ACTIONS(2935),
    [anon_sym_with] = ACTIONS(2935),
    [anon_sym_var] = ACTIONS(2935),
    [anon_sym_let] = ACTIONS(2935),
    [anon_sym_const] = ACTIONS(2935),
    [anon_sym_BANG] = ACTIONS(2933),
    [anon_sym_else] = ACTIONS(2935),
    [anon_sym_if] = ACTIONS(2935),
    [anon_sym_switch] = ACTIONS(2935),
    [anon_sym_for] = ACTIONS(2935),
    [anon_sym_LPAREN] = ACTIONS(2933),
    [anon_sym_SEMI] = ACTIONS(2933),
    [anon_sym_await] = ACTIONS(2935),
    [anon_sym_while] = ACTIONS(2935),
    [anon_sym_do] = ACTIONS(2935),
    [anon_sym_try] = ACTIONS(2935),
    [anon_sym_break] = ACTIONS(2935),
    [anon_sym_continue] = ACTIONS(2935),
    [anon_sym_debugger] = ACTIONS(2935),
    [anon_sym_return] = ACTIONS(2935),
    [anon_sym_throw] = ACTIONS(2935),
    [anon_sym_case] = ACTIONS(2935),
    [anon_sym_yield] = ACTIONS(2935),
    [anon_sym_LBRACK] = ACTIONS(2933),
    [anon_sym_class] = ACTIONS(2935),
    [anon_sym_async] = ACTIONS(2935),
    [anon_sym_function] = ACTIONS(2935),
    [anon_sym_new] = ACTIONS(2935),
    [anon_sym_using] = ACTIONS(2935),
    [anon_sym_PLUS] = ACTIONS(2935),
    [anon_sym_DASH] = ACTIONS(2935),
    [anon_sym_SLASH] = ACTIONS(2935),
    [anon_sym_LT] = ACTIONS(2933),
    [anon_sym_TILDE] = ACTIONS(2933),
    [anon_sym_void] = ACTIONS(2935),
    [anon_sym_delete] = ACTIONS(2935),
    [anon_sym_PLUS_PLUS] = ACTIONS(2933),
    [anon_sym_DASH_DASH] = ACTIONS(2933),
    [anon_sym_DQUOTE] = ACTIONS(2933),
    [anon_sym_SQUOTE] = ACTIONS(2933),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(2933),
    [sym_number] = ACTIONS(2933),
    [sym_private_property_identifier] = ACTIONS(2933),
    [sym_this] = ACTIONS(2935),
    [sym_super] = ACTIONS(2935),
    [sym_true] = ACTIONS(2935),
    [sym_false] = ACTIONS(2935),
    [sym_null] = ACTIONS(2935),
    [sym_undefined] = ACTIONS(2935),
    [anon_sym_AT] = ACTIONS(2933),
    [anon_sym_static] = ACTIONS(2935),
    [anon_sym_readonly] = ACTIONS(2935),
    [anon_sym_get] = ACTIONS(2935),
    [anon_sym_set] = ACTIONS(2935),
    [anon_sym_declare] = ACTIONS(2935),
    [anon_sym_public] = ACTIONS(2935),
    [anon_sym_private] = ACTIONS(2935),
    [anon_sym_protected] = ACTIONS(2935),
    [anon_sym_override] = ACTIONS(2935),
    [anon_sym_module] = ACTIONS(2935),
    [anon_sym_any] = ACTIONS(2935),
    [anon_sym_number] = ACTIONS(2935),
    [anon_sym_boolean] = ACTIONS(2935),
    [anon_sym_string] = ACTIONS(2935),
    [anon_sym_symbol] = ACTIONS(2935),
    [anon_sym_object] = ACTIONS(2935),
    [anon_sym_abstract] = ACTIONS(2935),
    [anon_sym_interface] = ACTIONS(2935),
    [anon_sym_enum] = ACTIONS(2935),
    [sym_html_comment] = ACTIONS(5),
  },
  [932] = {
    [ts_builtin_sym_end] = ACTIONS(2937),
    [sym_identifier] = ACTIONS(2939),
    [anon_sym_export] = ACTIONS(2939),
    [anon_sym_default] = ACTIONS(2939),
    [anon_sym_type] = ACTIONS(2939),
    [anon_sym_namespace] = ACTIONS(2939),
    [anon_sym_LBRACE] = ACTIONS(2937),
    [anon_sym_RBRACE] = ACTIONS(2937),
    [anon_sym_typeof] = ACTIONS(2939),
    [anon_sym_import] = ACTIONS(2939),
    [anon_sym_with] = ACTIONS(2939),
    [anon_sym_var] = ACTIONS(2939),
    [anon_sym_let] = ACTIONS(2939),
    [anon_sym_const] = ACTIONS(2939),
    [anon_sym_BANG] = ACTIONS(2937),
    [anon_sym_else] = ACTIONS(2939),
    [anon_sym_if] = ACTIONS(2939),
    [anon_sym_switch] = ACTIONS(2939),
    [anon_sym_for] = ACTIONS(2939),
    [anon_sym_LPAREN] = ACTIONS(2937),
    [anon_sym_SEMI] = ACTIONS(2937),
    [anon_sym_await] = ACTIONS(2939),
    [anon_sym_while] = ACTIONS(2939),
    [anon_sym_do] = ACTIONS(2939),
    [anon_sym_try] = ACTIONS(2939),
    [anon_sym_break] = ACTIONS(2939),
    [anon_sym_continue] = ACTIONS(2939),
    [anon_sym_debugger] = ACTIONS(2939),
    [anon_sym_return] = ACTIONS(2939),
    [anon_sym_throw] = ACTIONS(2939),
    [anon_sym_case] = ACTIONS(2939),
    [anon_sym_yield] = ACTIONS(2939),
    [anon_sym_LBRACK] = ACTIONS(2937),
    [anon_sym_class] = ACTIONS(2939),
    [anon_sym_async] = ACTIONS(2939),
    [anon_sym_function] = ACTIONS(2939),
    [anon_sym_new] = ACTIONS(2939),
    [anon_sym_using] = ACTIONS(2939),
    [anon_sym_PLUS] = ACTIONS(2939),
    [anon_sym_DASH] = ACTIONS(2939),
    [anon_sym_SLASH] = ACTIONS(2939),
    [anon_sym_LT] = ACTIONS(2937),
    [anon_sym_TILDE] = ACTIONS(2937),
    [anon_sym_void] = ACTIONS(2939),
    [anon_sym_delete] = ACTIONS(2939),
    [anon_sym_PLUS_PLUS] = ACTIONS(2937),
    [anon_sym_DASH_DASH] = ACTIONS(2937),
    [anon_sym_DQUOTE] = ACTIONS(2937),
    [anon_sym_SQUOTE] = ACTIONS(2937),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(2937),
    [sym_number] = ACTIONS(2937),
    [sym_private_property_identifier] = ACTIONS(2937),
    [sym_this] = ACTIONS(2939),
    [sym_super] = ACTIONS(2939),
    [sym_true] = ACTIONS(2939),
    [sym_false] = ACTIONS(2939),
    [sym_null] = ACTIONS(2939),
    [sym_undefined] = ACTIONS(2939),
    [anon_sym_AT] = ACTIONS(2937),
    [anon_sym_static] = ACTIONS(2939),
    [anon_sym_readonly] = ACTIONS(2939),
    [anon_sym_get] = ACTIONS(2939),
    [anon_sym_set] = ACTIONS(2939),
    [anon_sym_declare] = ACTIONS(2939),
    [anon_sym_public] = ACTIONS(2939),
    [anon_sym_private] = ACTIONS(2939),
    [anon_sym_protected] = ACTIONS(2939),
    [anon_sym_override] = ACTIONS(2939),
    [anon_sym_module] = ACTIONS(2939),
    [anon_sym_any] = ACTIONS(2939),
    [anon_sym_number] = ACTIONS(2939),
    [anon_sym_boolean] = ACTIONS(2939),
    [anon_sym_string] = ACTIONS(2939),
    [anon_sym_symbol] = ACTIONS(2939),
    [anon_sym_object] = ACTIONS(2939),
    [anon_sym_abstract] = ACTIONS(2939),
    [anon_sym_interface] = ACTIONS(2939),
    [anon_sym_enum] = ACTIONS(2939),
    [sym_html_comment] = ACTIONS(5),
  },
  [933] = {
    [sym_import] = STATE(4681),
    [sym_nested_identifier] = STATE(5474),
    [sym_string] = STATE(2994),
    [sym_formal_parameters] = STATE(5619),
    [sym_rest_pattern] = STATE(5165),
    [sym_nested_type_identifier] = STATE(2939),
    [sym__type_query_member_expression_in_type_annotation] = STATE(3303),
    [sym__type_query_call_expression_in_type_annotation] = STATE(2938),
    [sym_type] = STATE(3773),
    [sym_tuple_parameter] = STATE(5278),
    [sym_optional_tuple_parameter] = STATE(5278),
    [sym_optional_type] = STATE(5278),
    [sym_rest_type] = STATE(5278),
    [sym__tuple_type_member] = STATE(5278),
    [sym_constructor_type] = STATE(3007),
    [sym_primary_type] = STATE(2981),
    [sym_template_literal_type] = STATE(3039),
    [sym_infer_type] = STATE(3007),
    [sym_conditional_type] = STATE(3039),
    [sym_generic_type] = STATE(3039),
    [sym_type_query] = STATE(3039),
    [sym_index_type_query] = STATE(3039),
    [sym_lookup_type] = STATE(3039),
    [sym_literal_type] = STATE(3039),
    [sym__number] = STATE(3041),
    [sym_existential_type] = STATE(3039),
    [sym_flow_maybe_type] = STATE(3039),
    [sym_parenthesized_type] = STATE(3039),
    [sym_predefined_type] = STATE(3039),
    [sym_object_type] = STATE(3039),
    [sym_type_parameters] = STATE(5454),
    [sym_array_type] = STATE(3039),
    [sym_tuple_type] = STATE(3039),
    [sym_readonly_type] = STATE(3007),
    [sym_union_type] = STATE(3039),
    [sym_intersection_type] = STATE(3039),
    [sym_function_type] = STATE(3007),
    [sym_identifier] = ACTIONS(2489),
    [anon_sym_STAR] = ACTIONS(543),
    [anon_sym_LBRACE] = ACTIONS(1534),
    [anon_sym_typeof] = ACTIONS(1536),
    [anon_sym_import] = ACTIONS(1538),
    [anon_sym_const] = ACTIONS(133),
    [anon_sym_LPAREN] = ACTIONS(1540),
    [anon_sym_LBRACK] = ACTIONS(1542),
    [anon_sym_RBRACK] = ACTIONS(2941),
    [anon_sym_new] = ACTIONS(1642),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(2495),
    [anon_sym_AMP] = ACTIONS(571),
    [anon_sym_PIPE] = ACTIONS(573),
    [anon_sym_PLUS] = ACTIONS(2497),
    [anon_sym_DASH] = ACTIONS(2497),
    [anon_sym_LT] = ACTIONS(2499),
    [anon_sym_void] = ACTIONS(216),
    [anon_sym_DQUOTE] = ACTIONS(1550),
    [anon_sym_SQUOTE] = ACTIONS(1552),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1554),
    [sym_number] = ACTIONS(1556),
    [sym_this] = ACTIONS(1558),
    [sym_true] = ACTIONS(1560),
    [sym_false] = ACTIONS(1560),
    [sym_null] = ACTIONS(1560),
    [sym_undefined] = ACTIONS(1560),
    [anon_sym_readonly] = ACTIONS(1648),
    [anon_sym_QMARK] = ACTIONS(593),
    [anon_sym_any] = ACTIONS(216),
    [anon_sym_number] = ACTIONS(216),
    [anon_sym_boolean] = ACTIONS(216),
    [anon_sym_string] = ACTIONS(216),
    [anon_sym_symbol] = ACTIONS(216),
    [anon_sym_object] = ACTIONS(216),
    [anon_sym_abstract] = ACTIONS(597),
    [anon_sym_infer] = ACTIONS(599),
    [anon_sym_keyof] = ACTIONS(601),
    [anon_sym_unique] = ACTIONS(214),
    [anon_sym_unknown] = ACTIONS(216),
    [anon_sym_never] = ACTIONS(216),
    [anon_sym_LBRACE_PIPE] = ACTIONS(218),
    [sym_html_comment] = ACTIONS(5),
  },
  [934] = {
    [ts_builtin_sym_end] = ACTIONS(2943),
    [sym_identifier] = ACTIONS(2945),
    [anon_sym_export] = ACTIONS(2945),
    [anon_sym_default] = ACTIONS(2945),
    [anon_sym_type] = ACTIONS(2945),
    [anon_sym_namespace] = ACTIONS(2945),
    [anon_sym_LBRACE] = ACTIONS(2943),
    [anon_sym_RBRACE] = ACTIONS(2943),
    [anon_sym_typeof] = ACTIONS(2945),
    [anon_sym_import] = ACTIONS(2945),
    [anon_sym_with] = ACTIONS(2945),
    [anon_sym_var] = ACTIONS(2945),
    [anon_sym_let] = ACTIONS(2945),
    [anon_sym_const] = ACTIONS(2945),
    [anon_sym_BANG] = ACTIONS(2943),
    [anon_sym_else] = ACTIONS(2945),
    [anon_sym_if] = ACTIONS(2945),
    [anon_sym_switch] = ACTIONS(2945),
    [anon_sym_for] = ACTIONS(2945),
    [anon_sym_LPAREN] = ACTIONS(2943),
    [anon_sym_SEMI] = ACTIONS(2943),
    [anon_sym_await] = ACTIONS(2945),
    [anon_sym_while] = ACTIONS(2945),
    [anon_sym_do] = ACTIONS(2945),
    [anon_sym_try] = ACTIONS(2945),
    [anon_sym_break] = ACTIONS(2945),
    [anon_sym_continue] = ACTIONS(2945),
    [anon_sym_debugger] = ACTIONS(2945),
    [anon_sym_return] = ACTIONS(2945),
    [anon_sym_throw] = ACTIONS(2945),
    [anon_sym_case] = ACTIONS(2945),
    [anon_sym_yield] = ACTIONS(2945),
    [anon_sym_LBRACK] = ACTIONS(2943),
    [anon_sym_class] = ACTIONS(2945),
    [anon_sym_async] = ACTIONS(2945),
    [anon_sym_function] = ACTIONS(2945),
    [anon_sym_new] = ACTIONS(2945),
    [anon_sym_using] = ACTIONS(2945),
    [anon_sym_PLUS] = ACTIONS(2945),
    [anon_sym_DASH] = ACTIONS(2945),
    [anon_sym_SLASH] = ACTIONS(2945),
    [anon_sym_LT] = ACTIONS(2943),
    [anon_sym_TILDE] = ACTIONS(2943),
    [anon_sym_void] = ACTIONS(2945),
    [anon_sym_delete] = ACTIONS(2945),
    [anon_sym_PLUS_PLUS] = ACTIONS(2943),
    [anon_sym_DASH_DASH] = ACTIONS(2943),
    [anon_sym_DQUOTE] = ACTIONS(2943),
    [anon_sym_SQUOTE] = ACTIONS(2943),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(2943),
    [sym_number] = ACTIONS(2943),
    [sym_private_property_identifier] = ACTIONS(2943),
    [sym_this] = ACTIONS(2945),
    [sym_super] = ACTIONS(2945),
    [sym_true] = ACTIONS(2945),
    [sym_false] = ACTIONS(2945),
    [sym_null] = ACTIONS(2945),
    [sym_undefined] = ACTIONS(2945),
    [anon_sym_AT] = ACTIONS(2943),
    [anon_sym_static] = ACTIONS(2945),
    [anon_sym_readonly] = ACTIONS(2945),
    [anon_sym_get] = ACTIONS(2945),
    [anon_sym_set] = ACTIONS(2945),
    [anon_sym_declare] = ACTIONS(2945),
    [anon_sym_public] = ACTIONS(2945),
    [anon_sym_private] = ACTIONS(2945),
    [anon_sym_protected] = ACTIONS(2945),
    [anon_sym_override] = ACTIONS(2945),
    [anon_sym_module] = ACTIONS(2945),
    [anon_sym_any] = ACTIONS(2945),
    [anon_sym_number] = ACTIONS(2945),
    [anon_sym_boolean] = ACTIONS(2945),
    [anon_sym_string] = ACTIONS(2945),
    [anon_sym_symbol] = ACTIONS(2945),
    [anon_sym_object] = ACTIONS(2945),
    [anon_sym_abstract] = ACTIONS(2945),
    [anon_sym_interface] = ACTIONS(2945),
    [anon_sym_enum] = ACTIONS(2945),
    [sym_html_comment] = ACTIONS(5),
  },
  [935] = {
    [sym_import] = STATE(4681),
    [sym_nested_identifier] = STATE(5474),
    [sym_string] = STATE(2994),
    [sym_formal_parameters] = STATE(5619),
    [sym_rest_pattern] = STATE(5165),
    [sym_nested_type_identifier] = STATE(2939),
    [sym__type_query_member_expression_in_type_annotation] = STATE(3303),
    [sym__type_query_call_expression_in_type_annotation] = STATE(2938),
    [sym_type] = STATE(3773),
    [sym_tuple_parameter] = STATE(5278),
    [sym_optional_tuple_parameter] = STATE(5278),
    [sym_optional_type] = STATE(5278),
    [sym_rest_type] = STATE(5278),
    [sym__tuple_type_member] = STATE(5278),
    [sym_constructor_type] = STATE(3007),
    [sym_primary_type] = STATE(2981),
    [sym_template_literal_type] = STATE(3039),
    [sym_infer_type] = STATE(3007),
    [sym_conditional_type] = STATE(3039),
    [sym_generic_type] = STATE(3039),
    [sym_type_query] = STATE(3039),
    [sym_index_type_query] = STATE(3039),
    [sym_lookup_type] = STATE(3039),
    [sym_literal_type] = STATE(3039),
    [sym__number] = STATE(3041),
    [sym_existential_type] = STATE(3039),
    [sym_flow_maybe_type] = STATE(3039),
    [sym_parenthesized_type] = STATE(3039),
    [sym_predefined_type] = STATE(3039),
    [sym_object_type] = STATE(3039),
    [sym_type_parameters] = STATE(5454),
    [sym_array_type] = STATE(3039),
    [sym_tuple_type] = STATE(3039),
    [sym_readonly_type] = STATE(3007),
    [sym_union_type] = STATE(3039),
    [sym_intersection_type] = STATE(3039),
    [sym_function_type] = STATE(3007),
    [sym_identifier] = ACTIONS(2489),
    [anon_sym_STAR] = ACTIONS(543),
    [anon_sym_LBRACE] = ACTIONS(1534),
    [anon_sym_typeof] = ACTIONS(1536),
    [anon_sym_import] = ACTIONS(1538),
    [anon_sym_const] = ACTIONS(133),
    [anon_sym_LPAREN] = ACTIONS(1540),
    [anon_sym_LBRACK] = ACTIONS(1542),
    [anon_sym_RBRACK] = ACTIONS(2947),
    [anon_sym_new] = ACTIONS(1642),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(2495),
    [anon_sym_AMP] = ACTIONS(571),
    [anon_sym_PIPE] = ACTIONS(573),
    [anon_sym_PLUS] = ACTIONS(2497),
    [anon_sym_DASH] = ACTIONS(2497),
    [anon_sym_LT] = ACTIONS(2499),
    [anon_sym_void] = ACTIONS(216),
    [anon_sym_DQUOTE] = ACTIONS(1550),
    [anon_sym_SQUOTE] = ACTIONS(1552),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1554),
    [sym_number] = ACTIONS(1556),
    [sym_this] = ACTIONS(1558),
    [sym_true] = ACTIONS(1560),
    [sym_false] = ACTIONS(1560),
    [sym_null] = ACTIONS(1560),
    [sym_undefined] = ACTIONS(1560),
    [anon_sym_readonly] = ACTIONS(1648),
    [anon_sym_QMARK] = ACTIONS(593),
    [anon_sym_any] = ACTIONS(216),
    [anon_sym_number] = ACTIONS(216),
    [anon_sym_boolean] = ACTIONS(216),
    [anon_sym_string] = ACTIONS(216),
    [anon_sym_symbol] = ACTIONS(216),
    [anon_sym_object] = ACTIONS(216),
    [anon_sym_abstract] = ACTIONS(597),
    [anon_sym_infer] = ACTIONS(599),
    [anon_sym_keyof] = ACTIONS(601),
    [anon_sym_unique] = ACTIONS(214),
    [anon_sym_unknown] = ACTIONS(216),
    [anon_sym_never] = ACTIONS(216),
    [anon_sym_LBRACE_PIPE] = ACTIONS(218),
    [sym_html_comment] = ACTIONS(5),
  },
  [936] = {
    [ts_builtin_sym_end] = ACTIONS(2949),
    [sym_identifier] = ACTIONS(2951),
    [anon_sym_export] = ACTIONS(2951),
    [anon_sym_default] = ACTIONS(2951),
    [anon_sym_type] = ACTIONS(2951),
    [anon_sym_namespace] = ACTIONS(2951),
    [anon_sym_LBRACE] = ACTIONS(2949),
    [anon_sym_RBRACE] = ACTIONS(2949),
    [anon_sym_typeof] = ACTIONS(2951),
    [anon_sym_import] = ACTIONS(2951),
    [anon_sym_with] = ACTIONS(2951),
    [anon_sym_var] = ACTIONS(2951),
    [anon_sym_let] = ACTIONS(2951),
    [anon_sym_const] = ACTIONS(2951),
    [anon_sym_BANG] = ACTIONS(2949),
    [anon_sym_else] = ACTIONS(2951),
    [anon_sym_if] = ACTIONS(2951),
    [anon_sym_switch] = ACTIONS(2951),
    [anon_sym_for] = ACTIONS(2951),
    [anon_sym_LPAREN] = ACTIONS(2949),
    [anon_sym_SEMI] = ACTIONS(2949),
    [anon_sym_await] = ACTIONS(2951),
    [anon_sym_while] = ACTIONS(2951),
    [anon_sym_do] = ACTIONS(2951),
    [anon_sym_try] = ACTIONS(2951),
    [anon_sym_break] = ACTIONS(2951),
    [anon_sym_continue] = ACTIONS(2951),
    [anon_sym_debugger] = ACTIONS(2951),
    [anon_sym_return] = ACTIONS(2951),
    [anon_sym_throw] = ACTIONS(2951),
    [anon_sym_case] = ACTIONS(2951),
    [anon_sym_yield] = ACTIONS(2951),
    [anon_sym_LBRACK] = ACTIONS(2949),
    [anon_sym_class] = ACTIONS(2951),
    [anon_sym_async] = ACTIONS(2951),
    [anon_sym_function] = ACTIONS(2951),
    [anon_sym_new] = ACTIONS(2951),
    [anon_sym_using] = ACTIONS(2951),
    [anon_sym_PLUS] = ACTIONS(2951),
    [anon_sym_DASH] = ACTIONS(2951),
    [anon_sym_SLASH] = ACTIONS(2951),
    [anon_sym_LT] = ACTIONS(2949),
    [anon_sym_TILDE] = ACTIONS(2949),
    [anon_sym_void] = ACTIONS(2951),
    [anon_sym_delete] = ACTIONS(2951),
    [anon_sym_PLUS_PLUS] = ACTIONS(2949),
    [anon_sym_DASH_DASH] = ACTIONS(2949),
    [anon_sym_DQUOTE] = ACTIONS(2949),
    [anon_sym_SQUOTE] = ACTIONS(2949),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(2949),
    [sym_number] = ACTIONS(2949),
    [sym_private_property_identifier] = ACTIONS(2949),
    [sym_this] = ACTIONS(2951),
    [sym_super] = ACTIONS(2951),
    [sym_true] = ACTIONS(2951),
    [sym_false] = ACTIONS(2951),
    [sym_null] = ACTIONS(2951),
    [sym_undefined] = ACTIONS(2951),
    [anon_sym_AT] = ACTIONS(2949),
    [anon_sym_static] = ACTIONS(2951),
    [anon_sym_readonly] = ACTIONS(2951),
    [anon_sym_get] = ACTIONS(2951),
    [anon_sym_set] = ACTIONS(2951),
    [anon_sym_declare] = ACTIONS(2951),
    [anon_sym_public] = ACTIONS(2951),
    [anon_sym_private] = ACTIONS(2951),
    [anon_sym_protected] = ACTIONS(2951),
    [anon_sym_override] = ACTIONS(2951),
    [anon_sym_module] = ACTIONS(2951),
    [anon_sym_any] = ACTIONS(2951),
    [anon_sym_number] = ACTIONS(2951),
    [anon_sym_boolean] = ACTIONS(2951),
    [anon_sym_string] = ACTIONS(2951),
    [anon_sym_symbol] = ACTIONS(2951),
    [anon_sym_object] = ACTIONS(2951),
    [anon_sym_abstract] = ACTIONS(2951),
    [anon_sym_interface] = ACTIONS(2951),
    [anon_sym_enum] = ACTIONS(2951),
    [sym_html_comment] = ACTIONS(5),
  },
  [937] = {
    [ts_builtin_sym_end] = ACTIONS(2953),
    [sym_identifier] = ACTIONS(2955),
    [anon_sym_export] = ACTIONS(2955),
    [anon_sym_default] = ACTIONS(2955),
    [anon_sym_type] = ACTIONS(2955),
    [anon_sym_namespace] = ACTIONS(2955),
    [anon_sym_LBRACE] = ACTIONS(2953),
    [anon_sym_RBRACE] = ACTIONS(2953),
    [anon_sym_typeof] = ACTIONS(2955),
    [anon_sym_import] = ACTIONS(2955),
    [anon_sym_with] = ACTIONS(2955),
    [anon_sym_var] = ACTIONS(2955),
    [anon_sym_let] = ACTIONS(2955),
    [anon_sym_const] = ACTIONS(2955),
    [anon_sym_BANG] = ACTIONS(2953),
    [anon_sym_else] = ACTIONS(2955),
    [anon_sym_if] = ACTIONS(2955),
    [anon_sym_switch] = ACTIONS(2955),
    [anon_sym_for] = ACTIONS(2955),
    [anon_sym_LPAREN] = ACTIONS(2953),
    [anon_sym_SEMI] = ACTIONS(2953),
    [anon_sym_await] = ACTIONS(2955),
    [anon_sym_while] = ACTIONS(2955),
    [anon_sym_do] = ACTIONS(2955),
    [anon_sym_try] = ACTIONS(2955),
    [anon_sym_break] = ACTIONS(2955),
    [anon_sym_continue] = ACTIONS(2955),
    [anon_sym_debugger] = ACTIONS(2955),
    [anon_sym_return] = ACTIONS(2955),
    [anon_sym_throw] = ACTIONS(2955),
    [anon_sym_case] = ACTIONS(2955),
    [anon_sym_yield] = ACTIONS(2955),
    [anon_sym_LBRACK] = ACTIONS(2953),
    [anon_sym_class] = ACTIONS(2955),
    [anon_sym_async] = ACTIONS(2955),
    [anon_sym_function] = ACTIONS(2955),
    [anon_sym_new] = ACTIONS(2955),
    [anon_sym_using] = ACTIONS(2955),
    [anon_sym_PLUS] = ACTIONS(2955),
    [anon_sym_DASH] = ACTIONS(2955),
    [anon_sym_SLASH] = ACTIONS(2955),
    [anon_sym_LT] = ACTIONS(2953),
    [anon_sym_TILDE] = ACTIONS(2953),
    [anon_sym_void] = ACTIONS(2955),
    [anon_sym_delete] = ACTIONS(2955),
    [anon_sym_PLUS_PLUS] = ACTIONS(2953),
    [anon_sym_DASH_DASH] = ACTIONS(2953),
    [anon_sym_DQUOTE] = ACTIONS(2953),
    [anon_sym_SQUOTE] = ACTIONS(2953),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(2953),
    [sym_number] = ACTIONS(2953),
    [sym_private_property_identifier] = ACTIONS(2953),
    [sym_this] = ACTIONS(2955),
    [sym_super] = ACTIONS(2955),
    [sym_true] = ACTIONS(2955),
    [sym_false] = ACTIONS(2955),
    [sym_null] = ACTIONS(2955),
    [sym_undefined] = ACTIONS(2955),
    [anon_sym_AT] = ACTIONS(2953),
    [anon_sym_static] = ACTIONS(2955),
    [anon_sym_readonly] = ACTIONS(2955),
    [anon_sym_get] = ACTIONS(2955),
    [anon_sym_set] = ACTIONS(2955),
    [anon_sym_declare] = ACTIONS(2955),
    [anon_sym_public] = ACTIONS(2955),
    [anon_sym_private] = ACTIONS(2955),
    [anon_sym_protected] = ACTIONS(2955),
    [anon_sym_override] = ACTIONS(2955),
    [anon_sym_module] = ACTIONS(2955),
    [anon_sym_any] = ACTIONS(2955),
    [anon_sym_number] = ACTIONS(2955),
    [anon_sym_boolean] = ACTIONS(2955),
    [anon_sym_string] = ACTIONS(2955),
    [anon_sym_symbol] = ACTIONS(2955),
    [anon_sym_object] = ACTIONS(2955),
    [anon_sym_abstract] = ACTIONS(2955),
    [anon_sym_interface] = ACTIONS(2955),
    [anon_sym_enum] = ACTIONS(2955),
    [sym_html_comment] = ACTIONS(5),
  },
  [938] = {
    [ts_builtin_sym_end] = ACTIONS(2561),
    [sym_identifier] = ACTIONS(2563),
    [anon_sym_export] = ACTIONS(2563),
    [anon_sym_default] = ACTIONS(2563),
    [anon_sym_type] = ACTIONS(2563),
    [anon_sym_namespace] = ACTIONS(2563),
    [anon_sym_LBRACE] = ACTIONS(2561),
    [anon_sym_RBRACE] = ACTIONS(2561),
    [anon_sym_typeof] = ACTIONS(2563),
    [anon_sym_import] = ACTIONS(2563),
    [anon_sym_with] = ACTIONS(2563),
    [anon_sym_var] = ACTIONS(2563),
    [anon_sym_let] = ACTIONS(2563),
    [anon_sym_const] = ACTIONS(2563),
    [anon_sym_BANG] = ACTIONS(2561),
    [anon_sym_else] = ACTIONS(2563),
    [anon_sym_if] = ACTIONS(2563),
    [anon_sym_switch] = ACTIONS(2563),
    [anon_sym_for] = ACTIONS(2563),
    [anon_sym_LPAREN] = ACTIONS(2561),
    [anon_sym_SEMI] = ACTIONS(2561),
    [anon_sym_await] = ACTIONS(2563),
    [anon_sym_while] = ACTIONS(2563),
    [anon_sym_do] = ACTIONS(2563),
    [anon_sym_try] = ACTIONS(2563),
    [anon_sym_break] = ACTIONS(2563),
    [anon_sym_continue] = ACTIONS(2563),
    [anon_sym_debugger] = ACTIONS(2563),
    [anon_sym_return] = ACTIONS(2563),
    [anon_sym_throw] = ACTIONS(2563),
    [anon_sym_case] = ACTIONS(2563),
    [anon_sym_yield] = ACTIONS(2563),
    [anon_sym_LBRACK] = ACTIONS(2561),
    [anon_sym_class] = ACTIONS(2563),
    [anon_sym_async] = ACTIONS(2563),
    [anon_sym_function] = ACTIONS(2563),
    [anon_sym_new] = ACTIONS(2563),
    [anon_sym_using] = ACTIONS(2563),
    [anon_sym_PLUS] = ACTIONS(2563),
    [anon_sym_DASH] = ACTIONS(2563),
    [anon_sym_SLASH] = ACTIONS(2563),
    [anon_sym_LT] = ACTIONS(2561),
    [anon_sym_TILDE] = ACTIONS(2561),
    [anon_sym_void] = ACTIONS(2563),
    [anon_sym_delete] = ACTIONS(2563),
    [anon_sym_PLUS_PLUS] = ACTIONS(2561),
    [anon_sym_DASH_DASH] = ACTIONS(2561),
    [anon_sym_DQUOTE] = ACTIONS(2561),
    [anon_sym_SQUOTE] = ACTIONS(2561),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(2561),
    [sym_number] = ACTIONS(2561),
    [sym_private_property_identifier] = ACTIONS(2561),
    [sym_this] = ACTIONS(2563),
    [sym_super] = ACTIONS(2563),
    [sym_true] = ACTIONS(2563),
    [sym_false] = ACTIONS(2563),
    [sym_null] = ACTIONS(2563),
    [sym_undefined] = ACTIONS(2563),
    [anon_sym_AT] = ACTIONS(2561),
    [anon_sym_static] = ACTIONS(2563),
    [anon_sym_readonly] = ACTIONS(2563),
    [anon_sym_get] = ACTIONS(2563),
    [anon_sym_set] = ACTIONS(2563),
    [anon_sym_declare] = ACTIONS(2563),
    [anon_sym_public] = ACTIONS(2563),
    [anon_sym_private] = ACTIONS(2563),
    [anon_sym_protected] = ACTIONS(2563),
    [anon_sym_override] = ACTIONS(2563),
    [anon_sym_module] = ACTIONS(2563),
    [anon_sym_any] = ACTIONS(2563),
    [anon_sym_number] = ACTIONS(2563),
    [anon_sym_boolean] = ACTIONS(2563),
    [anon_sym_string] = ACTIONS(2563),
    [anon_sym_symbol] = ACTIONS(2563),
    [anon_sym_object] = ACTIONS(2563),
    [anon_sym_abstract] = ACTIONS(2563),
    [anon_sym_interface] = ACTIONS(2563),
    [anon_sym_enum] = ACTIONS(2563),
    [sym_html_comment] = ACTIONS(5),
  },
  [939] = {
    [ts_builtin_sym_end] = ACTIONS(2957),
    [sym_identifier] = ACTIONS(2959),
    [anon_sym_export] = ACTIONS(2959),
    [anon_sym_default] = ACTIONS(2959),
    [anon_sym_type] = ACTIONS(2959),
    [anon_sym_namespace] = ACTIONS(2959),
    [anon_sym_LBRACE] = ACTIONS(2957),
    [anon_sym_RBRACE] = ACTIONS(2957),
    [anon_sym_typeof] = ACTIONS(2959),
    [anon_sym_import] = ACTIONS(2959),
    [anon_sym_with] = ACTIONS(2959),
    [anon_sym_var] = ACTIONS(2959),
    [anon_sym_let] = ACTIONS(2959),
    [anon_sym_const] = ACTIONS(2959),
    [anon_sym_BANG] = ACTIONS(2957),
    [anon_sym_else] = ACTIONS(2959),
    [anon_sym_if] = ACTIONS(2959),
    [anon_sym_switch] = ACTIONS(2959),
    [anon_sym_for] = ACTIONS(2959),
    [anon_sym_LPAREN] = ACTIONS(2957),
    [anon_sym_SEMI] = ACTIONS(2957),
    [anon_sym_await] = ACTIONS(2959),
    [anon_sym_while] = ACTIONS(2959),
    [anon_sym_do] = ACTIONS(2959),
    [anon_sym_try] = ACTIONS(2959),
    [anon_sym_break] = ACTIONS(2959),
    [anon_sym_continue] = ACTIONS(2959),
    [anon_sym_debugger] = ACTIONS(2959),
    [anon_sym_return] = ACTIONS(2959),
    [anon_sym_throw] = ACTIONS(2959),
    [anon_sym_case] = ACTIONS(2959),
    [anon_sym_yield] = ACTIONS(2959),
    [anon_sym_LBRACK] = ACTIONS(2957),
    [anon_sym_class] = ACTIONS(2959),
    [anon_sym_async] = ACTIONS(2959),
    [anon_sym_function] = ACTIONS(2959),
    [anon_sym_new] = ACTIONS(2959),
    [anon_sym_using] = ACTIONS(2959),
    [anon_sym_PLUS] = ACTIONS(2959),
    [anon_sym_DASH] = ACTIONS(2959),
    [anon_sym_SLASH] = ACTIONS(2959),
    [anon_sym_LT] = ACTIONS(2957),
    [anon_sym_TILDE] = ACTIONS(2957),
    [anon_sym_void] = ACTIONS(2959),
    [anon_sym_delete] = ACTIONS(2959),
    [anon_sym_PLUS_PLUS] = ACTIONS(2957),
    [anon_sym_DASH_DASH] = ACTIONS(2957),
    [anon_sym_DQUOTE] = ACTIONS(2957),
    [anon_sym_SQUOTE] = ACTIONS(2957),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(2957),
    [sym_number] = ACTIONS(2957),
    [sym_private_property_identifier] = ACTIONS(2957),
    [sym_this] = ACTIONS(2959),
    [sym_super] = ACTIONS(2959),
    [sym_true] = ACTIONS(2959),
    [sym_false] = ACTIONS(2959),
    [sym_null] = ACTIONS(2959),
    [sym_undefined] = ACTIONS(2959),
    [anon_sym_AT] = ACTIONS(2957),
    [anon_sym_static] = ACTIONS(2959),
    [anon_sym_readonly] = ACTIONS(2959),
    [anon_sym_get] = ACTIONS(2959),
    [anon_sym_set] = ACTIONS(2959),
    [anon_sym_declare] = ACTIONS(2959),
    [anon_sym_public] = ACTIONS(2959),
    [anon_sym_private] = ACTIONS(2959),
    [anon_sym_protected] = ACTIONS(2959),
    [anon_sym_override] = ACTIONS(2959),
    [anon_sym_module] = ACTIONS(2959),
    [anon_sym_any] = ACTIONS(2959),
    [anon_sym_number] = ACTIONS(2959),
    [anon_sym_boolean] = ACTIONS(2959),
    [anon_sym_string] = ACTIONS(2959),
    [anon_sym_symbol] = ACTIONS(2959),
    [anon_sym_object] = ACTIONS(2959),
    [anon_sym_abstract] = ACTIONS(2959),
    [anon_sym_interface] = ACTIONS(2959),
    [anon_sym_enum] = ACTIONS(2959),
    [sym_html_comment] = ACTIONS(5),
  },
  [940] = {
    [ts_builtin_sym_end] = ACTIONS(2961),
    [sym_identifier] = ACTIONS(2963),
    [anon_sym_export] = ACTIONS(2963),
    [anon_sym_default] = ACTIONS(2963),
    [anon_sym_type] = ACTIONS(2963),
    [anon_sym_namespace] = ACTIONS(2963),
    [anon_sym_LBRACE] = ACTIONS(2961),
    [anon_sym_RBRACE] = ACTIONS(2961),
    [anon_sym_typeof] = ACTIONS(2963),
    [anon_sym_import] = ACTIONS(2963),
    [anon_sym_with] = ACTIONS(2963),
    [anon_sym_var] = ACTIONS(2963),
    [anon_sym_let] = ACTIONS(2963),
    [anon_sym_const] = ACTIONS(2963),
    [anon_sym_BANG] = ACTIONS(2961),
    [anon_sym_else] = ACTIONS(2963),
    [anon_sym_if] = ACTIONS(2963),
    [anon_sym_switch] = ACTIONS(2963),
    [anon_sym_for] = ACTIONS(2963),
    [anon_sym_LPAREN] = ACTIONS(2961),
    [anon_sym_SEMI] = ACTIONS(2961),
    [anon_sym_await] = ACTIONS(2963),
    [anon_sym_while] = ACTIONS(2963),
    [anon_sym_do] = ACTIONS(2963),
    [anon_sym_try] = ACTIONS(2963),
    [anon_sym_break] = ACTIONS(2963),
    [anon_sym_continue] = ACTIONS(2963),
    [anon_sym_debugger] = ACTIONS(2963),
    [anon_sym_return] = ACTIONS(2963),
    [anon_sym_throw] = ACTIONS(2963),
    [anon_sym_case] = ACTIONS(2963),
    [anon_sym_yield] = ACTIONS(2963),
    [anon_sym_LBRACK] = ACTIONS(2961),
    [anon_sym_class] = ACTIONS(2963),
    [anon_sym_async] = ACTIONS(2963),
    [anon_sym_function] = ACTIONS(2963),
    [anon_sym_new] = ACTIONS(2963),
    [anon_sym_using] = ACTIONS(2963),
    [anon_sym_PLUS] = ACTIONS(2963),
    [anon_sym_DASH] = ACTIONS(2963),
    [anon_sym_SLASH] = ACTIONS(2963),
    [anon_sym_LT] = ACTIONS(2961),
    [anon_sym_TILDE] = ACTIONS(2961),
    [anon_sym_void] = ACTIONS(2963),
    [anon_sym_delete] = ACTIONS(2963),
    [anon_sym_PLUS_PLUS] = ACTIONS(2961),
    [anon_sym_DASH_DASH] = ACTIONS(2961),
    [anon_sym_DQUOTE] = ACTIONS(2961),
    [anon_sym_SQUOTE] = ACTIONS(2961),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(2961),
    [sym_number] = ACTIONS(2961),
    [sym_private_property_identifier] = ACTIONS(2961),
    [sym_this] = ACTIONS(2963),
    [sym_super] = ACTIONS(2963),
    [sym_true] = ACTIONS(2963),
    [sym_false] = ACTIONS(2963),
    [sym_null] = ACTIONS(2963),
    [sym_undefined] = ACTIONS(2963),
    [anon_sym_AT] = ACTIONS(2961),
    [anon_sym_static] = ACTIONS(2963),
    [anon_sym_readonly] = ACTIONS(2963),
    [anon_sym_get] = ACTIONS(2963),
    [anon_sym_set] = ACTIONS(2963),
    [anon_sym_declare] = ACTIONS(2963),
    [anon_sym_public] = ACTIONS(2963),
    [anon_sym_private] = ACTIONS(2963),
    [anon_sym_protected] = ACTIONS(2963),
    [anon_sym_override] = ACTIONS(2963),
    [anon_sym_module] = ACTIONS(2963),
    [anon_sym_any] = ACTIONS(2963),
    [anon_sym_number] = ACTIONS(2963),
    [anon_sym_boolean] = ACTIONS(2963),
    [anon_sym_string] = ACTIONS(2963),
    [anon_sym_symbol] = ACTIONS(2963),
    [anon_sym_object] = ACTIONS(2963),
    [anon_sym_abstract] = ACTIONS(2963),
    [anon_sym_interface] = ACTIONS(2963),
    [anon_sym_enum] = ACTIONS(2963),
    [sym_html_comment] = ACTIONS(5),
  },
  [941] = {
    [ts_builtin_sym_end] = ACTIONS(2965),
    [sym_identifier] = ACTIONS(2967),
    [anon_sym_export] = ACTIONS(2967),
    [anon_sym_default] = ACTIONS(2967),
    [anon_sym_type] = ACTIONS(2967),
    [anon_sym_namespace] = ACTIONS(2967),
    [anon_sym_LBRACE] = ACTIONS(2965),
    [anon_sym_RBRACE] = ACTIONS(2965),
    [anon_sym_typeof] = ACTIONS(2967),
    [anon_sym_import] = ACTIONS(2967),
    [anon_sym_with] = ACTIONS(2967),
    [anon_sym_var] = ACTIONS(2967),
    [anon_sym_let] = ACTIONS(2967),
    [anon_sym_const] = ACTIONS(2967),
    [anon_sym_BANG] = ACTIONS(2965),
    [anon_sym_else] = ACTIONS(2967),
    [anon_sym_if] = ACTIONS(2967),
    [anon_sym_switch] = ACTIONS(2967),
    [anon_sym_for] = ACTIONS(2967),
    [anon_sym_LPAREN] = ACTIONS(2965),
    [anon_sym_SEMI] = ACTIONS(2965),
    [anon_sym_await] = ACTIONS(2967),
    [anon_sym_while] = ACTIONS(2967),
    [anon_sym_do] = ACTIONS(2967),
    [anon_sym_try] = ACTIONS(2967),
    [anon_sym_break] = ACTIONS(2967),
    [anon_sym_continue] = ACTIONS(2967),
    [anon_sym_debugger] = ACTIONS(2967),
    [anon_sym_return] = ACTIONS(2967),
    [anon_sym_throw] = ACTIONS(2967),
    [anon_sym_case] = ACTIONS(2967),
    [anon_sym_yield] = ACTIONS(2967),
    [anon_sym_LBRACK] = ACTIONS(2965),
    [anon_sym_class] = ACTIONS(2967),
    [anon_sym_async] = ACTIONS(2967),
    [anon_sym_function] = ACTIONS(2967),
    [anon_sym_new] = ACTIONS(2967),
    [anon_sym_using] = ACTIONS(2967),
    [anon_sym_PLUS] = ACTIONS(2967),
    [anon_sym_DASH] = ACTIONS(2967),
    [anon_sym_SLASH] = ACTIONS(2967),
    [anon_sym_LT] = ACTIONS(2965),
    [anon_sym_TILDE] = ACTIONS(2965),
    [anon_sym_void] = ACTIONS(2967),
    [anon_sym_delete] = ACTIONS(2967),
    [anon_sym_PLUS_PLUS] = ACTIONS(2965),
    [anon_sym_DASH_DASH] = ACTIONS(2965),
    [anon_sym_DQUOTE] = ACTIONS(2965),
    [anon_sym_SQUOTE] = ACTIONS(2965),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(2965),
    [sym_number] = ACTIONS(2965),
    [sym_private_property_identifier] = ACTIONS(2965),
    [sym_this] = ACTIONS(2967),
    [sym_super] = ACTIONS(2967),
    [sym_true] = ACTIONS(2967),
    [sym_false] = ACTIONS(2967),
    [sym_null] = ACTIONS(2967),
    [sym_undefined] = ACTIONS(2967),
    [anon_sym_AT] = ACTIONS(2965),
    [anon_sym_static] = ACTIONS(2967),
    [anon_sym_readonly] = ACTIONS(2967),
    [anon_sym_get] = ACTIONS(2967),
    [anon_sym_set] = ACTIONS(2967),
    [anon_sym_declare] = ACTIONS(2967),
    [anon_sym_public] = ACTIONS(2967),
    [anon_sym_private] = ACTIONS(2967),
    [anon_sym_protected] = ACTIONS(2967),
    [anon_sym_override] = ACTIONS(2967),
    [anon_sym_module] = ACTIONS(2967),
    [anon_sym_any] = ACTIONS(2967),
    [anon_sym_number] = ACTIONS(2967),
    [anon_sym_boolean] = ACTIONS(2967),
    [anon_sym_string] = ACTIONS(2967),
    [anon_sym_symbol] = ACTIONS(2967),
    [anon_sym_object] = ACTIONS(2967),
    [anon_sym_abstract] = ACTIONS(2967),
    [anon_sym_interface] = ACTIONS(2967),
    [anon_sym_enum] = ACTIONS(2967),
    [sym_html_comment] = ACTIONS(5),
  },
  [942] = {
    [ts_builtin_sym_end] = ACTIONS(2969),
    [sym_identifier] = ACTIONS(2971),
    [anon_sym_export] = ACTIONS(2971),
    [anon_sym_default] = ACTIONS(2971),
    [anon_sym_type] = ACTIONS(2971),
    [anon_sym_namespace] = ACTIONS(2971),
    [anon_sym_LBRACE] = ACTIONS(2969),
    [anon_sym_RBRACE] = ACTIONS(2969),
    [anon_sym_typeof] = ACTIONS(2971),
    [anon_sym_import] = ACTIONS(2971),
    [anon_sym_with] = ACTIONS(2971),
    [anon_sym_var] = ACTIONS(2971),
    [anon_sym_let] = ACTIONS(2971),
    [anon_sym_const] = ACTIONS(2971),
    [anon_sym_BANG] = ACTIONS(2969),
    [anon_sym_else] = ACTIONS(2971),
    [anon_sym_if] = ACTIONS(2971),
    [anon_sym_switch] = ACTIONS(2971),
    [anon_sym_for] = ACTIONS(2971),
    [anon_sym_LPAREN] = ACTIONS(2969),
    [anon_sym_SEMI] = ACTIONS(2969),
    [anon_sym_await] = ACTIONS(2971),
    [anon_sym_while] = ACTIONS(2971),
    [anon_sym_do] = ACTIONS(2971),
    [anon_sym_try] = ACTIONS(2971),
    [anon_sym_break] = ACTIONS(2971),
    [anon_sym_continue] = ACTIONS(2971),
    [anon_sym_debugger] = ACTIONS(2971),
    [anon_sym_return] = ACTIONS(2971),
    [anon_sym_throw] = ACTIONS(2971),
    [anon_sym_case] = ACTIONS(2971),
    [anon_sym_yield] = ACTIONS(2971),
    [anon_sym_LBRACK] = ACTIONS(2969),
    [anon_sym_class] = ACTIONS(2971),
    [anon_sym_async] = ACTIONS(2971),
    [anon_sym_function] = ACTIONS(2971),
    [anon_sym_new] = ACTIONS(2971),
    [anon_sym_using] = ACTIONS(2971),
    [anon_sym_PLUS] = ACTIONS(2971),
    [anon_sym_DASH] = ACTIONS(2971),
    [anon_sym_SLASH] = ACTIONS(2971),
    [anon_sym_LT] = ACTIONS(2969),
    [anon_sym_TILDE] = ACTIONS(2969),
    [anon_sym_void] = ACTIONS(2971),
    [anon_sym_delete] = ACTIONS(2971),
    [anon_sym_PLUS_PLUS] = ACTIONS(2969),
    [anon_sym_DASH_DASH] = ACTIONS(2969),
    [anon_sym_DQUOTE] = ACTIONS(2969),
    [anon_sym_SQUOTE] = ACTIONS(2969),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(2969),
    [sym_number] = ACTIONS(2969),
    [sym_private_property_identifier] = ACTIONS(2969),
    [sym_this] = ACTIONS(2971),
    [sym_super] = ACTIONS(2971),
    [sym_true] = ACTIONS(2971),
    [sym_false] = ACTIONS(2971),
    [sym_null] = ACTIONS(2971),
    [sym_undefined] = ACTIONS(2971),
    [anon_sym_AT] = ACTIONS(2969),
    [anon_sym_static] = ACTIONS(2971),
    [anon_sym_readonly] = ACTIONS(2971),
    [anon_sym_get] = ACTIONS(2971),
    [anon_sym_set] = ACTIONS(2971),
    [anon_sym_declare] = ACTIONS(2971),
    [anon_sym_public] = ACTIONS(2971),
    [anon_sym_private] = ACTIONS(2971),
    [anon_sym_protected] = ACTIONS(2971),
    [anon_sym_override] = ACTIONS(2971),
    [anon_sym_module] = ACTIONS(2971),
    [anon_sym_any] = ACTIONS(2971),
    [anon_sym_number] = ACTIONS(2971),
    [anon_sym_boolean] = ACTIONS(2971),
    [anon_sym_string] = ACTIONS(2971),
    [anon_sym_symbol] = ACTIONS(2971),
    [anon_sym_object] = ACTIONS(2971),
    [anon_sym_abstract] = ACTIONS(2971),
    [anon_sym_interface] = ACTIONS(2971),
    [anon_sym_enum] = ACTIONS(2971),
    [sym_html_comment] = ACTIONS(5),
  },
  [943] = {
    [ts_builtin_sym_end] = ACTIONS(2973),
    [sym_identifier] = ACTIONS(2975),
    [anon_sym_export] = ACTIONS(2975),
    [anon_sym_default] = ACTIONS(2975),
    [anon_sym_type] = ACTIONS(2975),
    [anon_sym_namespace] = ACTIONS(2975),
    [anon_sym_LBRACE] = ACTIONS(2973),
    [anon_sym_RBRACE] = ACTIONS(2973),
    [anon_sym_typeof] = ACTIONS(2975),
    [anon_sym_import] = ACTIONS(2975),
    [anon_sym_with] = ACTIONS(2975),
    [anon_sym_var] = ACTIONS(2975),
    [anon_sym_let] = ACTIONS(2975),
    [anon_sym_const] = ACTIONS(2975),
    [anon_sym_BANG] = ACTIONS(2973),
    [anon_sym_else] = ACTIONS(2975),
    [anon_sym_if] = ACTIONS(2975),
    [anon_sym_switch] = ACTIONS(2975),
    [anon_sym_for] = ACTIONS(2975),
    [anon_sym_LPAREN] = ACTIONS(2973),
    [anon_sym_SEMI] = ACTIONS(2973),
    [anon_sym_await] = ACTIONS(2975),
    [anon_sym_while] = ACTIONS(2975),
    [anon_sym_do] = ACTIONS(2975),
    [anon_sym_try] = ACTIONS(2975),
    [anon_sym_break] = ACTIONS(2975),
    [anon_sym_continue] = ACTIONS(2975),
    [anon_sym_debugger] = ACTIONS(2975),
    [anon_sym_return] = ACTIONS(2975),
    [anon_sym_throw] = ACTIONS(2975),
    [anon_sym_case] = ACTIONS(2975),
    [anon_sym_yield] = ACTIONS(2975),
    [anon_sym_LBRACK] = ACTIONS(2973),
    [anon_sym_class] = ACTIONS(2975),
    [anon_sym_async] = ACTIONS(2975),
    [anon_sym_function] = ACTIONS(2975),
    [anon_sym_new] = ACTIONS(2975),
    [anon_sym_using] = ACTIONS(2975),
    [anon_sym_PLUS] = ACTIONS(2975),
    [anon_sym_DASH] = ACTIONS(2975),
    [anon_sym_SLASH] = ACTIONS(2975),
    [anon_sym_LT] = ACTIONS(2973),
    [anon_sym_TILDE] = ACTIONS(2973),
    [anon_sym_void] = ACTIONS(2975),
    [anon_sym_delete] = ACTIONS(2975),
    [anon_sym_PLUS_PLUS] = ACTIONS(2973),
    [anon_sym_DASH_DASH] = ACTIONS(2973),
    [anon_sym_DQUOTE] = ACTIONS(2973),
    [anon_sym_SQUOTE] = ACTIONS(2973),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(2973),
    [sym_number] = ACTIONS(2973),
    [sym_private_property_identifier] = ACTIONS(2973),
    [sym_this] = ACTIONS(2975),
    [sym_super] = ACTIONS(2975),
    [sym_true] = ACTIONS(2975),
    [sym_false] = ACTIONS(2975),
    [sym_null] = ACTIONS(2975),
    [sym_undefined] = ACTIONS(2975),
    [anon_sym_AT] = ACTIONS(2973),
    [anon_sym_static] = ACTIONS(2975),
    [anon_sym_readonly] = ACTIONS(2975),
    [anon_sym_get] = ACTIONS(2975),
    [anon_sym_set] = ACTIONS(2975),
    [anon_sym_declare] = ACTIONS(2975),
    [anon_sym_public] = ACTIONS(2975),
    [anon_sym_private] = ACTIONS(2975),
    [anon_sym_protected] = ACTIONS(2975),
    [anon_sym_override] = ACTIONS(2975),
    [anon_sym_module] = ACTIONS(2975),
    [anon_sym_any] = ACTIONS(2975),
    [anon_sym_number] = ACTIONS(2975),
    [anon_sym_boolean] = ACTIONS(2975),
    [anon_sym_string] = ACTIONS(2975),
    [anon_sym_symbol] = ACTIONS(2975),
    [anon_sym_object] = ACTIONS(2975),
    [anon_sym_abstract] = ACTIONS(2975),
    [anon_sym_interface] = ACTIONS(2975),
    [anon_sym_enum] = ACTIONS(2975),
    [sym_html_comment] = ACTIONS(5),
  },
  [944] = {
    [ts_builtin_sym_end] = ACTIONS(2977),
    [sym_identifier] = ACTIONS(2979),
    [anon_sym_export] = ACTIONS(2979),
    [anon_sym_default] = ACTIONS(2979),
    [anon_sym_type] = ACTIONS(2979),
    [anon_sym_namespace] = ACTIONS(2979),
    [anon_sym_LBRACE] = ACTIONS(2977),
    [anon_sym_RBRACE] = ACTIONS(2977),
    [anon_sym_typeof] = ACTIONS(2979),
    [anon_sym_import] = ACTIONS(2979),
    [anon_sym_with] = ACTIONS(2979),
    [anon_sym_var] = ACTIONS(2979),
    [anon_sym_let] = ACTIONS(2979),
    [anon_sym_const] = ACTIONS(2979),
    [anon_sym_BANG] = ACTIONS(2977),
    [anon_sym_else] = ACTIONS(2979),
    [anon_sym_if] = ACTIONS(2979),
    [anon_sym_switch] = ACTIONS(2979),
    [anon_sym_for] = ACTIONS(2979),
    [anon_sym_LPAREN] = ACTIONS(2977),
    [anon_sym_SEMI] = ACTIONS(2977),
    [anon_sym_await] = ACTIONS(2979),
    [anon_sym_while] = ACTIONS(2979),
    [anon_sym_do] = ACTIONS(2979),
    [anon_sym_try] = ACTIONS(2979),
    [anon_sym_break] = ACTIONS(2979),
    [anon_sym_continue] = ACTIONS(2979),
    [anon_sym_debugger] = ACTIONS(2979),
    [anon_sym_return] = ACTIONS(2979),
    [anon_sym_throw] = ACTIONS(2979),
    [anon_sym_case] = ACTIONS(2979),
    [anon_sym_yield] = ACTIONS(2979),
    [anon_sym_LBRACK] = ACTIONS(2977),
    [anon_sym_class] = ACTIONS(2979),
    [anon_sym_async] = ACTIONS(2979),
    [anon_sym_function] = ACTIONS(2979),
    [anon_sym_new] = ACTIONS(2979),
    [anon_sym_using] = ACTIONS(2979),
    [anon_sym_PLUS] = ACTIONS(2979),
    [anon_sym_DASH] = ACTIONS(2979),
    [anon_sym_SLASH] = ACTIONS(2979),
    [anon_sym_LT] = ACTIONS(2977),
    [anon_sym_TILDE] = ACTIONS(2977),
    [anon_sym_void] = ACTIONS(2979),
    [anon_sym_delete] = ACTIONS(2979),
    [anon_sym_PLUS_PLUS] = ACTIONS(2977),
    [anon_sym_DASH_DASH] = ACTIONS(2977),
    [anon_sym_DQUOTE] = ACTIONS(2977),
    [anon_sym_SQUOTE] = ACTIONS(2977),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(2977),
    [sym_number] = ACTIONS(2977),
    [sym_private_property_identifier] = ACTIONS(2977),
    [sym_this] = ACTIONS(2979),
    [sym_super] = ACTIONS(2979),
    [sym_true] = ACTIONS(2979),
    [sym_false] = ACTIONS(2979),
    [sym_null] = ACTIONS(2979),
    [sym_undefined] = ACTIONS(2979),
    [anon_sym_AT] = ACTIONS(2977),
    [anon_sym_static] = ACTIONS(2979),
    [anon_sym_readonly] = ACTIONS(2979),
    [anon_sym_get] = ACTIONS(2979),
    [anon_sym_set] = ACTIONS(2979),
    [anon_sym_declare] = ACTIONS(2979),
    [anon_sym_public] = ACTIONS(2979),
    [anon_sym_private] = ACTIONS(2979),
    [anon_sym_protected] = ACTIONS(2979),
    [anon_sym_override] = ACTIONS(2979),
    [anon_sym_module] = ACTIONS(2979),
    [anon_sym_any] = ACTIONS(2979),
    [anon_sym_number] = ACTIONS(2979),
    [anon_sym_boolean] = ACTIONS(2979),
    [anon_sym_string] = ACTIONS(2979),
    [anon_sym_symbol] = ACTIONS(2979),
    [anon_sym_object] = ACTIONS(2979),
    [anon_sym_abstract] = ACTIONS(2979),
    [anon_sym_interface] = ACTIONS(2979),
    [anon_sym_enum] = ACTIONS(2979),
    [sym_html_comment] = ACTIONS(5),
  },
  [945] = {
    [sym_import] = STATE(4681),
    [sym_nested_identifier] = STATE(5474),
    [sym_string] = STATE(2994),
    [sym_formal_parameters] = STATE(5619),
    [sym_rest_pattern] = STATE(5165),
    [sym_nested_type_identifier] = STATE(2939),
    [sym__type_query_member_expression_in_type_annotation] = STATE(3303),
    [sym__type_query_call_expression_in_type_annotation] = STATE(2938),
    [sym_type] = STATE(3773),
    [sym_tuple_parameter] = STATE(5278),
    [sym_optional_tuple_parameter] = STATE(5278),
    [sym_optional_type] = STATE(5278),
    [sym_rest_type] = STATE(5278),
    [sym__tuple_type_member] = STATE(5278),
    [sym_constructor_type] = STATE(3007),
    [sym_primary_type] = STATE(2981),
    [sym_template_literal_type] = STATE(3039),
    [sym_infer_type] = STATE(3007),
    [sym_conditional_type] = STATE(3039),
    [sym_generic_type] = STATE(3039),
    [sym_type_query] = STATE(3039),
    [sym_index_type_query] = STATE(3039),
    [sym_lookup_type] = STATE(3039),
    [sym_literal_type] = STATE(3039),
    [sym__number] = STATE(3041),
    [sym_existential_type] = STATE(3039),
    [sym_flow_maybe_type] = STATE(3039),
    [sym_parenthesized_type] = STATE(3039),
    [sym_predefined_type] = STATE(3039),
    [sym_object_type] = STATE(3039),
    [sym_type_parameters] = STATE(5454),
    [sym_array_type] = STATE(3039),
    [sym_tuple_type] = STATE(3039),
    [sym_readonly_type] = STATE(3007),
    [sym_union_type] = STATE(3039),
    [sym_intersection_type] = STATE(3039),
    [sym_function_type] = STATE(3007),
    [sym_identifier] = ACTIONS(2489),
    [anon_sym_STAR] = ACTIONS(543),
    [anon_sym_LBRACE] = ACTIONS(1534),
    [anon_sym_typeof] = ACTIONS(1536),
    [anon_sym_import] = ACTIONS(1538),
    [anon_sym_const] = ACTIONS(133),
    [anon_sym_LPAREN] = ACTIONS(1540),
    [anon_sym_LBRACK] = ACTIONS(1542),
    [anon_sym_new] = ACTIONS(1642),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(2495),
    [anon_sym_AMP] = ACTIONS(571),
    [anon_sym_PIPE] = ACTIONS(573),
    [anon_sym_PLUS] = ACTIONS(2497),
    [anon_sym_DASH] = ACTIONS(2497),
    [anon_sym_LT] = ACTIONS(2499),
    [anon_sym_void] = ACTIONS(216),
    [anon_sym_DQUOTE] = ACTIONS(1550),
    [anon_sym_SQUOTE] = ACTIONS(1552),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1554),
    [sym_number] = ACTIONS(1556),
    [sym_this] = ACTIONS(1558),
    [sym_true] = ACTIONS(1560),
    [sym_false] = ACTIONS(1560),
    [sym_null] = ACTIONS(1560),
    [sym_undefined] = ACTIONS(1560),
    [anon_sym_readonly] = ACTIONS(1648),
    [anon_sym_QMARK] = ACTIONS(593),
    [anon_sym_any] = ACTIONS(216),
    [anon_sym_number] = ACTIONS(216),
    [anon_sym_boolean] = ACTIONS(216),
    [anon_sym_string] = ACTIONS(216),
    [anon_sym_symbol] = ACTIONS(216),
    [anon_sym_object] = ACTIONS(216),
    [anon_sym_abstract] = ACTIONS(597),
    [anon_sym_infer] = ACTIONS(599),
    [anon_sym_keyof] = ACTIONS(601),
    [anon_sym_unique] = ACTIONS(214),
    [anon_sym_unknown] = ACTIONS(216),
    [anon_sym_never] = ACTIONS(216),
    [anon_sym_LBRACE_PIPE] = ACTIONS(218),
    [sym_html_comment] = ACTIONS(5),
  },
  [946] = {
    [sym_import] = STATE(4950),
    [sym_nested_identifier] = STATE(5535),
    [sym_string] = STATE(3265),
    [sym_formal_parameters] = STATE(5840),
    [sym_nested_type_identifier] = STATE(3151),
    [sym__type_query_member_expression_in_type_annotation] = STATE(3076),
    [sym__type_query_call_expression_in_type_annotation] = STATE(3200),
    [sym_asserts] = STATE(3229),
    [sym_type] = STATE(3242),
    [sym_constructor_type] = STATE(3271),
    [sym_primary_type] = STATE(3272),
    [sym_template_literal_type] = STATE(3273),
    [sym_infer_type] = STATE(3271),
    [sym_conditional_type] = STATE(3273),
    [sym_generic_type] = STATE(3273),
    [sym_type_predicate] = STATE(3229),
    [sym_type_query] = STATE(3273),
    [sym_index_type_query] = STATE(3273),
    [sym_lookup_type] = STATE(3273),
    [sym_literal_type] = STATE(3273),
    [sym__number] = STATE(3274),
    [sym_existential_type] = STATE(3273),
    [sym_flow_maybe_type] = STATE(3273),
    [sym_parenthesized_type] = STATE(3273),
    [sym_predefined_type] = STATE(3212),
    [sym_object_type] = STATE(3273),
    [sym_type_parameters] = STATE(5146),
    [sym_array_type] = STATE(3273),
    [sym_tuple_type] = STATE(3273),
    [sym_readonly_type] = STATE(3271),
    [sym_union_type] = STATE(3273),
    [sym_intersection_type] = STATE(3273),
    [sym_function_type] = STATE(3271),
    [sym_identifier] = ACTIONS(2981),
    [anon_sym_STAR] = ACTIONS(986),
    [anon_sym_LBRACE] = ACTIONS(1610),
    [anon_sym_typeof] = ACTIONS(1612),
    [anon_sym_import] = ACTIONS(1538),
    [anon_sym_const] = ACTIONS(992),
    [anon_sym_LPAREN] = ACTIONS(1614),
    [anon_sym_LBRACK] = ACTIONS(1616),
    [anon_sym_new] = ACTIONS(1618),
    [anon_sym_AMP] = ACTIONS(1000),
    [anon_sym_PIPE] = ACTIONS(1002),
    [anon_sym_PLUS] = ACTIONS(2983),
    [anon_sym_DASH] = ACTIONS(2983),
    [anon_sym_LT] = ACTIONS(2499),
    [anon_sym_void] = ACTIONS(1032),
    [anon_sym_DQUOTE] = ACTIONS(1626),
    [anon_sym_SQUOTE] = ACTIONS(1628),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1630),
    [sym_number] = ACTIONS(1632),
    [sym_this] = ACTIONS(2985),
    [sym_true] = ACTIONS(1636),
    [sym_false] = ACTIONS(1636),
    [sym_null] = ACTIONS(1636),
    [sym_undefined] = ACTIONS(1636),
    [anon_sym_readonly] = ACTIONS(1638),
    [anon_sym_QMARK] = ACTIONS(1020),
    [anon_sym_any] = ACTIONS(1032),
    [anon_sym_number] = ACTIONS(1032),
    [anon_sym_boolean] = ACTIONS(1032),
    [anon_sym_string] = ACTIONS(1032),
    [anon_sym_symbol] = ACTIONS(1032),
    [anon_sym_object] = ACTIONS(1032),
    [anon_sym_abstract] = ACTIONS(1024),
    [anon_sym_asserts] = ACTIONS(2987),
    [anon_sym_infer] = ACTIONS(1026),
    [anon_sym_keyof] = ACTIONS(1028),
    [anon_sym_unique] = ACTIONS(1030),
    [anon_sym_unknown] = ACTIONS(1032),
    [anon_sym_never] = ACTIONS(1032),
    [anon_sym_LBRACE_PIPE] = ACTIONS(1034),
    [sym_html_comment] = ACTIONS(5),
  },
  [947] = {
    [sym_identifier] = ACTIONS(2989),
    [anon_sym_export] = ACTIONS(2989),
    [anon_sym_type] = ACTIONS(2989),
    [anon_sym_namespace] = ACTIONS(2989),
    [anon_sym_LBRACE] = ACTIONS(2991),
    [anon_sym_typeof] = ACTIONS(2989),
    [anon_sym_import] = ACTIONS(2989),
    [anon_sym_with] = ACTIONS(2989),
    [anon_sym_var] = ACTIONS(2989),
    [anon_sym_let] = ACTIONS(2989),
    [anon_sym_const] = ACTIONS(2989),
    [anon_sym_BANG] = ACTIONS(2991),
    [anon_sym_if] = ACTIONS(2989),
    [anon_sym_switch] = ACTIONS(2989),
    [anon_sym_for] = ACTIONS(2989),
    [anon_sym_LPAREN] = ACTIONS(2991),
    [anon_sym_SEMI] = ACTIONS(2991),
    [anon_sym_await] = ACTIONS(2989),
    [anon_sym_while] = ACTIONS(2989),
    [anon_sym_do] = ACTIONS(2989),
    [anon_sym_try] = ACTIONS(2989),
    [anon_sym_break] = ACTIONS(2989),
    [anon_sym_continue] = ACTIONS(2989),
    [anon_sym_debugger] = ACTIONS(2989),
    [anon_sym_return] = ACTIONS(2989),
    [anon_sym_throw] = ACTIONS(2989),
    [anon_sym_yield] = ACTIONS(2989),
    [anon_sym_LBRACK] = ACTIONS(2991),
    [anon_sym_class] = ACTIONS(2989),
    [anon_sym_async] = ACTIONS(2989),
    [anon_sym_function] = ACTIONS(2989),
    [anon_sym_new] = ACTIONS(2989),
    [anon_sym_using] = ACTIONS(2989),
    [anon_sym_PLUS] = ACTIONS(2989),
    [anon_sym_DASH] = ACTIONS(2989),
    [anon_sym_SLASH] = ACTIONS(2989),
    [anon_sym_LT] = ACTIONS(2991),
    [anon_sym_TILDE] = ACTIONS(2991),
    [anon_sym_void] = ACTIONS(2989),
    [anon_sym_delete] = ACTIONS(2989),
    [anon_sym_PLUS_PLUS] = ACTIONS(2991),
    [anon_sym_DASH_DASH] = ACTIONS(2991),
    [anon_sym_DQUOTE] = ACTIONS(2991),
    [anon_sym_SQUOTE] = ACTIONS(2991),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(2991),
    [sym_number] = ACTIONS(2991),
    [sym_private_property_identifier] = ACTIONS(2991),
    [sym_this] = ACTIONS(2989),
    [sym_super] = ACTIONS(2989),
    [sym_true] = ACTIONS(2989),
    [sym_false] = ACTIONS(2989),
    [sym_null] = ACTIONS(2989),
    [sym_undefined] = ACTIONS(2989),
    [anon_sym_AT] = ACTIONS(2991),
    [anon_sym_static] = ACTIONS(2989),
    [anon_sym_readonly] = ACTIONS(2989),
    [anon_sym_get] = ACTIONS(2989),
    [anon_sym_set] = ACTIONS(2989),
    [anon_sym_declare] = ACTIONS(2989),
    [anon_sym_public] = ACTIONS(2989),
    [anon_sym_private] = ACTIONS(2989),
    [anon_sym_protected] = ACTIONS(2989),
    [anon_sym_override] = ACTIONS(2989),
    [anon_sym_module] = ACTIONS(2989),
    [anon_sym_any] = ACTIONS(2989),
    [anon_sym_number] = ACTIONS(2989),
    [anon_sym_boolean] = ACTIONS(2989),
    [anon_sym_string] = ACTIONS(2989),
    [anon_sym_symbol] = ACTIONS(2989),
    [anon_sym_object] = ACTIONS(2989),
    [anon_sym_abstract] = ACTIONS(2989),
    [anon_sym_interface] = ACTIONS(2989),
    [anon_sym_enum] = ACTIONS(2989),
    [sym_html_comment] = ACTIONS(5),
  },
  [948] = {
    [sym_import] = STATE(4578),
    [sym_nested_identifier] = STATE(5796),
    [sym_string] = STATE(3437),
    [sym_formal_parameters] = STATE(5519),
    [sym_nested_type_identifier] = STATE(3278),
    [sym__type_query_member_expression_in_type_annotation] = STATE(3181),
    [sym__type_query_call_expression_in_type_annotation] = STATE(3311),
    [sym_asserts] = STATE(3445),
    [sym_type] = STATE(3447),
    [sym_constructor_type] = STATE(3448),
    [sym_primary_type] = STATE(3450),
    [sym_template_literal_type] = STATE(3453),
    [sym_infer_type] = STATE(3448),
    [sym_conditional_type] = STATE(3453),
    [sym_generic_type] = STATE(3453),
    [sym_type_predicate] = STATE(3445),
    [sym_type_query] = STATE(3453),
    [sym_index_type_query] = STATE(3453),
    [sym_lookup_type] = STATE(3453),
    [sym_literal_type] = STATE(3453),
    [sym__number] = STATE(3454),
    [sym_existential_type] = STATE(3453),
    [sym_flow_maybe_type] = STATE(3453),
    [sym_parenthesized_type] = STATE(3453),
    [sym_predefined_type] = STATE(3305),
    [sym_object_type] = STATE(3453),
    [sym_type_parameters] = STATE(5251),
    [sym_array_type] = STATE(3453),
    [sym_tuple_type] = STATE(3453),
    [sym_readonly_type] = STATE(3448),
    [sym_union_type] = STATE(3453),
    [sym_intersection_type] = STATE(3453),
    [sym_function_type] = STATE(3448),
    [sym_identifier] = ACTIONS(2993),
    [anon_sym_STAR] = ACTIONS(2995),
    [anon_sym_LBRACE] = ACTIONS(2997),
    [anon_sym_typeof] = ACTIONS(2999),
    [anon_sym_import] = ACTIONS(1538),
    [anon_sym_const] = ACTIONS(3001),
    [anon_sym_LPAREN] = ACTIONS(3003),
    [anon_sym_LBRACK] = ACTIONS(3005),
    [anon_sym_new] = ACTIONS(3007),
    [anon_sym_AMP] = ACTIONS(3009),
    [anon_sym_PIPE] = ACTIONS(3011),
    [anon_sym_PLUS] = ACTIONS(3013),
    [anon_sym_DASH] = ACTIONS(3013),
    [anon_sym_LT] = ACTIONS(2499),
    [anon_sym_void] = ACTIONS(3015),
    [anon_sym_DQUOTE] = ACTIONS(3017),
    [anon_sym_SQUOTE] = ACTIONS(3019),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(3021),
    [sym_number] = ACTIONS(3023),
    [sym_this] = ACTIONS(3025),
    [sym_true] = ACTIONS(3027),
    [sym_false] = ACTIONS(3027),
    [sym_null] = ACTIONS(3027),
    [sym_undefined] = ACTIONS(3027),
    [anon_sym_readonly] = ACTIONS(3029),
    [anon_sym_QMARK] = ACTIONS(3031),
    [anon_sym_any] = ACTIONS(3015),
    [anon_sym_number] = ACTIONS(3015),
    [anon_sym_boolean] = ACTIONS(3015),
    [anon_sym_string] = ACTIONS(3015),
    [anon_sym_symbol] = ACTIONS(3015),
    [anon_sym_object] = ACTIONS(3015),
    [anon_sym_abstract] = ACTIONS(3033),
    [anon_sym_asserts] = ACTIONS(3035),
    [anon_sym_infer] = ACTIONS(3037),
    [anon_sym_keyof] = ACTIONS(3039),
    [anon_sym_unique] = ACTIONS(3041),
    [anon_sym_unknown] = ACTIONS(3015),
    [anon_sym_never] = ACTIONS(3015),
    [anon_sym_LBRACE_PIPE] = ACTIONS(3043),
    [sym_html_comment] = ACTIONS(5),
  },
  [949] = {
    [sym_import] = STATE(4650),
    [sym_nested_identifier] = STATE(5567),
    [sym_string] = STATE(1975),
    [sym_formal_parameters] = STATE(5527),
    [sym_nested_type_identifier] = STATE(1865),
    [sym__type_query_member_expression_in_type_annotation] = STATE(1781),
    [sym__type_query_call_expression_in_type_annotation] = STATE(1911),
    [sym_asserts] = STATE(1991),
    [sym_type] = STATE(1992),
    [sym_constructor_type] = STATE(1912),
    [sym_primary_type] = STATE(1915),
    [sym_template_literal_type] = STATE(1916),
    [sym_infer_type] = STATE(1912),
    [sym_conditional_type] = STATE(1916),
    [sym_generic_type] = STATE(1916),
    [sym_type_predicate] = STATE(1991),
    [sym_type_query] = STATE(1916),
    [sym_index_type_query] = STATE(1916),
    [sym_lookup_type] = STATE(1916),
    [sym_literal_type] = STATE(1916),
    [sym__number] = STATE(1918),
    [sym_existential_type] = STATE(1916),
    [sym_flow_maybe_type] = STATE(1916),
    [sym_parenthesized_type] = STATE(1916),
    [sym_predefined_type] = STATE(1822),
    [sym_object_type] = STATE(1916),
    [sym_type_parameters] = STATE(5243),
    [sym_array_type] = STATE(1916),
    [sym_tuple_type] = STATE(1916),
    [sym_readonly_type] = STATE(1912),
    [sym_union_type] = STATE(1916),
    [sym_intersection_type] = STATE(1916),
    [sym_function_type] = STATE(1912),
    [sym_identifier] = ACTIONS(3045),
    [anon_sym_STAR] = ACTIONS(3047),
    [anon_sym_LBRACE] = ACTIONS(3049),
    [anon_sym_typeof] = ACTIONS(3051),
    [anon_sym_import] = ACTIONS(1538),
    [anon_sym_const] = ACTIONS(3053),
    [anon_sym_LPAREN] = ACTIONS(3055),
    [anon_sym_LBRACK] = ACTIONS(3057),
    [anon_sym_new] = ACTIONS(3059),
    [anon_sym_AMP] = ACTIONS(3061),
    [anon_sym_PIPE] = ACTIONS(3063),
    [anon_sym_PLUS] = ACTIONS(3065),
    [anon_sym_DASH] = ACTIONS(3065),
    [anon_sym_LT] = ACTIONS(2499),
    [anon_sym_void] = ACTIONS(3067),
    [anon_sym_DQUOTE] = ACTIONS(83),
    [anon_sym_SQUOTE] = ACTIONS(85),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(3069),
    [sym_number] = ACTIONS(3071),
    [sym_this] = ACTIONS(3073),
    [sym_true] = ACTIONS(3075),
    [sym_false] = ACTIONS(3075),
    [sym_null] = ACTIONS(3075),
    [sym_undefined] = ACTIONS(3075),
    [anon_sym_readonly] = ACTIONS(3077),
    [anon_sym_QMARK] = ACTIONS(3079),
    [anon_sym_any] = ACTIONS(3067),
    [anon_sym_number] = ACTIONS(3067),
    [anon_sym_boolean] = ACTIONS(3067),
    [anon_sym_string] = ACTIONS(3067),
    [anon_sym_symbol] = ACTIONS(3067),
    [anon_sym_object] = ACTIONS(3067),
    [anon_sym_abstract] = ACTIONS(3081),
    [anon_sym_asserts] = ACTIONS(3083),
    [anon_sym_infer] = ACTIONS(3085),
    [anon_sym_keyof] = ACTIONS(3087),
    [anon_sym_unique] = ACTIONS(3089),
    [anon_sym_unknown] = ACTIONS(3067),
    [anon_sym_never] = ACTIONS(3067),
    [anon_sym_LBRACE_PIPE] = ACTIONS(3091),
    [sym_html_comment] = ACTIONS(5),
  },
  [950] = {
    [sym_identifier] = ACTIONS(3093),
    [anon_sym_export] = ACTIONS(3093),
    [anon_sym_type] = ACTIONS(3093),
    [anon_sym_namespace] = ACTIONS(3093),
    [anon_sym_LBRACE] = ACTIONS(3095),
    [anon_sym_typeof] = ACTIONS(3093),
    [anon_sym_import] = ACTIONS(3093),
    [anon_sym_with] = ACTIONS(3093),
    [anon_sym_var] = ACTIONS(3093),
    [anon_sym_let] = ACTIONS(3093),
    [anon_sym_const] = ACTIONS(3093),
    [anon_sym_BANG] = ACTIONS(3095),
    [anon_sym_if] = ACTIONS(3093),
    [anon_sym_switch] = ACTIONS(3093),
    [anon_sym_for] = ACTIONS(3093),
    [anon_sym_LPAREN] = ACTIONS(3095),
    [anon_sym_SEMI] = ACTIONS(3095),
    [anon_sym_await] = ACTIONS(3093),
    [anon_sym_while] = ACTIONS(3093),
    [anon_sym_do] = ACTIONS(3093),
    [anon_sym_try] = ACTIONS(3093),
    [anon_sym_break] = ACTIONS(3093),
    [anon_sym_continue] = ACTIONS(3093),
    [anon_sym_debugger] = ACTIONS(3093),
    [anon_sym_return] = ACTIONS(3093),
    [anon_sym_throw] = ACTIONS(3093),
    [anon_sym_yield] = ACTIONS(3093),
    [anon_sym_LBRACK] = ACTIONS(3095),
    [anon_sym_class] = ACTIONS(3093),
    [anon_sym_async] = ACTIONS(3093),
    [anon_sym_function] = ACTIONS(3093),
    [anon_sym_new] = ACTIONS(3093),
    [anon_sym_using] = ACTIONS(3093),
    [anon_sym_PLUS] = ACTIONS(3093),
    [anon_sym_DASH] = ACTIONS(3093),
    [anon_sym_SLASH] = ACTIONS(3093),
    [anon_sym_LT] = ACTIONS(3095),
    [anon_sym_TILDE] = ACTIONS(3095),
    [anon_sym_void] = ACTIONS(3093),
    [anon_sym_delete] = ACTIONS(3093),
    [anon_sym_PLUS_PLUS] = ACTIONS(3095),
    [anon_sym_DASH_DASH] = ACTIONS(3095),
    [anon_sym_DQUOTE] = ACTIONS(3095),
    [anon_sym_SQUOTE] = ACTIONS(3095),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(3095),
    [sym_number] = ACTIONS(3095),
    [sym_private_property_identifier] = ACTIONS(3095),
    [sym_this] = ACTIONS(3093),
    [sym_super] = ACTIONS(3093),
    [sym_true] = ACTIONS(3093),
    [sym_false] = ACTIONS(3093),
    [sym_null] = ACTIONS(3093),
    [sym_undefined] = ACTIONS(3093),
    [anon_sym_AT] = ACTIONS(3095),
    [anon_sym_static] = ACTIONS(3093),
    [anon_sym_readonly] = ACTIONS(3093),
    [anon_sym_get] = ACTIONS(3093),
    [anon_sym_set] = ACTIONS(3093),
    [anon_sym_declare] = ACTIONS(3093),
    [anon_sym_public] = ACTIONS(3093),
    [anon_sym_private] = ACTIONS(3093),
    [anon_sym_protected] = ACTIONS(3093),
    [anon_sym_override] = ACTIONS(3093),
    [anon_sym_module] = ACTIONS(3093),
    [anon_sym_any] = ACTIONS(3093),
    [anon_sym_number] = ACTIONS(3093),
    [anon_sym_boolean] = ACTIONS(3093),
    [anon_sym_string] = ACTIONS(3093),
    [anon_sym_symbol] = ACTIONS(3093),
    [anon_sym_object] = ACTIONS(3093),
    [anon_sym_abstract] = ACTIONS(3093),
    [anon_sym_interface] = ACTIONS(3093),
    [anon_sym_enum] = ACTIONS(3093),
    [sym_html_comment] = ACTIONS(5),
  },
  [951] = {
    [sym_import] = STATE(4808),
    [sym_nested_identifier] = STATE(5474),
    [sym_string] = STATE(2994),
    [sym_formal_parameters] = STATE(5569),
    [sym_nested_type_identifier] = STATE(3487),
    [sym__type_query_member_expression_in_type_annotation] = STATE(3388),
    [sym__type_query_call_expression_in_type_annotation] = STATE(2938),
    [sym_asserts] = STATE(3018),
    [sym_type] = STATE(3849),
    [sym_constructor_type] = STATE(3007),
    [sym_primary_type] = STATE(2981),
    [sym_template_literal_type] = STATE(3039),
    [sym_infer_type] = STATE(3007),
    [sym_conditional_type] = STATE(3039),
    [sym_generic_type] = STATE(3039),
    [sym_type_predicate] = STATE(3018),
    [sym_type_query] = STATE(3039),
    [sym_index_type_query] = STATE(3039),
    [sym_lookup_type] = STATE(3039),
    [sym_literal_type] = STATE(3039),
    [sym__number] = STATE(3041),
    [sym_existential_type] = STATE(3039),
    [sym_flow_maybe_type] = STATE(3039),
    [sym_parenthesized_type] = STATE(3039),
    [sym_predefined_type] = STATE(3697),
    [sym_object_type] = STATE(3039),
    [sym_type_parameters] = STATE(5361),
    [sym_array_type] = STATE(3039),
    [sym_tuple_type] = STATE(3039),
    [sym_readonly_type] = STATE(3007),
    [sym_union_type] = STATE(3039),
    [sym_intersection_type] = STATE(3039),
    [sym_function_type] = STATE(3007),
    [sym_identifier] = ACTIONS(3097),
    [anon_sym_STAR] = ACTIONS(543),
    [anon_sym_LBRACE] = ACTIONS(3099),
    [anon_sym_typeof] = ACTIONS(3101),
    [anon_sym_import] = ACTIONS(1538),
    [anon_sym_const] = ACTIONS(133),
    [anon_sym_LPAREN] = ACTIONS(1540),
    [anon_sym_LBRACK] = ACTIONS(1542),
    [anon_sym_new] = ACTIONS(3103),
    [anon_sym_AMP] = ACTIONS(3105),
    [anon_sym_PIPE] = ACTIONS(3107),
    [anon_sym_PLUS] = ACTIONS(2497),
    [anon_sym_DASH] = ACTIONS(2497),
    [anon_sym_LT] = ACTIONS(2499),
    [anon_sym_void] = ACTIONS(216),
    [anon_sym_DQUOTE] = ACTIONS(3109),
    [anon_sym_SQUOTE] = ACTIONS(3111),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1554),
    [sym_number] = ACTIONS(1556),
    [sym_this] = ACTIONS(3113),
    [sym_true] = ACTIONS(1560),
    [sym_false] = ACTIONS(1560),
    [sym_null] = ACTIONS(1560),
    [sym_undefined] = ACTIONS(1560),
    [anon_sym_readonly] = ACTIONS(3115),
    [anon_sym_QMARK] = ACTIONS(3117),
    [anon_sym_any] = ACTIONS(216),
    [anon_sym_number] = ACTIONS(216),
    [anon_sym_boolean] = ACTIONS(216),
    [anon_sym_string] = ACTIONS(216),
    [anon_sym_symbol] = ACTIONS(216),
    [anon_sym_object] = ACTIONS(216),
    [anon_sym_abstract] = ACTIONS(3119),
    [anon_sym_asserts] = ACTIONS(3121),
    [anon_sym_infer] = ACTIONS(3123),
    [anon_sym_keyof] = ACTIONS(3125),
    [anon_sym_unique] = ACTIONS(214),
    [anon_sym_unknown] = ACTIONS(216),
    [anon_sym_never] = ACTIONS(216),
    [anon_sym_LBRACE_PIPE] = ACTIONS(3127),
    [sym_html_comment] = ACTIONS(5),
  },
  [952] = {
    [sym_identifier] = ACTIONS(3129),
    [anon_sym_export] = ACTIONS(3129),
    [anon_sym_type] = ACTIONS(3129),
    [anon_sym_namespace] = ACTIONS(3129),
    [anon_sym_LBRACE] = ACTIONS(3131),
    [anon_sym_typeof] = ACTIONS(3129),
    [anon_sym_import] = ACTIONS(3129),
    [anon_sym_with] = ACTIONS(3129),
    [anon_sym_var] = ACTIONS(3129),
    [anon_sym_let] = ACTIONS(3129),
    [anon_sym_const] = ACTIONS(3129),
    [anon_sym_BANG] = ACTIONS(3131),
    [anon_sym_if] = ACTIONS(3129),
    [anon_sym_switch] = ACTIONS(3129),
    [anon_sym_for] = ACTIONS(3129),
    [anon_sym_LPAREN] = ACTIONS(3131),
    [anon_sym_SEMI] = ACTIONS(3131),
    [anon_sym_await] = ACTIONS(3129),
    [anon_sym_while] = ACTIONS(3129),
    [anon_sym_do] = ACTIONS(3129),
    [anon_sym_try] = ACTIONS(3129),
    [anon_sym_break] = ACTIONS(3129),
    [anon_sym_continue] = ACTIONS(3129),
    [anon_sym_debugger] = ACTIONS(3129),
    [anon_sym_return] = ACTIONS(3129),
    [anon_sym_throw] = ACTIONS(3129),
    [anon_sym_yield] = ACTIONS(3129),
    [anon_sym_LBRACK] = ACTIONS(3131),
    [anon_sym_class] = ACTIONS(3129),
    [anon_sym_async] = ACTIONS(3129),
    [anon_sym_function] = ACTIONS(3129),
    [anon_sym_new] = ACTIONS(3129),
    [anon_sym_using] = ACTIONS(3129),
    [anon_sym_PLUS] = ACTIONS(3129),
    [anon_sym_DASH] = ACTIONS(3129),
    [anon_sym_SLASH] = ACTIONS(3129),
    [anon_sym_LT] = ACTIONS(3131),
    [anon_sym_TILDE] = ACTIONS(3131),
    [anon_sym_void] = ACTIONS(3129),
    [anon_sym_delete] = ACTIONS(3129),
    [anon_sym_PLUS_PLUS] = ACTIONS(3131),
    [anon_sym_DASH_DASH] = ACTIONS(3131),
    [anon_sym_DQUOTE] = ACTIONS(3131),
    [anon_sym_SQUOTE] = ACTIONS(3131),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(3131),
    [sym_number] = ACTIONS(3131),
    [sym_private_property_identifier] = ACTIONS(3131),
    [sym_this] = ACTIONS(3129),
    [sym_super] = ACTIONS(3129),
    [sym_true] = ACTIONS(3129),
    [sym_false] = ACTIONS(3129),
    [sym_null] = ACTIONS(3129),
    [sym_undefined] = ACTIONS(3129),
    [anon_sym_AT] = ACTIONS(3131),
    [anon_sym_static] = ACTIONS(3129),
    [anon_sym_readonly] = ACTIONS(3129),
    [anon_sym_get] = ACTIONS(3129),
    [anon_sym_set] = ACTIONS(3129),
    [anon_sym_declare] = ACTIONS(3129),
    [anon_sym_public] = ACTIONS(3129),
    [anon_sym_private] = ACTIONS(3129),
    [anon_sym_protected] = ACTIONS(3129),
    [anon_sym_override] = ACTIONS(3129),
    [anon_sym_module] = ACTIONS(3129),
    [anon_sym_any] = ACTIONS(3129),
    [anon_sym_number] = ACTIONS(3129),
    [anon_sym_boolean] = ACTIONS(3129),
    [anon_sym_string] = ACTIONS(3129),
    [anon_sym_symbol] = ACTIONS(3129),
    [anon_sym_object] = ACTIONS(3129),
    [anon_sym_abstract] = ACTIONS(3129),
    [anon_sym_interface] = ACTIONS(3129),
    [anon_sym_enum] = ACTIONS(3129),
    [sym_html_comment] = ACTIONS(5),
  },
  [953] = {
    [sym_import] = STATE(4878),
    [sym_nested_identifier] = STATE(5474),
    [sym_string] = STATE(2994),
    [sym_formal_parameters] = STATE(5475),
    [sym_nested_type_identifier] = STATE(2939),
    [sym__type_query_member_expression_in_type_annotation] = STATE(2937),
    [sym__type_query_call_expression_in_type_annotation] = STATE(2938),
    [sym_asserts] = STATE(3023),
    [sym_type] = STATE(3095),
    [sym_constructor_type] = STATE(3007),
    [sym_primary_type] = STATE(2981),
    [sym_template_literal_type] = STATE(3039),
    [sym_infer_type] = STATE(3007),
    [sym_conditional_type] = STATE(3039),
    [sym_generic_type] = STATE(3039),
    [sym_type_predicate] = STATE(3023),
    [sym_type_query] = STATE(3039),
    [sym_index_type_query] = STATE(3039),
    [sym_lookup_type] = STATE(3039),
    [sym_literal_type] = STATE(3039),
    [sym__number] = STATE(3041),
    [sym_existential_type] = STATE(3039),
    [sym_flow_maybe_type] = STATE(3039),
    [sym_parenthesized_type] = STATE(3039),
    [sym_predefined_type] = STATE(3056),
    [sym_object_type] = STATE(3039),
    [sym_type_parameters] = STATE(5248),
    [sym_array_type] = STATE(3039),
    [sym_tuple_type] = STATE(3039),
    [sym_readonly_type] = STATE(3007),
    [sym_union_type] = STATE(3039),
    [sym_intersection_type] = STATE(3039),
    [sym_function_type] = STATE(3007),
    [sym_identifier] = ACTIONS(3133),
    [anon_sym_STAR] = ACTIONS(543),
    [anon_sym_LBRACE] = ACTIONS(1534),
    [anon_sym_typeof] = ACTIONS(1536),
    [anon_sym_import] = ACTIONS(1538),
    [anon_sym_const] = ACTIONS(133),
    [anon_sym_LPAREN] = ACTIONS(1540),
    [anon_sym_LBRACK] = ACTIONS(1542),
    [anon_sym_new] = ACTIONS(1544),
    [anon_sym_AMP] = ACTIONS(748),
    [anon_sym_PIPE] = ACTIONS(750),
    [anon_sym_PLUS] = ACTIONS(2497),
    [anon_sym_DASH] = ACTIONS(2497),
    [anon_sym_LT] = ACTIONS(2499),
    [anon_sym_void] = ACTIONS(216),
    [anon_sym_DQUOTE] = ACTIONS(1550),
    [anon_sym_SQUOTE] = ACTIONS(1552),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1554),
    [sym_number] = ACTIONS(1556),
    [sym_this] = ACTIONS(3135),
    [sym_true] = ACTIONS(1560),
    [sym_false] = ACTIONS(1560),
    [sym_null] = ACTIONS(1560),
    [sym_undefined] = ACTIONS(1560),
    [anon_sym_readonly] = ACTIONS(1562),
    [anon_sym_QMARK] = ACTIONS(774),
    [anon_sym_any] = ACTIONS(216),
    [anon_sym_number] = ACTIONS(216),
    [anon_sym_boolean] = ACTIONS(216),
    [anon_sym_string] = ACTIONS(216),
    [anon_sym_symbol] = ACTIONS(216),
    [anon_sym_object] = ACTIONS(216),
    [anon_sym_abstract] = ACTIONS(208),
    [anon_sym_asserts] = ACTIONS(3137),
    [anon_sym_infer] = ACTIONS(210),
    [anon_sym_keyof] = ACTIONS(212),
    [anon_sym_unique] = ACTIONS(214),
    [anon_sym_unknown] = ACTIONS(216),
    [anon_sym_never] = ACTIONS(216),
    [anon_sym_LBRACE_PIPE] = ACTIONS(218),
    [sym_html_comment] = ACTIONS(5),
  },
  [954] = {
    [sym_identifier] = ACTIONS(2531),
    [anon_sym_export] = ACTIONS(2531),
    [anon_sym_type] = ACTIONS(2531),
    [anon_sym_namespace] = ACTIONS(2531),
    [anon_sym_LBRACE] = ACTIONS(2529),
    [anon_sym_typeof] = ACTIONS(2531),
    [anon_sym_import] = ACTIONS(2531),
    [anon_sym_with] = ACTIONS(2531),
    [anon_sym_var] = ACTIONS(2531),
    [anon_sym_let] = ACTIONS(2531),
    [anon_sym_const] = ACTIONS(2531),
    [anon_sym_BANG] = ACTIONS(2529),
    [anon_sym_if] = ACTIONS(2531),
    [anon_sym_switch] = ACTIONS(2531),
    [anon_sym_for] = ACTIONS(2531),
    [anon_sym_LPAREN] = ACTIONS(2529),
    [anon_sym_SEMI] = ACTIONS(2529),
    [anon_sym_await] = ACTIONS(2531),
    [anon_sym_while] = ACTIONS(2531),
    [anon_sym_do] = ACTIONS(2531),
    [anon_sym_try] = ACTIONS(2531),
    [anon_sym_break] = ACTIONS(2531),
    [anon_sym_continue] = ACTIONS(2531),
    [anon_sym_debugger] = ACTIONS(2531),
    [anon_sym_return] = ACTIONS(2531),
    [anon_sym_throw] = ACTIONS(2531),
    [anon_sym_yield] = ACTIONS(2531),
    [anon_sym_LBRACK] = ACTIONS(2529),
    [anon_sym_class] = ACTIONS(2531),
    [anon_sym_async] = ACTIONS(2531),
    [anon_sym_function] = ACTIONS(2531),
    [anon_sym_new] = ACTIONS(2531),
    [anon_sym_using] = ACTIONS(2531),
    [anon_sym_PLUS] = ACTIONS(2531),
    [anon_sym_DASH] = ACTIONS(2531),
    [anon_sym_SLASH] = ACTIONS(2531),
    [anon_sym_LT] = ACTIONS(2529),
    [anon_sym_TILDE] = ACTIONS(2529),
    [anon_sym_void] = ACTIONS(2531),
    [anon_sym_delete] = ACTIONS(2531),
    [anon_sym_PLUS_PLUS] = ACTIONS(2529),
    [anon_sym_DASH_DASH] = ACTIONS(2529),
    [anon_sym_DQUOTE] = ACTIONS(2529),
    [anon_sym_SQUOTE] = ACTIONS(2529),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(2529),
    [sym_number] = ACTIONS(2529),
    [sym_private_property_identifier] = ACTIONS(2529),
    [sym_this] = ACTIONS(2531),
    [sym_super] = ACTIONS(2531),
    [sym_true] = ACTIONS(2531),
    [sym_false] = ACTIONS(2531),
    [sym_null] = ACTIONS(2531),
    [sym_undefined] = ACTIONS(2531),
    [anon_sym_AT] = ACTIONS(2529),
    [anon_sym_static] = ACTIONS(2531),
    [anon_sym_readonly] = ACTIONS(2531),
    [anon_sym_get] = ACTIONS(2531),
    [anon_sym_set] = ACTIONS(2531),
    [anon_sym_declare] = ACTIONS(2531),
    [anon_sym_public] = ACTIONS(2531),
    [anon_sym_private] = ACTIONS(2531),
    [anon_sym_protected] = ACTIONS(2531),
    [anon_sym_override] = ACTIONS(2531),
    [anon_sym_module] = ACTIONS(2531),
    [anon_sym_any] = ACTIONS(2531),
    [anon_sym_number] = ACTIONS(2531),
    [anon_sym_boolean] = ACTIONS(2531),
    [anon_sym_string] = ACTIONS(2531),
    [anon_sym_symbol] = ACTIONS(2531),
    [anon_sym_object] = ACTIONS(2531),
    [anon_sym_abstract] = ACTIONS(2531),
    [anon_sym_interface] = ACTIONS(2531),
    [anon_sym_enum] = ACTIONS(2531),
    [sym_html_comment] = ACTIONS(5),
  },
  [955] = {
    [sym_identifier] = ACTIONS(3129),
    [anon_sym_export] = ACTIONS(3129),
    [anon_sym_type] = ACTIONS(3129),
    [anon_sym_namespace] = ACTIONS(3129),
    [anon_sym_LBRACE] = ACTIONS(3131),
    [anon_sym_typeof] = ACTIONS(3129),
    [anon_sym_import] = ACTIONS(3129),
    [anon_sym_with] = ACTIONS(3129),
    [anon_sym_var] = ACTIONS(3129),
    [anon_sym_let] = ACTIONS(3129),
    [anon_sym_const] = ACTIONS(3129),
    [anon_sym_BANG] = ACTIONS(3131),
    [anon_sym_if] = ACTIONS(3129),
    [anon_sym_switch] = ACTIONS(3129),
    [anon_sym_for] = ACTIONS(3129),
    [anon_sym_LPAREN] = ACTIONS(3131),
    [anon_sym_SEMI] = ACTIONS(3131),
    [anon_sym_await] = ACTIONS(3129),
    [anon_sym_while] = ACTIONS(3129),
    [anon_sym_do] = ACTIONS(3129),
    [anon_sym_try] = ACTIONS(3129),
    [anon_sym_break] = ACTIONS(3129),
    [anon_sym_continue] = ACTIONS(3129),
    [anon_sym_debugger] = ACTIONS(3129),
    [anon_sym_return] = ACTIONS(3129),
    [anon_sym_throw] = ACTIONS(3129),
    [anon_sym_yield] = ACTIONS(3129),
    [anon_sym_LBRACK] = ACTIONS(3131),
    [anon_sym_class] = ACTIONS(3129),
    [anon_sym_async] = ACTIONS(3129),
    [anon_sym_function] = ACTIONS(3129),
    [anon_sym_new] = ACTIONS(3129),
    [anon_sym_using] = ACTIONS(3129),
    [anon_sym_PLUS] = ACTIONS(3129),
    [anon_sym_DASH] = ACTIONS(3129),
    [anon_sym_SLASH] = ACTIONS(3129),
    [anon_sym_LT] = ACTIONS(3131),
    [anon_sym_TILDE] = ACTIONS(3131),
    [anon_sym_void] = ACTIONS(3129),
    [anon_sym_delete] = ACTIONS(3129),
    [anon_sym_PLUS_PLUS] = ACTIONS(3131),
    [anon_sym_DASH_DASH] = ACTIONS(3131),
    [anon_sym_DQUOTE] = ACTIONS(3131),
    [anon_sym_SQUOTE] = ACTIONS(3131),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(3131),
    [sym_number] = ACTIONS(3131),
    [sym_private_property_identifier] = ACTIONS(3131),
    [sym_this] = ACTIONS(3129),
    [sym_super] = ACTIONS(3129),
    [sym_true] = ACTIONS(3129),
    [sym_false] = ACTIONS(3129),
    [sym_null] = ACTIONS(3129),
    [sym_undefined] = ACTIONS(3129),
    [anon_sym_AT] = ACTIONS(3131),
    [anon_sym_static] = ACTIONS(3129),
    [anon_sym_readonly] = ACTIONS(3129),
    [anon_sym_get] = ACTIONS(3129),
    [anon_sym_set] = ACTIONS(3129),
    [anon_sym_declare] = ACTIONS(3129),
    [anon_sym_public] = ACTIONS(3129),
    [anon_sym_private] = ACTIONS(3129),
    [anon_sym_protected] = ACTIONS(3129),
    [anon_sym_override] = ACTIONS(3129),
    [anon_sym_module] = ACTIONS(3129),
    [anon_sym_any] = ACTIONS(3129),
    [anon_sym_number] = ACTIONS(3129),
    [anon_sym_boolean] = ACTIONS(3129),
    [anon_sym_string] = ACTIONS(3129),
    [anon_sym_symbol] = ACTIONS(3129),
    [anon_sym_object] = ACTIONS(3129),
    [anon_sym_abstract] = ACTIONS(3129),
    [anon_sym_interface] = ACTIONS(3129),
    [anon_sym_enum] = ACTIONS(3129),
    [sym_html_comment] = ACTIONS(5),
  },
  [956] = {
    [sym_identifier] = ACTIONS(3129),
    [anon_sym_export] = ACTIONS(3129),
    [anon_sym_type] = ACTIONS(3129),
    [anon_sym_namespace] = ACTIONS(3129),
    [anon_sym_LBRACE] = ACTIONS(3131),
    [anon_sym_typeof] = ACTIONS(3129),
    [anon_sym_import] = ACTIONS(3129),
    [anon_sym_with] = ACTIONS(3129),
    [anon_sym_var] = ACTIONS(3129),
    [anon_sym_let] = ACTIONS(3129),
    [anon_sym_const] = ACTIONS(3129),
    [anon_sym_BANG] = ACTIONS(3131),
    [anon_sym_if] = ACTIONS(3129),
    [anon_sym_switch] = ACTIONS(3129),
    [anon_sym_for] = ACTIONS(3129),
    [anon_sym_LPAREN] = ACTIONS(3131),
    [anon_sym_SEMI] = ACTIONS(3131),
    [anon_sym_await] = ACTIONS(3129),
    [anon_sym_while] = ACTIONS(3129),
    [anon_sym_do] = ACTIONS(3129),
    [anon_sym_try] = ACTIONS(3129),
    [anon_sym_break] = ACTIONS(3129),
    [anon_sym_continue] = ACTIONS(3129),
    [anon_sym_debugger] = ACTIONS(3129),
    [anon_sym_return] = ACTIONS(3129),
    [anon_sym_throw] = ACTIONS(3129),
    [anon_sym_yield] = ACTIONS(3129),
    [anon_sym_LBRACK] = ACTIONS(3131),
    [anon_sym_class] = ACTIONS(3129),
    [anon_sym_async] = ACTIONS(3129),
    [anon_sym_function] = ACTIONS(3129),
    [anon_sym_new] = ACTIONS(3129),
    [anon_sym_using] = ACTIONS(3129),
    [anon_sym_PLUS] = ACTIONS(3129),
    [anon_sym_DASH] = ACTIONS(3129),
    [anon_sym_SLASH] = ACTIONS(3129),
    [anon_sym_LT] = ACTIONS(3131),
    [anon_sym_TILDE] = ACTIONS(3131),
    [anon_sym_void] = ACTIONS(3129),
    [anon_sym_delete] = ACTIONS(3129),
    [anon_sym_PLUS_PLUS] = ACTIONS(3131),
    [anon_sym_DASH_DASH] = ACTIONS(3131),
    [anon_sym_DQUOTE] = ACTIONS(3131),
    [anon_sym_SQUOTE] = ACTIONS(3131),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(3131),
    [sym_number] = ACTIONS(3131),
    [sym_private_property_identifier] = ACTIONS(3131),
    [sym_this] = ACTIONS(3129),
    [sym_super] = ACTIONS(3129),
    [sym_true] = ACTIONS(3129),
    [sym_false] = ACTIONS(3129),
    [sym_null] = ACTIONS(3129),
    [sym_undefined] = ACTIONS(3129),
    [anon_sym_AT] = ACTIONS(3131),
    [anon_sym_static] = ACTIONS(3129),
    [anon_sym_readonly] = ACTIONS(3129),
    [anon_sym_get] = ACTIONS(3129),
    [anon_sym_set] = ACTIONS(3129),
    [anon_sym_declare] = ACTIONS(3129),
    [anon_sym_public] = ACTIONS(3129),
    [anon_sym_private] = ACTIONS(3129),
    [anon_sym_protected] = ACTIONS(3129),
    [anon_sym_override] = ACTIONS(3129),
    [anon_sym_module] = ACTIONS(3129),
    [anon_sym_any] = ACTIONS(3129),
    [anon_sym_number] = ACTIONS(3129),
    [anon_sym_boolean] = ACTIONS(3129),
    [anon_sym_string] = ACTIONS(3129),
    [anon_sym_symbol] = ACTIONS(3129),
    [anon_sym_object] = ACTIONS(3129),
    [anon_sym_abstract] = ACTIONS(3129),
    [anon_sym_interface] = ACTIONS(3129),
    [anon_sym_enum] = ACTIONS(3129),
    [sym_html_comment] = ACTIONS(5),
  },
  [957] = {
    [sym_import] = STATE(4650),
    [sym_nested_identifier] = STATE(5567),
    [sym_string] = STATE(1975),
    [sym_formal_parameters] = STATE(5527),
    [sym_nested_type_identifier] = STATE(1865),
    [sym__type_query_member_expression_in_type_annotation] = STATE(1781),
    [sym__type_query_call_expression_in_type_annotation] = STATE(1911),
    [sym_asserts] = STATE(2039),
    [sym_type] = STATE(2040),
    [sym_constructor_type] = STATE(1912),
    [sym_primary_type] = STATE(1915),
    [sym_template_literal_type] = STATE(1916),
    [sym_infer_type] = STATE(1912),
    [sym_conditional_type] = STATE(1916),
    [sym_generic_type] = STATE(1916),
    [sym_type_predicate] = STATE(2039),
    [sym_type_query] = STATE(1916),
    [sym_index_type_query] = STATE(1916),
    [sym_lookup_type] = STATE(1916),
    [sym_literal_type] = STATE(1916),
    [sym__number] = STATE(1918),
    [sym_existential_type] = STATE(1916),
    [sym_flow_maybe_type] = STATE(1916),
    [sym_parenthesized_type] = STATE(1916),
    [sym_predefined_type] = STATE(1822),
    [sym_object_type] = STATE(1916),
    [sym_type_parameters] = STATE(5243),
    [sym_array_type] = STATE(1916),
    [sym_tuple_type] = STATE(1916),
    [sym_readonly_type] = STATE(1912),
    [sym_union_type] = STATE(1916),
    [sym_intersection_type] = STATE(1916),
    [sym_function_type] = STATE(1912),
    [sym_identifier] = ACTIONS(3045),
    [anon_sym_STAR] = ACTIONS(3047),
    [anon_sym_LBRACE] = ACTIONS(3049),
    [anon_sym_typeof] = ACTIONS(3051),
    [anon_sym_import] = ACTIONS(1538),
    [anon_sym_const] = ACTIONS(3053),
    [anon_sym_LPAREN] = ACTIONS(3055),
    [anon_sym_LBRACK] = ACTIONS(3057),
    [anon_sym_new] = ACTIONS(3059),
    [anon_sym_AMP] = ACTIONS(3061),
    [anon_sym_PIPE] = ACTIONS(3063),
    [anon_sym_PLUS] = ACTIONS(3065),
    [anon_sym_DASH] = ACTIONS(3065),
    [anon_sym_LT] = ACTIONS(2499),
    [anon_sym_void] = ACTIONS(3067),
    [anon_sym_DQUOTE] = ACTIONS(83),
    [anon_sym_SQUOTE] = ACTIONS(85),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(3069),
    [sym_number] = ACTIONS(3071),
    [sym_this] = ACTIONS(3073),
    [sym_true] = ACTIONS(3075),
    [sym_false] = ACTIONS(3075),
    [sym_null] = ACTIONS(3075),
    [sym_undefined] = ACTIONS(3075),
    [anon_sym_readonly] = ACTIONS(3077),
    [anon_sym_QMARK] = ACTIONS(3079),
    [anon_sym_any] = ACTIONS(3067),
    [anon_sym_number] = ACTIONS(3067),
    [anon_sym_boolean] = ACTIONS(3067),
    [anon_sym_string] = ACTIONS(3067),
    [anon_sym_symbol] = ACTIONS(3067),
    [anon_sym_object] = ACTIONS(3067),
    [anon_sym_abstract] = ACTIONS(3081),
    [anon_sym_asserts] = ACTIONS(3083),
    [anon_sym_infer] = ACTIONS(3085),
    [anon_sym_keyof] = ACTIONS(3087),
    [anon_sym_unique] = ACTIONS(3089),
    [anon_sym_unknown] = ACTIONS(3067),
    [anon_sym_never] = ACTIONS(3067),
    [anon_sym_LBRACE_PIPE] = ACTIONS(3091),
    [sym_html_comment] = ACTIONS(5),
  },
  [958] = {
    [sym_identifier] = ACTIONS(3129),
    [anon_sym_export] = ACTIONS(3129),
    [anon_sym_type] = ACTIONS(3129),
    [anon_sym_namespace] = ACTIONS(3129),
    [anon_sym_LBRACE] = ACTIONS(3131),
    [anon_sym_typeof] = ACTIONS(3129),
    [anon_sym_import] = ACTIONS(3129),
    [anon_sym_with] = ACTIONS(3129),
    [anon_sym_var] = ACTIONS(3129),
    [anon_sym_let] = ACTIONS(3129),
    [anon_sym_const] = ACTIONS(3129),
    [anon_sym_BANG] = ACTIONS(3131),
    [anon_sym_if] = ACTIONS(3129),
    [anon_sym_switch] = ACTIONS(3129),
    [anon_sym_for] = ACTIONS(3129),
    [anon_sym_LPAREN] = ACTIONS(3131),
    [anon_sym_SEMI] = ACTIONS(3131),
    [anon_sym_await] = ACTIONS(3129),
    [anon_sym_while] = ACTIONS(3129),
    [anon_sym_do] = ACTIONS(3129),
    [anon_sym_try] = ACTIONS(3129),
    [anon_sym_break] = ACTIONS(3129),
    [anon_sym_continue] = ACTIONS(3129),
    [anon_sym_debugger] = ACTIONS(3129),
    [anon_sym_return] = ACTIONS(3129),
    [anon_sym_throw] = ACTIONS(3129),
    [anon_sym_yield] = ACTIONS(3129),
    [anon_sym_LBRACK] = ACTIONS(3131),
    [anon_sym_class] = ACTIONS(3129),
    [anon_sym_async] = ACTIONS(3129),
    [anon_sym_function] = ACTIONS(3129),
    [anon_sym_new] = ACTIONS(3129),
    [anon_sym_using] = ACTIONS(3129),
    [anon_sym_PLUS] = ACTIONS(3129),
    [anon_sym_DASH] = ACTIONS(3129),
    [anon_sym_SLASH] = ACTIONS(3129),
    [anon_sym_LT] = ACTIONS(3131),
    [anon_sym_TILDE] = ACTIONS(3131),
    [anon_sym_void] = ACTIONS(3129),
    [anon_sym_delete] = ACTIONS(3129),
    [anon_sym_PLUS_PLUS] = ACTIONS(3131),
    [anon_sym_DASH_DASH] = ACTIONS(3131),
    [anon_sym_DQUOTE] = ACTIONS(3131),
    [anon_sym_SQUOTE] = ACTIONS(3131),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(3131),
    [sym_number] = ACTIONS(3131),
    [sym_private_property_identifier] = ACTIONS(3131),
    [sym_this] = ACTIONS(3129),
    [sym_super] = ACTIONS(3129),
    [sym_true] = ACTIONS(3129),
    [sym_false] = ACTIONS(3129),
    [sym_null] = ACTIONS(3129),
    [sym_undefined] = ACTIONS(3129),
    [anon_sym_AT] = ACTIONS(3131),
    [anon_sym_static] = ACTIONS(3129),
    [anon_sym_readonly] = ACTIONS(3129),
    [anon_sym_get] = ACTIONS(3129),
    [anon_sym_set] = ACTIONS(3129),
    [anon_sym_declare] = ACTIONS(3129),
    [anon_sym_public] = ACTIONS(3129),
    [anon_sym_private] = ACTIONS(3129),
    [anon_sym_protected] = ACTIONS(3129),
    [anon_sym_override] = ACTIONS(3129),
    [anon_sym_module] = ACTIONS(3129),
    [anon_sym_any] = ACTIONS(3129),
    [anon_sym_number] = ACTIONS(3129),
    [anon_sym_boolean] = ACTIONS(3129),
    [anon_sym_string] = ACTIONS(3129),
    [anon_sym_symbol] = ACTIONS(3129),
    [anon_sym_object] = ACTIONS(3129),
    [anon_sym_abstract] = ACTIONS(3129),
    [anon_sym_interface] = ACTIONS(3129),
    [anon_sym_enum] = ACTIONS(3129),
    [sym_html_comment] = ACTIONS(5),
  },
  [959] = {
    [sym_import] = STATE(4578),
    [sym_nested_identifier] = STATE(5796),
    [sym_string] = STATE(3437),
    [sym_formal_parameters] = STATE(5519),
    [sym_nested_type_identifier] = STATE(3278),
    [sym__type_query_member_expression_in_type_annotation] = STATE(3181),
    [sym__type_query_call_expression_in_type_annotation] = STATE(3311),
    [sym_asserts] = STATE(3918),
    [sym_type] = STATE(3502),
    [sym_constructor_type] = STATE(3448),
    [sym_primary_type] = STATE(3450),
    [sym_template_literal_type] = STATE(3453),
    [sym_infer_type] = STATE(3448),
    [sym_conditional_type] = STATE(3453),
    [sym_generic_type] = STATE(3453),
    [sym_type_predicate] = STATE(3919),
    [sym_type_query] = STATE(3453),
    [sym_index_type_query] = STATE(3453),
    [sym_lookup_type] = STATE(3453),
    [sym_literal_type] = STATE(3453),
    [sym__number] = STATE(3454),
    [sym_existential_type] = STATE(3453),
    [sym_flow_maybe_type] = STATE(3453),
    [sym_parenthesized_type] = STATE(3453),
    [sym_predefined_type] = STATE(3305),
    [sym_object_type] = STATE(3453),
    [sym_type_parameters] = STATE(5251),
    [sym_array_type] = STATE(3453),
    [sym_tuple_type] = STATE(3453),
    [sym_readonly_type] = STATE(3448),
    [sym_union_type] = STATE(3453),
    [sym_intersection_type] = STATE(3453),
    [sym_function_type] = STATE(3448),
    [sym_identifier] = ACTIONS(2993),
    [anon_sym_STAR] = ACTIONS(2995),
    [anon_sym_LBRACE] = ACTIONS(2997),
    [anon_sym_typeof] = ACTIONS(2999),
    [anon_sym_import] = ACTIONS(1538),
    [anon_sym_const] = ACTIONS(3001),
    [anon_sym_LPAREN] = ACTIONS(3003),
    [anon_sym_LBRACK] = ACTIONS(3005),
    [anon_sym_new] = ACTIONS(3007),
    [anon_sym_AMP] = ACTIONS(3009),
    [anon_sym_PIPE] = ACTIONS(3011),
    [anon_sym_PLUS] = ACTIONS(3013),
    [anon_sym_DASH] = ACTIONS(3013),
    [anon_sym_LT] = ACTIONS(2499),
    [anon_sym_void] = ACTIONS(3015),
    [anon_sym_DQUOTE] = ACTIONS(3017),
    [anon_sym_SQUOTE] = ACTIONS(3019),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(3021),
    [sym_number] = ACTIONS(3023),
    [sym_this] = ACTIONS(3025),
    [sym_true] = ACTIONS(3027),
    [sym_false] = ACTIONS(3027),
    [sym_null] = ACTIONS(3027),
    [sym_undefined] = ACTIONS(3027),
    [anon_sym_readonly] = ACTIONS(3029),
    [anon_sym_QMARK] = ACTIONS(3031),
    [anon_sym_any] = ACTIONS(3015),
    [anon_sym_number] = ACTIONS(3015),
    [anon_sym_boolean] = ACTIONS(3015),
    [anon_sym_string] = ACTIONS(3015),
    [anon_sym_symbol] = ACTIONS(3015),
    [anon_sym_object] = ACTIONS(3015),
    [anon_sym_abstract] = ACTIONS(3033),
    [anon_sym_asserts] = ACTIONS(3035),
    [anon_sym_infer] = ACTIONS(3037),
    [anon_sym_keyof] = ACTIONS(3039),
    [anon_sym_unique] = ACTIONS(3041),
    [anon_sym_unknown] = ACTIONS(3015),
    [anon_sym_never] = ACTIONS(3015),
    [anon_sym_LBRACE_PIPE] = ACTIONS(3043),
    [sym_html_comment] = ACTIONS(5),
  },
  [960] = {
    [sym_identifier] = ACTIONS(3129),
    [anon_sym_export] = ACTIONS(3129),
    [anon_sym_type] = ACTIONS(3129),
    [anon_sym_namespace] = ACTIONS(3129),
    [anon_sym_LBRACE] = ACTIONS(3131),
    [anon_sym_typeof] = ACTIONS(3129),
    [anon_sym_import] = ACTIONS(3129),
    [anon_sym_with] = ACTIONS(3129),
    [anon_sym_var] = ACTIONS(3129),
    [anon_sym_let] = ACTIONS(3129),
    [anon_sym_const] = ACTIONS(3129),
    [anon_sym_BANG] = ACTIONS(3131),
    [anon_sym_if] = ACTIONS(3129),
    [anon_sym_switch] = ACTIONS(3129),
    [anon_sym_for] = ACTIONS(3129),
    [anon_sym_LPAREN] = ACTIONS(3131),
    [anon_sym_SEMI] = ACTIONS(3131),
    [anon_sym_await] = ACTIONS(3129),
    [anon_sym_while] = ACTIONS(3129),
    [anon_sym_do] = ACTIONS(3129),
    [anon_sym_try] = ACTIONS(3129),
    [anon_sym_break] = ACTIONS(3129),
    [anon_sym_continue] = ACTIONS(3129),
    [anon_sym_debugger] = ACTIONS(3129),
    [anon_sym_return] = ACTIONS(3129),
    [anon_sym_throw] = ACTIONS(3129),
    [anon_sym_yield] = ACTIONS(3129),
    [anon_sym_LBRACK] = ACTIONS(3131),
    [anon_sym_class] = ACTIONS(3129),
    [anon_sym_async] = ACTIONS(3129),
    [anon_sym_function] = ACTIONS(3129),
    [anon_sym_new] = ACTIONS(3129),
    [anon_sym_using] = ACTIONS(3129),
    [anon_sym_PLUS] = ACTIONS(3129),
    [anon_sym_DASH] = ACTIONS(3129),
    [anon_sym_SLASH] = ACTIONS(3129),
    [anon_sym_LT] = ACTIONS(3131),
    [anon_sym_TILDE] = ACTIONS(3131),
    [anon_sym_void] = ACTIONS(3129),
    [anon_sym_delete] = ACTIONS(3129),
    [anon_sym_PLUS_PLUS] = ACTIONS(3131),
    [anon_sym_DASH_DASH] = ACTIONS(3131),
    [anon_sym_DQUOTE] = ACTIONS(3131),
    [anon_sym_SQUOTE] = ACTIONS(3131),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(3131),
    [sym_number] = ACTIONS(3131),
    [sym_private_property_identifier] = ACTIONS(3131),
    [sym_this] = ACTIONS(3129),
    [sym_super] = ACTIONS(3129),
    [sym_true] = ACTIONS(3129),
    [sym_false] = ACTIONS(3129),
    [sym_null] = ACTIONS(3129),
    [sym_undefined] = ACTIONS(3129),
    [anon_sym_AT] = ACTIONS(3131),
    [anon_sym_static] = ACTIONS(3129),
    [anon_sym_readonly] = ACTIONS(3129),
    [anon_sym_get] = ACTIONS(3129),
    [anon_sym_set] = ACTIONS(3129),
    [anon_sym_declare] = ACTIONS(3129),
    [anon_sym_public] = ACTIONS(3129),
    [anon_sym_private] = ACTIONS(3129),
    [anon_sym_protected] = ACTIONS(3129),
    [anon_sym_override] = ACTIONS(3129),
    [anon_sym_module] = ACTIONS(3129),
    [anon_sym_any] = ACTIONS(3129),
    [anon_sym_number] = ACTIONS(3129),
    [anon_sym_boolean] = ACTIONS(3129),
    [anon_sym_string] = ACTIONS(3129),
    [anon_sym_symbol] = ACTIONS(3129),
    [anon_sym_object] = ACTIONS(3129),
    [anon_sym_abstract] = ACTIONS(3129),
    [anon_sym_interface] = ACTIONS(3129),
    [anon_sym_enum] = ACTIONS(3129),
    [sym_html_comment] = ACTIONS(5),
  },
  [961] = {
    [sym_import] = STATE(4950),
    [sym_nested_identifier] = STATE(5535),
    [sym_string] = STATE(3265),
    [sym_formal_parameters] = STATE(5840),
    [sym_nested_type_identifier] = STATE(3151),
    [sym__type_query_member_expression_in_type_annotation] = STATE(3076),
    [sym__type_query_call_expression_in_type_annotation] = STATE(3200),
    [sym_asserts] = STATE(3811),
    [sym_type] = STATE(3302),
    [sym_constructor_type] = STATE(3271),
    [sym_primary_type] = STATE(3272),
    [sym_template_literal_type] = STATE(3273),
    [sym_infer_type] = STATE(3271),
    [sym_conditional_type] = STATE(3273),
    [sym_generic_type] = STATE(3273),
    [sym_type_predicate] = STATE(3862),
    [sym_type_query] = STATE(3273),
    [sym_index_type_query] = STATE(3273),
    [sym_lookup_type] = STATE(3273),
    [sym_literal_type] = STATE(3273),
    [sym__number] = STATE(3274),
    [sym_existential_type] = STATE(3273),
    [sym_flow_maybe_type] = STATE(3273),
    [sym_parenthesized_type] = STATE(3273),
    [sym_predefined_type] = STATE(3212),
    [sym_object_type] = STATE(3273),
    [sym_type_parameters] = STATE(5146),
    [sym_array_type] = STATE(3273),
    [sym_tuple_type] = STATE(3273),
    [sym_readonly_type] = STATE(3271),
    [sym_union_type] = STATE(3273),
    [sym_intersection_type] = STATE(3273),
    [sym_function_type] = STATE(3271),
    [sym_identifier] = ACTIONS(2981),
    [anon_sym_STAR] = ACTIONS(986),
    [anon_sym_LBRACE] = ACTIONS(1610),
    [anon_sym_typeof] = ACTIONS(1612),
    [anon_sym_import] = ACTIONS(1538),
    [anon_sym_const] = ACTIONS(992),
    [anon_sym_LPAREN] = ACTIONS(1614),
    [anon_sym_LBRACK] = ACTIONS(1616),
    [anon_sym_new] = ACTIONS(1618),
    [anon_sym_AMP] = ACTIONS(1000),
    [anon_sym_PIPE] = ACTIONS(1002),
    [anon_sym_PLUS] = ACTIONS(2983),
    [anon_sym_DASH] = ACTIONS(2983),
    [anon_sym_LT] = ACTIONS(2499),
    [anon_sym_void] = ACTIONS(1032),
    [anon_sym_DQUOTE] = ACTIONS(1626),
    [anon_sym_SQUOTE] = ACTIONS(1628),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1630),
    [sym_number] = ACTIONS(1632),
    [sym_this] = ACTIONS(2985),
    [sym_true] = ACTIONS(1636),
    [sym_false] = ACTIONS(1636),
    [sym_null] = ACTIONS(1636),
    [sym_undefined] = ACTIONS(1636),
    [anon_sym_readonly] = ACTIONS(1638),
    [anon_sym_QMARK] = ACTIONS(1020),
    [anon_sym_any] = ACTIONS(1032),
    [anon_sym_number] = ACTIONS(1032),
    [anon_sym_boolean] = ACTIONS(1032),
    [anon_sym_string] = ACTIONS(1032),
    [anon_sym_symbol] = ACTIONS(1032),
    [anon_sym_object] = ACTIONS(1032),
    [anon_sym_abstract] = ACTIONS(1024),
    [anon_sym_asserts] = ACTIONS(2987),
    [anon_sym_infer] = ACTIONS(1026),
    [anon_sym_keyof] = ACTIONS(1028),
    [anon_sym_unique] = ACTIONS(1030),
    [anon_sym_unknown] = ACTIONS(1032),
    [anon_sym_never] = ACTIONS(1032),
    [anon_sym_LBRACE_PIPE] = ACTIONS(1034),
    [sym_html_comment] = ACTIONS(5),
  },
  [962] = {
    [sym_import] = STATE(4681),
    [sym_nested_identifier] = STATE(5474),
    [sym_string] = STATE(2994),
    [sym_formal_parameters] = STATE(5619),
    [sym_nested_type_identifier] = STATE(2939),
    [sym__type_query_member_expression_in_type_annotation] = STATE(3303),
    [sym__type_query_call_expression_in_type_annotation] = STATE(2938),
    [sym_asserts] = STATE(3023),
    [sym_type] = STATE(3711),
    [sym_constructor_type] = STATE(3007),
    [sym_primary_type] = STATE(2981),
    [sym_template_literal_type] = STATE(3039),
    [sym_infer_type] = STATE(3007),
    [sym_conditional_type] = STATE(3039),
    [sym_generic_type] = STATE(3039),
    [sym_type_predicate] = STATE(3023),
    [sym_type_query] = STATE(3039),
    [sym_index_type_query] = STATE(3039),
    [sym_lookup_type] = STATE(3039),
    [sym_literal_type] = STATE(3039),
    [sym__number] = STATE(3041),
    [sym_existential_type] = STATE(3039),
    [sym_flow_maybe_type] = STATE(3039),
    [sym_parenthesized_type] = STATE(3039),
    [sym_predefined_type] = STATE(3494),
    [sym_object_type] = STATE(3039),
    [sym_type_parameters] = STATE(5454),
    [sym_array_type] = STATE(3039),
    [sym_tuple_type] = STATE(3039),
    [sym_readonly_type] = STATE(3007),
    [sym_union_type] = STATE(3039),
    [sym_intersection_type] = STATE(3039),
    [sym_function_type] = STATE(3007),
    [sym_identifier] = ACTIONS(3139),
    [anon_sym_STAR] = ACTIONS(543),
    [anon_sym_LBRACE] = ACTIONS(1534),
    [anon_sym_typeof] = ACTIONS(1536),
    [anon_sym_import] = ACTIONS(1538),
    [anon_sym_const] = ACTIONS(133),
    [anon_sym_LPAREN] = ACTIONS(1540),
    [anon_sym_LBRACK] = ACTIONS(1542),
    [anon_sym_new] = ACTIONS(1642),
    [anon_sym_AMP] = ACTIONS(571),
    [anon_sym_PIPE] = ACTIONS(573),
    [anon_sym_PLUS] = ACTIONS(2497),
    [anon_sym_DASH] = ACTIONS(2497),
    [anon_sym_LT] = ACTIONS(2499),
    [anon_sym_void] = ACTIONS(216),
    [anon_sym_DQUOTE] = ACTIONS(1550),
    [anon_sym_SQUOTE] = ACTIONS(1552),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1554),
    [sym_number] = ACTIONS(1556),
    [sym_this] = ACTIONS(3141),
    [sym_true] = ACTIONS(1560),
    [sym_false] = ACTIONS(1560),
    [sym_null] = ACTIONS(1560),
    [sym_undefined] = ACTIONS(1560),
    [anon_sym_readonly] = ACTIONS(1648),
    [anon_sym_QMARK] = ACTIONS(593),
    [anon_sym_any] = ACTIONS(216),
    [anon_sym_number] = ACTIONS(216),
    [anon_sym_boolean] = ACTIONS(216),
    [anon_sym_string] = ACTIONS(216),
    [anon_sym_symbol] = ACTIONS(216),
    [anon_sym_object] = ACTIONS(216),
    [anon_sym_abstract] = ACTIONS(597),
    [anon_sym_asserts] = ACTIONS(3143),
    [anon_sym_infer] = ACTIONS(599),
    [anon_sym_keyof] = ACTIONS(601),
    [anon_sym_unique] = ACTIONS(214),
    [anon_sym_unknown] = ACTIONS(216),
    [anon_sym_never] = ACTIONS(216),
    [anon_sym_LBRACE_PIPE] = ACTIONS(218),
    [sym_html_comment] = ACTIONS(5),
  },
  [963] = {
    [sym_import] = STATE(4878),
    [sym_nested_identifier] = STATE(5474),
    [sym_string] = STATE(2994),
    [sym_formal_parameters] = STATE(5475),
    [sym_nested_type_identifier] = STATE(2939),
    [sym__type_query_member_expression_in_type_annotation] = STATE(2937),
    [sym__type_query_call_expression_in_type_annotation] = STATE(2938),
    [sym_asserts] = STATE(5193),
    [sym_type] = STATE(3340),
    [sym_constructor_type] = STATE(3007),
    [sym_primary_type] = STATE(2981),
    [sym_template_literal_type] = STATE(3039),
    [sym_infer_type] = STATE(3007),
    [sym_conditional_type] = STATE(3039),
    [sym_generic_type] = STATE(3039),
    [sym_type_predicate] = STATE(5196),
    [sym_type_query] = STATE(3039),
    [sym_index_type_query] = STATE(3039),
    [sym_lookup_type] = STATE(3039),
    [sym_literal_type] = STATE(3039),
    [sym__number] = STATE(3041),
    [sym_existential_type] = STATE(3039),
    [sym_flow_maybe_type] = STATE(3039),
    [sym_parenthesized_type] = STATE(3039),
    [sym_predefined_type] = STATE(3056),
    [sym_object_type] = STATE(3039),
    [sym_type_parameters] = STATE(5248),
    [sym_array_type] = STATE(3039),
    [sym_tuple_type] = STATE(3039),
    [sym_readonly_type] = STATE(3007),
    [sym_union_type] = STATE(3039),
    [sym_intersection_type] = STATE(3039),
    [sym_function_type] = STATE(3007),
    [sym_identifier] = ACTIONS(3133),
    [anon_sym_STAR] = ACTIONS(543),
    [anon_sym_LBRACE] = ACTIONS(1534),
    [anon_sym_typeof] = ACTIONS(1536),
    [anon_sym_import] = ACTIONS(1538),
    [anon_sym_const] = ACTIONS(133),
    [anon_sym_LPAREN] = ACTIONS(1540),
    [anon_sym_LBRACK] = ACTIONS(1542),
    [anon_sym_new] = ACTIONS(1544),
    [anon_sym_AMP] = ACTIONS(748),
    [anon_sym_PIPE] = ACTIONS(750),
    [anon_sym_PLUS] = ACTIONS(2497),
    [anon_sym_DASH] = ACTIONS(2497),
    [anon_sym_LT] = ACTIONS(2499),
    [anon_sym_void] = ACTIONS(216),
    [anon_sym_DQUOTE] = ACTIONS(1550),
    [anon_sym_SQUOTE] = ACTIONS(1552),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1554),
    [sym_number] = ACTIONS(1556),
    [sym_this] = ACTIONS(3135),
    [sym_true] = ACTIONS(1560),
    [sym_false] = ACTIONS(1560),
    [sym_null] = ACTIONS(1560),
    [sym_undefined] = ACTIONS(1560),
    [anon_sym_readonly] = ACTIONS(1562),
    [anon_sym_QMARK] = ACTIONS(774),
    [anon_sym_any] = ACTIONS(216),
    [anon_sym_number] = ACTIONS(216),
    [anon_sym_boolean] = ACTIONS(216),
    [anon_sym_string] = ACTIONS(216),
    [anon_sym_symbol] = ACTIONS(216),
    [anon_sym_object] = ACTIONS(216),
    [anon_sym_abstract] = ACTIONS(208),
    [anon_sym_asserts] = ACTIONS(3137),
    [anon_sym_infer] = ACTIONS(210),
    [anon_sym_keyof] = ACTIONS(212),
    [anon_sym_unique] = ACTIONS(214),
    [anon_sym_unknown] = ACTIONS(216),
    [anon_sym_never] = ACTIONS(216),
    [anon_sym_LBRACE_PIPE] = ACTIONS(218),
    [sym_html_comment] = ACTIONS(5),
  },
  [964] = {
    [sym_import] = STATE(4950),
    [sym_nested_identifier] = STATE(5535),
    [sym_string] = STATE(3265),
    [sym_formal_parameters] = STATE(5840),
    [sym_nested_type_identifier] = STATE(3151),
    [sym__type_query_member_expression_in_type_annotation] = STATE(3076),
    [sym__type_query_call_expression_in_type_annotation] = STATE(3200),
    [sym_asserts] = STATE(3270),
    [sym_type] = STATE(3275),
    [sym_constructor_type] = STATE(3271),
    [sym_primary_type] = STATE(3272),
    [sym_template_literal_type] = STATE(3273),
    [sym_infer_type] = STATE(3271),
    [sym_conditional_type] = STATE(3273),
    [sym_generic_type] = STATE(3273),
    [sym_type_predicate] = STATE(3270),
    [sym_type_query] = STATE(3273),
    [sym_index_type_query] = STATE(3273),
    [sym_lookup_type] = STATE(3273),
    [sym_literal_type] = STATE(3273),
    [sym__number] = STATE(3274),
    [sym_existential_type] = STATE(3273),
    [sym_flow_maybe_type] = STATE(3273),
    [sym_parenthesized_type] = STATE(3273),
    [sym_predefined_type] = STATE(3212),
    [sym_object_type] = STATE(3273),
    [sym_type_parameters] = STATE(5146),
    [sym_array_type] = STATE(3273),
    [sym_tuple_type] = STATE(3273),
    [sym_readonly_type] = STATE(3271),
    [sym_union_type] = STATE(3273),
    [sym_intersection_type] = STATE(3273),
    [sym_function_type] = STATE(3271),
    [sym_identifier] = ACTIONS(2981),
    [anon_sym_STAR] = ACTIONS(986),
    [anon_sym_LBRACE] = ACTIONS(1610),
    [anon_sym_typeof] = ACTIONS(1612),
    [anon_sym_import] = ACTIONS(1538),
    [anon_sym_const] = ACTIONS(992),
    [anon_sym_LPAREN] = ACTIONS(1614),
    [anon_sym_LBRACK] = ACTIONS(1616),
    [anon_sym_new] = ACTIONS(1618),
    [anon_sym_AMP] = ACTIONS(1000),
    [anon_sym_PIPE] = ACTIONS(1002),
    [anon_sym_PLUS] = ACTIONS(2983),
    [anon_sym_DASH] = ACTIONS(2983),
    [anon_sym_LT] = ACTIONS(2499),
    [anon_sym_void] = ACTIONS(1032),
    [anon_sym_DQUOTE] = ACTIONS(1626),
    [anon_sym_SQUOTE] = ACTIONS(1628),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1630),
    [sym_number] = ACTIONS(1632),
    [sym_this] = ACTIONS(2985),
    [sym_true] = ACTIONS(1636),
    [sym_false] = ACTIONS(1636),
    [sym_null] = ACTIONS(1636),
    [sym_undefined] = ACTIONS(1636),
    [anon_sym_readonly] = ACTIONS(1638),
    [anon_sym_QMARK] = ACTIONS(1020),
    [anon_sym_any] = ACTIONS(1032),
    [anon_sym_number] = ACTIONS(1032),
    [anon_sym_boolean] = ACTIONS(1032),
    [anon_sym_string] = ACTIONS(1032),
    [anon_sym_symbol] = ACTIONS(1032),
    [anon_sym_object] = ACTIONS(1032),
    [anon_sym_abstract] = ACTIONS(1024),
    [anon_sym_asserts] = ACTIONS(2987),
    [anon_sym_infer] = ACTIONS(1026),
    [anon_sym_keyof] = ACTIONS(1028),
    [anon_sym_unique] = ACTIONS(1030),
    [anon_sym_unknown] = ACTIONS(1032),
    [anon_sym_never] = ACTIONS(1032),
    [anon_sym_LBRACE_PIPE] = ACTIONS(1034),
    [sym_html_comment] = ACTIONS(5),
  },
  [965] = {
    [sym_identifier] = ACTIONS(3129),
    [anon_sym_export] = ACTIONS(3129),
    [anon_sym_type] = ACTIONS(3129),
    [anon_sym_namespace] = ACTIONS(3129),
    [anon_sym_LBRACE] = ACTIONS(3131),
    [anon_sym_typeof] = ACTIONS(3129),
    [anon_sym_import] = ACTIONS(3129),
    [anon_sym_with] = ACTIONS(3129),
    [anon_sym_var] = ACTIONS(3129),
    [anon_sym_let] = ACTIONS(3129),
    [anon_sym_const] = ACTIONS(3129),
    [anon_sym_BANG] = ACTIONS(3131),
    [anon_sym_if] = ACTIONS(3129),
    [anon_sym_switch] = ACTIONS(3129),
    [anon_sym_for] = ACTIONS(3129),
    [anon_sym_LPAREN] = ACTIONS(3131),
    [anon_sym_SEMI] = ACTIONS(3131),
    [anon_sym_await] = ACTIONS(3129),
    [anon_sym_while] = ACTIONS(3129),
    [anon_sym_do] = ACTIONS(3129),
    [anon_sym_try] = ACTIONS(3129),
    [anon_sym_break] = ACTIONS(3129),
    [anon_sym_continue] = ACTIONS(3129),
    [anon_sym_debugger] = ACTIONS(3129),
    [anon_sym_return] = ACTIONS(3129),
    [anon_sym_throw] = ACTIONS(3129),
    [anon_sym_yield] = ACTIONS(3129),
    [anon_sym_LBRACK] = ACTIONS(3131),
    [anon_sym_class] = ACTIONS(3129),
    [anon_sym_async] = ACTIONS(3129),
    [anon_sym_function] = ACTIONS(3129),
    [anon_sym_new] = ACTIONS(3129),
    [anon_sym_using] = ACTIONS(3129),
    [anon_sym_PLUS] = ACTIONS(3129),
    [anon_sym_DASH] = ACTIONS(3129),
    [anon_sym_SLASH] = ACTIONS(3129),
    [anon_sym_LT] = ACTIONS(3131),
    [anon_sym_TILDE] = ACTIONS(3131),
    [anon_sym_void] = ACTIONS(3129),
    [anon_sym_delete] = ACTIONS(3129),
    [anon_sym_PLUS_PLUS] = ACTIONS(3131),
    [anon_sym_DASH_DASH] = ACTIONS(3131),
    [anon_sym_DQUOTE] = ACTIONS(3131),
    [anon_sym_SQUOTE] = ACTIONS(3131),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(3131),
    [sym_number] = ACTIONS(3131),
    [sym_private_property_identifier] = ACTIONS(3131),
    [sym_this] = ACTIONS(3129),
    [sym_super] = ACTIONS(3129),
    [sym_true] = ACTIONS(3129),
    [sym_false] = ACTIONS(3129),
    [sym_null] = ACTIONS(3129),
    [sym_undefined] = ACTIONS(3129),
    [anon_sym_AT] = ACTIONS(3131),
    [anon_sym_static] = ACTIONS(3129),
    [anon_sym_readonly] = ACTIONS(3129),
    [anon_sym_get] = ACTIONS(3129),
    [anon_sym_set] = ACTIONS(3129),
    [anon_sym_declare] = ACTIONS(3129),
    [anon_sym_public] = ACTIONS(3129),
    [anon_sym_private] = ACTIONS(3129),
    [anon_sym_protected] = ACTIONS(3129),
    [anon_sym_override] = ACTIONS(3129),
    [anon_sym_module] = ACTIONS(3129),
    [anon_sym_any] = ACTIONS(3129),
    [anon_sym_number] = ACTIONS(3129),
    [anon_sym_boolean] = ACTIONS(3129),
    [anon_sym_string] = ACTIONS(3129),
    [anon_sym_symbol] = ACTIONS(3129),
    [anon_sym_object] = ACTIONS(3129),
    [anon_sym_abstract] = ACTIONS(3129),
    [anon_sym_interface] = ACTIONS(3129),
    [anon_sym_enum] = ACTIONS(3129),
    [sym_html_comment] = ACTIONS(5),
  },
  [966] = {
    [sym_identifier] = ACTIONS(3129),
    [anon_sym_export] = ACTIONS(3129),
    [anon_sym_type] = ACTIONS(3129),
    [anon_sym_namespace] = ACTIONS(3129),
    [anon_sym_LBRACE] = ACTIONS(3131),
    [anon_sym_typeof] = ACTIONS(3129),
    [anon_sym_import] = ACTIONS(3129),
    [anon_sym_with] = ACTIONS(3129),
    [anon_sym_var] = ACTIONS(3129),
    [anon_sym_let] = ACTIONS(3129),
    [anon_sym_const] = ACTIONS(3129),
    [anon_sym_BANG] = ACTIONS(3131),
    [anon_sym_if] = ACTIONS(3129),
    [anon_sym_switch] = ACTIONS(3129),
    [anon_sym_for] = ACTIONS(3129),
    [anon_sym_LPAREN] = ACTIONS(3131),
    [anon_sym_SEMI] = ACTIONS(3131),
    [anon_sym_await] = ACTIONS(3129),
    [anon_sym_while] = ACTIONS(3129),
    [anon_sym_do] = ACTIONS(3129),
    [anon_sym_try] = ACTIONS(3129),
    [anon_sym_break] = ACTIONS(3129),
    [anon_sym_continue] = ACTIONS(3129),
    [anon_sym_debugger] = ACTIONS(3129),
    [anon_sym_return] = ACTIONS(3129),
    [anon_sym_throw] = ACTIONS(3129),
    [anon_sym_yield] = ACTIONS(3129),
    [anon_sym_LBRACK] = ACTIONS(3131),
    [anon_sym_class] = ACTIONS(3129),
    [anon_sym_async] = ACTIONS(3129),
    [anon_sym_function] = ACTIONS(3129),
    [anon_sym_new] = ACTIONS(3129),
    [anon_sym_using] = ACTIONS(3129),
    [anon_sym_PLUS] = ACTIONS(3129),
    [anon_sym_DASH] = ACTIONS(3129),
    [anon_sym_SLASH] = ACTIONS(3129),
    [anon_sym_LT] = ACTIONS(3131),
    [anon_sym_TILDE] = ACTIONS(3131),
    [anon_sym_void] = ACTIONS(3129),
    [anon_sym_delete] = ACTIONS(3129),
    [anon_sym_PLUS_PLUS] = ACTIONS(3131),
    [anon_sym_DASH_DASH] = ACTIONS(3131),
    [anon_sym_DQUOTE] = ACTIONS(3131),
    [anon_sym_SQUOTE] = ACTIONS(3131),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(3131),
    [sym_number] = ACTIONS(3131),
    [sym_private_property_identifier] = ACTIONS(3131),
    [sym_this] = ACTIONS(3129),
    [sym_super] = ACTIONS(3129),
    [sym_true] = ACTIONS(3129),
    [sym_false] = ACTIONS(3129),
    [sym_null] = ACTIONS(3129),
    [sym_undefined] = ACTIONS(3129),
    [anon_sym_AT] = ACTIONS(3131),
    [anon_sym_static] = ACTIONS(3129),
    [anon_sym_readonly] = ACTIONS(3129),
    [anon_sym_get] = ACTIONS(3129),
    [anon_sym_set] = ACTIONS(3129),
    [anon_sym_declare] = ACTIONS(3129),
    [anon_sym_public] = ACTIONS(3129),
    [anon_sym_private] = ACTIONS(3129),
    [anon_sym_protected] = ACTIONS(3129),
    [anon_sym_override] = ACTIONS(3129),
    [anon_sym_module] = ACTIONS(3129),
    [anon_sym_any] = ACTIONS(3129),
    [anon_sym_number] = ACTIONS(3129),
    [anon_sym_boolean] = ACTIONS(3129),
    [anon_sym_string] = ACTIONS(3129),
    [anon_sym_symbol] = ACTIONS(3129),
    [anon_sym_object] = ACTIONS(3129),
    [anon_sym_abstract] = ACTIONS(3129),
    [anon_sym_interface] = ACTIONS(3129),
    [anon_sym_enum] = ACTIONS(3129),
    [sym_html_comment] = ACTIONS(5),
  },
  [967] = {
    [sym_import] = STATE(4681),
    [sym_nested_identifier] = STATE(5474),
    [sym_string] = STATE(2994),
    [sym_formal_parameters] = STATE(5619),
    [sym_nested_type_identifier] = STATE(2939),
    [sym__type_query_member_expression_in_type_annotation] = STATE(3303),
    [sym__type_query_call_expression_in_type_annotation] = STATE(2938),
    [sym_asserts] = STATE(3018),
    [sym_type] = STATE(3731),
    [sym_constructor_type] = STATE(3007),
    [sym_primary_type] = STATE(2981),
    [sym_template_literal_type] = STATE(3039),
    [sym_infer_type] = STATE(3007),
    [sym_conditional_type] = STATE(3039),
    [sym_generic_type] = STATE(3039),
    [sym_type_predicate] = STATE(3018),
    [sym_type_query] = STATE(3039),
    [sym_index_type_query] = STATE(3039),
    [sym_lookup_type] = STATE(3039),
    [sym_literal_type] = STATE(3039),
    [sym__number] = STATE(3041),
    [sym_existential_type] = STATE(3039),
    [sym_flow_maybe_type] = STATE(3039),
    [sym_parenthesized_type] = STATE(3039),
    [sym_predefined_type] = STATE(3494),
    [sym_object_type] = STATE(3039),
    [sym_type_parameters] = STATE(5454),
    [sym_array_type] = STATE(3039),
    [sym_tuple_type] = STATE(3039),
    [sym_readonly_type] = STATE(3007),
    [sym_union_type] = STATE(3039),
    [sym_intersection_type] = STATE(3039),
    [sym_function_type] = STATE(3007),
    [sym_identifier] = ACTIONS(3139),
    [anon_sym_STAR] = ACTIONS(543),
    [anon_sym_LBRACE] = ACTIONS(1534),
    [anon_sym_typeof] = ACTIONS(1536),
    [anon_sym_import] = ACTIONS(1538),
    [anon_sym_const] = ACTIONS(133),
    [anon_sym_LPAREN] = ACTIONS(1540),
    [anon_sym_LBRACK] = ACTIONS(1542),
    [anon_sym_new] = ACTIONS(1642),
    [anon_sym_AMP] = ACTIONS(571),
    [anon_sym_PIPE] = ACTIONS(573),
    [anon_sym_PLUS] = ACTIONS(2497),
    [anon_sym_DASH] = ACTIONS(2497),
    [anon_sym_LT] = ACTIONS(2499),
    [anon_sym_void] = ACTIONS(216),
    [anon_sym_DQUOTE] = ACTIONS(1550),
    [anon_sym_SQUOTE] = ACTIONS(1552),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1554),
    [sym_number] = ACTIONS(1556),
    [sym_this] = ACTIONS(3141),
    [sym_true] = ACTIONS(1560),
    [sym_false] = ACTIONS(1560),
    [sym_null] = ACTIONS(1560),
    [sym_undefined] = ACTIONS(1560),
    [anon_sym_readonly] = ACTIONS(1648),
    [anon_sym_QMARK] = ACTIONS(593),
    [anon_sym_any] = ACTIONS(216),
    [anon_sym_number] = ACTIONS(216),
    [anon_sym_boolean] = ACTIONS(216),
    [anon_sym_string] = ACTIONS(216),
    [anon_sym_symbol] = ACTIONS(216),
    [anon_sym_object] = ACTIONS(216),
    [anon_sym_abstract] = ACTIONS(597),
    [anon_sym_asserts] = ACTIONS(3143),
    [anon_sym_infer] = ACTIONS(599),
    [anon_sym_keyof] = ACTIONS(601),
    [anon_sym_unique] = ACTIONS(214),
    [anon_sym_unknown] = ACTIONS(216),
    [anon_sym_never] = ACTIONS(216),
    [anon_sym_LBRACE_PIPE] = ACTIONS(218),
    [sym_html_comment] = ACTIONS(5),
  },
  [968] = {
    [sym_import] = STATE(4531),
    [sym_nested_identifier] = STATE(5486),
    [sym_string] = STATE(1632),
    [sym_formal_parameters] = STATE(5639),
    [sym_nested_type_identifier] = STATE(1527),
    [sym__type_query_member_expression_in_type_annotation] = STATE(1514),
    [sym__type_query_call_expression_in_type_annotation] = STATE(1574),
    [sym_asserts] = STATE(1631),
    [sym_type] = STATE(1634),
    [sym_constructor_type] = STATE(1544),
    [sym_primary_type] = STATE(1554),
    [sym_template_literal_type] = STATE(1556),
    [sym_infer_type] = STATE(1544),
    [sym_conditional_type] = STATE(1556),
    [sym_generic_type] = STATE(1556),
    [sym_type_predicate] = STATE(1631),
    [sym_type_query] = STATE(1556),
    [sym_index_type_query] = STATE(1556),
    [sym_lookup_type] = STATE(1556),
    [sym_literal_type] = STATE(1556),
    [sym__number] = STATE(1536),
    [sym_existential_type] = STATE(1556),
    [sym_flow_maybe_type] = STATE(1556),
    [sym_parenthesized_type] = STATE(1556),
    [sym_predefined_type] = STATE(1524),
    [sym_object_type] = STATE(1556),
    [sym_type_parameters] = STATE(5205),
    [sym_array_type] = STATE(1556),
    [sym_tuple_type] = STATE(1556),
    [sym_readonly_type] = STATE(1544),
    [sym_union_type] = STATE(1556),
    [sym_intersection_type] = STATE(1556),
    [sym_function_type] = STATE(1544),
    [sym_identifier] = ACTIONS(3145),
    [anon_sym_STAR] = ACTIONS(3147),
    [anon_sym_LBRACE] = ACTIONS(3149),
    [anon_sym_typeof] = ACTIONS(3151),
    [anon_sym_import] = ACTIONS(1538),
    [anon_sym_const] = ACTIONS(3153),
    [anon_sym_LPAREN] = ACTIONS(3155),
    [anon_sym_LBRACK] = ACTIONS(3157),
    [anon_sym_new] = ACTIONS(3159),
    [anon_sym_AMP] = ACTIONS(3161),
    [anon_sym_PIPE] = ACTIONS(3163),
    [anon_sym_PLUS] = ACTIONS(3165),
    [anon_sym_DASH] = ACTIONS(3165),
    [anon_sym_LT] = ACTIONS(2499),
    [anon_sym_void] = ACTIONS(3167),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(3169),
    [sym_number] = ACTIONS(3171),
    [sym_this] = ACTIONS(3173),
    [sym_true] = ACTIONS(3175),
    [sym_false] = ACTIONS(3175),
    [sym_null] = ACTIONS(3175),
    [sym_undefined] = ACTIONS(3175),
    [anon_sym_readonly] = ACTIONS(3177),
    [anon_sym_QMARK] = ACTIONS(3179),
    [anon_sym_any] = ACTIONS(3167),
    [anon_sym_number] = ACTIONS(3167),
    [anon_sym_boolean] = ACTIONS(3167),
    [anon_sym_string] = ACTIONS(3167),
    [anon_sym_symbol] = ACTIONS(3167),
    [anon_sym_object] = ACTIONS(3167),
    [anon_sym_abstract] = ACTIONS(3181),
    [anon_sym_asserts] = ACTIONS(3183),
    [anon_sym_infer] = ACTIONS(3185),
    [anon_sym_keyof] = ACTIONS(3187),
    [anon_sym_unique] = ACTIONS(3189),
    [anon_sym_unknown] = ACTIONS(3167),
    [anon_sym_never] = ACTIONS(3167),
    [anon_sym_LBRACE_PIPE] = ACTIONS(3191),
    [sym_html_comment] = ACTIONS(5),
  },
  [969] = {
    [sym_identifier] = ACTIONS(2509),
    [anon_sym_export] = ACTIONS(2509),
    [anon_sym_type] = ACTIONS(2509),
    [anon_sym_namespace] = ACTIONS(2509),
    [anon_sym_LBRACE] = ACTIONS(2507),
    [anon_sym_typeof] = ACTIONS(2509),
    [anon_sym_import] = ACTIONS(2509),
    [anon_sym_with] = ACTIONS(2509),
    [anon_sym_var] = ACTIONS(2509),
    [anon_sym_let] = ACTIONS(2509),
    [anon_sym_const] = ACTIONS(2509),
    [anon_sym_BANG] = ACTIONS(2507),
    [anon_sym_if] = ACTIONS(2509),
    [anon_sym_switch] = ACTIONS(2509),
    [anon_sym_for] = ACTIONS(2509),
    [anon_sym_LPAREN] = ACTIONS(2507),
    [anon_sym_SEMI] = ACTIONS(2507),
    [anon_sym_await] = ACTIONS(2509),
    [anon_sym_while] = ACTIONS(2509),
    [anon_sym_do] = ACTIONS(2509),
    [anon_sym_try] = ACTIONS(2509),
    [anon_sym_break] = ACTIONS(2509),
    [anon_sym_continue] = ACTIONS(2509),
    [anon_sym_debugger] = ACTIONS(2509),
    [anon_sym_return] = ACTIONS(2509),
    [anon_sym_throw] = ACTIONS(2509),
    [anon_sym_yield] = ACTIONS(2509),
    [anon_sym_LBRACK] = ACTIONS(2507),
    [anon_sym_class] = ACTIONS(2509),
    [anon_sym_async] = ACTIONS(2509),
    [anon_sym_function] = ACTIONS(2509),
    [anon_sym_new] = ACTIONS(2509),
    [anon_sym_using] = ACTIONS(2509),
    [anon_sym_PLUS] = ACTIONS(2509),
    [anon_sym_DASH] = ACTIONS(2509),
    [anon_sym_SLASH] = ACTIONS(2509),
    [anon_sym_LT] = ACTIONS(2507),
    [anon_sym_TILDE] = ACTIONS(2507),
    [anon_sym_void] = ACTIONS(2509),
    [anon_sym_delete] = ACTIONS(2509),
    [anon_sym_PLUS_PLUS] = ACTIONS(2507),
    [anon_sym_DASH_DASH] = ACTIONS(2507),
    [anon_sym_DQUOTE] = ACTIONS(2507),
    [anon_sym_SQUOTE] = ACTIONS(2507),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(2507),
    [sym_number] = ACTIONS(2507),
    [sym_private_property_identifier] = ACTIONS(2507),
    [sym_this] = ACTIONS(2509),
    [sym_super] = ACTIONS(2509),
    [sym_true] = ACTIONS(2509),
    [sym_false] = ACTIONS(2509),
    [sym_null] = ACTIONS(2509),
    [sym_undefined] = ACTIONS(2509),
    [anon_sym_AT] = ACTIONS(2507),
    [anon_sym_static] = ACTIONS(2509),
    [anon_sym_readonly] = ACTIONS(2509),
    [anon_sym_get] = ACTIONS(2509),
    [anon_sym_set] = ACTIONS(2509),
    [anon_sym_declare] = ACTIONS(2509),
    [anon_sym_public] = ACTIONS(2509),
    [anon_sym_private] = ACTIONS(2509),
    [anon_sym_protected] = ACTIONS(2509),
    [anon_sym_override] = ACTIONS(2509),
    [anon_sym_module] = ACTIONS(2509),
    [anon_sym_any] = ACTIONS(2509),
    [anon_sym_number] = ACTIONS(2509),
    [anon_sym_boolean] = ACTIONS(2509),
    [anon_sym_string] = ACTIONS(2509),
    [anon_sym_symbol] = ACTIONS(2509),
    [anon_sym_object] = ACTIONS(2509),
    [anon_sym_abstract] = ACTIONS(2509),
    [anon_sym_interface] = ACTIONS(2509),
    [anon_sym_enum] = ACTIONS(2509),
    [sym_html_comment] = ACTIONS(5),
  },
  [970] = {
    [sym_identifier] = ACTIONS(3129),
    [anon_sym_export] = ACTIONS(3129),
    [anon_sym_type] = ACTIONS(3129),
    [anon_sym_namespace] = ACTIONS(3129),
    [anon_sym_LBRACE] = ACTIONS(3131),
    [anon_sym_typeof] = ACTIONS(3129),
    [anon_sym_import] = ACTIONS(3129),
    [anon_sym_with] = ACTIONS(3129),
    [anon_sym_var] = ACTIONS(3129),
    [anon_sym_let] = ACTIONS(3129),
    [anon_sym_const] = ACTIONS(3129),
    [anon_sym_BANG] = ACTIONS(3131),
    [anon_sym_if] = ACTIONS(3129),
    [anon_sym_switch] = ACTIONS(3129),
    [anon_sym_for] = ACTIONS(3129),
    [anon_sym_LPAREN] = ACTIONS(3131),
    [anon_sym_SEMI] = ACTIONS(3131),
    [anon_sym_await] = ACTIONS(3129),
    [anon_sym_while] = ACTIONS(3129),
    [anon_sym_do] = ACTIONS(3129),
    [anon_sym_try] = ACTIONS(3129),
    [anon_sym_break] = ACTIONS(3129),
    [anon_sym_continue] = ACTIONS(3129),
    [anon_sym_debugger] = ACTIONS(3129),
    [anon_sym_return] = ACTIONS(3129),
    [anon_sym_throw] = ACTIONS(3129),
    [anon_sym_yield] = ACTIONS(3129),
    [anon_sym_LBRACK] = ACTIONS(3131),
    [anon_sym_class] = ACTIONS(3129),
    [anon_sym_async] = ACTIONS(3129),
    [anon_sym_function] = ACTIONS(3129),
    [anon_sym_new] = ACTIONS(3129),
    [anon_sym_using] = ACTIONS(3129),
    [anon_sym_PLUS] = ACTIONS(3129),
    [anon_sym_DASH] = ACTIONS(3129),
    [anon_sym_SLASH] = ACTIONS(3129),
    [anon_sym_LT] = ACTIONS(3131),
    [anon_sym_TILDE] = ACTIONS(3131),
    [anon_sym_void] = ACTIONS(3129),
    [anon_sym_delete] = ACTIONS(3129),
    [anon_sym_PLUS_PLUS] = ACTIONS(3131),
    [anon_sym_DASH_DASH] = ACTIONS(3131),
    [anon_sym_DQUOTE] = ACTIONS(3131),
    [anon_sym_SQUOTE] = ACTIONS(3131),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(3131),
    [sym_number] = ACTIONS(3131),
    [sym_private_property_identifier] = ACTIONS(3131),
    [sym_this] = ACTIONS(3129),
    [sym_super] = ACTIONS(3129),
    [sym_true] = ACTIONS(3129),
    [sym_false] = ACTIONS(3129),
    [sym_null] = ACTIONS(3129),
    [sym_undefined] = ACTIONS(3129),
    [anon_sym_AT] = ACTIONS(3131),
    [anon_sym_static] = ACTIONS(3129),
    [anon_sym_readonly] = ACTIONS(3129),
    [anon_sym_get] = ACTIONS(3129),
    [anon_sym_set] = ACTIONS(3129),
    [anon_sym_declare] = ACTIONS(3129),
    [anon_sym_public] = ACTIONS(3129),
    [anon_sym_private] = ACTIONS(3129),
    [anon_sym_protected] = ACTIONS(3129),
    [anon_sym_override] = ACTIONS(3129),
    [anon_sym_module] = ACTIONS(3129),
    [anon_sym_any] = ACTIONS(3129),
    [anon_sym_number] = ACTIONS(3129),
    [anon_sym_boolean] = ACTIONS(3129),
    [anon_sym_string] = ACTIONS(3129),
    [anon_sym_symbol] = ACTIONS(3129),
    [anon_sym_object] = ACTIONS(3129),
    [anon_sym_abstract] = ACTIONS(3129),
    [anon_sym_interface] = ACTIONS(3129),
    [anon_sym_enum] = ACTIONS(3129),
    [sym_html_comment] = ACTIONS(5),
  },
  [971] = {
    [sym_import] = STATE(4531),
    [sym_nested_identifier] = STATE(5486),
    [sym_string] = STATE(1632),
    [sym_formal_parameters] = STATE(5639),
    [sym_nested_type_identifier] = STATE(1527),
    [sym__type_query_member_expression_in_type_annotation] = STATE(1514),
    [sym__type_query_call_expression_in_type_annotation] = STATE(1574),
    [sym_asserts] = STATE(1560),
    [sym_type] = STATE(1561),
    [sym_constructor_type] = STATE(1544),
    [sym_primary_type] = STATE(1554),
    [sym_template_literal_type] = STATE(1556),
    [sym_infer_type] = STATE(1544),
    [sym_conditional_type] = STATE(1556),
    [sym_generic_type] = STATE(1556),
    [sym_type_predicate] = STATE(1560),
    [sym_type_query] = STATE(1556),
    [sym_index_type_query] = STATE(1556),
    [sym_lookup_type] = STATE(1556),
    [sym_literal_type] = STATE(1556),
    [sym__number] = STATE(1536),
    [sym_existential_type] = STATE(1556),
    [sym_flow_maybe_type] = STATE(1556),
    [sym_parenthesized_type] = STATE(1556),
    [sym_predefined_type] = STATE(1524),
    [sym_object_type] = STATE(1556),
    [sym_type_parameters] = STATE(5205),
    [sym_array_type] = STATE(1556),
    [sym_tuple_type] = STATE(1556),
    [sym_readonly_type] = STATE(1544),
    [sym_union_type] = STATE(1556),
    [sym_intersection_type] = STATE(1556),
    [sym_function_type] = STATE(1544),
    [sym_identifier] = ACTIONS(3145),
    [anon_sym_STAR] = ACTIONS(3147),
    [anon_sym_LBRACE] = ACTIONS(3149),
    [anon_sym_typeof] = ACTIONS(3151),
    [anon_sym_import] = ACTIONS(1538),
    [anon_sym_const] = ACTIONS(3153),
    [anon_sym_LPAREN] = ACTIONS(3155),
    [anon_sym_LBRACK] = ACTIONS(3157),
    [anon_sym_new] = ACTIONS(3159),
    [anon_sym_AMP] = ACTIONS(3161),
    [anon_sym_PIPE] = ACTIONS(3163),
    [anon_sym_PLUS] = ACTIONS(3165),
    [anon_sym_DASH] = ACTIONS(3165),
    [anon_sym_LT] = ACTIONS(2499),
    [anon_sym_void] = ACTIONS(3167),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(3169),
    [sym_number] = ACTIONS(3171),
    [sym_this] = ACTIONS(3173),
    [sym_true] = ACTIONS(3175),
    [sym_false] = ACTIONS(3175),
    [sym_null] = ACTIONS(3175),
    [sym_undefined] = ACTIONS(3175),
    [anon_sym_readonly] = ACTIONS(3177),
    [anon_sym_QMARK] = ACTIONS(3179),
    [anon_sym_any] = ACTIONS(3167),
    [anon_sym_number] = ACTIONS(3167),
    [anon_sym_boolean] = ACTIONS(3167),
    [anon_sym_string] = ACTIONS(3167),
    [anon_sym_symbol] = ACTIONS(3167),
    [anon_sym_object] = ACTIONS(3167),
    [anon_sym_abstract] = ACTIONS(3181),
    [anon_sym_asserts] = ACTIONS(3183),
    [anon_sym_infer] = ACTIONS(3185),
    [anon_sym_keyof] = ACTIONS(3187),
    [anon_sym_unique] = ACTIONS(3189),
    [anon_sym_unknown] = ACTIONS(3167),
    [anon_sym_never] = ACTIONS(3167),
    [anon_sym_LBRACE_PIPE] = ACTIONS(3191),
    [sym_html_comment] = ACTIONS(5),
  },
  [972] = {
    [sym_identifier] = ACTIONS(3193),
    [anon_sym_export] = ACTIONS(3193),
    [anon_sym_type] = ACTIONS(3193),
    [anon_sym_namespace] = ACTIONS(3193),
    [anon_sym_LBRACE] = ACTIONS(3195),
    [anon_sym_typeof] = ACTIONS(3193),
    [anon_sym_import] = ACTIONS(3193),
    [anon_sym_with] = ACTIONS(3193),
    [anon_sym_var] = ACTIONS(3193),
    [anon_sym_let] = ACTIONS(3193),
    [anon_sym_const] = ACTIONS(3193),
    [anon_sym_BANG] = ACTIONS(3195),
    [anon_sym_if] = ACTIONS(3193),
    [anon_sym_switch] = ACTIONS(3193),
    [anon_sym_for] = ACTIONS(3193),
    [anon_sym_LPAREN] = ACTIONS(3195),
    [anon_sym_SEMI] = ACTIONS(3195),
    [anon_sym_await] = ACTIONS(3193),
    [anon_sym_while] = ACTIONS(3193),
    [anon_sym_do] = ACTIONS(3193),
    [anon_sym_try] = ACTIONS(3193),
    [anon_sym_break] = ACTIONS(3193),
    [anon_sym_continue] = ACTIONS(3193),
    [anon_sym_debugger] = ACTIONS(3193),
    [anon_sym_return] = ACTIONS(3193),
    [anon_sym_throw] = ACTIONS(3193),
    [anon_sym_yield] = ACTIONS(3193),
    [anon_sym_LBRACK] = ACTIONS(3195),
    [anon_sym_class] = ACTIONS(3193),
    [anon_sym_async] = ACTIONS(3193),
    [anon_sym_function] = ACTIONS(3193),
    [anon_sym_new] = ACTIONS(3193),
    [anon_sym_using] = ACTIONS(3193),
    [anon_sym_PLUS] = ACTIONS(3193),
    [anon_sym_DASH] = ACTIONS(3193),
    [anon_sym_SLASH] = ACTIONS(3193),
    [anon_sym_LT] = ACTIONS(3195),
    [anon_sym_TILDE] = ACTIONS(3195),
    [anon_sym_void] = ACTIONS(3193),
    [anon_sym_delete] = ACTIONS(3193),
    [anon_sym_PLUS_PLUS] = ACTIONS(3195),
    [anon_sym_DASH_DASH] = ACTIONS(3195),
    [anon_sym_DQUOTE] = ACTIONS(3195),
    [anon_sym_SQUOTE] = ACTIONS(3195),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(3195),
    [sym_number] = ACTIONS(3195),
    [sym_private_property_identifier] = ACTIONS(3195),
    [sym_this] = ACTIONS(3193),
    [sym_super] = ACTIONS(3193),
    [sym_true] = ACTIONS(3193),
    [sym_false] = ACTIONS(3193),
    [sym_null] = ACTIONS(3193),
    [sym_undefined] = ACTIONS(3193),
    [anon_sym_AT] = ACTIONS(3195),
    [anon_sym_static] = ACTIONS(3193),
    [anon_sym_readonly] = ACTIONS(3193),
    [anon_sym_get] = ACTIONS(3193),
    [anon_sym_set] = ACTIONS(3193),
    [anon_sym_declare] = ACTIONS(3193),
    [anon_sym_public] = ACTIONS(3193),
    [anon_sym_private] = ACTIONS(3193),
    [anon_sym_protected] = ACTIONS(3193),
    [anon_sym_override] = ACTIONS(3193),
    [anon_sym_module] = ACTIONS(3193),
    [anon_sym_any] = ACTIONS(3193),
    [anon_sym_number] = ACTIONS(3193),
    [anon_sym_boolean] = ACTIONS(3193),
    [anon_sym_string] = ACTIONS(3193),
    [anon_sym_symbol] = ACTIONS(3193),
    [anon_sym_object] = ACTIONS(3193),
    [anon_sym_abstract] = ACTIONS(3193),
    [anon_sym_interface] = ACTIONS(3193),
    [anon_sym_enum] = ACTIONS(3193),
    [sym_html_comment] = ACTIONS(5),
  },
  [973] = {
    [sym_import] = STATE(4878),
    [sym_nested_identifier] = STATE(5474),
    [sym_string] = STATE(2994),
    [sym_formal_parameters] = STATE(5475),
    [sym_nested_type_identifier] = STATE(2939),
    [sym__type_query_member_expression_in_type_annotation] = STATE(2937),
    [sym__type_query_call_expression_in_type_annotation] = STATE(2938),
    [sym_asserts] = STATE(3018),
    [sym_type] = STATE(3146),
    [sym_constructor_type] = STATE(3007),
    [sym_primary_type] = STATE(2981),
    [sym_template_literal_type] = STATE(3039),
    [sym_infer_type] = STATE(3007),
    [sym_conditional_type] = STATE(3039),
    [sym_generic_type] = STATE(3039),
    [sym_type_predicate] = STATE(3018),
    [sym_type_query] = STATE(3039),
    [sym_index_type_query] = STATE(3039),
    [sym_lookup_type] = STATE(3039),
    [sym_literal_type] = STATE(3039),
    [sym__number] = STATE(3041),
    [sym_existential_type] = STATE(3039),
    [sym_flow_maybe_type] = STATE(3039),
    [sym_parenthesized_type] = STATE(3039),
    [sym_predefined_type] = STATE(3056),
    [sym_object_type] = STATE(3039),
    [sym_type_parameters] = STATE(5248),
    [sym_array_type] = STATE(3039),
    [sym_tuple_type] = STATE(3039),
    [sym_readonly_type] = STATE(3007),
    [sym_union_type] = STATE(3039),
    [sym_intersection_type] = STATE(3039),
    [sym_function_type] = STATE(3007),
    [sym_identifier] = ACTIONS(3133),
    [anon_sym_STAR] = ACTIONS(543),
    [anon_sym_LBRACE] = ACTIONS(1534),
    [anon_sym_typeof] = ACTIONS(1536),
    [anon_sym_import] = ACTIONS(1538),
    [anon_sym_const] = ACTIONS(133),
    [anon_sym_LPAREN] = ACTIONS(1540),
    [anon_sym_LBRACK] = ACTIONS(1542),
    [anon_sym_new] = ACTIONS(1544),
    [anon_sym_AMP] = ACTIONS(748),
    [anon_sym_PIPE] = ACTIONS(750),
    [anon_sym_PLUS] = ACTIONS(2497),
    [anon_sym_DASH] = ACTIONS(2497),
    [anon_sym_LT] = ACTIONS(2499),
    [anon_sym_void] = ACTIONS(216),
    [anon_sym_DQUOTE] = ACTIONS(1550),
    [anon_sym_SQUOTE] = ACTIONS(1552),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1554),
    [sym_number] = ACTIONS(1556),
    [sym_this] = ACTIONS(3135),
    [sym_true] = ACTIONS(1560),
    [sym_false] = ACTIONS(1560),
    [sym_null] = ACTIONS(1560),
    [sym_undefined] = ACTIONS(1560),
    [anon_sym_readonly] = ACTIONS(1562),
    [anon_sym_QMARK] = ACTIONS(774),
    [anon_sym_any] = ACTIONS(216),
    [anon_sym_number] = ACTIONS(216),
    [anon_sym_boolean] = ACTIONS(216),
    [anon_sym_string] = ACTIONS(216),
    [anon_sym_symbol] = ACTIONS(216),
    [anon_sym_object] = ACTIONS(216),
    [anon_sym_abstract] = ACTIONS(208),
    [anon_sym_asserts] = ACTIONS(3137),
    [anon_sym_infer] = ACTIONS(210),
    [anon_sym_keyof] = ACTIONS(212),
    [anon_sym_unique] = ACTIONS(214),
    [anon_sym_unknown] = ACTIONS(216),
    [anon_sym_never] = ACTIONS(216),
    [anon_sym_LBRACE_PIPE] = ACTIONS(218),
    [sym_html_comment] = ACTIONS(5),
  },
  [974] = {
    [sym_import] = STATE(4808),
    [sym_nested_identifier] = STATE(5474),
    [sym_string] = STATE(2994),
    [sym_formal_parameters] = STATE(5569),
    [sym_nested_type_identifier] = STATE(3487),
    [sym__type_query_member_expression_in_type_annotation] = STATE(3388),
    [sym__type_query_call_expression_in_type_annotation] = STATE(2938),
    [sym_asserts] = STATE(3023),
    [sym_type] = STATE(3857),
    [sym_constructor_type] = STATE(3007),
    [sym_primary_type] = STATE(2981),
    [sym_template_literal_type] = STATE(3039),
    [sym_infer_type] = STATE(3007),
    [sym_conditional_type] = STATE(3039),
    [sym_generic_type] = STATE(3039),
    [sym_type_predicate] = STATE(3023),
    [sym_type_query] = STATE(3039),
    [sym_index_type_query] = STATE(3039),
    [sym_lookup_type] = STATE(3039),
    [sym_literal_type] = STATE(3039),
    [sym__number] = STATE(3041),
    [sym_existential_type] = STATE(3039),
    [sym_flow_maybe_type] = STATE(3039),
    [sym_parenthesized_type] = STATE(3039),
    [sym_predefined_type] = STATE(3697),
    [sym_object_type] = STATE(3039),
    [sym_type_parameters] = STATE(5361),
    [sym_array_type] = STATE(3039),
    [sym_tuple_type] = STATE(3039),
    [sym_readonly_type] = STATE(3007),
    [sym_union_type] = STATE(3039),
    [sym_intersection_type] = STATE(3039),
    [sym_function_type] = STATE(3007),
    [sym_identifier] = ACTIONS(3097),
    [anon_sym_STAR] = ACTIONS(543),
    [anon_sym_LBRACE] = ACTIONS(3099),
    [anon_sym_typeof] = ACTIONS(3101),
    [anon_sym_import] = ACTIONS(1538),
    [anon_sym_const] = ACTIONS(133),
    [anon_sym_LPAREN] = ACTIONS(1540),
    [anon_sym_LBRACK] = ACTIONS(1542),
    [anon_sym_new] = ACTIONS(3103),
    [anon_sym_AMP] = ACTIONS(3105),
    [anon_sym_PIPE] = ACTIONS(3107),
    [anon_sym_PLUS] = ACTIONS(2497),
    [anon_sym_DASH] = ACTIONS(2497),
    [anon_sym_LT] = ACTIONS(2499),
    [anon_sym_void] = ACTIONS(216),
    [anon_sym_DQUOTE] = ACTIONS(3109),
    [anon_sym_SQUOTE] = ACTIONS(3111),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1554),
    [sym_number] = ACTIONS(1556),
    [sym_this] = ACTIONS(3113),
    [sym_true] = ACTIONS(1560),
    [sym_false] = ACTIONS(1560),
    [sym_null] = ACTIONS(1560),
    [sym_undefined] = ACTIONS(1560),
    [anon_sym_readonly] = ACTIONS(3115),
    [anon_sym_QMARK] = ACTIONS(3117),
    [anon_sym_any] = ACTIONS(216),
    [anon_sym_number] = ACTIONS(216),
    [anon_sym_boolean] = ACTIONS(216),
    [anon_sym_string] = ACTIONS(216),
    [anon_sym_symbol] = ACTIONS(216),
    [anon_sym_object] = ACTIONS(216),
    [anon_sym_abstract] = ACTIONS(3119),
    [anon_sym_asserts] = ACTIONS(3121),
    [anon_sym_infer] = ACTIONS(3123),
    [anon_sym_keyof] = ACTIONS(3125),
    [anon_sym_unique] = ACTIONS(214),
    [anon_sym_unknown] = ACTIONS(216),
    [anon_sym_never] = ACTIONS(216),
    [anon_sym_LBRACE_PIPE] = ACTIONS(3127),
    [sym_html_comment] = ACTIONS(5),
  },
  [975] = {
    [sym_identifier] = ACTIONS(3197),
    [anon_sym_export] = ACTIONS(3197),
    [anon_sym_type] = ACTIONS(3197),
    [anon_sym_namespace] = ACTIONS(3197),
    [anon_sym_LBRACE] = ACTIONS(3199),
    [anon_sym_typeof] = ACTIONS(3197),
    [anon_sym_import] = ACTIONS(3197),
    [anon_sym_with] = ACTIONS(3197),
    [anon_sym_var] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_const] = ACTIONS(3197),
    [anon_sym_BANG] = ACTIONS(3199),
    [anon_sym_if] = ACTIONS(3197),
    [anon_sym_switch] = ACTIONS(3197),
    [anon_sym_for] = ACTIONS(3197),
    [anon_sym_LPAREN] = ACTIONS(3199),
    [anon_sym_SEMI] = ACTIONS(3199),
    [anon_sym_await] = ACTIONS(3197),
    [anon_sym_while] = ACTIONS(3197),
    [anon_sym_do] = ACTIONS(3197),
    [anon_sym_try] = ACTIONS(3197),
    [anon_sym_break] = ACTIONS(3197),
    [anon_sym_continue] = ACTIONS(3197),
    [anon_sym_debugger] = ACTIONS(3197),
    [anon_sym_return] = ACTIONS(3197),
    [anon_sym_throw] = ACTIONS(3197),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_LBRACK] = ACTIONS(3199),
    [anon_sym_class] = ACTIONS(3197),
    [anon_sym_async] = ACTIONS(3197),
    [anon_sym_function] = ACTIONS(3197),
    [anon_sym_new] = ACTIONS(3197),
    [anon_sym_using] = ACTIONS(3197),
    [anon_sym_PLUS] = ACTIONS(3197),
    [anon_sym_DASH] = ACTIONS(3197),
    [anon_sym_SLASH] = ACTIONS(3197),
    [anon_sym_LT] = ACTIONS(3199),
    [anon_sym_TILDE] = ACTIONS(3199),
    [anon_sym_void] = ACTIONS(3197),
    [anon_sym_delete] = ACTIONS(3197),
    [anon_sym_PLUS_PLUS] = ACTIONS(3199),
    [anon_sym_DASH_DASH] = ACTIONS(3199),
    [anon_sym_DQUOTE] = ACTIONS(3199),
    [anon_sym_SQUOTE] = ACTIONS(3199),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(3199),
    [sym_number] = ACTIONS(3199),
    [sym_private_property_identifier] = ACTIONS(3199),
    [sym_this] = ACTIONS(3197),
    [sym_super] = ACTIONS(3197),
    [sym_true] = ACTIONS(3197),
    [sym_false] = ACTIONS(3197),
    [sym_null] = ACTIONS(3197),
    [sym_undefined] = ACTIONS(3197),
    [anon_sym_AT] = ACTIONS(3199),
    [anon_sym_static] = ACTIONS(3197),
    [anon_sym_readonly] = ACTIONS(3197),
    [anon_sym_get] = ACTIONS(3197),
    [anon_sym_set] = ACTIONS(3197),
    [anon_sym_declare] = ACTIONS(3197),
    [anon_sym_public] = ACTIONS(3197),
    [anon_sym_private] = ACTIONS(3197),
    [anon_sym_protected] = ACTIONS(3197),
    [anon_sym_override] = ACTIONS(3197),
    [anon_sym_module] = ACTIONS(3197),
    [anon_sym_any] = ACTIONS(3197),
    [anon_sym_number] = ACTIONS(3197),
    [anon_sym_boolean] = ACTIONS(3197),
    [anon_sym_string] = ACTIONS(3197),
    [anon_sym_symbol] = ACTIONS(3197),
    [anon_sym_object] = ACTIONS(3197),
    [anon_sym_abstract] = ACTIONS(3197),
    [anon_sym_interface] = ACTIONS(3197),
    [anon_sym_enum] = ACTIONS(3197),
    [sym_html_comment] = ACTIONS(5),
  },
  [976] = {
    [sym_import] = STATE(4578),
    [sym_nested_identifier] = STATE(5796),
    [sym_string] = STATE(3437),
    [sym_formal_parameters] = STATE(5519),
    [sym_nested_type_identifier] = STATE(3278),
    [sym__type_query_member_expression_in_type_annotation] = STATE(3181),
    [sym__type_query_call_expression_in_type_annotation] = STATE(3311),
    [sym_asserts] = STATE(3355),
    [sym_type] = STATE(3356),
    [sym_constructor_type] = STATE(3448),
    [sym_primary_type] = STATE(3450),
    [sym_template_literal_type] = STATE(3453),
    [sym_infer_type] = STATE(3448),
    [sym_conditional_type] = STATE(3453),
    [sym_generic_type] = STATE(3453),
    [sym_type_predicate] = STATE(3355),
    [sym_type_query] = STATE(3453),
    [sym_index_type_query] = STATE(3453),
    [sym_lookup_type] = STATE(3453),
    [sym_literal_type] = STATE(3453),
    [sym__number] = STATE(3454),
    [sym_existential_type] = STATE(3453),
    [sym_flow_maybe_type] = STATE(3453),
    [sym_parenthesized_type] = STATE(3453),
    [sym_predefined_type] = STATE(3305),
    [sym_object_type] = STATE(3453),
    [sym_type_parameters] = STATE(5251),
    [sym_array_type] = STATE(3453),
    [sym_tuple_type] = STATE(3453),
    [sym_readonly_type] = STATE(3448),
    [sym_union_type] = STATE(3453),
    [sym_intersection_type] = STATE(3453),
    [sym_function_type] = STATE(3448),
    [sym_identifier] = ACTIONS(2993),
    [anon_sym_STAR] = ACTIONS(2995),
    [anon_sym_LBRACE] = ACTIONS(2997),
    [anon_sym_typeof] = ACTIONS(2999),
    [anon_sym_import] = ACTIONS(1538),
    [anon_sym_const] = ACTIONS(3001),
    [anon_sym_LPAREN] = ACTIONS(3003),
    [anon_sym_LBRACK] = ACTIONS(3005),
    [anon_sym_new] = ACTIONS(3007),
    [anon_sym_AMP] = ACTIONS(3009),
    [anon_sym_PIPE] = ACTIONS(3011),
    [anon_sym_PLUS] = ACTIONS(3013),
    [anon_sym_DASH] = ACTIONS(3013),
    [anon_sym_LT] = ACTIONS(2499),
    [anon_sym_void] = ACTIONS(3015),
    [anon_sym_DQUOTE] = ACTIONS(3017),
    [anon_sym_SQUOTE] = ACTIONS(3019),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(3021),
    [sym_number] = ACTIONS(3023),
    [sym_this] = ACTIONS(3025),
    [sym_true] = ACTIONS(3027),
    [sym_false] = ACTIONS(3027),
    [sym_null] = ACTIONS(3027),
    [sym_undefined] = ACTIONS(3027),
    [anon_sym_readonly] = ACTIONS(3029),
    [anon_sym_QMARK] = ACTIONS(3031),
    [anon_sym_any] = ACTIONS(3015),
    [anon_sym_number] = ACTIONS(3015),
    [anon_sym_boolean] = ACTIONS(3015),
    [anon_sym_string] = ACTIONS(3015),
    [anon_sym_symbol] = ACTIONS(3015),
    [anon_sym_object] = ACTIONS(3015),
    [anon_sym_abstract] = ACTIONS(3033),
    [anon_sym_asserts] = ACTIONS(3035),
    [anon_sym_infer] = ACTIONS(3037),
    [anon_sym_keyof] = ACTIONS(3039),
    [anon_sym_unique] = ACTIONS(3041),
    [anon_sym_unknown] = ACTIONS(3015),
    [anon_sym_never] = ACTIONS(3015),
    [anon_sym_LBRACE_PIPE] = ACTIONS(3043),
    [sym_html_comment] = ACTIONS(5),
  },
  [977] = {
    [sym_import] = STATE(4878),
    [sym_nested_identifier] = STATE(5474),
    [sym_string] = STATE(2994),
    [sym_formal_parameters] = STATE(5475),
    [sym_nested_type_identifier] = STATE(2939),
    [sym__type_query_member_expression_in_type_annotation] = STATE(2937),
    [sym__type_query_call_expression_in_type_annotation] = STATE(2938),
    [sym_type] = STATE(3758),
    [sym_constructor_type] = STATE(3007),
    [sym_primary_type] = STATE(2981),
    [sym_template_literal_type] = STATE(3039),
    [sym_infer_type] = STATE(3007),
    [sym_conditional_type] = STATE(3039),
    [sym_generic_type] = STATE(3039),
    [sym_type_query] = STATE(3039),
    [sym_index_type_query] = STATE(3039),
    [sym_lookup_type] = STATE(3039),
    [sym_literal_type] = STATE(3039),
    [sym__number] = STATE(3041),
    [sym_existential_type] = STATE(3039),
    [sym_flow_maybe_type] = STATE(3039),
    [sym_parenthesized_type] = STATE(3039),
    [sym_predefined_type] = STATE(3039),
    [sym_object_type] = STATE(3039),
    [sym_type_parameters] = STATE(5248),
    [sym_array_type] = STATE(3039),
    [sym_tuple_type] = STATE(3039),
    [sym_readonly_type] = STATE(3007),
    [sym_union_type] = STATE(3039),
    [sym_intersection_type] = STATE(3039),
    [sym_function_type] = STATE(3007),
    [sym_identifier] = ACTIONS(1532),
    [anon_sym_STAR] = ACTIONS(543),
    [anon_sym_LBRACE] = ACTIONS(1534),
    [anon_sym_typeof] = ACTIONS(1536),
    [anon_sym_import] = ACTIONS(1538),
    [anon_sym_const] = ACTIONS(133),
    [anon_sym_LPAREN] = ACTIONS(1540),
    [anon_sym_LBRACK] = ACTIONS(1542),
    [anon_sym_new] = ACTIONS(1544),
    [anon_sym_AMP] = ACTIONS(748),
    [anon_sym_PIPE] = ACTIONS(750),
    [anon_sym_PLUS] = ACTIONS(2497),
    [anon_sym_DASH] = ACTIONS(2497),
    [anon_sym_LT] = ACTIONS(2499),
    [anon_sym_GT] = ACTIONS(3201),
    [anon_sym_void] = ACTIONS(216),
    [anon_sym_DQUOTE] = ACTIONS(1550),
    [anon_sym_SQUOTE] = ACTIONS(1552),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1554),
    [sym_number] = ACTIONS(1556),
    [sym_this] = ACTIONS(1558),
    [sym_true] = ACTIONS(1560),
    [sym_false] = ACTIONS(1560),
    [sym_null] = ACTIONS(1560),
    [sym_undefined] = ACTIONS(1560),
    [anon_sym_readonly] = ACTIONS(1562),
    [anon_sym_QMARK] = ACTIONS(774),
    [anon_sym_any] = ACTIONS(216),
    [anon_sym_number] = ACTIONS(216),
    [anon_sym_boolean] = ACTIONS(216),
    [anon_sym_string] = ACTIONS(216),
    [anon_sym_symbol] = ACTIONS(216),
    [anon_sym_object] = ACTIONS(216),
    [anon_sym_abstract] = ACTIONS(208),
    [anon_sym_infer] = ACTIONS(210),
    [anon_sym_keyof] = ACTIONS(212),
    [anon_sym_unique] = ACTIONS(214),
    [anon_sym_unknown] = ACTIONS(216),
    [anon_sym_never] = ACTIONS(216),
    [anon_sym_LBRACE_PIPE] = ACTIONS(218),
    [sym_html_comment] = ACTIONS(5),
  },
  [978] = {
    [sym_import] = STATE(4878),
    [sym_nested_identifier] = STATE(5474),
    [sym_string] = STATE(2994),
    [sym_formal_parameters] = STATE(5475),
    [sym_nested_type_identifier] = STATE(2939),
    [sym__type_query_member_expression_in_type_annotation] = STATE(2937),
    [sym__type_query_call_expression_in_type_annotation] = STATE(2938),
    [sym_type] = STATE(3758),
    [sym_constructor_type] = STATE(3007),
    [sym_primary_type] = STATE(2981),
    [sym_template_literal_type] = STATE(3039),
    [sym_infer_type] = STATE(3007),
    [sym_conditional_type] = STATE(3039),
    [sym_generic_type] = STATE(3039),
    [sym_type_query] = STATE(3039),
    [sym_index_type_query] = STATE(3039),
    [sym_lookup_type] = STATE(3039),
    [sym_literal_type] = STATE(3039),
    [sym__number] = STATE(3041),
    [sym_existential_type] = STATE(3039),
    [sym_flow_maybe_type] = STATE(3039),
    [sym_parenthesized_type] = STATE(3039),
    [sym_predefined_type] = STATE(3039),
    [sym_object_type] = STATE(3039),
    [sym_type_parameters] = STATE(5248),
    [sym_array_type] = STATE(3039),
    [sym_tuple_type] = STATE(3039),
    [sym_readonly_type] = STATE(3007),
    [sym_union_type] = STATE(3039),
    [sym_intersection_type] = STATE(3039),
    [sym_function_type] = STATE(3007),
    [sym_identifier] = ACTIONS(1532),
    [anon_sym_STAR] = ACTIONS(543),
    [anon_sym_LBRACE] = ACTIONS(1534),
    [anon_sym_typeof] = ACTIONS(1536),
    [anon_sym_import] = ACTIONS(1538),
    [anon_sym_const] = ACTIONS(133),
    [anon_sym_LPAREN] = ACTIONS(1540),
    [anon_sym_LBRACK] = ACTIONS(1542),
    [anon_sym_new] = ACTIONS(1544),
    [anon_sym_AMP] = ACTIONS(748),
    [anon_sym_PIPE] = ACTIONS(750),
    [anon_sym_PLUS] = ACTIONS(2497),
    [anon_sym_DASH] = ACTIONS(2497),
    [anon_sym_LT] = ACTIONS(2499),
    [anon_sym_GT] = ACTIONS(3203),
    [anon_sym_void] = ACTIONS(216),
    [anon_sym_DQUOTE] = ACTIONS(1550),
    [anon_sym_SQUOTE] = ACTIONS(1552),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1554),
    [sym_number] = ACTIONS(1556),
    [sym_this] = ACTIONS(1558),
    [sym_true] = ACTIONS(1560),
    [sym_false] = ACTIONS(1560),
    [sym_null] = ACTIONS(1560),
    [sym_undefined] = ACTIONS(1560),
    [anon_sym_readonly] = ACTIONS(1562),
    [anon_sym_QMARK] = ACTIONS(774),
    [anon_sym_any] = ACTIONS(216),
    [anon_sym_number] = ACTIONS(216),
    [anon_sym_boolean] = ACTIONS(216),
    [anon_sym_string] = ACTIONS(216),
    [anon_sym_symbol] = ACTIONS(216),
    [anon_sym_object] = ACTIONS(216),
    [anon_sym_abstract] = ACTIONS(208),
    [anon_sym_infer] = ACTIONS(210),
    [anon_sym_keyof] = ACTIONS(212),
    [anon_sym_unique] = ACTIONS(214),
    [anon_sym_unknown] = ACTIONS(216),
    [anon_sym_never] = ACTIONS(216),
    [anon_sym_LBRACE_PIPE] = ACTIONS(218),
    [sym_html_comment] = ACTIONS(5),
  },
  [979] = {
    [sym_import] = STATE(4878),
    [sym_nested_identifier] = STATE(5474),
    [sym_string] = STATE(2994),
    [sym_formal_parameters] = STATE(5475),
    [sym_nested_type_identifier] = STATE(2939),
    [sym__type_query_member_expression_in_type_annotation] = STATE(2937),
    [sym__type_query_call_expression_in_type_annotation] = STATE(2938),
    [sym_type] = STATE(4432),
    [sym_constructor_type] = STATE(3007),
    [sym_primary_type] = STATE(2981),
    [sym_template_literal_type] = STATE(3039),
    [sym_infer_type] = STATE(3007),
    [sym_conditional_type] = STATE(3039),
    [sym_generic_type] = STATE(3039),
    [sym_type_query] = STATE(3039),
    [sym_index_type_query] = STATE(3039),
    [sym_lookup_type] = STATE(3039),
    [sym_literal_type] = STATE(3039),
    [sym__number] = STATE(3041),
    [sym_existential_type] = STATE(3039),
    [sym_flow_maybe_type] = STATE(3039),
    [sym_parenthesized_type] = STATE(3039),
    [sym_predefined_type] = STATE(3039),
    [sym_object_type] = STATE(3039),
    [sym_type_parameters] = STATE(5248),
    [sym_array_type] = STATE(3039),
    [sym_tuple_type] = STATE(3039),
    [sym_readonly_type] = STATE(3007),
    [sym_union_type] = STATE(3039),
    [sym_intersection_type] = STATE(3039),
    [sym_function_type] = STATE(3007),
    [sym_identifier] = ACTIONS(1532),
    [anon_sym_STAR] = ACTIONS(543),
    [anon_sym_LBRACE] = ACTIONS(1534),
    [anon_sym_typeof] = ACTIONS(1536),
    [anon_sym_import] = ACTIONS(1538),
    [anon_sym_const] = ACTIONS(133),
    [anon_sym_LPAREN] = ACTIONS(1540),
    [anon_sym_LBRACK] = ACTIONS(1542),
    [anon_sym_RBRACK] = ACTIONS(3205),
    [anon_sym_new] = ACTIONS(1544),
    [anon_sym_AMP] = ACTIONS(748),
    [anon_sym_PIPE] = ACTIONS(750),
    [anon_sym_PLUS] = ACTIONS(2497),
    [anon_sym_DASH] = ACTIONS(2497),
    [anon_sym_LT] = ACTIONS(2499),
    [anon_sym_void] = ACTIONS(216),
    [anon_sym_DQUOTE] = ACTIONS(1550),
    [anon_sym_SQUOTE] = ACTIONS(1552),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1554),
    [sym_number] = ACTIONS(1556),
    [sym_this] = ACTIONS(1558),
    [sym_true] = ACTIONS(1560),
    [sym_false] = ACTIONS(1560),
    [sym_null] = ACTIONS(1560),
    [sym_undefined] = ACTIONS(1560),
    [anon_sym_readonly] = ACTIONS(1562),
    [anon_sym_QMARK] = ACTIONS(774),
    [anon_sym_any] = ACTIONS(216),
    [anon_sym_number] = ACTIONS(216),
    [anon_sym_boolean] = ACTIONS(216),
    [anon_sym_string] = ACTIONS(216),
    [anon_sym_symbol] = ACTIONS(216),
    [anon_sym_object] = ACTIONS(216),
    [anon_sym_abstract] = ACTIONS(208),
    [anon_sym_infer] = ACTIONS(210),
    [anon_sym_keyof] = ACTIONS(212),
    [anon_sym_unique] = ACTIONS(214),
    [anon_sym_unknown] = ACTIONS(216),
    [anon_sym_never] = ACTIONS(216),
    [anon_sym_LBRACE_PIPE] = ACTIONS(218),
    [sym_html_comment] = ACTIONS(5),
  },
  [980] = {
    [sym_import] = STATE(4878),
    [sym_nested_identifier] = STATE(5474),
    [sym_string] = STATE(2994),
    [sym_formal_parameters] = STATE(5475),
    [sym_nested_type_identifier] = STATE(2939),
    [sym__type_query_member_expression_in_type_annotation] = STATE(2937),
    [sym__type_query_call_expression_in_type_annotation] = STATE(2938),
    [sym_type] = STATE(3758),
    [sym_constructor_type] = STATE(3007),
    [sym_primary_type] = STATE(2981),
    [sym_template_literal_type] = STATE(3039),
    [sym_infer_type] = STATE(3007),
    [sym_conditional_type] = STATE(3039),
    [sym_generic_type] = STATE(3039),
    [sym_type_query] = STATE(3039),
    [sym_index_type_query] = STATE(3039),
    [sym_lookup_type] = STATE(3039),
    [sym_literal_type] = STATE(3039),
    [sym__number] = STATE(3041),
    [sym_existential_type] = STATE(3039),
    [sym_flow_maybe_type] = STATE(3039),
    [sym_parenthesized_type] = STATE(3039),
    [sym_predefined_type] = STATE(3039),
    [sym_object_type] = STATE(3039),
    [sym_type_parameters] = STATE(5248),
    [sym_array_type] = STATE(3039),
    [sym_tuple_type] = STATE(3039),
    [sym_readonly_type] = STATE(3007),
    [sym_union_type] = STATE(3039),
    [sym_intersection_type] = STATE(3039),
    [sym_function_type] = STATE(3007),
    [sym_identifier] = ACTIONS(1532),
    [anon_sym_STAR] = ACTIONS(543),
    [anon_sym_LBRACE] = ACTIONS(1534),
    [anon_sym_typeof] = ACTIONS(1536),
    [anon_sym_import] = ACTIONS(1538),
    [anon_sym_const] = ACTIONS(133),
    [anon_sym_LPAREN] = ACTIONS(1540),
    [anon_sym_LBRACK] = ACTIONS(1542),
    [anon_sym_new] = ACTIONS(1544),
    [anon_sym_AMP] = ACTIONS(748),
    [anon_sym_PIPE] = ACTIONS(750),
    [anon_sym_PLUS] = ACTIONS(2497),
    [anon_sym_DASH] = ACTIONS(2497),
    [anon_sym_LT] = ACTIONS(2499),
    [anon_sym_GT] = ACTIONS(3207),
    [anon_sym_void] = ACTIONS(216),
    [anon_sym_DQUOTE] = ACTIONS(1550),
    [anon_sym_SQUOTE] = ACTIONS(1552),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1554),
    [sym_number] = ACTIONS(1556),
    [sym_this] = ACTIONS(1558),
    [sym_true] = ACTIONS(1560),
    [sym_false] = ACTIONS(1560),
    [sym_null] = ACTIONS(1560),
    [sym_undefined] = ACTIONS(1560),
    [anon_sym_readonly] = ACTIONS(1562),
    [anon_sym_QMARK] = ACTIONS(774),
    [anon_sym_any] = ACTIONS(216),
    [anon_sym_number] = ACTIONS(216),
    [anon_sym_boolean] = ACTIONS(216),
    [anon_sym_string] = ACTIONS(216),
    [anon_sym_symbol] = ACTIONS(216),
    [anon_sym_object] = ACTIONS(216),
    [anon_sym_abstract] = ACTIONS(208),
    [anon_sym_infer] = ACTIONS(210),
    [anon_sym_keyof] = ACTIONS(212),
    [anon_sym_unique] = ACTIONS(214),
    [anon_sym_unknown] = ACTIONS(216),
    [anon_sym_never] = ACTIONS(216),
    [anon_sym_LBRACE_PIPE] = ACTIONS(218),
    [sym_html_comment] = ACTIONS(5),
  },
  [981] = {
    [sym_import] = STATE(4878),
    [sym_nested_identifier] = STATE(5474),
    [sym_string] = STATE(2994),
    [sym_formal_parameters] = STATE(5475),
    [sym_nested_type_identifier] = STATE(2939),
    [sym__type_query_member_expression_in_type_annotation] = STATE(2937),
    [sym__type_query_call_expression_in_type_annotation] = STATE(2938),
    [sym_type] = STATE(3775),
    [sym_constructor_type] = STATE(3007),
    [sym_primary_type] = STATE(2981),
    [sym_template_literal_type] = STATE(3039),
    [sym_infer_type] = STATE(3007),
    [sym_conditional_type] = STATE(3039),
    [sym_generic_type] = STATE(3039),
    [sym_type_query] = STATE(3039),
    [sym_index_type_query] = STATE(3039),
    [sym_lookup_type] = STATE(3039),
    [sym_literal_type] = STATE(3039),
    [sym__number] = STATE(3041),
    [sym_existential_type] = STATE(3039),
    [sym_flow_maybe_type] = STATE(3039),
    [sym_parenthesized_type] = STATE(3039),
    [sym_predefined_type] = STATE(3039),
    [sym_object_type] = STATE(3039),
    [sym_type_parameters] = STATE(5248),
    [sym_type_parameter] = STATE(4908),
    [sym_array_type] = STATE(3039),
    [sym_tuple_type] = STATE(3039),
    [sym_readonly_type] = STATE(3007),
    [sym_union_type] = STATE(3039),
    [sym_intersection_type] = STATE(3039),
    [sym_function_type] = STATE(3007),
    [sym_identifier] = ACTIONS(3209),
    [anon_sym_STAR] = ACTIONS(543),
    [anon_sym_LBRACE] = ACTIONS(1534),
    [anon_sym_typeof] = ACTIONS(1536),
    [anon_sym_import] = ACTIONS(1538),
    [anon_sym_const] = ACTIONS(3211),
    [anon_sym_LPAREN] = ACTIONS(1540),
    [anon_sym_LBRACK] = ACTIONS(1542),
    [anon_sym_new] = ACTIONS(1544),
    [anon_sym_AMP] = ACTIONS(748),
    [anon_sym_PIPE] = ACTIONS(750),
    [anon_sym_PLUS] = ACTIONS(2497),
    [anon_sym_DASH] = ACTIONS(2497),
    [anon_sym_LT] = ACTIONS(2499),
    [anon_sym_void] = ACTIONS(216),
    [anon_sym_DQUOTE] = ACTIONS(1550),
    [anon_sym_SQUOTE] = ACTIONS(1552),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1554),
    [sym_number] = ACTIONS(1556),
    [sym_this] = ACTIONS(1558),
    [sym_true] = ACTIONS(1560),
    [sym_false] = ACTIONS(1560),
    [sym_null] = ACTIONS(1560),
    [sym_undefined] = ACTIONS(1560),
    [anon_sym_readonly] = ACTIONS(1562),
    [anon_sym_QMARK] = ACTIONS(774),
    [anon_sym_any] = ACTIONS(216),
    [anon_sym_number] = ACTIONS(216),
    [anon_sym_boolean] = ACTIONS(216),
    [anon_sym_string] = ACTIONS(216),
    [anon_sym_symbol] = ACTIONS(216),
    [anon_sym_object] = ACTIONS(216),
    [anon_sym_abstract] = ACTIONS(208),
    [anon_sym_infer] = ACTIONS(210),
    [anon_sym_keyof] = ACTIONS(212),
    [anon_sym_unique] = ACTIONS(214),
    [anon_sym_unknown] = ACTIONS(216),
    [anon_sym_never] = ACTIONS(216),
    [anon_sym_LBRACE_PIPE] = ACTIONS(218),
    [sym_html_comment] = ACTIONS(5),
  },
  [982] = {
    [sym_import] = STATE(4878),
    [sym_nested_identifier] = STATE(5474),
    [sym_string] = STATE(2994),
    [sym_formal_parameters] = STATE(5475),
    [sym_nested_type_identifier] = STATE(2939),
    [sym__type_query_member_expression_in_type_annotation] = STATE(2937),
    [sym__type_query_call_expression_in_type_annotation] = STATE(2938),
    [sym_type] = STATE(3758),
    [sym_constructor_type] = STATE(3007),
    [sym_primary_type] = STATE(2981),
    [sym_template_literal_type] = STATE(3039),
    [sym_infer_type] = STATE(3007),
    [sym_conditional_type] = STATE(3039),
    [sym_generic_type] = STATE(3039),
    [sym_type_query] = STATE(3039),
    [sym_index_type_query] = STATE(3039),
    [sym_lookup_type] = STATE(3039),
    [sym_literal_type] = STATE(3039),
    [sym__number] = STATE(3041),
    [sym_existential_type] = STATE(3039),
    [sym_flow_maybe_type] = STATE(3039),
    [sym_parenthesized_type] = STATE(3039),
    [sym_predefined_type] = STATE(3039),
    [sym_object_type] = STATE(3039),
    [sym_type_parameters] = STATE(5248),
    [sym_array_type] = STATE(3039),
    [sym_tuple_type] = STATE(3039),
    [sym_readonly_type] = STATE(3007),
    [sym_union_type] = STATE(3039),
    [sym_intersection_type] = STATE(3039),
    [sym_function_type] = STATE(3007),
    [sym_identifier] = ACTIONS(1532),
    [anon_sym_STAR] = ACTIONS(543),
    [anon_sym_LBRACE] = ACTIONS(1534),
    [anon_sym_typeof] = ACTIONS(1536),
    [anon_sym_import] = ACTIONS(1538),
    [anon_sym_const] = ACTIONS(133),
    [anon_sym_LPAREN] = ACTIONS(1540),
    [anon_sym_LBRACK] = ACTIONS(1542),
    [anon_sym_new] = ACTIONS(1544),
    [anon_sym_AMP] = ACTIONS(748),
    [anon_sym_PIPE] = ACTIONS(750),
    [anon_sym_PLUS] = ACTIONS(2497),
    [anon_sym_DASH] = ACTIONS(2497),
    [anon_sym_LT] = ACTIONS(2499),
    [anon_sym_GT] = ACTIONS(3213),
    [anon_sym_void] = ACTIONS(216),
    [anon_sym_DQUOTE] = ACTIONS(1550),
    [anon_sym_SQUOTE] = ACTIONS(1552),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1554),
    [sym_number] = ACTIONS(1556),
    [sym_this] = ACTIONS(1558),
    [sym_true] = ACTIONS(1560),
    [sym_false] = ACTIONS(1560),
    [sym_null] = ACTIONS(1560),
    [sym_undefined] = ACTIONS(1560),
    [anon_sym_readonly] = ACTIONS(1562),
    [anon_sym_QMARK] = ACTIONS(774),
    [anon_sym_any] = ACTIONS(216),
    [anon_sym_number] = ACTIONS(216),
    [anon_sym_boolean] = ACTIONS(216),
    [anon_sym_string] = ACTIONS(216),
    [anon_sym_symbol] = ACTIONS(216),
    [anon_sym_object] = ACTIONS(216),
    [anon_sym_abstract] = ACTIONS(208),
    [anon_sym_infer] = ACTIONS(210),
    [anon_sym_keyof] = ACTIONS(212),
    [anon_sym_unique] = ACTIONS(214),
    [anon_sym_unknown] = ACTIONS(216),
    [anon_sym_never] = ACTIONS(216),
    [anon_sym_LBRACE_PIPE] = ACTIONS(218),
    [sym_html_comment] = ACTIONS(5),
  },
  [983] = {
    [sym_import] = STATE(4878),
    [sym_nested_identifier] = STATE(5474),
    [sym_string] = STATE(2994),
    [sym_formal_parameters] = STATE(5475),
    [sym_nested_type_identifier] = STATE(2939),
    [sym__type_query_member_expression_in_type_annotation] = STATE(2937),
    [sym__type_query_call_expression_in_type_annotation] = STATE(2938),
    [sym_type] = STATE(3758),
    [sym_constructor_type] = STATE(3007),
    [sym_primary_type] = STATE(2981),
    [sym_template_literal_type] = STATE(3039),
    [sym_infer_type] = STATE(3007),
    [sym_conditional_type] = STATE(3039),
    [sym_generic_type] = STATE(3039),
    [sym_type_query] = STATE(3039),
    [sym_index_type_query] = STATE(3039),
    [sym_lookup_type] = STATE(3039),
    [sym_literal_type] = STATE(3039),
    [sym__number] = STATE(3041),
    [sym_existential_type] = STATE(3039),
    [sym_flow_maybe_type] = STATE(3039),
    [sym_parenthesized_type] = STATE(3039),
    [sym_predefined_type] = STATE(3039),
    [sym_object_type] = STATE(3039),
    [sym_type_parameters] = STATE(5248),
    [sym_array_type] = STATE(3039),
    [sym_tuple_type] = STATE(3039),
    [sym_readonly_type] = STATE(3007),
    [sym_union_type] = STATE(3039),
    [sym_intersection_type] = STATE(3039),
    [sym_function_type] = STATE(3007),
    [sym_identifier] = ACTIONS(1532),
    [anon_sym_STAR] = ACTIONS(543),
    [anon_sym_LBRACE] = ACTIONS(1534),
    [anon_sym_typeof] = ACTIONS(1536),
    [anon_sym_import] = ACTIONS(1538),
    [anon_sym_const] = ACTIONS(133),
    [anon_sym_LPAREN] = ACTIONS(1540),
    [anon_sym_LBRACK] = ACTIONS(1542),
    [anon_sym_new] = ACTIONS(1544),
    [anon_sym_AMP] = ACTIONS(748),
    [anon_sym_PIPE] = ACTIONS(750),
    [anon_sym_PLUS] = ACTIONS(2497),
    [anon_sym_DASH] = ACTIONS(2497),
    [anon_sym_LT] = ACTIONS(2499),
    [anon_sym_GT] = ACTIONS(3215),
    [anon_sym_void] = ACTIONS(216),
    [anon_sym_DQUOTE] = ACTIONS(1550),
    [anon_sym_SQUOTE] = ACTIONS(1552),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1554),
    [sym_number] = ACTIONS(1556),
    [sym_this] = ACTIONS(1558),
    [sym_true] = ACTIONS(1560),
    [sym_false] = ACTIONS(1560),
    [sym_null] = ACTIONS(1560),
    [sym_undefined] = ACTIONS(1560),
    [anon_sym_readonly] = ACTIONS(1562),
    [anon_sym_QMARK] = ACTIONS(774),
    [anon_sym_any] = ACTIONS(216),
    [anon_sym_number] = ACTIONS(216),
    [anon_sym_boolean] = ACTIONS(216),
    [anon_sym_string] = ACTIONS(216),
    [anon_sym_symbol] = ACTIONS(216),
    [anon_sym_object] = ACTIONS(216),
    [anon_sym_abstract] = ACTIONS(208),
    [anon_sym_infer] = ACTIONS(210),
    [anon_sym_keyof] = ACTIONS(212),
    [anon_sym_unique] = ACTIONS(214),
    [anon_sym_unknown] = ACTIONS(216),
    [anon_sym_never] = ACTIONS(216),
    [anon_sym_LBRACE_PIPE] = ACTIONS(218),
    [sym_html_comment] = ACTIONS(5),
  },
  [984] = {
    [sym_import] = STATE(4878),
    [sym_nested_identifier] = STATE(5474),
    [sym_string] = STATE(2994),
    [sym_formal_parameters] = STATE(5475),
    [sym_nested_type_identifier] = STATE(2939),
    [sym__type_query_member_expression_in_type_annotation] = STATE(2937),
    [sym__type_query_call_expression_in_type_annotation] = STATE(2938),
    [sym_type] = STATE(4409),
    [sym_constructor_type] = STATE(3007),
    [sym_primary_type] = STATE(2981),
    [sym_template_literal_type] = STATE(3039),
    [sym_infer_type] = STATE(3007),
    [sym_conditional_type] = STATE(3039),
    [sym_generic_type] = STATE(3039),
    [sym_type_query] = STATE(3039),
    [sym_index_type_query] = STATE(3039),
    [sym_lookup_type] = STATE(3039),
    [sym_literal_type] = STATE(3039),
    [sym__number] = STATE(3041),
    [sym_existential_type] = STATE(3039),
    [sym_flow_maybe_type] = STATE(3039),
    [sym_parenthesized_type] = STATE(3039),
    [sym_predefined_type] = STATE(3039),
    [sym_object_type] = STATE(3039),
    [sym_type_parameters] = STATE(5248),
    [sym_array_type] = STATE(3039),
    [sym_tuple_type] = STATE(3039),
    [sym_readonly_type] = STATE(3007),
    [sym_union_type] = STATE(3039),
    [sym_intersection_type] = STATE(3039),
    [sym_function_type] = STATE(3007),
    [sym_identifier] = ACTIONS(1532),
    [anon_sym_STAR] = ACTIONS(543),
    [anon_sym_LBRACE] = ACTIONS(1534),
    [anon_sym_typeof] = ACTIONS(1536),
    [anon_sym_import] = ACTIONS(1538),
    [anon_sym_const] = ACTIONS(133),
    [anon_sym_LPAREN] = ACTIONS(1540),
    [anon_sym_LBRACK] = ACTIONS(1542),
    [anon_sym_RBRACK] = ACTIONS(3217),
    [anon_sym_new] = ACTIONS(1544),
    [anon_sym_AMP] = ACTIONS(748),
    [anon_sym_PIPE] = ACTIONS(750),
    [anon_sym_PLUS] = ACTIONS(2497),
    [anon_sym_DASH] = ACTIONS(2497),
    [anon_sym_LT] = ACTIONS(2499),
    [anon_sym_void] = ACTIONS(216),
    [anon_sym_DQUOTE] = ACTIONS(1550),
    [anon_sym_SQUOTE] = ACTIONS(1552),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1554),
    [sym_number] = ACTIONS(1556),
    [sym_this] = ACTIONS(1558),
    [sym_true] = ACTIONS(1560),
    [sym_false] = ACTIONS(1560),
    [sym_null] = ACTIONS(1560),
    [sym_undefined] = ACTIONS(1560),
    [anon_sym_readonly] = ACTIONS(1562),
    [anon_sym_QMARK] = ACTIONS(774),
    [anon_sym_any] = ACTIONS(216),
    [anon_sym_number] = ACTIONS(216),
    [anon_sym_boolean] = ACTIONS(216),
    [anon_sym_string] = ACTIONS(216),
    [anon_sym_symbol] = ACTIONS(216),
    [anon_sym_object] = ACTIONS(216),
    [anon_sym_abstract] = ACTIONS(208),
    [anon_sym_infer] = ACTIONS(210),
    [anon_sym_keyof] = ACTIONS(212),
    [anon_sym_unique] = ACTIONS(214),
    [anon_sym_unknown] = ACTIONS(216),
    [anon_sym_never] = ACTIONS(216),
    [anon_sym_LBRACE_PIPE] = ACTIONS(218),
    [sym_html_comment] = ACTIONS(5),
  },
  [985] = {
    [sym_import] = STATE(4878),
    [sym_nested_identifier] = STATE(5474),
    [sym_string] = STATE(2994),
    [sym_formal_parameters] = STATE(5475),
    [sym_nested_type_identifier] = STATE(2939),
    [sym__type_query_member_expression_in_type_annotation] = STATE(2937),
    [sym__type_query_call_expression_in_type_annotation] = STATE(2938),
    [sym_type] = STATE(3758),
    [sym_constructor_type] = STATE(3007),
    [sym_primary_type] = STATE(2981),
    [sym_template_literal_type] = STATE(3039),
    [sym_infer_type] = STATE(3007),
    [sym_conditional_type] = STATE(3039),
    [sym_generic_type] = STATE(3039),
    [sym_type_query] = STATE(3039),
    [sym_index_type_query] = STATE(3039),
    [sym_lookup_type] = STATE(3039),
    [sym_literal_type] = STATE(3039),
    [sym__number] = STATE(3041),
    [sym_existential_type] = STATE(3039),
    [sym_flow_maybe_type] = STATE(3039),
    [sym_parenthesized_type] = STATE(3039),
    [sym_predefined_type] = STATE(3039),
    [sym_object_type] = STATE(3039),
    [sym_type_parameters] = STATE(5248),
    [sym_array_type] = STATE(3039),
    [sym_tuple_type] = STATE(3039),
    [sym_readonly_type] = STATE(3007),
    [sym_union_type] = STATE(3039),
    [sym_intersection_type] = STATE(3039),
    [sym_function_type] = STATE(3007),
    [sym_identifier] = ACTIONS(1532),
    [anon_sym_STAR] = ACTIONS(543),
    [anon_sym_LBRACE] = ACTIONS(1534),
    [anon_sym_typeof] = ACTIONS(1536),
    [anon_sym_import] = ACTIONS(1538),
    [anon_sym_const] = ACTIONS(133),
    [anon_sym_LPAREN] = ACTIONS(1540),
    [anon_sym_LBRACK] = ACTIONS(1542),
    [anon_sym_new] = ACTIONS(1544),
    [anon_sym_AMP] = ACTIONS(748),
    [anon_sym_PIPE] = ACTIONS(750),
    [anon_sym_PLUS] = ACTIONS(2497),
    [anon_sym_DASH] = ACTIONS(2497),
    [anon_sym_LT] = ACTIONS(2499),
    [anon_sym_GT] = ACTIONS(3219),
    [anon_sym_void] = ACTIONS(216),
    [anon_sym_DQUOTE] = ACTIONS(1550),
    [anon_sym_SQUOTE] = ACTIONS(1552),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1554),
    [sym_number] = ACTIONS(1556),
    [sym_this] = ACTIONS(1558),
    [sym_true] = ACTIONS(1560),
    [sym_false] = ACTIONS(1560),
    [sym_null] = ACTIONS(1560),
    [sym_undefined] = ACTIONS(1560),
    [anon_sym_readonly] = ACTIONS(1562),
    [anon_sym_QMARK] = ACTIONS(774),
    [anon_sym_any] = ACTIONS(216),
    [anon_sym_number] = ACTIONS(216),
    [anon_sym_boolean] = ACTIONS(216),
    [anon_sym_string] = ACTIONS(216),
    [anon_sym_symbol] = ACTIONS(216),
    [anon_sym_object] = ACTIONS(216),
    [anon_sym_abstract] = ACTIONS(208),
    [anon_sym_infer] = ACTIONS(210),
    [anon_sym_keyof] = ACTIONS(212),
    [anon_sym_unique] = ACTIONS(214),
    [anon_sym_unknown] = ACTIONS(216),
    [anon_sym_never] = ACTIONS(216),
    [anon_sym_LBRACE_PIPE] = ACTIONS(218),
    [sym_html_comment] = ACTIONS(5),
  },
  [986] = {
    [sym_import] = STATE(4878),
    [sym_nested_identifier] = STATE(5474),
    [sym_string] = STATE(2994),
    [sym_formal_parameters] = STATE(5475),
    [sym_nested_type_identifier] = STATE(2939),
    [sym__type_query_member_expression_in_type_annotation] = STATE(2937),
    [sym__type_query_call_expression_in_type_annotation] = STATE(2938),
    [sym_type] = STATE(4486),
    [sym_constructor_type] = STATE(3007),
    [sym_primary_type] = STATE(2981),
    [sym_template_literal_type] = STATE(3039),
    [sym_infer_type] = STATE(3007),
    [sym_conditional_type] = STATE(3039),
    [sym_generic_type] = STATE(3039),
    [sym_type_query] = STATE(3039),
    [sym_index_type_query] = STATE(3039),
    [sym_lookup_type] = STATE(3039),
    [sym_literal_type] = STATE(3039),
    [sym__number] = STATE(3041),
    [sym_existential_type] = STATE(3039),
    [sym_flow_maybe_type] = STATE(3039),
    [sym_parenthesized_type] = STATE(3039),
    [sym_predefined_type] = STATE(3039),
    [sym_object_type] = STATE(3039),
    [sym_type_parameters] = STATE(5248),
    [sym_array_type] = STATE(3039),
    [sym_tuple_type] = STATE(3039),
    [sym_readonly_type] = STATE(3007),
    [sym_union_type] = STATE(3039),
    [sym_intersection_type] = STATE(3039),
    [sym_function_type] = STATE(3007),
    [sym_identifier] = ACTIONS(1532),
    [anon_sym_STAR] = ACTIONS(543),
    [anon_sym_LBRACE] = ACTIONS(1534),
    [anon_sym_typeof] = ACTIONS(1536),
    [anon_sym_import] = ACTIONS(1538),
    [anon_sym_const] = ACTIONS(133),
    [anon_sym_LPAREN] = ACTIONS(1540),
    [anon_sym_LBRACK] = ACTIONS(1542),
    [anon_sym_RBRACK] = ACTIONS(3221),
    [anon_sym_new] = ACTIONS(1544),
    [anon_sym_AMP] = ACTIONS(748),
    [anon_sym_PIPE] = ACTIONS(750),
    [anon_sym_PLUS] = ACTIONS(2497),
    [anon_sym_DASH] = ACTIONS(2497),
    [anon_sym_LT] = ACTIONS(2499),
    [anon_sym_void] = ACTIONS(216),
    [anon_sym_DQUOTE] = ACTIONS(1550),
    [anon_sym_SQUOTE] = ACTIONS(1552),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1554),
    [sym_number] = ACTIONS(1556),
    [sym_this] = ACTIONS(1558),
    [sym_true] = ACTIONS(1560),
    [sym_false] = ACTIONS(1560),
    [sym_null] = ACTIONS(1560),
    [sym_undefined] = ACTIONS(1560),
    [anon_sym_readonly] = ACTIONS(1562),
    [anon_sym_QMARK] = ACTIONS(774),
    [anon_sym_any] = ACTIONS(216),
    [anon_sym_number] = ACTIONS(216),
    [anon_sym_boolean] = ACTIONS(216),
    [anon_sym_string] = ACTIONS(216),
    [anon_sym_symbol] = ACTIONS(216),
    [anon_sym_object] = ACTIONS(216),
    [anon_sym_abstract] = ACTIONS(208),
    [anon_sym_infer] = ACTIONS(210),
    [anon_sym_keyof] = ACTIONS(212),
    [anon_sym_unique] = ACTIONS(214),
    [anon_sym_unknown] = ACTIONS(216),
    [anon_sym_never] = ACTIONS(216),
    [anon_sym_LBRACE_PIPE] = ACTIONS(218),
    [sym_html_comment] = ACTIONS(5),
  },
  [987] = {
    [sym_import] = STATE(4878),
    [sym_nested_identifier] = STATE(5474),
    [sym_string] = STATE(2994),
    [sym_formal_parameters] = STATE(5475),
    [sym_nested_type_identifier] = STATE(2939),
    [sym__type_query_member_expression_in_type_annotation] = STATE(2937),
    [sym__type_query_call_expression_in_type_annotation] = STATE(2938),
    [sym_type] = STATE(3758),
    [sym_constructor_type] = STATE(3007),
    [sym_primary_type] = STATE(2981),
    [sym_template_literal_type] = STATE(3039),
    [sym_infer_type] = STATE(3007),
    [sym_conditional_type] = STATE(3039),
    [sym_generic_type] = STATE(3039),
    [sym_type_query] = STATE(3039),
    [sym_index_type_query] = STATE(3039),
    [sym_lookup_type] = STATE(3039),
    [sym_literal_type] = STATE(3039),
    [sym__number] = STATE(3041),
    [sym_existential_type] = STATE(3039),
    [sym_flow_maybe_type] = STATE(3039),
    [sym_parenthesized_type] = STATE(3039),
    [sym_predefined_type] = STATE(3039),
    [sym_object_type] = STATE(3039),
    [sym_type_parameters] = STATE(5248),
    [sym_array_type] = STATE(3039),
    [sym_tuple_type] = STATE(3039),
    [sym_readonly_type] = STATE(3007),
    [sym_union_type] = STATE(3039),
    [sym_intersection_type] = STATE(3039),
    [sym_function_type] = STATE(3007),
    [sym_identifier] = ACTIONS(1532),
    [anon_sym_STAR] = ACTIONS(543),
    [anon_sym_LBRACE] = ACTIONS(1534),
    [anon_sym_typeof] = ACTIONS(1536),
    [anon_sym_import] = ACTIONS(1538),
    [anon_sym_const] = ACTIONS(133),
    [anon_sym_LPAREN] = ACTIONS(1540),
    [anon_sym_LBRACK] = ACTIONS(1542),
    [anon_sym_new] = ACTIONS(1544),
    [anon_sym_AMP] = ACTIONS(748),
    [anon_sym_PIPE] = ACTIONS(750),
    [anon_sym_PLUS] = ACTIONS(2497),
    [anon_sym_DASH] = ACTIONS(2497),
    [anon_sym_LT] = ACTIONS(2499),
    [anon_sym_GT] = ACTIONS(3223),
    [anon_sym_void] = ACTIONS(216),
    [anon_sym_DQUOTE] = ACTIONS(1550),
    [anon_sym_SQUOTE] = ACTIONS(1552),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1554),
    [sym_number] = ACTIONS(1556),
    [sym_this] = ACTIONS(1558),
    [sym_true] = ACTIONS(1560),
    [sym_false] = ACTIONS(1560),
    [sym_null] = ACTIONS(1560),
    [sym_undefined] = ACTIONS(1560),
    [anon_sym_readonly] = ACTIONS(1562),
    [anon_sym_QMARK] = ACTIONS(774),
    [anon_sym_any] = ACTIONS(216),
    [anon_sym_number] = ACTIONS(216),
    [anon_sym_boolean] = ACTIONS(216),
    [anon_sym_string] = ACTIONS(216),
    [anon_sym_symbol] = ACTIONS(216),
    [anon_sym_object] = ACTIONS(216),
    [anon_sym_abstract] = ACTIONS(208),
    [anon_sym_infer] = ACTIONS(210),
    [anon_sym_keyof] = ACTIONS(212),
    [anon_sym_unique] = ACTIONS(214),
    [anon_sym_unknown] = ACTIONS(216),
    [anon_sym_never] = ACTIONS(216),
    [anon_sym_LBRACE_PIPE] = ACTIONS(218),
    [sym_html_comment] = ACTIONS(5),
  },
  [988] = {
    [sym_identifier] = ACTIONS(3225),
    [anon_sym_export] = ACTIONS(3225),
    [anon_sym_type] = ACTIONS(3225),
    [anon_sym_EQ] = ACTIONS(3225),
    [anon_sym_namespace] = ACTIONS(3225),
    [anon_sym_LBRACE] = ACTIONS(3227),
    [anon_sym_COMMA] = ACTIONS(3227),
    [anon_sym_RBRACE] = ACTIONS(3227),
    [anon_sym_typeof] = ACTIONS(3225),
    [anon_sym_import] = ACTIONS(3225),
    [anon_sym_let] = ACTIONS(3225),
    [anon_sym_BANG] = ACTIONS(3227),
    [anon_sym_LPAREN] = ACTIONS(3227),
    [anon_sym_RPAREN] = ACTIONS(3227),
    [anon_sym_await] = ACTIONS(3225),
    [anon_sym_COLON] = ACTIONS(3227),
    [anon_sym_yield] = ACTIONS(3225),
    [anon_sym_LBRACK] = ACTIONS(3227),
    [anon_sym_RBRACK] = ACTIONS(3227),
    [anon_sym_DOT] = ACTIONS(3225),
    [anon_sym_class] = ACTIONS(3225),
    [anon_sym_async] = ACTIONS(3225),
    [anon_sym_function] = ACTIONS(3225),
    [anon_sym_EQ_GT] = ACTIONS(3227),
    [anon_sym_QMARK_DOT] = ACTIONS(3227),
    [anon_sym_new] = ACTIONS(3225),
    [anon_sym_using] = ACTIONS(3225),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(3227),
    [anon_sym_AMP] = ACTIONS(3227),
    [anon_sym_PIPE] = ACTIONS(3227),
    [anon_sym_PLUS] = ACTIONS(3225),
    [anon_sym_DASH] = ACTIONS(3225),
    [anon_sym_SLASH] = ACTIONS(3225),
    [anon_sym_LT] = ACTIONS(3227),
    [anon_sym_GT] = ACTIONS(3227),
    [anon_sym_TILDE] = ACTIONS(3227),
    [anon_sym_void] = ACTIONS(3225),
    [anon_sym_delete] = ACTIONS(3225),
    [anon_sym_PLUS_PLUS] = ACTIONS(3227),
    [anon_sym_DASH_DASH] = ACTIONS(3227),
    [anon_sym_DQUOTE] = ACTIONS(3227),
    [anon_sym_SQUOTE] = ACTIONS(3227),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(3227),
    [sym_number] = ACTIONS(3227),
    [sym_private_property_identifier] = ACTIONS(3227),
    [sym_this] = ACTIONS(3225),
    [sym_super] = ACTIONS(3225),
    [sym_true] = ACTIONS(3225),
    [sym_false] = ACTIONS(3225),
    [sym_null] = ACTIONS(3225),
    [sym_undefined] = ACTIONS(3225),
    [anon_sym_AT] = ACTIONS(3227),
    [anon_sym_static] = ACTIONS(3225),
    [anon_sym_readonly] = ACTIONS(3225),
    [anon_sym_get] = ACTIONS(3225),
    [anon_sym_set] = ACTIONS(3225),
    [anon_sym_QMARK] = ACTIONS(3225),
    [anon_sym_declare] = ACTIONS(3225),
    [anon_sym_public] = ACTIONS(3225),
    [anon_sym_private] = ACTIONS(3225),
    [anon_sym_protected] = ACTIONS(3225),
    [anon_sym_override] = ACTIONS(3225),
    [anon_sym_module] = ACTIONS(3225),
    [anon_sym_any] = ACTIONS(3225),
    [anon_sym_number] = ACTIONS(3225),
    [anon_sym_boolean] = ACTIONS(3225),
    [anon_sym_string] = ACTIONS(3225),
    [anon_sym_symbol] = ACTIONS(3225),
    [anon_sym_object] = ACTIONS(3225),
    [anon_sym_abstract] = ACTIONS(3225),
    [anon_sym_extends] = ACTIONS(3225),
    [sym_html_comment] = ACTIONS(5),
  },
  [989] = {
    [sym_import] = STATE(4878),
    [sym_nested_identifier] = STATE(5474),
    [sym_string] = STATE(2994),
    [sym_formal_parameters] = STATE(5475),
    [sym_nested_type_identifier] = STATE(2939),
    [sym__type_query_member_expression_in_type_annotation] = STATE(2937),
    [sym__type_query_call_expression_in_type_annotation] = STATE(2938),
    [sym_type] = STATE(3758),
    [sym_constructor_type] = STATE(3007),
    [sym_primary_type] = STATE(2981),
    [sym_template_literal_type] = STATE(3039),
    [sym_infer_type] = STATE(3007),
    [sym_conditional_type] = STATE(3039),
    [sym_generic_type] = STATE(3039),
    [sym_type_query] = STATE(3039),
    [sym_index_type_query] = STATE(3039),
    [sym_lookup_type] = STATE(3039),
    [sym_literal_type] = STATE(3039),
    [sym__number] = STATE(3041),
    [sym_existential_type] = STATE(3039),
    [sym_flow_maybe_type] = STATE(3039),
    [sym_parenthesized_type] = STATE(3039),
    [sym_predefined_type] = STATE(3039),
    [sym_object_type] = STATE(3039),
    [sym_type_parameters] = STATE(5248),
    [sym_array_type] = STATE(3039),
    [sym_tuple_type] = STATE(3039),
    [sym_readonly_type] = STATE(3007),
    [sym_union_type] = STATE(3039),
    [sym_intersection_type] = STATE(3039),
    [sym_function_type] = STATE(3007),
    [sym_identifier] = ACTIONS(1532),
    [anon_sym_STAR] = ACTIONS(543),
    [anon_sym_LBRACE] = ACTIONS(1534),
    [anon_sym_typeof] = ACTIONS(1536),
    [anon_sym_import] = ACTIONS(1538),
    [anon_sym_const] = ACTIONS(133),
    [anon_sym_LPAREN] = ACTIONS(1540),
    [anon_sym_LBRACK] = ACTIONS(1542),
    [anon_sym_new] = ACTIONS(1544),
    [anon_sym_AMP] = ACTIONS(748),
    [anon_sym_PIPE] = ACTIONS(750),
    [anon_sym_PLUS] = ACTIONS(2497),
    [anon_sym_DASH] = ACTIONS(2497),
    [anon_sym_LT] = ACTIONS(2499),
    [anon_sym_GT] = ACTIONS(3229),
    [anon_sym_void] = ACTIONS(216),
    [anon_sym_DQUOTE] = ACTIONS(1550),
    [anon_sym_SQUOTE] = ACTIONS(1552),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1554),
    [sym_number] = ACTIONS(1556),
    [sym_this] = ACTIONS(1558),
    [sym_true] = ACTIONS(1560),
    [sym_false] = ACTIONS(1560),
    [sym_null] = ACTIONS(1560),
    [sym_undefined] = ACTIONS(1560),
    [anon_sym_readonly] = ACTIONS(1562),
    [anon_sym_QMARK] = ACTIONS(774),
    [anon_sym_any] = ACTIONS(216),
    [anon_sym_number] = ACTIONS(216),
    [anon_sym_boolean] = ACTIONS(216),
    [anon_sym_string] = ACTIONS(216),
    [anon_sym_symbol] = ACTIONS(216),
    [anon_sym_object] = ACTIONS(216),
    [anon_sym_abstract] = ACTIONS(208),
    [anon_sym_infer] = ACTIONS(210),
    [anon_sym_keyof] = ACTIONS(212),
    [anon_sym_unique] = ACTIONS(214),
    [anon_sym_unknown] = ACTIONS(216),
    [anon_sym_never] = ACTIONS(216),
    [anon_sym_LBRACE_PIPE] = ACTIONS(218),
    [sym_html_comment] = ACTIONS(5),
  },
  [990] = {
    [sym_import] = STATE(4878),
    [sym_nested_identifier] = STATE(5474),
    [sym_string] = STATE(2994),
    [sym_formal_parameters] = STATE(5475),
    [sym_nested_type_identifier] = STATE(2939),
    [sym__type_query_member_expression_in_type_annotation] = STATE(2937),
    [sym__type_query_call_expression_in_type_annotation] = STATE(2938),
    [sym_type] = STATE(3758),
    [sym_constructor_type] = STATE(3007),
    [sym_primary_type] = STATE(2981),
    [sym_template_literal_type] = STATE(3039),
    [sym_infer_type] = STATE(3007),
    [sym_conditional_type] = STATE(3039),
    [sym_generic_type] = STATE(3039),
    [sym_type_query] = STATE(3039),
    [sym_index_type_query] = STATE(3039),
    [sym_lookup_type] = STATE(3039),
    [sym_literal_type] = STATE(3039),
    [sym__number] = STATE(3041),
    [sym_existential_type] = STATE(3039),
    [sym_flow_maybe_type] = STATE(3039),
    [sym_parenthesized_type] = STATE(3039),
    [sym_predefined_type] = STATE(3039),
    [sym_object_type] = STATE(3039),
    [sym_type_parameters] = STATE(5248),
    [sym_array_type] = STATE(3039),
    [sym_tuple_type] = STATE(3039),
    [sym_readonly_type] = STATE(3007),
    [sym_union_type] = STATE(3039),
    [sym_intersection_type] = STATE(3039),
    [sym_function_type] = STATE(3007),
    [sym_identifier] = ACTIONS(1532),
    [anon_sym_STAR] = ACTIONS(543),
    [anon_sym_LBRACE] = ACTIONS(1534),
    [anon_sym_typeof] = ACTIONS(1536),
    [anon_sym_import] = ACTIONS(1538),
    [anon_sym_const] = ACTIONS(133),
    [anon_sym_LPAREN] = ACTIONS(1540),
    [anon_sym_LBRACK] = ACTIONS(1542),
    [anon_sym_new] = ACTIONS(1544),
    [anon_sym_AMP] = ACTIONS(748),
    [anon_sym_PIPE] = ACTIONS(750),
    [anon_sym_PLUS] = ACTIONS(2497),
    [anon_sym_DASH] = ACTIONS(2497),
    [anon_sym_LT] = ACTIONS(2499),
    [anon_sym_GT] = ACTIONS(3231),
    [anon_sym_void] = ACTIONS(216),
    [anon_sym_DQUOTE] = ACTIONS(1550),
    [anon_sym_SQUOTE] = ACTIONS(1552),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1554),
    [sym_number] = ACTIONS(1556),
    [sym_this] = ACTIONS(1558),
    [sym_true] = ACTIONS(1560),
    [sym_false] = ACTIONS(1560),
    [sym_null] = ACTIONS(1560),
    [sym_undefined] = ACTIONS(1560),
    [anon_sym_readonly] = ACTIONS(1562),
    [anon_sym_QMARK] = ACTIONS(774),
    [anon_sym_any] = ACTIONS(216),
    [anon_sym_number] = ACTIONS(216),
    [anon_sym_boolean] = ACTIONS(216),
    [anon_sym_string] = ACTIONS(216),
    [anon_sym_symbol] = ACTIONS(216),
    [anon_sym_object] = ACTIONS(216),
    [anon_sym_abstract] = ACTIONS(208),
    [anon_sym_infer] = ACTIONS(210),
    [anon_sym_keyof] = ACTIONS(212),
    [anon_sym_unique] = ACTIONS(214),
    [anon_sym_unknown] = ACTIONS(216),
    [anon_sym_never] = ACTIONS(216),
    [anon_sym_LBRACE_PIPE] = ACTIONS(218),
    [sym_html_comment] = ACTIONS(5),
  },
  [991] = {
    [sym_identifier] = ACTIONS(3233),
    [anon_sym_export] = ACTIONS(3233),
    [anon_sym_type] = ACTIONS(3233),
    [anon_sym_EQ] = ACTIONS(3233),
    [anon_sym_namespace] = ACTIONS(3233),
    [anon_sym_LBRACE] = ACTIONS(3235),
    [anon_sym_COMMA] = ACTIONS(3235),
    [anon_sym_RBRACE] = ACTIONS(3235),
    [anon_sym_typeof] = ACTIONS(3233),
    [anon_sym_import] = ACTIONS(3233),
    [anon_sym_let] = ACTIONS(3233),
    [anon_sym_BANG] = ACTIONS(3235),
    [anon_sym_LPAREN] = ACTIONS(3235),
    [anon_sym_RPAREN] = ACTIONS(3235),
    [anon_sym_await] = ACTIONS(3233),
    [anon_sym_COLON] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3233),
    [anon_sym_LBRACK] = ACTIONS(3235),
    [anon_sym_RBRACK] = ACTIONS(3235),
    [anon_sym_DOT] = ACTIONS(3233),
    [anon_sym_class] = ACTIONS(3233),
    [anon_sym_async] = ACTIONS(3233),
    [anon_sym_function] = ACTIONS(3233),
    [anon_sym_EQ_GT] = ACTIONS(3235),
    [anon_sym_QMARK_DOT] = ACTIONS(3235),
    [anon_sym_new] = ACTIONS(3233),
    [anon_sym_using] = ACTIONS(3233),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(3235),
    [anon_sym_AMP] = ACTIONS(3235),
    [anon_sym_PIPE] = ACTIONS(3235),
    [anon_sym_PLUS] = ACTIONS(3233),
    [anon_sym_DASH] = ACTIONS(3233),
    [anon_sym_SLASH] = ACTIONS(3233),
    [anon_sym_LT] = ACTIONS(3235),
    [anon_sym_GT] = ACTIONS(3235),
    [anon_sym_TILDE] = ACTIONS(3235),
    [anon_sym_void] = ACTIONS(3233),
    [anon_sym_delete] = ACTIONS(3233),
    [anon_sym_PLUS_PLUS] = ACTIONS(3235),
    [anon_sym_DASH_DASH] = ACTIONS(3235),
    [anon_sym_DQUOTE] = ACTIONS(3235),
    [anon_sym_SQUOTE] = ACTIONS(3235),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(3235),
    [sym_number] = ACTIONS(3235),
    [sym_private_property_identifier] = ACTIONS(3235),
    [sym_this] = ACTIONS(3233),
    [sym_super] = ACTIONS(3233),
    [sym_true] = ACTIONS(3233),
    [sym_false] = ACTIONS(3233),
    [sym_null] = ACTIONS(3233),
    [sym_undefined] = ACTIONS(3233),
    [anon_sym_AT] = ACTIONS(3235),
    [anon_sym_static] = ACTIONS(3233),
    [anon_sym_readonly] = ACTIONS(3233),
    [anon_sym_get] = ACTIONS(3233),
    [anon_sym_set] = ACTIONS(3233),
    [anon_sym_QMARK] = ACTIONS(3233),
    [anon_sym_declare] = ACTIONS(3233),
    [anon_sym_public] = ACTIONS(3233),
    [anon_sym_private] = ACTIONS(3233),
    [anon_sym_protected] = ACTIONS(3233),
    [anon_sym_override] = ACTIONS(3233),
    [anon_sym_module] = ACTIONS(3233),
    [anon_sym_any] = ACTIONS(3233),
    [anon_sym_number] = ACTIONS(3233),
    [anon_sym_boolean] = ACTIONS(3233),
    [anon_sym_string] = ACTIONS(3233),
    [anon_sym_symbol] = ACTIONS(3233),
    [anon_sym_object] = ACTIONS(3233),
    [anon_sym_abstract] = ACTIONS(3233),
    [anon_sym_extends] = ACTIONS(3233),
    [sym_html_comment] = ACTIONS(5),
  },
  [992] = {
    [sym_identifier] = ACTIONS(3237),
    [anon_sym_export] = ACTIONS(3237),
    [anon_sym_type] = ACTIONS(3237),
    [anon_sym_EQ] = ACTIONS(3237),
    [anon_sym_namespace] = ACTIONS(3237),
    [anon_sym_LBRACE] = ACTIONS(3239),
    [anon_sym_COMMA] = ACTIONS(3239),
    [anon_sym_RBRACE] = ACTIONS(3239),
    [anon_sym_typeof] = ACTIONS(3237),
    [anon_sym_import] = ACTIONS(3237),
    [anon_sym_let] = ACTIONS(3237),
    [anon_sym_BANG] = ACTIONS(3239),
    [anon_sym_LPAREN] = ACTIONS(3239),
    [anon_sym_RPAREN] = ACTIONS(3239),
    [anon_sym_await] = ACTIONS(3237),
    [anon_sym_COLON] = ACTIONS(3239),
    [anon_sym_yield] = ACTIONS(3237),
    [anon_sym_LBRACK] = ACTIONS(3239),
    [anon_sym_RBRACK] = ACTIONS(3239),
    [anon_sym_DOT] = ACTIONS(3237),
    [anon_sym_class] = ACTIONS(3237),
    [anon_sym_async] = ACTIONS(3237),
    [anon_sym_function] = ACTIONS(3237),
    [anon_sym_EQ_GT] = ACTIONS(3239),
    [anon_sym_QMARK_DOT] = ACTIONS(3239),
    [anon_sym_new] = ACTIONS(3237),
    [anon_sym_using] = ACTIONS(3237),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(3239),
    [anon_sym_AMP] = ACTIONS(3239),
    [anon_sym_PIPE] = ACTIONS(3239),
    [anon_sym_PLUS] = ACTIONS(3237),
    [anon_sym_DASH] = ACTIONS(3237),
    [anon_sym_SLASH] = ACTIONS(3237),
    [anon_sym_LT] = ACTIONS(3239),
    [anon_sym_GT] = ACTIONS(3239),
    [anon_sym_TILDE] = ACTIONS(3239),
    [anon_sym_void] = ACTIONS(3237),
    [anon_sym_delete] = ACTIONS(3237),
    [anon_sym_PLUS_PLUS] = ACTIONS(3239),
    [anon_sym_DASH_DASH] = ACTIONS(3239),
    [anon_sym_DQUOTE] = ACTIONS(3239),
    [anon_sym_SQUOTE] = ACTIONS(3239),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(3239),
    [sym_number] = ACTIONS(3239),
    [sym_private_property_identifier] = ACTIONS(3239),
    [sym_this] = ACTIONS(3237),
    [sym_super] = ACTIONS(3237),
    [sym_true] = ACTIONS(3237),
    [sym_false] = ACTIONS(3237),
    [sym_null] = ACTIONS(3237),
    [sym_undefined] = ACTIONS(3237),
    [anon_sym_AT] = ACTIONS(3239),
    [anon_sym_static] = ACTIONS(3237),
    [anon_sym_readonly] = ACTIONS(3237),
    [anon_sym_get] = ACTIONS(3237),
    [anon_sym_set] = ACTIONS(3237),
    [anon_sym_QMARK] = ACTIONS(3237),
    [anon_sym_declare] = ACTIONS(3237),
    [anon_sym_public] = ACTIONS(3237),
    [anon_sym_private] = ACTIONS(3237),
    [anon_sym_protected] = ACTIONS(3237),
    [anon_sym_override] = ACTIONS(3237),
    [anon_sym_module] = ACTIONS(3237),
    [anon_sym_any] = ACTIONS(3237),
    [anon_sym_number] = ACTIONS(3237),
    [anon_sym_boolean] = ACTIONS(3237),
    [anon_sym_string] = ACTIONS(3237),
    [anon_sym_symbol] = ACTIONS(3237),
    [anon_sym_object] = ACTIONS(3237),
    [anon_sym_abstract] = ACTIONS(3237),
    [anon_sym_extends] = ACTIONS(3237),
    [sym_html_comment] = ACTIONS(5),
  },
  [993] = {
    [sym_import] = STATE(4878),
    [sym_nested_identifier] = STATE(5474),
    [sym_string] = STATE(2994),
    [sym_formal_parameters] = STATE(5475),
    [sym_nested_type_identifier] = STATE(2939),
    [sym__type_query_member_expression_in_type_annotation] = STATE(2937),
    [sym__type_query_call_expression_in_type_annotation] = STATE(2938),
    [sym_type] = STATE(3758),
    [sym_constructor_type] = STATE(3007),
    [sym_primary_type] = STATE(2981),
    [sym_template_literal_type] = STATE(3039),
    [sym_infer_type] = STATE(3007),
    [sym_conditional_type] = STATE(3039),
    [sym_generic_type] = STATE(3039),
    [sym_type_query] = STATE(3039),
    [sym_index_type_query] = STATE(3039),
    [sym_lookup_type] = STATE(3039),
    [sym_literal_type] = STATE(3039),
    [sym__number] = STATE(3041),
    [sym_existential_type] = STATE(3039),
    [sym_flow_maybe_type] = STATE(3039),
    [sym_parenthesized_type] = STATE(3039),
    [sym_predefined_type] = STATE(3039),
    [sym_object_type] = STATE(3039),
    [sym_type_parameters] = STATE(5248),
    [sym_array_type] = STATE(3039),
    [sym_tuple_type] = STATE(3039),
    [sym_readonly_type] = STATE(3007),
    [sym_union_type] = STATE(3039),
    [sym_intersection_type] = STATE(3039),
    [sym_function_type] = STATE(3007),
    [sym_identifier] = ACTIONS(1532),
    [anon_sym_STAR] = ACTIONS(543),
    [anon_sym_LBRACE] = ACTIONS(1534),
    [anon_sym_typeof] = ACTIONS(1536),
    [anon_sym_import] = ACTIONS(1538),
    [anon_sym_const] = ACTIONS(133),
    [anon_sym_LPAREN] = ACTIONS(1540),
    [anon_sym_LBRACK] = ACTIONS(1542),
    [anon_sym_new] = ACTIONS(1544),
    [anon_sym_AMP] = ACTIONS(748),
    [anon_sym_PIPE] = ACTIONS(750),
    [anon_sym_PLUS] = ACTIONS(2497),
    [anon_sym_DASH] = ACTIONS(2497),
    [anon_sym_LT] = ACTIONS(2499),
    [anon_sym_GT] = ACTIONS(3241),
    [anon_sym_void] = ACTIONS(216),
    [anon_sym_DQUOTE] = ACTIONS(1550),
    [anon_sym_SQUOTE] = ACTIONS(1552),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1554),
    [sym_number] = ACTIONS(1556),
    [sym_this] = ACTIONS(1558),
    [sym_true] = ACTIONS(1560),
    [sym_false] = ACTIONS(1560),
    [sym_null] = ACTIONS(1560),
    [sym_undefined] = ACTIONS(1560),
    [anon_sym_readonly] = ACTIONS(1562),
    [anon_sym_QMARK] = ACTIONS(774),
    [anon_sym_any] = ACTIONS(216),
    [anon_sym_number] = ACTIONS(216),
    [anon_sym_boolean] = ACTIONS(216),
    [anon_sym_string] = ACTIONS(216),
    [anon_sym_symbol] = ACTIONS(216),
    [anon_sym_object] = ACTIONS(216),
    [anon_sym_abstract] = ACTIONS(208),
    [anon_sym_infer] = ACTIONS(210),
    [anon_sym_keyof] = ACTIONS(212),
    [anon_sym_unique] = ACTIONS(214),
    [anon_sym_unknown] = ACTIONS(216),
    [anon_sym_never] = ACTIONS(216),
    [anon_sym_LBRACE_PIPE] = ACTIONS(218),
    [sym_html_comment] = ACTIONS(5),
  },
  [994] = {
    [sym_import] = STATE(4878),
    [sym_nested_identifier] = STATE(5474),
    [sym_string] = STATE(2994),
    [sym_formal_parameters] = STATE(5475),
    [sym_nested_type_identifier] = STATE(2939),
    [sym__type_query_member_expression_in_type_annotation] = STATE(2937),
    [sym__type_query_call_expression_in_type_annotation] = STATE(2938),
    [sym_type] = STATE(4435),
    [sym_constructor_type] = STATE(3007),
    [sym_primary_type] = STATE(2981),
    [sym_template_literal_type] = STATE(3039),
    [sym_infer_type] = STATE(3007),
    [sym_conditional_type] = STATE(3039),
    [sym_generic_type] = STATE(3039),
    [sym_type_query] = STATE(3039),
    [sym_index_type_query] = STATE(3039),
    [sym_lookup_type] = STATE(3039),
    [sym_literal_type] = STATE(3039),
    [sym__number] = STATE(3041),
    [sym_existential_type] = STATE(3039),
    [sym_flow_maybe_type] = STATE(3039),
    [sym_parenthesized_type] = STATE(3039),
    [sym_predefined_type] = STATE(3039),
    [sym_object_type] = STATE(3039),
    [sym_type_parameters] = STATE(5248),
    [sym_array_type] = STATE(3039),
    [sym_tuple_type] = STATE(3039),
    [sym_readonly_type] = STATE(3007),
    [sym_union_type] = STATE(3039),
    [sym_intersection_type] = STATE(3039),
    [sym_function_type] = STATE(3007),
    [sym_identifier] = ACTIONS(1532),
    [anon_sym_STAR] = ACTIONS(543),
    [anon_sym_LBRACE] = ACTIONS(1534),
    [anon_sym_typeof] = ACTIONS(1536),
    [anon_sym_import] = ACTIONS(1538),
    [anon_sym_const] = ACTIONS(133),
    [anon_sym_LPAREN] = ACTIONS(1540),
    [anon_sym_LBRACK] = ACTIONS(1542),
    [anon_sym_RBRACK] = ACTIONS(3243),
    [anon_sym_new] = ACTIONS(1544),
    [anon_sym_AMP] = ACTIONS(748),
    [anon_sym_PIPE] = ACTIONS(750),
    [anon_sym_PLUS] = ACTIONS(2497),
    [anon_sym_DASH] = ACTIONS(2497),
    [anon_sym_LT] = ACTIONS(2499),
    [anon_sym_void] = ACTIONS(216),
    [anon_sym_DQUOTE] = ACTIONS(1550),
    [anon_sym_SQUOTE] = ACTIONS(1552),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1554),
    [sym_number] = ACTIONS(1556),
    [sym_this] = ACTIONS(1558),
    [sym_true] = ACTIONS(1560),
    [sym_false] = ACTIONS(1560),
    [sym_null] = ACTIONS(1560),
    [sym_undefined] = ACTIONS(1560),
    [anon_sym_readonly] = ACTIONS(1562),
    [anon_sym_QMARK] = ACTIONS(774),
    [anon_sym_any] = ACTIONS(216),
    [anon_sym_number] = ACTIONS(216),
    [anon_sym_boolean] = ACTIONS(216),
    [anon_sym_string] = ACTIONS(216),
    [anon_sym_symbol] = ACTIONS(216),
    [anon_sym_object] = ACTIONS(216),
    [anon_sym_abstract] = ACTIONS(208),
    [anon_sym_infer] = ACTIONS(210),
    [anon_sym_keyof] = ACTIONS(212),
    [anon_sym_unique] = ACTIONS(214),
    [anon_sym_unknown] = ACTIONS(216),
    [anon_sym_never] = ACTIONS(216),
    [anon_sym_LBRACE_PIPE] = ACTIONS(218),
    [sym_html_comment] = ACTIONS(5),
  },
  [995] = {
    [sym_import] = STATE(4878),
    [sym_nested_identifier] = STATE(5474),
    [sym_string] = STATE(2994),
    [sym_formal_parameters] = STATE(5475),
    [sym_nested_type_identifier] = STATE(2939),
    [sym__type_query_member_expression_in_type_annotation] = STATE(2937),
    [sym__type_query_call_expression_in_type_annotation] = STATE(2938),
    [sym_type] = STATE(3758),
    [sym_constructor_type] = STATE(3007),
    [sym_primary_type] = STATE(2981),
    [sym_template_literal_type] = STATE(3039),
    [sym_infer_type] = STATE(3007),
    [sym_conditional_type] = STATE(3039),
    [sym_generic_type] = STATE(3039),
    [sym_type_query] = STATE(3039),
    [sym_index_type_query] = STATE(3039),
    [sym_lookup_type] = STATE(3039),
    [sym_literal_type] = STATE(3039),
    [sym__number] = STATE(3041),
    [sym_existential_type] = STATE(3039),
    [sym_flow_maybe_type] = STATE(3039),
    [sym_parenthesized_type] = STATE(3039),
    [sym_predefined_type] = STATE(3039),
    [sym_object_type] = STATE(3039),
    [sym_type_parameters] = STATE(5248),
    [sym_array_type] = STATE(3039),
    [sym_tuple_type] = STATE(3039),
    [sym_readonly_type] = STATE(3007),
    [sym_union_type] = STATE(3039),
    [sym_intersection_type] = STATE(3039),
    [sym_function_type] = STATE(3007),
    [sym_identifier] = ACTIONS(1532),
    [anon_sym_STAR] = ACTIONS(543),
    [anon_sym_LBRACE] = ACTIONS(1534),
    [anon_sym_typeof] = ACTIONS(1536),
    [anon_sym_import] = ACTIONS(1538),
    [anon_sym_const] = ACTIONS(133),
    [anon_sym_LPAREN] = ACTIONS(1540),
    [anon_sym_LBRACK] = ACTIONS(1542),
    [anon_sym_new] = ACTIONS(1544),
    [anon_sym_AMP] = ACTIONS(748),
    [anon_sym_PIPE] = ACTIONS(750),
    [anon_sym_PLUS] = ACTIONS(2497),
    [anon_sym_DASH] = ACTIONS(2497),
    [anon_sym_LT] = ACTIONS(2499),
    [anon_sym_GT] = ACTIONS(3245),
    [anon_sym_void] = ACTIONS(216),
    [anon_sym_DQUOTE] = ACTIONS(1550),
    [anon_sym_SQUOTE] = ACTIONS(1552),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1554),
    [sym_number] = ACTIONS(1556),
    [sym_this] = ACTIONS(1558),
    [sym_true] = ACTIONS(1560),
    [sym_false] = ACTIONS(1560),
    [sym_null] = ACTIONS(1560),
    [sym_undefined] = ACTIONS(1560),
    [anon_sym_readonly] = ACTIONS(1562),
    [anon_sym_QMARK] = ACTIONS(774),
    [anon_sym_any] = ACTIONS(216),
    [anon_sym_number] = ACTIONS(216),
    [anon_sym_boolean] = ACTIONS(216),
    [anon_sym_string] = ACTIONS(216),
    [anon_sym_symbol] = ACTIONS(216),
    [anon_sym_object] = ACTIONS(216),
    [anon_sym_abstract] = ACTIONS(208),
    [anon_sym_infer] = ACTIONS(210),
    [anon_sym_keyof] = ACTIONS(212),
    [anon_sym_unique] = ACTIONS(214),
    [anon_sym_unknown] = ACTIONS(216),
    [anon_sym_never] = ACTIONS(216),
    [anon_sym_LBRACE_PIPE] = ACTIONS(218),
    [sym_html_comment] = ACTIONS(5),
  },
  [996] = {
    [sym_import] = STATE(4878),
    [sym_nested_identifier] = STATE(5474),
    [sym_string] = STATE(2994),
    [sym_formal_parameters] = STATE(5475),
    [sym_nested_type_identifier] = STATE(2939),
    [sym__type_query_member_expression_in_type_annotation] = STATE(2937),
    [sym__type_query_call_expression_in_type_annotation] = STATE(2938),
    [sym_type] = STATE(3758),
    [sym_constructor_type] = STATE(3007),
    [sym_primary_type] = STATE(2981),
    [sym_template_literal_type] = STATE(3039),
    [sym_infer_type] = STATE(3007),
    [sym_conditional_type] = STATE(3039),
    [sym_generic_type] = STATE(3039),
    [sym_type_query] = STATE(3039),
    [sym_index_type_query] = STATE(3039),
    [sym_lookup_type] = STATE(3039),
    [sym_literal_type] = STATE(3039),
    [sym__number] = STATE(3041),
    [sym_existential_type] = STATE(3039),
    [sym_flow_maybe_type] = STATE(3039),
    [sym_parenthesized_type] = STATE(3039),
    [sym_predefined_type] = STATE(3039),
    [sym_object_type] = STATE(3039),
    [sym_type_parameters] = STATE(5248),
    [sym_array_type] = STATE(3039),
    [sym_tuple_type] = STATE(3039),
    [sym_readonly_type] = STATE(3007),
    [sym_union_type] = STATE(3039),
    [sym_intersection_type] = STATE(3039),
    [sym_function_type] = STATE(3007),
    [sym_identifier] = ACTIONS(1532),
    [anon_sym_STAR] = ACTIONS(543),
    [anon_sym_LBRACE] = ACTIONS(1534),
    [anon_sym_typeof] = ACTIONS(1536),
    [anon_sym_import] = ACTIONS(1538),
    [anon_sym_const] = ACTIONS(133),
    [anon_sym_LPAREN] = ACTIONS(1540),
    [anon_sym_LBRACK] = ACTIONS(1542),
    [anon_sym_new] = ACTIONS(1544),
    [anon_sym_AMP] = ACTIONS(748),
    [anon_sym_PIPE] = ACTIONS(750),
    [anon_sym_PLUS] = ACTIONS(2497),
    [anon_sym_DASH] = ACTIONS(2497),
    [anon_sym_LT] = ACTIONS(2499),
    [anon_sym_GT] = ACTIONS(3247),
    [anon_sym_void] = ACTIONS(216),
    [anon_sym_DQUOTE] = ACTIONS(1550),
    [anon_sym_SQUOTE] = ACTIONS(1552),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1554),
    [sym_number] = ACTIONS(1556),
    [sym_this] = ACTIONS(1558),
    [sym_true] = ACTIONS(1560),
    [sym_false] = ACTIONS(1560),
    [sym_null] = ACTIONS(1560),
    [sym_undefined] = ACTIONS(1560),
    [anon_sym_readonly] = ACTIONS(1562),
    [anon_sym_QMARK] = ACTIONS(774),
    [anon_sym_any] = ACTIONS(216),
    [anon_sym_number] = ACTIONS(216),
    [anon_sym_boolean] = ACTIONS(216),
    [anon_sym_string] = ACTIONS(216),
    [anon_sym_symbol] = ACTIONS(216),
    [anon_sym_object] = ACTIONS(216),
    [anon_sym_abstract] = ACTIONS(208),
    [anon_sym_infer] = ACTIONS(210),
    [anon_sym_keyof] = ACTIONS(212),
    [anon_sym_unique] = ACTIONS(214),
    [anon_sym_unknown] = ACTIONS(216),
    [anon_sym_never] = ACTIONS(216),
    [anon_sym_LBRACE_PIPE] = ACTIONS(218),
    [sym_html_comment] = ACTIONS(5),
  },
  [997] = {
    [sym_import] = STATE(4878),
    [sym_nested_identifier] = STATE(5474),
    [sym_string] = STATE(2994),
    [sym_formal_parameters] = STATE(5475),
    [sym_nested_type_identifier] = STATE(2939),
    [sym__type_query_member_expression_in_type_annotation] = STATE(2937),
    [sym__type_query_call_expression_in_type_annotation] = STATE(2938),
    [sym_type] = STATE(4461),
    [sym_constructor_type] = STATE(3007),
    [sym_primary_type] = STATE(2981),
    [sym_template_literal_type] = STATE(3039),
    [sym_infer_type] = STATE(3007),
    [sym_conditional_type] = STATE(3039),
    [sym_generic_type] = STATE(3039),
    [sym_type_query] = STATE(3039),
    [sym_index_type_query] = STATE(3039),
    [sym_lookup_type] = STATE(3039),
    [sym_literal_type] = STATE(3039),
    [sym__number] = STATE(3041),
    [sym_existential_type] = STATE(3039),
    [sym_flow_maybe_type] = STATE(3039),
    [sym_parenthesized_type] = STATE(3039),
    [sym_predefined_type] = STATE(3039),
    [sym_object_type] = STATE(3039),
    [sym_type_parameters] = STATE(5248),
    [sym_array_type] = STATE(3039),
    [sym_tuple_type] = STATE(3039),
    [sym_readonly_type] = STATE(3007),
    [sym_union_type] = STATE(3039),
    [sym_intersection_type] = STATE(3039),
    [sym_function_type] = STATE(3007),
    [sym_identifier] = ACTIONS(1532),
    [anon_sym_STAR] = ACTIONS(543),
    [anon_sym_LBRACE] = ACTIONS(1534),
    [anon_sym_typeof] = ACTIONS(1536),
    [anon_sym_import] = ACTIONS(1538),
    [anon_sym_const] = ACTIONS(133),
    [anon_sym_LPAREN] = ACTIONS(1540),
    [anon_sym_LBRACK] = ACTIONS(1542),
    [anon_sym_RBRACK] = ACTIONS(3249),
    [anon_sym_new] = ACTIONS(1544),
    [anon_sym_AMP] = ACTIONS(748),
    [anon_sym_PIPE] = ACTIONS(750),
    [anon_sym_PLUS] = ACTIONS(2497),
    [anon_sym_DASH] = ACTIONS(2497),
    [anon_sym_LT] = ACTIONS(2499),
    [anon_sym_void] = ACTIONS(216),
    [anon_sym_DQUOTE] = ACTIONS(1550),
    [anon_sym_SQUOTE] = ACTIONS(1552),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1554),
    [sym_number] = ACTIONS(1556),
    [sym_this] = ACTIONS(1558),
    [sym_true] = ACTIONS(1560),
    [sym_false] = ACTIONS(1560),
    [sym_null] = ACTIONS(1560),
    [sym_undefined] = ACTIONS(1560),
    [anon_sym_readonly] = ACTIONS(1562),
    [anon_sym_QMARK] = ACTIONS(774),
    [anon_sym_any] = ACTIONS(216),
    [anon_sym_number] = ACTIONS(216),
    [anon_sym_boolean] = ACTIONS(216),
    [anon_sym_string] = ACTIONS(216),
    [anon_sym_symbol] = ACTIONS(216),
    [anon_sym_object] = ACTIONS(216),
    [anon_sym_abstract] = ACTIONS(208),
    [anon_sym_infer] = ACTIONS(210),
    [anon_sym_keyof] = ACTIONS(212),
    [anon_sym_unique] = ACTIONS(214),
    [anon_sym_unknown] = ACTIONS(216),
    [anon_sym_never] = ACTIONS(216),
    [anon_sym_LBRACE_PIPE] = ACTIONS(218),
    [sym_html_comment] = ACTIONS(5),
  },
  [998] = {
    [sym_import] = STATE(4531),
    [sym_nested_identifier] = STATE(5486),
    [sym_string] = STATE(1632),
    [sym_formal_parameters] = STATE(5639),
    [sym_nested_type_identifier] = STATE(1527),
    [sym__type_query_member_expression_in_type_annotation] = STATE(1514),
    [sym__type_query_call_expression_in_type_annotation] = STATE(1574),
    [sym_type] = STATE(1643),
    [sym_constructor_type] = STATE(1544),
    [sym_primary_type] = STATE(1554),
    [sym_template_literal_type] = STATE(1556),
    [sym_infer_type] = STATE(1544),
    [sym_conditional_type] = STATE(1556),
    [sym_generic_type] = STATE(1556),
    [sym_type_query] = STATE(1556),
    [sym_index_type_query] = STATE(1556),
    [sym_lookup_type] = STATE(1556),
    [sym_literal_type] = STATE(1556),
    [sym__number] = STATE(1536),
    [sym_existential_type] = STATE(1556),
    [sym_flow_maybe_type] = STATE(1556),
    [sym_parenthesized_type] = STATE(1556),
    [sym_predefined_type] = STATE(1556),
    [sym_object_type] = STATE(1556),
    [sym_type_parameters] = STATE(5205),
    [sym_array_type] = STATE(1556),
    [sym_tuple_type] = STATE(1556),
    [sym_readonly_type] = STATE(1544),
    [sym_union_type] = STATE(1556),
    [sym_intersection_type] = STATE(1556),
    [sym_function_type] = STATE(1544),
    [sym_identifier] = ACTIONS(3251),
    [anon_sym_STAR] = ACTIONS(3147),
    [anon_sym_LBRACE] = ACTIONS(3149),
    [anon_sym_typeof] = ACTIONS(3151),
    [anon_sym_import] = ACTIONS(1538),
    [anon_sym_const] = ACTIONS(3153),
    [anon_sym_LPAREN] = ACTIONS(3155),
    [anon_sym_LBRACK] = ACTIONS(3157),
    [anon_sym_new] = ACTIONS(3159),
    [anon_sym_AMP] = ACTIONS(3161),
    [anon_sym_PIPE] = ACTIONS(3163),
    [anon_sym_PLUS] = ACTIONS(3165),
    [anon_sym_DASH] = ACTIONS(3165),
    [anon_sym_LT] = ACTIONS(2499),
    [anon_sym_void] = ACTIONS(3167),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(3169),
    [sym_number] = ACTIONS(3171),
    [sym_this] = ACTIONS(3253),
    [sym_true] = ACTIONS(3175),
    [sym_false] = ACTIONS(3175),
    [sym_null] = ACTIONS(3175),
    [sym_undefined] = ACTIONS(3175),
    [anon_sym_readonly] = ACTIONS(3177),
    [anon_sym_QMARK] = ACTIONS(3179),
    [anon_sym_any] = ACTIONS(3167),
    [anon_sym_number] = ACTIONS(3167),
    [anon_sym_boolean] = ACTIONS(3167),
    [anon_sym_string] = ACTIONS(3167),
    [anon_sym_symbol] = ACTIONS(3167),
    [anon_sym_object] = ACTIONS(3167),
    [anon_sym_abstract] = ACTIONS(3181),
    [anon_sym_infer] = ACTIONS(3185),
    [anon_sym_keyof] = ACTIONS(3187),
    [anon_sym_unique] = ACTIONS(3189),
    [anon_sym_unknown] = ACTIONS(3167),
    [anon_sym_never] = ACTIONS(3167),
    [anon_sym_LBRACE_PIPE] = ACTIONS(3191),
    [sym_html_comment] = ACTIONS(5),
  },
  [999] = {
    [sym_import] = STATE(4681),
    [sym_nested_identifier] = STATE(5474),
    [sym_string] = STATE(2994),
    [sym_formal_parameters] = STATE(5619),
    [sym_nested_type_identifier] = STATE(2939),
    [sym__type_query_member_expression_in_type_annotation] = STATE(3303),
    [sym__type_query_call_expression_in_type_annotation] = STATE(2938),
    [sym_type] = STATE(4473),
    [sym_constructor_type] = STATE(3007),
    [sym_primary_type] = STATE(2981),
    [sym_template_literal_type] = STATE(3039),
    [sym_infer_type] = STATE(3007),
    [sym_conditional_type] = STATE(3039),
    [sym_generic_type] = STATE(3039),
    [sym_type_query] = STATE(3039),
    [sym_index_type_query] = STATE(3039),
    [sym_lookup_type] = STATE(3039),
    [sym_literal_type] = STATE(3039),
    [sym__number] = STATE(3041),
    [sym_existential_type] = STATE(3039),
    [sym_flow_maybe_type] = STATE(3039),
    [sym_parenthesized_type] = STATE(3039),
    [sym_predefined_type] = STATE(3039),
    [sym_object_type] = STATE(3039),
    [sym_type_parameters] = STATE(5454),
    [sym_array_type] = STATE(3039),
    [sym_tuple_type] = STATE(3039),
    [sym_readonly_type] = STATE(3007),
    [sym_union_type] = STATE(3039),
    [sym_intersection_type] = STATE(3039),
    [sym_function_type] = STATE(3007),
    [sym_identifier] = ACTIONS(1532),
    [anon_sym_STAR] = ACTIONS(543),
    [anon_sym_LBRACE] = ACTIONS(1534),
    [anon_sym_typeof] = ACTIONS(1536),
    [anon_sym_import] = ACTIONS(1538),
    [anon_sym_const] = ACTIONS(133),
    [anon_sym_LPAREN] = ACTIONS(1540),
    [anon_sym_LBRACK] = ACTIONS(1542),
    [anon_sym_new] = ACTIONS(1642),
    [anon_sym_AMP] = ACTIONS(571),
    [anon_sym_PIPE] = ACTIONS(573),
    [anon_sym_PLUS] = ACTIONS(2497),
    [anon_sym_DASH] = ACTIONS(2497),
    [anon_sym_LT] = ACTIONS(2499),
    [anon_sym_void] = ACTIONS(216),
    [anon_sym_DQUOTE] = ACTIONS(1550),
    [anon_sym_SQUOTE] = ACTIONS(1552),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1554),
    [sym_number] = ACTIONS(1556),
    [sym_this] = ACTIONS(1558),
    [sym_true] = ACTIONS(1560),
    [sym_false] = ACTIONS(1560),
    [sym_null] = ACTIONS(1560),
    [sym_undefined] = ACTIONS(1560),
    [anon_sym_readonly] = ACTIONS(1648),
    [anon_sym_QMARK] = ACTIONS(593),
    [anon_sym_any] = ACTIONS(216),
    [anon_sym_number] = ACTIONS(216),
    [anon_sym_boolean] = ACTIONS(216),
    [anon_sym_string] = ACTIONS(216),
    [anon_sym_symbol] = ACTIONS(216),
    [anon_sym_object] = ACTIONS(216),
    [anon_sym_abstract] = ACTIONS(597),
    [anon_sym_infer] = ACTIONS(599),
    [anon_sym_keyof] = ACTIONS(601),
    [anon_sym_unique] = ACTIONS(214),
    [anon_sym_unknown] = ACTIONS(216),
    [anon_sym_never] = ACTIONS(216),
    [anon_sym_LBRACE_PIPE] = ACTIONS(218),
    [sym_html_comment] = ACTIONS(5),
  },
  [1000] = {
    [sym_import] = STATE(4531),
    [sym_nested_identifier] = STATE(5486),
    [sym_string] = STATE(1632),
    [sym_formal_parameters] = STATE(5639),
    [sym_nested_type_identifier] = STATE(1527),
    [sym__type_query_member_expression_in_type_annotation] = STATE(1514),
    [sym__type_query_call_expression_in_type_annotation] = STATE(1574),
    [sym_type] = STATE(1645),
    [sym_constructor_type] = STATE(1544),
    [sym_primary_type] = STATE(1554),
    [sym_template_literal_type] = STATE(1556),
    [sym_infer_type] = STATE(1544),
    [sym_conditional_type] = STATE(1556),
    [sym_generic_type] = STATE(1556),
    [sym_type_query] = STATE(1556),
    [sym_index_type_query] = STATE(1556),
    [sym_lookup_type] = STATE(1556),
    [sym_literal_type] = STATE(1556),
    [sym__number] = STATE(1536),
    [sym_existential_type] = STATE(1556),
    [sym_flow_maybe_type] = STATE(1556),
    [sym_parenthesized_type] = STATE(1556),
    [sym_predefined_type] = STATE(1556),
    [sym_object_type] = STATE(1556),
    [sym_type_parameters] = STATE(5205),
    [sym_array_type] = STATE(1556),
    [sym_tuple_type] = STATE(1556),
    [sym_readonly_type] = STATE(1544),
    [sym_union_type] = STATE(1556),
    [sym_intersection_type] = STATE(1556),
    [sym_function_type] = STATE(1544),
    [sym_identifier] = ACTIONS(3251),
    [anon_sym_STAR] = ACTIONS(3147),
    [anon_sym_LBRACE] = ACTIONS(3149),
    [anon_sym_typeof] = ACTIONS(3151),
    [anon_sym_import] = ACTIONS(1538),
    [anon_sym_const] = ACTIONS(3153),
    [anon_sym_LPAREN] = ACTIONS(3155),
    [anon_sym_LBRACK] = ACTIONS(3157),
    [anon_sym_new] = ACTIONS(3159),
    [anon_sym_AMP] = ACTIONS(3161),
    [anon_sym_PIPE] = ACTIONS(3163),
    [anon_sym_PLUS] = ACTIONS(3165),
    [anon_sym_DASH] = ACTIONS(3165),
    [anon_sym_LT] = ACTIONS(2499),
    [anon_sym_void] = ACTIONS(3167),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(3169),
    [sym_number] = ACTIONS(3171),
    [sym_this] = ACTIONS(3253),
    [sym_true] = ACTIONS(3175),
    [sym_false] = ACTIONS(3175),
    [sym_null] = ACTIONS(3175),
    [sym_undefined] = ACTIONS(3175),
    [anon_sym_readonly] = ACTIONS(3177),
    [anon_sym_QMARK] = ACTIONS(3179),
    [anon_sym_any] = ACTIONS(3167),
    [anon_sym_number] = ACTIONS(3167),
    [anon_sym_boolean] = ACTIONS(3167),
    [anon_sym_string] = ACTIONS(3167),
    [anon_sym_symbol] = ACTIONS(3167),
    [anon_sym_object] = ACTIONS(3167),
    [anon_sym_abstract] = ACTIONS(3181),
    [anon_sym_infer] = ACTIONS(3185),
    [anon_sym_keyof] = ACTIONS(3187),
    [anon_sym_unique] = ACTIONS(3189),
    [anon_sym_unknown] = ACTIONS(3167),
    [anon_sym_never] = ACTIONS(3167),
    [anon_sym_LBRACE_PIPE] = ACTIONS(3191),
    [sym_html_comment] = ACTIONS(5),
  },
  [1001] = {
    [sym_import] = STATE(4878),
    [sym_nested_identifier] = STATE(5474),
    [sym_string] = STATE(2994),
    [sym_formal_parameters] = STATE(5475),
    [sym_nested_type_identifier] = STATE(2939),
    [sym__type_query_member_expression_in_type_annotation] = STATE(2937),
    [sym__type_query_call_expression_in_type_annotation] = STATE(2938),
    [sym_type] = STATE(3883),
    [sym_constructor_type] = STATE(3007),
    [sym_primary_type] = STATE(2981),
    [sym_template_literal_type] = STATE(3039),
    [sym_infer_type] = STATE(3007),
    [sym_conditional_type] = STATE(3039),
    [sym_generic_type] = STATE(3039),
    [sym_type_query] = STATE(3039),
    [sym_index_type_query] = STATE(3039),
    [sym_lookup_type] = STATE(3039),
    [sym_literal_type] = STATE(3039),
    [sym__number] = STATE(3041),
    [sym_existential_type] = STATE(3039),
    [sym_flow_maybe_type] = STATE(3039),
    [sym_parenthesized_type] = STATE(3039),
    [sym_predefined_type] = STATE(3039),
    [sym_object_type] = STATE(3039),
    [sym_type_parameters] = STATE(5248),
    [sym_array_type] = STATE(3039),
    [sym_tuple_type] = STATE(3039),
    [sym_readonly_type] = STATE(3007),
    [sym_union_type] = STATE(3039),
    [sym_intersection_type] = STATE(3039),
    [sym_function_type] = STATE(3007),
    [sym_identifier] = ACTIONS(1532),
    [anon_sym_STAR] = ACTIONS(543),
    [anon_sym_LBRACE] = ACTIONS(1534),
    [anon_sym_typeof] = ACTIONS(1536),
    [anon_sym_import] = ACTIONS(1538),
    [anon_sym_const] = ACTIONS(133),
    [anon_sym_LPAREN] = ACTIONS(1540),
    [anon_sym_LBRACK] = ACTIONS(1542),
    [anon_sym_new] = ACTIONS(1544),
    [anon_sym_AMP] = ACTIONS(748),
    [anon_sym_PIPE] = ACTIONS(750),
    [anon_sym_PLUS] = ACTIONS(2497),
    [anon_sym_DASH] = ACTIONS(2497),
    [anon_sym_LT] = ACTIONS(2499),
    [anon_sym_void] = ACTIONS(216),
    [anon_sym_DQUOTE] = ACTIONS(1550),
    [anon_sym_SQUOTE] = ACTIONS(1552),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1554),
    [sym_number] = ACTIONS(1556),
    [sym_this] = ACTIONS(1558),
    [sym_true] = ACTIONS(1560),
    [sym_false] = ACTIONS(1560),
    [sym_null] = ACTIONS(1560),
    [sym_undefined] = ACTIONS(1560),
    [anon_sym_readonly] = ACTIONS(1562),
    [anon_sym_QMARK] = ACTIONS(774),
    [anon_sym_any] = ACTIONS(216),
    [anon_sym_number] = ACTIONS(216),
    [anon_sym_boolean] = ACTIONS(216),
    [anon_sym_string] = ACTIONS(216),
    [anon_sym_symbol] = ACTIONS(216),
    [anon_sym_object] = ACTIONS(216),
    [anon_sym_abstract] = ACTIONS(208),
    [anon_sym_infer] = ACTIONS(210),
    [anon_sym_keyof] = ACTIONS(212),
    [anon_sym_unique] = ACTIONS(214),
    [anon_sym_unknown] = ACTIONS(216),
    [anon_sym_never] = ACTIONS(216),
    [anon_sym_LBRACE_PIPE] = ACTIONS(218),
    [sym_html_comment] = ACTIONS(5),
  },
  [1002] = {
    [sym_import] = STATE(4878),
    [sym_nested_identifier] = STATE(5474),
    [sym_string] = STATE(2994),
    [sym_formal_parameters] = STATE(5475),
    [sym_nested_type_identifier] = STATE(2939),
    [sym__type_query_member_expression_in_type_annotation] = STATE(2937),
    [sym__type_query_call_expression_in_type_annotation] = STATE(2938),
    [sym_type] = STATE(2955),
    [sym_constructor_type] = STATE(3007),
    [sym_primary_type] = STATE(2981),
    [sym_template_literal_type] = STATE(3039),
    [sym_infer_type] = STATE(3007),
    [sym_conditional_type] = STATE(3039),
    [sym_generic_type] = STATE(3039),
    [sym_type_query] = STATE(3039),
    [sym_index_type_query] = STATE(3039),
    [sym_lookup_type] = STATE(3039),
    [sym_literal_type] = STATE(3039),
    [sym__number] = STATE(3041),
    [sym_existential_type] = STATE(3039),
    [sym_flow_maybe_type] = STATE(3039),
    [sym_parenthesized_type] = STATE(3039),
    [sym_predefined_type] = STATE(3039),
    [sym_object_type] = STATE(3039),
    [sym_type_parameters] = STATE(5248),
    [sym_array_type] = STATE(3039),
    [sym_tuple_type] = STATE(3039),
    [sym_readonly_type] = STATE(3007),
    [sym_union_type] = STATE(3039),
    [sym_intersection_type] = STATE(3039),
    [sym_function_type] = STATE(3007),
    [sym_identifier] = ACTIONS(1532),
    [anon_sym_STAR] = ACTIONS(543),
    [anon_sym_LBRACE] = ACTIONS(1534),
    [anon_sym_typeof] = ACTIONS(1536),
    [anon_sym_import] = ACTIONS(1538),
    [anon_sym_const] = ACTIONS(133),
    [anon_sym_LPAREN] = ACTIONS(1540),
    [anon_sym_LBRACK] = ACTIONS(1542),
    [anon_sym_new] = ACTIONS(1544),
    [anon_sym_AMP] = ACTIONS(748),
    [anon_sym_PIPE] = ACTIONS(750),
    [anon_sym_PLUS] = ACTIONS(2497),
    [anon_sym_DASH] = ACTIONS(2497),
    [anon_sym_LT] = ACTIONS(2499),
    [anon_sym_void] = ACTIONS(216),
    [anon_sym_DQUOTE] = ACTIONS(1550),
    [anon_sym_SQUOTE] = ACTIONS(1552),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1554),
    [sym_number] = ACTIONS(1556),
    [sym_this] = ACTIONS(1558),
    [sym_true] = ACTIONS(1560),
    [sym_false] = ACTIONS(1560),
    [sym_null] = ACTIONS(1560),
    [sym_undefined] = ACTIONS(1560),
    [anon_sym_readonly] = ACTIONS(1562),
    [anon_sym_QMARK] = ACTIONS(774),
    [anon_sym_any] = ACTIONS(216),
    [anon_sym_number] = ACTIONS(216),
    [anon_sym_boolean] = ACTIONS(216),
    [anon_sym_string] = ACTIONS(216),
    [anon_sym_symbol] = ACTIONS(216),
    [anon_sym_object] = ACTIONS(216),
    [anon_sym_abstract] = ACTIONS(208),
    [anon_sym_infer] = ACTIONS(210),
    [anon_sym_keyof] = ACTIONS(212),
    [anon_sym_unique] = ACTIONS(214),
    [anon_sym_unknown] = ACTIONS(216),
    [anon_sym_never] = ACTIONS(216),
    [anon_sym_LBRACE_PIPE] = ACTIONS(218),
    [sym_html_comment] = ACTIONS(5),
  },
  [1003] = {
    [sym_import] = STATE(4878),
    [sym_nested_identifier] = STATE(5474),
    [sym_string] = STATE(2994),
    [sym_formal_parameters] = STATE(5475),
    [sym_nested_type_identifier] = STATE(2939),
    [sym__type_query_member_expression_in_type_annotation] = STATE(2937),
    [sym__type_query_call_expression_in_type_annotation] = STATE(2938),
    [sym_type] = STATE(2972),
    [sym_constructor_type] = STATE(3007),
    [sym_primary_type] = STATE(2981),
    [sym_template_literal_type] = STATE(3039),
    [sym_infer_type] = STATE(3007),
    [sym_conditional_type] = STATE(3039),
    [sym_generic_type] = STATE(3039),
    [sym_type_query] = STATE(3039),
    [sym_index_type_query] = STATE(3039),
    [sym_lookup_type] = STATE(3039),
    [sym_literal_type] = STATE(3039),
    [sym__number] = STATE(3041),
    [sym_existential_type] = STATE(3039),
    [sym_flow_maybe_type] = STATE(3039),
    [sym_parenthesized_type] = STATE(3039),
    [sym_predefined_type] = STATE(3039),
    [sym_object_type] = STATE(3039),
    [sym_type_parameters] = STATE(5248),
    [sym_array_type] = STATE(3039),
    [sym_tuple_type] = STATE(3039),
    [sym_readonly_type] = STATE(3007),
    [sym_union_type] = STATE(3039),
    [sym_intersection_type] = STATE(3039),
    [sym_function_type] = STATE(3007),
    [sym_identifier] = ACTIONS(1532),
    [anon_sym_STAR] = ACTIONS(543),
    [anon_sym_LBRACE] = ACTIONS(1534),
    [anon_sym_typeof] = ACTIONS(1536),
    [anon_sym_import] = ACTIONS(1538),
    [anon_sym_const] = ACTIONS(133),
    [anon_sym_LPAREN] = ACTIONS(1540),
    [anon_sym_LBRACK] = ACTIONS(1542),
    [anon_sym_new] = ACTIONS(1544),
    [anon_sym_AMP] = ACTIONS(748),
    [anon_sym_PIPE] = ACTIONS(750),
    [anon_sym_PLUS] = ACTIONS(2497),
    [anon_sym_DASH] = ACTIONS(2497),
    [anon_sym_LT] = ACTIONS(2499),
    [anon_sym_void] = ACTIONS(216),
    [anon_sym_DQUOTE] = ACTIONS(1550),
    [anon_sym_SQUOTE] = ACTIONS(1552),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1554),
    [sym_number] = ACTIONS(1556),
    [sym_this] = ACTIONS(1558),
    [sym_true] = ACTIONS(1560),
    [sym_false] = ACTIONS(1560),
    [sym_null] = ACTIONS(1560),
    [sym_undefined] = ACTIONS(1560),
    [anon_sym_readonly] = ACTIONS(1562),
    [anon_sym_QMARK] = ACTIONS(774),
    [anon_sym_any] = ACTIONS(216),
    [anon_sym_number] = ACTIONS(216),
    [anon_sym_boolean] = ACTIONS(216),
    [anon_sym_string] = ACTIONS(216),
    [anon_sym_symbol] = ACTIONS(216),
    [anon_sym_object] = ACTIONS(216),
    [anon_sym_abstract] = ACTIONS(208),
    [anon_sym_infer] = ACTIONS(210),
    [anon_sym_keyof] = ACTIONS(212),
    [anon_sym_unique] = ACTIONS(214),
    [anon_sym_unknown] = ACTIONS(216),
    [anon_sym_never] = ACTIONS(216),
    [anon_sym_LBRACE_PIPE] = ACTIONS(218),
    [sym_html_comment] = ACTIONS(5),
  },
  [1004] = {
    [sym_import] = STATE(4878),
    [sym_nested_identifier] = STATE(5474),
    [sym_string] = STATE(2994),
    [sym_formal_parameters] = STATE(5475),
    [sym_nested_type_identifier] = STATE(2939),
    [sym__type_query_member_expression_in_type_annotation] = STATE(2937),
    [sym__type_query_call_expression_in_type_annotation] = STATE(2938),
    [sym_type] = STATE(4433),
    [sym_constructor_type] = STATE(3007),
    [sym_primary_type] = STATE(2981),
    [sym_template_literal_type] = STATE(3039),
    [sym_infer_type] = STATE(3007),
    [sym_conditional_type] = STATE(3039),
    [sym_generic_type] = STATE(3039),
    [sym_type_query] = STATE(3039),
    [sym_index_type_query] = STATE(3039),
    [sym_lookup_type] = STATE(3039),
    [sym_literal_type] = STATE(3039),
    [sym__number] = STATE(3041),
    [sym_existential_type] = STATE(3039),
    [sym_flow_maybe_type] = STATE(3039),
    [sym_parenthesized_type] = STATE(3039),
    [sym_predefined_type] = STATE(3039),
    [sym_object_type] = STATE(3039),
    [sym_type_parameters] = STATE(5248),
    [sym_array_type] = STATE(3039),
    [sym_tuple_type] = STATE(3039),
    [sym_readonly_type] = STATE(3007),
    [sym_union_type] = STATE(3039),
    [sym_intersection_type] = STATE(3039),
    [sym_function_type] = STATE(3007),
    [sym_identifier] = ACTIONS(1532),
    [anon_sym_STAR] = ACTIONS(543),
    [anon_sym_LBRACE] = ACTIONS(1534),
    [anon_sym_typeof] = ACTIONS(1536),
    [anon_sym_import] = ACTIONS(1538),
    [anon_sym_const] = ACTIONS(133),
    [anon_sym_LPAREN] = ACTIONS(1540),
    [anon_sym_LBRACK] = ACTIONS(1542),
    [anon_sym_new] = ACTIONS(1544),
    [anon_sym_AMP] = ACTIONS(748),
    [anon_sym_PIPE] = ACTIONS(750),
    [anon_sym_PLUS] = ACTIONS(2497),
    [anon_sym_DASH] = ACTIONS(2497),
    [anon_sym_LT] = ACTIONS(2499),
    [anon_sym_void] = ACTIONS(216),
    [anon_sym_DQUOTE] = ACTIONS(1550),
    [anon_sym_SQUOTE] = ACTIONS(1552),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1554),
    [sym_number] = ACTIONS(1556),
    [sym_this] = ACTIONS(1558),
    [sym_true] = ACTIONS(1560),
    [sym_false] = ACTIONS(1560),
    [sym_null] = ACTIONS(1560),
    [sym_undefined] = ACTIONS(1560),
    [anon_sym_readonly] = ACTIONS(1562),
    [anon_sym_QMARK] = ACTIONS(774),
    [anon_sym_any] = ACTIONS(216),
    [anon_sym_number] = ACTIONS(216),
    [anon_sym_boolean] = ACTIONS(216),
    [anon_sym_string] = ACTIONS(216),
    [anon_sym_symbol] = ACTIONS(216),
    [anon_sym_object] = ACTIONS(216),
    [anon_sym_abstract] = ACTIONS(208),
    [anon_sym_infer] = ACTIONS(210),
    [anon_sym_keyof] = ACTIONS(212),
    [anon_sym_unique] = ACTIONS(214),
    [anon_sym_unknown] = ACTIONS(216),
    [anon_sym_never] = ACTIONS(216),
    [anon_sym_LBRACE_PIPE] = ACTIONS(218),
    [sym_html_comment] = ACTIONS(5),
  },
  [1005] = {
    [sym_import] = STATE(4950),
    [sym_nested_identifier] = STATE(5535),
    [sym_string] = STATE(3265),
    [sym_formal_parameters] = STATE(5840),
    [sym_nested_type_identifier] = STATE(3151),
    [sym__type_query_member_expression_in_type_annotation] = STATE(3076),
    [sym__type_query_call_expression_in_type_annotation] = STATE(3200),
    [sym_type] = STATE(4104),
    [sym_constructor_type] = STATE(3271),
    [sym_primary_type] = STATE(3272),
    [sym_template_literal_type] = STATE(3273),
    [sym_infer_type] = STATE(3271),
    [sym_conditional_type] = STATE(3273),
    [sym_generic_type] = STATE(3273),
    [sym_type_query] = STATE(3273),
    [sym_index_type_query] = STATE(3273),
    [sym_lookup_type] = STATE(3273),
    [sym_literal_type] = STATE(3273),
    [sym__number] = STATE(3274),
    [sym_existential_type] = STATE(3273),
    [sym_flow_maybe_type] = STATE(3273),
    [sym_parenthesized_type] = STATE(3273),
    [sym_predefined_type] = STATE(3273),
    [sym_object_type] = STATE(3273),
    [sym_type_parameters] = STATE(5146),
    [sym_array_type] = STATE(3273),
    [sym_tuple_type] = STATE(3273),
    [sym_readonly_type] = STATE(3271),
    [sym_union_type] = STATE(3273),
    [sym_intersection_type] = STATE(3273),
    [sym_function_type] = STATE(3271),
    [sym_identifier] = ACTIONS(1606),
    [anon_sym_STAR] = ACTIONS(986),
    [anon_sym_LBRACE] = ACTIONS(1610),
    [anon_sym_typeof] = ACTIONS(1612),
    [anon_sym_import] = ACTIONS(1538),
    [anon_sym_const] = ACTIONS(992),
    [anon_sym_LPAREN] = ACTIONS(1614),
    [anon_sym_LBRACK] = ACTIONS(1616),
    [anon_sym_new] = ACTIONS(1618),
    [anon_sym_AMP] = ACTIONS(1000),
    [anon_sym_PIPE] = ACTIONS(1002),
    [anon_sym_PLUS] = ACTIONS(2983),
    [anon_sym_DASH] = ACTIONS(2983),
    [anon_sym_LT] = ACTIONS(2499),
    [anon_sym_void] = ACTIONS(1032),
    [anon_sym_DQUOTE] = ACTIONS(1626),
    [anon_sym_SQUOTE] = ACTIONS(1628),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1630),
    [sym_number] = ACTIONS(1632),
    [sym_this] = ACTIONS(1634),
    [sym_true] = ACTIONS(1636),
    [sym_false] = ACTIONS(1636),
    [sym_null] = ACTIONS(1636),
    [sym_undefined] = ACTIONS(1636),
    [anon_sym_readonly] = ACTIONS(1638),
    [anon_sym_QMARK] = ACTIONS(1020),
    [anon_sym_any] = ACTIONS(1032),
    [anon_sym_number] = ACTIONS(1032),
    [anon_sym_boolean] = ACTIONS(1032),
    [anon_sym_string] = ACTIONS(1032),
    [anon_sym_symbol] = ACTIONS(1032),
    [anon_sym_object] = ACTIONS(1032),
    [anon_sym_abstract] = ACTIONS(1024),
    [anon_sym_infer] = ACTIONS(1026),
    [anon_sym_keyof] = ACTIONS(1028),
    [anon_sym_unique] = ACTIONS(1030),
    [anon_sym_unknown] = ACTIONS(1032),
    [anon_sym_never] = ACTIONS(1032),
    [anon_sym_LBRACE_PIPE] = ACTIONS(1034),
    [sym_html_comment] = ACTIONS(5),
  },
  [1006] = {
    [sym_import] = STATE(4878),
    [sym_nested_identifier] = STATE(5474),
    [sym_string] = STATE(2994),
    [sym_formal_parameters] = STATE(5475),
    [sym_nested_type_identifier] = STATE(2939),
    [sym__type_query_member_expression_in_type_annotation] = STATE(2937),
    [sym__type_query_call_expression_in_type_annotation] = STATE(2938),
    [sym_type] = STATE(3340),
    [sym_constructor_type] = STATE(3007),
    [sym_primary_type] = STATE(2981),
    [sym_template_literal_type] = STATE(3039),
    [sym_infer_type] = STATE(3007),
    [sym_conditional_type] = STATE(3039),
    [sym_generic_type] = STATE(3039),
    [sym_type_query] = STATE(3039),
    [sym_index_type_query] = STATE(3039),
    [sym_lookup_type] = STATE(3039),
    [sym_literal_type] = STATE(3039),
    [sym__number] = STATE(3041),
    [sym_existential_type] = STATE(3039),
    [sym_flow_maybe_type] = STATE(3039),
    [sym_parenthesized_type] = STATE(3039),
    [sym_predefined_type] = STATE(3039),
    [sym_object_type] = STATE(3039),
    [sym_type_parameters] = STATE(5248),
    [sym_array_type] = STATE(3039),
    [sym_tuple_type] = STATE(3039),
    [sym_readonly_type] = STATE(3007),
    [sym_union_type] = STATE(3039),
    [sym_intersection_type] = STATE(3039),
    [sym_function_type] = STATE(3007),
    [sym_identifier] = ACTIONS(1532),
    [anon_sym_STAR] = ACTIONS(543),
    [anon_sym_LBRACE] = ACTIONS(1534),
    [anon_sym_typeof] = ACTIONS(1536),
    [anon_sym_import] = ACTIONS(1538),
    [anon_sym_const] = ACTIONS(133),
    [anon_sym_LPAREN] = ACTIONS(1540),
    [anon_sym_LBRACK] = ACTIONS(1542),
    [anon_sym_new] = ACTIONS(1544),
    [anon_sym_AMP] = ACTIONS(748),
    [anon_sym_PIPE] = ACTIONS(750),
    [anon_sym_PLUS] = ACTIONS(2497),
    [anon_sym_DASH] = ACTIONS(2497),
    [anon_sym_LT] = ACTIONS(2499),
    [anon_sym_void] = ACTIONS(216),
    [anon_sym_DQUOTE] = ACTIONS(1550),
    [anon_sym_SQUOTE] = ACTIONS(1552),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1554),
    [sym_number] = ACTIONS(1556),
    [sym_this] = ACTIONS(1558),
    [sym_true] = ACTIONS(1560),
    [sym_false] = ACTIONS(1560),
    [sym_null] = ACTIONS(1560),
    [sym_undefined] = ACTIONS(1560),
    [anon_sym_readonly] = ACTIONS(1562),
    [anon_sym_QMARK] = ACTIONS(774),
    [anon_sym_any] = ACTIONS(216),
    [anon_sym_number] = ACTIONS(216),
    [anon_sym_boolean] = ACTIONS(216),
    [anon_sym_string] = ACTIONS(216),
    [anon_sym_symbol] = ACTIONS(216),
    [anon_sym_object] = ACTIONS(216),
    [anon_sym_abstract] = ACTIONS(208),
    [anon_sym_infer] = ACTIONS(210),
    [anon_sym_keyof] = ACTIONS(212),
    [anon_sym_unique] = ACTIONS(214),
    [anon_sym_unknown] = ACTIONS(216),
    [anon_sym_never] = ACTIONS(216),
    [anon_sym_LBRACE_PIPE] = ACTIONS(218),
    [sym_html_comment] = ACTIONS(5),
  },
  [1007] = {
    [sym_import] = STATE(4878),
    [sym_nested_identifier] = STATE(5474),
    [sym_string] = STATE(2994),
    [sym_formal_parameters] = STATE(5475),
    [sym_nested_type_identifier] = STATE(2939),
    [sym__type_query_member_expression_in_type_annotation] = STATE(2937),
    [sym__type_query_call_expression_in_type_annotation] = STATE(2938),
    [sym_type] = STATE(3019),
    [sym_constructor_type] = STATE(3007),
    [sym_primary_type] = STATE(2981),
    [sym_template_literal_type] = STATE(3039),
    [sym_infer_type] = STATE(3007),
    [sym_conditional_type] = STATE(3039),
    [sym_generic_type] = STATE(3039),
    [sym_type_query] = STATE(3039),
    [sym_index_type_query] = STATE(3039),
    [sym_lookup_type] = STATE(3039),
    [sym_literal_type] = STATE(3039),
    [sym__number] = STATE(3041),
    [sym_existential_type] = STATE(3039),
    [sym_flow_maybe_type] = STATE(3039),
    [sym_parenthesized_type] = STATE(3039),
    [sym_predefined_type] = STATE(3039),
    [sym_object_type] = STATE(3039),
    [sym_type_parameters] = STATE(5248),
    [sym_array_type] = STATE(3039),
    [sym_tuple_type] = STATE(3039),
    [sym_readonly_type] = STATE(3007),
    [sym_union_type] = STATE(3039),
    [sym_intersection_type] = STATE(3039),
    [sym_function_type] = STATE(3007),
    [sym_identifier] = ACTIONS(1532),
    [anon_sym_STAR] = ACTIONS(543),
    [anon_sym_LBRACE] = ACTIONS(1534),
    [anon_sym_typeof] = ACTIONS(1536),
    [anon_sym_import] = ACTIONS(1538),
    [anon_sym_const] = ACTIONS(133),
    [anon_sym_LPAREN] = ACTIONS(1540),
    [anon_sym_LBRACK] = ACTIONS(1542),
    [anon_sym_new] = ACTIONS(1544),
    [anon_sym_AMP] = ACTIONS(748),
    [anon_sym_PIPE] = ACTIONS(750),
    [anon_sym_PLUS] = ACTIONS(2497),
    [anon_sym_DASH] = ACTIONS(2497),
    [anon_sym_LT] = ACTIONS(2499),
    [anon_sym_void] = ACTIONS(216),
    [anon_sym_DQUOTE] = ACTIONS(1550),
    [anon_sym_SQUOTE] = ACTIONS(1552),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1554),
    [sym_number] = ACTIONS(1556),
    [sym_this] = ACTIONS(1558),
    [sym_true] = ACTIONS(1560),
    [sym_false] = ACTIONS(1560),
    [sym_null] = ACTIONS(1560),
    [sym_undefined] = ACTIONS(1560),
    [anon_sym_readonly] = ACTIONS(1562),
    [anon_sym_QMARK] = ACTIONS(774),
    [anon_sym_any] = ACTIONS(216),
    [anon_sym_number] = ACTIONS(216),
    [anon_sym_boolean] = ACTIONS(216),
    [anon_sym_string] = ACTIONS(216),
    [anon_sym_symbol] = ACTIONS(216),
    [anon_sym_object] = ACTIONS(216),
    [anon_sym_abstract] = ACTIONS(208),
    [anon_sym_infer] = ACTIONS(210),
    [anon_sym_keyof] = ACTIONS(212),
    [anon_sym_unique] = ACTIONS(214),
    [anon_sym_unknown] = ACTIONS(216),
    [anon_sym_never] = ACTIONS(216),
    [anon_sym_LBRACE_PIPE] = ACTIONS(218),
    [sym_html_comment] = ACTIONS(5),
  },
  [1008] = {
    [sym_import] = STATE(4878),
    [sym_nested_identifier] = STATE(5474),
    [sym_string] = STATE(2994),
    [sym_formal_parameters] = STATE(5475),
    [sym_nested_type_identifier] = STATE(2939),
    [sym__type_query_member_expression_in_type_annotation] = STATE(2937),
    [sym__type_query_call_expression_in_type_annotation] = STATE(2938),
    [sym_type] = STATE(3150),
    [sym_constructor_type] = STATE(3007),
    [sym_primary_type] = STATE(2981),
    [sym_template_literal_type] = STATE(3039),
    [sym_infer_type] = STATE(3007),
    [sym_conditional_type] = STATE(3039),
    [sym_generic_type] = STATE(3039),
    [sym_type_query] = STATE(3039),
    [sym_index_type_query] = STATE(3039),
    [sym_lookup_type] = STATE(3039),
    [sym_literal_type] = STATE(3039),
    [sym__number] = STATE(3041),
    [sym_existential_type] = STATE(3039),
    [sym_flow_maybe_type] = STATE(3039),
    [sym_parenthesized_type] = STATE(3039),
    [sym_predefined_type] = STATE(3039),
    [sym_object_type] = STATE(3039),
    [sym_type_parameters] = STATE(5248),
    [sym_array_type] = STATE(3039),
    [sym_tuple_type] = STATE(3039),
    [sym_readonly_type] = STATE(3007),
    [sym_union_type] = STATE(3039),
    [sym_intersection_type] = STATE(3039),
    [sym_function_type] = STATE(3007),
    [sym_identifier] = ACTIONS(1532),
    [anon_sym_STAR] = ACTIONS(543),
    [anon_sym_LBRACE] = ACTIONS(1534),
    [anon_sym_typeof] = ACTIONS(1536),
    [anon_sym_import] = ACTIONS(1538),
    [anon_sym_const] = ACTIONS(133),
    [anon_sym_LPAREN] = ACTIONS(1540),
    [anon_sym_LBRACK] = ACTIONS(1542),
    [anon_sym_new] = ACTIONS(1544),
    [anon_sym_AMP] = ACTIONS(748),
    [anon_sym_PIPE] = ACTIONS(750),
    [anon_sym_PLUS] = ACTIONS(2497),
    [anon_sym_DASH] = ACTIONS(2497),
    [anon_sym_LT] = ACTIONS(2499),
    [anon_sym_void] = ACTIONS(216),
    [anon_sym_DQUOTE] = ACTIONS(1550),
    [anon_sym_SQUOTE] = ACTIONS(1552),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1554),
    [sym_number] = ACTIONS(1556),
    [sym_this] = ACTIONS(1558),
    [sym_true] = ACTIONS(1560),
    [sym_false] = ACTIONS(1560),
    [sym_null] = ACTIONS(1560),
    [sym_undefined] = ACTIONS(1560),
    [anon_sym_readonly] = ACTIONS(1562),
    [anon_sym_QMARK] = ACTIONS(774),
    [anon_sym_any] = ACTIONS(216),
    [anon_sym_number] = ACTIONS(216),
    [anon_sym_boolean] = ACTIONS(216),
    [anon_sym_string] = ACTIONS(216),
    [anon_sym_symbol] = ACTIONS(216),
    [anon_sym_object] = ACTIONS(216),
    [anon_sym_abstract] = ACTIONS(208),
    [anon_sym_infer] = ACTIONS(210),
    [anon_sym_keyof] = ACTIONS(212),
    [anon_sym_unique] = ACTIONS(214),
    [anon_sym_unknown] = ACTIONS(216),
    [anon_sym_never] = ACTIONS(216),
    [anon_sym_LBRACE_PIPE] = ACTIONS(218),
    [sym_html_comment] = ACTIONS(5),
  },
  [1009] = {
    [sym_import] = STATE(4878),
    [sym_nested_identifier] = STATE(5474),
    [sym_string] = STATE(2994),
    [sym_formal_parameters] = STATE(5475),
    [sym_nested_type_identifier] = STATE(2939),
    [sym__type_query_member_expression_in_type_annotation] = STATE(2937),
    [sym__type_query_call_expression_in_type_annotation] = STATE(2938),
    [sym_type] = STATE(3755),
    [sym_constructor_type] = STATE(3007),
    [sym_primary_type] = STATE(2981),
    [sym_template_literal_type] = STATE(3039),
    [sym_infer_type] = STATE(3007),
    [sym_conditional_type] = STATE(3039),
    [sym_generic_type] = STATE(3039),
    [sym_type_query] = STATE(3039),
    [sym_index_type_query] = STATE(3039),
    [sym_lookup_type] = STATE(3039),
    [sym_literal_type] = STATE(3039),
    [sym__number] = STATE(3041),
    [sym_existential_type] = STATE(3039),
    [sym_flow_maybe_type] = STATE(3039),
    [sym_parenthesized_type] = STATE(3039),
    [sym_predefined_type] = STATE(3039),
    [sym_object_type] = STATE(3039),
    [sym_type_parameters] = STATE(5248),
    [sym_array_type] = STATE(3039),
    [sym_tuple_type] = STATE(3039),
    [sym_readonly_type] = STATE(3007),
    [sym_union_type] = STATE(3039),
    [sym_intersection_type] = STATE(3039),
    [sym_function_type] = STATE(3007),
    [sym_identifier] = ACTIONS(1532),
    [anon_sym_STAR] = ACTIONS(543),
    [anon_sym_LBRACE] = ACTIONS(1534),
    [anon_sym_typeof] = ACTIONS(1536),
    [anon_sym_import] = ACTIONS(1538),
    [anon_sym_const] = ACTIONS(133),
    [anon_sym_LPAREN] = ACTIONS(1540),
    [anon_sym_LBRACK] = ACTIONS(1542),
    [anon_sym_new] = ACTIONS(1544),
    [anon_sym_AMP] = ACTIONS(748),
    [anon_sym_PIPE] = ACTIONS(750),
    [anon_sym_PLUS] = ACTIONS(2497),
    [anon_sym_DASH] = ACTIONS(2497),
    [anon_sym_LT] = ACTIONS(2499),
    [anon_sym_void] = ACTIONS(216),
    [anon_sym_DQUOTE] = ACTIONS(1550),
    [anon_sym_SQUOTE] = ACTIONS(1552),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1554),
    [sym_number] = ACTIONS(1556),
    [sym_this] = ACTIONS(1558),
    [sym_true] = ACTIONS(1560),
    [sym_false] = ACTIONS(1560),
    [sym_null] = ACTIONS(1560),
    [sym_undefined] = ACTIONS(1560),
    [anon_sym_readonly] = ACTIONS(1562),
    [anon_sym_QMARK] = ACTIONS(774),
    [anon_sym_any] = ACTIONS(216),
    [anon_sym_number] = ACTIONS(216),
    [anon_sym_boolean] = ACTIONS(216),
    [anon_sym_string] = ACTIONS(216),
    [anon_sym_symbol] = ACTIONS(216),
    [anon_sym_object] = ACTIONS(216),
    [anon_sym_abstract] = ACTIONS(208),
    [anon_sym_infer] = ACTIONS(210),
    [anon_sym_keyof] = ACTIONS(212),
    [anon_sym_unique] = ACTIONS(214),
    [anon_sym_unknown] = ACTIONS(216),
    [anon_sym_never] = ACTIONS(216),
    [anon_sym_LBRACE_PIPE] = ACTIONS(218),
    [sym_html_comment] = ACTIONS(5),
  },
  [1010] = {
    [sym_import] = STATE(4950),
    [sym_nested_identifier] = STATE(5535),
    [sym_string] = STATE(3265),
    [sym_formal_parameters] = STATE(5840),
    [sym_nested_type_identifier] = STATE(3151),
    [sym__type_query_member_expression_in_type_annotation] = STATE(3076),
    [sym__type_query_call_expression_in_type_annotation] = STATE(3200),
    [sym_type] = STATE(4254),
    [sym_constructor_type] = STATE(3271),
    [sym_primary_type] = STATE(3272),
    [sym_template_literal_type] = STATE(3273),
    [sym_infer_type] = STATE(3271),
    [sym_conditional_type] = STATE(3273),
    [sym_generic_type] = STATE(3273),
    [sym_type_query] = STATE(3273),
    [sym_index_type_query] = STATE(3273),
    [sym_lookup_type] = STATE(3273),
    [sym_literal_type] = STATE(3273),
    [sym__number] = STATE(3274),
    [sym_existential_type] = STATE(3273),
    [sym_flow_maybe_type] = STATE(3273),
    [sym_parenthesized_type] = STATE(3273),
    [sym_predefined_type] = STATE(3273),
    [sym_object_type] = STATE(3273),
    [sym_type_parameters] = STATE(5146),
    [sym_array_type] = STATE(3273),
    [sym_tuple_type] = STATE(3273),
    [sym_readonly_type] = STATE(3271),
    [sym_union_type] = STATE(3273),
    [sym_intersection_type] = STATE(3273),
    [sym_function_type] = STATE(3271),
    [sym_identifier] = ACTIONS(1606),
    [anon_sym_STAR] = ACTIONS(986),
    [anon_sym_LBRACE] = ACTIONS(1610),
    [anon_sym_typeof] = ACTIONS(1612),
    [anon_sym_import] = ACTIONS(1538),
    [anon_sym_const] = ACTIONS(992),
    [anon_sym_LPAREN] = ACTIONS(1614),
    [anon_sym_LBRACK] = ACTIONS(1616),
    [anon_sym_new] = ACTIONS(1618),
    [anon_sym_AMP] = ACTIONS(1000),
    [anon_sym_PIPE] = ACTIONS(1002),
    [anon_sym_PLUS] = ACTIONS(2983),
    [anon_sym_DASH] = ACTIONS(2983),
    [anon_sym_LT] = ACTIONS(2499),
    [anon_sym_void] = ACTIONS(1032),
    [anon_sym_DQUOTE] = ACTIONS(1626),
    [anon_sym_SQUOTE] = ACTIONS(1628),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1630),
    [sym_number] = ACTIONS(1632),
    [sym_this] = ACTIONS(1634),
    [sym_true] = ACTIONS(1636),
    [sym_false] = ACTIONS(1636),
    [sym_null] = ACTIONS(1636),
    [sym_undefined] = ACTIONS(1636),
    [anon_sym_readonly] = ACTIONS(1638),
    [anon_sym_QMARK] = ACTIONS(1020),
    [anon_sym_any] = ACTIONS(1032),
    [anon_sym_number] = ACTIONS(1032),
    [anon_sym_boolean] = ACTIONS(1032),
    [anon_sym_string] = ACTIONS(1032),
    [anon_sym_symbol] = ACTIONS(1032),
    [anon_sym_object] = ACTIONS(1032),
    [anon_sym_abstract] = ACTIONS(1024),
    [anon_sym_infer] = ACTIONS(1026),
    [anon_sym_keyof] = ACTIONS(1028),
    [anon_sym_unique] = ACTIONS(1030),
    [anon_sym_unknown] = ACTIONS(1032),
    [anon_sym_never] = ACTIONS(1032),
    [anon_sym_LBRACE_PIPE] = ACTIONS(1034),
    [sym_html_comment] = ACTIONS(5),
  },
  [1011] = {
    [sym_import] = STATE(4878),
    [sym_nested_identifier] = STATE(5474),
    [sym_string] = STATE(2994),
    [sym_formal_parameters] = STATE(5475),
    [sym_nested_type_identifier] = STATE(2939),
    [sym__type_query_member_expression_in_type_annotation] = STATE(2937),
    [sym__type_query_call_expression_in_type_annotation] = STATE(2938),
    [sym_type] = STATE(3153),
    [sym_constructor_type] = STATE(3007),
    [sym_primary_type] = STATE(2981),
    [sym_template_literal_type] = STATE(3039),
    [sym_infer_type] = STATE(3007),
    [sym_conditional_type] = STATE(3039),
    [sym_generic_type] = STATE(3039),
    [sym_type_query] = STATE(3039),
    [sym_index_type_query] = STATE(3039),
    [sym_lookup_type] = STATE(3039),
    [sym_literal_type] = STATE(3039),
    [sym__number] = STATE(3041),
    [sym_existential_type] = STATE(3039),
    [sym_flow_maybe_type] = STATE(3039),
    [sym_parenthesized_type] = STATE(3039),
    [sym_predefined_type] = STATE(3039),
    [sym_object_type] = STATE(3039),
    [sym_type_parameters] = STATE(5248),
    [sym_array_type] = STATE(3039),
    [sym_tuple_type] = STATE(3039),
    [sym_readonly_type] = STATE(3007),
    [sym_union_type] = STATE(3039),
    [sym_intersection_type] = STATE(3039),
    [sym_function_type] = STATE(3007),
    [sym_identifier] = ACTIONS(1532),
    [anon_sym_STAR] = ACTIONS(543),
    [anon_sym_LBRACE] = ACTIONS(1534),
    [anon_sym_typeof] = ACTIONS(1536),
    [anon_sym_import] = ACTIONS(1538),
    [anon_sym_const] = ACTIONS(133),
    [anon_sym_LPAREN] = ACTIONS(1540),
    [anon_sym_LBRACK] = ACTIONS(1542),
    [anon_sym_new] = ACTIONS(1544),
    [anon_sym_AMP] = ACTIONS(748),
    [anon_sym_PIPE] = ACTIONS(750),
    [anon_sym_PLUS] = ACTIONS(2497),
    [anon_sym_DASH] = ACTIONS(2497),
    [anon_sym_LT] = ACTIONS(2499),
    [anon_sym_void] = ACTIONS(216),
    [anon_sym_DQUOTE] = ACTIONS(1550),
    [anon_sym_SQUOTE] = ACTIONS(1552),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1554),
    [sym_number] = ACTIONS(1556),
    [sym_this] = ACTIONS(1558),
    [sym_true] = ACTIONS(1560),
    [sym_false] = ACTIONS(1560),
    [sym_null] = ACTIONS(1560),
    [sym_undefined] = ACTIONS(1560),
    [anon_sym_readonly] = ACTIONS(1562),
    [anon_sym_QMARK] = ACTIONS(774),
    [anon_sym_any] = ACTIONS(216),
    [anon_sym_number] = ACTIONS(216),
    [anon_sym_boolean] = ACTIONS(216),
    [anon_sym_string] = ACTIONS(216),
    [anon_sym_symbol] = ACTIONS(216),
    [anon_sym_object] = ACTIONS(216),
    [anon_sym_abstract] = ACTIONS(208),
    [anon_sym_infer] = ACTIONS(210),
    [anon_sym_keyof] = ACTIONS(212),
    [anon_sym_unique] = ACTIONS(214),
    [anon_sym_unknown] = ACTIONS(216),
    [anon_sym_never] = ACTIONS(216),
    [anon_sym_LBRACE_PIPE] = ACTIONS(218),
    [sym_html_comment] = ACTIONS(5),
  },
  [1012] = {
    [sym_import] = STATE(4878),
    [sym_nested_identifier] = STATE(5474),
    [sym_string] = STATE(2994),
    [sym_formal_parameters] = STATE(5475),
    [sym_nested_type_identifier] = STATE(2939),
    [sym__type_query_member_expression_in_type_annotation] = STATE(2937),
    [sym__type_query_call_expression_in_type_annotation] = STATE(2938),
    [sym_type] = STATE(4622),
    [sym_constructor_type] = STATE(3007),
    [sym_primary_type] = STATE(2949),
    [sym_template_literal_type] = STATE(3039),
    [sym_infer_type] = STATE(3007),
    [sym_conditional_type] = STATE(3039),
    [sym_generic_type] = STATE(3039),
    [sym_type_query] = STATE(3039),
    [sym_index_type_query] = STATE(3039),
    [sym_lookup_type] = STATE(3039),
    [sym_literal_type] = STATE(3039),
    [sym__number] = STATE(3041),
    [sym_existential_type] = STATE(3039),
    [sym_flow_maybe_type] = STATE(3039),
    [sym_parenthesized_type] = STATE(3039),
    [sym_predefined_type] = STATE(3039),
    [sym_object_type] = STATE(3039),
    [sym_type_parameters] = STATE(5248),
    [sym_array_type] = STATE(3039),
    [sym_tuple_type] = STATE(3039),
    [sym_readonly_type] = STATE(3007),
    [sym_union_type] = STATE(3039),
    [sym_intersection_type] = STATE(3039),
    [sym_function_type] = STATE(3007),
    [sym_identifier] = ACTIONS(1532),
    [anon_sym_STAR] = ACTIONS(543),
    [anon_sym_LBRACE] = ACTIONS(1534),
    [anon_sym_typeof] = ACTIONS(1536),
    [anon_sym_import] = ACTIONS(1538),
    [anon_sym_const] = ACTIONS(133),
    [anon_sym_LPAREN] = ACTIONS(1540),
    [anon_sym_LBRACK] = ACTIONS(1542),
    [anon_sym_new] = ACTIONS(1544),
    [anon_sym_AMP] = ACTIONS(748),
    [anon_sym_PIPE] = ACTIONS(750),
    [anon_sym_PLUS] = ACTIONS(2497),
    [anon_sym_DASH] = ACTIONS(2497),
    [anon_sym_LT] = ACTIONS(2499),
    [anon_sym_void] = ACTIONS(216),
    [anon_sym_DQUOTE] = ACTIONS(1550),
    [anon_sym_SQUOTE] = ACTIONS(1552),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1554),
    [sym_number] = ACTIONS(1556),
    [sym_this] = ACTIONS(1558),
    [sym_true] = ACTIONS(1560),
    [sym_false] = ACTIONS(1560),
    [sym_null] = ACTIONS(1560),
    [sym_undefined] = ACTIONS(1560),
    [anon_sym_readonly] = ACTIONS(1562),
    [anon_sym_QMARK] = ACTIONS(774),
    [anon_sym_any] = ACTIONS(216),
    [anon_sym_number] = ACTIONS(216),
    [anon_sym_boolean] = ACTIONS(216),
    [anon_sym_string] = ACTIONS(216),
    [anon_sym_symbol] = ACTIONS(216),
    [anon_sym_object] = ACTIONS(216),
    [anon_sym_abstract] = ACTIONS(208),
    [anon_sym_infer] = ACTIONS(210),
    [anon_sym_keyof] = ACTIONS(212),
    [anon_sym_unique] = ACTIONS(214),
    [anon_sym_unknown] = ACTIONS(216),
    [anon_sym_never] = ACTIONS(216),
    [anon_sym_LBRACE_PIPE] = ACTIONS(218),
    [sym_html_comment] = ACTIONS(5),
  },
  [1013] = {
    [sym_import] = STATE(4878),
    [sym_nested_identifier] = STATE(5474),
    [sym_string] = STATE(2994),
    [sym_formal_parameters] = STATE(5475),
    [sym_nested_type_identifier] = STATE(2939),
    [sym__type_query_member_expression_in_type_annotation] = STATE(2937),
    [sym__type_query_call_expression_in_type_annotation] = STATE(2938),
    [sym_type] = STATE(4622),
    [sym_constructor_type] = STATE(3007),
    [sym_primary_type] = STATE(2971),
    [sym_template_literal_type] = STATE(3039),
    [sym_infer_type] = STATE(3007),
    [sym_conditional_type] = STATE(3039),
    [sym_generic_type] = STATE(3039),
    [sym_type_query] = STATE(3039),
    [sym_index_type_query] = STATE(3039),
    [sym_lookup_type] = STATE(3039),
    [sym_literal_type] = STATE(3039),
    [sym__number] = STATE(3041),
    [sym_existential_type] = STATE(3039),
    [sym_flow_maybe_type] = STATE(3039),
    [sym_parenthesized_type] = STATE(3039),
    [sym_predefined_type] = STATE(3039),
    [sym_object_type] = STATE(3039),
    [sym_type_parameters] = STATE(5248),
    [sym_array_type] = STATE(3039),
    [sym_tuple_type] = STATE(3039),
    [sym_readonly_type] = STATE(3007),
    [sym_union_type] = STATE(3039),
    [sym_intersection_type] = STATE(3039),
    [sym_function_type] = STATE(3007),
    [sym_identifier] = ACTIONS(1532),
    [anon_sym_STAR] = ACTIONS(543),
    [anon_sym_LBRACE] = ACTIONS(1534),
    [anon_sym_typeof] = ACTIONS(1536),
    [anon_sym_import] = ACTIONS(1538),
    [anon_sym_const] = ACTIONS(133),
    [anon_sym_LPAREN] = ACTIONS(1540),
    [anon_sym_LBRACK] = ACTIONS(1542),
    [anon_sym_new] = ACTIONS(1544),
    [anon_sym_AMP] = ACTIONS(748),
    [anon_sym_PIPE] = ACTIONS(750),
    [anon_sym_PLUS] = ACTIONS(2497),
    [anon_sym_DASH] = ACTIONS(2497),
    [anon_sym_LT] = ACTIONS(2499),
    [anon_sym_void] = ACTIONS(216),
    [anon_sym_DQUOTE] = ACTIONS(1550),
    [anon_sym_SQUOTE] = ACTIONS(1552),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1554),
    [sym_number] = ACTIONS(1556),
    [sym_this] = ACTIONS(1558),
    [sym_true] = ACTIONS(1560),
    [sym_false] = ACTIONS(1560),
    [sym_null] = ACTIONS(1560),
    [sym_undefined] = ACTIONS(1560),
    [anon_sym_readonly] = ACTIONS(1562),
    [anon_sym_QMARK] = ACTIONS(774),
    [anon_sym_any] = ACTIONS(216),
    [anon_sym_number] = ACTIONS(216),
    [anon_sym_boolean] = ACTIONS(216),
    [anon_sym_string] = ACTIONS(216),
    [anon_sym_symbol] = ACTIONS(216),
    [anon_sym_object] = ACTIONS(216),
    [anon_sym_abstract] = ACTIONS(208),
    [anon_sym_infer] = ACTIONS(210),
    [anon_sym_keyof] = ACTIONS(212),
    [anon_sym_unique] = ACTIONS(214),
    [anon_sym_unknown] = ACTIONS(216),
    [anon_sym_never] = ACTIONS(216),
    [anon_sym_LBRACE_PIPE] = ACTIONS(218),
    [sym_html_comment] = ACTIONS(5),
  },
  [1014] = {
    [sym_import] = STATE(4878),
    [sym_nested_identifier] = STATE(5474),
    [sym_string] = STATE(2994),
    [sym_formal_parameters] = STATE(5475),
    [sym_nested_type_identifier] = STATE(2939),
    [sym__type_query_member_expression_in_type_annotation] = STATE(2937),
    [sym__type_query_call_expression_in_type_annotation] = STATE(2938),
    [sym_type] = STATE(3768),
    [sym_constructor_type] = STATE(3007),
    [sym_primary_type] = STATE(2981),
    [sym_template_literal_type] = STATE(3039),
    [sym_infer_type] = STATE(3007),
    [sym_conditional_type] = STATE(3039),
    [sym_generic_type] = STATE(3039),
    [sym_type_query] = STATE(3039),
    [sym_index_type_query] = STATE(3039),
    [sym_lookup_type] = STATE(3039),
    [sym_literal_type] = STATE(3039),
    [sym__number] = STATE(3041),
    [sym_existential_type] = STATE(3039),
    [sym_flow_maybe_type] = STATE(3039),
    [sym_parenthesized_type] = STATE(3039),
    [sym_predefined_type] = STATE(3039),
    [sym_object_type] = STATE(3039),
    [sym_type_parameters] = STATE(5248),
    [sym_array_type] = STATE(3039),
    [sym_tuple_type] = STATE(3039),
    [sym_readonly_type] = STATE(3007),
    [sym_union_type] = STATE(3039),
    [sym_intersection_type] = STATE(3039),
    [sym_function_type] = STATE(3007),
    [sym_identifier] = ACTIONS(1532),
    [anon_sym_STAR] = ACTIONS(543),
    [anon_sym_LBRACE] = ACTIONS(1534),
    [anon_sym_typeof] = ACTIONS(1536),
    [anon_sym_import] = ACTIONS(1538),
    [anon_sym_const] = ACTIONS(133),
    [anon_sym_LPAREN] = ACTIONS(1540),
    [anon_sym_LBRACK] = ACTIONS(1542),
    [anon_sym_new] = ACTIONS(1544),
    [anon_sym_AMP] = ACTIONS(748),
    [anon_sym_PIPE] = ACTIONS(750),
    [anon_sym_PLUS] = ACTIONS(2497),
    [anon_sym_DASH] = ACTIONS(2497),
    [anon_sym_LT] = ACTIONS(2499),
    [anon_sym_void] = ACTIONS(216),
    [anon_sym_DQUOTE] = ACTIONS(1550),
    [anon_sym_SQUOTE] = ACTIONS(1552),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1554),
    [sym_number] = ACTIONS(1556),
    [sym_this] = ACTIONS(1558),
    [sym_true] = ACTIONS(1560),
    [sym_false] = ACTIONS(1560),
    [sym_null] = ACTIONS(1560),
    [sym_undefined] = ACTIONS(1560),
    [anon_sym_readonly] = ACTIONS(1562),
    [anon_sym_QMARK] = ACTIONS(774),
    [anon_sym_any] = ACTIONS(216),
    [anon_sym_number] = ACTIONS(216),
    [anon_sym_boolean] = ACTIONS(216),
    [anon_sym_string] = ACTIONS(216),
    [anon_sym_symbol] = ACTIONS(216),
    [anon_sym_object] = ACTIONS(216),
    [anon_sym_abstract] = ACTIONS(208),
    [anon_sym_infer] = ACTIONS(210),
    [anon_sym_keyof] = ACTIONS(212),
    [anon_sym_unique] = ACTIONS(214),
    [anon_sym_unknown] = ACTIONS(216),
    [anon_sym_never] = ACTIONS(216),
    [anon_sym_LBRACE_PIPE] = ACTIONS(218),
    [sym_html_comment] = ACTIONS(5),
  },
  [1015] = {
    [sym_import] = STATE(4650),
    [sym_nested_identifier] = STATE(5567),
    [sym_string] = STATE(1975),
    [sym_formal_parameters] = STATE(5527),
    [sym_nested_type_identifier] = STATE(1865),
    [sym__type_query_member_expression_in_type_annotation] = STATE(1781),
    [sym__type_query_call_expression_in_type_annotation] = STATE(1911),
    [sym_type] = STATE(1998),
    [sym_constructor_type] = STATE(1912),
    [sym_primary_type] = STATE(1915),
    [sym_template_literal_type] = STATE(1916),
    [sym_infer_type] = STATE(1912),
    [sym_conditional_type] = STATE(1916),
    [sym_generic_type] = STATE(1916),
    [sym_type_query] = STATE(1916),
    [sym_index_type_query] = STATE(1916),
    [sym_lookup_type] = STATE(1916),
    [sym_literal_type] = STATE(1916),
    [sym__number] = STATE(1918),
    [sym_existential_type] = STATE(1916),
    [sym_flow_maybe_type] = STATE(1916),
    [sym_parenthesized_type] = STATE(1916),
    [sym_predefined_type] = STATE(1916),
    [sym_object_type] = STATE(1916),
    [sym_type_parameters] = STATE(5243),
    [sym_array_type] = STATE(1916),
    [sym_tuple_type] = STATE(1916),
    [sym_readonly_type] = STATE(1912),
    [sym_union_type] = STATE(1916),
    [sym_intersection_type] = STATE(1916),
    [sym_function_type] = STATE(1912),
    [sym_identifier] = ACTIONS(3255),
    [anon_sym_STAR] = ACTIONS(3047),
    [anon_sym_LBRACE] = ACTIONS(3049),
    [anon_sym_typeof] = ACTIONS(3051),
    [anon_sym_import] = ACTIONS(1538),
    [anon_sym_const] = ACTIONS(3053),
    [anon_sym_LPAREN] = ACTIONS(3055),
    [anon_sym_LBRACK] = ACTIONS(3057),
    [anon_sym_new] = ACTIONS(3059),
    [anon_sym_AMP] = ACTIONS(3061),
    [anon_sym_PIPE] = ACTIONS(3063),
    [anon_sym_PLUS] = ACTIONS(3065),
    [anon_sym_DASH] = ACTIONS(3065),
    [anon_sym_LT] = ACTIONS(2499),
    [anon_sym_void] = ACTIONS(3067),
    [anon_sym_DQUOTE] = ACTIONS(83),
    [anon_sym_SQUOTE] = ACTIONS(85),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(3069),
    [sym_number] = ACTIONS(3071),
    [sym_this] = ACTIONS(3257),
    [sym_true] = ACTIONS(3075),
    [sym_false] = ACTIONS(3075),
    [sym_null] = ACTIONS(3075),
    [sym_undefined] = ACTIONS(3075),
    [anon_sym_readonly] = ACTIONS(3077),
    [anon_sym_QMARK] = ACTIONS(3079),
    [anon_sym_any] = ACTIONS(3067),
    [anon_sym_number] = ACTIONS(3067),
    [anon_sym_boolean] = ACTIONS(3067),
    [anon_sym_string] = ACTIONS(3067),
    [anon_sym_symbol] = ACTIONS(3067),
    [anon_sym_object] = ACTIONS(3067),
    [anon_sym_abstract] = ACTIONS(3081),
    [anon_sym_infer] = ACTIONS(3085),
    [anon_sym_keyof] = ACTIONS(3087),
    [anon_sym_unique] = ACTIONS(3089),
    [anon_sym_unknown] = ACTIONS(3067),
    [anon_sym_never] = ACTIONS(3067),
    [anon_sym_LBRACE_PIPE] = ACTIONS(3091),
    [sym_html_comment] = ACTIONS(5),
  },
  [1016] = {
    [sym_import] = STATE(4650),
    [sym_nested_identifier] = STATE(5567),
    [sym_string] = STATE(1975),
    [sym_formal_parameters] = STATE(5527),
    [sym_nested_type_identifier] = STATE(1865),
    [sym__type_query_member_expression_in_type_annotation] = STATE(1781),
    [sym__type_query_call_expression_in_type_annotation] = STATE(1911),
    [sym_type] = STATE(1999),
    [sym_constructor_type] = STATE(1912),
    [sym_primary_type] = STATE(1915),
    [sym_template_literal_type] = STATE(1916),
    [sym_infer_type] = STATE(1912),
    [sym_conditional_type] = STATE(1916),
    [sym_generic_type] = STATE(1916),
    [sym_type_query] = STATE(1916),
    [sym_index_type_query] = STATE(1916),
    [sym_lookup_type] = STATE(1916),
    [sym_literal_type] = STATE(1916),
    [sym__number] = STATE(1918),
    [sym_existential_type] = STATE(1916),
    [sym_flow_maybe_type] = STATE(1916),
    [sym_parenthesized_type] = STATE(1916),
    [sym_predefined_type] = STATE(1916),
    [sym_object_type] = STATE(1916),
    [sym_type_parameters] = STATE(5243),
    [sym_array_type] = STATE(1916),
    [sym_tuple_type] = STATE(1916),
    [sym_readonly_type] = STATE(1912),
    [sym_union_type] = STATE(1916),
    [sym_intersection_type] = STATE(1916),
    [sym_function_type] = STATE(1912),
    [sym_identifier] = ACTIONS(3255),
    [anon_sym_STAR] = ACTIONS(3047),
    [anon_sym_LBRACE] = ACTIONS(3049),
    [anon_sym_typeof] = ACTIONS(3051),
    [anon_sym_import] = ACTIONS(1538),
    [anon_sym_const] = ACTIONS(3053),
    [anon_sym_LPAREN] = ACTIONS(3055),
    [anon_sym_LBRACK] = ACTIONS(3057),
    [anon_sym_new] = ACTIONS(3059),
    [anon_sym_AMP] = ACTIONS(3061),
    [anon_sym_PIPE] = ACTIONS(3063),
    [anon_sym_PLUS] = ACTIONS(3065),
    [anon_sym_DASH] = ACTIONS(3065),
    [anon_sym_LT] = ACTIONS(2499),
    [anon_sym_void] = ACTIONS(3067),
    [anon_sym_DQUOTE] = ACTIONS(83),
    [anon_sym_SQUOTE] = ACTIONS(85),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(3069),
    [sym_number] = ACTIONS(3071),
    [sym_this] = ACTIONS(3257),
    [sym_true] = ACTIONS(3075),
    [sym_false] = ACTIONS(3075),
    [sym_null] = ACTIONS(3075),
    [sym_undefined] = ACTIONS(3075),
    [anon_sym_readonly] = ACTIONS(3077),
    [anon_sym_QMARK] = ACTIONS(3079),
    [anon_sym_any] = ACTIONS(3067),
    [anon_sym_number] = ACTIONS(3067),
    [anon_sym_boolean] = ACTIONS(3067),
    [anon_sym_string] = ACTIONS(3067),
    [anon_sym_symbol] = ACTIONS(3067),
    [anon_sym_object] = ACTIONS(3067),
    [anon_sym_abstract] = ACTIONS(3081),
    [anon_sym_infer] = ACTIONS(3085),
    [anon_sym_keyof] = ACTIONS(3087),
    [anon_sym_unique] = ACTIONS(3089),
    [anon_sym_unknown] = ACTIONS(3067),
    [anon_sym_never] = ACTIONS(3067),
    [anon_sym_LBRACE_PIPE] = ACTIONS(3091),
    [sym_html_comment] = ACTIONS(5),
  },
  [1017] = {
    [sym_import] = STATE(4650),
    [sym_nested_identifier] = STATE(5567),
    [sym_string] = STATE(1975),
    [sym_formal_parameters] = STATE(5527),
    [sym_nested_type_identifier] = STATE(1865),
    [sym__type_query_member_expression_in_type_annotation] = STATE(1781),
    [sym__type_query_call_expression_in_type_annotation] = STATE(1911),
    [sym_type] = STATE(2033),
    [sym_constructor_type] = STATE(1912),
    [sym_primary_type] = STATE(1915),
    [sym_template_literal_type] = STATE(1916),
    [sym_infer_type] = STATE(1912),
    [sym_conditional_type] = STATE(1916),
    [sym_generic_type] = STATE(1916),
    [sym_type_query] = STATE(1916),
    [sym_index_type_query] = STATE(1916),
    [sym_lookup_type] = STATE(1916),
    [sym_literal_type] = STATE(1916),
    [sym__number] = STATE(1918),
    [sym_existential_type] = STATE(1916),
    [sym_flow_maybe_type] = STATE(1916),
    [sym_parenthesized_type] = STATE(1916),
    [sym_predefined_type] = STATE(1916),
    [sym_object_type] = STATE(1916),
    [sym_type_parameters] = STATE(5243),
    [sym_array_type] = STATE(1916),
    [sym_tuple_type] = STATE(1916),
    [sym_readonly_type] = STATE(1912),
    [sym_union_type] = STATE(1916),
    [sym_intersection_type] = STATE(1916),
    [sym_function_type] = STATE(1912),
    [sym_identifier] = ACTIONS(3255),
    [anon_sym_STAR] = ACTIONS(3047),
    [anon_sym_LBRACE] = ACTIONS(3049),
    [anon_sym_typeof] = ACTIONS(3051),
    [anon_sym_import] = ACTIONS(1538),
    [anon_sym_const] = ACTIONS(3053),
    [anon_sym_LPAREN] = ACTIONS(3055),
    [anon_sym_LBRACK] = ACTIONS(3057),
    [anon_sym_new] = ACTIONS(3059),
    [anon_sym_AMP] = ACTIONS(3061),
    [anon_sym_PIPE] = ACTIONS(3063),
    [anon_sym_PLUS] = ACTIONS(3065),
    [anon_sym_DASH] = ACTIONS(3065),
    [anon_sym_LT] = ACTIONS(2499),
    [anon_sym_void] = ACTIONS(3067),
    [anon_sym_DQUOTE] = ACTIONS(83),
    [anon_sym_SQUOTE] = ACTIONS(85),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(3069),
    [sym_number] = ACTIONS(3071),
    [sym_this] = ACTIONS(3257),
    [sym_true] = ACTIONS(3075),
    [sym_false] = ACTIONS(3075),
    [sym_null] = ACTIONS(3075),
    [sym_undefined] = ACTIONS(3075),
    [anon_sym_readonly] = ACTIONS(3077),
    [anon_sym_QMARK] = ACTIONS(3079),
    [anon_sym_any] = ACTIONS(3067),
    [anon_sym_number] = ACTIONS(3067),
    [anon_sym_boolean] = ACTIONS(3067),
    [anon_sym_string] = ACTIONS(3067),
    [anon_sym_symbol] = ACTIONS(3067),
    [anon_sym_object] = ACTIONS(3067),
    [anon_sym_abstract] = ACTIONS(3081),
    [anon_sym_infer] = ACTIONS(3085),
    [anon_sym_keyof] = ACTIONS(3087),
    [anon_sym_unique] = ACTIONS(3089),
    [anon_sym_unknown] = ACTIONS(3067),
    [anon_sym_never] = ACTIONS(3067),
    [anon_sym_LBRACE_PIPE] = ACTIONS(3091),
    [sym_html_comment] = ACTIONS(5),
  },
  [1018] = {
    [sym_import] = STATE(4650),
    [sym_nested_identifier] = STATE(5567),
    [sym_string] = STATE(1975),
    [sym_formal_parameters] = STATE(5527),
    [sym_nested_type_identifier] = STATE(1865),
    [sym__type_query_member_expression_in_type_annotation] = STATE(1781),
    [sym__type_query_call_expression_in_type_annotation] = STATE(1911),
    [sym_type] = STATE(2036),
    [sym_constructor_type] = STATE(1912),
    [sym_primary_type] = STATE(1915),
    [sym_template_literal_type] = STATE(1916),
    [sym_infer_type] = STATE(1912),
    [sym_conditional_type] = STATE(1916),
    [sym_generic_type] = STATE(1916),
    [sym_type_query] = STATE(1916),
    [sym_index_type_query] = STATE(1916),
    [sym_lookup_type] = STATE(1916),
    [sym_literal_type] = STATE(1916),
    [sym__number] = STATE(1918),
    [sym_existential_type] = STATE(1916),
    [sym_flow_maybe_type] = STATE(1916),
    [sym_parenthesized_type] = STATE(1916),
    [sym_predefined_type] = STATE(1916),
    [sym_object_type] = STATE(1916),
    [sym_type_parameters] = STATE(5243),
    [sym_array_type] = STATE(1916),
    [sym_tuple_type] = STATE(1916),
    [sym_readonly_type] = STATE(1912),
    [sym_union_type] = STATE(1916),
    [sym_intersection_type] = STATE(1916),
    [sym_function_type] = STATE(1912),
    [sym_identifier] = ACTIONS(3255),
    [anon_sym_STAR] = ACTIONS(3047),
    [anon_sym_LBRACE] = ACTIONS(3049),
    [anon_sym_typeof] = ACTIONS(3051),
    [anon_sym_import] = ACTIONS(1538),
    [anon_sym_const] = ACTIONS(3053),
    [anon_sym_LPAREN] = ACTIONS(3055),
    [anon_sym_LBRACK] = ACTIONS(3057),
    [anon_sym_new] = ACTIONS(3059),
    [anon_sym_AMP] = ACTIONS(3061),
    [anon_sym_PIPE] = ACTIONS(3063),
    [anon_sym_PLUS] = ACTIONS(3065),
    [anon_sym_DASH] = ACTIONS(3065),
    [anon_sym_LT] = ACTIONS(2499),
    [anon_sym_void] = ACTIONS(3067),
    [anon_sym_DQUOTE] = ACTIONS(83),
    [anon_sym_SQUOTE] = ACTIONS(85),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(3069),
    [sym_number] = ACTIONS(3071),
    [sym_this] = ACTIONS(3257),
    [sym_true] = ACTIONS(3075),
    [sym_false] = ACTIONS(3075),
    [sym_null] = ACTIONS(3075),
    [sym_undefined] = ACTIONS(3075),
    [anon_sym_readonly] = ACTIONS(3077),
    [anon_sym_QMARK] = ACTIONS(3079),
    [anon_sym_any] = ACTIONS(3067),
    [anon_sym_number] = ACTIONS(3067),
    [anon_sym_boolean] = ACTIONS(3067),
    [anon_sym_string] = ACTIONS(3067),
    [anon_sym_symbol] = ACTIONS(3067),
    [anon_sym_object] = ACTIONS(3067),
    [anon_sym_abstract] = ACTIONS(3081),
    [anon_sym_infer] = ACTIONS(3085),
    [anon_sym_keyof] = ACTIONS(3087),
    [anon_sym_unique] = ACTIONS(3089),
    [anon_sym_unknown] = ACTIONS(3067),
    [anon_sym_never] = ACTIONS(3067),
    [anon_sym_LBRACE_PIPE] = ACTIONS(3091),
    [sym_html_comment] = ACTIONS(5),
  },
  [1019] = {
    [sym_import] = STATE(4878),
    [sym_nested_identifier] = STATE(5474),
    [sym_string] = STATE(2994),
    [sym_formal_parameters] = STATE(5475),
    [sym_nested_type_identifier] = STATE(2939),
    [sym__type_query_member_expression_in_type_annotation] = STATE(2937),
    [sym__type_query_call_expression_in_type_annotation] = STATE(2938),
    [sym_type] = STATE(3758),
    [sym_constructor_type] = STATE(3007),
    [sym_primary_type] = STATE(2981),
    [sym_template_literal_type] = STATE(3039),
    [sym_infer_type] = STATE(3007),
    [sym_conditional_type] = STATE(3039),
    [sym_generic_type] = STATE(3039),
    [sym_type_query] = STATE(3039),
    [sym_index_type_query] = STATE(3039),
    [sym_lookup_type] = STATE(3039),
    [sym_literal_type] = STATE(3039),
    [sym__number] = STATE(3041),
    [sym_existential_type] = STATE(3039),
    [sym_flow_maybe_type] = STATE(3039),
    [sym_parenthesized_type] = STATE(3039),
    [sym_predefined_type] = STATE(3039),
    [sym_object_type] = STATE(3039),
    [sym_type_parameters] = STATE(5248),
    [sym_array_type] = STATE(3039),
    [sym_tuple_type] = STATE(3039),
    [sym_readonly_type] = STATE(3007),
    [sym_union_type] = STATE(3039),
    [sym_intersection_type] = STATE(3039),
    [sym_function_type] = STATE(3007),
    [sym_identifier] = ACTIONS(1532),
    [anon_sym_STAR] = ACTIONS(543),
    [anon_sym_LBRACE] = ACTIONS(1534),
    [anon_sym_typeof] = ACTIONS(1536),
    [anon_sym_import] = ACTIONS(1538),
    [anon_sym_const] = ACTIONS(133),
    [anon_sym_LPAREN] = ACTIONS(1540),
    [anon_sym_LBRACK] = ACTIONS(1542),
    [anon_sym_new] = ACTIONS(1544),
    [anon_sym_AMP] = ACTIONS(748),
    [anon_sym_PIPE] = ACTIONS(750),
    [anon_sym_PLUS] = ACTIONS(2497),
    [anon_sym_DASH] = ACTIONS(2497),
    [anon_sym_LT] = ACTIONS(2499),
    [anon_sym_void] = ACTIONS(216),
    [anon_sym_DQUOTE] = ACTIONS(1550),
    [anon_sym_SQUOTE] = ACTIONS(1552),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1554),
    [sym_number] = ACTIONS(1556),
    [sym_this] = ACTIONS(1558),
    [sym_true] = ACTIONS(1560),
    [sym_false] = ACTIONS(1560),
    [sym_null] = ACTIONS(1560),
    [sym_undefined] = ACTIONS(1560),
    [anon_sym_readonly] = ACTIONS(1562),
    [anon_sym_QMARK] = ACTIONS(774),
    [anon_sym_any] = ACTIONS(216),
    [anon_sym_number] = ACTIONS(216),
    [anon_sym_boolean] = ACTIONS(216),
    [anon_sym_string] = ACTIONS(216),
    [anon_sym_symbol] = ACTIONS(216),
    [anon_sym_object] = ACTIONS(216),
    [anon_sym_abstract] = ACTIONS(208),
    [anon_sym_infer] = ACTIONS(210),
    [anon_sym_keyof] = ACTIONS(212),
    [anon_sym_unique] = ACTIONS(214),
    [anon_sym_unknown] = ACTIONS(216),
    [anon_sym_never] = ACTIONS(216),
    [anon_sym_LBRACE_PIPE] = ACTIONS(218),
    [sym_html_comment] = ACTIONS(5),
  },
  [1020] = {
    [sym_import] = STATE(4578),
    [sym_nested_identifier] = STATE(5796),
    [sym_string] = STATE(3437),
    [sym_formal_parameters] = STATE(5519),
    [sym_nested_type_identifier] = STATE(3278),
    [sym__type_query_member_expression_in_type_annotation] = STATE(3181),
    [sym__type_query_call_expression_in_type_annotation] = STATE(3311),
    [sym_type] = STATE(3384),
    [sym_constructor_type] = STATE(3448),
    [sym_primary_type] = STATE(3450),
    [sym_template_literal_type] = STATE(3453),
    [sym_infer_type] = STATE(3448),
    [sym_conditional_type] = STATE(3453),
    [sym_generic_type] = STATE(3453),
    [sym_type_query] = STATE(3453),
    [sym_index_type_query] = STATE(3453),
    [sym_lookup_type] = STATE(3453),
    [sym_literal_type] = STATE(3453),
    [sym__number] = STATE(3454),
    [sym_existential_type] = STATE(3453),
    [sym_flow_maybe_type] = STATE(3453),
    [sym_parenthesized_type] = STATE(3453),
    [sym_predefined_type] = STATE(3453),
    [sym_object_type] = STATE(3453),
    [sym_type_parameters] = STATE(5251),
    [sym_array_type] = STATE(3453),
    [sym_tuple_type] = STATE(3453),
    [sym_readonly_type] = STATE(3448),
    [sym_union_type] = STATE(3453),
    [sym_intersection_type] = STATE(3453),
    [sym_function_type] = STATE(3448),
    [sym_identifier] = ACTIONS(3259),
    [anon_sym_STAR] = ACTIONS(2995),
    [anon_sym_LBRACE] = ACTIONS(2997),
    [anon_sym_typeof] = ACTIONS(2999),
    [anon_sym_import] = ACTIONS(1538),
    [anon_sym_const] = ACTIONS(3001),
    [anon_sym_LPAREN] = ACTIONS(3003),
    [anon_sym_LBRACK] = ACTIONS(3005),
    [anon_sym_new] = ACTIONS(3007),
    [anon_sym_AMP] = ACTIONS(3009),
    [anon_sym_PIPE] = ACTIONS(3011),
    [anon_sym_PLUS] = ACTIONS(3013),
    [anon_sym_DASH] = ACTIONS(3013),
    [anon_sym_LT] = ACTIONS(2499),
    [anon_sym_void] = ACTIONS(3015),
    [anon_sym_DQUOTE] = ACTIONS(3017),
    [anon_sym_SQUOTE] = ACTIONS(3019),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(3021),
    [sym_number] = ACTIONS(3023),
    [sym_this] = ACTIONS(3261),
    [sym_true] = ACTIONS(3027),
    [sym_false] = ACTIONS(3027),
    [sym_null] = ACTIONS(3027),
    [sym_undefined] = ACTIONS(3027),
    [anon_sym_readonly] = ACTIONS(3029),
    [anon_sym_QMARK] = ACTIONS(3031),
    [anon_sym_any] = ACTIONS(3015),
    [anon_sym_number] = ACTIONS(3015),
    [anon_sym_boolean] = ACTIONS(3015),
    [anon_sym_string] = ACTIONS(3015),
    [anon_sym_symbol] = ACTIONS(3015),
    [anon_sym_object] = ACTIONS(3015),
    [anon_sym_abstract] = ACTIONS(3033),
    [anon_sym_infer] = ACTIONS(3037),
    [anon_sym_keyof] = ACTIONS(3039),
    [anon_sym_unique] = ACTIONS(3041),
    [anon_sym_unknown] = ACTIONS(3015),
    [anon_sym_never] = ACTIONS(3015),
    [anon_sym_LBRACE_PIPE] = ACTIONS(3043),
    [sym_html_comment] = ACTIONS(5),
  },
  [1021] = {
    [sym_import] = STATE(4578),
    [sym_nested_identifier] = STATE(5796),
    [sym_string] = STATE(3437),
    [sym_formal_parameters] = STATE(5519),
    [sym_nested_type_identifier] = STATE(3278),
    [sym__type_query_member_expression_in_type_annotation] = STATE(3181),
    [sym__type_query_call_expression_in_type_annotation] = STATE(3311),
    [sym_type] = STATE(3354),
    [sym_constructor_type] = STATE(3448),
    [sym_primary_type] = STATE(3450),
    [sym_template_literal_type] = STATE(3453),
    [sym_infer_type] = STATE(3448),
    [sym_conditional_type] = STATE(3453),
    [sym_generic_type] = STATE(3453),
    [sym_type_query] = STATE(3453),
    [sym_index_type_query] = STATE(3453),
    [sym_lookup_type] = STATE(3453),
    [sym_literal_type] = STATE(3453),
    [sym__number] = STATE(3454),
    [sym_existential_type] = STATE(3453),
    [sym_flow_maybe_type] = STATE(3453),
    [sym_parenthesized_type] = STATE(3453),
    [sym_predefined_type] = STATE(3453),
    [sym_object_type] = STATE(3453),
    [sym_type_parameters] = STATE(5251),
    [sym_array_type] = STATE(3453),
    [sym_tuple_type] = STATE(3453),
    [sym_readonly_type] = STATE(3448),
    [sym_union_type] = STATE(3453),
    [sym_intersection_type] = STATE(3453),
    [sym_function_type] = STATE(3448),
    [sym_identifier] = ACTIONS(3259),
    [anon_sym_STAR] = ACTIONS(2995),
    [anon_sym_LBRACE] = ACTIONS(2997),
    [anon_sym_typeof] = ACTIONS(2999),
    [anon_sym_import] = ACTIONS(1538),
    [anon_sym_const] = ACTIONS(3001),
    [anon_sym_LPAREN] = ACTIONS(3003),
    [anon_sym_LBRACK] = ACTIONS(3005),
    [anon_sym_new] = ACTIONS(3007),
    [anon_sym_AMP] = ACTIONS(3009),
    [anon_sym_PIPE] = ACTIONS(3011),
    [anon_sym_PLUS] = ACTIONS(3013),
    [anon_sym_DASH] = ACTIONS(3013),
    [anon_sym_LT] = ACTIONS(2499),
    [anon_sym_void] = ACTIONS(3015),
    [anon_sym_DQUOTE] = ACTIONS(3017),
    [anon_sym_SQUOTE] = ACTIONS(3019),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(3021),
    [sym_number] = ACTIONS(3023),
    [sym_this] = ACTIONS(3261),
    [sym_true] = ACTIONS(3027),
    [sym_false] = ACTIONS(3027),
    [sym_null] = ACTIONS(3027),
    [sym_undefined] = ACTIONS(3027),
    [anon_sym_readonly] = ACTIONS(3029),
    [anon_sym_QMARK] = ACTIONS(3031),
    [anon_sym_any] = ACTIONS(3015),
    [anon_sym_number] = ACTIONS(3015),
    [anon_sym_boolean] = ACTIONS(3015),
    [anon_sym_string] = ACTIONS(3015),
    [anon_sym_symbol] = ACTIONS(3015),
    [anon_sym_object] = ACTIONS(3015),
    [anon_sym_abstract] = ACTIONS(3033),
    [anon_sym_infer] = ACTIONS(3037),
    [anon_sym_keyof] = ACTIONS(3039),
    [anon_sym_unique] = ACTIONS(3041),
    [anon_sym_unknown] = ACTIONS(3015),
    [anon_sym_never] = ACTIONS(3015),
    [anon_sym_LBRACE_PIPE] = ACTIONS(3043),
    [sym_html_comment] = ACTIONS(5),
  },
  [1022] = {
    [sym_import] = STATE(4650),
    [sym_nested_identifier] = STATE(5567),
    [sym_string] = STATE(1975),
    [sym_formal_parameters] = STATE(5527),
    [sym_nested_type_identifier] = STATE(1865),
    [sym__type_query_member_expression_in_type_annotation] = STATE(1781),
    [sym__type_query_call_expression_in_type_annotation] = STATE(1911),
    [sym_type] = STATE(2061),
    [sym_constructor_type] = STATE(1912),
    [sym_primary_type] = STATE(1915),
    [sym_template_literal_type] = STATE(1916),
    [sym_infer_type] = STATE(1912),
    [sym_conditional_type] = STATE(1916),
    [sym_generic_type] = STATE(1916),
    [sym_type_query] = STATE(1916),
    [sym_index_type_query] = STATE(1916),
    [sym_lookup_type] = STATE(1916),
    [sym_literal_type] = STATE(1916),
    [sym__number] = STATE(1918),
    [sym_existential_type] = STATE(1916),
    [sym_flow_maybe_type] = STATE(1916),
    [sym_parenthesized_type] = STATE(1916),
    [sym_predefined_type] = STATE(1916),
    [sym_object_type] = STATE(1916),
    [sym_type_parameters] = STATE(5243),
    [sym_array_type] = STATE(1916),
    [sym_tuple_type] = STATE(1916),
    [sym_readonly_type] = STATE(1912),
    [sym_union_type] = STATE(1916),
    [sym_intersection_type] = STATE(1916),
    [sym_function_type] = STATE(1912),
    [sym_identifier] = ACTIONS(3255),
    [anon_sym_STAR] = ACTIONS(3047),
    [anon_sym_LBRACE] = ACTIONS(3049),
    [anon_sym_typeof] = ACTIONS(3051),
    [anon_sym_import] = ACTIONS(1538),
    [anon_sym_const] = ACTIONS(3053),
    [anon_sym_LPAREN] = ACTIONS(3055),
    [anon_sym_LBRACK] = ACTIONS(3057),
    [anon_sym_new] = ACTIONS(3059),
    [anon_sym_AMP] = ACTIONS(3061),
    [anon_sym_PIPE] = ACTIONS(3063),
    [anon_sym_PLUS] = ACTIONS(3065),
    [anon_sym_DASH] = ACTIONS(3065),
    [anon_sym_LT] = ACTIONS(2499),
    [anon_sym_void] = ACTIONS(3067),
    [anon_sym_DQUOTE] = ACTIONS(83),
    [anon_sym_SQUOTE] = ACTIONS(85),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(3069),
    [sym_number] = ACTIONS(3071),
    [sym_this] = ACTIONS(3257),
    [sym_true] = ACTIONS(3075),
    [sym_false] = ACTIONS(3075),
    [sym_null] = ACTIONS(3075),
    [sym_undefined] = ACTIONS(3075),
    [anon_sym_readonly] = ACTIONS(3077),
    [anon_sym_QMARK] = ACTIONS(3079),
    [anon_sym_any] = ACTIONS(3067),
    [anon_sym_number] = ACTIONS(3067),
    [anon_sym_boolean] = ACTIONS(3067),
    [anon_sym_string] = ACTIONS(3067),
    [anon_sym_symbol] = ACTIONS(3067),
    [anon_sym_object] = ACTIONS(3067),
    [anon_sym_abstract] = ACTIONS(3081),
    [anon_sym_infer] = ACTIONS(3085),
    [anon_sym_keyof] = ACTIONS(3087),
    [anon_sym_unique] = ACTIONS(3089),
    [anon_sym_unknown] = ACTIONS(3067),
    [anon_sym_never] = ACTIONS(3067),
    [anon_sym_LBRACE_PIPE] = ACTIONS(3091),
    [sym_html_comment] = ACTIONS(5),
  },
  [1023] = {
    [sym_import] = STATE(4650),
    [sym_nested_identifier] = STATE(5567),
    [sym_string] = STATE(1975),
    [sym_formal_parameters] = STATE(5527),
    [sym_nested_type_identifier] = STATE(1865),
    [sym__type_query_member_expression_in_type_annotation] = STATE(1781),
    [sym__type_query_call_expression_in_type_annotation] = STATE(1911),
    [sym_type] = STATE(2062),
    [sym_constructor_type] = STATE(1912),
    [sym_primary_type] = STATE(1915),
    [sym_template_literal_type] = STATE(1916),
    [sym_infer_type] = STATE(1912),
    [sym_conditional_type] = STATE(1916),
    [sym_generic_type] = STATE(1916),
    [sym_type_query] = STATE(1916),
    [sym_index_type_query] = STATE(1916),
    [sym_lookup_type] = STATE(1916),
    [sym_literal_type] = STATE(1916),
    [sym__number] = STATE(1918),
    [sym_existential_type] = STATE(1916),
    [sym_flow_maybe_type] = STATE(1916),
    [sym_parenthesized_type] = STATE(1916),
    [sym_predefined_type] = STATE(1916),
    [sym_object_type] = STATE(1916),
    [sym_type_parameters] = STATE(5243),
    [sym_array_type] = STATE(1916),
    [sym_tuple_type] = STATE(1916),
    [sym_readonly_type] = STATE(1912),
    [sym_union_type] = STATE(1916),
    [sym_intersection_type] = STATE(1916),
    [sym_function_type] = STATE(1912),
    [sym_identifier] = ACTIONS(3255),
    [anon_sym_STAR] = ACTIONS(3047),
    [anon_sym_LBRACE] = ACTIONS(3049),
    [anon_sym_typeof] = ACTIONS(3051),
    [anon_sym_import] = ACTIONS(1538),
    [anon_sym_const] = ACTIONS(3053),
    [anon_sym_LPAREN] = ACTIONS(3055),
    [anon_sym_LBRACK] = ACTIONS(3057),
    [anon_sym_new] = ACTIONS(3059),
    [anon_sym_AMP] = ACTIONS(3061),
    [anon_sym_PIPE] = ACTIONS(3063),
    [anon_sym_PLUS] = ACTIONS(3065),
    [anon_sym_DASH] = ACTIONS(3065),
    [anon_sym_LT] = ACTIONS(2499),
    [anon_sym_void] = ACTIONS(3067),
    [anon_sym_DQUOTE] = ACTIONS(83),
    [anon_sym_SQUOTE] = ACTIONS(85),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(3069),
    [sym_number] = ACTIONS(3071),
    [sym_this] = ACTIONS(3257),
    [sym_true] = ACTIONS(3075),
    [sym_false] = ACTIONS(3075),
    [sym_null] = ACTIONS(3075),
    [sym_undefined] = ACTIONS(3075),
    [anon_sym_readonly] = ACTIONS(3077),
    [anon_sym_QMARK] = ACTIONS(3079),
    [anon_sym_any] = ACTIONS(3067),
    [anon_sym_number] = ACTIONS(3067),
    [anon_sym_boolean] = ACTIONS(3067),
    [anon_sym_string] = ACTIONS(3067),
    [anon_sym_symbol] = ACTIONS(3067),
    [anon_sym_object] = ACTIONS(3067),
    [anon_sym_abstract] = ACTIONS(3081),
    [anon_sym_infer] = ACTIONS(3085),
    [anon_sym_keyof] = ACTIONS(3087),
    [anon_sym_unique] = ACTIONS(3089),
    [anon_sym_unknown] = ACTIONS(3067),
    [anon_sym_never] = ACTIONS(3067),
    [anon_sym_LBRACE_PIPE] = ACTIONS(3091),
    [sym_html_comment] = ACTIONS(5),
  },
  [1024] = {
    [sym_import] = STATE(4650),
    [sym_nested_identifier] = STATE(5567),
    [sym_string] = STATE(1975),
    [sym_formal_parameters] = STATE(5527),
    [sym_nested_type_identifier] = STATE(1865),
    [sym__type_query_member_expression_in_type_annotation] = STATE(1781),
    [sym__type_query_call_expression_in_type_annotation] = STATE(1911),
    [sym_type] = STATE(1882),
    [sym_constructor_type] = STATE(1912),
    [sym_primary_type] = STATE(1915),
    [sym_template_literal_type] = STATE(1916),
    [sym_infer_type] = STATE(1912),
    [sym_conditional_type] = STATE(1916),
    [sym_generic_type] = STATE(1916),
    [sym_type_query] = STATE(1916),
    [sym_index_type_query] = STATE(1916),
    [sym_lookup_type] = STATE(1916),
    [sym_literal_type] = STATE(1916),
    [sym__number] = STATE(1918),
    [sym_existential_type] = STATE(1916),
    [sym_flow_maybe_type] = STATE(1916),
    [sym_parenthesized_type] = STATE(1916),
    [sym_predefined_type] = STATE(1916),
    [sym_object_type] = STATE(1916),
    [sym_type_parameters] = STATE(5243),
    [sym_array_type] = STATE(1916),
    [sym_tuple_type] = STATE(1916),
    [sym_readonly_type] = STATE(1912),
    [sym_union_type] = STATE(1916),
    [sym_intersection_type] = STATE(1916),
    [sym_function_type] = STATE(1912),
    [sym_identifier] = ACTIONS(3255),
    [anon_sym_STAR] = ACTIONS(3047),
    [anon_sym_LBRACE] = ACTIONS(3049),
    [anon_sym_typeof] = ACTIONS(3051),
    [anon_sym_import] = ACTIONS(1538),
    [anon_sym_const] = ACTIONS(3053),
    [anon_sym_LPAREN] = ACTIONS(3055),
    [anon_sym_LBRACK] = ACTIONS(3057),
    [anon_sym_new] = ACTIONS(3059),
    [anon_sym_AMP] = ACTIONS(3061),
    [anon_sym_PIPE] = ACTIONS(3063),
    [anon_sym_PLUS] = ACTIONS(3065),
    [anon_sym_DASH] = ACTIONS(3065),
    [anon_sym_LT] = ACTIONS(2499),
    [anon_sym_void] = ACTIONS(3067),
    [anon_sym_DQUOTE] = ACTIONS(83),
    [anon_sym_SQUOTE] = ACTIONS(85),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(3069),
    [sym_number] = ACTIONS(3071),
    [sym_this] = ACTIONS(3257),
    [sym_true] = ACTIONS(3075),
    [sym_false] = ACTIONS(3075),
    [sym_null] = ACTIONS(3075),
    [sym_undefined] = ACTIONS(3075),
    [anon_sym_readonly] = ACTIONS(3077),
    [anon_sym_QMARK] = ACTIONS(3079),
    [anon_sym_any] = ACTIONS(3067),
    [anon_sym_number] = ACTIONS(3067),
    [anon_sym_boolean] = ACTIONS(3067),
    [anon_sym_string] = ACTIONS(3067),
    [anon_sym_symbol] = ACTIONS(3067),
    [anon_sym_object] = ACTIONS(3067),
    [anon_sym_abstract] = ACTIONS(3081),
    [anon_sym_infer] = ACTIONS(3085),
    [anon_sym_keyof] = ACTIONS(3087),
    [anon_sym_unique] = ACTIONS(3089),
    [anon_sym_unknown] = ACTIONS(3067),
    [anon_sym_never] = ACTIONS(3067),
    [anon_sym_LBRACE_PIPE] = ACTIONS(3091),
    [sym_html_comment] = ACTIONS(5),
  },
  [1025] = {
    [sym_import] = STATE(4650),
    [sym_nested_identifier] = STATE(5567),
    [sym_string] = STATE(1975),
    [sym_formal_parameters] = STATE(5527),
    [sym_nested_type_identifier] = STATE(1865),
    [sym__type_query_member_expression_in_type_annotation] = STATE(1781),
    [sym__type_query_call_expression_in_type_annotation] = STATE(1911),
    [sym_type] = STATE(1883),
    [sym_constructor_type] = STATE(1912),
    [sym_primary_type] = STATE(1915),
    [sym_template_literal_type] = STATE(1916),
    [sym_infer_type] = STATE(1912),
    [sym_conditional_type] = STATE(1916),
    [sym_generic_type] = STATE(1916),
    [sym_type_query] = STATE(1916),
    [sym_index_type_query] = STATE(1916),
    [sym_lookup_type] = STATE(1916),
    [sym_literal_type] = STATE(1916),
    [sym__number] = STATE(1918),
    [sym_existential_type] = STATE(1916),
    [sym_flow_maybe_type] = STATE(1916),
    [sym_parenthesized_type] = STATE(1916),
    [sym_predefined_type] = STATE(1916),
    [sym_object_type] = STATE(1916),
    [sym_type_parameters] = STATE(5243),
    [sym_array_type] = STATE(1916),
    [sym_tuple_type] = STATE(1916),
    [sym_readonly_type] = STATE(1912),
    [sym_union_type] = STATE(1916),
    [sym_intersection_type] = STATE(1916),
    [sym_function_type] = STATE(1912),
    [sym_identifier] = ACTIONS(3255),
    [anon_sym_STAR] = ACTIONS(3047),
    [anon_sym_LBRACE] = ACTIONS(3049),
    [anon_sym_typeof] = ACTIONS(3051),
    [anon_sym_import] = ACTIONS(1538),
    [anon_sym_const] = ACTIONS(3053),
    [anon_sym_LPAREN] = ACTIONS(3055),
    [anon_sym_LBRACK] = ACTIONS(3057),
    [anon_sym_new] = ACTIONS(3059),
    [anon_sym_AMP] = ACTIONS(3061),
    [anon_sym_PIPE] = ACTIONS(3063),
    [anon_sym_PLUS] = ACTIONS(3065),
    [anon_sym_DASH] = ACTIONS(3065),
    [anon_sym_LT] = ACTIONS(2499),
    [anon_sym_void] = ACTIONS(3067),
    [anon_sym_DQUOTE] = ACTIONS(83),
    [anon_sym_SQUOTE] = ACTIONS(85),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(3069),
    [sym_number] = ACTIONS(3071),
    [sym_this] = ACTIONS(3257),
    [sym_true] = ACTIONS(3075),
    [sym_false] = ACTIONS(3075),
    [sym_null] = ACTIONS(3075),
    [sym_undefined] = ACTIONS(3075),
    [anon_sym_readonly] = ACTIONS(3077),
    [anon_sym_QMARK] = ACTIONS(3079),
    [anon_sym_any] = ACTIONS(3067),
    [anon_sym_number] = ACTIONS(3067),
    [anon_sym_boolean] = ACTIONS(3067),
    [anon_sym_string] = ACTIONS(3067),
    [anon_sym_symbol] = ACTIONS(3067),
    [anon_sym_object] = ACTIONS(3067),
    [anon_sym_abstract] = ACTIONS(3081),
    [anon_sym_infer] = ACTIONS(3085),
    [anon_sym_keyof] = ACTIONS(3087),
    [anon_sym_unique] = ACTIONS(3089),
    [anon_sym_unknown] = ACTIONS(3067),
    [anon_sym_never] = ACTIONS(3067),
    [anon_sym_LBRACE_PIPE] = ACTIONS(3091),
    [sym_html_comment] = ACTIONS(5),
  },
  [1026] = {
    [sym_import] = STATE(4950),
    [sym_nested_identifier] = STATE(5535),
    [sym_string] = STATE(3265),
    [sym_formal_parameters] = STATE(5840),
    [sym_nested_type_identifier] = STATE(3151),
    [sym__type_query_member_expression_in_type_annotation] = STATE(3076),
    [sym__type_query_call_expression_in_type_annotation] = STATE(3200),
    [sym_type] = STATE(3962),
    [sym_constructor_type] = STATE(3271),
    [sym_primary_type] = STATE(3272),
    [sym_template_literal_type] = STATE(3273),
    [sym_infer_type] = STATE(3271),
    [sym_conditional_type] = STATE(3273),
    [sym_generic_type] = STATE(3273),
    [sym_type_query] = STATE(3273),
    [sym_index_type_query] = STATE(3273),
    [sym_lookup_type] = STATE(3273),
    [sym_literal_type] = STATE(3273),
    [sym__number] = STATE(3274),
    [sym_existential_type] = STATE(3273),
    [sym_flow_maybe_type] = STATE(3273),
    [sym_parenthesized_type] = STATE(3273),
    [sym_predefined_type] = STATE(3273),
    [sym_object_type] = STATE(3273),
    [sym_type_parameters] = STATE(5146),
    [sym_array_type] = STATE(3273),
    [sym_tuple_type] = STATE(3273),
    [sym_readonly_type] = STATE(3271),
    [sym_union_type] = STATE(3273),
    [sym_intersection_type] = STATE(3273),
    [sym_function_type] = STATE(3271),
    [sym_identifier] = ACTIONS(1606),
    [anon_sym_STAR] = ACTIONS(986),
    [anon_sym_LBRACE] = ACTIONS(1610),
    [anon_sym_typeof] = ACTIONS(1612),
    [anon_sym_import] = ACTIONS(1538),
    [anon_sym_const] = ACTIONS(992),
    [anon_sym_LPAREN] = ACTIONS(1614),
    [anon_sym_LBRACK] = ACTIONS(1616),
    [anon_sym_new] = ACTIONS(1618),
    [anon_sym_AMP] = ACTIONS(1000),
    [anon_sym_PIPE] = ACTIONS(1002),
    [anon_sym_PLUS] = ACTIONS(2983),
    [anon_sym_DASH] = ACTIONS(2983),
    [anon_sym_LT] = ACTIONS(2499),
    [anon_sym_void] = ACTIONS(1032),
    [anon_sym_DQUOTE] = ACTIONS(1626),
    [anon_sym_SQUOTE] = ACTIONS(1628),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1630),
    [sym_number] = ACTIONS(1632),
    [sym_this] = ACTIONS(1634),
    [sym_true] = ACTIONS(1636),
    [sym_false] = ACTIONS(1636),
    [sym_null] = ACTIONS(1636),
    [sym_undefined] = ACTIONS(1636),
    [anon_sym_readonly] = ACTIONS(1638),
    [anon_sym_QMARK] = ACTIONS(1020),
    [anon_sym_any] = ACTIONS(1032),
    [anon_sym_number] = ACTIONS(1032),
    [anon_sym_boolean] = ACTIONS(1032),
    [anon_sym_string] = ACTIONS(1032),
    [anon_sym_symbol] = ACTIONS(1032),
    [anon_sym_object] = ACTIONS(1032),
    [anon_sym_abstract] = ACTIONS(1024),
    [anon_sym_infer] = ACTIONS(1026),
    [anon_sym_keyof] = ACTIONS(1028),
    [anon_sym_unique] = ACTIONS(1030),
    [anon_sym_unknown] = ACTIONS(1032),
    [anon_sym_never] = ACTIONS(1032),
    [anon_sym_LBRACE_PIPE] = ACTIONS(1034),
    [sym_html_comment] = ACTIONS(5),
  },
  [1027] = {
    [sym_import] = STATE(4950),
    [sym_nested_identifier] = STATE(5535),
    [sym_string] = STATE(3265),
    [sym_formal_parameters] = STATE(5840),
    [sym_nested_type_identifier] = STATE(3151),
    [sym__type_query_member_expression_in_type_annotation] = STATE(3076),
    [sym__type_query_call_expression_in_type_annotation] = STATE(3200),
    [sym_type] = STATE(3282),
    [sym_constructor_type] = STATE(3271),
    [sym_primary_type] = STATE(3272),
    [sym_template_literal_type] = STATE(3273),
    [sym_infer_type] = STATE(3271),
    [sym_conditional_type] = STATE(3273),
    [sym_generic_type] = STATE(3273),
    [sym_type_query] = STATE(3273),
    [sym_index_type_query] = STATE(3273),
    [sym_lookup_type] = STATE(3273),
    [sym_literal_type] = STATE(3273),
    [sym__number] = STATE(3274),
    [sym_existential_type] = STATE(3273),
    [sym_flow_maybe_type] = STATE(3273),
    [sym_parenthesized_type] = STATE(3273),
    [sym_predefined_type] = STATE(3273),
    [sym_object_type] = STATE(3273),
    [sym_type_parameters] = STATE(5146),
    [sym_array_type] = STATE(3273),
    [sym_tuple_type] = STATE(3273),
    [sym_readonly_type] = STATE(3271),
    [sym_union_type] = STATE(3273),
    [sym_intersection_type] = STATE(3273),
    [sym_function_type] = STATE(3271),
    [sym_identifier] = ACTIONS(1606),
    [anon_sym_STAR] = ACTIONS(986),
    [anon_sym_LBRACE] = ACTIONS(1610),
    [anon_sym_typeof] = ACTIONS(1612),
    [anon_sym_import] = ACTIONS(1538),
    [anon_sym_const] = ACTIONS(992),
    [anon_sym_LPAREN] = ACTIONS(1614),
    [anon_sym_LBRACK] = ACTIONS(1616),
    [anon_sym_new] = ACTIONS(1618),
    [anon_sym_AMP] = ACTIONS(1000),
    [anon_sym_PIPE] = ACTIONS(1002),
    [anon_sym_PLUS] = ACTIONS(2983),
    [anon_sym_DASH] = ACTIONS(2983),
    [anon_sym_LT] = ACTIONS(2499),
    [anon_sym_void] = ACTIONS(1032),
    [anon_sym_DQUOTE] = ACTIONS(1626),
    [anon_sym_SQUOTE] = ACTIONS(1628),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1630),
    [sym_number] = ACTIONS(1632),
    [sym_this] = ACTIONS(1634),
    [sym_true] = ACTIONS(1636),
    [sym_false] = ACTIONS(1636),
    [sym_null] = ACTIONS(1636),
    [sym_undefined] = ACTIONS(1636),
    [anon_sym_readonly] = ACTIONS(1638),
    [anon_sym_QMARK] = ACTIONS(1020),
    [anon_sym_any] = ACTIONS(1032),
    [anon_sym_number] = ACTIONS(1032),
    [anon_sym_boolean] = ACTIONS(1032),
    [anon_sym_string] = ACTIONS(1032),
    [anon_sym_symbol] = ACTIONS(1032),
    [anon_sym_object] = ACTIONS(1032),
    [anon_sym_abstract] = ACTIONS(1024),
    [anon_sym_infer] = ACTIONS(1026),
    [anon_sym_keyof] = ACTIONS(1028),
    [anon_sym_unique] = ACTIONS(1030),
    [anon_sym_unknown] = ACTIONS(1032),
    [anon_sym_never] = ACTIONS(1032),
    [anon_sym_LBRACE_PIPE] = ACTIONS(1034),
    [sym_html_comment] = ACTIONS(5),
  },
  [1028] = {
    [sym_import] = STATE(4950),
    [sym_nested_identifier] = STATE(5535),
    [sym_string] = STATE(3265),
    [sym_formal_parameters] = STATE(5840),
    [sym_nested_type_identifier] = STATE(3151),
    [sym__type_query_member_expression_in_type_annotation] = STATE(3076),
    [sym__type_query_call_expression_in_type_annotation] = STATE(3200),
    [sym_type] = STATE(3283),
    [sym_constructor_type] = STATE(3271),
    [sym_primary_type] = STATE(3272),
    [sym_template_literal_type] = STATE(3273),
    [sym_infer_type] = STATE(3271),
    [sym_conditional_type] = STATE(3273),
    [sym_generic_type] = STATE(3273),
    [sym_type_query] = STATE(3273),
    [sym_index_type_query] = STATE(3273),
    [sym_lookup_type] = STATE(3273),
    [sym_literal_type] = STATE(3273),
    [sym__number] = STATE(3274),
    [sym_existential_type] = STATE(3273),
    [sym_flow_maybe_type] = STATE(3273),
    [sym_parenthesized_type] = STATE(3273),
    [sym_predefined_type] = STATE(3273),
    [sym_object_type] = STATE(3273),
    [sym_type_parameters] = STATE(5146),
    [sym_array_type] = STATE(3273),
    [sym_tuple_type] = STATE(3273),
    [sym_readonly_type] = STATE(3271),
    [sym_union_type] = STATE(3273),
    [sym_intersection_type] = STATE(3273),
    [sym_function_type] = STATE(3271),
    [sym_identifier] = ACTIONS(1606),
    [anon_sym_STAR] = ACTIONS(986),
    [anon_sym_LBRACE] = ACTIONS(1610),
    [anon_sym_typeof] = ACTIONS(1612),
    [anon_sym_import] = ACTIONS(1538),
    [anon_sym_const] = ACTIONS(992),
    [anon_sym_LPAREN] = ACTIONS(1614),
    [anon_sym_LBRACK] = ACTIONS(1616),
    [anon_sym_new] = ACTIONS(1618),
    [anon_sym_AMP] = ACTIONS(1000),
    [anon_sym_PIPE] = ACTIONS(1002),
    [anon_sym_PLUS] = ACTIONS(2983),
    [anon_sym_DASH] = ACTIONS(2983),
    [anon_sym_LT] = ACTIONS(2499),
    [anon_sym_void] = ACTIONS(1032),
    [anon_sym_DQUOTE] = ACTIONS(1626),
    [anon_sym_SQUOTE] = ACTIONS(1628),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1630),
    [sym_number] = ACTIONS(1632),
    [sym_this] = ACTIONS(1634),
    [sym_true] = ACTIONS(1636),
    [sym_false] = ACTIONS(1636),
    [sym_null] = ACTIONS(1636),
    [sym_undefined] = ACTIONS(1636),
    [anon_sym_readonly] = ACTIONS(1638),
    [anon_sym_QMARK] = ACTIONS(1020),
    [anon_sym_any] = ACTIONS(1032),
    [anon_sym_number] = ACTIONS(1032),
    [anon_sym_boolean] = ACTIONS(1032),
    [anon_sym_string] = ACTIONS(1032),
    [anon_sym_symbol] = ACTIONS(1032),
    [anon_sym_object] = ACTIONS(1032),
    [anon_sym_abstract] = ACTIONS(1024),
    [anon_sym_infer] = ACTIONS(1026),
    [anon_sym_keyof] = ACTIONS(1028),
    [anon_sym_unique] = ACTIONS(1030),
    [anon_sym_unknown] = ACTIONS(1032),
    [anon_sym_never] = ACTIONS(1032),
    [anon_sym_LBRACE_PIPE] = ACTIONS(1034),
    [sym_html_comment] = ACTIONS(5),
  },
  [1029] = {
    [sym_import] = STATE(4950),
    [sym_nested_identifier] = STATE(5535),
    [sym_string] = STATE(3265),
    [sym_formal_parameters] = STATE(5840),
    [sym_nested_type_identifier] = STATE(3151),
    [sym__type_query_member_expression_in_type_annotation] = STATE(3076),
    [sym__type_query_call_expression_in_type_annotation] = STATE(3200),
    [sym_type] = STATE(3222),
    [sym_constructor_type] = STATE(3271),
    [sym_primary_type] = STATE(3272),
    [sym_template_literal_type] = STATE(3273),
    [sym_infer_type] = STATE(3271),
    [sym_conditional_type] = STATE(3273),
    [sym_generic_type] = STATE(3273),
    [sym_type_query] = STATE(3273),
    [sym_index_type_query] = STATE(3273),
    [sym_lookup_type] = STATE(3273),
    [sym_literal_type] = STATE(3273),
    [sym__number] = STATE(3274),
    [sym_existential_type] = STATE(3273),
    [sym_flow_maybe_type] = STATE(3273),
    [sym_parenthesized_type] = STATE(3273),
    [sym_predefined_type] = STATE(3273),
    [sym_object_type] = STATE(3273),
    [sym_type_parameters] = STATE(5146),
    [sym_array_type] = STATE(3273),
    [sym_tuple_type] = STATE(3273),
    [sym_readonly_type] = STATE(3271),
    [sym_union_type] = STATE(3273),
    [sym_intersection_type] = STATE(3273),
    [sym_function_type] = STATE(3271),
    [sym_identifier] = ACTIONS(1606),
    [anon_sym_STAR] = ACTIONS(986),
    [anon_sym_LBRACE] = ACTIONS(1610),
    [anon_sym_typeof] = ACTIONS(1612),
    [anon_sym_import] = ACTIONS(1538),
    [anon_sym_const] = ACTIONS(992),
    [anon_sym_LPAREN] = ACTIONS(1614),
    [anon_sym_LBRACK] = ACTIONS(1616),
    [anon_sym_new] = ACTIONS(1618),
    [anon_sym_AMP] = ACTIONS(1000),
    [anon_sym_PIPE] = ACTIONS(1002),
    [anon_sym_PLUS] = ACTIONS(2983),
    [anon_sym_DASH] = ACTIONS(2983),
    [anon_sym_LT] = ACTIONS(2499),
    [anon_sym_void] = ACTIONS(1032),
    [anon_sym_DQUOTE] = ACTIONS(1626),
    [anon_sym_SQUOTE] = ACTIONS(1628),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1630),
    [sym_number] = ACTIONS(1632),
    [sym_this] = ACTIONS(1634),
    [sym_true] = ACTIONS(1636),
    [sym_false] = ACTIONS(1636),
    [sym_null] = ACTIONS(1636),
    [sym_undefined] = ACTIONS(1636),
    [anon_sym_readonly] = ACTIONS(1638),
    [anon_sym_QMARK] = ACTIONS(1020),
    [anon_sym_any] = ACTIONS(1032),
    [anon_sym_number] = ACTIONS(1032),
    [anon_sym_boolean] = ACTIONS(1032),
    [anon_sym_string] = ACTIONS(1032),
    [anon_sym_symbol] = ACTIONS(1032),
    [anon_sym_object] = ACTIONS(1032),
    [anon_sym_abstract] = ACTIONS(1024),
    [anon_sym_infer] = ACTIONS(1026),
    [anon_sym_keyof] = ACTIONS(1028),
    [anon_sym_unique] = ACTIONS(1030),
    [anon_sym_unknown] = ACTIONS(1032),
    [anon_sym_never] = ACTIONS(1032),
    [anon_sym_LBRACE_PIPE] = ACTIONS(1034),
    [sym_html_comment] = ACTIONS(5),
  },
  [1030] = {
    [sym_import] = STATE(4878),
    [sym_nested_identifier] = STATE(5535),
    [sym_string] = STATE(3265),
    [sym_formal_parameters] = STATE(5475),
    [sym_nested_type_identifier] = STATE(3151),
    [sym__type_query_member_expression_in_type_annotation] = STATE(2937),
    [sym__type_query_call_expression_in_type_annotation] = STATE(2938),
    [sym_type] = STATE(5001),
    [sym_constructor_type] = STATE(3007),
    [sym_primary_type] = STATE(3216),
    [sym_template_literal_type] = STATE(3273),
    [sym_infer_type] = STATE(3007),
    [sym_conditional_type] = STATE(3273),
    [sym_generic_type] = STATE(3273),
    [sym_type_query] = STATE(3273),
    [sym_index_type_query] = STATE(3273),
    [sym_lookup_type] = STATE(3273),
    [sym_literal_type] = STATE(3273),
    [sym__number] = STATE(3274),
    [sym_existential_type] = STATE(3273),
    [sym_flow_maybe_type] = STATE(3273),
    [sym_parenthesized_type] = STATE(3273),
    [sym_predefined_type] = STATE(3273),
    [sym_object_type] = STATE(3273),
    [sym_type_parameters] = STATE(5248),
    [sym_array_type] = STATE(3273),
    [sym_tuple_type] = STATE(3273),
    [sym_readonly_type] = STATE(3007),
    [sym_union_type] = STATE(3273),
    [sym_intersection_type] = STATE(3273),
    [sym_function_type] = STATE(3007),
    [sym_identifier] = ACTIONS(1606),
    [anon_sym_STAR] = ACTIONS(986),
    [anon_sym_LBRACE] = ACTIONS(1610),
    [anon_sym_typeof] = ACTIONS(1612),
    [anon_sym_import] = ACTIONS(1538),
    [anon_sym_const] = ACTIONS(992),
    [anon_sym_LPAREN] = ACTIONS(1614),
    [anon_sym_LBRACK] = ACTIONS(1616),
    [anon_sym_new] = ACTIONS(1544),
    [anon_sym_AMP] = ACTIONS(1000),
    [anon_sym_PIPE] = ACTIONS(1002),
    [anon_sym_PLUS] = ACTIONS(2983),
    [anon_sym_DASH] = ACTIONS(2983),
    [anon_sym_LT] = ACTIONS(2499),
    [anon_sym_void] = ACTIONS(1032),
    [anon_sym_DQUOTE] = ACTIONS(1626),
    [anon_sym_SQUOTE] = ACTIONS(1628),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1630),
    [sym_number] = ACTIONS(1632),
    [sym_this] = ACTIONS(1634),
    [sym_true] = ACTIONS(1636),
    [sym_false] = ACTIONS(1636),
    [sym_null] = ACTIONS(1636),
    [sym_undefined] = ACTIONS(1636),
    [anon_sym_readonly] = ACTIONS(1562),
    [anon_sym_QMARK] = ACTIONS(1020),
    [anon_sym_any] = ACTIONS(1032),
    [anon_sym_number] = ACTIONS(1032),
    [anon_sym_boolean] = ACTIONS(1032),
    [anon_sym_string] = ACTIONS(1032),
    [anon_sym_symbol] = ACTIONS(1032),
    [anon_sym_object] = ACTIONS(1032),
    [anon_sym_abstract] = ACTIONS(208),
    [anon_sym_infer] = ACTIONS(210),
    [anon_sym_keyof] = ACTIONS(1028),
    [anon_sym_unique] = ACTIONS(1030),
    [anon_sym_unknown] = ACTIONS(1032),
    [anon_sym_never] = ACTIONS(1032),
    [anon_sym_LBRACE_PIPE] = ACTIONS(1034),
    [sym_html_comment] = ACTIONS(5),
  },
  [1031] = {
    [sym_import] = STATE(4878),
    [sym_nested_identifier] = STATE(5535),
    [sym_string] = STATE(3265),
    [sym_formal_parameters] = STATE(5475),
    [sym_nested_type_identifier] = STATE(3151),
    [sym__type_query_member_expression_in_type_annotation] = STATE(2937),
    [sym__type_query_call_expression_in_type_annotation] = STATE(2938),
    [sym_type] = STATE(5001),
    [sym_constructor_type] = STATE(3007),
    [sym_primary_type] = STATE(3254),
    [sym_template_literal_type] = STATE(3273),
    [sym_infer_type] = STATE(3007),
    [sym_conditional_type] = STATE(3273),
    [sym_generic_type] = STATE(3273),
    [sym_type_query] = STATE(3273),
    [sym_index_type_query] = STATE(3273),
    [sym_lookup_type] = STATE(3273),
    [sym_literal_type] = STATE(3273),
    [sym__number] = STATE(3274),
    [sym_existential_type] = STATE(3273),
    [sym_flow_maybe_type] = STATE(3273),
    [sym_parenthesized_type] = STATE(3273),
    [sym_predefined_type] = STATE(3273),
    [sym_object_type] = STATE(3273),
    [sym_type_parameters] = STATE(5248),
    [sym_array_type] = STATE(3273),
    [sym_tuple_type] = STATE(3273),
    [sym_readonly_type] = STATE(3007),
    [sym_union_type] = STATE(3273),
    [sym_intersection_type] = STATE(3273),
    [sym_function_type] = STATE(3007),
    [sym_identifier] = ACTIONS(1606),
    [anon_sym_STAR] = ACTIONS(986),
    [anon_sym_LBRACE] = ACTIONS(1610),
    [anon_sym_typeof] = ACTIONS(1612),
    [anon_sym_import] = ACTIONS(1538),
    [anon_sym_const] = ACTIONS(992),
    [anon_sym_LPAREN] = ACTIONS(1614),
    [anon_sym_LBRACK] = ACTIONS(1616),
    [anon_sym_new] = ACTIONS(1544),
    [anon_sym_AMP] = ACTIONS(1000),
    [anon_sym_PIPE] = ACTIONS(1002),
    [anon_sym_PLUS] = ACTIONS(2983),
    [anon_sym_DASH] = ACTIONS(2983),
    [anon_sym_LT] = ACTIONS(2499),
    [anon_sym_void] = ACTIONS(1032),
    [anon_sym_DQUOTE] = ACTIONS(1626),
    [anon_sym_SQUOTE] = ACTIONS(1628),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1630),
    [sym_number] = ACTIONS(1632),
    [sym_this] = ACTIONS(1634),
    [sym_true] = ACTIONS(1636),
    [sym_false] = ACTIONS(1636),
    [sym_null] = ACTIONS(1636),
    [sym_undefined] = ACTIONS(1636),
    [anon_sym_readonly] = ACTIONS(1562),
    [anon_sym_QMARK] = ACTIONS(1020),
    [anon_sym_any] = ACTIONS(1032),
    [anon_sym_number] = ACTIONS(1032),
    [anon_sym_boolean] = ACTIONS(1032),
    [anon_sym_string] = ACTIONS(1032),
    [anon_sym_symbol] = ACTIONS(1032),
    [anon_sym_object] = ACTIONS(1032),
    [anon_sym_abstract] = ACTIONS(208),
    [anon_sym_infer] = ACTIONS(210),
    [anon_sym_keyof] = ACTIONS(1028),
    [anon_sym_unique] = ACTIONS(1030),
    [anon_sym_unknown] = ACTIONS(1032),
    [anon_sym_never] = ACTIONS(1032),
    [anon_sym_LBRACE_PIPE] = ACTIONS(1034),
    [sym_html_comment] = ACTIONS(5),
  },
  [1032] = {
    [sym_import] = STATE(4681),
    [sym_nested_identifier] = STATE(5474),
    [sym_string] = STATE(2994),
    [sym_formal_parameters] = STATE(5619),
    [sym_nested_type_identifier] = STATE(2939),
    [sym__type_query_member_expression_in_type_annotation] = STATE(3303),
    [sym__type_query_call_expression_in_type_annotation] = STATE(2938),
    [sym_type] = STATE(3021),
    [sym_constructor_type] = STATE(3007),
    [sym_primary_type] = STATE(2981),
    [sym_template_literal_type] = STATE(3039),
    [sym_infer_type] = STATE(3007),
    [sym_conditional_type] = STATE(3039),
    [sym_generic_type] = STATE(3039),
    [sym_type_query] = STATE(3039),
    [sym_index_type_query] = STATE(3039),
    [sym_lookup_type] = STATE(3039),
    [sym_literal_type] = STATE(3039),
    [sym__number] = STATE(3041),
    [sym_existential_type] = STATE(3039),
    [sym_flow_maybe_type] = STATE(3039),
    [sym_parenthesized_type] = STATE(3039),
    [sym_predefined_type] = STATE(3039),
    [sym_object_type] = STATE(3039),
    [sym_type_parameters] = STATE(5454),
    [sym_array_type] = STATE(3039),
    [sym_tuple_type] = STATE(3039),
    [sym_readonly_type] = STATE(3007),
    [sym_union_type] = STATE(3039),
    [sym_intersection_type] = STATE(3039),
    [sym_function_type] = STATE(3007),
    [sym_identifier] = ACTIONS(1532),
    [anon_sym_STAR] = ACTIONS(543),
    [anon_sym_LBRACE] = ACTIONS(1534),
    [anon_sym_typeof] = ACTIONS(1536),
    [anon_sym_import] = ACTIONS(1538),
    [anon_sym_const] = ACTIONS(133),
    [anon_sym_LPAREN] = ACTIONS(1540),
    [anon_sym_LBRACK] = ACTIONS(1542),
    [anon_sym_new] = ACTIONS(1642),
    [anon_sym_AMP] = ACTIONS(571),
    [anon_sym_PIPE] = ACTIONS(573),
    [anon_sym_PLUS] = ACTIONS(2497),
    [anon_sym_DASH] = ACTIONS(2497),
    [anon_sym_LT] = ACTIONS(2499),
    [anon_sym_void] = ACTIONS(216),
    [anon_sym_DQUOTE] = ACTIONS(1550),
    [anon_sym_SQUOTE] = ACTIONS(1552),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1554),
    [sym_number] = ACTIONS(1556),
    [sym_this] = ACTIONS(1558),
    [sym_true] = ACTIONS(1560),
    [sym_false] = ACTIONS(1560),
    [sym_null] = ACTIONS(1560),
    [sym_undefined] = ACTIONS(1560),
    [anon_sym_readonly] = ACTIONS(1648),
    [anon_sym_QMARK] = ACTIONS(593),
    [anon_sym_any] = ACTIONS(216),
    [anon_sym_number] = ACTIONS(216),
    [anon_sym_boolean] = ACTIONS(216),
    [anon_sym_string] = ACTIONS(216),
    [anon_sym_symbol] = ACTIONS(216),
    [anon_sym_object] = ACTIONS(216),
    [anon_sym_abstract] = ACTIONS(597),
    [anon_sym_infer] = ACTIONS(599),
    [anon_sym_keyof] = ACTIONS(601),
    [anon_sym_unique] = ACTIONS(214),
    [anon_sym_unknown] = ACTIONS(216),
    [anon_sym_never] = ACTIONS(216),
    [anon_sym_LBRACE_PIPE] = ACTIONS(218),
    [sym_html_comment] = ACTIONS(5),
  },
  [1033] = {
    [sym_import] = STATE(4681),
    [sym_nested_identifier] = STATE(5474),
    [sym_string] = STATE(2994),
    [sym_formal_parameters] = STATE(5619),
    [sym_nested_type_identifier] = STATE(2939),
    [sym__type_query_member_expression_in_type_annotation] = STATE(3303),
    [sym__type_query_call_expression_in_type_annotation] = STATE(2938),
    [sym_type] = STATE(3713),
    [sym_constructor_type] = STATE(3007),
    [sym_primary_type] = STATE(2981),
    [sym_template_literal_type] = STATE(3039),
    [sym_infer_type] = STATE(3007),
    [sym_conditional_type] = STATE(3039),
    [sym_generic_type] = STATE(3039),
    [sym_type_query] = STATE(3039),
    [sym_index_type_query] = STATE(3039),
    [sym_lookup_type] = STATE(3039),
    [sym_literal_type] = STATE(3039),
    [sym__number] = STATE(3041),
    [sym_existential_type] = STATE(3039),
    [sym_flow_maybe_type] = STATE(3039),
    [sym_parenthesized_type] = STATE(3039),
    [sym_predefined_type] = STATE(3039),
    [sym_object_type] = STATE(3039),
    [sym_type_parameters] = STATE(5454),
    [sym_array_type] = STATE(3039),
    [sym_tuple_type] = STATE(3039),
    [sym_readonly_type] = STATE(3007),
    [sym_union_type] = STATE(3039),
    [sym_intersection_type] = STATE(3039),
    [sym_function_type] = STATE(3007),
    [sym_identifier] = ACTIONS(1532),
    [anon_sym_STAR] = ACTIONS(543),
    [anon_sym_LBRACE] = ACTIONS(1534),
    [anon_sym_typeof] = ACTIONS(1536),
    [anon_sym_import] = ACTIONS(1538),
    [anon_sym_const] = ACTIONS(133),
    [anon_sym_LPAREN] = ACTIONS(1540),
    [anon_sym_LBRACK] = ACTIONS(1542),
    [anon_sym_new] = ACTIONS(1642),
    [anon_sym_AMP] = ACTIONS(571),
    [anon_sym_PIPE] = ACTIONS(573),
    [anon_sym_PLUS] = ACTIONS(2497),
    [anon_sym_DASH] = ACTIONS(2497),
    [anon_sym_LT] = ACTIONS(2499),
    [anon_sym_void] = ACTIONS(216),
    [anon_sym_DQUOTE] = ACTIONS(1550),
    [anon_sym_SQUOTE] = ACTIONS(1552),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1554),
    [sym_number] = ACTIONS(1556),
    [sym_this] = ACTIONS(1558),
    [sym_true] = ACTIONS(1560),
    [sym_false] = ACTIONS(1560),
    [sym_null] = ACTIONS(1560),
    [sym_undefined] = ACTIONS(1560),
    [anon_sym_readonly] = ACTIONS(1648),
    [anon_sym_QMARK] = ACTIONS(593),
    [anon_sym_any] = ACTIONS(216),
    [anon_sym_number] = ACTIONS(216),
    [anon_sym_boolean] = ACTIONS(216),
    [anon_sym_string] = ACTIONS(216),
    [anon_sym_symbol] = ACTIONS(216),
    [anon_sym_object] = ACTIONS(216),
    [anon_sym_abstract] = ACTIONS(597),
    [anon_sym_infer] = ACTIONS(599),
    [anon_sym_keyof] = ACTIONS(601),
    [anon_sym_unique] = ACTIONS(214),
    [anon_sym_unknown] = ACTIONS(216),
    [anon_sym_never] = ACTIONS(216),
    [anon_sym_LBRACE_PIPE] = ACTIONS(218),
    [sym_html_comment] = ACTIONS(5),
  },
  [1034] = {
    [sym_import] = STATE(4878),
    [sym_nested_identifier] = STATE(5474),
    [sym_string] = STATE(2994),
    [sym_formal_parameters] = STATE(5475),
    [sym_nested_type_identifier] = STATE(2939),
    [sym__type_query_member_expression_in_type_annotation] = STATE(2937),
    [sym__type_query_call_expression_in_type_annotation] = STATE(2938),
    [sym_type] = STATE(4622),
    [sym_constructor_type] = STATE(3007),
    [sym_primary_type] = STATE(4133),
    [sym_template_literal_type] = STATE(3039),
    [sym_infer_type] = STATE(4403),
    [sym_conditional_type] = STATE(3039),
    [sym_generic_type] = STATE(3039),
    [sym_type_query] = STATE(3039),
    [sym_index_type_query] = STATE(3039),
    [sym_lookup_type] = STATE(3039),
    [sym_literal_type] = STATE(3039),
    [sym__number] = STATE(3041),
    [sym_existential_type] = STATE(3039),
    [sym_flow_maybe_type] = STATE(3039),
    [sym_parenthesized_type] = STATE(3039),
    [sym_predefined_type] = STATE(3039),
    [sym_object_type] = STATE(3039),
    [sym_type_parameters] = STATE(5248),
    [sym_array_type] = STATE(3039),
    [sym_tuple_type] = STATE(3039),
    [sym_readonly_type] = STATE(3007),
    [sym_union_type] = STATE(3039),
    [sym_intersection_type] = STATE(3039),
    [sym_function_type] = STATE(3007),
    [sym_identifier] = ACTIONS(1532),
    [anon_sym_STAR] = ACTIONS(543),
    [anon_sym_LBRACE] = ACTIONS(1534),
    [anon_sym_typeof] = ACTIONS(1536),
    [anon_sym_import] = ACTIONS(1538),
    [anon_sym_const] = ACTIONS(133),
    [anon_sym_LPAREN] = ACTIONS(1540),
    [anon_sym_LBRACK] = ACTIONS(1542),
    [anon_sym_new] = ACTIONS(1544),
    [anon_sym_AMP] = ACTIONS(748),
    [anon_sym_PIPE] = ACTIONS(750),
    [anon_sym_PLUS] = ACTIONS(2497),
    [anon_sym_DASH] = ACTIONS(2497),
    [anon_sym_LT] = ACTIONS(2499),
    [anon_sym_void] = ACTIONS(216),
    [anon_sym_DQUOTE] = ACTIONS(1550),
    [anon_sym_SQUOTE] = ACTIONS(1552),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1554),
    [sym_number] = ACTIONS(1556),
    [sym_this] = ACTIONS(1558),
    [sym_true] = ACTIONS(1560),
    [sym_false] = ACTIONS(1560),
    [sym_null] = ACTIONS(1560),
    [sym_undefined] = ACTIONS(1560),
    [anon_sym_readonly] = ACTIONS(1562),
    [anon_sym_QMARK] = ACTIONS(774),
    [anon_sym_any] = ACTIONS(216),
    [anon_sym_number] = ACTIONS(216),
    [anon_sym_boolean] = ACTIONS(216),
    [anon_sym_string] = ACTIONS(216),
    [anon_sym_symbol] = ACTIONS(216),
    [anon_sym_object] = ACTIONS(216),
    [anon_sym_abstract] = ACTIONS(208),
    [anon_sym_infer] = ACTIONS(210),
    [anon_sym_keyof] = ACTIONS(212),
    [anon_sym_unique] = ACTIONS(214),
    [anon_sym_unknown] = ACTIONS(216),
    [anon_sym_never] = ACTIONS(216),
    [anon_sym_LBRACE_PIPE] = ACTIONS(218),
    [sym_html_comment] = ACTIONS(5),
  },
  [1035] = {
    [sym_import] = STATE(4950),
    [sym_nested_identifier] = STATE(5535),
    [sym_string] = STATE(3265),
    [sym_formal_parameters] = STATE(5840),
    [sym_nested_type_identifier] = STATE(3151),
    [sym__type_query_member_expression_in_type_annotation] = STATE(3076),
    [sym__type_query_call_expression_in_type_annotation] = STATE(3200),
    [sym_type] = STATE(3983),
    [sym_constructor_type] = STATE(3271),
    [sym_primary_type] = STATE(3272),
    [sym_template_literal_type] = STATE(3273),
    [sym_infer_type] = STATE(3271),
    [sym_conditional_type] = STATE(3273),
    [sym_generic_type] = STATE(3273),
    [sym_type_query] = STATE(3273),
    [sym_index_type_query] = STATE(3273),
    [sym_lookup_type] = STATE(3273),
    [sym_literal_type] = STATE(3273),
    [sym__number] = STATE(3274),
    [sym_existential_type] = STATE(3273),
    [sym_flow_maybe_type] = STATE(3273),
    [sym_parenthesized_type] = STATE(3273),
    [sym_predefined_type] = STATE(3273),
    [sym_object_type] = STATE(3273),
    [sym_type_parameters] = STATE(5146),
    [sym_array_type] = STATE(3273),
    [sym_tuple_type] = STATE(3273),
    [sym_readonly_type] = STATE(3271),
    [sym_union_type] = STATE(3273),
    [sym_intersection_type] = STATE(3273),
    [sym_function_type] = STATE(3271),
    [sym_identifier] = ACTIONS(1606),
    [anon_sym_STAR] = ACTIONS(986),
    [anon_sym_LBRACE] = ACTIONS(1610),
    [anon_sym_typeof] = ACTIONS(1612),
    [anon_sym_import] = ACTIONS(1538),
    [anon_sym_const] = ACTIONS(992),
    [anon_sym_LPAREN] = ACTIONS(1614),
    [anon_sym_LBRACK] = ACTIONS(1616),
    [anon_sym_new] = ACTIONS(1618),
    [anon_sym_AMP] = ACTIONS(1000),
    [anon_sym_PIPE] = ACTIONS(1002),
    [anon_sym_PLUS] = ACTIONS(2983),
    [anon_sym_DASH] = ACTIONS(2983),
    [anon_sym_LT] = ACTIONS(2499),
    [anon_sym_void] = ACTIONS(1032),
    [anon_sym_DQUOTE] = ACTIONS(1626),
    [anon_sym_SQUOTE] = ACTIONS(1628),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1630),
    [sym_number] = ACTIONS(1632),
    [sym_this] = ACTIONS(1634),
    [sym_true] = ACTIONS(1636),
    [sym_false] = ACTIONS(1636),
    [sym_null] = ACTIONS(1636),
    [sym_undefined] = ACTIONS(1636),
    [anon_sym_readonly] = ACTIONS(1638),
    [anon_sym_QMARK] = ACTIONS(1020),
    [anon_sym_any] = ACTIONS(1032),
    [anon_sym_number] = ACTIONS(1032),
    [anon_sym_boolean] = ACTIONS(1032),
    [anon_sym_string] = ACTIONS(1032),
    [anon_sym_symbol] = ACTIONS(1032),
    [anon_sym_object] = ACTIONS(1032),
    [anon_sym_abstract] = ACTIONS(1024),
    [anon_sym_infer] = ACTIONS(1026),
    [anon_sym_keyof] = ACTIONS(1028),
    [anon_sym_unique] = ACTIONS(1030),
    [anon_sym_unknown] = ACTIONS(1032),
    [anon_sym_never] = ACTIONS(1032),
    [anon_sym_LBRACE_PIPE] = ACTIONS(1034),
    [sym_html_comment] = ACTIONS(5),
  },
  [1036] = {
    [sym_import] = STATE(4878),
    [sym_nested_identifier] = STATE(5474),
    [sym_string] = STATE(2994),
    [sym_formal_parameters] = STATE(5475),
    [sym_nested_type_identifier] = STATE(2939),
    [sym__type_query_member_expression_in_type_annotation] = STATE(2937),
    [sym__type_query_call_expression_in_type_annotation] = STATE(2938),
    [sym_type] = STATE(4137),
    [sym_constructor_type] = STATE(3007),
    [sym_primary_type] = STATE(2981),
    [sym_template_literal_type] = STATE(3039),
    [sym_infer_type] = STATE(3007),
    [sym_conditional_type] = STATE(3039),
    [sym_generic_type] = STATE(3039),
    [sym_type_query] = STATE(3039),
    [sym_index_type_query] = STATE(3039),
    [sym_lookup_type] = STATE(3039),
    [sym_literal_type] = STATE(3039),
    [sym__number] = STATE(3041),
    [sym_existential_type] = STATE(3039),
    [sym_flow_maybe_type] = STATE(3039),
    [sym_parenthesized_type] = STATE(3039),
    [sym_predefined_type] = STATE(3039),
    [sym_object_type] = STATE(3039),
    [sym_type_parameters] = STATE(5248),
    [sym_array_type] = STATE(3039),
    [sym_tuple_type] = STATE(3039),
    [sym_readonly_type] = STATE(3007),
    [sym_union_type] = STATE(3039),
    [sym_intersection_type] = STATE(3039),
    [sym_function_type] = STATE(3007),
    [sym_identifier] = ACTIONS(1532),
    [anon_sym_STAR] = ACTIONS(543),
    [anon_sym_LBRACE] = ACTIONS(1534),
    [anon_sym_typeof] = ACTIONS(1536),
    [anon_sym_import] = ACTIONS(1538),
    [anon_sym_const] = ACTIONS(133),
    [anon_sym_LPAREN] = ACTIONS(1540),
    [anon_sym_LBRACK] = ACTIONS(1542),
    [anon_sym_new] = ACTIONS(1544),
    [anon_sym_AMP] = ACTIONS(748),
    [anon_sym_PIPE] = ACTIONS(750),
    [anon_sym_PLUS] = ACTIONS(2497),
    [anon_sym_DASH] = ACTIONS(2497),
    [anon_sym_LT] = ACTIONS(2499),
    [anon_sym_void] = ACTIONS(216),
    [anon_sym_DQUOTE] = ACTIONS(1550),
    [anon_sym_SQUOTE] = ACTIONS(1552),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1554),
    [sym_number] = ACTIONS(1556),
    [sym_this] = ACTIONS(1558),
    [sym_true] = ACTIONS(1560),
    [sym_false] = ACTIONS(1560),
    [sym_null] = ACTIONS(1560),
    [sym_undefined] = ACTIONS(1560),
    [anon_sym_readonly] = ACTIONS(1562),
    [anon_sym_QMARK] = ACTIONS(774),
    [anon_sym_any] = ACTIONS(216),
    [anon_sym_number] = ACTIONS(216),
    [anon_sym_boolean] = ACTIONS(216),
    [anon_sym_string] = ACTIONS(216),
    [anon_sym_symbol] = ACTIONS(216),
    [anon_sym_object] = ACTIONS(216),
    [anon_sym_abstract] = ACTIONS(208),
    [anon_sym_infer] = ACTIONS(210),
    [anon_sym_keyof] = ACTIONS(212),
    [anon_sym_unique] = ACTIONS(214),
    [anon_sym_unknown] = ACTIONS(216),
    [anon_sym_never] = ACTIONS(216),
    [anon_sym_LBRACE_PIPE] = ACTIONS(218),
    [sym_html_comment] = ACTIONS(5),
  },
  [1037] = {
    [sym_import] = STATE(4681),
    [sym_nested_identifier] = STATE(5474),
    [sym_string] = STATE(2994),
    [sym_formal_parameters] = STATE(5619),
    [sym_nested_type_identifier] = STATE(2939),
    [sym__type_query_member_expression_in_type_annotation] = STATE(3303),
    [sym__type_query_call_expression_in_type_annotation] = STATE(2938),
    [sym_type] = STATE(2947),
    [sym_constructor_type] = STATE(3007),
    [sym_primary_type] = STATE(2981),
    [sym_template_literal_type] = STATE(3039),
    [sym_infer_type] = STATE(3007),
    [sym_conditional_type] = STATE(3039),
    [sym_generic_type] = STATE(3039),
    [sym_type_query] = STATE(3039),
    [sym_index_type_query] = STATE(3039),
    [sym_lookup_type] = STATE(3039),
    [sym_literal_type] = STATE(3039),
    [sym__number] = STATE(3041),
    [sym_existential_type] = STATE(3039),
    [sym_flow_maybe_type] = STATE(3039),
    [sym_parenthesized_type] = STATE(3039),
    [sym_predefined_type] = STATE(3039),
    [sym_object_type] = STATE(3039),
    [sym_type_parameters] = STATE(5454),
    [sym_array_type] = STATE(3039),
    [sym_tuple_type] = STATE(3039),
    [sym_readonly_type] = STATE(3007),
    [sym_union_type] = STATE(3039),
    [sym_intersection_type] = STATE(3039),
    [sym_function_type] = STATE(3007),
    [sym_identifier] = ACTIONS(1532),
    [anon_sym_STAR] = ACTIONS(543),
    [anon_sym_LBRACE] = ACTIONS(1534),
    [anon_sym_typeof] = ACTIONS(1536),
    [anon_sym_import] = ACTIONS(1538),
    [anon_sym_const] = ACTIONS(133),
    [anon_sym_LPAREN] = ACTIONS(1540),
    [anon_sym_LBRACK] = ACTIONS(1542),
    [anon_sym_new] = ACTIONS(1642),
    [anon_sym_AMP] = ACTIONS(571),
    [anon_sym_PIPE] = ACTIONS(573),
    [anon_sym_PLUS] = ACTIONS(2497),
    [anon_sym_DASH] = ACTIONS(2497),
    [anon_sym_LT] = ACTIONS(2499),
    [anon_sym_void] = ACTIONS(216),
    [anon_sym_DQUOTE] = ACTIONS(1550),
    [anon_sym_SQUOTE] = ACTIONS(1552),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1554),
    [sym_number] = ACTIONS(1556),
    [sym_this] = ACTIONS(1558),
    [sym_true] = ACTIONS(1560),
    [sym_false] = ACTIONS(1560),
    [sym_null] = ACTIONS(1560),
    [sym_undefined] = ACTIONS(1560),
    [anon_sym_readonly] = ACTIONS(1648),
    [anon_sym_QMARK] = ACTIONS(593),
    [anon_sym_any] = ACTIONS(216),
    [anon_sym_number] = ACTIONS(216),
    [anon_sym_boolean] = ACTIONS(216),
    [anon_sym_string] = ACTIONS(216),
    [anon_sym_symbol] = ACTIONS(216),
    [anon_sym_object] = ACTIONS(216),
    [anon_sym_abstract] = ACTIONS(597),
    [anon_sym_infer] = ACTIONS(599),
    [anon_sym_keyof] = ACTIONS(601),
    [anon_sym_unique] = ACTIONS(214),
    [anon_sym_unknown] = ACTIONS(216),
    [anon_sym_never] = ACTIONS(216),
    [anon_sym_LBRACE_PIPE] = ACTIONS(218),
    [sym_html_comment] = ACTIONS(5),
  },
  [1038] = {
    [sym_import] = STATE(4681),
    [sym_nested_identifier] = STATE(5474),
    [sym_string] = STATE(2994),
    [sym_formal_parameters] = STATE(5619),
    [sym_nested_type_identifier] = STATE(2939),
    [sym__type_query_member_expression_in_type_annotation] = STATE(3303),
    [sym__type_query_call_expression_in_type_annotation] = STATE(2938),
    [sym_type] = STATE(3730),
    [sym_constructor_type] = STATE(3007),
    [sym_primary_type] = STATE(2981),
    [sym_template_literal_type] = STATE(3039),
    [sym_infer_type] = STATE(3007),
    [sym_conditional_type] = STATE(3039),
    [sym_generic_type] = STATE(3039),
    [sym_type_query] = STATE(3039),
    [sym_index_type_query] = STATE(3039),
    [sym_lookup_type] = STATE(3039),
    [sym_literal_type] = STATE(3039),
    [sym__number] = STATE(3041),
    [sym_existential_type] = STATE(3039),
    [sym_flow_maybe_type] = STATE(3039),
    [sym_parenthesized_type] = STATE(3039),
    [sym_predefined_type] = STATE(3039),
    [sym_object_type] = STATE(3039),
    [sym_type_parameters] = STATE(5454),
    [sym_array_type] = STATE(3039),
    [sym_tuple_type] = STATE(3039),
    [sym_readonly_type] = STATE(3007),
    [sym_union_type] = STATE(3039),
    [sym_intersection_type] = STATE(3039),
    [sym_function_type] = STATE(3007),
    [sym_identifier] = ACTIONS(1532),
    [anon_sym_STAR] = ACTIONS(543),
    [anon_sym_LBRACE] = ACTIONS(1534),
    [anon_sym_typeof] = ACTIONS(1536),
    [anon_sym_import] = ACTIONS(1538),
    [anon_sym_const] = ACTIONS(133),
    [anon_sym_LPAREN] = ACTIONS(1540),
    [anon_sym_LBRACK] = ACTIONS(1542),
    [anon_sym_new] = ACTIONS(1642),
    [anon_sym_AMP] = ACTIONS(571),
    [anon_sym_PIPE] = ACTIONS(573),
    [anon_sym_PLUS] = ACTIONS(2497),
    [anon_sym_DASH] = ACTIONS(2497),
    [anon_sym_LT] = ACTIONS(2499),
    [anon_sym_void] = ACTIONS(216),
    [anon_sym_DQUOTE] = ACTIONS(1550),
    [anon_sym_SQUOTE] = ACTIONS(1552),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1554),
    [sym_number] = ACTIONS(1556),
    [sym_this] = ACTIONS(1558),
    [sym_true] = ACTIONS(1560),
    [sym_false] = ACTIONS(1560),
    [sym_null] = ACTIONS(1560),
    [sym_undefined] = ACTIONS(1560),
    [anon_sym_readonly] = ACTIONS(1648),
    [anon_sym_QMARK] = ACTIONS(593),
    [anon_sym_any] = ACTIONS(216),
    [anon_sym_number] = ACTIONS(216),
    [anon_sym_boolean] = ACTIONS(216),
    [anon_sym_string] = ACTIONS(216),
    [anon_sym_symbol] = ACTIONS(216),
    [anon_sym_object] = ACTIONS(216),
    [anon_sym_abstract] = ACTIONS(597),
    [anon_sym_infer] = ACTIONS(599),
    [anon_sym_keyof] = ACTIONS(601),
    [anon_sym_unique] = ACTIONS(214),
    [anon_sym_unknown] = ACTIONS(216),
    [anon_sym_never] = ACTIONS(216),
    [anon_sym_LBRACE_PIPE] = ACTIONS(218),
    [sym_html_comment] = ACTIONS(5),
  },
  [1039] = {
    [sym_import] = STATE(4681),
    [sym_nested_identifier] = STATE(5474),
    [sym_string] = STATE(2994),
    [sym_formal_parameters] = STATE(5619),
    [sym_nested_type_identifier] = STATE(2939),
    [sym__type_query_member_expression_in_type_annotation] = STATE(3303),
    [sym__type_query_call_expression_in_type_annotation] = STATE(2938),
    [sym_type] = STATE(3732),
    [sym_constructor_type] = STATE(3007),
    [sym_primary_type] = STATE(2981),
    [sym_template_literal_type] = STATE(3039),
    [sym_infer_type] = STATE(3007),
    [sym_conditional_type] = STATE(3039),
    [sym_generic_type] = STATE(3039),
    [sym_type_query] = STATE(3039),
    [sym_index_type_query] = STATE(3039),
    [sym_lookup_type] = STATE(3039),
    [sym_literal_type] = STATE(3039),
    [sym__number] = STATE(3041),
    [sym_existential_type] = STATE(3039),
    [sym_flow_maybe_type] = STATE(3039),
    [sym_parenthesized_type] = STATE(3039),
    [sym_predefined_type] = STATE(3039),
    [sym_object_type] = STATE(3039),
    [sym_type_parameters] = STATE(5454),
    [sym_array_type] = STATE(3039),
    [sym_tuple_type] = STATE(3039),
    [sym_readonly_type] = STATE(3007),
    [sym_union_type] = STATE(3039),
    [sym_intersection_type] = STATE(3039),
    [sym_function_type] = STATE(3007),
    [sym_identifier] = ACTIONS(1532),
    [anon_sym_STAR] = ACTIONS(543),
    [anon_sym_LBRACE] = ACTIONS(1534),
    [anon_sym_typeof] = ACTIONS(1536),
    [anon_sym_import] = ACTIONS(1538),
    [anon_sym_const] = ACTIONS(133),
    [anon_sym_LPAREN] = ACTIONS(1540),
    [anon_sym_LBRACK] = ACTIONS(1542),
    [anon_sym_new] = ACTIONS(1642),
    [anon_sym_AMP] = ACTIONS(571),
    [anon_sym_PIPE] = ACTIONS(573),
    [anon_sym_PLUS] = ACTIONS(2497),
    [anon_sym_DASH] = ACTIONS(2497),
    [anon_sym_LT] = ACTIONS(2499),
    [anon_sym_void] = ACTIONS(216),
    [anon_sym_DQUOTE] = ACTIONS(1550),
    [anon_sym_SQUOTE] = ACTIONS(1552),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1554),
    [sym_number] = ACTIONS(1556),
    [sym_this] = ACTIONS(1558),
    [sym_true] = ACTIONS(1560),
    [sym_false] = ACTIONS(1560),
    [sym_null] = ACTIONS(1560),
    [sym_undefined] = ACTIONS(1560),
    [anon_sym_readonly] = ACTIONS(1648),
    [anon_sym_QMARK] = ACTIONS(593),
    [anon_sym_any] = ACTIONS(216),
    [anon_sym_number] = ACTIONS(216),
    [anon_sym_boolean] = ACTIONS(216),
    [anon_sym_string] = ACTIONS(216),
    [anon_sym_symbol] = ACTIONS(216),
    [anon_sym_object] = ACTIONS(216),
    [anon_sym_abstract] = ACTIONS(597),
    [anon_sym_infer] = ACTIONS(599),
    [anon_sym_keyof] = ACTIONS(601),
    [anon_sym_unique] = ACTIONS(214),
    [anon_sym_unknown] = ACTIONS(216),
    [anon_sym_never] = ACTIONS(216),
    [anon_sym_LBRACE_PIPE] = ACTIONS(218),
    [sym_html_comment] = ACTIONS(5),
  },
  [1040] = {
    [sym_import] = STATE(4681),
    [sym_nested_identifier] = STATE(5474),
    [sym_string] = STATE(2994),
    [sym_formal_parameters] = STATE(5619),
    [sym_nested_type_identifier] = STATE(2939),
    [sym__type_query_member_expression_in_type_annotation] = STATE(3303),
    [sym__type_query_call_expression_in_type_annotation] = STATE(2938),
    [sym_type] = STATE(3733),
    [sym_constructor_type] = STATE(3007),
    [sym_primary_type] = STATE(2981),
    [sym_template_literal_type] = STATE(3039),
    [sym_infer_type] = STATE(3007),
    [sym_conditional_type] = STATE(3039),
    [sym_generic_type] = STATE(3039),
    [sym_type_query] = STATE(3039),
    [sym_index_type_query] = STATE(3039),
    [sym_lookup_type] = STATE(3039),
    [sym_literal_type] = STATE(3039),
    [sym__number] = STATE(3041),
    [sym_existential_type] = STATE(3039),
    [sym_flow_maybe_type] = STATE(3039),
    [sym_parenthesized_type] = STATE(3039),
    [sym_predefined_type] = STATE(3039),
    [sym_object_type] = STATE(3039),
    [sym_type_parameters] = STATE(5454),
    [sym_array_type] = STATE(3039),
    [sym_tuple_type] = STATE(3039),
    [sym_readonly_type] = STATE(3007),
    [sym_union_type] = STATE(3039),
    [sym_intersection_type] = STATE(3039),
    [sym_function_type] = STATE(3007),
    [sym_identifier] = ACTIONS(1532),
    [anon_sym_STAR] = ACTIONS(543),
    [anon_sym_LBRACE] = ACTIONS(1534),
    [anon_sym_typeof] = ACTIONS(1536),
    [anon_sym_import] = ACTIONS(1538),
    [anon_sym_const] = ACTIONS(133),
    [anon_sym_LPAREN] = ACTIONS(1540),
    [anon_sym_LBRACK] = ACTIONS(1542),
    [anon_sym_new] = ACTIONS(1642),
    [anon_sym_AMP] = ACTIONS(571),
    [anon_sym_PIPE] = ACTIONS(573),
    [anon_sym_PLUS] = ACTIONS(2497),
    [anon_sym_DASH] = ACTIONS(2497),
    [anon_sym_LT] = ACTIONS(2499),
    [anon_sym_void] = ACTIONS(216),
    [anon_sym_DQUOTE] = ACTIONS(1550),
    [anon_sym_SQUOTE] = ACTIONS(1552),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1554),
    [sym_number] = ACTIONS(1556),
    [sym_this] = ACTIONS(1558),
    [sym_true] = ACTIONS(1560),
    [sym_false] = ACTIONS(1560),
    [sym_null] = ACTIONS(1560),
    [sym_undefined] = ACTIONS(1560),
    [anon_sym_readonly] = ACTIONS(1648),
    [anon_sym_QMARK] = ACTIONS(593),
    [anon_sym_any] = ACTIONS(216),
    [anon_sym_number] = ACTIONS(216),
    [anon_sym_boolean] = ACTIONS(216),
    [anon_sym_string] = ACTIONS(216),
    [anon_sym_symbol] = ACTIONS(216),
    [anon_sym_object] = ACTIONS(216),
    [anon_sym_abstract] = ACTIONS(597),
    [anon_sym_infer] = ACTIONS(599),
    [anon_sym_keyof] = ACTIONS(601),
    [anon_sym_unique] = ACTIONS(214),
    [anon_sym_unknown] = ACTIONS(216),
    [anon_sym_never] = ACTIONS(216),
    [anon_sym_LBRACE_PIPE] = ACTIONS(218),
    [sym_html_comment] = ACTIONS(5),
  },
  [1041] = {
    [sym_import] = STATE(4950),
    [sym_nested_identifier] = STATE(5535),
    [sym_string] = STATE(3265),
    [sym_formal_parameters] = STATE(5840),
    [sym_nested_type_identifier] = STATE(3151),
    [sym__type_query_member_expression_in_type_annotation] = STATE(3076),
    [sym__type_query_call_expression_in_type_annotation] = STATE(3200),
    [sym_type] = STATE(3246),
    [sym_constructor_type] = STATE(3271),
    [sym_primary_type] = STATE(3272),
    [sym_template_literal_type] = STATE(3273),
    [sym_infer_type] = STATE(3271),
    [sym_conditional_type] = STATE(3273),
    [sym_generic_type] = STATE(3273),
    [sym_type_query] = STATE(3273),
    [sym_index_type_query] = STATE(3273),
    [sym_lookup_type] = STATE(3273),
    [sym_literal_type] = STATE(3273),
    [sym__number] = STATE(3274),
    [sym_existential_type] = STATE(3273),
    [sym_flow_maybe_type] = STATE(3273),
    [sym_parenthesized_type] = STATE(3273),
    [sym_predefined_type] = STATE(3273),
    [sym_object_type] = STATE(3273),
    [sym_type_parameters] = STATE(5146),
    [sym_array_type] = STATE(3273),
    [sym_tuple_type] = STATE(3273),
    [sym_readonly_type] = STATE(3271),
    [sym_union_type] = STATE(3273),
    [sym_intersection_type] = STATE(3273),
    [sym_function_type] = STATE(3271),
    [sym_identifier] = ACTIONS(1606),
    [anon_sym_STAR] = ACTIONS(986),
    [anon_sym_LBRACE] = ACTIONS(1610),
    [anon_sym_typeof] = ACTIONS(1612),
    [anon_sym_import] = ACTIONS(1538),
    [anon_sym_const] = ACTIONS(992),
    [anon_sym_LPAREN] = ACTIONS(1614),
    [anon_sym_LBRACK] = ACTIONS(1616),
    [anon_sym_new] = ACTIONS(1618),
    [anon_sym_AMP] = ACTIONS(1000),
    [anon_sym_PIPE] = ACTIONS(1002),
    [anon_sym_PLUS] = ACTIONS(2983),
    [anon_sym_DASH] = ACTIONS(2983),
    [anon_sym_LT] = ACTIONS(2499),
    [anon_sym_void] = ACTIONS(1032),
    [anon_sym_DQUOTE] = ACTIONS(1626),
    [anon_sym_SQUOTE] = ACTIONS(1628),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1630),
    [sym_number] = ACTIONS(1632),
    [sym_this] = ACTIONS(1634),
    [sym_true] = ACTIONS(1636),
    [sym_false] = ACTIONS(1636),
    [sym_null] = ACTIONS(1636),
    [sym_undefined] = ACTIONS(1636),
    [anon_sym_readonly] = ACTIONS(1638),
    [anon_sym_QMARK] = ACTIONS(1020),
    [anon_sym_any] = ACTIONS(1032),
    [anon_sym_number] = ACTIONS(1032),
    [anon_sym_boolean] = ACTIONS(1032),
    [anon_sym_string] = ACTIONS(1032),
    [anon_sym_symbol] = ACTIONS(1032),
    [anon_sym_object] = ACTIONS(1032),
    [anon_sym_abstract] = ACTIONS(1024),
    [anon_sym_infer] = ACTIONS(1026),
    [anon_sym_keyof] = ACTIONS(1028),
    [anon_sym_unique] = ACTIONS(1030),
    [anon_sym_unknown] = ACTIONS(1032),
    [anon_sym_never] = ACTIONS(1032),
    [anon_sym_LBRACE_PIPE] = ACTIONS(1034),
    [sym_html_comment] = ACTIONS(5),
  },
  [1042] = {
    [sym_import] = STATE(4950),
    [sym_nested_identifier] = STATE(5535),
    [sym_string] = STATE(3265),
    [sym_formal_parameters] = STATE(5840),
    [sym_nested_type_identifier] = STATE(3151),
    [sym__type_query_member_expression_in_type_annotation] = STATE(3076),
    [sym__type_query_call_expression_in_type_annotation] = STATE(3200),
    [sym_type] = STATE(3248),
    [sym_constructor_type] = STATE(3271),
    [sym_primary_type] = STATE(3272),
    [sym_template_literal_type] = STATE(3273),
    [sym_infer_type] = STATE(3271),
    [sym_conditional_type] = STATE(3273),
    [sym_generic_type] = STATE(3273),
    [sym_type_query] = STATE(3273),
    [sym_index_type_query] = STATE(3273),
    [sym_lookup_type] = STATE(3273),
    [sym_literal_type] = STATE(3273),
    [sym__number] = STATE(3274),
    [sym_existential_type] = STATE(3273),
    [sym_flow_maybe_type] = STATE(3273),
    [sym_parenthesized_type] = STATE(3273),
    [sym_predefined_type] = STATE(3273),
    [sym_object_type] = STATE(3273),
    [sym_type_parameters] = STATE(5146),
    [sym_array_type] = STATE(3273),
    [sym_tuple_type] = STATE(3273),
    [sym_readonly_type] = STATE(3271),
    [sym_union_type] = STATE(3273),
    [sym_intersection_type] = STATE(3273),
    [sym_function_type] = STATE(3271),
    [sym_identifier] = ACTIONS(1606),
    [anon_sym_STAR] = ACTIONS(986),
    [anon_sym_LBRACE] = ACTIONS(1610),
    [anon_sym_typeof] = ACTIONS(1612),
    [anon_sym_import] = ACTIONS(1538),
    [anon_sym_const] = ACTIONS(992),
    [anon_sym_LPAREN] = ACTIONS(1614),
    [anon_sym_LBRACK] = ACTIONS(1616),
    [anon_sym_new] = ACTIONS(1618),
    [anon_sym_AMP] = ACTIONS(1000),
    [anon_sym_PIPE] = ACTIONS(1002),
    [anon_sym_PLUS] = ACTIONS(2983),
    [anon_sym_DASH] = ACTIONS(2983),
    [anon_sym_LT] = ACTIONS(2499),
    [anon_sym_void] = ACTIONS(1032),
    [anon_sym_DQUOTE] = ACTIONS(1626),
    [anon_sym_SQUOTE] = ACTIONS(1628),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1630),
    [sym_number] = ACTIONS(1632),
    [sym_this] = ACTIONS(1634),
    [sym_true] = ACTIONS(1636),
    [sym_false] = ACTIONS(1636),
    [sym_null] = ACTIONS(1636),
    [sym_undefined] = ACTIONS(1636),
    [anon_sym_readonly] = ACTIONS(1638),
    [anon_sym_QMARK] = ACTIONS(1020),
    [anon_sym_any] = ACTIONS(1032),
    [anon_sym_number] = ACTIONS(1032),
    [anon_sym_boolean] = ACTIONS(1032),
    [anon_sym_string] = ACTIONS(1032),
    [anon_sym_symbol] = ACTIONS(1032),
    [anon_sym_object] = ACTIONS(1032),
    [anon_sym_abstract] = ACTIONS(1024),
    [anon_sym_infer] = ACTIONS(1026),
    [anon_sym_keyof] = ACTIONS(1028),
    [anon_sym_unique] = ACTIONS(1030),
    [anon_sym_unknown] = ACTIONS(1032),
    [anon_sym_never] = ACTIONS(1032),
    [anon_sym_LBRACE_PIPE] = ACTIONS(1034),
    [sym_html_comment] = ACTIONS(5),
  },
  [1043] = {
    [sym_import] = STATE(4681),
    [sym_nested_identifier] = STATE(5474),
    [sym_string] = STATE(2994),
    [sym_formal_parameters] = STATE(5619),
    [sym_nested_type_identifier] = STATE(2939),
    [sym__type_query_member_expression_in_type_annotation] = STATE(3303),
    [sym__type_query_call_expression_in_type_annotation] = STATE(2938),
    [sym_type] = STATE(2955),
    [sym_constructor_type] = STATE(3007),
    [sym_primary_type] = STATE(2981),
    [sym_template_literal_type] = STATE(3039),
    [sym_infer_type] = STATE(3007),
    [sym_conditional_type] = STATE(3039),
    [sym_generic_type] = STATE(3039),
    [sym_type_query] = STATE(3039),
    [sym_index_type_query] = STATE(3039),
    [sym_lookup_type] = STATE(3039),
    [sym_literal_type] = STATE(3039),
    [sym__number] = STATE(3041),
    [sym_existential_type] = STATE(3039),
    [sym_flow_maybe_type] = STATE(3039),
    [sym_parenthesized_type] = STATE(3039),
    [sym_predefined_type] = STATE(3039),
    [sym_object_type] = STATE(3039),
    [sym_type_parameters] = STATE(5454),
    [sym_array_type] = STATE(3039),
    [sym_tuple_type] = STATE(3039),
    [sym_readonly_type] = STATE(3007),
    [sym_union_type] = STATE(3039),
    [sym_intersection_type] = STATE(3039),
    [sym_function_type] = STATE(3007),
    [sym_identifier] = ACTIONS(1532),
    [anon_sym_STAR] = ACTIONS(543),
    [anon_sym_LBRACE] = ACTIONS(1534),
    [anon_sym_typeof] = ACTIONS(1536),
    [anon_sym_import] = ACTIONS(1538),
    [anon_sym_const] = ACTIONS(133),
    [anon_sym_LPAREN] = ACTIONS(1540),
    [anon_sym_LBRACK] = ACTIONS(1542),
    [anon_sym_new] = ACTIONS(1642),
    [anon_sym_AMP] = ACTIONS(571),
    [anon_sym_PIPE] = ACTIONS(573),
    [anon_sym_PLUS] = ACTIONS(2497),
    [anon_sym_DASH] = ACTIONS(2497),
    [anon_sym_LT] = ACTIONS(2499),
    [anon_sym_void] = ACTIONS(216),
    [anon_sym_DQUOTE] = ACTIONS(1550),
    [anon_sym_SQUOTE] = ACTIONS(1552),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1554),
    [sym_number] = ACTIONS(1556),
    [sym_this] = ACTIONS(1558),
    [sym_true] = ACTIONS(1560),
    [sym_false] = ACTIONS(1560),
    [sym_null] = ACTIONS(1560),
    [sym_undefined] = ACTIONS(1560),
    [anon_sym_readonly] = ACTIONS(1648),
    [anon_sym_QMARK] = ACTIONS(593),
    [anon_sym_any] = ACTIONS(216),
    [anon_sym_number] = ACTIONS(216),
    [anon_sym_boolean] = ACTIONS(216),
    [anon_sym_string] = ACTIONS(216),
    [anon_sym_symbol] = ACTIONS(216),
    [anon_sym_object] = ACTIONS(216),
    [anon_sym_abstract] = ACTIONS(597),
    [anon_sym_infer] = ACTIONS(599),
    [anon_sym_keyof] = ACTIONS(601),
    [anon_sym_unique] = ACTIONS(214),
    [anon_sym_unknown] = ACTIONS(216),
    [anon_sym_never] = ACTIONS(216),
    [anon_sym_LBRACE_PIPE] = ACTIONS(218),
    [sym_html_comment] = ACTIONS(5),
  },
  [1044] = {
    [sym_import] = STATE(4681),
    [sym_nested_identifier] = STATE(5474),
    [sym_string] = STATE(2994),
    [sym_formal_parameters] = STATE(5619),
    [sym_nested_type_identifier] = STATE(2939),
    [sym__type_query_member_expression_in_type_annotation] = STATE(3303),
    [sym__type_query_call_expression_in_type_annotation] = STATE(2938),
    [sym_type] = STATE(2972),
    [sym_constructor_type] = STATE(3007),
    [sym_primary_type] = STATE(2981),
    [sym_template_literal_type] = STATE(3039),
    [sym_infer_type] = STATE(3007),
    [sym_conditional_type] = STATE(3039),
    [sym_generic_type] = STATE(3039),
    [sym_type_query] = STATE(3039),
    [sym_index_type_query] = STATE(3039),
    [sym_lookup_type] = STATE(3039),
    [sym_literal_type] = STATE(3039),
    [sym__number] = STATE(3041),
    [sym_existential_type] = STATE(3039),
    [sym_flow_maybe_type] = STATE(3039),
    [sym_parenthesized_type] = STATE(3039),
    [sym_predefined_type] = STATE(3039),
    [sym_object_type] = STATE(3039),
    [sym_type_parameters] = STATE(5454),
    [sym_array_type] = STATE(3039),
    [sym_tuple_type] = STATE(3039),
    [sym_readonly_type] = STATE(3007),
    [sym_union_type] = STATE(3039),
    [sym_intersection_type] = STATE(3039),
    [sym_function_type] = STATE(3007),
    [sym_identifier] = ACTIONS(1532),
    [anon_sym_STAR] = ACTIONS(543),
    [anon_sym_LBRACE] = ACTIONS(1534),
    [anon_sym_typeof] = ACTIONS(1536),
    [anon_sym_import] = ACTIONS(1538),
    [anon_sym_const] = ACTIONS(133),
    [anon_sym_LPAREN] = ACTIONS(1540),
    [anon_sym_LBRACK] = ACTIONS(1542),
    [anon_sym_new] = ACTIONS(1642),
    [anon_sym_AMP] = ACTIONS(571),
    [anon_sym_PIPE] = ACTIONS(573),
    [anon_sym_PLUS] = ACTIONS(2497),
    [anon_sym_DASH] = ACTIONS(2497),
    [anon_sym_LT] = ACTIONS(2499),
    [anon_sym_void] = ACTIONS(216),
    [anon_sym_DQUOTE] = ACTIONS(1550),
    [anon_sym_SQUOTE] = ACTIONS(1552),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1554),
    [sym_number] = ACTIONS(1556),
    [sym_this] = ACTIONS(1558),
    [sym_true] = ACTIONS(1560),
    [sym_false] = ACTIONS(1560),
    [sym_null] = ACTIONS(1560),
    [sym_undefined] = ACTIONS(1560),
    [anon_sym_readonly] = ACTIONS(1648),
    [anon_sym_QMARK] = ACTIONS(593),
    [anon_sym_any] = ACTIONS(216),
    [anon_sym_number] = ACTIONS(216),
    [anon_sym_boolean] = ACTIONS(216),
    [anon_sym_string] = ACTIONS(216),
    [anon_sym_symbol] = ACTIONS(216),
    [anon_sym_object] = ACTIONS(216),
    [anon_sym_abstract] = ACTIONS(597),
    [anon_sym_infer] = ACTIONS(599),
    [anon_sym_keyof] = ACTIONS(601),
    [anon_sym_unique] = ACTIONS(214),
    [anon_sym_unknown] = ACTIONS(216),
    [anon_sym_never] = ACTIONS(216),
    [anon_sym_LBRACE_PIPE] = ACTIONS(218),
    [sym_html_comment] = ACTIONS(5),
  },
  [1045] = {
    [sym_import] = STATE(4878),
    [sym_nested_identifier] = STATE(5474),
    [sym_string] = STATE(2994),
    [sym_formal_parameters] = STATE(5475),
    [sym_nested_type_identifier] = STATE(2939),
    [sym__type_query_member_expression_in_type_annotation] = STATE(2937),
    [sym__type_query_call_expression_in_type_annotation] = STATE(2938),
    [sym_type] = STATE(4498),
    [sym_constructor_type] = STATE(3007),
    [sym_primary_type] = STATE(2981),
    [sym_template_literal_type] = STATE(3039),
    [sym_infer_type] = STATE(3007),
    [sym_conditional_type] = STATE(3039),
    [sym_generic_type] = STATE(3039),
    [sym_type_query] = STATE(3039),
    [sym_index_type_query] = STATE(3039),
    [sym_lookup_type] = STATE(3039),
    [sym_literal_type] = STATE(3039),
    [sym__number] = STATE(3041),
    [sym_existential_type] = STATE(3039),
    [sym_flow_maybe_type] = STATE(3039),
    [sym_parenthesized_type] = STATE(3039),
    [sym_predefined_type] = STATE(3039),
    [sym_object_type] = STATE(3039),
    [sym_type_parameters] = STATE(5248),
    [sym_array_type] = STATE(3039),
    [sym_tuple_type] = STATE(3039),
    [sym_readonly_type] = STATE(3007),
    [sym_union_type] = STATE(3039),
    [sym_intersection_type] = STATE(3039),
    [sym_function_type] = STATE(3007),
    [sym_identifier] = ACTIONS(1532),
    [anon_sym_STAR] = ACTIONS(543),
    [anon_sym_LBRACE] = ACTIONS(1534),
    [anon_sym_typeof] = ACTIONS(1536),
    [anon_sym_import] = ACTIONS(1538),
    [anon_sym_const] = ACTIONS(133),
    [anon_sym_LPAREN] = ACTIONS(1540),
    [anon_sym_LBRACK] = ACTIONS(1542),
    [anon_sym_new] = ACTIONS(1544),
    [anon_sym_AMP] = ACTIONS(748),
    [anon_sym_PIPE] = ACTIONS(750),
    [anon_sym_PLUS] = ACTIONS(2497),
    [anon_sym_DASH] = ACTIONS(2497),
    [anon_sym_LT] = ACTIONS(2499),
    [anon_sym_void] = ACTIONS(216),
    [anon_sym_DQUOTE] = ACTIONS(1550),
    [anon_sym_SQUOTE] = ACTIONS(1552),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1554),
    [sym_number] = ACTIONS(1556),
    [sym_this] = ACTIONS(1558),
    [sym_true] = ACTIONS(1560),
    [sym_false] = ACTIONS(1560),
    [sym_null] = ACTIONS(1560),
    [sym_undefined] = ACTIONS(1560),
    [anon_sym_readonly] = ACTIONS(1562),
    [anon_sym_QMARK] = ACTIONS(774),
    [anon_sym_any] = ACTIONS(216),
    [anon_sym_number] = ACTIONS(216),
    [anon_sym_boolean] = ACTIONS(216),
    [anon_sym_string] = ACTIONS(216),
    [anon_sym_symbol] = ACTIONS(216),
    [anon_sym_object] = ACTIONS(216),
    [anon_sym_abstract] = ACTIONS(208),
    [anon_sym_infer] = ACTIONS(210),
    [anon_sym_keyof] = ACTIONS(212),
    [anon_sym_unique] = ACTIONS(214),
    [anon_sym_unknown] = ACTIONS(216),
    [anon_sym_never] = ACTIONS(216),
    [anon_sym_LBRACE_PIPE] = ACTIONS(218),
    [sym_html_comment] = ACTIONS(5),
  },
  [1046] = {
    [sym_import] = STATE(4950),
    [sym_nested_identifier] = STATE(5535),
    [sym_string] = STATE(3265),
    [sym_formal_parameters] = STATE(5840),
    [sym_nested_type_identifier] = STATE(3151),
    [sym__type_query_member_expression_in_type_annotation] = STATE(3076),
    [sym__type_query_call_expression_in_type_annotation] = STATE(3200),
    [sym_type] = STATE(4005),
    [sym_constructor_type] = STATE(3271),
    [sym_primary_type] = STATE(3272),
    [sym_template_literal_type] = STATE(3273),
    [sym_infer_type] = STATE(3271),
    [sym_conditional_type] = STATE(3273),
    [sym_generic_type] = STATE(3273),
    [sym_type_query] = STATE(3273),
    [sym_index_type_query] = STATE(3273),
    [sym_lookup_type] = STATE(3273),
    [sym_literal_type] = STATE(3273),
    [sym__number] = STATE(3274),
    [sym_existential_type] = STATE(3273),
    [sym_flow_maybe_type] = STATE(3273),
    [sym_parenthesized_type] = STATE(3273),
    [sym_predefined_type] = STATE(3273),
    [sym_object_type] = STATE(3273),
    [sym_type_parameters] = STATE(5146),
    [sym_array_type] = STATE(3273),
    [sym_tuple_type] = STATE(3273),
    [sym_readonly_type] = STATE(3271),
    [sym_union_type] = STATE(3273),
    [sym_intersection_type] = STATE(3273),
    [sym_function_type] = STATE(3271),
    [sym_identifier] = ACTIONS(1606),
    [anon_sym_STAR] = ACTIONS(986),
    [anon_sym_LBRACE] = ACTIONS(1610),
    [anon_sym_typeof] = ACTIONS(1612),
    [anon_sym_import] = ACTIONS(1538),
    [anon_sym_const] = ACTIONS(992),
    [anon_sym_LPAREN] = ACTIONS(1614),
    [anon_sym_LBRACK] = ACTIONS(1616),
    [anon_sym_new] = ACTIONS(1618),
    [anon_sym_AMP] = ACTIONS(1000),
    [anon_sym_PIPE] = ACTIONS(1002),
    [anon_sym_PLUS] = ACTIONS(2983),
    [anon_sym_DASH] = ACTIONS(2983),
    [anon_sym_LT] = ACTIONS(2499),
    [anon_sym_void] = ACTIONS(1032),
    [anon_sym_DQUOTE] = ACTIONS(1626),
    [anon_sym_SQUOTE] = ACTIONS(1628),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1630),
    [sym_number] = ACTIONS(1632),
    [sym_this] = ACTIONS(1634),
    [sym_true] = ACTIONS(1636),
    [sym_false] = ACTIONS(1636),
    [sym_null] = ACTIONS(1636),
    [sym_undefined] = ACTIONS(1636),
    [anon_sym_readonly] = ACTIONS(1638),
    [anon_sym_QMARK] = ACTIONS(1020),
    [anon_sym_any] = ACTIONS(1032),
    [anon_sym_number] = ACTIONS(1032),
    [anon_sym_boolean] = ACTIONS(1032),
    [anon_sym_string] = ACTIONS(1032),
    [anon_sym_symbol] = ACTIONS(1032),
    [anon_sym_object] = ACTIONS(1032),
    [anon_sym_abstract] = ACTIONS(1024),
    [anon_sym_infer] = ACTIONS(1026),
    [anon_sym_keyof] = ACTIONS(1028),
    [anon_sym_unique] = ACTIONS(1030),
    [anon_sym_unknown] = ACTIONS(1032),
    [anon_sym_never] = ACTIONS(1032),
    [anon_sym_LBRACE_PIPE] = ACTIONS(1034),
    [sym_html_comment] = ACTIONS(5),
  },
  [1047] = {
    [sym_import] = STATE(4681),
    [sym_nested_identifier] = STATE(5474),
    [sym_string] = STATE(2994),
    [sym_formal_parameters] = STATE(5619),
    [sym_nested_type_identifier] = STATE(2939),
    [sym__type_query_member_expression_in_type_annotation] = STATE(3303),
    [sym__type_query_call_expression_in_type_annotation] = STATE(2938),
    [sym_type] = STATE(2962),
    [sym_constructor_type] = STATE(3007),
    [sym_primary_type] = STATE(2981),
    [sym_template_literal_type] = STATE(3039),
    [sym_infer_type] = STATE(3007),
    [sym_conditional_type] = STATE(3039),
    [sym_generic_type] = STATE(3039),
    [sym_type_query] = STATE(3039),
    [sym_index_type_query] = STATE(3039),
    [sym_lookup_type] = STATE(3039),
    [sym_literal_type] = STATE(3039),
    [sym__number] = STATE(3041),
    [sym_existential_type] = STATE(3039),
    [sym_flow_maybe_type] = STATE(3039),
    [sym_parenthesized_type] = STATE(3039),
    [sym_predefined_type] = STATE(3039),
    [sym_object_type] = STATE(3039),
    [sym_type_parameters] = STATE(5454),
    [sym_array_type] = STATE(3039),
    [sym_tuple_type] = STATE(3039),
    [sym_readonly_type] = STATE(3007),
    [sym_union_type] = STATE(3039),
    [sym_intersection_type] = STATE(3039),
    [sym_function_type] = STATE(3007),
    [sym_identifier] = ACTIONS(1532),
    [anon_sym_STAR] = ACTIONS(543),
    [anon_sym_LBRACE] = ACTIONS(1534),
    [anon_sym_typeof] = ACTIONS(1536),
    [anon_sym_import] = ACTIONS(1538),
    [anon_sym_const] = ACTIONS(133),
    [anon_sym_LPAREN] = ACTIONS(1540),
    [anon_sym_LBRACK] = ACTIONS(1542),
    [anon_sym_new] = ACTIONS(1642),
    [anon_sym_AMP] = ACTIONS(571),
    [anon_sym_PIPE] = ACTIONS(573),
    [anon_sym_PLUS] = ACTIONS(2497),
    [anon_sym_DASH] = ACTIONS(2497),
    [anon_sym_LT] = ACTIONS(2499),
    [anon_sym_void] = ACTIONS(216),
    [anon_sym_DQUOTE] = ACTIONS(1550),
    [anon_sym_SQUOTE] = ACTIONS(1552),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1554),
    [sym_number] = ACTIONS(1556),
    [sym_this] = ACTIONS(1558),
    [sym_true] = ACTIONS(1560),
    [sym_false] = ACTIONS(1560),
    [sym_null] = ACTIONS(1560),
    [sym_undefined] = ACTIONS(1560),
    [anon_sym_readonly] = ACTIONS(1648),
    [anon_sym_QMARK] = ACTIONS(593),
    [anon_sym_any] = ACTIONS(216),
    [anon_sym_number] = ACTIONS(216),
    [anon_sym_boolean] = ACTIONS(216),
    [anon_sym_string] = ACTIONS(216),
    [anon_sym_symbol] = ACTIONS(216),
    [anon_sym_object] = ACTIONS(216),
    [anon_sym_abstract] = ACTIONS(597),
    [anon_sym_infer] = ACTIONS(599),
    [anon_sym_keyof] = ACTIONS(601),
    [anon_sym_unique] = ACTIONS(214),
    [anon_sym_unknown] = ACTIONS(216),
    [anon_sym_never] = ACTIONS(216),
    [anon_sym_LBRACE_PIPE] = ACTIONS(218),
    [sym_html_comment] = ACTIONS(5),
  },
  [1048] = {
    [sym_import] = STATE(4681),
    [sym_nested_identifier] = STATE(5474),
    [sym_string] = STATE(2994),
    [sym_formal_parameters] = STATE(5619),
    [sym_nested_type_identifier] = STATE(2939),
    [sym__type_query_member_expression_in_type_annotation] = STATE(3303),
    [sym__type_query_call_expression_in_type_annotation] = STATE(2938),
    [sym_type] = STATE(3542),
    [sym_constructor_type] = STATE(3007),
    [sym_primary_type] = STATE(2981),
    [sym_template_literal_type] = STATE(3039),
    [sym_infer_type] = STATE(3007),
    [sym_conditional_type] = STATE(3039),
    [sym_generic_type] = STATE(3039),
    [sym_type_query] = STATE(3039),
    [sym_index_type_query] = STATE(3039),
    [sym_lookup_type] = STATE(3039),
    [sym_literal_type] = STATE(3039),
    [sym__number] = STATE(3041),
    [sym_existential_type] = STATE(3039),
    [sym_flow_maybe_type] = STATE(3039),
    [sym_parenthesized_type] = STATE(3039),
    [sym_predefined_type] = STATE(3039),
    [sym_object_type] = STATE(3039),
    [sym_type_parameters] = STATE(5454),
    [sym_array_type] = STATE(3039),
    [sym_tuple_type] = STATE(3039),
    [sym_readonly_type] = STATE(3007),
    [sym_union_type] = STATE(3039),
    [sym_intersection_type] = STATE(3039),
    [sym_function_type] = STATE(3007),
    [sym_identifier] = ACTIONS(1532),
    [anon_sym_STAR] = ACTIONS(543),
    [anon_sym_LBRACE] = ACTIONS(1534),
    [anon_sym_typeof] = ACTIONS(1536),
    [anon_sym_import] = ACTIONS(1538),
    [anon_sym_const] = ACTIONS(133),
    [anon_sym_LPAREN] = ACTIONS(1540),
    [anon_sym_LBRACK] = ACTIONS(1542),
    [anon_sym_new] = ACTIONS(1642),
    [anon_sym_AMP] = ACTIONS(571),
    [anon_sym_PIPE] = ACTIONS(573),
    [anon_sym_PLUS] = ACTIONS(2497),
    [anon_sym_DASH] = ACTIONS(2497),
    [anon_sym_LT] = ACTIONS(2499),
    [anon_sym_void] = ACTIONS(216),
    [anon_sym_DQUOTE] = ACTIONS(1550),
    [anon_sym_SQUOTE] = ACTIONS(1552),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1554),
    [sym_number] = ACTIONS(1556),
    [sym_this] = ACTIONS(1558),
    [sym_true] = ACTIONS(1560),
    [sym_false] = ACTIONS(1560),
    [sym_null] = ACTIONS(1560),
    [sym_undefined] = ACTIONS(1560),
    [anon_sym_readonly] = ACTIONS(1648),
    [anon_sym_QMARK] = ACTIONS(593),
    [anon_sym_any] = ACTIONS(216),
    [anon_sym_number] = ACTIONS(216),
    [anon_sym_boolean] = ACTIONS(216),
    [anon_sym_string] = ACTIONS(216),
    [anon_sym_symbol] = ACTIONS(216),
    [anon_sym_object] = ACTIONS(216),
    [anon_sym_abstract] = ACTIONS(597),
    [anon_sym_infer] = ACTIONS(599),
    [anon_sym_keyof] = ACTIONS(601),
    [anon_sym_unique] = ACTIONS(214),
    [anon_sym_unknown] = ACTIONS(216),
    [anon_sym_never] = ACTIONS(216),
    [anon_sym_LBRACE_PIPE] = ACTIONS(218),
    [sym_html_comment] = ACTIONS(5),
  },
  [1049] = {
    [sym_import] = STATE(4950),
    [sym_nested_identifier] = STATE(5535),
    [sym_string] = STATE(3265),
    [sym_formal_parameters] = STATE(5840),
    [sym_nested_type_identifier] = STATE(3151),
    [sym__type_query_member_expression_in_type_annotation] = STATE(3076),
    [sym__type_query_call_expression_in_type_annotation] = STATE(3200),
    [sym_type] = STATE(3466),
    [sym_constructor_type] = STATE(3271),
    [sym_primary_type] = STATE(3272),
    [sym_template_literal_type] = STATE(3273),
    [sym_infer_type] = STATE(3271),
    [sym_conditional_type] = STATE(3273),
    [sym_generic_type] = STATE(3273),
    [sym_type_query] = STATE(3273),
    [sym_index_type_query] = STATE(3273),
    [sym_lookup_type] = STATE(3273),
    [sym_literal_type] = STATE(3273),
    [sym__number] = STATE(3274),
    [sym_existential_type] = STATE(3273),
    [sym_flow_maybe_type] = STATE(3273),
    [sym_parenthesized_type] = STATE(3273),
    [sym_predefined_type] = STATE(3273),
    [sym_object_type] = STATE(3273),
    [sym_type_parameters] = STATE(5146),
    [sym_array_type] = STATE(3273),
    [sym_tuple_type] = STATE(3273),
    [sym_readonly_type] = STATE(3271),
    [sym_union_type] = STATE(3273),
    [sym_intersection_type] = STATE(3273),
    [sym_function_type] = STATE(3271),
    [sym_identifier] = ACTIONS(1606),
    [anon_sym_STAR] = ACTIONS(986),
    [anon_sym_LBRACE] = ACTIONS(1610),
    [anon_sym_typeof] = ACTIONS(1612),
    [anon_sym_import] = ACTIONS(1538),
    [anon_sym_const] = ACTIONS(992),
    [anon_sym_LPAREN] = ACTIONS(1614),
    [anon_sym_LBRACK] = ACTIONS(1616),
    [anon_sym_new] = ACTIONS(1618),
    [anon_sym_AMP] = ACTIONS(1000),
    [anon_sym_PIPE] = ACTIONS(1002),
    [anon_sym_PLUS] = ACTIONS(2983),
    [anon_sym_DASH] = ACTIONS(2983),
    [anon_sym_LT] = ACTIONS(2499),
    [anon_sym_void] = ACTIONS(1032),
    [anon_sym_DQUOTE] = ACTIONS(1626),
    [anon_sym_SQUOTE] = ACTIONS(1628),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1630),
    [sym_number] = ACTIONS(1632),
    [sym_this] = ACTIONS(1634),
    [sym_true] = ACTIONS(1636),
    [sym_false] = ACTIONS(1636),
    [sym_null] = ACTIONS(1636),
    [sym_undefined] = ACTIONS(1636),
    [anon_sym_readonly] = ACTIONS(1638),
    [anon_sym_QMARK] = ACTIONS(1020),
    [anon_sym_any] = ACTIONS(1032),
    [anon_sym_number] = ACTIONS(1032),
    [anon_sym_boolean] = ACTIONS(1032),
    [anon_sym_string] = ACTIONS(1032),
    [anon_sym_symbol] = ACTIONS(1032),
    [anon_sym_object] = ACTIONS(1032),
    [anon_sym_abstract] = ACTIONS(1024),
    [anon_sym_infer] = ACTIONS(1026),
    [anon_sym_keyof] = ACTIONS(1028),
    [anon_sym_unique] = ACTIONS(1030),
    [anon_sym_unknown] = ACTIONS(1032),
    [anon_sym_never] = ACTIONS(1032),
    [anon_sym_LBRACE_PIPE] = ACTIONS(1034),
    [sym_html_comment] = ACTIONS(5),
  },
  [1050] = {
    [sym_import] = STATE(4950),
    [sym_nested_identifier] = STATE(5535),
    [sym_string] = STATE(3265),
    [sym_formal_parameters] = STATE(5840),
    [sym_nested_type_identifier] = STATE(3151),
    [sym__type_query_member_expression_in_type_annotation] = STATE(3076),
    [sym__type_query_call_expression_in_type_annotation] = STATE(3200),
    [sym_type] = STATE(3464),
    [sym_constructor_type] = STATE(3271),
    [sym_primary_type] = STATE(3272),
    [sym_template_literal_type] = STATE(3273),
    [sym_infer_type] = STATE(3271),
    [sym_conditional_type] = STATE(3273),
    [sym_generic_type] = STATE(3273),
    [sym_type_query] = STATE(3273),
    [sym_index_type_query] = STATE(3273),
    [sym_lookup_type] = STATE(3273),
    [sym_literal_type] = STATE(3273),
    [sym__number] = STATE(3274),
    [sym_existential_type] = STATE(3273),
    [sym_flow_maybe_type] = STATE(3273),
    [sym_parenthesized_type] = STATE(3273),
    [sym_predefined_type] = STATE(3273),
    [sym_object_type] = STATE(3273),
    [sym_type_parameters] = STATE(5146),
    [sym_array_type] = STATE(3273),
    [sym_tuple_type] = STATE(3273),
    [sym_readonly_type] = STATE(3271),
    [sym_union_type] = STATE(3273),
    [sym_intersection_type] = STATE(3273),
    [sym_function_type] = STATE(3271),
    [sym_identifier] = ACTIONS(1606),
    [anon_sym_STAR] = ACTIONS(986),
    [anon_sym_LBRACE] = ACTIONS(1610),
    [anon_sym_typeof] = ACTIONS(1612),
    [anon_sym_import] = ACTIONS(1538),
    [anon_sym_const] = ACTIONS(992),
    [anon_sym_LPAREN] = ACTIONS(1614),
    [anon_sym_LBRACK] = ACTIONS(1616),
    [anon_sym_new] = ACTIONS(1618),
    [anon_sym_AMP] = ACTIONS(1000),
    [anon_sym_PIPE] = ACTIONS(1002),
    [anon_sym_PLUS] = ACTIONS(2983),
    [anon_sym_DASH] = ACTIONS(2983),
    [anon_sym_LT] = ACTIONS(2499),
    [anon_sym_void] = ACTIONS(1032),
    [anon_sym_DQUOTE] = ACTIONS(1626),
    [anon_sym_SQUOTE] = ACTIONS(1628),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1630),
    [sym_number] = ACTIONS(1632),
    [sym_this] = ACTIONS(1634),
    [sym_true] = ACTIONS(1636),
    [sym_false] = ACTIONS(1636),
    [sym_null] = ACTIONS(1636),
    [sym_undefined] = ACTIONS(1636),
    [anon_sym_readonly] = ACTIONS(1638),
    [anon_sym_QMARK] = ACTIONS(1020),
    [anon_sym_any] = ACTIONS(1032),
    [anon_sym_number] = ACTIONS(1032),
    [anon_sym_boolean] = ACTIONS(1032),
    [anon_sym_string] = ACTIONS(1032),
    [anon_sym_symbol] = ACTIONS(1032),
    [anon_sym_object] = ACTIONS(1032),
    [anon_sym_abstract] = ACTIONS(1024),
    [anon_sym_infer] = ACTIONS(1026),
    [anon_sym_keyof] = ACTIONS(1028),
    [anon_sym_unique] = ACTIONS(1030),
    [anon_sym_unknown] = ACTIONS(1032),
    [anon_sym_never] = ACTIONS(1032),
    [anon_sym_LBRACE_PIPE] = ACTIONS(1034),
    [sym_html_comment] = ACTIONS(5),
  },
  [1051] = {
    [sym_import] = STATE(4950),
    [sym_nested_identifier] = STATE(5535),
    [sym_string] = STATE(3265),
    [sym_formal_parameters] = STATE(5840),
    [sym_nested_type_identifier] = STATE(3151),
    [sym__type_query_member_expression_in_type_annotation] = STATE(3076),
    [sym__type_query_call_expression_in_type_annotation] = STATE(3200),
    [sym_type] = STATE(3467),
    [sym_constructor_type] = STATE(3271),
    [sym_primary_type] = STATE(3272),
    [sym_template_literal_type] = STATE(3273),
    [sym_infer_type] = STATE(3271),
    [sym_conditional_type] = STATE(3273),
    [sym_generic_type] = STATE(3273),
    [sym_type_query] = STATE(3273),
    [sym_index_type_query] = STATE(3273),
    [sym_lookup_type] = STATE(3273),
    [sym_literal_type] = STATE(3273),
    [sym__number] = STATE(3274),
    [sym_existential_type] = STATE(3273),
    [sym_flow_maybe_type] = STATE(3273),
    [sym_parenthesized_type] = STATE(3273),
    [sym_predefined_type] = STATE(3273),
    [sym_object_type] = STATE(3273),
    [sym_type_parameters] = STATE(5146),
    [sym_array_type] = STATE(3273),
    [sym_tuple_type] = STATE(3273),
    [sym_readonly_type] = STATE(3271),
    [sym_union_type] = STATE(3273),
    [sym_intersection_type] = STATE(3273),
    [sym_function_type] = STATE(3271),
    [sym_identifier] = ACTIONS(1606),
    [anon_sym_STAR] = ACTIONS(986),
    [anon_sym_LBRACE] = ACTIONS(1610),
    [anon_sym_typeof] = ACTIONS(1612),
    [anon_sym_import] = ACTIONS(1538),
    [anon_sym_const] = ACTIONS(992),
    [anon_sym_LPAREN] = ACTIONS(1614),
    [anon_sym_LBRACK] = ACTIONS(1616),
    [anon_sym_new] = ACTIONS(1618),
    [anon_sym_AMP] = ACTIONS(1000),
    [anon_sym_PIPE] = ACTIONS(1002),
    [anon_sym_PLUS] = ACTIONS(2983),
    [anon_sym_DASH] = ACTIONS(2983),
    [anon_sym_LT] = ACTIONS(2499),
    [anon_sym_void] = ACTIONS(1032),
    [anon_sym_DQUOTE] = ACTIONS(1626),
    [anon_sym_SQUOTE] = ACTIONS(1628),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1630),
    [sym_number] = ACTIONS(1632),
    [sym_this] = ACTIONS(1634),
    [sym_true] = ACTIONS(1636),
    [sym_false] = ACTIONS(1636),
    [sym_null] = ACTIONS(1636),
    [sym_undefined] = ACTIONS(1636),
    [anon_sym_readonly] = ACTIONS(1638),
    [anon_sym_QMARK] = ACTIONS(1020),
    [anon_sym_any] = ACTIONS(1032),
    [anon_sym_number] = ACTIONS(1032),
    [anon_sym_boolean] = ACTIONS(1032),
    [anon_sym_string] = ACTIONS(1032),
    [anon_sym_symbol] = ACTIONS(1032),
    [anon_sym_object] = ACTIONS(1032),
    [anon_sym_abstract] = ACTIONS(1024),
    [anon_sym_infer] = ACTIONS(1026),
    [anon_sym_keyof] = ACTIONS(1028),
    [anon_sym_unique] = ACTIONS(1030),
    [anon_sym_unknown] = ACTIONS(1032),
    [anon_sym_never] = ACTIONS(1032),
    [anon_sym_LBRACE_PIPE] = ACTIONS(1034),
    [sym_html_comment] = ACTIONS(5),
  },
  [1052] = {
    [sym_import] = STATE(4878),
    [sym_nested_identifier] = STATE(5474),
    [sym_string] = STATE(2994),
    [sym_formal_parameters] = STATE(5475),
    [sym_nested_type_identifier] = STATE(2939),
    [sym__type_query_member_expression_in_type_annotation] = STATE(2937),
    [sym__type_query_call_expression_in_type_annotation] = STATE(2938),
    [sym_type] = STATE(4514),
    [sym_constructor_type] = STATE(3007),
    [sym_primary_type] = STATE(2981),
    [sym_template_literal_type] = STATE(3039),
    [sym_infer_type] = STATE(3007),
    [sym_conditional_type] = STATE(3039),
    [sym_generic_type] = STATE(3039),
    [sym_type_query] = STATE(3039),
    [sym_index_type_query] = STATE(3039),
    [sym_lookup_type] = STATE(3039),
    [sym_literal_type] = STATE(3039),
    [sym__number] = STATE(3041),
    [sym_existential_type] = STATE(3039),
    [sym_flow_maybe_type] = STATE(3039),
    [sym_parenthesized_type] = STATE(3039),
    [sym_predefined_type] = STATE(3039),
    [sym_object_type] = STATE(3039),
    [sym_type_parameters] = STATE(5248),
    [sym_array_type] = STATE(3039),
    [sym_tuple_type] = STATE(3039),
    [sym_readonly_type] = STATE(3007),
    [sym_union_type] = STATE(3039),
    [sym_intersection_type] = STATE(3039),
    [sym_function_type] = STATE(3007),
    [sym_identifier] = ACTIONS(1532),
    [anon_sym_STAR] = ACTIONS(543),
    [anon_sym_LBRACE] = ACTIONS(1534),
    [anon_sym_typeof] = ACTIONS(1536),
    [anon_sym_import] = ACTIONS(1538),
    [anon_sym_const] = ACTIONS(133),
    [anon_sym_LPAREN] = ACTIONS(1540),
    [anon_sym_LBRACK] = ACTIONS(1542),
    [anon_sym_new] = ACTIONS(1544),
    [anon_sym_AMP] = ACTIONS(748),
    [anon_sym_PIPE] = ACTIONS(750),
    [anon_sym_PLUS] = ACTIONS(2497),
    [anon_sym_DASH] = ACTIONS(2497),
    [anon_sym_LT] = ACTIONS(2499),
    [anon_sym_void] = ACTIONS(216),
    [anon_sym_DQUOTE] = ACTIONS(1550),
    [anon_sym_SQUOTE] = ACTIONS(1552),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1554),
    [sym_number] = ACTIONS(1556),
    [sym_this] = ACTIONS(1558),
    [sym_true] = ACTIONS(1560),
    [sym_false] = ACTIONS(1560),
    [sym_null] = ACTIONS(1560),
    [sym_undefined] = ACTIONS(1560),
    [anon_sym_readonly] = ACTIONS(1562),
    [anon_sym_QMARK] = ACTIONS(774),
    [anon_sym_any] = ACTIONS(216),
    [anon_sym_number] = ACTIONS(216),
    [anon_sym_boolean] = ACTIONS(216),
    [anon_sym_string] = ACTIONS(216),
    [anon_sym_symbol] = ACTIONS(216),
    [anon_sym_object] = ACTIONS(216),
    [anon_sym_abstract] = ACTIONS(208),
    [anon_sym_infer] = ACTIONS(210),
    [anon_sym_keyof] = ACTIONS(212),
    [anon_sym_unique] = ACTIONS(214),
    [anon_sym_unknown] = ACTIONS(216),
    [anon_sym_never] = ACTIONS(216),
    [anon_sym_LBRACE_PIPE] = ACTIONS(218),
    [sym_html_comment] = ACTIONS(5),
  },
  [1053] = {
    [sym_import] = STATE(4950),
    [sym_nested_identifier] = STATE(5535),
    [sym_string] = STATE(3265),
    [sym_formal_parameters] = STATE(5840),
    [sym_nested_type_identifier] = STATE(3151),
    [sym__type_query_member_expression_in_type_annotation] = STATE(3076),
    [sym__type_query_call_expression_in_type_annotation] = STATE(3200),
    [sym_type] = STATE(3261),
    [sym_constructor_type] = STATE(3271),
    [sym_primary_type] = STATE(3272),
    [sym_template_literal_type] = STATE(3273),
    [sym_infer_type] = STATE(3271),
    [sym_conditional_type] = STATE(3273),
    [sym_generic_type] = STATE(3273),
    [sym_type_query] = STATE(3273),
    [sym_index_type_query] = STATE(3273),
    [sym_lookup_type] = STATE(3273),
    [sym_literal_type] = STATE(3273),
    [sym__number] = STATE(3274),
    [sym_existential_type] = STATE(3273),
    [sym_flow_maybe_type] = STATE(3273),
    [sym_parenthesized_type] = STATE(3273),
    [sym_predefined_type] = STATE(3273),
    [sym_object_type] = STATE(3273),
    [sym_type_parameters] = STATE(5146),
    [sym_array_type] = STATE(3273),
    [sym_tuple_type] = STATE(3273),
    [sym_readonly_type] = STATE(3271),
    [sym_union_type] = STATE(3273),
    [sym_intersection_type] = STATE(3273),
    [sym_function_type] = STATE(3271),
    [sym_identifier] = ACTIONS(1606),
    [anon_sym_STAR] = ACTIONS(986),
    [anon_sym_LBRACE] = ACTIONS(1610),
    [anon_sym_typeof] = ACTIONS(1612),
    [anon_sym_import] = ACTIONS(1538),
    [anon_sym_const] = ACTIONS(992),
    [anon_sym_LPAREN] = ACTIONS(1614),
    [anon_sym_LBRACK] = ACTIONS(1616),
    [anon_sym_new] = ACTIONS(1618),
    [anon_sym_AMP] = ACTIONS(1000),
    [anon_sym_PIPE] = ACTIONS(1002),
    [anon_sym_PLUS] = ACTIONS(2983),
    [anon_sym_DASH] = ACTIONS(2983),
    [anon_sym_LT] = ACTIONS(2499),
    [anon_sym_void] = ACTIONS(1032),
    [anon_sym_DQUOTE] = ACTIONS(1626),
    [anon_sym_SQUOTE] = ACTIONS(1628),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1630),
    [sym_number] = ACTIONS(1632),
    [sym_this] = ACTIONS(1634),
    [sym_true] = ACTIONS(1636),
    [sym_false] = ACTIONS(1636),
    [sym_null] = ACTIONS(1636),
    [sym_undefined] = ACTIONS(1636),
    [anon_sym_readonly] = ACTIONS(1638),
    [anon_sym_QMARK] = ACTIONS(1020),
    [anon_sym_any] = ACTIONS(1032),
    [anon_sym_number] = ACTIONS(1032),
    [anon_sym_boolean] = ACTIONS(1032),
    [anon_sym_string] = ACTIONS(1032),
    [anon_sym_symbol] = ACTIONS(1032),
    [anon_sym_object] = ACTIONS(1032),
    [anon_sym_abstract] = ACTIONS(1024),
    [anon_sym_infer] = ACTIONS(1026),
    [anon_sym_keyof] = ACTIONS(1028),
    [anon_sym_unique] = ACTIONS(1030),
    [anon_sym_unknown] = ACTIONS(1032),
    [anon_sym_never] = ACTIONS(1032),
    [anon_sym_LBRACE_PIPE] = ACTIONS(1034),
    [sym_html_comment] = ACTIONS(5),
  },
  [1054] = {
    [sym_import] = STATE(4950),
    [sym_nested_identifier] = STATE(5535),
    [sym_string] = STATE(3265),
    [sym_formal_parameters] = STATE(5840),
    [sym_nested_type_identifier] = STATE(3151),
    [sym__type_query_member_expression_in_type_annotation] = STATE(3076),
    [sym__type_query_call_expression_in_type_annotation] = STATE(3200),
    [sym_type] = STATE(3267),
    [sym_constructor_type] = STATE(3271),
    [sym_primary_type] = STATE(3272),
    [sym_template_literal_type] = STATE(3273),
    [sym_infer_type] = STATE(3271),
    [sym_conditional_type] = STATE(3273),
    [sym_generic_type] = STATE(3273),
    [sym_type_query] = STATE(3273),
    [sym_index_type_query] = STATE(3273),
    [sym_lookup_type] = STATE(3273),
    [sym_literal_type] = STATE(3273),
    [sym__number] = STATE(3274),
    [sym_existential_type] = STATE(3273),
    [sym_flow_maybe_type] = STATE(3273),
    [sym_parenthesized_type] = STATE(3273),
    [sym_predefined_type] = STATE(3273),
    [sym_object_type] = STATE(3273),
    [sym_type_parameters] = STATE(5146),
    [sym_array_type] = STATE(3273),
    [sym_tuple_type] = STATE(3273),
    [sym_readonly_type] = STATE(3271),
    [sym_union_type] = STATE(3273),
    [sym_intersection_type] = STATE(3273),
    [sym_function_type] = STATE(3271),
    [sym_identifier] = ACTIONS(1606),
    [anon_sym_STAR] = ACTIONS(986),
    [anon_sym_LBRACE] = ACTIONS(1610),
    [anon_sym_typeof] = ACTIONS(1612),
    [anon_sym_import] = ACTIONS(1538),
    [anon_sym_const] = ACTIONS(992),
    [anon_sym_LPAREN] = ACTIONS(1614),
    [anon_sym_LBRACK] = ACTIONS(1616),
    [anon_sym_new] = ACTIONS(1618),
    [anon_sym_AMP] = ACTIONS(1000),
    [anon_sym_PIPE] = ACTIONS(1002),
    [anon_sym_PLUS] = ACTIONS(2983),
    [anon_sym_DASH] = ACTIONS(2983),
    [anon_sym_LT] = ACTIONS(2499),
    [anon_sym_void] = ACTIONS(1032),
    [anon_sym_DQUOTE] = ACTIONS(1626),
    [anon_sym_SQUOTE] = ACTIONS(1628),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1630),
    [sym_number] = ACTIONS(1632),
    [sym_this] = ACTIONS(1634),
    [sym_true] = ACTIONS(1636),
    [sym_false] = ACTIONS(1636),
    [sym_null] = ACTIONS(1636),
    [sym_undefined] = ACTIONS(1636),
    [anon_sym_readonly] = ACTIONS(1638),
    [anon_sym_QMARK] = ACTIONS(1020),
    [anon_sym_any] = ACTIONS(1032),
    [anon_sym_number] = ACTIONS(1032),
    [anon_sym_boolean] = ACTIONS(1032),
    [anon_sym_string] = ACTIONS(1032),
    [anon_sym_symbol] = ACTIONS(1032),
    [anon_sym_object] = ACTIONS(1032),
    [anon_sym_abstract] = ACTIONS(1024),
    [anon_sym_infer] = ACTIONS(1026),
    [anon_sym_keyof] = ACTIONS(1028),
    [anon_sym_unique] = ACTIONS(1030),
    [anon_sym_unknown] = ACTIONS(1032),
    [anon_sym_never] = ACTIONS(1032),
    [anon_sym_LBRACE_PIPE] = ACTIONS(1034),
    [sym_html_comment] = ACTIONS(5),
  },
  [1055] = {
    [sym_import] = STATE(4878),
    [sym_nested_identifier] = STATE(5474),
    [sym_string] = STATE(2994),
    [sym_formal_parameters] = STATE(5475),
    [sym_nested_type_identifier] = STATE(2939),
    [sym__type_query_member_expression_in_type_annotation] = STATE(2937),
    [sym__type_query_call_expression_in_type_annotation] = STATE(2938),
    [sym_type] = STATE(4386),
    [sym_constructor_type] = STATE(3007),
    [sym_primary_type] = STATE(2981),
    [sym_template_literal_type] = STATE(3039),
    [sym_infer_type] = STATE(3007),
    [sym_conditional_type] = STATE(3039),
    [sym_generic_type] = STATE(3039),
    [sym_type_query] = STATE(3039),
    [sym_index_type_query] = STATE(3039),
    [sym_lookup_type] = STATE(3039),
    [sym_literal_type] = STATE(3039),
    [sym__number] = STATE(3041),
    [sym_existential_type] = STATE(3039),
    [sym_flow_maybe_type] = STATE(3039),
    [sym_parenthesized_type] = STATE(3039),
    [sym_predefined_type] = STATE(3039),
    [sym_object_type] = STATE(3039),
    [sym_type_parameters] = STATE(5248),
    [sym_array_type] = STATE(3039),
    [sym_tuple_type] = STATE(3039),
    [sym_readonly_type] = STATE(3007),
    [sym_union_type] = STATE(3039),
    [sym_intersection_type] = STATE(3039),
    [sym_function_type] = STATE(3007),
    [sym_identifier] = ACTIONS(1532),
    [anon_sym_STAR] = ACTIONS(543),
    [anon_sym_LBRACE] = ACTIONS(1534),
    [anon_sym_typeof] = ACTIONS(1536),
    [anon_sym_import] = ACTIONS(1538),
    [anon_sym_const] = ACTIONS(133),
    [anon_sym_LPAREN] = ACTIONS(1540),
    [anon_sym_LBRACK] = ACTIONS(1542),
    [anon_sym_new] = ACTIONS(1544),
    [anon_sym_AMP] = ACTIONS(748),
    [anon_sym_PIPE] = ACTIONS(750),
    [anon_sym_PLUS] = ACTIONS(2497),
    [anon_sym_DASH] = ACTIONS(2497),
    [anon_sym_LT] = ACTIONS(2499),
    [anon_sym_void] = ACTIONS(216),
    [anon_sym_DQUOTE] = ACTIONS(1550),
    [anon_sym_SQUOTE] = ACTIONS(1552),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1554),
    [sym_number] = ACTIONS(1556),
    [sym_this] = ACTIONS(1558),
    [sym_true] = ACTIONS(1560),
    [sym_false] = ACTIONS(1560),
    [sym_null] = ACTIONS(1560),
    [sym_undefined] = ACTIONS(1560),
    [anon_sym_readonly] = ACTIONS(1562),
    [anon_sym_QMARK] = ACTIONS(774),
    [anon_sym_any] = ACTIONS(216),
    [anon_sym_number] = ACTIONS(216),
    [anon_sym_boolean] = ACTIONS(216),
    [anon_sym_string] = ACTIONS(216),
    [anon_sym_symbol] = ACTIONS(216),
    [anon_sym_object] = ACTIONS(216),
    [anon_sym_abstract] = ACTIONS(208),
    [anon_sym_infer] = ACTIONS(210),
    [anon_sym_keyof] = ACTIONS(212),
    [anon_sym_unique] = ACTIONS(214),
    [anon_sym_unknown] = ACTIONS(216),
    [anon_sym_never] = ACTIONS(216),
    [anon_sym_LBRACE_PIPE] = ACTIONS(218),
    [sym_html_comment] = ACTIONS(5),
  },
  [1056] = {
    [sym_import] = STATE(4878),
    [sym_nested_identifier] = STATE(5474),
    [sym_string] = STATE(2994),
    [sym_formal_parameters] = STATE(5475),
    [sym_nested_type_identifier] = STATE(2939),
    [sym__type_query_member_expression_in_type_annotation] = STATE(2937),
    [sym__type_query_call_expression_in_type_annotation] = STATE(2938),
    [sym_type] = STATE(3835),
    [sym_constructor_type] = STATE(3007),
    [sym_primary_type] = STATE(2981),
    [sym_template_literal_type] = STATE(3039),
    [sym_infer_type] = STATE(3007),
    [sym_conditional_type] = STATE(3039),
    [sym_generic_type] = STATE(3039),
    [sym_type_query] = STATE(3039),
    [sym_index_type_query] = STATE(3039),
    [sym_lookup_type] = STATE(3039),
    [sym_literal_type] = STATE(3039),
    [sym__number] = STATE(3041),
    [sym_existential_type] = STATE(3039),
    [sym_flow_maybe_type] = STATE(3039),
    [sym_parenthesized_type] = STATE(3039),
    [sym_predefined_type] = STATE(3039),
    [sym_object_type] = STATE(3039),
    [sym_type_parameters] = STATE(5248),
    [sym_array_type] = STATE(3039),
    [sym_tuple_type] = STATE(3039),
    [sym_readonly_type] = STATE(3007),
    [sym_union_type] = STATE(3039),
    [sym_intersection_type] = STATE(3039),
    [sym_function_type] = STATE(3007),
    [sym_identifier] = ACTIONS(1532),
    [anon_sym_STAR] = ACTIONS(543),
    [anon_sym_LBRACE] = ACTIONS(1534),
    [anon_sym_typeof] = ACTIONS(1536),
    [anon_sym_import] = ACTIONS(1538),
    [anon_sym_const] = ACTIONS(133),
    [anon_sym_LPAREN] = ACTIONS(1540),
    [anon_sym_LBRACK] = ACTIONS(1542),
    [anon_sym_new] = ACTIONS(1544),
    [anon_sym_AMP] = ACTIONS(748),
    [anon_sym_PIPE] = ACTIONS(750),
    [anon_sym_PLUS] = ACTIONS(2497),
    [anon_sym_DASH] = ACTIONS(2497),
    [anon_sym_LT] = ACTIONS(2499),
    [anon_sym_void] = ACTIONS(216),
    [anon_sym_DQUOTE] = ACTIONS(1550),
    [anon_sym_SQUOTE] = ACTIONS(1552),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1554),
    [sym_number] = ACTIONS(1556),
    [sym_this] = ACTIONS(1558),
    [sym_true] = ACTIONS(1560),
    [sym_false] = ACTIONS(1560),
    [sym_null] = ACTIONS(1560),
    [sym_undefined] = ACTIONS(1560),
    [anon_sym_readonly] = ACTIONS(1562),
    [anon_sym_QMARK] = ACTIONS(774),
    [anon_sym_any] = ACTIONS(216),
    [anon_sym_number] = ACTIONS(216),
    [anon_sym_boolean] = ACTIONS(216),
    [anon_sym_string] = ACTIONS(216),
    [anon_sym_symbol] = ACTIONS(216),
    [anon_sym_object] = ACTIONS(216),
    [anon_sym_abstract] = ACTIONS(208),
    [anon_sym_infer] = ACTIONS(210),
    [anon_sym_keyof] = ACTIONS(212),
    [anon_sym_unique] = ACTIONS(214),
    [anon_sym_unknown] = ACTIONS(216),
    [anon_sym_never] = ACTIONS(216),
    [anon_sym_LBRACE_PIPE] = ACTIONS(218),
    [sym_html_comment] = ACTIONS(5),
  },
  [1057] = {
    [sym_import] = STATE(4650),
    [sym_nested_identifier] = STATE(5567),
    [sym_string] = STATE(1975),
    [sym_formal_parameters] = STATE(5527),
    [sym_nested_type_identifier] = STATE(1865),
    [sym__type_query_member_expression_in_type_annotation] = STATE(1781),
    [sym__type_query_call_expression_in_type_annotation] = STATE(1911),
    [sym_type] = STATE(1941),
    [sym_constructor_type] = STATE(1912),
    [sym_primary_type] = STATE(1915),
    [sym_template_literal_type] = STATE(1916),
    [sym_infer_type] = STATE(1912),
    [sym_conditional_type] = STATE(1916),
    [sym_generic_type] = STATE(1916),
    [sym_type_query] = STATE(1916),
    [sym_index_type_query] = STATE(1916),
    [sym_lookup_type] = STATE(1916),
    [sym_literal_type] = STATE(1916),
    [sym__number] = STATE(1918),
    [sym_existential_type] = STATE(1916),
    [sym_flow_maybe_type] = STATE(1916),
    [sym_parenthesized_type] = STATE(1916),
    [sym_predefined_type] = STATE(1916),
    [sym_object_type] = STATE(1916),
    [sym_type_parameters] = STATE(5243),
    [sym_array_type] = STATE(1916),
    [sym_tuple_type] = STATE(1916),
    [sym_readonly_type] = STATE(1912),
    [sym_union_type] = STATE(1916),
    [sym_intersection_type] = STATE(1916),
    [sym_function_type] = STATE(1912),
    [sym_identifier] = ACTIONS(3255),
    [anon_sym_STAR] = ACTIONS(3047),
    [anon_sym_LBRACE] = ACTIONS(3049),
    [anon_sym_typeof] = ACTIONS(3051),
    [anon_sym_import] = ACTIONS(1538),
    [anon_sym_const] = ACTIONS(3053),
    [anon_sym_LPAREN] = ACTIONS(3055),
    [anon_sym_LBRACK] = ACTIONS(3057),
    [anon_sym_new] = ACTIONS(3059),
    [anon_sym_AMP] = ACTIONS(3061),
    [anon_sym_PIPE] = ACTIONS(3063),
    [anon_sym_PLUS] = ACTIONS(3065),
    [anon_sym_DASH] = ACTIONS(3065),
    [anon_sym_LT] = ACTIONS(2499),
    [anon_sym_void] = ACTIONS(3067),
    [anon_sym_DQUOTE] = ACTIONS(83),
    [anon_sym_SQUOTE] = ACTIONS(85),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(3069),
    [sym_number] = ACTIONS(3071),
    [sym_this] = ACTIONS(3257),
    [sym_true] = ACTIONS(3075),
    [sym_false] = ACTIONS(3075),
    [sym_null] = ACTIONS(3075),
    [sym_undefined] = ACTIONS(3075),
    [anon_sym_readonly] = ACTIONS(3077),
    [anon_sym_QMARK] = ACTIONS(3079),
    [anon_sym_any] = ACTIONS(3067),
    [anon_sym_number] = ACTIONS(3067),
    [anon_sym_boolean] = ACTIONS(3067),
    [anon_sym_string] = ACTIONS(3067),
    [anon_sym_symbol] = ACTIONS(3067),
    [anon_sym_object] = ACTIONS(3067),
    [anon_sym_abstract] = ACTIONS(3081),
    [anon_sym_infer] = ACTIONS(3085),
    [anon_sym_keyof] = ACTIONS(3087),
    [anon_sym_unique] = ACTIONS(3089),
    [anon_sym_unknown] = ACTIONS(3067),
    [anon_sym_never] = ACTIONS(3067),
    [anon_sym_LBRACE_PIPE] = ACTIONS(3091),
    [sym_html_comment] = ACTIONS(5),
  },
  [1058] = {
    [sym_import] = STATE(4650),
    [sym_nested_identifier] = STATE(5567),
    [sym_string] = STATE(1975),
    [sym_formal_parameters] = STATE(5527),
    [sym_nested_type_identifier] = STATE(1865),
    [sym__type_query_member_expression_in_type_annotation] = STATE(1781),
    [sym__type_query_call_expression_in_type_annotation] = STATE(1911),
    [sym_type] = STATE(1942),
    [sym_constructor_type] = STATE(1912),
    [sym_primary_type] = STATE(1915),
    [sym_template_literal_type] = STATE(1916),
    [sym_infer_type] = STATE(1912),
    [sym_conditional_type] = STATE(1916),
    [sym_generic_type] = STATE(1916),
    [sym_type_query] = STATE(1916),
    [sym_index_type_query] = STATE(1916),
    [sym_lookup_type] = STATE(1916),
    [sym_literal_type] = STATE(1916),
    [sym__number] = STATE(1918),
    [sym_existential_type] = STATE(1916),
    [sym_flow_maybe_type] = STATE(1916),
    [sym_parenthesized_type] = STATE(1916),
    [sym_predefined_type] = STATE(1916),
    [sym_object_type] = STATE(1916),
    [sym_type_parameters] = STATE(5243),
    [sym_array_type] = STATE(1916),
    [sym_tuple_type] = STATE(1916),
    [sym_readonly_type] = STATE(1912),
    [sym_union_type] = STATE(1916),
    [sym_intersection_type] = STATE(1916),
    [sym_function_type] = STATE(1912),
    [sym_identifier] = ACTIONS(3255),
    [anon_sym_STAR] = ACTIONS(3047),
    [anon_sym_LBRACE] = ACTIONS(3049),
    [anon_sym_typeof] = ACTIONS(3051),
    [anon_sym_import] = ACTIONS(1538),
    [anon_sym_const] = ACTIONS(3053),
    [anon_sym_LPAREN] = ACTIONS(3055),
    [anon_sym_LBRACK] = ACTIONS(3057),
    [anon_sym_new] = ACTIONS(3059),
    [anon_sym_AMP] = ACTIONS(3061),
    [anon_sym_PIPE] = ACTIONS(3063),
    [anon_sym_PLUS] = ACTIONS(3065),
    [anon_sym_DASH] = ACTIONS(3065),
    [anon_sym_LT] = ACTIONS(2499),
    [anon_sym_void] = ACTIONS(3067),
    [anon_sym_DQUOTE] = ACTIONS(83),
    [anon_sym_SQUOTE] = ACTIONS(85),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(3069),
    [sym_number] = ACTIONS(3071),
    [sym_this] = ACTIONS(3257),
    [sym_true] = ACTIONS(3075),
    [sym_false] = ACTIONS(3075),
    [sym_null] = ACTIONS(3075),
    [sym_undefined] = ACTIONS(3075),
    [anon_sym_readonly] = ACTIONS(3077),
    [anon_sym_QMARK] = ACTIONS(3079),
    [anon_sym_any] = ACTIONS(3067),
    [anon_sym_number] = ACTIONS(3067),
    [anon_sym_boolean] = ACTIONS(3067),
    [anon_sym_string] = ACTIONS(3067),
    [anon_sym_symbol] = ACTIONS(3067),
    [anon_sym_object] = ACTIONS(3067),
    [anon_sym_abstract] = ACTIONS(3081),
    [anon_sym_infer] = ACTIONS(3085),
    [anon_sym_keyof] = ACTIONS(3087),
    [anon_sym_unique] = ACTIONS(3089),
    [anon_sym_unknown] = ACTIONS(3067),
    [anon_sym_never] = ACTIONS(3067),
    [anon_sym_LBRACE_PIPE] = ACTIONS(3091),
    [sym_html_comment] = ACTIONS(5),
  },
  [1059] = {
    [sym_import] = STATE(4950),
    [sym_nested_identifier] = STATE(5535),
    [sym_string] = STATE(3265),
    [sym_formal_parameters] = STATE(5840),
    [sym_nested_type_identifier] = STATE(3151),
    [sym__type_query_member_expression_in_type_annotation] = STATE(3076),
    [sym__type_query_call_expression_in_type_annotation] = STATE(3200),
    [sym_type] = STATE(3239),
    [sym_constructor_type] = STATE(3271),
    [sym_primary_type] = STATE(3272),
    [sym_template_literal_type] = STATE(3273),
    [sym_infer_type] = STATE(3271),
    [sym_conditional_type] = STATE(3273),
    [sym_generic_type] = STATE(3273),
    [sym_type_query] = STATE(3273),
    [sym_index_type_query] = STATE(3273),
    [sym_lookup_type] = STATE(3273),
    [sym_literal_type] = STATE(3273),
    [sym__number] = STATE(3274),
    [sym_existential_type] = STATE(3273),
    [sym_flow_maybe_type] = STATE(3273),
    [sym_parenthesized_type] = STATE(3273),
    [sym_predefined_type] = STATE(3273),
    [sym_object_type] = STATE(3273),
    [sym_type_parameters] = STATE(5146),
    [sym_array_type] = STATE(3273),
    [sym_tuple_type] = STATE(3273),
    [sym_readonly_type] = STATE(3271),
    [sym_union_type] = STATE(3273),
    [sym_intersection_type] = STATE(3273),
    [sym_function_type] = STATE(3271),
    [sym_identifier] = ACTIONS(1606),
    [anon_sym_STAR] = ACTIONS(986),
    [anon_sym_LBRACE] = ACTIONS(1610),
    [anon_sym_typeof] = ACTIONS(1612),
    [anon_sym_import] = ACTIONS(1538),
    [anon_sym_const] = ACTIONS(992),
    [anon_sym_LPAREN] = ACTIONS(1614),
    [anon_sym_LBRACK] = ACTIONS(1616),
    [anon_sym_new] = ACTIONS(1618),
    [anon_sym_AMP] = ACTIONS(1000),
    [anon_sym_PIPE] = ACTIONS(1002),
    [anon_sym_PLUS] = ACTIONS(2983),
    [anon_sym_DASH] = ACTIONS(2983),
    [anon_sym_LT] = ACTIONS(2499),
    [anon_sym_void] = ACTIONS(1032),
    [anon_sym_DQUOTE] = ACTIONS(1626),
    [anon_sym_SQUOTE] = ACTIONS(1628),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1630),
    [sym_number] = ACTIONS(1632),
    [sym_this] = ACTIONS(1634),
    [sym_true] = ACTIONS(1636),
    [sym_false] = ACTIONS(1636),
    [sym_null] = ACTIONS(1636),
    [sym_undefined] = ACTIONS(1636),
    [anon_sym_readonly] = ACTIONS(1638),
    [anon_sym_QMARK] = ACTIONS(1020),
    [anon_sym_any] = ACTIONS(1032),
    [anon_sym_number] = ACTIONS(1032),
    [anon_sym_boolean] = ACTIONS(1032),
    [anon_sym_string] = ACTIONS(1032),
    [anon_sym_symbol] = ACTIONS(1032),
    [anon_sym_object] = ACTIONS(1032),
    [anon_sym_abstract] = ACTIONS(1024),
    [anon_sym_infer] = ACTIONS(1026),
    [anon_sym_keyof] = ACTIONS(1028),
    [anon_sym_unique] = ACTIONS(1030),
    [anon_sym_unknown] = ACTIONS(1032),
    [anon_sym_never] = ACTIONS(1032),
    [anon_sym_LBRACE_PIPE] = ACTIONS(1034),
    [sym_html_comment] = ACTIONS(5),
  },
  [1060] = {
    [sym_import] = STATE(4950),
    [sym_nested_identifier] = STATE(5535),
    [sym_string] = STATE(3265),
    [sym_formal_parameters] = STATE(5840),
    [sym_nested_type_identifier] = STATE(3151),
    [sym__type_query_member_expression_in_type_annotation] = STATE(3076),
    [sym__type_query_call_expression_in_type_annotation] = STATE(3200),
    [sym_type] = STATE(3240),
    [sym_constructor_type] = STATE(3271),
    [sym_primary_type] = STATE(3272),
    [sym_template_literal_type] = STATE(3273),
    [sym_infer_type] = STATE(3271),
    [sym_conditional_type] = STATE(3273),
    [sym_generic_type] = STATE(3273),
    [sym_type_query] = STATE(3273),
    [sym_index_type_query] = STATE(3273),
    [sym_lookup_type] = STATE(3273),
    [sym_literal_type] = STATE(3273),
    [sym__number] = STATE(3274),
    [sym_existential_type] = STATE(3273),
    [sym_flow_maybe_type] = STATE(3273),
    [sym_parenthesized_type] = STATE(3273),
    [sym_predefined_type] = STATE(3273),
    [sym_object_type] = STATE(3273),
    [sym_type_parameters] = STATE(5146),
    [sym_array_type] = STATE(3273),
    [sym_tuple_type] = STATE(3273),
    [sym_readonly_type] = STATE(3271),
    [sym_union_type] = STATE(3273),
    [sym_intersection_type] = STATE(3273),
    [sym_function_type] = STATE(3271),
    [sym_identifier] = ACTIONS(1606),
    [anon_sym_STAR] = ACTIONS(986),
    [anon_sym_LBRACE] = ACTIONS(1610),
    [anon_sym_typeof] = ACTIONS(1612),
    [anon_sym_import] = ACTIONS(1538),
    [anon_sym_const] = ACTIONS(992),
    [anon_sym_LPAREN] = ACTIONS(1614),
    [anon_sym_LBRACK] = ACTIONS(1616),
    [anon_sym_new] = ACTIONS(1618),
    [anon_sym_AMP] = ACTIONS(1000),
    [anon_sym_PIPE] = ACTIONS(1002),
    [anon_sym_PLUS] = ACTIONS(2983),
    [anon_sym_DASH] = ACTIONS(2983),
    [anon_sym_LT] = ACTIONS(2499),
    [anon_sym_void] = ACTIONS(1032),
    [anon_sym_DQUOTE] = ACTIONS(1626),
    [anon_sym_SQUOTE] = ACTIONS(1628),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1630),
    [sym_number] = ACTIONS(1632),
    [sym_this] = ACTIONS(1634),
    [sym_true] = ACTIONS(1636),
    [sym_false] = ACTIONS(1636),
    [sym_null] = ACTIONS(1636),
    [sym_undefined] = ACTIONS(1636),
    [anon_sym_readonly] = ACTIONS(1638),
    [anon_sym_QMARK] = ACTIONS(1020),
    [anon_sym_any] = ACTIONS(1032),
    [anon_sym_number] = ACTIONS(1032),
    [anon_sym_boolean] = ACTIONS(1032),
    [anon_sym_string] = ACTIONS(1032),
    [anon_sym_symbol] = ACTIONS(1032),
    [anon_sym_object] = ACTIONS(1032),
    [anon_sym_abstract] = ACTIONS(1024),
    [anon_sym_infer] = ACTIONS(1026),
    [anon_sym_keyof] = ACTIONS(1028),
    [anon_sym_unique] = ACTIONS(1030),
    [anon_sym_unknown] = ACTIONS(1032),
    [anon_sym_never] = ACTIONS(1032),
    [anon_sym_LBRACE_PIPE] = ACTIONS(1034),
    [sym_html_comment] = ACTIONS(5),
  },
  [1061] = {
    [sym_import] = STATE(4950),
    [sym_nested_identifier] = STATE(5535),
    [sym_string] = STATE(3265),
    [sym_formal_parameters] = STATE(5840),
    [sym_nested_type_identifier] = STATE(3151),
    [sym__type_query_member_expression_in_type_annotation] = STATE(3076),
    [sym__type_query_call_expression_in_type_annotation] = STATE(3200),
    [sym_type] = STATE(3243),
    [sym_constructor_type] = STATE(3271),
    [sym_primary_type] = STATE(3272),
    [sym_template_literal_type] = STATE(3273),
    [sym_infer_type] = STATE(3271),
    [sym_conditional_type] = STATE(3273),
    [sym_generic_type] = STATE(3273),
    [sym_type_query] = STATE(3273),
    [sym_index_type_query] = STATE(3273),
    [sym_lookup_type] = STATE(3273),
    [sym_literal_type] = STATE(3273),
    [sym__number] = STATE(3274),
    [sym_existential_type] = STATE(3273),
    [sym_flow_maybe_type] = STATE(3273),
    [sym_parenthesized_type] = STATE(3273),
    [sym_predefined_type] = STATE(3273),
    [sym_object_type] = STATE(3273),
    [sym_type_parameters] = STATE(5146),
    [sym_array_type] = STATE(3273),
    [sym_tuple_type] = STATE(3273),
    [sym_readonly_type] = STATE(3271),
    [sym_union_type] = STATE(3273),
    [sym_intersection_type] = STATE(3273),
    [sym_function_type] = STATE(3271),
    [sym_identifier] = ACTIONS(1606),
    [anon_sym_STAR] = ACTIONS(986),
    [anon_sym_LBRACE] = ACTIONS(1610),
    [anon_sym_typeof] = ACTIONS(1612),
    [anon_sym_import] = ACTIONS(1538),
    [anon_sym_const] = ACTIONS(992),
    [anon_sym_LPAREN] = ACTIONS(1614),
    [anon_sym_LBRACK] = ACTIONS(1616),
    [anon_sym_new] = ACTIONS(1618),
    [anon_sym_AMP] = ACTIONS(1000),
    [anon_sym_PIPE] = ACTIONS(1002),
    [anon_sym_PLUS] = ACTIONS(2983),
    [anon_sym_DASH] = ACTIONS(2983),
    [anon_sym_LT] = ACTIONS(2499),
    [anon_sym_void] = ACTIONS(1032),
    [anon_sym_DQUOTE] = ACTIONS(1626),
    [anon_sym_SQUOTE] = ACTIONS(1628),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1630),
    [sym_number] = ACTIONS(1632),
    [sym_this] = ACTIONS(1634),
    [sym_true] = ACTIONS(1636),
    [sym_false] = ACTIONS(1636),
    [sym_null] = ACTIONS(1636),
    [sym_undefined] = ACTIONS(1636),
    [anon_sym_readonly] = ACTIONS(1638),
    [anon_sym_QMARK] = ACTIONS(1020),
    [anon_sym_any] = ACTIONS(1032),
    [anon_sym_number] = ACTIONS(1032),
    [anon_sym_boolean] = ACTIONS(1032),
    [anon_sym_string] = ACTIONS(1032),
    [anon_sym_symbol] = ACTIONS(1032),
    [anon_sym_object] = ACTIONS(1032),
    [anon_sym_abstract] = ACTIONS(1024),
    [anon_sym_infer] = ACTIONS(1026),
    [anon_sym_keyof] = ACTIONS(1028),
    [anon_sym_unique] = ACTIONS(1030),
    [anon_sym_unknown] = ACTIONS(1032),
    [anon_sym_never] = ACTIONS(1032),
    [anon_sym_LBRACE_PIPE] = ACTIONS(1034),
    [sym_html_comment] = ACTIONS(5),
  },
  [1062] = {
    [sym_import] = STATE(4950),
    [sym_nested_identifier] = STATE(5535),
    [sym_string] = STATE(3265),
    [sym_formal_parameters] = STATE(5840),
    [sym_nested_type_identifier] = STATE(3151),
    [sym__type_query_member_expression_in_type_annotation] = STATE(3076),
    [sym__type_query_call_expression_in_type_annotation] = STATE(3200),
    [sym_type] = STATE(3244),
    [sym_constructor_type] = STATE(3271),
    [sym_primary_type] = STATE(3272),
    [sym_template_literal_type] = STATE(3273),
    [sym_infer_type] = STATE(3271),
    [sym_conditional_type] = STATE(3273),
    [sym_generic_type] = STATE(3273),
    [sym_type_query] = STATE(3273),
    [sym_index_type_query] = STATE(3273),
    [sym_lookup_type] = STATE(3273),
    [sym_literal_type] = STATE(3273),
    [sym__number] = STATE(3274),
    [sym_existential_type] = STATE(3273),
    [sym_flow_maybe_type] = STATE(3273),
    [sym_parenthesized_type] = STATE(3273),
    [sym_predefined_type] = STATE(3273),
    [sym_object_type] = STATE(3273),
    [sym_type_parameters] = STATE(5146),
    [sym_array_type] = STATE(3273),
    [sym_tuple_type] = STATE(3273),
    [sym_readonly_type] = STATE(3271),
    [sym_union_type] = STATE(3273),
    [sym_intersection_type] = STATE(3273),
    [sym_function_type] = STATE(3271),
    [sym_identifier] = ACTIONS(1606),
    [anon_sym_STAR] = ACTIONS(986),
    [anon_sym_LBRACE] = ACTIONS(1610),
    [anon_sym_typeof] = ACTIONS(1612),
    [anon_sym_import] = ACTIONS(1538),
    [anon_sym_const] = ACTIONS(992),
    [anon_sym_LPAREN] = ACTIONS(1614),
    [anon_sym_LBRACK] = ACTIONS(1616),
    [anon_sym_new] = ACTIONS(1618),
    [anon_sym_AMP] = ACTIONS(1000),
    [anon_sym_PIPE] = ACTIONS(1002),
    [anon_sym_PLUS] = ACTIONS(2983),
    [anon_sym_DASH] = ACTIONS(2983),
    [anon_sym_LT] = ACTIONS(2499),
    [anon_sym_void] = ACTIONS(1032),
    [anon_sym_DQUOTE] = ACTIONS(1626),
    [anon_sym_SQUOTE] = ACTIONS(1628),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1630),
    [sym_number] = ACTIONS(1632),
    [sym_this] = ACTIONS(1634),
    [sym_true] = ACTIONS(1636),
    [sym_false] = ACTIONS(1636),
    [sym_null] = ACTIONS(1636),
    [sym_undefined] = ACTIONS(1636),
    [anon_sym_readonly] = ACTIONS(1638),
    [anon_sym_QMARK] = ACTIONS(1020),
    [anon_sym_any] = ACTIONS(1032),
    [anon_sym_number] = ACTIONS(1032),
    [anon_sym_boolean] = ACTIONS(1032),
    [anon_sym_string] = ACTIONS(1032),
    [anon_sym_symbol] = ACTIONS(1032),
    [anon_sym_object] = ACTIONS(1032),
    [anon_sym_abstract] = ACTIONS(1024),
    [anon_sym_infer] = ACTIONS(1026),
    [anon_sym_keyof] = ACTIONS(1028),
    [anon_sym_unique] = ACTIONS(1030),
    [anon_sym_unknown] = ACTIONS(1032),
    [anon_sym_never] = ACTIONS(1032),
    [anon_sym_LBRACE_PIPE] = ACTIONS(1034),
    [sym_html_comment] = ACTIONS(5),
  },
  [1063] = {
    [sym_import] = STATE(4531),
    [sym_nested_identifier] = STATE(5486),
    [sym_string] = STATE(1632),
    [sym_formal_parameters] = STATE(5639),
    [sym_nested_type_identifier] = STATE(1527),
    [sym__type_query_member_expression_in_type_annotation] = STATE(1514),
    [sym__type_query_call_expression_in_type_annotation] = STATE(1574),
    [sym_type] = STATE(1594),
    [sym_constructor_type] = STATE(1544),
    [sym_primary_type] = STATE(1554),
    [sym_template_literal_type] = STATE(1556),
    [sym_infer_type] = STATE(1544),
    [sym_conditional_type] = STATE(1556),
    [sym_generic_type] = STATE(1556),
    [sym_type_query] = STATE(1556),
    [sym_index_type_query] = STATE(1556),
    [sym_lookup_type] = STATE(1556),
    [sym_literal_type] = STATE(1556),
    [sym__number] = STATE(1536),
    [sym_existential_type] = STATE(1556),
    [sym_flow_maybe_type] = STATE(1556),
    [sym_parenthesized_type] = STATE(1556),
    [sym_predefined_type] = STATE(1556),
    [sym_object_type] = STATE(1556),
    [sym_type_parameters] = STATE(5205),
    [sym_array_type] = STATE(1556),
    [sym_tuple_type] = STATE(1556),
    [sym_readonly_type] = STATE(1544),
    [sym_union_type] = STATE(1556),
    [sym_intersection_type] = STATE(1556),
    [sym_function_type] = STATE(1544),
    [sym_identifier] = ACTIONS(3251),
    [anon_sym_STAR] = ACTIONS(3147),
    [anon_sym_LBRACE] = ACTIONS(3149),
    [anon_sym_typeof] = ACTIONS(3151),
    [anon_sym_import] = ACTIONS(1538),
    [anon_sym_const] = ACTIONS(3153),
    [anon_sym_LPAREN] = ACTIONS(3155),
    [anon_sym_LBRACK] = ACTIONS(3157),
    [anon_sym_new] = ACTIONS(3159),
    [anon_sym_AMP] = ACTIONS(3161),
    [anon_sym_PIPE] = ACTIONS(3163),
    [anon_sym_PLUS] = ACTIONS(3165),
    [anon_sym_DASH] = ACTIONS(3165),
    [anon_sym_LT] = ACTIONS(2499),
    [anon_sym_void] = ACTIONS(3167),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(3169),
    [sym_number] = ACTIONS(3171),
    [sym_this] = ACTIONS(3253),
    [sym_true] = ACTIONS(3175),
    [sym_false] = ACTIONS(3175),
    [sym_null] = ACTIONS(3175),
    [sym_undefined] = ACTIONS(3175),
    [anon_sym_readonly] = ACTIONS(3177),
    [anon_sym_QMARK] = ACTIONS(3179),
    [anon_sym_any] = ACTIONS(3167),
    [anon_sym_number] = ACTIONS(3167),
    [anon_sym_boolean] = ACTIONS(3167),
    [anon_sym_string] = ACTIONS(3167),
    [anon_sym_symbol] = ACTIONS(3167),
    [anon_sym_object] = ACTIONS(3167),
    [anon_sym_abstract] = ACTIONS(3181),
    [anon_sym_infer] = ACTIONS(3185),
    [anon_sym_keyof] = ACTIONS(3187),
    [anon_sym_unique] = ACTIONS(3189),
    [anon_sym_unknown] = ACTIONS(3167),
    [anon_sym_never] = ACTIONS(3167),
    [anon_sym_LBRACE_PIPE] = ACTIONS(3191),
    [sym_html_comment] = ACTIONS(5),
  },
  [1064] = {
    [sym_import] = STATE(4531),
    [sym_nested_identifier] = STATE(5486),
    [sym_string] = STATE(1632),
    [sym_formal_parameters] = STATE(5639),
    [sym_nested_type_identifier] = STATE(1527),
    [sym__type_query_member_expression_in_type_annotation] = STATE(1514),
    [sym__type_query_call_expression_in_type_annotation] = STATE(1574),
    [sym_type] = STATE(1595),
    [sym_constructor_type] = STATE(1544),
    [sym_primary_type] = STATE(1554),
    [sym_template_literal_type] = STATE(1556),
    [sym_infer_type] = STATE(1544),
    [sym_conditional_type] = STATE(1556),
    [sym_generic_type] = STATE(1556),
    [sym_type_query] = STATE(1556),
    [sym_index_type_query] = STATE(1556),
    [sym_lookup_type] = STATE(1556),
    [sym_literal_type] = STATE(1556),
    [sym__number] = STATE(1536),
    [sym_existential_type] = STATE(1556),
    [sym_flow_maybe_type] = STATE(1556),
    [sym_parenthesized_type] = STATE(1556),
    [sym_predefined_type] = STATE(1556),
    [sym_object_type] = STATE(1556),
    [sym_type_parameters] = STATE(5205),
    [sym_array_type] = STATE(1556),
    [sym_tuple_type] = STATE(1556),
    [sym_readonly_type] = STATE(1544),
    [sym_union_type] = STATE(1556),
    [sym_intersection_type] = STATE(1556),
    [sym_function_type] = STATE(1544),
    [sym_identifier] = ACTIONS(3251),
    [anon_sym_STAR] = ACTIONS(3147),
    [anon_sym_LBRACE] = ACTIONS(3149),
    [anon_sym_typeof] = ACTIONS(3151),
    [anon_sym_import] = ACTIONS(1538),
    [anon_sym_const] = ACTIONS(3153),
    [anon_sym_LPAREN] = ACTIONS(3155),
    [anon_sym_LBRACK] = ACTIONS(3157),
    [anon_sym_new] = ACTIONS(3159),
    [anon_sym_AMP] = ACTIONS(3161),
    [anon_sym_PIPE] = ACTIONS(3163),
    [anon_sym_PLUS] = ACTIONS(3165),
    [anon_sym_DASH] = ACTIONS(3165),
    [anon_sym_LT] = ACTIONS(2499),
    [anon_sym_void] = ACTIONS(3167),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(3169),
    [sym_number] = ACTIONS(3171),
    [sym_this] = ACTIONS(3253),
    [sym_true] = ACTIONS(3175),
    [sym_false] = ACTIONS(3175),
    [sym_null] = ACTIONS(3175),
    [sym_undefined] = ACTIONS(3175),
    [anon_sym_readonly] = ACTIONS(3177),
    [anon_sym_QMARK] = ACTIONS(3179),
    [anon_sym_any] = ACTIONS(3167),
    [anon_sym_number] = ACTIONS(3167),
    [anon_sym_boolean] = ACTIONS(3167),
    [anon_sym_string] = ACTIONS(3167),
    [anon_sym_symbol] = ACTIONS(3167),
    [anon_sym_object] = ACTIONS(3167),
    [anon_sym_abstract] = ACTIONS(3181),
    [anon_sym_infer] = ACTIONS(3185),
    [anon_sym_keyof] = ACTIONS(3187),
    [anon_sym_unique] = ACTIONS(3189),
    [anon_sym_unknown] = ACTIONS(3167),
    [anon_sym_never] = ACTIONS(3167),
    [anon_sym_LBRACE_PIPE] = ACTIONS(3191),
    [sym_html_comment] = ACTIONS(5),
  },
  [1065] = {
    [sym_import] = STATE(4531),
    [sym_nested_identifier] = STATE(5486),
    [sym_string] = STATE(1632),
    [sym_formal_parameters] = STATE(5639),
    [sym_nested_type_identifier] = STATE(1527),
    [sym__type_query_member_expression_in_type_annotation] = STATE(1514),
    [sym__type_query_call_expression_in_type_annotation] = STATE(1574),
    [sym_type] = STATE(1592),
    [sym_constructor_type] = STATE(1544),
    [sym_primary_type] = STATE(1554),
    [sym_template_literal_type] = STATE(1556),
    [sym_infer_type] = STATE(1544),
    [sym_conditional_type] = STATE(1556),
    [sym_generic_type] = STATE(1556),
    [sym_type_query] = STATE(1556),
    [sym_index_type_query] = STATE(1556),
    [sym_lookup_type] = STATE(1556),
    [sym_literal_type] = STATE(1556),
    [sym__number] = STATE(1536),
    [sym_existential_type] = STATE(1556),
    [sym_flow_maybe_type] = STATE(1556),
    [sym_parenthesized_type] = STATE(1556),
    [sym_predefined_type] = STATE(1556),
    [sym_object_type] = STATE(1556),
    [sym_type_parameters] = STATE(5205),
    [sym_array_type] = STATE(1556),
    [sym_tuple_type] = STATE(1556),
    [sym_readonly_type] = STATE(1544),
    [sym_union_type] = STATE(1556),
    [sym_intersection_type] = STATE(1556),
    [sym_function_type] = STATE(1544),
    [sym_identifier] = ACTIONS(3251),
    [anon_sym_STAR] = ACTIONS(3147),
    [anon_sym_LBRACE] = ACTIONS(3149),
    [anon_sym_typeof] = ACTIONS(3151),
    [anon_sym_import] = ACTIONS(1538),
    [anon_sym_const] = ACTIONS(3153),
    [anon_sym_LPAREN] = ACTIONS(3155),
    [anon_sym_LBRACK] = ACTIONS(3157),
    [anon_sym_new] = ACTIONS(3159),
    [anon_sym_AMP] = ACTIONS(3161),
    [anon_sym_PIPE] = ACTIONS(3163),
    [anon_sym_PLUS] = ACTIONS(3165),
    [anon_sym_DASH] = ACTIONS(3165),
    [anon_sym_LT] = ACTIONS(2499),
    [anon_sym_void] = ACTIONS(3167),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(3169),
    [sym_number] = ACTIONS(3171),
    [sym_this] = ACTIONS(3253),
    [sym_true] = ACTIONS(3175),
    [sym_false] = ACTIONS(3175),
    [sym_null] = ACTIONS(3175),
    [sym_undefined] = ACTIONS(3175),
    [anon_sym_readonly] = ACTIONS(3177),
    [anon_sym_QMARK] = ACTIONS(3179),
    [anon_sym_any] = ACTIONS(3167),
    [anon_sym_number] = ACTIONS(3167),
    [anon_sym_boolean] = ACTIONS(3167),
    [anon_sym_string] = ACTIONS(3167),
    [anon_sym_symbol] = ACTIONS(3167),
    [anon_sym_object] = ACTIONS(3167),
    [anon_sym_abstract] = ACTIONS(3181),
    [anon_sym_infer] = ACTIONS(3185),
    [anon_sym_keyof] = ACTIONS(3187),
    [anon_sym_unique] = ACTIONS(3189),
    [anon_sym_unknown] = ACTIONS(3167),
    [anon_sym_never] = ACTIONS(3167),
    [anon_sym_LBRACE_PIPE] = ACTIONS(3191),
    [sym_html_comment] = ACTIONS(5),
  },
  [1066] = {
    [sym_import] = STATE(4878),
    [sym_nested_identifier] = STATE(5486),
    [sym_string] = STATE(1632),
    [sym_formal_parameters] = STATE(5475),
    [sym_nested_type_identifier] = STATE(1527),
    [sym__type_query_member_expression_in_type_annotation] = STATE(2937),
    [sym__type_query_call_expression_in_type_annotation] = STATE(2938),
    [sym_type] = STATE(4541),
    [sym_constructor_type] = STATE(3007),
    [sym_primary_type] = STATE(1649),
    [sym_template_literal_type] = STATE(1556),
    [sym_infer_type] = STATE(3007),
    [sym_conditional_type] = STATE(1556),
    [sym_generic_type] = STATE(1556),
    [sym_type_query] = STATE(1556),
    [sym_index_type_query] = STATE(1556),
    [sym_lookup_type] = STATE(1556),
    [sym_literal_type] = STATE(1556),
    [sym__number] = STATE(1536),
    [sym_existential_type] = STATE(1556),
    [sym_flow_maybe_type] = STATE(1556),
    [sym_parenthesized_type] = STATE(1556),
    [sym_predefined_type] = STATE(1556),
    [sym_object_type] = STATE(1556),
    [sym_type_parameters] = STATE(5248),
    [sym_array_type] = STATE(1556),
    [sym_tuple_type] = STATE(1556),
    [sym_readonly_type] = STATE(3007),
    [sym_union_type] = STATE(1556),
    [sym_intersection_type] = STATE(1556),
    [sym_function_type] = STATE(3007),
    [sym_identifier] = ACTIONS(3251),
    [anon_sym_STAR] = ACTIONS(3147),
    [anon_sym_LBRACE] = ACTIONS(3149),
    [anon_sym_typeof] = ACTIONS(3151),
    [anon_sym_import] = ACTIONS(1538),
    [anon_sym_const] = ACTIONS(3153),
    [anon_sym_LPAREN] = ACTIONS(3155),
    [anon_sym_LBRACK] = ACTIONS(3157),
    [anon_sym_new] = ACTIONS(1544),
    [anon_sym_AMP] = ACTIONS(3161),
    [anon_sym_PIPE] = ACTIONS(3163),
    [anon_sym_PLUS] = ACTIONS(3165),
    [anon_sym_DASH] = ACTIONS(3165),
    [anon_sym_LT] = ACTIONS(2499),
    [anon_sym_void] = ACTIONS(3167),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(3169),
    [sym_number] = ACTIONS(3171),
    [sym_this] = ACTIONS(3253),
    [sym_true] = ACTIONS(3175),
    [sym_false] = ACTIONS(3175),
    [sym_null] = ACTIONS(3175),
    [sym_undefined] = ACTIONS(3175),
    [anon_sym_readonly] = ACTIONS(1562),
    [anon_sym_QMARK] = ACTIONS(3179),
    [anon_sym_any] = ACTIONS(3167),
    [anon_sym_number] = ACTIONS(3167),
    [anon_sym_boolean] = ACTIONS(3167),
    [anon_sym_string] = ACTIONS(3167),
    [anon_sym_symbol] = ACTIONS(3167),
    [anon_sym_object] = ACTIONS(3167),
    [anon_sym_abstract] = ACTIONS(208),
    [anon_sym_infer] = ACTIONS(210),
    [anon_sym_keyof] = ACTIONS(3187),
    [anon_sym_unique] = ACTIONS(3189),
    [anon_sym_unknown] = ACTIONS(3167),
    [anon_sym_never] = ACTIONS(3167),
    [anon_sym_LBRACE_PIPE] = ACTIONS(3191),
    [sym_html_comment] = ACTIONS(5),
  },
  [1067] = {
    [sym_import] = STATE(4878),
    [sym_nested_identifier] = STATE(5486),
    [sym_string] = STATE(1632),
    [sym_formal_parameters] = STATE(5475),
    [sym_nested_type_identifier] = STATE(1527),
    [sym__type_query_member_expression_in_type_annotation] = STATE(2937),
    [sym__type_query_call_expression_in_type_annotation] = STATE(2938),
    [sym_type] = STATE(4541),
    [sym_constructor_type] = STATE(3007),
    [sym_primary_type] = STATE(1558),
    [sym_template_literal_type] = STATE(1556),
    [sym_infer_type] = STATE(3007),
    [sym_conditional_type] = STATE(1556),
    [sym_generic_type] = STATE(1556),
    [sym_type_query] = STATE(1556),
    [sym_index_type_query] = STATE(1556),
    [sym_lookup_type] = STATE(1556),
    [sym_literal_type] = STATE(1556),
    [sym__number] = STATE(1536),
    [sym_existential_type] = STATE(1556),
    [sym_flow_maybe_type] = STATE(1556),
    [sym_parenthesized_type] = STATE(1556),
    [sym_predefined_type] = STATE(1556),
    [sym_object_type] = STATE(1556),
    [sym_type_parameters] = STATE(5248),
    [sym_array_type] = STATE(1556),
    [sym_tuple_type] = STATE(1556),
    [sym_readonly_type] = STATE(3007),
    [sym_union_type] = STATE(1556),
    [sym_intersection_type] = STATE(1556),
    [sym_function_type] = STATE(3007),
    [sym_identifier] = ACTIONS(3251),
    [anon_sym_STAR] = ACTIONS(3147),
    [anon_sym_LBRACE] = ACTIONS(3149),
    [anon_sym_typeof] = ACTIONS(3151),
    [anon_sym_import] = ACTIONS(1538),
    [anon_sym_const] = ACTIONS(3153),
    [anon_sym_LPAREN] = ACTIONS(3155),
    [anon_sym_LBRACK] = ACTIONS(3157),
    [anon_sym_new] = ACTIONS(1544),
    [anon_sym_AMP] = ACTIONS(3161),
    [anon_sym_PIPE] = ACTIONS(3163),
    [anon_sym_PLUS] = ACTIONS(3165),
    [anon_sym_DASH] = ACTIONS(3165),
    [anon_sym_LT] = ACTIONS(2499),
    [anon_sym_void] = ACTIONS(3167),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(3169),
    [sym_number] = ACTIONS(3171),
    [sym_this] = ACTIONS(3253),
    [sym_true] = ACTIONS(3175),
    [sym_false] = ACTIONS(3175),
    [sym_null] = ACTIONS(3175),
    [sym_undefined] = ACTIONS(3175),
    [anon_sym_readonly] = ACTIONS(1562),
    [anon_sym_QMARK] = ACTIONS(3179),
    [anon_sym_any] = ACTIONS(3167),
    [anon_sym_number] = ACTIONS(3167),
    [anon_sym_boolean] = ACTIONS(3167),
    [anon_sym_string] = ACTIONS(3167),
    [anon_sym_symbol] = ACTIONS(3167),
    [anon_sym_object] = ACTIONS(3167),
    [anon_sym_abstract] = ACTIONS(208),
    [anon_sym_infer] = ACTIONS(210),
    [anon_sym_keyof] = ACTIONS(3187),
    [anon_sym_unique] = ACTIONS(3189),
    [anon_sym_unknown] = ACTIONS(3167),
    [anon_sym_never] = ACTIONS(3167),
    [anon_sym_LBRACE_PIPE] = ACTIONS(3191),
    [sym_html_comment] = ACTIONS(5),
  },
  [1068] = {
    [sym_import] = STATE(4878),
    [sym_nested_identifier] = STATE(5474),
    [sym_string] = STATE(2994),
    [sym_formal_parameters] = STATE(5475),
    [sym_nested_type_identifier] = STATE(2939),
    [sym__type_query_member_expression_in_type_annotation] = STATE(2937),
    [sym__type_query_call_expression_in_type_annotation] = STATE(2938),
    [sym_type] = STATE(3021),
    [sym_constructor_type] = STATE(3007),
    [sym_primary_type] = STATE(2981),
    [sym_template_literal_type] = STATE(3039),
    [sym_infer_type] = STATE(3007),
    [sym_conditional_type] = STATE(3039),
    [sym_generic_type] = STATE(3039),
    [sym_type_query] = STATE(3039),
    [sym_index_type_query] = STATE(3039),
    [sym_lookup_type] = STATE(3039),
    [sym_literal_type] = STATE(3039),
    [sym__number] = STATE(3041),
    [sym_existential_type] = STATE(3039),
    [sym_flow_maybe_type] = STATE(3039),
    [sym_parenthesized_type] = STATE(3039),
    [sym_predefined_type] = STATE(3039),
    [sym_object_type] = STATE(3039),
    [sym_type_parameters] = STATE(5248),
    [sym_array_type] = STATE(3039),
    [sym_tuple_type] = STATE(3039),
    [sym_readonly_type] = STATE(3007),
    [sym_union_type] = STATE(3039),
    [sym_intersection_type] = STATE(3039),
    [sym_function_type] = STATE(3007),
    [sym_identifier] = ACTIONS(1532),
    [anon_sym_STAR] = ACTIONS(543),
    [anon_sym_LBRACE] = ACTIONS(1534),
    [anon_sym_typeof] = ACTIONS(1536),
    [anon_sym_import] = ACTIONS(1538),
    [anon_sym_const] = ACTIONS(133),
    [anon_sym_LPAREN] = ACTIONS(1540),
    [anon_sym_LBRACK] = ACTIONS(1542),
    [anon_sym_new] = ACTIONS(1544),
    [anon_sym_AMP] = ACTIONS(748),
    [anon_sym_PIPE] = ACTIONS(750),
    [anon_sym_PLUS] = ACTIONS(2497),
    [anon_sym_DASH] = ACTIONS(2497),
    [anon_sym_LT] = ACTIONS(2499),
    [anon_sym_void] = ACTIONS(216),
    [anon_sym_DQUOTE] = ACTIONS(1550),
    [anon_sym_SQUOTE] = ACTIONS(1552),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1554),
    [sym_number] = ACTIONS(1556),
    [sym_this] = ACTIONS(1558),
    [sym_true] = ACTIONS(1560),
    [sym_false] = ACTIONS(1560),
    [sym_null] = ACTIONS(1560),
    [sym_undefined] = ACTIONS(1560),
    [anon_sym_readonly] = ACTIONS(1562),
    [anon_sym_QMARK] = ACTIONS(774),
    [anon_sym_any] = ACTIONS(216),
    [anon_sym_number] = ACTIONS(216),
    [anon_sym_boolean] = ACTIONS(216),
    [anon_sym_string] = ACTIONS(216),
    [anon_sym_symbol] = ACTIONS(216),
    [anon_sym_object] = ACTIONS(216),
    [anon_sym_abstract] = ACTIONS(208),
    [anon_sym_infer] = ACTIONS(210),
    [anon_sym_keyof] = ACTIONS(212),
    [anon_sym_unique] = ACTIONS(214),
    [anon_sym_unknown] = ACTIONS(216),
    [anon_sym_never] = ACTIONS(216),
    [anon_sym_LBRACE_PIPE] = ACTIONS(218),
    [sym_html_comment] = ACTIONS(5),
  },
  [1069] = {
    [sym_import] = STATE(4531),
    [sym_nested_identifier] = STATE(5486),
    [sym_string] = STATE(1632),
    [sym_formal_parameters] = STATE(5639),
    [sym_nested_type_identifier] = STATE(1527),
    [sym__type_query_member_expression_in_type_annotation] = STATE(1514),
    [sym__type_query_call_expression_in_type_annotation] = STATE(1574),
    [sym_type] = STATE(1642),
    [sym_constructor_type] = STATE(1544),
    [sym_primary_type] = STATE(1554),
    [sym_template_literal_type] = STATE(1556),
    [sym_infer_type] = STATE(1544),
    [sym_conditional_type] = STATE(1556),
    [sym_generic_type] = STATE(1556),
    [sym_type_query] = STATE(1556),
    [sym_index_type_query] = STATE(1556),
    [sym_lookup_type] = STATE(1556),
    [sym_literal_type] = STATE(1556),
    [sym__number] = STATE(1536),
    [sym_existential_type] = STATE(1556),
    [sym_flow_maybe_type] = STATE(1556),
    [sym_parenthesized_type] = STATE(1556),
    [sym_predefined_type] = STATE(1556),
    [sym_object_type] = STATE(1556),
    [sym_type_parameters] = STATE(5205),
    [sym_array_type] = STATE(1556),
    [sym_tuple_type] = STATE(1556),
    [sym_readonly_type] = STATE(1544),
    [sym_union_type] = STATE(1556),
    [sym_intersection_type] = STATE(1556),
    [sym_function_type] = STATE(1544),
    [sym_identifier] = ACTIONS(3251),
    [anon_sym_STAR] = ACTIONS(3147),
    [anon_sym_LBRACE] = ACTIONS(3149),
    [anon_sym_typeof] = ACTIONS(3151),
    [anon_sym_import] = ACTIONS(1538),
    [anon_sym_const] = ACTIONS(3153),
    [anon_sym_LPAREN] = ACTIONS(3155),
    [anon_sym_LBRACK] = ACTIONS(3157),
    [anon_sym_new] = ACTIONS(3159),
    [anon_sym_AMP] = ACTIONS(3161),
    [anon_sym_PIPE] = ACTIONS(3163),
    [anon_sym_PLUS] = ACTIONS(3165),
    [anon_sym_DASH] = ACTIONS(3165),
    [anon_sym_LT] = ACTIONS(2499),
    [anon_sym_void] = ACTIONS(3167),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(3169),
    [sym_number] = ACTIONS(3171),
    [sym_this] = ACTIONS(3253),
    [sym_true] = ACTIONS(3175),
    [sym_false] = ACTIONS(3175),
    [sym_null] = ACTIONS(3175),
    [sym_undefined] = ACTIONS(3175),
    [anon_sym_readonly] = ACTIONS(3177),
    [anon_sym_QMARK] = ACTIONS(3179),
    [anon_sym_any] = ACTIONS(3167),
    [anon_sym_number] = ACTIONS(3167),
    [anon_sym_boolean] = ACTIONS(3167),
    [anon_sym_string] = ACTIONS(3167),
    [anon_sym_symbol] = ACTIONS(3167),
    [anon_sym_object] = ACTIONS(3167),
    [anon_sym_abstract] = ACTIONS(3181),
    [anon_sym_infer] = ACTIONS(3185),
    [anon_sym_keyof] = ACTIONS(3187),
    [anon_sym_unique] = ACTIONS(3189),
    [anon_sym_unknown] = ACTIONS(3167),
    [anon_sym_never] = ACTIONS(3167),
    [anon_sym_LBRACE_PIPE] = ACTIONS(3191),
    [sym_html_comment] = ACTIONS(5),
  },
  [1070] = {
    [sym_import] = STATE(4531),
    [sym_nested_identifier] = STATE(5486),
    [sym_string] = STATE(1632),
    [sym_formal_parameters] = STATE(5639),
    [sym_nested_type_identifier] = STATE(1527),
    [sym__type_query_member_expression_in_type_annotation] = STATE(1514),
    [sym__type_query_call_expression_in_type_annotation] = STATE(1574),
    [sym_type] = STATE(1644),
    [sym_constructor_type] = STATE(1544),
    [sym_primary_type] = STATE(1554),
    [sym_template_literal_type] = STATE(1556),
    [sym_infer_type] = STATE(1544),
    [sym_conditional_type] = STATE(1556),
    [sym_generic_type] = STATE(1556),
    [sym_type_query] = STATE(1556),
    [sym_index_type_query] = STATE(1556),
    [sym_lookup_type] = STATE(1556),
    [sym_literal_type] = STATE(1556),
    [sym__number] = STATE(1536),
    [sym_existential_type] = STATE(1556),
    [sym_flow_maybe_type] = STATE(1556),
    [sym_parenthesized_type] = STATE(1556),
    [sym_predefined_type] = STATE(1556),
    [sym_object_type] = STATE(1556),
    [sym_type_parameters] = STATE(5205),
    [sym_array_type] = STATE(1556),
    [sym_tuple_type] = STATE(1556),
    [sym_readonly_type] = STATE(1544),
    [sym_union_type] = STATE(1556),
    [sym_intersection_type] = STATE(1556),
    [sym_function_type] = STATE(1544),
    [sym_identifier] = ACTIONS(3251),
    [anon_sym_STAR] = ACTIONS(3147),
    [anon_sym_LBRACE] = ACTIONS(3149),
    [anon_sym_typeof] = ACTIONS(3151),
    [anon_sym_import] = ACTIONS(1538),
    [anon_sym_const] = ACTIONS(3153),
    [anon_sym_LPAREN] = ACTIONS(3155),
    [anon_sym_LBRACK] = ACTIONS(3157),
    [anon_sym_new] = ACTIONS(3159),
    [anon_sym_AMP] = ACTIONS(3161),
    [anon_sym_PIPE] = ACTIONS(3163),
    [anon_sym_PLUS] = ACTIONS(3165),
    [anon_sym_DASH] = ACTIONS(3165),
    [anon_sym_LT] = ACTIONS(2499),
    [anon_sym_void] = ACTIONS(3167),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(3169),
    [sym_number] = ACTIONS(3171),
    [sym_this] = ACTIONS(3253),
    [sym_true] = ACTIONS(3175),
    [sym_false] = ACTIONS(3175),
    [sym_null] = ACTIONS(3175),
    [sym_undefined] = ACTIONS(3175),
    [anon_sym_readonly] = ACTIONS(3177),
    [anon_sym_QMARK] = ACTIONS(3179),
    [anon_sym_any] = ACTIONS(3167),
    [anon_sym_number] = ACTIONS(3167),
    [anon_sym_boolean] = ACTIONS(3167),
    [anon_sym_string] = ACTIONS(3167),
    [anon_sym_symbol] = ACTIONS(3167),
    [anon_sym_object] = ACTIONS(3167),
    [anon_sym_abstract] = ACTIONS(3181),
    [anon_sym_infer] = ACTIONS(3185),
    [anon_sym_keyof] = ACTIONS(3187),
    [anon_sym_unique] = ACTIONS(3189),
    [anon_sym_unknown] = ACTIONS(3167),
    [anon_sym_never] = ACTIONS(3167),
    [anon_sym_LBRACE_PIPE] = ACTIONS(3191),
    [sym_html_comment] = ACTIONS(5),
  },
  [1071] = {
    [sym_import] = STATE(4878),
    [sym_nested_identifier] = STATE(5474),
    [sym_string] = STATE(2994),
    [sym_formal_parameters] = STATE(5475),
    [sym_nested_type_identifier] = STATE(2939),
    [sym__type_query_member_expression_in_type_annotation] = STATE(2937),
    [sym__type_query_call_expression_in_type_annotation] = STATE(2938),
    [sym_type] = STATE(4437),
    [sym_constructor_type] = STATE(3007),
    [sym_primary_type] = STATE(2981),
    [sym_template_literal_type] = STATE(3039),
    [sym_infer_type] = STATE(3007),
    [sym_conditional_type] = STATE(3039),
    [sym_generic_type] = STATE(3039),
    [sym_type_query] = STATE(3039),
    [sym_index_type_query] = STATE(3039),
    [sym_lookup_type] = STATE(3039),
    [sym_literal_type] = STATE(3039),
    [sym__number] = STATE(3041),
    [sym_existential_type] = STATE(3039),
    [sym_flow_maybe_type] = STATE(3039),
    [sym_parenthesized_type] = STATE(3039),
    [sym_predefined_type] = STATE(3039),
    [sym_object_type] = STATE(3039),
    [sym_type_parameters] = STATE(5248),
    [sym_array_type] = STATE(3039),
    [sym_tuple_type] = STATE(3039),
    [sym_readonly_type] = STATE(3007),
    [sym_union_type] = STATE(3039),
    [sym_intersection_type] = STATE(3039),
    [sym_function_type] = STATE(3007),
    [sym_identifier] = ACTIONS(1532),
    [anon_sym_STAR] = ACTIONS(543),
    [anon_sym_LBRACE] = ACTIONS(1534),
    [anon_sym_typeof] = ACTIONS(1536),
    [anon_sym_import] = ACTIONS(1538),
    [anon_sym_const] = ACTIONS(133),
    [anon_sym_LPAREN] = ACTIONS(1540),
    [anon_sym_LBRACK] = ACTIONS(1542),
    [anon_sym_new] = ACTIONS(1544),
    [anon_sym_AMP] = ACTIONS(748),
    [anon_sym_PIPE] = ACTIONS(750),
    [anon_sym_PLUS] = ACTIONS(2497),
    [anon_sym_DASH] = ACTIONS(2497),
    [anon_sym_LT] = ACTIONS(2499),
    [anon_sym_void] = ACTIONS(216),
    [anon_sym_DQUOTE] = ACTIONS(1550),
    [anon_sym_SQUOTE] = ACTIONS(1552),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1554),
    [sym_number] = ACTIONS(1556),
    [sym_this] = ACTIONS(1558),
    [sym_true] = ACTIONS(1560),
    [sym_false] = ACTIONS(1560),
    [sym_null] = ACTIONS(1560),
    [sym_undefined] = ACTIONS(1560),
    [anon_sym_readonly] = ACTIONS(1562),
    [anon_sym_QMARK] = ACTIONS(774),
    [anon_sym_any] = ACTIONS(216),
    [anon_sym_number] = ACTIONS(216),
    [anon_sym_boolean] = ACTIONS(216),
    [anon_sym_string] = ACTIONS(216),
    [anon_sym_symbol] = ACTIONS(216),
    [anon_sym_object] = ACTIONS(216),
    [anon_sym_abstract] = ACTIONS(208),
    [anon_sym_infer] = ACTIONS(210),
    [anon_sym_keyof] = ACTIONS(212),
    [anon_sym_unique] = ACTIONS(214),
    [anon_sym_unknown] = ACTIONS(216),
    [anon_sym_never] = ACTIONS(216),
    [anon_sym_LBRACE_PIPE] = ACTIONS(218),
    [sym_html_comment] = ACTIONS(5),
  },
  [1072] = {
    [sym_import] = STATE(4531),
    [sym_nested_identifier] = STATE(5486),
    [sym_string] = STATE(1632),
    [sym_formal_parameters] = STATE(5639),
    [sym_nested_type_identifier] = STATE(1527),
    [sym__type_query_member_expression_in_type_annotation] = STATE(1514),
    [sym__type_query_call_expression_in_type_annotation] = STATE(1574),
    [sym_type] = STATE(1553),
    [sym_constructor_type] = STATE(1544),
    [sym_primary_type] = STATE(1554),
    [sym_template_literal_type] = STATE(1556),
    [sym_infer_type] = STATE(1544),
    [sym_conditional_type] = STATE(1556),
    [sym_generic_type] = STATE(1556),
    [sym_type_query] = STATE(1556),
    [sym_index_type_query] = STATE(1556),
    [sym_lookup_type] = STATE(1556),
    [sym_literal_type] = STATE(1556),
    [sym__number] = STATE(1536),
    [sym_existential_type] = STATE(1556),
    [sym_flow_maybe_type] = STATE(1556),
    [sym_parenthesized_type] = STATE(1556),
    [sym_predefined_type] = STATE(1556),
    [sym_object_type] = STATE(1556),
    [sym_type_parameters] = STATE(5205),
    [sym_array_type] = STATE(1556),
    [sym_tuple_type] = STATE(1556),
    [sym_readonly_type] = STATE(1544),
    [sym_union_type] = STATE(1556),
    [sym_intersection_type] = STATE(1556),
    [sym_function_type] = STATE(1544),
    [sym_identifier] = ACTIONS(3251),
    [anon_sym_STAR] = ACTIONS(3147),
    [anon_sym_LBRACE] = ACTIONS(3149),
    [anon_sym_typeof] = ACTIONS(3151),
    [anon_sym_import] = ACTIONS(1538),
    [anon_sym_const] = ACTIONS(3153),
    [anon_sym_LPAREN] = ACTIONS(3155),
    [anon_sym_LBRACK] = ACTIONS(3157),
    [anon_sym_new] = ACTIONS(3159),
    [anon_sym_AMP] = ACTIONS(3161),
    [anon_sym_PIPE] = ACTIONS(3163),
    [anon_sym_PLUS] = ACTIONS(3165),
    [anon_sym_DASH] = ACTIONS(3165),
    [anon_sym_LT] = ACTIONS(2499),
    [anon_sym_void] = ACTIONS(3167),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(3169),
    [sym_number] = ACTIONS(3171),
    [sym_this] = ACTIONS(3253),
    [sym_true] = ACTIONS(3175),
    [sym_false] = ACTIONS(3175),
    [sym_null] = ACTIONS(3175),
    [sym_undefined] = ACTIONS(3175),
    [anon_sym_readonly] = ACTIONS(3177),
    [anon_sym_QMARK] = ACTIONS(3179),
    [anon_sym_any] = ACTIONS(3167),
    [anon_sym_number] = ACTIONS(3167),
    [anon_sym_boolean] = ACTIONS(3167),
    [anon_sym_string] = ACTIONS(3167),
    [anon_sym_symbol] = ACTIONS(3167),
    [anon_sym_object] = ACTIONS(3167),
    [anon_sym_abstract] = ACTIONS(3181),
    [anon_sym_infer] = ACTIONS(3185),
    [anon_sym_keyof] = ACTIONS(3187),
    [anon_sym_unique] = ACTIONS(3189),
    [anon_sym_unknown] = ACTIONS(3167),
    [anon_sym_never] = ACTIONS(3167),
    [anon_sym_LBRACE_PIPE] = ACTIONS(3191),
    [sym_html_comment] = ACTIONS(5),
  },
  [1073] = {
    [sym_import] = STATE(4531),
    [sym_nested_identifier] = STATE(5486),
    [sym_string] = STATE(1632),
    [sym_formal_parameters] = STATE(5639),
    [sym_nested_type_identifier] = STATE(1527),
    [sym__type_query_member_expression_in_type_annotation] = STATE(1514),
    [sym__type_query_call_expression_in_type_annotation] = STATE(1574),
    [sym_type] = STATE(1557),
    [sym_constructor_type] = STATE(1544),
    [sym_primary_type] = STATE(1554),
    [sym_template_literal_type] = STATE(1556),
    [sym_infer_type] = STATE(1544),
    [sym_conditional_type] = STATE(1556),
    [sym_generic_type] = STATE(1556),
    [sym_type_query] = STATE(1556),
    [sym_index_type_query] = STATE(1556),
    [sym_lookup_type] = STATE(1556),
    [sym_literal_type] = STATE(1556),
    [sym__number] = STATE(1536),
    [sym_existential_type] = STATE(1556),
    [sym_flow_maybe_type] = STATE(1556),
    [sym_parenthesized_type] = STATE(1556),
    [sym_predefined_type] = STATE(1556),
    [sym_object_type] = STATE(1556),
    [sym_type_parameters] = STATE(5205),
    [sym_array_type] = STATE(1556),
    [sym_tuple_type] = STATE(1556),
    [sym_readonly_type] = STATE(1544),
    [sym_union_type] = STATE(1556),
    [sym_intersection_type] = STATE(1556),
    [sym_function_type] = STATE(1544),
    [sym_identifier] = ACTIONS(3251),
    [anon_sym_STAR] = ACTIONS(3147),
    [anon_sym_LBRACE] = ACTIONS(3149),
    [anon_sym_typeof] = ACTIONS(3151),
    [anon_sym_import] = ACTIONS(1538),
    [anon_sym_const] = ACTIONS(3153),
    [anon_sym_LPAREN] = ACTIONS(3155),
    [anon_sym_LBRACK] = ACTIONS(3157),
    [anon_sym_new] = ACTIONS(3159),
    [anon_sym_AMP] = ACTIONS(3161),
    [anon_sym_PIPE] = ACTIONS(3163),
    [anon_sym_PLUS] = ACTIONS(3165),
    [anon_sym_DASH] = ACTIONS(3165),
    [anon_sym_LT] = ACTIONS(2499),
    [anon_sym_void] = ACTIONS(3167),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(3169),
    [sym_number] = ACTIONS(3171),
    [sym_this] = ACTIONS(3253),
    [sym_true] = ACTIONS(3175),
    [sym_false] = ACTIONS(3175),
    [sym_null] = ACTIONS(3175),
    [sym_undefined] = ACTIONS(3175),
    [anon_sym_readonly] = ACTIONS(3177),
    [anon_sym_QMARK] = ACTIONS(3179),
    [anon_sym_any] = ACTIONS(3167),
    [anon_sym_number] = ACTIONS(3167),
    [anon_sym_boolean] = ACTIONS(3167),
    [anon_sym_string] = ACTIONS(3167),
    [anon_sym_symbol] = ACTIONS(3167),
    [anon_sym_object] = ACTIONS(3167),
    [anon_sym_abstract] = ACTIONS(3181),
    [anon_sym_infer] = ACTIONS(3185),
    [anon_sym_keyof] = ACTIONS(3187),
    [anon_sym_unique] = ACTIONS(3189),
    [anon_sym_unknown] = ACTIONS(3167),
    [anon_sym_never] = ACTIONS(3167),
    [anon_sym_LBRACE_PIPE] = ACTIONS(3191),
    [sym_html_comment] = ACTIONS(5),
  },
  [1074] = {
    [sym_import] = STATE(4878),
    [sym_nested_identifier] = STATE(5474),
    [sym_string] = STATE(2994),
    [sym_formal_parameters] = STATE(5475),
    [sym_nested_type_identifier] = STATE(2939),
    [sym__type_query_member_expression_in_type_annotation] = STATE(2937),
    [sym__type_query_call_expression_in_type_annotation] = STATE(2938),
    [sym_type] = STATE(4415),
    [sym_constructor_type] = STATE(3007),
    [sym_primary_type] = STATE(2981),
    [sym_template_literal_type] = STATE(3039),
    [sym_infer_type] = STATE(3007),
    [sym_conditional_type] = STATE(3039),
    [sym_generic_type] = STATE(3039),
    [sym_type_query] = STATE(3039),
    [sym_index_type_query] = STATE(3039),
    [sym_lookup_type] = STATE(3039),
    [sym_literal_type] = STATE(3039),
    [sym__number] = STATE(3041),
    [sym_existential_type] = STATE(3039),
    [sym_flow_maybe_type] = STATE(3039),
    [sym_parenthesized_type] = STATE(3039),
    [sym_predefined_type] = STATE(3039),
    [sym_object_type] = STATE(3039),
    [sym_type_parameters] = STATE(5248),
    [sym_array_type] = STATE(3039),
    [sym_tuple_type] = STATE(3039),
    [sym_readonly_type] = STATE(3007),
    [sym_union_type] = STATE(3039),
    [sym_intersection_type] = STATE(3039),
    [sym_function_type] = STATE(3007),
    [sym_identifier] = ACTIONS(1532),
    [anon_sym_STAR] = ACTIONS(543),
    [anon_sym_LBRACE] = ACTIONS(1534),
    [anon_sym_typeof] = ACTIONS(1536),
    [anon_sym_import] = ACTIONS(1538),
    [anon_sym_const] = ACTIONS(133),
    [anon_sym_LPAREN] = ACTIONS(1540),
    [anon_sym_LBRACK] = ACTIONS(1542),
    [anon_sym_new] = ACTIONS(1544),
    [anon_sym_AMP] = ACTIONS(748),
    [anon_sym_PIPE] = ACTIONS(750),
    [anon_sym_PLUS] = ACTIONS(2497),
    [anon_sym_DASH] = ACTIONS(2497),
    [anon_sym_LT] = ACTIONS(2499),
    [anon_sym_void] = ACTIONS(216),
    [anon_sym_DQUOTE] = ACTIONS(1550),
    [anon_sym_SQUOTE] = ACTIONS(1552),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1554),
    [sym_number] = ACTIONS(1556),
    [sym_this] = ACTIONS(1558),
    [sym_true] = ACTIONS(1560),
    [sym_false] = ACTIONS(1560),
    [sym_null] = ACTIONS(1560),
    [sym_undefined] = ACTIONS(1560),
    [anon_sym_readonly] = ACTIONS(1562),
    [anon_sym_QMARK] = ACTIONS(774),
    [anon_sym_any] = ACTIONS(216),
    [anon_sym_number] = ACTIONS(216),
    [anon_sym_boolean] = ACTIONS(216),
    [anon_sym_string] = ACTIONS(216),
    [anon_sym_symbol] = ACTIONS(216),
    [anon_sym_object] = ACTIONS(216),
    [anon_sym_abstract] = ACTIONS(208),
    [anon_sym_infer] = ACTIONS(210),
    [anon_sym_keyof] = ACTIONS(212),
    [anon_sym_unique] = ACTIONS(214),
    [anon_sym_unknown] = ACTIONS(216),
    [anon_sym_never] = ACTIONS(216),
    [anon_sym_LBRACE_PIPE] = ACTIONS(218),
    [sym_html_comment] = ACTIONS(5),
  },
  [1075] = {
    [sym_import] = STATE(4531),
    [sym_nested_identifier] = STATE(5486),
    [sym_string] = STATE(1632),
    [sym_formal_parameters] = STATE(5639),
    [sym_nested_type_identifier] = STATE(1527),
    [sym__type_query_member_expression_in_type_annotation] = STATE(1514),
    [sym__type_query_call_expression_in_type_annotation] = STATE(1574),
    [sym_type] = STATE(1577),
    [sym_constructor_type] = STATE(1544),
    [sym_primary_type] = STATE(1554),
    [sym_template_literal_type] = STATE(1556),
    [sym_infer_type] = STATE(1544),
    [sym_conditional_type] = STATE(1556),
    [sym_generic_type] = STATE(1556),
    [sym_type_query] = STATE(1556),
    [sym_index_type_query] = STATE(1556),
    [sym_lookup_type] = STATE(1556),
    [sym_literal_type] = STATE(1556),
    [sym__number] = STATE(1536),
    [sym_existential_type] = STATE(1556),
    [sym_flow_maybe_type] = STATE(1556),
    [sym_parenthesized_type] = STATE(1556),
    [sym_predefined_type] = STATE(1556),
    [sym_object_type] = STATE(1556),
    [sym_type_parameters] = STATE(5205),
    [sym_array_type] = STATE(1556),
    [sym_tuple_type] = STATE(1556),
    [sym_readonly_type] = STATE(1544),
    [sym_union_type] = STATE(1556),
    [sym_intersection_type] = STATE(1556),
    [sym_function_type] = STATE(1544),
    [sym_identifier] = ACTIONS(3251),
    [anon_sym_STAR] = ACTIONS(3147),
    [anon_sym_LBRACE] = ACTIONS(3149),
    [anon_sym_typeof] = ACTIONS(3151),
    [anon_sym_import] = ACTIONS(1538),
    [anon_sym_const] = ACTIONS(3153),
    [anon_sym_LPAREN] = ACTIONS(3155),
    [anon_sym_LBRACK] = ACTIONS(3157),
    [anon_sym_new] = ACTIONS(3159),
    [anon_sym_AMP] = ACTIONS(3161),
    [anon_sym_PIPE] = ACTIONS(3163),
    [anon_sym_PLUS] = ACTIONS(3165),
    [anon_sym_DASH] = ACTIONS(3165),
    [anon_sym_LT] = ACTIONS(2499),
    [anon_sym_void] = ACTIONS(3167),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(3169),
    [sym_number] = ACTIONS(3171),
    [sym_this] = ACTIONS(3253),
    [sym_true] = ACTIONS(3175),
    [sym_false] = ACTIONS(3175),
    [sym_null] = ACTIONS(3175),
    [sym_undefined] = ACTIONS(3175),
    [anon_sym_readonly] = ACTIONS(3177),
    [anon_sym_QMARK] = ACTIONS(3179),
    [anon_sym_any] = ACTIONS(3167),
    [anon_sym_number] = ACTIONS(3167),
    [anon_sym_boolean] = ACTIONS(3167),
    [anon_sym_string] = ACTIONS(3167),
    [anon_sym_symbol] = ACTIONS(3167),
    [anon_sym_object] = ACTIONS(3167),
    [anon_sym_abstract] = ACTIONS(3181),
    [anon_sym_infer] = ACTIONS(3185),
    [anon_sym_keyof] = ACTIONS(3187),
    [anon_sym_unique] = ACTIONS(3189),
    [anon_sym_unknown] = ACTIONS(3167),
    [anon_sym_never] = ACTIONS(3167),
    [anon_sym_LBRACE_PIPE] = ACTIONS(3191),
    [sym_html_comment] = ACTIONS(5),
  },
  [1076] = {
    [sym_import] = STATE(4531),
    [sym_nested_identifier] = STATE(5486),
    [sym_string] = STATE(1632),
    [sym_formal_parameters] = STATE(5639),
    [sym_nested_type_identifier] = STATE(1527),
    [sym__type_query_member_expression_in_type_annotation] = STATE(1514),
    [sym__type_query_call_expression_in_type_annotation] = STATE(1574),
    [sym_type] = STATE(1578),
    [sym_constructor_type] = STATE(1544),
    [sym_primary_type] = STATE(1554),
    [sym_template_literal_type] = STATE(1556),
    [sym_infer_type] = STATE(1544),
    [sym_conditional_type] = STATE(1556),
    [sym_generic_type] = STATE(1556),
    [sym_type_query] = STATE(1556),
    [sym_index_type_query] = STATE(1556),
    [sym_lookup_type] = STATE(1556),
    [sym_literal_type] = STATE(1556),
    [sym__number] = STATE(1536),
    [sym_existential_type] = STATE(1556),
    [sym_flow_maybe_type] = STATE(1556),
    [sym_parenthesized_type] = STATE(1556),
    [sym_predefined_type] = STATE(1556),
    [sym_object_type] = STATE(1556),
    [sym_type_parameters] = STATE(5205),
    [sym_array_type] = STATE(1556),
    [sym_tuple_type] = STATE(1556),
    [sym_readonly_type] = STATE(1544),
    [sym_union_type] = STATE(1556),
    [sym_intersection_type] = STATE(1556),
    [sym_function_type] = STATE(1544),
    [sym_identifier] = ACTIONS(3251),
    [anon_sym_STAR] = ACTIONS(3147),
    [anon_sym_LBRACE] = ACTIONS(3149),
    [anon_sym_typeof] = ACTIONS(3151),
    [anon_sym_import] = ACTIONS(1538),
    [anon_sym_const] = ACTIONS(3153),
    [anon_sym_LPAREN] = ACTIONS(3155),
    [anon_sym_LBRACK] = ACTIONS(3157),
    [anon_sym_new] = ACTIONS(3159),
    [anon_sym_AMP] = ACTIONS(3161),
    [anon_sym_PIPE] = ACTIONS(3163),
    [anon_sym_PLUS] = ACTIONS(3165),
    [anon_sym_DASH] = ACTIONS(3165),
    [anon_sym_LT] = ACTIONS(2499),
    [anon_sym_void] = ACTIONS(3167),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(3169),
    [sym_number] = ACTIONS(3171),
    [sym_this] = ACTIONS(3253),
    [sym_true] = ACTIONS(3175),
    [sym_false] = ACTIONS(3175),
    [sym_null] = ACTIONS(3175),
    [sym_undefined] = ACTIONS(3175),
    [anon_sym_readonly] = ACTIONS(3177),
    [anon_sym_QMARK] = ACTIONS(3179),
    [anon_sym_any] = ACTIONS(3167),
    [anon_sym_number] = ACTIONS(3167),
    [anon_sym_boolean] = ACTIONS(3167),
    [anon_sym_string] = ACTIONS(3167),
    [anon_sym_symbol] = ACTIONS(3167),
    [anon_sym_object] = ACTIONS(3167),
    [anon_sym_abstract] = ACTIONS(3181),
    [anon_sym_infer] = ACTIONS(3185),
    [anon_sym_keyof] = ACTIONS(3187),
    [anon_sym_unique] = ACTIONS(3189),
    [anon_sym_unknown] = ACTIONS(3167),
    [anon_sym_never] = ACTIONS(3167),
    [anon_sym_LBRACE_PIPE] = ACTIONS(3191),
    [sym_html_comment] = ACTIONS(5),
  },
  [1077] = {
    [sym_import] = STATE(4531),
    [sym_nested_identifier] = STATE(5486),
    [sym_string] = STATE(1632),
    [sym_formal_parameters] = STATE(5639),
    [sym_nested_type_identifier] = STATE(1527),
    [sym__type_query_member_expression_in_type_annotation] = STATE(1514),
    [sym__type_query_call_expression_in_type_annotation] = STATE(1574),
    [sym_type] = STATE(1600),
    [sym_constructor_type] = STATE(1544),
    [sym_primary_type] = STATE(1554),
    [sym_template_literal_type] = STATE(1556),
    [sym_infer_type] = STATE(1544),
    [sym_conditional_type] = STATE(1556),
    [sym_generic_type] = STATE(1556),
    [sym_type_query] = STATE(1556),
    [sym_index_type_query] = STATE(1556),
    [sym_lookup_type] = STATE(1556),
    [sym_literal_type] = STATE(1556),
    [sym__number] = STATE(1536),
    [sym_existential_type] = STATE(1556),
    [sym_flow_maybe_type] = STATE(1556),
    [sym_parenthesized_type] = STATE(1556),
    [sym_predefined_type] = STATE(1556),
    [sym_object_type] = STATE(1556),
    [sym_type_parameters] = STATE(5205),
    [sym_array_type] = STATE(1556),
    [sym_tuple_type] = STATE(1556),
    [sym_readonly_type] = STATE(1544),
    [sym_union_type] = STATE(1556),
    [sym_intersection_type] = STATE(1556),
    [sym_function_type] = STATE(1544),
    [sym_identifier] = ACTIONS(3251),
    [anon_sym_STAR] = ACTIONS(3147),
    [anon_sym_LBRACE] = ACTIONS(3149),
    [anon_sym_typeof] = ACTIONS(3151),
    [anon_sym_import] = ACTIONS(1538),
    [anon_sym_const] = ACTIONS(3153),
    [anon_sym_LPAREN] = ACTIONS(3155),
    [anon_sym_LBRACK] = ACTIONS(3157),
    [anon_sym_new] = ACTIONS(3159),
    [anon_sym_AMP] = ACTIONS(3161),
    [anon_sym_PIPE] = ACTIONS(3163),
    [anon_sym_PLUS] = ACTIONS(3165),
    [anon_sym_DASH] = ACTIONS(3165),
    [anon_sym_LT] = ACTIONS(2499),
    [anon_sym_void] = ACTIONS(3167),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(3169),
    [sym_number] = ACTIONS(3171),
    [sym_this] = ACTIONS(3253),
    [sym_true] = ACTIONS(3175),
    [sym_false] = ACTIONS(3175),
    [sym_null] = ACTIONS(3175),
    [sym_undefined] = ACTIONS(3175),
    [anon_sym_readonly] = ACTIONS(3177),
    [anon_sym_QMARK] = ACTIONS(3179),
    [anon_sym_any] = ACTIONS(3167),
    [anon_sym_number] = ACTIONS(3167),
    [anon_sym_boolean] = ACTIONS(3167),
    [anon_sym_string] = ACTIONS(3167),
    [anon_sym_symbol] = ACTIONS(3167),
    [anon_sym_object] = ACTIONS(3167),
    [anon_sym_abstract] = ACTIONS(3181),
    [anon_sym_infer] = ACTIONS(3185),
    [anon_sym_keyof] = ACTIONS(3187),
    [anon_sym_unique] = ACTIONS(3189),
    [anon_sym_unknown] = ACTIONS(3167),
    [anon_sym_never] = ACTIONS(3167),
    [anon_sym_LBRACE_PIPE] = ACTIONS(3191),
    [sym_html_comment] = ACTIONS(5),
  },
  [1078] = {
    [sym_import] = STATE(4531),
    [sym_nested_identifier] = STATE(5486),
    [sym_string] = STATE(1632),
    [sym_formal_parameters] = STATE(5639),
    [sym_nested_type_identifier] = STATE(1527),
    [sym__type_query_member_expression_in_type_annotation] = STATE(1514),
    [sym__type_query_call_expression_in_type_annotation] = STATE(1574),
    [sym_type] = STATE(1605),
    [sym_constructor_type] = STATE(1544),
    [sym_primary_type] = STATE(1554),
    [sym_template_literal_type] = STATE(1556),
    [sym_infer_type] = STATE(1544),
    [sym_conditional_type] = STATE(1556),
    [sym_generic_type] = STATE(1556),
    [sym_type_query] = STATE(1556),
    [sym_index_type_query] = STATE(1556),
    [sym_lookup_type] = STATE(1556),
    [sym_literal_type] = STATE(1556),
    [sym__number] = STATE(1536),
    [sym_existential_type] = STATE(1556),
    [sym_flow_maybe_type] = STATE(1556),
    [sym_parenthesized_type] = STATE(1556),
    [sym_predefined_type] = STATE(1556),
    [sym_object_type] = STATE(1556),
    [sym_type_parameters] = STATE(5205),
    [sym_array_type] = STATE(1556),
    [sym_tuple_type] = STATE(1556),
    [sym_readonly_type] = STATE(1544),
    [sym_union_type] = STATE(1556),
    [sym_intersection_type] = STATE(1556),
    [sym_function_type] = STATE(1544),
    [sym_identifier] = ACTIONS(3251),
    [anon_sym_STAR] = ACTIONS(3147),
    [anon_sym_LBRACE] = ACTIONS(3149),
    [anon_sym_typeof] = ACTIONS(3151),
    [anon_sym_import] = ACTIONS(1538),
    [anon_sym_const] = ACTIONS(3153),
    [anon_sym_LPAREN] = ACTIONS(3155),
    [anon_sym_LBRACK] = ACTIONS(3157),
    [anon_sym_new] = ACTIONS(3159),
    [anon_sym_AMP] = ACTIONS(3161),
    [anon_sym_PIPE] = ACTIONS(3163),
    [anon_sym_PLUS] = ACTIONS(3165),
    [anon_sym_DASH] = ACTIONS(3165),
    [anon_sym_LT] = ACTIONS(2499),
    [anon_sym_void] = ACTIONS(3167),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(3169),
    [sym_number] = ACTIONS(3171),
    [sym_this] = ACTIONS(3253),
    [sym_true] = ACTIONS(3175),
    [sym_false] = ACTIONS(3175),
    [sym_null] = ACTIONS(3175),
    [sym_undefined] = ACTIONS(3175),
    [anon_sym_readonly] = ACTIONS(3177),
    [anon_sym_QMARK] = ACTIONS(3179),
    [anon_sym_any] = ACTIONS(3167),
    [anon_sym_number] = ACTIONS(3167),
    [anon_sym_boolean] = ACTIONS(3167),
    [anon_sym_string] = ACTIONS(3167),
    [anon_sym_symbol] = ACTIONS(3167),
    [anon_sym_object] = ACTIONS(3167),
    [anon_sym_abstract] = ACTIONS(3181),
    [anon_sym_infer] = ACTIONS(3185),
    [anon_sym_keyof] = ACTIONS(3187),
    [anon_sym_unique] = ACTIONS(3189),
    [anon_sym_unknown] = ACTIONS(3167),
    [anon_sym_never] = ACTIONS(3167),
    [anon_sym_LBRACE_PIPE] = ACTIONS(3191),
    [sym_html_comment] = ACTIONS(5),
  },
  [1079] = {
    [sym_import] = STATE(4578),
    [sym_nested_identifier] = STATE(5796),
    [sym_string] = STATE(3437),
    [sym_formal_parameters] = STATE(5519),
    [sym_nested_type_identifier] = STATE(3278),
    [sym__type_query_member_expression_in_type_annotation] = STATE(3181),
    [sym__type_query_call_expression_in_type_annotation] = STATE(3311),
    [sym_type] = STATE(3406),
    [sym_constructor_type] = STATE(3448),
    [sym_primary_type] = STATE(3450),
    [sym_template_literal_type] = STATE(3453),
    [sym_infer_type] = STATE(3448),
    [sym_conditional_type] = STATE(3453),
    [sym_generic_type] = STATE(3453),
    [sym_type_query] = STATE(3453),
    [sym_index_type_query] = STATE(3453),
    [sym_lookup_type] = STATE(3453),
    [sym_literal_type] = STATE(3453),
    [sym__number] = STATE(3454),
    [sym_existential_type] = STATE(3453),
    [sym_flow_maybe_type] = STATE(3453),
    [sym_parenthesized_type] = STATE(3453),
    [sym_predefined_type] = STATE(3453),
    [sym_object_type] = STATE(3453),
    [sym_type_parameters] = STATE(5251),
    [sym_array_type] = STATE(3453),
    [sym_tuple_type] = STATE(3453),
    [sym_readonly_type] = STATE(3448),
    [sym_union_type] = STATE(3453),
    [sym_intersection_type] = STATE(3453),
    [sym_function_type] = STATE(3448),
    [sym_identifier] = ACTIONS(3259),
    [anon_sym_STAR] = ACTIONS(2995),
    [anon_sym_LBRACE] = ACTIONS(2997),
    [anon_sym_typeof] = ACTIONS(2999),
    [anon_sym_import] = ACTIONS(1538),
    [anon_sym_const] = ACTIONS(3001),
    [anon_sym_LPAREN] = ACTIONS(3003),
    [anon_sym_LBRACK] = ACTIONS(3005),
    [anon_sym_new] = ACTIONS(3007),
    [anon_sym_AMP] = ACTIONS(3009),
    [anon_sym_PIPE] = ACTIONS(3011),
    [anon_sym_PLUS] = ACTIONS(3013),
    [anon_sym_DASH] = ACTIONS(3013),
    [anon_sym_LT] = ACTIONS(2499),
    [anon_sym_void] = ACTIONS(3015),
    [anon_sym_DQUOTE] = ACTIONS(3017),
    [anon_sym_SQUOTE] = ACTIONS(3019),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(3021),
    [sym_number] = ACTIONS(3023),
    [sym_this] = ACTIONS(3261),
    [sym_true] = ACTIONS(3027),
    [sym_false] = ACTIONS(3027),
    [sym_null] = ACTIONS(3027),
    [sym_undefined] = ACTIONS(3027),
    [anon_sym_readonly] = ACTIONS(3029),
    [anon_sym_QMARK] = ACTIONS(3031),
    [anon_sym_any] = ACTIONS(3015),
    [anon_sym_number] = ACTIONS(3015),
    [anon_sym_boolean] = ACTIONS(3015),
    [anon_sym_string] = ACTIONS(3015),
    [anon_sym_symbol] = ACTIONS(3015),
    [anon_sym_object] = ACTIONS(3015),
    [anon_sym_abstract] = ACTIONS(3033),
    [anon_sym_infer] = ACTIONS(3037),
    [anon_sym_keyof] = ACTIONS(3039),
    [anon_sym_unique] = ACTIONS(3041),
    [anon_sym_unknown] = ACTIONS(3015),
    [anon_sym_never] = ACTIONS(3015),
    [anon_sym_LBRACE_PIPE] = ACTIONS(3043),
    [sym_html_comment] = ACTIONS(5),
  },
  [1080] = {
    [sym_import] = STATE(4578),
    [sym_nested_identifier] = STATE(5796),
    [sym_string] = STATE(3437),
    [sym_formal_parameters] = STATE(5519),
    [sym_nested_type_identifier] = STATE(3278),
    [sym__type_query_member_expression_in_type_annotation] = STATE(3181),
    [sym__type_query_call_expression_in_type_annotation] = STATE(3311),
    [sym_type] = STATE(3436),
    [sym_constructor_type] = STATE(3448),
    [sym_primary_type] = STATE(3450),
    [sym_template_literal_type] = STATE(3453),
    [sym_infer_type] = STATE(3448),
    [sym_conditional_type] = STATE(3453),
    [sym_generic_type] = STATE(3453),
    [sym_type_query] = STATE(3453),
    [sym_index_type_query] = STATE(3453),
    [sym_lookup_type] = STATE(3453),
    [sym_literal_type] = STATE(3453),
    [sym__number] = STATE(3454),
    [sym_existential_type] = STATE(3453),
    [sym_flow_maybe_type] = STATE(3453),
    [sym_parenthesized_type] = STATE(3453),
    [sym_predefined_type] = STATE(3453),
    [sym_object_type] = STATE(3453),
    [sym_type_parameters] = STATE(5251),
    [sym_array_type] = STATE(3453),
    [sym_tuple_type] = STATE(3453),
    [sym_readonly_type] = STATE(3448),
    [sym_union_type] = STATE(3453),
    [sym_intersection_type] = STATE(3453),
    [sym_function_type] = STATE(3448),
    [sym_identifier] = ACTIONS(3259),
    [anon_sym_STAR] = ACTIONS(2995),
    [anon_sym_LBRACE] = ACTIONS(2997),
    [anon_sym_typeof] = ACTIONS(2999),
    [anon_sym_import] = ACTIONS(1538),
    [anon_sym_const] = ACTIONS(3001),
    [anon_sym_LPAREN] = ACTIONS(3003),
    [anon_sym_LBRACK] = ACTIONS(3005),
    [anon_sym_new] = ACTIONS(3007),
    [anon_sym_AMP] = ACTIONS(3009),
    [anon_sym_PIPE] = ACTIONS(3011),
    [anon_sym_PLUS] = ACTIONS(3013),
    [anon_sym_DASH] = ACTIONS(3013),
    [anon_sym_LT] = ACTIONS(2499),
    [anon_sym_void] = ACTIONS(3015),
    [anon_sym_DQUOTE] = ACTIONS(3017),
    [anon_sym_SQUOTE] = ACTIONS(3019),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(3021),
    [sym_number] = ACTIONS(3023),
    [sym_this] = ACTIONS(3261),
    [sym_true] = ACTIONS(3027),
    [sym_false] = ACTIONS(3027),
    [sym_null] = ACTIONS(3027),
    [sym_undefined] = ACTIONS(3027),
    [anon_sym_readonly] = ACTIONS(3029),
    [anon_sym_QMARK] = ACTIONS(3031),
    [anon_sym_any] = ACTIONS(3015),
    [anon_sym_number] = ACTIONS(3015),
    [anon_sym_boolean] = ACTIONS(3015),
    [anon_sym_string] = ACTIONS(3015),
    [anon_sym_symbol] = ACTIONS(3015),
    [anon_sym_object] = ACTIONS(3015),
    [anon_sym_abstract] = ACTIONS(3033),
    [anon_sym_infer] = ACTIONS(3037),
    [anon_sym_keyof] = ACTIONS(3039),
    [anon_sym_unique] = ACTIONS(3041),
    [anon_sym_unknown] = ACTIONS(3015),
    [anon_sym_never] = ACTIONS(3015),
    [anon_sym_LBRACE_PIPE] = ACTIONS(3043),
    [sym_html_comment] = ACTIONS(5),
  },
  [1081] = {
    [sym_import] = STATE(4578),
    [sym_nested_identifier] = STATE(5796),
    [sym_string] = STATE(3437),
    [sym_formal_parameters] = STATE(5519),
    [sym_nested_type_identifier] = STATE(3278),
    [sym__type_query_member_expression_in_type_annotation] = STATE(3181),
    [sym__type_query_call_expression_in_type_annotation] = STATE(3311),
    [sym_type] = STATE(3335),
    [sym_constructor_type] = STATE(3448),
    [sym_primary_type] = STATE(3450),
    [sym_template_literal_type] = STATE(3453),
    [sym_infer_type] = STATE(3448),
    [sym_conditional_type] = STATE(3453),
    [sym_generic_type] = STATE(3453),
    [sym_type_query] = STATE(3453),
    [sym_index_type_query] = STATE(3453),
    [sym_lookup_type] = STATE(3453),
    [sym_literal_type] = STATE(3453),
    [sym__number] = STATE(3454),
    [sym_existential_type] = STATE(3453),
    [sym_flow_maybe_type] = STATE(3453),
    [sym_parenthesized_type] = STATE(3453),
    [sym_predefined_type] = STATE(3453),
    [sym_object_type] = STATE(3453),
    [sym_type_parameters] = STATE(5251),
    [sym_array_type] = STATE(3453),
    [sym_tuple_type] = STATE(3453),
    [sym_readonly_type] = STATE(3448),
    [sym_union_type] = STATE(3453),
    [sym_intersection_type] = STATE(3453),
    [sym_function_type] = STATE(3448),
    [sym_identifier] = ACTIONS(3259),
    [anon_sym_STAR] = ACTIONS(2995),
    [anon_sym_LBRACE] = ACTIONS(2997),
    [anon_sym_typeof] = ACTIONS(2999),
    [anon_sym_import] = ACTIONS(1538),
    [anon_sym_const] = ACTIONS(3001),
    [anon_sym_LPAREN] = ACTIONS(3003),
    [anon_sym_LBRACK] = ACTIONS(3005),
    [anon_sym_new] = ACTIONS(3007),
    [anon_sym_AMP] = ACTIONS(3009),
    [anon_sym_PIPE] = ACTIONS(3011),
    [anon_sym_PLUS] = ACTIONS(3013),
    [anon_sym_DASH] = ACTIONS(3013),
    [anon_sym_LT] = ACTIONS(2499),
    [anon_sym_void] = ACTIONS(3015),
    [anon_sym_DQUOTE] = ACTIONS(3017),
    [anon_sym_SQUOTE] = ACTIONS(3019),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(3021),
    [sym_number] = ACTIONS(3023),
    [sym_this] = ACTIONS(3261),
    [sym_true] = ACTIONS(3027),
    [sym_false] = ACTIONS(3027),
    [sym_null] = ACTIONS(3027),
    [sym_undefined] = ACTIONS(3027),
    [anon_sym_readonly] = ACTIONS(3029),
    [anon_sym_QMARK] = ACTIONS(3031),
    [anon_sym_any] = ACTIONS(3015),
    [anon_sym_number] = ACTIONS(3015),
    [anon_sym_boolean] = ACTIONS(3015),
    [anon_sym_string] = ACTIONS(3015),
    [anon_sym_symbol] = ACTIONS(3015),
    [anon_sym_object] = ACTIONS(3015),
    [anon_sym_abstract] = ACTIONS(3033),
    [anon_sym_infer] = ACTIONS(3037),
    [anon_sym_keyof] = ACTIONS(3039),
    [anon_sym_unique] = ACTIONS(3041),
    [anon_sym_unknown] = ACTIONS(3015),
    [anon_sym_never] = ACTIONS(3015),
    [anon_sym_LBRACE_PIPE] = ACTIONS(3043),
    [sym_html_comment] = ACTIONS(5),
  },
  [1082] = {
    [sym_import] = STATE(4878),
    [sym_nested_identifier] = STATE(5796),
    [sym_string] = STATE(3437),
    [sym_formal_parameters] = STATE(5475),
    [sym_nested_type_identifier] = STATE(3278),
    [sym__type_query_member_expression_in_type_annotation] = STATE(2937),
    [sym__type_query_call_expression_in_type_annotation] = STATE(2938),
    [sym_type] = STATE(4587),
    [sym_constructor_type] = STATE(3007),
    [sym_primary_type] = STATE(3338),
    [sym_template_literal_type] = STATE(3453),
    [sym_infer_type] = STATE(3007),
    [sym_conditional_type] = STATE(3453),
    [sym_generic_type] = STATE(3453),
    [sym_type_query] = STATE(3453),
    [sym_index_type_query] = STATE(3453),
    [sym_lookup_type] = STATE(3453),
    [sym_literal_type] = STATE(3453),
    [sym__number] = STATE(3454),
    [sym_existential_type] = STATE(3453),
    [sym_flow_maybe_type] = STATE(3453),
    [sym_parenthesized_type] = STATE(3453),
    [sym_predefined_type] = STATE(3453),
    [sym_object_type] = STATE(3453),
    [sym_type_parameters] = STATE(5248),
    [sym_array_type] = STATE(3453),
    [sym_tuple_type] = STATE(3453),
    [sym_readonly_type] = STATE(3007),
    [sym_union_type] = STATE(3453),
    [sym_intersection_type] = STATE(3453),
    [sym_function_type] = STATE(3007),
    [sym_identifier] = ACTIONS(3259),
    [anon_sym_STAR] = ACTIONS(2995),
    [anon_sym_LBRACE] = ACTIONS(2997),
    [anon_sym_typeof] = ACTIONS(2999),
    [anon_sym_import] = ACTIONS(1538),
    [anon_sym_const] = ACTIONS(3001),
    [anon_sym_LPAREN] = ACTIONS(3003),
    [anon_sym_LBRACK] = ACTIONS(3005),
    [anon_sym_new] = ACTIONS(1544),
    [anon_sym_AMP] = ACTIONS(3009),
    [anon_sym_PIPE] = ACTIONS(3011),
    [anon_sym_PLUS] = ACTIONS(3013),
    [anon_sym_DASH] = ACTIONS(3013),
    [anon_sym_LT] = ACTIONS(2499),
    [anon_sym_void] = ACTIONS(3015),
    [anon_sym_DQUOTE] = ACTIONS(3017),
    [anon_sym_SQUOTE] = ACTIONS(3019),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(3021),
    [sym_number] = ACTIONS(3023),
    [sym_this] = ACTIONS(3261),
    [sym_true] = ACTIONS(3027),
    [sym_false] = ACTIONS(3027),
    [sym_null] = ACTIONS(3027),
    [sym_undefined] = ACTIONS(3027),
    [anon_sym_readonly] = ACTIONS(1562),
    [anon_sym_QMARK] = ACTIONS(3031),
    [anon_sym_any] = ACTIONS(3015),
    [anon_sym_number] = ACTIONS(3015),
    [anon_sym_boolean] = ACTIONS(3015),
    [anon_sym_string] = ACTIONS(3015),
    [anon_sym_symbol] = ACTIONS(3015),
    [anon_sym_object] = ACTIONS(3015),
    [anon_sym_abstract] = ACTIONS(208),
    [anon_sym_infer] = ACTIONS(210),
    [anon_sym_keyof] = ACTIONS(3039),
    [anon_sym_unique] = ACTIONS(3041),
    [anon_sym_unknown] = ACTIONS(3015),
    [anon_sym_never] = ACTIONS(3015),
    [anon_sym_LBRACE_PIPE] = ACTIONS(3043),
    [sym_html_comment] = ACTIONS(5),
  },
  [1083] = {
    [sym_import] = STATE(4878),
    [sym_nested_identifier] = STATE(5474),
    [sym_string] = STATE(2994),
    [sym_formal_parameters] = STATE(5475),
    [sym_nested_type_identifier] = STATE(2939),
    [sym__type_query_member_expression_in_type_annotation] = STATE(2937),
    [sym__type_query_call_expression_in_type_annotation] = STATE(2938),
    [sym_type] = STATE(4490),
    [sym_constructor_type] = STATE(3007),
    [sym_primary_type] = STATE(2981),
    [sym_template_literal_type] = STATE(3039),
    [sym_infer_type] = STATE(3007),
    [sym_conditional_type] = STATE(3039),
    [sym_generic_type] = STATE(3039),
    [sym_type_query] = STATE(3039),
    [sym_index_type_query] = STATE(3039),
    [sym_lookup_type] = STATE(3039),
    [sym_literal_type] = STATE(3039),
    [sym__number] = STATE(3041),
    [sym_existential_type] = STATE(3039),
    [sym_flow_maybe_type] = STATE(3039),
    [sym_parenthesized_type] = STATE(3039),
    [sym_predefined_type] = STATE(3039),
    [sym_object_type] = STATE(3039),
    [sym_type_parameters] = STATE(5248),
    [sym_array_type] = STATE(3039),
    [sym_tuple_type] = STATE(3039),
    [sym_readonly_type] = STATE(3007),
    [sym_union_type] = STATE(3039),
    [sym_intersection_type] = STATE(3039),
    [sym_function_type] = STATE(3007),
    [sym_identifier] = ACTIONS(1532),
    [anon_sym_STAR] = ACTIONS(543),
    [anon_sym_LBRACE] = ACTIONS(1534),
    [anon_sym_typeof] = ACTIONS(1536),
    [anon_sym_import] = ACTIONS(1538),
    [anon_sym_const] = ACTIONS(133),
    [anon_sym_LPAREN] = ACTIONS(1540),
    [anon_sym_LBRACK] = ACTIONS(1542),
    [anon_sym_new] = ACTIONS(1544),
    [anon_sym_AMP] = ACTIONS(748),
    [anon_sym_PIPE] = ACTIONS(750),
    [anon_sym_PLUS] = ACTIONS(2497),
    [anon_sym_DASH] = ACTIONS(2497),
    [anon_sym_LT] = ACTIONS(2499),
    [anon_sym_void] = ACTIONS(216),
    [anon_sym_DQUOTE] = ACTIONS(1550),
    [anon_sym_SQUOTE] = ACTIONS(1552),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1554),
    [sym_number] = ACTIONS(1556),
    [sym_this] = ACTIONS(1558),
    [sym_true] = ACTIONS(1560),
    [sym_false] = ACTIONS(1560),
    [sym_null] = ACTIONS(1560),
    [sym_undefined] = ACTIONS(1560),
    [anon_sym_readonly] = ACTIONS(1562),
    [anon_sym_QMARK] = ACTIONS(774),
    [anon_sym_any] = ACTIONS(216),
    [anon_sym_number] = ACTIONS(216),
    [anon_sym_boolean] = ACTIONS(216),
    [anon_sym_string] = ACTIONS(216),
    [anon_sym_symbol] = ACTIONS(216),
    [anon_sym_object] = ACTIONS(216),
    [anon_sym_abstract] = ACTIONS(208),
    [anon_sym_infer] = ACTIONS(210),
    [anon_sym_keyof] = ACTIONS(212),
    [anon_sym_unique] = ACTIONS(214),
    [anon_sym_unknown] = ACTIONS(216),
    [anon_sym_never] = ACTIONS(216),
    [anon_sym_LBRACE_PIPE] = ACTIONS(218),
    [sym_html_comment] = ACTIONS(5),
  },
  [1084] = {
    [sym_import] = STATE(4878),
    [sym_nested_identifier] = STATE(5474),
    [sym_string] = STATE(2994),
    [sym_formal_parameters] = STATE(5475),
    [sym_nested_type_identifier] = STATE(2939),
    [sym__type_query_member_expression_in_type_annotation] = STATE(2937),
    [sym__type_query_call_expression_in_type_annotation] = STATE(2938),
    [sym_type] = STATE(3788),
    [sym_constructor_type] = STATE(3007),
    [sym_primary_type] = STATE(2981),
    [sym_template_literal_type] = STATE(3039),
    [sym_infer_type] = STATE(3007),
    [sym_conditional_type] = STATE(3039),
    [sym_generic_type] = STATE(3039),
    [sym_type_query] = STATE(3039),
    [sym_index_type_query] = STATE(3039),
    [sym_lookup_type] = STATE(3039),
    [sym_literal_type] = STATE(3039),
    [sym__number] = STATE(3041),
    [sym_existential_type] = STATE(3039),
    [sym_flow_maybe_type] = STATE(3039),
    [sym_parenthesized_type] = STATE(3039),
    [sym_predefined_type] = STATE(3039),
    [sym_object_type] = STATE(3039),
    [sym_type_parameters] = STATE(5248),
    [sym_array_type] = STATE(3039),
    [sym_tuple_type] = STATE(3039),
    [sym_readonly_type] = STATE(3007),
    [sym_union_type] = STATE(3039),
    [sym_intersection_type] = STATE(3039),
    [sym_function_type] = STATE(3007),
    [sym_identifier] = ACTIONS(1532),
    [anon_sym_STAR] = ACTIONS(543),
    [anon_sym_LBRACE] = ACTIONS(1534),
    [anon_sym_typeof] = ACTIONS(1536),
    [anon_sym_import] = ACTIONS(1538),
    [anon_sym_const] = ACTIONS(133),
    [anon_sym_LPAREN] = ACTIONS(1540),
    [anon_sym_LBRACK] = ACTIONS(1542),
    [anon_sym_new] = ACTIONS(1544),
    [anon_sym_AMP] = ACTIONS(748),
    [anon_sym_PIPE] = ACTIONS(750),
    [anon_sym_PLUS] = ACTIONS(2497),
    [anon_sym_DASH] = ACTIONS(2497),
    [anon_sym_LT] = ACTIONS(2499),
    [anon_sym_void] = ACTIONS(216),
    [anon_sym_DQUOTE] = ACTIONS(1550),
    [anon_sym_SQUOTE] = ACTIONS(1552),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1554),
    [sym_number] = ACTIONS(1556),
    [sym_this] = ACTIONS(1558),
    [sym_true] = ACTIONS(1560),
    [sym_false] = ACTIONS(1560),
    [sym_null] = ACTIONS(1560),
    [sym_undefined] = ACTIONS(1560),
    [anon_sym_readonly] = ACTIONS(1562),
    [anon_sym_QMARK] = ACTIONS(774),
    [anon_sym_any] = ACTIONS(216),
    [anon_sym_number] = ACTIONS(216),
    [anon_sym_boolean] = ACTIONS(216),
    [anon_sym_string] = ACTIONS(216),
    [anon_sym_symbol] = ACTIONS(216),
    [anon_sym_object] = ACTIONS(216),
    [anon_sym_abstract] = ACTIONS(208),
    [anon_sym_infer] = ACTIONS(210),
    [anon_sym_keyof] = ACTIONS(212),
    [anon_sym_unique] = ACTIONS(214),
    [anon_sym_unknown] = ACTIONS(216),
    [anon_sym_never] = ACTIONS(216),
    [anon_sym_LBRACE_PIPE] = ACTIONS(218),
    [sym_html_comment] = ACTIONS(5),
  },
  [1085] = {
    [sym_import] = STATE(4878),
    [sym_nested_identifier] = STATE(5474),
    [sym_string] = STATE(2994),
    [sym_formal_parameters] = STATE(5475),
    [sym_nested_type_identifier] = STATE(2939),
    [sym__type_query_member_expression_in_type_annotation] = STATE(2937),
    [sym__type_query_call_expression_in_type_annotation] = STATE(2938),
    [sym_type] = STATE(2962),
    [sym_constructor_type] = STATE(3007),
    [sym_primary_type] = STATE(2981),
    [sym_template_literal_type] = STATE(3039),
    [sym_infer_type] = STATE(3007),
    [sym_conditional_type] = STATE(3039),
    [sym_generic_type] = STATE(3039),
    [sym_type_query] = STATE(3039),
    [sym_index_type_query] = STATE(3039),
    [sym_lookup_type] = STATE(3039),
    [sym_literal_type] = STATE(3039),
    [sym__number] = STATE(3041),
    [sym_existential_type] = STATE(3039),
    [sym_flow_maybe_type] = STATE(3039),
    [sym_parenthesized_type] = STATE(3039),
    [sym_predefined_type] = STATE(3039),
    [sym_object_type] = STATE(3039),
    [sym_type_parameters] = STATE(5248),
    [sym_array_type] = STATE(3039),
    [sym_tuple_type] = STATE(3039),
    [sym_readonly_type] = STATE(3007),
    [sym_union_type] = STATE(3039),
    [sym_intersection_type] = STATE(3039),
    [sym_function_type] = STATE(3007),
    [sym_identifier] = ACTIONS(1532),
    [anon_sym_STAR] = ACTIONS(543),
    [anon_sym_LBRACE] = ACTIONS(1534),
    [anon_sym_typeof] = ACTIONS(1536),
    [anon_sym_import] = ACTIONS(1538),
    [anon_sym_const] = ACTIONS(133),
    [anon_sym_LPAREN] = ACTIONS(1540),
    [anon_sym_LBRACK] = ACTIONS(1542),
    [anon_sym_new] = ACTIONS(1544),
    [anon_sym_AMP] = ACTIONS(748),
    [anon_sym_PIPE] = ACTIONS(750),
    [anon_sym_PLUS] = ACTIONS(2497),
    [anon_sym_DASH] = ACTIONS(2497),
    [anon_sym_LT] = ACTIONS(2499),
    [anon_sym_void] = ACTIONS(216),
    [anon_sym_DQUOTE] = ACTIONS(1550),
    [anon_sym_SQUOTE] = ACTIONS(1552),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1554),
    [sym_number] = ACTIONS(1556),
    [sym_this] = ACTIONS(1558),
    [sym_true] = ACTIONS(1560),
    [sym_false] = ACTIONS(1560),
    [sym_null] = ACTIONS(1560),
    [sym_undefined] = ACTIONS(1560),
    [anon_sym_readonly] = ACTIONS(1562),
    [anon_sym_QMARK] = ACTIONS(774),
    [anon_sym_any] = ACTIONS(216),
    [anon_sym_number] = ACTIONS(216),
    [anon_sym_boolean] = ACTIONS(216),
    [anon_sym_string] = ACTIONS(216),
    [anon_sym_symbol] = ACTIONS(216),
    [anon_sym_object] = ACTIONS(216),
    [anon_sym_abstract] = ACTIONS(208),
    [anon_sym_infer] = ACTIONS(210),
    [anon_sym_keyof] = ACTIONS(212),
    [anon_sym_unique] = ACTIONS(214),
    [anon_sym_unknown] = ACTIONS(216),
    [anon_sym_never] = ACTIONS(216),
    [anon_sym_LBRACE_PIPE] = ACTIONS(218),
    [sym_html_comment] = ACTIONS(5),
  },
  [1086] = {
    [sym_import] = STATE(4878),
    [sym_nested_identifier] = STATE(5474),
    [sym_string] = STATE(2994),
    [sym_formal_parameters] = STATE(5475),
    [sym_nested_type_identifier] = STATE(2939),
    [sym__type_query_member_expression_in_type_annotation] = STATE(2937),
    [sym__type_query_call_expression_in_type_annotation] = STATE(2938),
    [sym_type] = STATE(3096),
    [sym_constructor_type] = STATE(3007),
    [sym_primary_type] = STATE(2981),
    [sym_template_literal_type] = STATE(3039),
    [sym_infer_type] = STATE(3007),
    [sym_conditional_type] = STATE(3039),
    [sym_generic_type] = STATE(3039),
    [sym_type_query] = STATE(3039),
    [sym_index_type_query] = STATE(3039),
    [sym_lookup_type] = STATE(3039),
    [sym_literal_type] = STATE(3039),
    [sym__number] = STATE(3041),
    [sym_existential_type] = STATE(3039),
    [sym_flow_maybe_type] = STATE(3039),
    [sym_parenthesized_type] = STATE(3039),
    [sym_predefined_type] = STATE(3039),
    [sym_object_type] = STATE(3039),
    [sym_type_parameters] = STATE(5248),
    [sym_array_type] = STATE(3039),
    [sym_tuple_type] = STATE(3039),
    [sym_readonly_type] = STATE(3007),
    [sym_union_type] = STATE(3039),
    [sym_intersection_type] = STATE(3039),
    [sym_function_type] = STATE(3007),
    [sym_identifier] = ACTIONS(1532),
    [anon_sym_STAR] = ACTIONS(543),
    [anon_sym_LBRACE] = ACTIONS(1534),
    [anon_sym_typeof] = ACTIONS(1536),
    [anon_sym_import] = ACTIONS(1538),
    [anon_sym_const] = ACTIONS(133),
    [anon_sym_LPAREN] = ACTIONS(1540),
    [anon_sym_LBRACK] = ACTIONS(1542),
    [anon_sym_new] = ACTIONS(1544),
    [anon_sym_AMP] = ACTIONS(748),
    [anon_sym_PIPE] = ACTIONS(750),
    [anon_sym_PLUS] = ACTIONS(2497),
    [anon_sym_DASH] = ACTIONS(2497),
    [anon_sym_LT] = ACTIONS(2499),
    [anon_sym_void] = ACTIONS(216),
    [anon_sym_DQUOTE] = ACTIONS(1550),
    [anon_sym_SQUOTE] = ACTIONS(1552),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1554),
    [sym_number] = ACTIONS(1556),
    [sym_this] = ACTIONS(1558),
    [sym_true] = ACTIONS(1560),
    [sym_false] = ACTIONS(1560),
    [sym_null] = ACTIONS(1560),
    [sym_undefined] = ACTIONS(1560),
    [anon_sym_readonly] = ACTIONS(1562),
    [anon_sym_QMARK] = ACTIONS(774),
    [anon_sym_any] = ACTIONS(216),
    [anon_sym_number] = ACTIONS(216),
    [anon_sym_boolean] = ACTIONS(216),
    [anon_sym_string] = ACTIONS(216),
    [anon_sym_symbol] = ACTIONS(216),
    [anon_sym_object] = ACTIONS(216),
    [anon_sym_abstract] = ACTIONS(208),
    [anon_sym_infer] = ACTIONS(210),
    [anon_sym_keyof] = ACTIONS(212),
    [anon_sym_unique] = ACTIONS(214),
    [anon_sym_unknown] = ACTIONS(216),
    [anon_sym_never] = ACTIONS(216),
    [anon_sym_LBRACE_PIPE] = ACTIONS(218),
    [sym_html_comment] = ACTIONS(5),
  },
  [1087] = {
    [sym_import] = STATE(4578),
    [sym_nested_identifier] = STATE(5796),
    [sym_string] = STATE(3437),
    [sym_formal_parameters] = STATE(5519),
    [sym_nested_type_identifier] = STATE(3278),
    [sym__type_query_member_expression_in_type_annotation] = STATE(3181),
    [sym__type_query_call_expression_in_type_annotation] = STATE(3311),
    [sym_type] = STATE(3373),
    [sym_constructor_type] = STATE(3448),
    [sym_primary_type] = STATE(3450),
    [sym_template_literal_type] = STATE(3453),
    [sym_infer_type] = STATE(3448),
    [sym_conditional_type] = STATE(3453),
    [sym_generic_type] = STATE(3453),
    [sym_type_query] = STATE(3453),
    [sym_index_type_query] = STATE(3453),
    [sym_lookup_type] = STATE(3453),
    [sym_literal_type] = STATE(3453),
    [sym__number] = STATE(3454),
    [sym_existential_type] = STATE(3453),
    [sym_flow_maybe_type] = STATE(3453),
    [sym_parenthesized_type] = STATE(3453),
    [sym_predefined_type] = STATE(3453),
    [sym_object_type] = STATE(3453),
    [sym_type_parameters] = STATE(5251),
    [sym_array_type] = STATE(3453),
    [sym_tuple_type] = STATE(3453),
    [sym_readonly_type] = STATE(3448),
    [sym_union_type] = STATE(3453),
    [sym_intersection_type] = STATE(3453),
    [sym_function_type] = STATE(3448),
    [sym_identifier] = ACTIONS(3259),
    [anon_sym_STAR] = ACTIONS(2995),
    [anon_sym_LBRACE] = ACTIONS(2997),
    [anon_sym_typeof] = ACTIONS(2999),
    [anon_sym_import] = ACTIONS(1538),
    [anon_sym_const] = ACTIONS(3001),
    [anon_sym_LPAREN] = ACTIONS(3003),
    [anon_sym_LBRACK] = ACTIONS(3005),
    [anon_sym_new] = ACTIONS(3007),
    [anon_sym_AMP] = ACTIONS(3009),
    [anon_sym_PIPE] = ACTIONS(3011),
    [anon_sym_PLUS] = ACTIONS(3013),
    [anon_sym_DASH] = ACTIONS(3013),
    [anon_sym_LT] = ACTIONS(2499),
    [anon_sym_void] = ACTIONS(3015),
    [anon_sym_DQUOTE] = ACTIONS(3017),
    [anon_sym_SQUOTE] = ACTIONS(3019),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(3021),
    [sym_number] = ACTIONS(3023),
    [sym_this] = ACTIONS(3261),
    [sym_true] = ACTIONS(3027),
    [sym_false] = ACTIONS(3027),
    [sym_null] = ACTIONS(3027),
    [sym_undefined] = ACTIONS(3027),
    [anon_sym_readonly] = ACTIONS(3029),
    [anon_sym_QMARK] = ACTIONS(3031),
    [anon_sym_any] = ACTIONS(3015),
    [anon_sym_number] = ACTIONS(3015),
    [anon_sym_boolean] = ACTIONS(3015),
    [anon_sym_string] = ACTIONS(3015),
    [anon_sym_symbol] = ACTIONS(3015),
    [anon_sym_object] = ACTIONS(3015),
    [anon_sym_abstract] = ACTIONS(3033),
    [anon_sym_infer] = ACTIONS(3037),
    [anon_sym_keyof] = ACTIONS(3039),
    [anon_sym_unique] = ACTIONS(3041),
    [anon_sym_unknown] = ACTIONS(3015),
    [anon_sym_never] = ACTIONS(3015),
    [anon_sym_LBRACE_PIPE] = ACTIONS(3043),
    [sym_html_comment] = ACTIONS(5),
  },
  [1088] = {
    [sym_import] = STATE(4578),
    [sym_nested_identifier] = STATE(5796),
    [sym_string] = STATE(3437),
    [sym_formal_parameters] = STATE(5519),
    [sym_nested_type_identifier] = STATE(3278),
    [sym__type_query_member_expression_in_type_annotation] = STATE(3181),
    [sym__type_query_call_expression_in_type_annotation] = STATE(3311),
    [sym_type] = STATE(3375),
    [sym_constructor_type] = STATE(3448),
    [sym_primary_type] = STATE(3450),
    [sym_template_literal_type] = STATE(3453),
    [sym_infer_type] = STATE(3448),
    [sym_conditional_type] = STATE(3453),
    [sym_generic_type] = STATE(3453),
    [sym_type_query] = STATE(3453),
    [sym_index_type_query] = STATE(3453),
    [sym_lookup_type] = STATE(3453),
    [sym_literal_type] = STATE(3453),
    [sym__number] = STATE(3454),
    [sym_existential_type] = STATE(3453),
    [sym_flow_maybe_type] = STATE(3453),
    [sym_parenthesized_type] = STATE(3453),
    [sym_predefined_type] = STATE(3453),
    [sym_object_type] = STATE(3453),
    [sym_type_parameters] = STATE(5251),
    [sym_array_type] = STATE(3453),
    [sym_tuple_type] = STATE(3453),
    [sym_readonly_type] = STATE(3448),
    [sym_union_type] = STATE(3453),
    [sym_intersection_type] = STATE(3453),
    [sym_function_type] = STATE(3448),
    [sym_identifier] = ACTIONS(3259),
    [anon_sym_STAR] = ACTIONS(2995),
    [anon_sym_LBRACE] = ACTIONS(2997),
    [anon_sym_typeof] = ACTIONS(2999),
    [anon_sym_import] = ACTIONS(1538),
    [anon_sym_const] = ACTIONS(3001),
    [anon_sym_LPAREN] = ACTIONS(3003),
    [anon_sym_LBRACK] = ACTIONS(3005),
    [anon_sym_new] = ACTIONS(3007),
    [anon_sym_AMP] = ACTIONS(3009),
    [anon_sym_PIPE] = ACTIONS(3011),
    [anon_sym_PLUS] = ACTIONS(3013),
    [anon_sym_DASH] = ACTIONS(3013),
    [anon_sym_LT] = ACTIONS(2499),
    [anon_sym_void] = ACTIONS(3015),
    [anon_sym_DQUOTE] = ACTIONS(3017),
    [anon_sym_SQUOTE] = ACTIONS(3019),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(3021),
    [sym_number] = ACTIONS(3023),
    [sym_this] = ACTIONS(3261),
    [sym_true] = ACTIONS(3027),
    [sym_false] = ACTIONS(3027),
    [sym_null] = ACTIONS(3027),
    [sym_undefined] = ACTIONS(3027),
    [anon_sym_readonly] = ACTIONS(3029),
    [anon_sym_QMARK] = ACTIONS(3031),
    [anon_sym_any] = ACTIONS(3015),
    [anon_sym_number] = ACTIONS(3015),
    [anon_sym_boolean] = ACTIONS(3015),
    [anon_sym_string] = ACTIONS(3015),
    [anon_sym_symbol] = ACTIONS(3015),
    [anon_sym_object] = ACTIONS(3015),
    [anon_sym_abstract] = ACTIONS(3033),
    [anon_sym_infer] = ACTIONS(3037),
    [anon_sym_keyof] = ACTIONS(3039),
    [anon_sym_unique] = ACTIONS(3041),
    [anon_sym_unknown] = ACTIONS(3015),
    [anon_sym_never] = ACTIONS(3015),
    [anon_sym_LBRACE_PIPE] = ACTIONS(3043),
    [sym_html_comment] = ACTIONS(5),
  },
  [1089] = {
    [sym_import] = STATE(4578),
    [sym_nested_identifier] = STATE(5796),
    [sym_string] = STATE(3437),
    [sym_formal_parameters] = STATE(5519),
    [sym_nested_type_identifier] = STATE(3278),
    [sym__type_query_member_expression_in_type_annotation] = STATE(3181),
    [sym__type_query_call_expression_in_type_annotation] = STATE(3311),
    [sym_type] = STATE(3432),
    [sym_constructor_type] = STATE(3448),
    [sym_primary_type] = STATE(3450),
    [sym_template_literal_type] = STATE(3453),
    [sym_infer_type] = STATE(3448),
    [sym_conditional_type] = STATE(3453),
    [sym_generic_type] = STATE(3453),
    [sym_type_query] = STATE(3453),
    [sym_index_type_query] = STATE(3453),
    [sym_lookup_type] = STATE(3453),
    [sym_literal_type] = STATE(3453),
    [sym__number] = STATE(3454),
    [sym_existential_type] = STATE(3453),
    [sym_flow_maybe_type] = STATE(3453),
    [sym_parenthesized_type] = STATE(3453),
    [sym_predefined_type] = STATE(3453),
    [sym_object_type] = STATE(3453),
    [sym_type_parameters] = STATE(5251),
    [sym_array_type] = STATE(3453),
    [sym_tuple_type] = STATE(3453),
    [sym_readonly_type] = STATE(3448),
    [sym_union_type] = STATE(3453),
    [sym_intersection_type] = STATE(3453),
    [sym_function_type] = STATE(3448),
    [sym_identifier] = ACTIONS(3259),
    [anon_sym_STAR] = ACTIONS(2995),
    [anon_sym_LBRACE] = ACTIONS(2997),
    [anon_sym_typeof] = ACTIONS(2999),
    [anon_sym_import] = ACTIONS(1538),
    [anon_sym_const] = ACTIONS(3001),
    [anon_sym_LPAREN] = ACTIONS(3003),
    [anon_sym_LBRACK] = ACTIONS(3005),
    [anon_sym_new] = ACTIONS(3007),
    [anon_sym_AMP] = ACTIONS(3009),
    [anon_sym_PIPE] = ACTIONS(3011),
    [anon_sym_PLUS] = ACTIONS(3013),
    [anon_sym_DASH] = ACTIONS(3013),
    [anon_sym_LT] = ACTIONS(2499),
    [anon_sym_void] = ACTIONS(3015),
    [anon_sym_DQUOTE] = ACTIONS(3017),
    [anon_sym_SQUOTE] = ACTIONS(3019),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(3021),
    [sym_number] = ACTIONS(3023),
    [sym_this] = ACTIONS(3261),
    [sym_true] = ACTIONS(3027),
    [sym_false] = ACTIONS(3027),
    [sym_null] = ACTIONS(3027),
    [sym_undefined] = ACTIONS(3027),
    [anon_sym_readonly] = ACTIONS(3029),
    [anon_sym_QMARK] = ACTIONS(3031),
    [anon_sym_any] = ACTIONS(3015),
    [anon_sym_number] = ACTIONS(3015),
    [anon_sym_boolean] = ACTIONS(3015),
    [anon_sym_string] = ACTIONS(3015),
    [anon_sym_symbol] = ACTIONS(3015),
    [anon_sym_object] = ACTIONS(3015),
    [anon_sym_abstract] = ACTIONS(3033),
    [anon_sym_infer] = ACTIONS(3037),
    [anon_sym_keyof] = ACTIONS(3039),
    [anon_sym_unique] = ACTIONS(3041),
    [anon_sym_unknown] = ACTIONS(3015),
    [anon_sym_never] = ACTIONS(3015),
    [anon_sym_LBRACE_PIPE] = ACTIONS(3043),
    [sym_html_comment] = ACTIONS(5),
  },
  [1090] = {
    [sym_import] = STATE(4578),
    [sym_nested_identifier] = STATE(5796),
    [sym_string] = STATE(3437),
    [sym_formal_parameters] = STATE(5519),
    [sym_nested_type_identifier] = STATE(3278),
    [sym__type_query_member_expression_in_type_annotation] = STATE(3181),
    [sym__type_query_call_expression_in_type_annotation] = STATE(3311),
    [sym_type] = STATE(3433),
    [sym_constructor_type] = STATE(3448),
    [sym_primary_type] = STATE(3450),
    [sym_template_literal_type] = STATE(3453),
    [sym_infer_type] = STATE(3448),
    [sym_conditional_type] = STATE(3453),
    [sym_generic_type] = STATE(3453),
    [sym_type_query] = STATE(3453),
    [sym_index_type_query] = STATE(3453),
    [sym_lookup_type] = STATE(3453),
    [sym_literal_type] = STATE(3453),
    [sym__number] = STATE(3454),
    [sym_existential_type] = STATE(3453),
    [sym_flow_maybe_type] = STATE(3453),
    [sym_parenthesized_type] = STATE(3453),
    [sym_predefined_type] = STATE(3453),
    [sym_object_type] = STATE(3453),
    [sym_type_parameters] = STATE(5251),
    [sym_array_type] = STATE(3453),
    [sym_tuple_type] = STATE(3453),
    [sym_readonly_type] = STATE(3448),
    [sym_union_type] = STATE(3453),
    [sym_intersection_type] = STATE(3453),
    [sym_function_type] = STATE(3448),
    [sym_identifier] = ACTIONS(3259),
    [anon_sym_STAR] = ACTIONS(2995),
    [anon_sym_LBRACE] = ACTIONS(2997),
    [anon_sym_typeof] = ACTIONS(2999),
    [anon_sym_import] = ACTIONS(1538),
    [anon_sym_const] = ACTIONS(3001),
    [anon_sym_LPAREN] = ACTIONS(3003),
    [anon_sym_LBRACK] = ACTIONS(3005),
    [anon_sym_new] = ACTIONS(3007),
    [anon_sym_AMP] = ACTIONS(3009),
    [anon_sym_PIPE] = ACTIONS(3011),
    [anon_sym_PLUS] = ACTIONS(3013),
    [anon_sym_DASH] = ACTIONS(3013),
    [anon_sym_LT] = ACTIONS(2499),
    [anon_sym_void] = ACTIONS(3015),
    [anon_sym_DQUOTE] = ACTIONS(3017),
    [anon_sym_SQUOTE] = ACTIONS(3019),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(3021),
    [sym_number] = ACTIONS(3023),
    [sym_this] = ACTIONS(3261),
    [sym_true] = ACTIONS(3027),
    [sym_false] = ACTIONS(3027),
    [sym_null] = ACTIONS(3027),
    [sym_undefined] = ACTIONS(3027),
    [anon_sym_readonly] = ACTIONS(3029),
    [anon_sym_QMARK] = ACTIONS(3031),
    [anon_sym_any] = ACTIONS(3015),
    [anon_sym_number] = ACTIONS(3015),
    [anon_sym_boolean] = ACTIONS(3015),
    [anon_sym_string] = ACTIONS(3015),
    [anon_sym_symbol] = ACTIONS(3015),
    [anon_sym_object] = ACTIONS(3015),
    [anon_sym_abstract] = ACTIONS(3033),
    [anon_sym_infer] = ACTIONS(3037),
    [anon_sym_keyof] = ACTIONS(3039),
    [anon_sym_unique] = ACTIONS(3041),
    [anon_sym_unknown] = ACTIONS(3015),
    [anon_sym_never] = ACTIONS(3015),
    [anon_sym_LBRACE_PIPE] = ACTIONS(3043),
    [sym_html_comment] = ACTIONS(5),
  },
  [1091] = {
    [sym_import] = STATE(4681),
    [sym_nested_identifier] = STATE(5474),
    [sym_string] = STATE(2994),
    [sym_formal_parameters] = STATE(5619),
    [sym_nested_type_identifier] = STATE(2939),
    [sym__type_query_member_expression_in_type_annotation] = STATE(3303),
    [sym__type_query_call_expression_in_type_annotation] = STATE(2938),
    [sym_type] = STATE(4420),
    [sym_constructor_type] = STATE(3007),
    [sym_primary_type] = STATE(2981),
    [sym_template_literal_type] = STATE(3039),
    [sym_infer_type] = STATE(3007),
    [sym_conditional_type] = STATE(3039),
    [sym_generic_type] = STATE(3039),
    [sym_type_query] = STATE(3039),
    [sym_index_type_query] = STATE(3039),
    [sym_lookup_type] = STATE(3039),
    [sym_literal_type] = STATE(3039),
    [sym__number] = STATE(3041),
    [sym_existential_type] = STATE(3039),
    [sym_flow_maybe_type] = STATE(3039),
    [sym_parenthesized_type] = STATE(3039),
    [sym_predefined_type] = STATE(3039),
    [sym_object_type] = STATE(3039),
    [sym_type_parameters] = STATE(5454),
    [sym_array_type] = STATE(3039),
    [sym_tuple_type] = STATE(3039),
    [sym_readonly_type] = STATE(3007),
    [sym_union_type] = STATE(3039),
    [sym_intersection_type] = STATE(3039),
    [sym_function_type] = STATE(3007),
    [sym_identifier] = ACTIONS(1532),
    [anon_sym_STAR] = ACTIONS(543),
    [anon_sym_LBRACE] = ACTIONS(1534),
    [anon_sym_typeof] = ACTIONS(1536),
    [anon_sym_import] = ACTIONS(1538),
    [anon_sym_const] = ACTIONS(133),
    [anon_sym_LPAREN] = ACTIONS(1540),
    [anon_sym_LBRACK] = ACTIONS(1542),
    [anon_sym_new] = ACTIONS(1642),
    [anon_sym_AMP] = ACTIONS(571),
    [anon_sym_PIPE] = ACTIONS(573),
    [anon_sym_PLUS] = ACTIONS(2497),
    [anon_sym_DASH] = ACTIONS(2497),
    [anon_sym_LT] = ACTIONS(2499),
    [anon_sym_void] = ACTIONS(216),
    [anon_sym_DQUOTE] = ACTIONS(1550),
    [anon_sym_SQUOTE] = ACTIONS(1552),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1554),
    [sym_number] = ACTIONS(1556),
    [sym_this] = ACTIONS(1558),
    [sym_true] = ACTIONS(1560),
    [sym_false] = ACTIONS(1560),
    [sym_null] = ACTIONS(1560),
    [sym_undefined] = ACTIONS(1560),
    [anon_sym_readonly] = ACTIONS(1648),
    [anon_sym_QMARK] = ACTIONS(593),
    [anon_sym_any] = ACTIONS(216),
    [anon_sym_number] = ACTIONS(216),
    [anon_sym_boolean] = ACTIONS(216),
    [anon_sym_string] = ACTIONS(216),
    [anon_sym_symbol] = ACTIONS(216),
    [anon_sym_object] = ACTIONS(216),
    [anon_sym_abstract] = ACTIONS(597),
    [anon_sym_infer] = ACTIONS(599),
    [anon_sym_keyof] = ACTIONS(601),
    [anon_sym_unique] = ACTIONS(214),
    [anon_sym_unknown] = ACTIONS(216),
    [anon_sym_never] = ACTIONS(216),
    [anon_sym_LBRACE_PIPE] = ACTIONS(218),
    [sym_html_comment] = ACTIONS(5),
  },
  [1092] = {
    [sym_import] = STATE(4578),
    [sym_nested_identifier] = STATE(5796),
    [sym_string] = STATE(3437),
    [sym_formal_parameters] = STATE(5519),
    [sym_nested_type_identifier] = STATE(3278),
    [sym__type_query_member_expression_in_type_annotation] = STATE(3181),
    [sym__type_query_call_expression_in_type_annotation] = STATE(3311),
    [sym_type] = STATE(3328),
    [sym_constructor_type] = STATE(3448),
    [sym_primary_type] = STATE(3450),
    [sym_template_literal_type] = STATE(3453),
    [sym_infer_type] = STATE(3448),
    [sym_conditional_type] = STATE(3453),
    [sym_generic_type] = STATE(3453),
    [sym_type_query] = STATE(3453),
    [sym_index_type_query] = STATE(3453),
    [sym_lookup_type] = STATE(3453),
    [sym_literal_type] = STATE(3453),
    [sym__number] = STATE(3454),
    [sym_existential_type] = STATE(3453),
    [sym_flow_maybe_type] = STATE(3453),
    [sym_parenthesized_type] = STATE(3453),
    [sym_predefined_type] = STATE(3453),
    [sym_object_type] = STATE(3453),
    [sym_type_parameters] = STATE(5251),
    [sym_array_type] = STATE(3453),
    [sym_tuple_type] = STATE(3453),
    [sym_readonly_type] = STATE(3448),
    [sym_union_type] = STATE(3453),
    [sym_intersection_type] = STATE(3453),
    [sym_function_type] = STATE(3448),
    [sym_identifier] = ACTIONS(3259),
    [anon_sym_STAR] = ACTIONS(2995),
    [anon_sym_LBRACE] = ACTIONS(2997),
    [anon_sym_typeof] = ACTIONS(2999),
    [anon_sym_import] = ACTIONS(1538),
    [anon_sym_const] = ACTIONS(3001),
    [anon_sym_LPAREN] = ACTIONS(3003),
    [anon_sym_LBRACK] = ACTIONS(3005),
    [anon_sym_new] = ACTIONS(3007),
    [anon_sym_AMP] = ACTIONS(3009),
    [anon_sym_PIPE] = ACTIONS(3011),
    [anon_sym_PLUS] = ACTIONS(3013),
    [anon_sym_DASH] = ACTIONS(3013),
    [anon_sym_LT] = ACTIONS(2499),
    [anon_sym_void] = ACTIONS(3015),
    [anon_sym_DQUOTE] = ACTIONS(3017),
    [anon_sym_SQUOTE] = ACTIONS(3019),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(3021),
    [sym_number] = ACTIONS(3023),
    [sym_this] = ACTIONS(3261),
    [sym_true] = ACTIONS(3027),
    [sym_false] = ACTIONS(3027),
    [sym_null] = ACTIONS(3027),
    [sym_undefined] = ACTIONS(3027),
    [anon_sym_readonly] = ACTIONS(3029),
    [anon_sym_QMARK] = ACTIONS(3031),
    [anon_sym_any] = ACTIONS(3015),
    [anon_sym_number] = ACTIONS(3015),
    [anon_sym_boolean] = ACTIONS(3015),
    [anon_sym_string] = ACTIONS(3015),
    [anon_sym_symbol] = ACTIONS(3015),
    [anon_sym_object] = ACTIONS(3015),
    [anon_sym_abstract] = ACTIONS(3033),
    [anon_sym_infer] = ACTIONS(3037),
    [anon_sym_keyof] = ACTIONS(3039),
    [anon_sym_unique] = ACTIONS(3041),
    [anon_sym_unknown] = ACTIONS(3015),
    [anon_sym_never] = ACTIONS(3015),
    [anon_sym_LBRACE_PIPE] = ACTIONS(3043),
    [sym_html_comment] = ACTIONS(5),
  },
  [1093] = {
    [sym_import] = STATE(4578),
    [sym_nested_identifier] = STATE(5796),
    [sym_string] = STATE(3437),
    [sym_formal_parameters] = STATE(5519),
    [sym_nested_type_identifier] = STATE(3278),
    [sym__type_query_member_expression_in_type_annotation] = STATE(3181),
    [sym__type_query_call_expression_in_type_annotation] = STATE(3311),
    [sym_type] = STATE(3329),
    [sym_constructor_type] = STATE(3448),
    [sym_primary_type] = STATE(3450),
    [sym_template_literal_type] = STATE(3453),
    [sym_infer_type] = STATE(3448),
    [sym_conditional_type] = STATE(3453),
    [sym_generic_type] = STATE(3453),
    [sym_type_query] = STATE(3453),
    [sym_index_type_query] = STATE(3453),
    [sym_lookup_type] = STATE(3453),
    [sym_literal_type] = STATE(3453),
    [sym__number] = STATE(3454),
    [sym_existential_type] = STATE(3453),
    [sym_flow_maybe_type] = STATE(3453),
    [sym_parenthesized_type] = STATE(3453),
    [sym_predefined_type] = STATE(3453),
    [sym_object_type] = STATE(3453),
    [sym_type_parameters] = STATE(5251),
    [sym_array_type] = STATE(3453),
    [sym_tuple_type] = STATE(3453),
    [sym_readonly_type] = STATE(3448),
    [sym_union_type] = STATE(3453),
    [sym_intersection_type] = STATE(3453),
    [sym_function_type] = STATE(3448),
    [sym_identifier] = ACTIONS(3259),
    [anon_sym_STAR] = ACTIONS(2995),
    [anon_sym_LBRACE] = ACTIONS(2997),
    [anon_sym_typeof] = ACTIONS(2999),
    [anon_sym_import] = ACTIONS(1538),
    [anon_sym_const] = ACTIONS(3001),
    [anon_sym_LPAREN] = ACTIONS(3003),
    [anon_sym_LBRACK] = ACTIONS(3005),
    [anon_sym_new] = ACTIONS(3007),
    [anon_sym_AMP] = ACTIONS(3009),
    [anon_sym_PIPE] = ACTIONS(3011),
    [anon_sym_PLUS] = ACTIONS(3013),
    [anon_sym_DASH] = ACTIONS(3013),
    [anon_sym_LT] = ACTIONS(2499),
    [anon_sym_void] = ACTIONS(3015),
    [anon_sym_DQUOTE] = ACTIONS(3017),
    [anon_sym_SQUOTE] = ACTIONS(3019),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(3021),
    [sym_number] = ACTIONS(3023),
    [sym_this] = ACTIONS(3261),
    [sym_true] = ACTIONS(3027),
    [sym_false] = ACTIONS(3027),
    [sym_null] = ACTIONS(3027),
    [sym_undefined] = ACTIONS(3027),
    [anon_sym_readonly] = ACTIONS(3029),
    [anon_sym_QMARK] = ACTIONS(3031),
    [anon_sym_any] = ACTIONS(3015),
    [anon_sym_number] = ACTIONS(3015),
    [anon_sym_boolean] = ACTIONS(3015),
    [anon_sym_string] = ACTIONS(3015),
    [anon_sym_symbol] = ACTIONS(3015),
    [anon_sym_object] = ACTIONS(3015),
    [anon_sym_abstract] = ACTIONS(3033),
    [anon_sym_infer] = ACTIONS(3037),
    [anon_sym_keyof] = ACTIONS(3039),
    [anon_sym_unique] = ACTIONS(3041),
    [anon_sym_unknown] = ACTIONS(3015),
    [anon_sym_never] = ACTIONS(3015),
    [anon_sym_LBRACE_PIPE] = ACTIONS(3043),
    [sym_html_comment] = ACTIONS(5),
  },
  [1094] = {
    [sym_import] = STATE(4578),
    [sym_nested_identifier] = STATE(5796),
    [sym_string] = STATE(3437),
    [sym_formal_parameters] = STATE(5519),
    [sym_nested_type_identifier] = STATE(3278),
    [sym__type_query_member_expression_in_type_annotation] = STATE(3181),
    [sym__type_query_call_expression_in_type_annotation] = STATE(3311),
    [sym_type] = STATE(3344),
    [sym_constructor_type] = STATE(3448),
    [sym_primary_type] = STATE(3450),
    [sym_template_literal_type] = STATE(3453),
    [sym_infer_type] = STATE(3448),
    [sym_conditional_type] = STATE(3453),
    [sym_generic_type] = STATE(3453),
    [sym_type_query] = STATE(3453),
    [sym_index_type_query] = STATE(3453),
    [sym_lookup_type] = STATE(3453),
    [sym_literal_type] = STATE(3453),
    [sym__number] = STATE(3454),
    [sym_existential_type] = STATE(3453),
    [sym_flow_maybe_type] = STATE(3453),
    [sym_parenthesized_type] = STATE(3453),
    [sym_predefined_type] = STATE(3453),
    [sym_object_type] = STATE(3453),
    [sym_type_parameters] = STATE(5251),
    [sym_array_type] = STATE(3453),
    [sym_tuple_type] = STATE(3453),
    [sym_readonly_type] = STATE(3448),
    [sym_union_type] = STATE(3453),
    [sym_intersection_type] = STATE(3453),
    [sym_function_type] = STATE(3448),
    [sym_identifier] = ACTIONS(3259),
    [anon_sym_STAR] = ACTIONS(2995),
    [anon_sym_LBRACE] = ACTIONS(2997),
    [anon_sym_typeof] = ACTIONS(2999),
    [anon_sym_import] = ACTIONS(1538),
    [anon_sym_const] = ACTIONS(3001),
    [anon_sym_LPAREN] = ACTIONS(3003),
    [anon_sym_LBRACK] = ACTIONS(3005),
    [anon_sym_new] = ACTIONS(3007),
    [anon_sym_AMP] = ACTIONS(3009),
    [anon_sym_PIPE] = ACTIONS(3011),
    [anon_sym_PLUS] = ACTIONS(3013),
    [anon_sym_DASH] = ACTIONS(3013),
    [anon_sym_LT] = ACTIONS(2499),
    [anon_sym_void] = ACTIONS(3015),
    [anon_sym_DQUOTE] = ACTIONS(3017),
    [anon_sym_SQUOTE] = ACTIONS(3019),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(3021),
    [sym_number] = ACTIONS(3023),
    [sym_this] = ACTIONS(3261),
    [sym_true] = ACTIONS(3027),
    [sym_false] = ACTIONS(3027),
    [sym_null] = ACTIONS(3027),
    [sym_undefined] = ACTIONS(3027),
    [anon_sym_readonly] = ACTIONS(3029),
    [anon_sym_QMARK] = ACTIONS(3031),
    [anon_sym_any] = ACTIONS(3015),
    [anon_sym_number] = ACTIONS(3015),
    [anon_sym_boolean] = ACTIONS(3015),
    [anon_sym_string] = ACTIONS(3015),
    [anon_sym_symbol] = ACTIONS(3015),
    [anon_sym_object] = ACTIONS(3015),
    [anon_sym_abstract] = ACTIONS(3033),
    [anon_sym_infer] = ACTIONS(3037),
    [anon_sym_keyof] = ACTIONS(3039),
    [anon_sym_unique] = ACTIONS(3041),
    [anon_sym_unknown] = ACTIONS(3015),
    [anon_sym_never] = ACTIONS(3015),
    [anon_sym_LBRACE_PIPE] = ACTIONS(3043),
    [sym_html_comment] = ACTIONS(5),
  },
  [1095] = {
    [sym_import] = STATE(4578),
    [sym_nested_identifier] = STATE(5796),
    [sym_string] = STATE(3437),
    [sym_formal_parameters] = STATE(5519),
    [sym_nested_type_identifier] = STATE(3278),
    [sym__type_query_member_expression_in_type_annotation] = STATE(3181),
    [sym__type_query_call_expression_in_type_annotation] = STATE(3311),
    [sym_type] = STATE(3345),
    [sym_constructor_type] = STATE(3448),
    [sym_primary_type] = STATE(3450),
    [sym_template_literal_type] = STATE(3453),
    [sym_infer_type] = STATE(3448),
    [sym_conditional_type] = STATE(3453),
    [sym_generic_type] = STATE(3453),
    [sym_type_query] = STATE(3453),
    [sym_index_type_query] = STATE(3453),
    [sym_lookup_type] = STATE(3453),
    [sym_literal_type] = STATE(3453),
    [sym__number] = STATE(3454),
    [sym_existential_type] = STATE(3453),
    [sym_flow_maybe_type] = STATE(3453),
    [sym_parenthesized_type] = STATE(3453),
    [sym_predefined_type] = STATE(3453),
    [sym_object_type] = STATE(3453),
    [sym_type_parameters] = STATE(5251),
    [sym_array_type] = STATE(3453),
    [sym_tuple_type] = STATE(3453),
    [sym_readonly_type] = STATE(3448),
    [sym_union_type] = STATE(3453),
    [sym_intersection_type] = STATE(3453),
    [sym_function_type] = STATE(3448),
    [sym_identifier] = ACTIONS(3259),
    [anon_sym_STAR] = ACTIONS(2995),
    [anon_sym_LBRACE] = ACTIONS(2997),
    [anon_sym_typeof] = ACTIONS(2999),
    [anon_sym_import] = ACTIONS(1538),
    [anon_sym_const] = ACTIONS(3001),
    [anon_sym_LPAREN] = ACTIONS(3003),
    [anon_sym_LBRACK] = ACTIONS(3005),
    [anon_sym_new] = ACTIONS(3007),
    [anon_sym_AMP] = ACTIONS(3009),
    [anon_sym_PIPE] = ACTIONS(3011),
    [anon_sym_PLUS] = ACTIONS(3013),
    [anon_sym_DASH] = ACTIONS(3013),
    [anon_sym_LT] = ACTIONS(2499),
    [anon_sym_void] = ACTIONS(3015),
    [anon_sym_DQUOTE] = ACTIONS(3017),
    [anon_sym_SQUOTE] = ACTIONS(3019),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(3021),
    [sym_number] = ACTIONS(3023),
    [sym_this] = ACTIONS(3261),
    [sym_true] = ACTIONS(3027),
    [sym_false] = ACTIONS(3027),
    [sym_null] = ACTIONS(3027),
    [sym_undefined] = ACTIONS(3027),
    [anon_sym_readonly] = ACTIONS(3029),
    [anon_sym_QMARK] = ACTIONS(3031),
    [anon_sym_any] = ACTIONS(3015),
    [anon_sym_number] = ACTIONS(3015),
    [anon_sym_boolean] = ACTIONS(3015),
    [anon_sym_string] = ACTIONS(3015),
    [anon_sym_symbol] = ACTIONS(3015),
    [anon_sym_object] = ACTIONS(3015),
    [anon_sym_abstract] = ACTIONS(3033),
    [anon_sym_infer] = ACTIONS(3037),
    [anon_sym_keyof] = ACTIONS(3039),
    [anon_sym_unique] = ACTIONS(3041),
    [anon_sym_unknown] = ACTIONS(3015),
    [anon_sym_never] = ACTIONS(3015),
    [anon_sym_LBRACE_PIPE] = ACTIONS(3043),
    [sym_html_comment] = ACTIONS(5),
  },
  [1096] = {
    [sym_import] = STATE(4878),
    [sym_nested_identifier] = STATE(5474),
    [sym_string] = STATE(2994),
    [sym_formal_parameters] = STATE(5475),
    [sym_nested_type_identifier] = STATE(2939),
    [sym__type_query_member_expression_in_type_annotation] = STATE(2937),
    [sym__type_query_call_expression_in_type_annotation] = STATE(2938),
    [sym_type] = STATE(2947),
    [sym_constructor_type] = STATE(3007),
    [sym_primary_type] = STATE(2981),
    [sym_template_literal_type] = STATE(3039),
    [sym_infer_type] = STATE(3007),
    [sym_conditional_type] = STATE(3039),
    [sym_generic_type] = STATE(3039),
    [sym_type_query] = STATE(3039),
    [sym_index_type_query] = STATE(3039),
    [sym_lookup_type] = STATE(3039),
    [sym_literal_type] = STATE(3039),
    [sym__number] = STATE(3041),
    [sym_existential_type] = STATE(3039),
    [sym_flow_maybe_type] = STATE(3039),
    [sym_parenthesized_type] = STATE(3039),
    [sym_predefined_type] = STATE(3039),
    [sym_object_type] = STATE(3039),
    [sym_type_parameters] = STATE(5248),
    [sym_array_type] = STATE(3039),
    [sym_tuple_type] = STATE(3039),
    [sym_readonly_type] = STATE(3007),
    [sym_union_type] = STATE(3039),
    [sym_intersection_type] = STATE(3039),
    [sym_function_type] = STATE(3007),
    [sym_identifier] = ACTIONS(1532),
    [anon_sym_STAR] = ACTIONS(543),
    [anon_sym_LBRACE] = ACTIONS(1534),
    [anon_sym_typeof] = ACTIONS(1536),
    [anon_sym_import] = ACTIONS(1538),
    [anon_sym_const] = ACTIONS(133),
    [anon_sym_LPAREN] = ACTIONS(1540),
    [anon_sym_LBRACK] = ACTIONS(1542),
    [anon_sym_new] = ACTIONS(1544),
    [anon_sym_AMP] = ACTIONS(748),
    [anon_sym_PIPE] = ACTIONS(750),
    [anon_sym_PLUS] = ACTIONS(2497),
    [anon_sym_DASH] = ACTIONS(2497),
    [anon_sym_LT] = ACTIONS(2499),
    [anon_sym_void] = ACTIONS(216),
    [anon_sym_DQUOTE] = ACTIONS(1550),
    [anon_sym_SQUOTE] = ACTIONS(1552),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1554),
    [sym_number] = ACTIONS(1556),
    [sym_this] = ACTIONS(1558),
    [sym_true] = ACTIONS(1560),
    [sym_false] = ACTIONS(1560),
    [sym_null] = ACTIONS(1560),
    [sym_undefined] = ACTIONS(1560),
    [anon_sym_readonly] = ACTIONS(1562),
    [anon_sym_QMARK] = ACTIONS(774),
    [anon_sym_any] = ACTIONS(216),
    [anon_sym_number] = ACTIONS(216),
    [anon_sym_boolean] = ACTIONS(216),
    [anon_sym_string] = ACTIONS(216),
    [anon_sym_symbol] = ACTIONS(216),
    [anon_sym_object] = ACTIONS(216),
    [anon_sym_abstract] = ACTIONS(208),
    [anon_sym_infer] = ACTIONS(210),
    [anon_sym_keyof] = ACTIONS(212),
    [anon_sym_unique] = ACTIONS(214),
    [anon_sym_unknown] = ACTIONS(216),
    [anon_sym_never] = ACTIONS(216),
    [anon_sym_LBRACE_PIPE] = ACTIONS(218),
    [sym_html_comment] = ACTIONS(5),
  },
  [1097] = {
    [sym_import] = STATE(4878),
    [sym_nested_identifier] = STATE(5474),
    [sym_string] = STATE(2994),
    [sym_formal_parameters] = STATE(5475),
    [sym_nested_type_identifier] = STATE(2939),
    [sym__type_query_member_expression_in_type_annotation] = STATE(2937),
    [sym__type_query_call_expression_in_type_annotation] = STATE(2938),
    [sym_type] = STATE(3145),
    [sym_constructor_type] = STATE(3007),
    [sym_primary_type] = STATE(2981),
    [sym_template_literal_type] = STATE(3039),
    [sym_infer_type] = STATE(3007),
    [sym_conditional_type] = STATE(3039),
    [sym_generic_type] = STATE(3039),
    [sym_type_query] = STATE(3039),
    [sym_index_type_query] = STATE(3039),
    [sym_lookup_type] = STATE(3039),
    [sym_literal_type] = STATE(3039),
    [sym__number] = STATE(3041),
    [sym_existential_type] = STATE(3039),
    [sym_flow_maybe_type] = STATE(3039),
    [sym_parenthesized_type] = STATE(3039),
    [sym_predefined_type] = STATE(3039),
    [sym_object_type] = STATE(3039),
    [sym_type_parameters] = STATE(5248),
    [sym_array_type] = STATE(3039),
    [sym_tuple_type] = STATE(3039),
    [sym_readonly_type] = STATE(3007),
    [sym_union_type] = STATE(3039),
    [sym_intersection_type] = STATE(3039),
    [sym_function_type] = STATE(3007),
    [sym_identifier] = ACTIONS(1532),
    [anon_sym_STAR] = ACTIONS(543),
    [anon_sym_LBRACE] = ACTIONS(1534),
    [anon_sym_typeof] = ACTIONS(1536),
    [anon_sym_import] = ACTIONS(1538),
    [anon_sym_const] = ACTIONS(133),
    [anon_sym_LPAREN] = ACTIONS(1540),
    [anon_sym_LBRACK] = ACTIONS(1542),
    [anon_sym_new] = ACTIONS(1544),
    [anon_sym_AMP] = ACTIONS(748),
    [anon_sym_PIPE] = ACTIONS(750),
    [anon_sym_PLUS] = ACTIONS(2497),
    [anon_sym_DASH] = ACTIONS(2497),
    [anon_sym_LT] = ACTIONS(2499),
    [anon_sym_void] = ACTIONS(216),
    [anon_sym_DQUOTE] = ACTIONS(1550),
    [anon_sym_SQUOTE] = ACTIONS(1552),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1554),
    [sym_number] = ACTIONS(1556),
    [sym_this] = ACTIONS(1558),
    [sym_true] = ACTIONS(1560),
    [sym_false] = ACTIONS(1560),
    [sym_null] = ACTIONS(1560),
    [sym_undefined] = ACTIONS(1560),
    [anon_sym_readonly] = ACTIONS(1562),
    [anon_sym_QMARK] = ACTIONS(774),
    [anon_sym_any] = ACTIONS(216),
    [anon_sym_number] = ACTIONS(216),
    [anon_sym_boolean] = ACTIONS(216),
    [anon_sym_string] = ACTIONS(216),
    [anon_sym_symbol] = ACTIONS(216),
    [anon_sym_object] = ACTIONS(216),
    [anon_sym_abstract] = ACTIONS(208),
    [anon_sym_infer] = ACTIONS(210),
    [anon_sym_keyof] = ACTIONS(212),
    [anon_sym_unique] = ACTIONS(214),
    [anon_sym_unknown] = ACTIONS(216),
    [anon_sym_never] = ACTIONS(216),
    [anon_sym_LBRACE_PIPE] = ACTIONS(218),
    [sym_html_comment] = ACTIONS(5),
  },
  [1098] = {
    [sym_import] = STATE(4878),
    [sym_nested_identifier] = STATE(5474),
    [sym_string] = STATE(2994),
    [sym_formal_parameters] = STATE(5475),
    [sym_nested_type_identifier] = STATE(2939),
    [sym__type_query_member_expression_in_type_annotation] = STATE(2937),
    [sym__type_query_call_expression_in_type_annotation] = STATE(2938),
    [sym_type] = STATE(3775),
    [sym_constructor_type] = STATE(3007),
    [sym_primary_type] = STATE(2981),
    [sym_template_literal_type] = STATE(3039),
    [sym_infer_type] = STATE(3007),
    [sym_conditional_type] = STATE(3039),
    [sym_generic_type] = STATE(3039),
    [sym_type_query] = STATE(3039),
    [sym_index_type_query] = STATE(3039),
    [sym_lookup_type] = STATE(3039),
    [sym_literal_type] = STATE(3039),
    [sym__number] = STATE(3041),
    [sym_existential_type] = STATE(3039),
    [sym_flow_maybe_type] = STATE(3039),
    [sym_parenthesized_type] = STATE(3039),
    [sym_predefined_type] = STATE(3039),
    [sym_object_type] = STATE(3039),
    [sym_type_parameters] = STATE(5248),
    [sym_array_type] = STATE(3039),
    [sym_tuple_type] = STATE(3039),
    [sym_readonly_type] = STATE(3007),
    [sym_union_type] = STATE(3039),
    [sym_intersection_type] = STATE(3039),
    [sym_function_type] = STATE(3007),
    [sym_identifier] = ACTIONS(1532),
    [anon_sym_STAR] = ACTIONS(543),
    [anon_sym_LBRACE] = ACTIONS(1534),
    [anon_sym_typeof] = ACTIONS(1536),
    [anon_sym_import] = ACTIONS(1538),
    [anon_sym_const] = ACTIONS(133),
    [anon_sym_LPAREN] = ACTIONS(1540),
    [anon_sym_LBRACK] = ACTIONS(1542),
    [anon_sym_new] = ACTIONS(1544),
    [anon_sym_AMP] = ACTIONS(748),
    [anon_sym_PIPE] = ACTIONS(750),
    [anon_sym_PLUS] = ACTIONS(2497),
    [anon_sym_DASH] = ACTIONS(2497),
    [anon_sym_LT] = ACTIONS(2499),
    [anon_sym_void] = ACTIONS(216),
    [anon_sym_DQUOTE] = ACTIONS(1550),
    [anon_sym_SQUOTE] = ACTIONS(1552),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1554),
    [sym_number] = ACTIONS(1556),
    [sym_this] = ACTIONS(1558),
    [sym_true] = ACTIONS(1560),
    [sym_false] = ACTIONS(1560),
    [sym_null] = ACTIONS(1560),
    [sym_undefined] = ACTIONS(1560),
    [anon_sym_readonly] = ACTIONS(1562),
    [anon_sym_QMARK] = ACTIONS(774),
    [anon_sym_any] = ACTIONS(216),
    [anon_sym_number] = ACTIONS(216),
    [anon_sym_boolean] = ACTIONS(216),
    [anon_sym_string] = ACTIONS(216),
    [anon_sym_symbol] = ACTIONS(216),
    [anon_sym_object] = ACTIONS(216),
    [anon_sym_abstract] = ACTIONS(208),
    [anon_sym_infer] = ACTIONS(210),
    [anon_sym_keyof] = ACTIONS(212),
    [anon_sym_unique] = ACTIONS(214),
    [anon_sym_unknown] = ACTIONS(216),
    [anon_sym_never] = ACTIONS(216),
    [anon_sym_LBRACE_PIPE] = ACTIONS(218),
    [sym_html_comment] = ACTIONS(5),
  },
  [1099] = {
    [sym_import] = STATE(4878),
    [sym_nested_identifier] = STATE(5474),
    [sym_string] = STATE(2994),
    [sym_formal_parameters] = STATE(5475),
    [sym_nested_type_identifier] = STATE(2939),
    [sym__type_query_member_expression_in_type_annotation] = STATE(2937),
    [sym__type_query_call_expression_in_type_annotation] = STATE(2938),
    [sym_type] = STATE(3148),
    [sym_constructor_type] = STATE(3007),
    [sym_primary_type] = STATE(2981),
    [sym_template_literal_type] = STATE(3039),
    [sym_infer_type] = STATE(3007),
    [sym_conditional_type] = STATE(3039),
    [sym_generic_type] = STATE(3039),
    [sym_type_query] = STATE(3039),
    [sym_index_type_query] = STATE(3039),
    [sym_lookup_type] = STATE(3039),
    [sym_literal_type] = STATE(3039),
    [sym__number] = STATE(3041),
    [sym_existential_type] = STATE(3039),
    [sym_flow_maybe_type] = STATE(3039),
    [sym_parenthesized_type] = STATE(3039),
    [sym_predefined_type] = STATE(3039),
    [sym_object_type] = STATE(3039),
    [sym_type_parameters] = STATE(5248),
    [sym_array_type] = STATE(3039),
    [sym_tuple_type] = STATE(3039),
    [sym_readonly_type] = STATE(3007),
    [sym_union_type] = STATE(3039),
    [sym_intersection_type] = STATE(3039),
    [sym_function_type] = STATE(3007),
    [sym_identifier] = ACTIONS(1532),
    [anon_sym_STAR] = ACTIONS(543),
    [anon_sym_LBRACE] = ACTIONS(1534),
    [anon_sym_typeof] = ACTIONS(1536),
    [anon_sym_import] = ACTIONS(1538),
    [anon_sym_const] = ACTIONS(133),
    [anon_sym_LPAREN] = ACTIONS(1540),
    [anon_sym_LBRACK] = ACTIONS(1542),
    [anon_sym_new] = ACTIONS(1544),
    [anon_sym_AMP] = ACTIONS(748),
    [anon_sym_PIPE] = ACTIONS(750),
    [anon_sym_PLUS] = ACTIONS(2497),
    [anon_sym_DASH] = ACTIONS(2497),
    [anon_sym_LT] = ACTIONS(2499),
    [anon_sym_void] = ACTIONS(216),
    [anon_sym_DQUOTE] = ACTIONS(1550),
    [anon_sym_SQUOTE] = ACTIONS(1552),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1554),
    [sym_number] = ACTIONS(1556),
    [sym_this] = ACTIONS(1558),
    [sym_true] = ACTIONS(1560),
    [sym_false] = ACTIONS(1560),
    [sym_null] = ACTIONS(1560),
    [sym_undefined] = ACTIONS(1560),
    [anon_sym_readonly] = ACTIONS(1562),
    [anon_sym_QMARK] = ACTIONS(774),
    [anon_sym_any] = ACTIONS(216),
    [anon_sym_number] = ACTIONS(216),
    [anon_sym_boolean] = ACTIONS(216),
    [anon_sym_string] = ACTIONS(216),
    [anon_sym_symbol] = ACTIONS(216),
    [anon_sym_object] = ACTIONS(216),
    [anon_sym_abstract] = ACTIONS(208),
    [anon_sym_infer] = ACTIONS(210),
    [anon_sym_keyof] = ACTIONS(212),
    [anon_sym_unique] = ACTIONS(214),
    [anon_sym_unknown] = ACTIONS(216),
    [anon_sym_never] = ACTIONS(216),
    [anon_sym_LBRACE_PIPE] = ACTIONS(218),
    [sym_html_comment] = ACTIONS(5),
  },
  [1100] = {
    [sym_import] = STATE(4878),
    [sym_nested_identifier] = STATE(5474),
    [sym_string] = STATE(2994),
    [sym_formal_parameters] = STATE(5475),
    [sym_nested_type_identifier] = STATE(2939),
    [sym__type_query_member_expression_in_type_annotation] = STATE(2937),
    [sym__type_query_call_expression_in_type_annotation] = STATE(2938),
    [sym_type] = STATE(3149),
    [sym_constructor_type] = STATE(3007),
    [sym_primary_type] = STATE(2981),
    [sym_template_literal_type] = STATE(3039),
    [sym_infer_type] = STATE(3007),
    [sym_conditional_type] = STATE(3039),
    [sym_generic_type] = STATE(3039),
    [sym_type_query] = STATE(3039),
    [sym_index_type_query] = STATE(3039),
    [sym_lookup_type] = STATE(3039),
    [sym_literal_type] = STATE(3039),
    [sym__number] = STATE(3041),
    [sym_existential_type] = STATE(3039),
    [sym_flow_maybe_type] = STATE(3039),
    [sym_parenthesized_type] = STATE(3039),
    [sym_predefined_type] = STATE(3039),
    [sym_object_type] = STATE(3039),
    [sym_type_parameters] = STATE(5248),
    [sym_array_type] = STATE(3039),
    [sym_tuple_type] = STATE(3039),
    [sym_readonly_type] = STATE(3007),
    [sym_union_type] = STATE(3039),
    [sym_intersection_type] = STATE(3039),
    [sym_function_type] = STATE(3007),
    [sym_identifier] = ACTIONS(1532),
    [anon_sym_STAR] = ACTIONS(543),
    [anon_sym_LBRACE] = ACTIONS(1534),
    [anon_sym_typeof] = ACTIONS(1536),
    [anon_sym_import] = ACTIONS(1538),
    [anon_sym_const] = ACTIONS(133),
    [anon_sym_LPAREN] = ACTIONS(1540),
    [anon_sym_LBRACK] = ACTIONS(1542),
    [anon_sym_new] = ACTIONS(1544),
    [anon_sym_AMP] = ACTIONS(748),
    [anon_sym_PIPE] = ACTIONS(750),
    [anon_sym_PLUS] = ACTIONS(2497),
    [anon_sym_DASH] = ACTIONS(2497),
    [anon_sym_LT] = ACTIONS(2499),
    [anon_sym_void] = ACTIONS(216),
    [anon_sym_DQUOTE] = ACTIONS(1550),
    [anon_sym_SQUOTE] = ACTIONS(1552),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1554),
    [sym_number] = ACTIONS(1556),
    [sym_this] = ACTIONS(1558),
    [sym_true] = ACTIONS(1560),
    [sym_false] = ACTIONS(1560),
    [sym_null] = ACTIONS(1560),
    [sym_undefined] = ACTIONS(1560),
    [anon_sym_readonly] = ACTIONS(1562),
    [anon_sym_QMARK] = ACTIONS(774),
    [anon_sym_any] = ACTIONS(216),
    [anon_sym_number] = ACTIONS(216),
    [anon_sym_boolean] = ACTIONS(216),
    [anon_sym_string] = ACTIONS(216),
    [anon_sym_symbol] = ACTIONS(216),
    [anon_sym_object] = ACTIONS(216),
    [anon_sym_abstract] = ACTIONS(208),
    [anon_sym_infer] = ACTIONS(210),
    [anon_sym_keyof] = ACTIONS(212),
    [anon_sym_unique] = ACTIONS(214),
    [anon_sym_unknown] = ACTIONS(216),
    [anon_sym_never] = ACTIONS(216),
    [anon_sym_LBRACE_PIPE] = ACTIONS(218),
    [sym_html_comment] = ACTIONS(5),
  },
  [1101] = {
    [sym_import] = STATE(4878),
    [sym_nested_identifier] = STATE(5474),
    [sym_string] = STATE(2994),
    [sym_formal_parameters] = STATE(5475),
    [sym_nested_type_identifier] = STATE(2939),
    [sym__type_query_member_expression_in_type_annotation] = STATE(2937),
    [sym__type_query_call_expression_in_type_annotation] = STATE(2938),
    [sym_type] = STATE(4436),
    [sym_constructor_type] = STATE(3007),
    [sym_primary_type] = STATE(2981),
    [sym_template_literal_type] = STATE(3039),
    [sym_infer_type] = STATE(3007),
    [sym_conditional_type] = STATE(3039),
    [sym_generic_type] = STATE(3039),
    [sym_type_query] = STATE(3039),
    [sym_index_type_query] = STATE(3039),
    [sym_lookup_type] = STATE(3039),
    [sym_literal_type] = STATE(3039),
    [sym__number] = STATE(3041),
    [sym_existential_type] = STATE(3039),
    [sym_flow_maybe_type] = STATE(3039),
    [sym_parenthesized_type] = STATE(3039),
    [sym_predefined_type] = STATE(3039),
    [sym_object_type] = STATE(3039),
    [sym_type_parameters] = STATE(5248),
    [sym_array_type] = STATE(3039),
    [sym_tuple_type] = STATE(3039),
    [sym_readonly_type] = STATE(3007),
    [sym_union_type] = STATE(3039),
    [sym_intersection_type] = STATE(3039),
    [sym_function_type] = STATE(3007),
    [sym_identifier] = ACTIONS(1532),
    [anon_sym_STAR] = ACTIONS(543),
    [anon_sym_LBRACE] = ACTIONS(1534),
    [anon_sym_typeof] = ACTIONS(1536),
    [anon_sym_import] = ACTIONS(1538),
    [anon_sym_const] = ACTIONS(133),
    [anon_sym_LPAREN] = ACTIONS(1540),
    [anon_sym_LBRACK] = ACTIONS(1542),
    [anon_sym_new] = ACTIONS(1544),
    [anon_sym_AMP] = ACTIONS(748),
    [anon_sym_PIPE] = ACTIONS(750),
    [anon_sym_PLUS] = ACTIONS(2497),
    [anon_sym_DASH] = ACTIONS(2497),
    [anon_sym_LT] = ACTIONS(2499),
    [anon_sym_void] = ACTIONS(216),
    [anon_sym_DQUOTE] = ACTIONS(1550),
    [anon_sym_SQUOTE] = ACTIONS(1552),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1554),
    [sym_number] = ACTIONS(1556),
    [sym_this] = ACTIONS(1558),
    [sym_true] = ACTIONS(1560),
    [sym_false] = ACTIONS(1560),
    [sym_null] = ACTIONS(1560),
    [sym_undefined] = ACTIONS(1560),
    [anon_sym_readonly] = ACTIONS(1562),
    [anon_sym_QMARK] = ACTIONS(774),
    [anon_sym_any] = ACTIONS(216),
    [anon_sym_number] = ACTIONS(216),
    [anon_sym_boolean] = ACTIONS(216),
    [anon_sym_string] = ACTIONS(216),
    [anon_sym_symbol] = ACTIONS(216),
    [anon_sym_object] = ACTIONS(216),
    [anon_sym_abstract] = ACTIONS(208),
    [anon_sym_infer] = ACTIONS(210),
    [anon_sym_keyof] = ACTIONS(212),
    [anon_sym_unique] = ACTIONS(214),
    [anon_sym_unknown] = ACTIONS(216),
    [anon_sym_never] = ACTIONS(216),
    [anon_sym_LBRACE_PIPE] = ACTIONS(218),
    [sym_html_comment] = ACTIONS(5),
  },
  [1102] = {
    [sym_import] = STATE(4878),
    [sym_nested_identifier] = STATE(5474),
    [sym_string] = STATE(2994),
    [sym_formal_parameters] = STATE(5475),
    [sym_nested_type_identifier] = STATE(2939),
    [sym__type_query_member_expression_in_type_annotation] = STATE(2937),
    [sym__type_query_call_expression_in_type_annotation] = STATE(2938),
    [sym_type] = STATE(4441),
    [sym_constructor_type] = STATE(3007),
    [sym_primary_type] = STATE(2981),
    [sym_template_literal_type] = STATE(3039),
    [sym_infer_type] = STATE(3007),
    [sym_conditional_type] = STATE(3039),
    [sym_generic_type] = STATE(3039),
    [sym_type_query] = STATE(3039),
    [sym_index_type_query] = STATE(3039),
    [sym_lookup_type] = STATE(3039),
    [sym_literal_type] = STATE(3039),
    [sym__number] = STATE(3041),
    [sym_existential_type] = STATE(3039),
    [sym_flow_maybe_type] = STATE(3039),
    [sym_parenthesized_type] = STATE(3039),
    [sym_predefined_type] = STATE(3039),
    [sym_object_type] = STATE(3039),
    [sym_type_parameters] = STATE(5248),
    [sym_array_type] = STATE(3039),
    [sym_tuple_type] = STATE(3039),
    [sym_readonly_type] = STATE(3007),
    [sym_union_type] = STATE(3039),
    [sym_intersection_type] = STATE(3039),
    [sym_function_type] = STATE(3007),
    [sym_identifier] = ACTIONS(1532),
    [anon_sym_STAR] = ACTIONS(543),
    [anon_sym_LBRACE] = ACTIONS(1534),
    [anon_sym_typeof] = ACTIONS(1536),
    [anon_sym_import] = ACTIONS(1538),
    [anon_sym_const] = ACTIONS(133),
    [anon_sym_LPAREN] = ACTIONS(1540),
    [anon_sym_LBRACK] = ACTIONS(1542),
    [anon_sym_new] = ACTIONS(1544),
    [anon_sym_AMP] = ACTIONS(748),
    [anon_sym_PIPE] = ACTIONS(750),
    [anon_sym_PLUS] = ACTIONS(2497),
    [anon_sym_DASH] = ACTIONS(2497),
    [anon_sym_LT] = ACTIONS(2499),
    [anon_sym_void] = ACTIONS(216),
    [anon_sym_DQUOTE] = ACTIONS(1550),
    [anon_sym_SQUOTE] = ACTIONS(1552),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1554),
    [sym_number] = ACTIONS(1556),
    [sym_this] = ACTIONS(1558),
    [sym_true] = ACTIONS(1560),
    [sym_false] = ACTIONS(1560),
    [sym_null] = ACTIONS(1560),
    [sym_undefined] = ACTIONS(1560),
    [anon_sym_readonly] = ACTIONS(1562),
    [anon_sym_QMARK] = ACTIONS(774),
    [anon_sym_any] = ACTIONS(216),
    [anon_sym_number] = ACTIONS(216),
    [anon_sym_boolean] = ACTIONS(216),
    [anon_sym_string] = ACTIONS(216),
    [anon_sym_symbol] = ACTIONS(216),
    [anon_sym_object] = ACTIONS(216),
    [anon_sym_abstract] = ACTIONS(208),
    [anon_sym_infer] = ACTIONS(210),
    [anon_sym_keyof] = ACTIONS(212),
    [anon_sym_unique] = ACTIONS(214),
    [anon_sym_unknown] = ACTIONS(216),
    [anon_sym_never] = ACTIONS(216),
    [anon_sym_LBRACE_PIPE] = ACTIONS(218),
    [sym_html_comment] = ACTIONS(5),
  },
  [1103] = {
    [sym_import] = STATE(4878),
    [sym_nested_identifier] = STATE(5474),
    [sym_string] = STATE(2994),
    [sym_formal_parameters] = STATE(5475),
    [sym_nested_type_identifier] = STATE(2939),
    [sym__type_query_member_expression_in_type_annotation] = STATE(2937),
    [sym__type_query_call_expression_in_type_annotation] = STATE(2938),
    [sym_type] = STATE(4442),
    [sym_constructor_type] = STATE(3007),
    [sym_primary_type] = STATE(2981),
    [sym_template_literal_type] = STATE(3039),
    [sym_infer_type] = STATE(3007),
    [sym_conditional_type] = STATE(3039),
    [sym_generic_type] = STATE(3039),
    [sym_type_query] = STATE(3039),
    [sym_index_type_query] = STATE(3039),
    [sym_lookup_type] = STATE(3039),
    [sym_literal_type] = STATE(3039),
    [sym__number] = STATE(3041),
    [sym_existential_type] = STATE(3039),
    [sym_flow_maybe_type] = STATE(3039),
    [sym_parenthesized_type] = STATE(3039),
    [sym_predefined_type] = STATE(3039),
    [sym_object_type] = STATE(3039),
    [sym_type_parameters] = STATE(5248),
    [sym_array_type] = STATE(3039),
    [sym_tuple_type] = STATE(3039),
    [sym_readonly_type] = STATE(3007),
    [sym_union_type] = STATE(3039),
    [sym_intersection_type] = STATE(3039),
    [sym_function_type] = STATE(3007),
    [sym_identifier] = ACTIONS(1532),
    [anon_sym_STAR] = ACTIONS(543),
    [anon_sym_LBRACE] = ACTIONS(1534),
    [anon_sym_typeof] = ACTIONS(1536),
    [anon_sym_import] = ACTIONS(1538),
    [anon_sym_const] = ACTIONS(133),
    [anon_sym_LPAREN] = ACTIONS(1540),
    [anon_sym_LBRACK] = ACTIONS(1542),
    [anon_sym_new] = ACTIONS(1544),
    [anon_sym_AMP] = ACTIONS(748),
    [anon_sym_PIPE] = ACTIONS(750),
    [anon_sym_PLUS] = ACTIONS(2497),
    [anon_sym_DASH] = ACTIONS(2497),
    [anon_sym_LT] = ACTIONS(2499),
    [anon_sym_void] = ACTIONS(216),
    [anon_sym_DQUOTE] = ACTIONS(1550),
    [anon_sym_SQUOTE] = ACTIONS(1552),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1554),
    [sym_number] = ACTIONS(1556),
    [sym_this] = ACTIONS(1558),
    [sym_true] = ACTIONS(1560),
    [sym_false] = ACTIONS(1560),
    [sym_null] = ACTIONS(1560),
    [sym_undefined] = ACTIONS(1560),
    [anon_sym_readonly] = ACTIONS(1562),
    [anon_sym_QMARK] = ACTIONS(774),
    [anon_sym_any] = ACTIONS(216),
    [anon_sym_number] = ACTIONS(216),
    [anon_sym_boolean] = ACTIONS(216),
    [anon_sym_string] = ACTIONS(216),
    [anon_sym_symbol] = ACTIONS(216),
    [anon_sym_object] = ACTIONS(216),
    [anon_sym_abstract] = ACTIONS(208),
    [anon_sym_infer] = ACTIONS(210),
    [anon_sym_keyof] = ACTIONS(212),
    [anon_sym_unique] = ACTIONS(214),
    [anon_sym_unknown] = ACTIONS(216),
    [anon_sym_never] = ACTIONS(216),
    [anon_sym_LBRACE_PIPE] = ACTIONS(218),
    [sym_html_comment] = ACTIONS(5),
  },
  [1104] = {
    [sym_import] = STATE(4878),
    [sym_nested_identifier] = STATE(5474),
    [sym_string] = STATE(2994),
    [sym_formal_parameters] = STATE(5475),
    [sym_nested_type_identifier] = STATE(2939),
    [sym__type_query_member_expression_in_type_annotation] = STATE(2937),
    [sym__type_query_call_expression_in_type_annotation] = STATE(2938),
    [sym_type] = STATE(3154),
    [sym_constructor_type] = STATE(3007),
    [sym_primary_type] = STATE(2981),
    [sym_template_literal_type] = STATE(3039),
    [sym_infer_type] = STATE(3007),
    [sym_conditional_type] = STATE(3039),
    [sym_generic_type] = STATE(3039),
    [sym_type_query] = STATE(3039),
    [sym_index_type_query] = STATE(3039),
    [sym_lookup_type] = STATE(3039),
    [sym_literal_type] = STATE(3039),
    [sym__number] = STATE(3041),
    [sym_existential_type] = STATE(3039),
    [sym_flow_maybe_type] = STATE(3039),
    [sym_parenthesized_type] = STATE(3039),
    [sym_predefined_type] = STATE(3039),
    [sym_object_type] = STATE(3039),
    [sym_type_parameters] = STATE(5248),
    [sym_array_type] = STATE(3039),
    [sym_tuple_type] = STATE(3039),
    [sym_readonly_type] = STATE(3007),
    [sym_union_type] = STATE(3039),
    [sym_intersection_type] = STATE(3039),
    [sym_function_type] = STATE(3007),
    [sym_identifier] = ACTIONS(1532),
    [anon_sym_STAR] = ACTIONS(543),
    [anon_sym_LBRACE] = ACTIONS(1534),
    [anon_sym_typeof] = ACTIONS(1536),
    [anon_sym_import] = ACTIONS(1538),
    [anon_sym_const] = ACTIONS(133),
    [anon_sym_LPAREN] = ACTIONS(1540),
    [anon_sym_LBRACK] = ACTIONS(1542),
    [anon_sym_new] = ACTIONS(1544),
    [anon_sym_AMP] = ACTIONS(748),
    [anon_sym_PIPE] = ACTIONS(750),
    [anon_sym_PLUS] = ACTIONS(2497),
    [anon_sym_DASH] = ACTIONS(2497),
    [anon_sym_LT] = ACTIONS(2499),
    [anon_sym_void] = ACTIONS(216),
    [anon_sym_DQUOTE] = ACTIONS(1550),
    [anon_sym_SQUOTE] = ACTIONS(1552),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1554),
    [sym_number] = ACTIONS(1556),
    [sym_this] = ACTIONS(1558),
    [sym_true] = ACTIONS(1560),
    [sym_false] = ACTIONS(1560),
    [sym_null] = ACTIONS(1560),
    [sym_undefined] = ACTIONS(1560),
    [anon_sym_readonly] = ACTIONS(1562),
    [anon_sym_QMARK] = ACTIONS(774),
    [anon_sym_any] = ACTIONS(216),
    [anon_sym_number] = ACTIONS(216),
    [anon_sym_boolean] = ACTIONS(216),
    [anon_sym_string] = ACTIONS(216),
    [anon_sym_symbol] = ACTIONS(216),
    [anon_sym_object] = ACTIONS(216),
    [anon_sym_abstract] = ACTIONS(208),
    [anon_sym_infer] = ACTIONS(210),
    [anon_sym_keyof] = ACTIONS(212),
    [anon_sym_unique] = ACTIONS(214),
    [anon_sym_unknown] = ACTIONS(216),
    [anon_sym_never] = ACTIONS(216),
    [anon_sym_LBRACE_PIPE] = ACTIONS(218),
    [sym_html_comment] = ACTIONS(5),
  },
  [1105] = {
    [sym_import] = STATE(4808),
    [sym_nested_identifier] = STATE(5474),
    [sym_string] = STATE(2994),
    [sym_formal_parameters] = STATE(5569),
    [sym_nested_type_identifier] = STATE(3487),
    [sym__type_query_member_expression_in_type_annotation] = STATE(3388),
    [sym__type_query_call_expression_in_type_annotation] = STATE(2938),
    [sym_type] = STATE(3019),
    [sym_constructor_type] = STATE(3007),
    [sym_primary_type] = STATE(2981),
    [sym_template_literal_type] = STATE(3039),
    [sym_infer_type] = STATE(3007),
    [sym_conditional_type] = STATE(3039),
    [sym_generic_type] = STATE(3039),
    [sym_type_query] = STATE(3039),
    [sym_index_type_query] = STATE(3039),
    [sym_lookup_type] = STATE(3039),
    [sym_literal_type] = STATE(3039),
    [sym__number] = STATE(3041),
    [sym_existential_type] = STATE(3039),
    [sym_flow_maybe_type] = STATE(3039),
    [sym_parenthesized_type] = STATE(3039),
    [sym_predefined_type] = STATE(3039),
    [sym_object_type] = STATE(3039),
    [sym_type_parameters] = STATE(5361),
    [sym_array_type] = STATE(3039),
    [sym_tuple_type] = STATE(3039),
    [sym_readonly_type] = STATE(3007),
    [sym_union_type] = STATE(3039),
    [sym_intersection_type] = STATE(3039),
    [sym_function_type] = STATE(3007),
    [sym_identifier] = ACTIONS(3263),
    [anon_sym_STAR] = ACTIONS(543),
    [anon_sym_LBRACE] = ACTIONS(3099),
    [anon_sym_typeof] = ACTIONS(3101),
    [anon_sym_import] = ACTIONS(1538),
    [anon_sym_const] = ACTIONS(133),
    [anon_sym_LPAREN] = ACTIONS(1540),
    [anon_sym_LBRACK] = ACTIONS(1542),
    [anon_sym_new] = ACTIONS(3103),
    [anon_sym_AMP] = ACTIONS(3105),
    [anon_sym_PIPE] = ACTIONS(3107),
    [anon_sym_PLUS] = ACTIONS(2497),
    [anon_sym_DASH] = ACTIONS(2497),
    [anon_sym_LT] = ACTIONS(2499),
    [anon_sym_void] = ACTIONS(216),
    [anon_sym_DQUOTE] = ACTIONS(3109),
    [anon_sym_SQUOTE] = ACTIONS(3111),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1554),
    [sym_number] = ACTIONS(1556),
    [sym_this] = ACTIONS(1558),
    [sym_true] = ACTIONS(1560),
    [sym_false] = ACTIONS(1560),
    [sym_null] = ACTIONS(1560),
    [sym_undefined] = ACTIONS(1560),
    [anon_sym_readonly] = ACTIONS(3115),
    [anon_sym_QMARK] = ACTIONS(3117),
    [anon_sym_any] = ACTIONS(216),
    [anon_sym_number] = ACTIONS(216),
    [anon_sym_boolean] = ACTIONS(216),
    [anon_sym_string] = ACTIONS(216),
    [anon_sym_symbol] = ACTIONS(216),
    [anon_sym_object] = ACTIONS(216),
    [anon_sym_abstract] = ACTIONS(3119),
    [anon_sym_infer] = ACTIONS(3123),
    [anon_sym_keyof] = ACTIONS(3125),
    [anon_sym_unique] = ACTIONS(214),
    [anon_sym_unknown] = ACTIONS(216),
    [anon_sym_never] = ACTIONS(216),
    [anon_sym_LBRACE_PIPE] = ACTIONS(3127),
    [sym_html_comment] = ACTIONS(5),
  },
  [1106] = {
    [sym_import] = STATE(4808),
    [sym_nested_identifier] = STATE(5474),
    [sym_string] = STATE(2994),
    [sym_formal_parameters] = STATE(5569),
    [sym_nested_type_identifier] = STATE(3487),
    [sym__type_query_member_expression_in_type_annotation] = STATE(3388),
    [sym__type_query_call_expression_in_type_annotation] = STATE(2938),
    [sym_type] = STATE(3767),
    [sym_constructor_type] = STATE(3007),
    [sym_primary_type] = STATE(2981),
    [sym_template_literal_type] = STATE(3039),
    [sym_infer_type] = STATE(3007),
    [sym_conditional_type] = STATE(3039),
    [sym_generic_type] = STATE(3039),
    [sym_type_query] = STATE(3039),
    [sym_index_type_query] = STATE(3039),
    [sym_lookup_type] = STATE(3039),
    [sym_literal_type] = STATE(3039),
    [sym__number] = STATE(3041),
    [sym_existential_type] = STATE(3039),
    [sym_flow_maybe_type] = STATE(3039),
    [sym_parenthesized_type] = STATE(3039),
    [sym_predefined_type] = STATE(3039),
    [sym_object_type] = STATE(3039),
    [sym_type_parameters] = STATE(5361),
    [sym_array_type] = STATE(3039),
    [sym_tuple_type] = STATE(3039),
    [sym_readonly_type] = STATE(3007),
    [sym_union_type] = STATE(3039),
    [sym_intersection_type] = STATE(3039),
    [sym_function_type] = STATE(3007),
    [sym_identifier] = ACTIONS(3263),
    [anon_sym_STAR] = ACTIONS(543),
    [anon_sym_LBRACE] = ACTIONS(3099),
    [anon_sym_typeof] = ACTIONS(3101),
    [anon_sym_import] = ACTIONS(1538),
    [anon_sym_const] = ACTIONS(133),
    [anon_sym_LPAREN] = ACTIONS(1540),
    [anon_sym_LBRACK] = ACTIONS(1542),
    [anon_sym_new] = ACTIONS(3103),
    [anon_sym_AMP] = ACTIONS(3105),
    [anon_sym_PIPE] = ACTIONS(3107),
    [anon_sym_PLUS] = ACTIONS(2497),
    [anon_sym_DASH] = ACTIONS(2497),
    [anon_sym_LT] = ACTIONS(2499),
    [anon_sym_void] = ACTIONS(216),
    [anon_sym_DQUOTE] = ACTIONS(3109),
    [anon_sym_SQUOTE] = ACTIONS(3111),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1554),
    [sym_number] = ACTIONS(1556),
    [sym_this] = ACTIONS(1558),
    [sym_true] = ACTIONS(1560),
    [sym_false] = ACTIONS(1560),
    [sym_null] = ACTIONS(1560),
    [sym_undefined] = ACTIONS(1560),
    [anon_sym_readonly] = ACTIONS(3115),
    [anon_sym_QMARK] = ACTIONS(3117),
    [anon_sym_any] = ACTIONS(216),
    [anon_sym_number] = ACTIONS(216),
    [anon_sym_boolean] = ACTIONS(216),
    [anon_sym_string] = ACTIONS(216),
    [anon_sym_symbol] = ACTIONS(216),
    [anon_sym_object] = ACTIONS(216),
    [anon_sym_abstract] = ACTIONS(3119),
    [anon_sym_infer] = ACTIONS(3123),
    [anon_sym_keyof] = ACTIONS(3125),
    [anon_sym_unique] = ACTIONS(214),
    [anon_sym_unknown] = ACTIONS(216),
    [anon_sym_never] = ACTIONS(216),
    [anon_sym_LBRACE_PIPE] = ACTIONS(3127),
    [sym_html_comment] = ACTIONS(5),
  },
  [1107] = {
    [sym_import] = STATE(4808),
    [sym_nested_identifier] = STATE(5474),
    [sym_string] = STATE(2994),
    [sym_formal_parameters] = STATE(5569),
    [sym_nested_type_identifier] = STATE(3487),
    [sym__type_query_member_expression_in_type_annotation] = STATE(3388),
    [sym__type_query_call_expression_in_type_annotation] = STATE(2938),
    [sym_type] = STATE(3769),
    [sym_constructor_type] = STATE(3007),
    [sym_primary_type] = STATE(2981),
    [sym_template_literal_type] = STATE(3039),
    [sym_infer_type] = STATE(3007),
    [sym_conditional_type] = STATE(3039),
    [sym_generic_type] = STATE(3039),
    [sym_type_query] = STATE(3039),
    [sym_index_type_query] = STATE(3039),
    [sym_lookup_type] = STATE(3039),
    [sym_literal_type] = STATE(3039),
    [sym__number] = STATE(3041),
    [sym_existential_type] = STATE(3039),
    [sym_flow_maybe_type] = STATE(3039),
    [sym_parenthesized_type] = STATE(3039),
    [sym_predefined_type] = STATE(3039),
    [sym_object_type] = STATE(3039),
    [sym_type_parameters] = STATE(5361),
    [sym_array_type] = STATE(3039),
    [sym_tuple_type] = STATE(3039),
    [sym_readonly_type] = STATE(3007),
    [sym_union_type] = STATE(3039),
    [sym_intersection_type] = STATE(3039),
    [sym_function_type] = STATE(3007),
    [sym_identifier] = ACTIONS(3263),
    [anon_sym_STAR] = ACTIONS(543),
    [anon_sym_LBRACE] = ACTIONS(3099),
    [anon_sym_typeof] = ACTIONS(3101),
    [anon_sym_import] = ACTIONS(1538),
    [anon_sym_const] = ACTIONS(133),
    [anon_sym_LPAREN] = ACTIONS(1540),
    [anon_sym_LBRACK] = ACTIONS(1542),
    [anon_sym_new] = ACTIONS(3103),
    [anon_sym_AMP] = ACTIONS(3105),
    [anon_sym_PIPE] = ACTIONS(3107),
    [anon_sym_PLUS] = ACTIONS(2497),
    [anon_sym_DASH] = ACTIONS(2497),
    [anon_sym_LT] = ACTIONS(2499),
    [anon_sym_void] = ACTIONS(216),
    [anon_sym_DQUOTE] = ACTIONS(3109),
    [anon_sym_SQUOTE] = ACTIONS(3111),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1554),
    [sym_number] = ACTIONS(1556),
    [sym_this] = ACTIONS(1558),
    [sym_true] = ACTIONS(1560),
    [sym_false] = ACTIONS(1560),
    [sym_null] = ACTIONS(1560),
    [sym_undefined] = ACTIONS(1560),
    [anon_sym_readonly] = ACTIONS(3115),
    [anon_sym_QMARK] = ACTIONS(3117),
    [anon_sym_any] = ACTIONS(216),
    [anon_sym_number] = ACTIONS(216),
    [anon_sym_boolean] = ACTIONS(216),
    [anon_sym_string] = ACTIONS(216),
    [anon_sym_symbol] = ACTIONS(216),
    [anon_sym_object] = ACTIONS(216),
    [anon_sym_abstract] = ACTIONS(3119),
    [anon_sym_infer] = ACTIONS(3123),
    [anon_sym_keyof] = ACTIONS(3125),
    [anon_sym_unique] = ACTIONS(214),
    [anon_sym_unknown] = ACTIONS(216),
    [anon_sym_never] = ACTIONS(216),
    [anon_sym_LBRACE_PIPE] = ACTIONS(3127),
    [sym_html_comment] = ACTIONS(5),
  },
  [1108] = {
    [sym_import] = STATE(4878),
    [sym_nested_identifier] = STATE(5474),
    [sym_string] = STATE(2994),
    [sym_formal_parameters] = STATE(5475),
    [sym_nested_type_identifier] = STATE(3487),
    [sym__type_query_member_expression_in_type_annotation] = STATE(2937),
    [sym__type_query_call_expression_in_type_annotation] = STATE(2938),
    [sym_type] = STATE(4708),
    [sym_constructor_type] = STATE(3007),
    [sym_primary_type] = STATE(2949),
    [sym_template_literal_type] = STATE(3039),
    [sym_infer_type] = STATE(3007),
    [sym_conditional_type] = STATE(3039),
    [sym_generic_type] = STATE(3039),
    [sym_type_query] = STATE(3039),
    [sym_index_type_query] = STATE(3039),
    [sym_lookup_type] = STATE(3039),
    [sym_literal_type] = STATE(3039),
    [sym__number] = STATE(3041),
    [sym_existential_type] = STATE(3039),
    [sym_flow_maybe_type] = STATE(3039),
    [sym_parenthesized_type] = STATE(3039),
    [sym_predefined_type] = STATE(3039),
    [sym_object_type] = STATE(3039),
    [sym_type_parameters] = STATE(5248),
    [sym_array_type] = STATE(3039),
    [sym_tuple_type] = STATE(3039),
    [sym_readonly_type] = STATE(3007),
    [sym_union_type] = STATE(3039),
    [sym_intersection_type] = STATE(3039),
    [sym_function_type] = STATE(3007),
    [sym_identifier] = ACTIONS(3263),
    [anon_sym_STAR] = ACTIONS(543),
    [anon_sym_LBRACE] = ACTIONS(3099),
    [anon_sym_typeof] = ACTIONS(3101),
    [anon_sym_import] = ACTIONS(1538),
    [anon_sym_const] = ACTIONS(133),
    [anon_sym_LPAREN] = ACTIONS(1540),
    [anon_sym_LBRACK] = ACTIONS(1542),
    [anon_sym_new] = ACTIONS(1544),
    [anon_sym_AMP] = ACTIONS(3105),
    [anon_sym_PIPE] = ACTIONS(3107),
    [anon_sym_PLUS] = ACTIONS(2497),
    [anon_sym_DASH] = ACTIONS(2497),
    [anon_sym_LT] = ACTIONS(2499),
    [anon_sym_void] = ACTIONS(216),
    [anon_sym_DQUOTE] = ACTIONS(3109),
    [anon_sym_SQUOTE] = ACTIONS(3111),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1554),
    [sym_number] = ACTIONS(1556),
    [sym_this] = ACTIONS(1558),
    [sym_true] = ACTIONS(1560),
    [sym_false] = ACTIONS(1560),
    [sym_null] = ACTIONS(1560),
    [sym_undefined] = ACTIONS(1560),
    [anon_sym_readonly] = ACTIONS(1562),
    [anon_sym_QMARK] = ACTIONS(3117),
    [anon_sym_any] = ACTIONS(216),
    [anon_sym_number] = ACTIONS(216),
    [anon_sym_boolean] = ACTIONS(216),
    [anon_sym_string] = ACTIONS(216),
    [anon_sym_symbol] = ACTIONS(216),
    [anon_sym_object] = ACTIONS(216),
    [anon_sym_abstract] = ACTIONS(208),
    [anon_sym_infer] = ACTIONS(210),
    [anon_sym_keyof] = ACTIONS(3125),
    [anon_sym_unique] = ACTIONS(214),
    [anon_sym_unknown] = ACTIONS(216),
    [anon_sym_never] = ACTIONS(216),
    [anon_sym_LBRACE_PIPE] = ACTIONS(3127),
    [sym_html_comment] = ACTIONS(5),
  },
  [1109] = {
    [sym_import] = STATE(4878),
    [sym_nested_identifier] = STATE(5474),
    [sym_string] = STATE(2994),
    [sym_formal_parameters] = STATE(5475),
    [sym_nested_type_identifier] = STATE(3487),
    [sym__type_query_member_expression_in_type_annotation] = STATE(2937),
    [sym__type_query_call_expression_in_type_annotation] = STATE(2938),
    [sym_type] = STATE(4708),
    [sym_constructor_type] = STATE(3007),
    [sym_primary_type] = STATE(2971),
    [sym_template_literal_type] = STATE(3039),
    [sym_infer_type] = STATE(3007),
    [sym_conditional_type] = STATE(3039),
    [sym_generic_type] = STATE(3039),
    [sym_type_query] = STATE(3039),
    [sym_index_type_query] = STATE(3039),
    [sym_lookup_type] = STATE(3039),
    [sym_literal_type] = STATE(3039),
    [sym__number] = STATE(3041),
    [sym_existential_type] = STATE(3039),
    [sym_flow_maybe_type] = STATE(3039),
    [sym_parenthesized_type] = STATE(3039),
    [sym_predefined_type] = STATE(3039),
    [sym_object_type] = STATE(3039),
    [sym_type_parameters] = STATE(5248),
    [sym_array_type] = STATE(3039),
    [sym_tuple_type] = STATE(3039),
    [sym_readonly_type] = STATE(3007),
    [sym_union_type] = STATE(3039),
    [sym_intersection_type] = STATE(3039),
    [sym_function_type] = STATE(3007),
    [sym_identifier] = ACTIONS(3263),
    [anon_sym_STAR] = ACTIONS(543),
    [anon_sym_LBRACE] = ACTIONS(3099),
    [anon_sym_typeof] = ACTIONS(3101),
    [anon_sym_import] = ACTIONS(1538),
    [anon_sym_const] = ACTIONS(133),
    [anon_sym_LPAREN] = ACTIONS(1540),
    [anon_sym_LBRACK] = ACTIONS(1542),
    [anon_sym_new] = ACTIONS(1544),
    [anon_sym_AMP] = ACTIONS(3105),
    [anon_sym_PIPE] = ACTIONS(3107),
    [anon_sym_PLUS] = ACTIONS(2497),
    [anon_sym_DASH] = ACTIONS(2497),
    [anon_sym_LT] = ACTIONS(2499),
    [anon_sym_void] = ACTIONS(216),
    [anon_sym_DQUOTE] = ACTIONS(3109),
    [anon_sym_SQUOTE] = ACTIONS(3111),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1554),
    [sym_number] = ACTIONS(1556),
    [sym_this] = ACTIONS(1558),
    [sym_true] = ACTIONS(1560),
    [sym_false] = ACTIONS(1560),
    [sym_null] = ACTIONS(1560),
    [sym_undefined] = ACTIONS(1560),
    [anon_sym_readonly] = ACTIONS(1562),
    [anon_sym_QMARK] = ACTIONS(3117),
    [anon_sym_any] = ACTIONS(216),
    [anon_sym_number] = ACTIONS(216),
    [anon_sym_boolean] = ACTIONS(216),
    [anon_sym_string] = ACTIONS(216),
    [anon_sym_symbol] = ACTIONS(216),
    [anon_sym_object] = ACTIONS(216),
    [anon_sym_abstract] = ACTIONS(208),
    [anon_sym_infer] = ACTIONS(210),
    [anon_sym_keyof] = ACTIONS(3125),
    [anon_sym_unique] = ACTIONS(214),
    [anon_sym_unknown] = ACTIONS(216),
    [anon_sym_never] = ACTIONS(216),
    [anon_sym_LBRACE_PIPE] = ACTIONS(3127),
    [sym_html_comment] = ACTIONS(5),
  },
  [1110] = {
    [sym_import] = STATE(4950),
    [sym_nested_identifier] = STATE(5535),
    [sym_string] = STATE(3265),
    [sym_formal_parameters] = STATE(5840),
    [sym_nested_type_identifier] = STATE(3151),
    [sym__type_query_member_expression_in_type_annotation] = STATE(3076),
    [sym__type_query_call_expression_in_type_annotation] = STATE(3200),
    [sym_type] = STATE(3302),
    [sym_constructor_type] = STATE(3271),
    [sym_primary_type] = STATE(3272),
    [sym_template_literal_type] = STATE(3273),
    [sym_infer_type] = STATE(3271),
    [sym_conditional_type] = STATE(3273),
    [sym_generic_type] = STATE(3273),
    [sym_type_query] = STATE(3273),
    [sym_index_type_query] = STATE(3273),
    [sym_lookup_type] = STATE(3273),
    [sym_literal_type] = STATE(3273),
    [sym__number] = STATE(3274),
    [sym_existential_type] = STATE(3273),
    [sym_flow_maybe_type] = STATE(3273),
    [sym_parenthesized_type] = STATE(3273),
    [sym_predefined_type] = STATE(3273),
    [sym_object_type] = STATE(3273),
    [sym_type_parameters] = STATE(5146),
    [sym_array_type] = STATE(3273),
    [sym_tuple_type] = STATE(3273),
    [sym_readonly_type] = STATE(3271),
    [sym_union_type] = STATE(3273),
    [sym_intersection_type] = STATE(3273),
    [sym_function_type] = STATE(3271),
    [sym_identifier] = ACTIONS(1606),
    [anon_sym_STAR] = ACTIONS(986),
    [anon_sym_LBRACE] = ACTIONS(1610),
    [anon_sym_typeof] = ACTIONS(1612),
    [anon_sym_import] = ACTIONS(1538),
    [anon_sym_const] = ACTIONS(992),
    [anon_sym_LPAREN] = ACTIONS(1614),
    [anon_sym_LBRACK] = ACTIONS(1616),
    [anon_sym_new] = ACTIONS(1618),
    [anon_sym_AMP] = ACTIONS(1000),
    [anon_sym_PIPE] = ACTIONS(1002),
    [anon_sym_PLUS] = ACTIONS(2983),
    [anon_sym_DASH] = ACTIONS(2983),
    [anon_sym_LT] = ACTIONS(2499),
    [anon_sym_void] = ACTIONS(1032),
    [anon_sym_DQUOTE] = ACTIONS(1626),
    [anon_sym_SQUOTE] = ACTIONS(1628),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1630),
    [sym_number] = ACTIONS(1632),
    [sym_this] = ACTIONS(1634),
    [sym_true] = ACTIONS(1636),
    [sym_false] = ACTIONS(1636),
    [sym_null] = ACTIONS(1636),
    [sym_undefined] = ACTIONS(1636),
    [anon_sym_readonly] = ACTIONS(1638),
    [anon_sym_QMARK] = ACTIONS(1020),
    [anon_sym_any] = ACTIONS(1032),
    [anon_sym_number] = ACTIONS(1032),
    [anon_sym_boolean] = ACTIONS(1032),
    [anon_sym_string] = ACTIONS(1032),
    [anon_sym_symbol] = ACTIONS(1032),
    [anon_sym_object] = ACTIONS(1032),
    [anon_sym_abstract] = ACTIONS(1024),
    [anon_sym_infer] = ACTIONS(1026),
    [anon_sym_keyof] = ACTIONS(1028),
    [anon_sym_unique] = ACTIONS(1030),
    [anon_sym_unknown] = ACTIONS(1032),
    [anon_sym_never] = ACTIONS(1032),
    [anon_sym_LBRACE_PIPE] = ACTIONS(1034),
    [sym_html_comment] = ACTIONS(5),
  },
  [1111] = {
    [sym_import] = STATE(4878),
    [sym_nested_identifier] = STATE(5474),
    [sym_string] = STATE(2994),
    [sym_formal_parameters] = STATE(5475),
    [sym_nested_type_identifier] = STATE(2939),
    [sym__type_query_member_expression_in_type_annotation] = STATE(2937),
    [sym__type_query_call_expression_in_type_annotation] = STATE(2938),
    [sym_type] = STATE(3784),
    [sym_constructor_type] = STATE(3007),
    [sym_primary_type] = STATE(2981),
    [sym_template_literal_type] = STATE(3039),
    [sym_infer_type] = STATE(3007),
    [sym_conditional_type] = STATE(3039),
    [sym_generic_type] = STATE(3039),
    [sym_type_query] = STATE(3039),
    [sym_index_type_query] = STATE(3039),
    [sym_lookup_type] = STATE(3039),
    [sym_literal_type] = STATE(3039),
    [sym__number] = STATE(3041),
    [sym_existential_type] = STATE(3039),
    [sym_flow_maybe_type] = STATE(3039),
    [sym_parenthesized_type] = STATE(3039),
    [sym_predefined_type] = STATE(3039),
    [sym_object_type] = STATE(3039),
    [sym_type_parameters] = STATE(5248),
    [sym_array_type] = STATE(3039),
    [sym_tuple_type] = STATE(3039),
    [sym_readonly_type] = STATE(3007),
    [sym_union_type] = STATE(3039),
    [sym_intersection_type] = STATE(3039),
    [sym_function_type] = STATE(3007),
    [sym_identifier] = ACTIONS(1532),
    [anon_sym_STAR] = ACTIONS(543),
    [anon_sym_LBRACE] = ACTIONS(1534),
    [anon_sym_typeof] = ACTIONS(1536),
    [anon_sym_import] = ACTIONS(1538),
    [anon_sym_const] = ACTIONS(133),
    [anon_sym_LPAREN] = ACTIONS(1540),
    [anon_sym_LBRACK] = ACTIONS(1542),
    [anon_sym_new] = ACTIONS(1544),
    [anon_sym_AMP] = ACTIONS(748),
    [anon_sym_PIPE] = ACTIONS(750),
    [anon_sym_PLUS] = ACTIONS(2497),
    [anon_sym_DASH] = ACTIONS(2497),
    [anon_sym_LT] = ACTIONS(2499),
    [anon_sym_void] = ACTIONS(216),
    [anon_sym_DQUOTE] = ACTIONS(1550),
    [anon_sym_SQUOTE] = ACTIONS(1552),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1554),
    [sym_number] = ACTIONS(1556),
    [sym_this] = ACTIONS(1558),
    [sym_true] = ACTIONS(1560),
    [sym_false] = ACTIONS(1560),
    [sym_null] = ACTIONS(1560),
    [sym_undefined] = ACTIONS(1560),
    [anon_sym_readonly] = ACTIONS(1562),
    [anon_sym_QMARK] = ACTIONS(774),
    [anon_sym_any] = ACTIONS(216),
    [anon_sym_number] = ACTIONS(216),
    [anon_sym_boolean] = ACTIONS(216),
    [anon_sym_string] = ACTIONS(216),
    [anon_sym_symbol] = ACTIONS(216),
    [anon_sym_object] = ACTIONS(216),
    [anon_sym_abstract] = ACTIONS(208),
    [anon_sym_infer] = ACTIONS(210),
    [anon_sym_keyof] = ACTIONS(212),
    [anon_sym_unique] = ACTIONS(214),
    [anon_sym_unknown] = ACTIONS(216),
    [anon_sym_never] = ACTIONS(216),
    [anon_sym_LBRACE_PIPE] = ACTIONS(218),
    [sym_html_comment] = ACTIONS(5),
  },
  [1112] = {
    [sym_import] = STATE(4531),
    [sym_nested_identifier] = STATE(5486),
    [sym_string] = STATE(1632),
    [sym_formal_parameters] = STATE(5639),
    [sym_nested_type_identifier] = STATE(1527),
    [sym__type_query_member_expression_in_type_annotation] = STATE(1514),
    [sym__type_query_call_expression_in_type_annotation] = STATE(1574),
    [sym_type] = STATE(1619),
    [sym_constructor_type] = STATE(1544),
    [sym_primary_type] = STATE(1554),
    [sym_template_literal_type] = STATE(1556),
    [sym_infer_type] = STATE(1544),
    [sym_conditional_type] = STATE(1556),
    [sym_generic_type] = STATE(1556),
    [sym_type_query] = STATE(1556),
    [sym_index_type_query] = STATE(1556),
    [sym_lookup_type] = STATE(1556),
    [sym_literal_type] = STATE(1556),
    [sym__number] = STATE(1536),
    [sym_existential_type] = STATE(1556),
    [sym_flow_maybe_type] = STATE(1556),
    [sym_parenthesized_type] = STATE(1556),
    [sym_predefined_type] = STATE(1556),
    [sym_object_type] = STATE(1556),
    [sym_type_parameters] = STATE(5205),
    [sym_array_type] = STATE(1556),
    [sym_tuple_type] = STATE(1556),
    [sym_readonly_type] = STATE(1544),
    [sym_union_type] = STATE(1556),
    [sym_intersection_type] = STATE(1556),
    [sym_function_type] = STATE(1544),
    [sym_identifier] = ACTIONS(3251),
    [anon_sym_STAR] = ACTIONS(3147),
    [anon_sym_LBRACE] = ACTIONS(3149),
    [anon_sym_typeof] = ACTIONS(3151),
    [anon_sym_import] = ACTIONS(1538),
    [anon_sym_const] = ACTIONS(3265),
    [anon_sym_LPAREN] = ACTIONS(3155),
    [anon_sym_LBRACK] = ACTIONS(3157),
    [anon_sym_new] = ACTIONS(3159),
    [anon_sym_AMP] = ACTIONS(3161),
    [anon_sym_PIPE] = ACTIONS(3163),
    [anon_sym_PLUS] = ACTIONS(3165),
    [anon_sym_DASH] = ACTIONS(3165),
    [anon_sym_LT] = ACTIONS(2499),
    [anon_sym_void] = ACTIONS(3167),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(3169),
    [sym_number] = ACTIONS(3171),
    [sym_this] = ACTIONS(3253),
    [sym_true] = ACTIONS(3175),
    [sym_false] = ACTIONS(3175),
    [sym_null] = ACTIONS(3175),
    [sym_undefined] = ACTIONS(3175),
    [anon_sym_readonly] = ACTIONS(3177),
    [anon_sym_QMARK] = ACTIONS(3179),
    [anon_sym_any] = ACTIONS(3167),
    [anon_sym_number] = ACTIONS(3167),
    [anon_sym_boolean] = ACTIONS(3167),
    [anon_sym_string] = ACTIONS(3167),
    [anon_sym_symbol] = ACTIONS(3167),
    [anon_sym_object] = ACTIONS(3167),
    [anon_sym_abstract] = ACTIONS(3181),
    [anon_sym_infer] = ACTIONS(3185),
    [anon_sym_keyof] = ACTIONS(3187),
    [anon_sym_unique] = ACTIONS(3189),
    [anon_sym_unknown] = ACTIONS(3167),
    [anon_sym_never] = ACTIONS(3167),
    [anon_sym_LBRACE_PIPE] = ACTIONS(3191),
    [sym_html_comment] = ACTIONS(5),
  },
  [1113] = {
    [sym_import] = STATE(4650),
    [sym_nested_identifier] = STATE(5567),
    [sym_string] = STATE(1975),
    [sym_formal_parameters] = STATE(5527),
    [sym_nested_type_identifier] = STATE(1865),
    [sym__type_query_member_expression_in_type_annotation] = STATE(1781),
    [sym__type_query_call_expression_in_type_annotation] = STATE(1911),
    [sym_type] = STATE(1910),
    [sym_constructor_type] = STATE(1912),
    [sym_primary_type] = STATE(1915),
    [sym_template_literal_type] = STATE(1916),
    [sym_infer_type] = STATE(1912),
    [sym_conditional_type] = STATE(1916),
    [sym_generic_type] = STATE(1916),
    [sym_type_query] = STATE(1916),
    [sym_index_type_query] = STATE(1916),
    [sym_lookup_type] = STATE(1916),
    [sym_literal_type] = STATE(1916),
    [sym__number] = STATE(1918),
    [sym_existential_type] = STATE(1916),
    [sym_flow_maybe_type] = STATE(1916),
    [sym_parenthesized_type] = STATE(1916),
    [sym_predefined_type] = STATE(1916),
    [sym_object_type] = STATE(1916),
    [sym_type_parameters] = STATE(5243),
    [sym_array_type] = STATE(1916),
    [sym_tuple_type] = STATE(1916),
    [sym_readonly_type] = STATE(1912),
    [sym_union_type] = STATE(1916),
    [sym_intersection_type] = STATE(1916),
    [sym_function_type] = STATE(1912),
    [sym_identifier] = ACTIONS(3255),
    [anon_sym_STAR] = ACTIONS(3047),
    [anon_sym_LBRACE] = ACTIONS(3049),
    [anon_sym_typeof] = ACTIONS(3051),
    [anon_sym_import] = ACTIONS(1538),
    [anon_sym_const] = ACTIONS(3267),
    [anon_sym_LPAREN] = ACTIONS(3055),
    [anon_sym_LBRACK] = ACTIONS(3057),
    [anon_sym_new] = ACTIONS(3059),
    [anon_sym_AMP] = ACTIONS(3061),
    [anon_sym_PIPE] = ACTIONS(3063),
    [anon_sym_PLUS] = ACTIONS(3065),
    [anon_sym_DASH] = ACTIONS(3065),
    [anon_sym_LT] = ACTIONS(2499),
    [anon_sym_void] = ACTIONS(3067),
    [anon_sym_DQUOTE] = ACTIONS(83),
    [anon_sym_SQUOTE] = ACTIONS(85),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(3069),
    [sym_number] = ACTIONS(3071),
    [sym_this] = ACTIONS(3257),
    [sym_true] = ACTIONS(3075),
    [sym_false] = ACTIONS(3075),
    [sym_null] = ACTIONS(3075),
    [sym_undefined] = ACTIONS(3075),
    [anon_sym_readonly] = ACTIONS(3077),
    [anon_sym_QMARK] = ACTIONS(3079),
    [anon_sym_any] = ACTIONS(3067),
    [anon_sym_number] = ACTIONS(3067),
    [anon_sym_boolean] = ACTIONS(3067),
    [anon_sym_string] = ACTIONS(3067),
    [anon_sym_symbol] = ACTIONS(3067),
    [anon_sym_object] = ACTIONS(3067),
    [anon_sym_abstract] = ACTIONS(3081),
    [anon_sym_infer] = ACTIONS(3085),
    [anon_sym_keyof] = ACTIONS(3087),
    [anon_sym_unique] = ACTIONS(3089),
    [anon_sym_unknown] = ACTIONS(3067),
    [anon_sym_never] = ACTIONS(3067),
    [anon_sym_LBRACE_PIPE] = ACTIONS(3091),
    [sym_html_comment] = ACTIONS(5),
  },
  [1114] = {
    [sym_import] = STATE(4531),
    [sym_nested_identifier] = STATE(5486),
    [sym_string] = STATE(1632),
    [sym_formal_parameters] = STATE(5639),
    [sym_nested_type_identifier] = STATE(1527),
    [sym__type_query_member_expression_in_type_annotation] = STATE(1514),
    [sym__type_query_call_expression_in_type_annotation] = STATE(1574),
    [sym_type] = STATE(1581),
    [sym_constructor_type] = STATE(1544),
    [sym_primary_type] = STATE(1554),
    [sym_template_literal_type] = STATE(1556),
    [sym_infer_type] = STATE(1544),
    [sym_conditional_type] = STATE(1556),
    [sym_generic_type] = STATE(1556),
    [sym_type_query] = STATE(1556),
    [sym_index_type_query] = STATE(1556),
    [sym_lookup_type] = STATE(1556),
    [sym_literal_type] = STATE(1556),
    [sym__number] = STATE(1536),
    [sym_existential_type] = STATE(1556),
    [sym_flow_maybe_type] = STATE(1556),
    [sym_parenthesized_type] = STATE(1556),
    [sym_predefined_type] = STATE(1556),
    [sym_object_type] = STATE(1556),
    [sym_type_parameters] = STATE(5205),
    [sym_array_type] = STATE(1556),
    [sym_tuple_type] = STATE(1556),
    [sym_readonly_type] = STATE(1544),
    [sym_union_type] = STATE(1556),
    [sym_intersection_type] = STATE(1556),
    [sym_function_type] = STATE(1544),
    [sym_identifier] = ACTIONS(3251),
    [anon_sym_STAR] = ACTIONS(3147),
    [anon_sym_LBRACE] = ACTIONS(3149),
    [anon_sym_typeof] = ACTIONS(3151),
    [anon_sym_import] = ACTIONS(1538),
    [anon_sym_const] = ACTIONS(3153),
    [anon_sym_LPAREN] = ACTIONS(3155),
    [anon_sym_LBRACK] = ACTIONS(3157),
    [anon_sym_new] = ACTIONS(3159),
    [anon_sym_AMP] = ACTIONS(3161),
    [anon_sym_PIPE] = ACTIONS(3163),
    [anon_sym_PLUS] = ACTIONS(3165),
    [anon_sym_DASH] = ACTIONS(3165),
    [anon_sym_LT] = ACTIONS(2499),
    [anon_sym_void] = ACTIONS(3167),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(3169),
    [sym_number] = ACTIONS(3171),
    [sym_this] = ACTIONS(3253),
    [sym_true] = ACTIONS(3175),
    [sym_false] = ACTIONS(3175),
    [sym_null] = ACTIONS(3175),
    [sym_undefined] = ACTIONS(3175),
    [anon_sym_readonly] = ACTIONS(3177),
    [anon_sym_QMARK] = ACTIONS(3179),
    [anon_sym_any] = ACTIONS(3167),
    [anon_sym_number] = ACTIONS(3167),
    [anon_sym_boolean] = ACTIONS(3167),
    [anon_sym_string] = ACTIONS(3167),
    [anon_sym_symbol] = ACTIONS(3167),
    [anon_sym_object] = ACTIONS(3167),
    [anon_sym_abstract] = ACTIONS(3181),
    [anon_sym_infer] = ACTIONS(3185),
    [anon_sym_keyof] = ACTIONS(3187),
    [anon_sym_unique] = ACTIONS(3189),
    [anon_sym_unknown] = ACTIONS(3167),
    [anon_sym_never] = ACTIONS(3167),
    [anon_sym_LBRACE_PIPE] = ACTIONS(3191),
    [sym_html_comment] = ACTIONS(5),
  },
  [1115] = {
    [sym_import] = STATE(4950),
    [sym_nested_identifier] = STATE(5535),
    [sym_string] = STATE(3265),
    [sym_formal_parameters] = STATE(5840),
    [sym_nested_type_identifier] = STATE(3151),
    [sym__type_query_member_expression_in_type_annotation] = STATE(3076),
    [sym__type_query_call_expression_in_type_annotation] = STATE(3200),
    [sym_type] = STATE(4202),
    [sym_constructor_type] = STATE(3271),
    [sym_primary_type] = STATE(3272),
    [sym_template_literal_type] = STATE(3273),
    [sym_infer_type] = STATE(3271),
    [sym_conditional_type] = STATE(3273),
    [sym_generic_type] = STATE(3273),
    [sym_type_query] = STATE(3273),
    [sym_index_type_query] = STATE(3273),
    [sym_lookup_type] = STATE(3273),
    [sym_literal_type] = STATE(3273),
    [sym__number] = STATE(3274),
    [sym_existential_type] = STATE(3273),
    [sym_flow_maybe_type] = STATE(3273),
    [sym_parenthesized_type] = STATE(3273),
    [sym_predefined_type] = STATE(3273),
    [sym_object_type] = STATE(3273),
    [sym_type_parameters] = STATE(5146),
    [sym_array_type] = STATE(3273),
    [sym_tuple_type] = STATE(3273),
    [sym_readonly_type] = STATE(3271),
    [sym_union_type] = STATE(3273),
    [sym_intersection_type] = STATE(3273),
    [sym_function_type] = STATE(3271),
    [sym_identifier] = ACTIONS(1606),
    [anon_sym_STAR] = ACTIONS(986),
    [anon_sym_LBRACE] = ACTIONS(1610),
    [anon_sym_typeof] = ACTIONS(1612),
    [anon_sym_import] = ACTIONS(1538),
    [anon_sym_const] = ACTIONS(992),
    [anon_sym_LPAREN] = ACTIONS(1614),
    [anon_sym_LBRACK] = ACTIONS(1616),
    [anon_sym_new] = ACTIONS(1618),
    [anon_sym_AMP] = ACTIONS(1000),
    [anon_sym_PIPE] = ACTIONS(1002),
    [anon_sym_PLUS] = ACTIONS(2983),
    [anon_sym_DASH] = ACTIONS(2983),
    [anon_sym_LT] = ACTIONS(2499),
    [anon_sym_void] = ACTIONS(1032),
    [anon_sym_DQUOTE] = ACTIONS(1626),
    [anon_sym_SQUOTE] = ACTIONS(1628),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1630),
    [sym_number] = ACTIONS(1632),
    [sym_this] = ACTIONS(1634),
    [sym_true] = ACTIONS(1636),
    [sym_false] = ACTIONS(1636),
    [sym_null] = ACTIONS(1636),
    [sym_undefined] = ACTIONS(1636),
    [anon_sym_readonly] = ACTIONS(1638),
    [anon_sym_QMARK] = ACTIONS(1020),
    [anon_sym_any] = ACTIONS(1032),
    [anon_sym_number] = ACTIONS(1032),
    [anon_sym_boolean] = ACTIONS(1032),
    [anon_sym_string] = ACTIONS(1032),
    [anon_sym_symbol] = ACTIONS(1032),
    [anon_sym_object] = ACTIONS(1032),
    [anon_sym_abstract] = ACTIONS(1024),
    [anon_sym_infer] = ACTIONS(1026),
    [anon_sym_keyof] = ACTIONS(1028),
    [anon_sym_unique] = ACTIONS(1030),
    [anon_sym_unknown] = ACTIONS(1032),
    [anon_sym_never] = ACTIONS(1032),
    [anon_sym_LBRACE_PIPE] = ACTIONS(1034),
    [sym_html_comment] = ACTIONS(5),
  },
  [1116] = {
    [sym_import] = STATE(4808),
    [sym_nested_identifier] = STATE(5474),
    [sym_string] = STATE(2994),
    [sym_formal_parameters] = STATE(5569),
    [sym_nested_type_identifier] = STATE(3487),
    [sym__type_query_member_expression_in_type_annotation] = STATE(3388),
    [sym__type_query_call_expression_in_type_annotation] = STATE(2938),
    [sym_type] = STATE(3021),
    [sym_constructor_type] = STATE(3007),
    [sym_primary_type] = STATE(2981),
    [sym_template_literal_type] = STATE(3039),
    [sym_infer_type] = STATE(3007),
    [sym_conditional_type] = STATE(3039),
    [sym_generic_type] = STATE(3039),
    [sym_type_query] = STATE(3039),
    [sym_index_type_query] = STATE(3039),
    [sym_lookup_type] = STATE(3039),
    [sym_literal_type] = STATE(3039),
    [sym__number] = STATE(3041),
    [sym_existential_type] = STATE(3039),
    [sym_flow_maybe_type] = STATE(3039),
    [sym_parenthesized_type] = STATE(3039),
    [sym_predefined_type] = STATE(3039),
    [sym_object_type] = STATE(3039),
    [sym_type_parameters] = STATE(5361),
    [sym_array_type] = STATE(3039),
    [sym_tuple_type] = STATE(3039),
    [sym_readonly_type] = STATE(3007),
    [sym_union_type] = STATE(3039),
    [sym_intersection_type] = STATE(3039),
    [sym_function_type] = STATE(3007),
    [sym_identifier] = ACTIONS(3263),
    [anon_sym_STAR] = ACTIONS(543),
    [anon_sym_LBRACE] = ACTIONS(3099),
    [anon_sym_typeof] = ACTIONS(3101),
    [anon_sym_import] = ACTIONS(1538),
    [anon_sym_const] = ACTIONS(133),
    [anon_sym_LPAREN] = ACTIONS(1540),
    [anon_sym_LBRACK] = ACTIONS(1542),
    [anon_sym_new] = ACTIONS(3103),
    [anon_sym_AMP] = ACTIONS(3105),
    [anon_sym_PIPE] = ACTIONS(3107),
    [anon_sym_PLUS] = ACTIONS(2497),
    [anon_sym_DASH] = ACTIONS(2497),
    [anon_sym_LT] = ACTIONS(2499),
    [anon_sym_void] = ACTIONS(216),
    [anon_sym_DQUOTE] = ACTIONS(3109),
    [anon_sym_SQUOTE] = ACTIONS(3111),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1554),
    [sym_number] = ACTIONS(1556),
    [sym_this] = ACTIONS(1558),
    [sym_true] = ACTIONS(1560),
    [sym_false] = ACTIONS(1560),
    [sym_null] = ACTIONS(1560),
    [sym_undefined] = ACTIONS(1560),
    [anon_sym_readonly] = ACTIONS(3115),
    [anon_sym_QMARK] = ACTIONS(3117),
    [anon_sym_any] = ACTIONS(216),
    [anon_sym_number] = ACTIONS(216),
    [anon_sym_boolean] = ACTIONS(216),
    [anon_sym_string] = ACTIONS(216),
    [anon_sym_symbol] = ACTIONS(216),
    [anon_sym_object] = ACTIONS(216),
    [anon_sym_abstract] = ACTIONS(3119),
    [anon_sym_infer] = ACTIONS(3123),
    [anon_sym_keyof] = ACTIONS(3125),
    [anon_sym_unique] = ACTIONS(214),
    [anon_sym_unknown] = ACTIONS(216),
    [anon_sym_never] = ACTIONS(216),
    [anon_sym_LBRACE_PIPE] = ACTIONS(3127),
    [sym_html_comment] = ACTIONS(5),
  },
  [1117] = {
    [sym_import] = STATE(4808),
    [sym_nested_identifier] = STATE(5474),
    [sym_string] = STATE(2994),
    [sym_formal_parameters] = STATE(5569),
    [sym_nested_type_identifier] = STATE(3487),
    [sym__type_query_member_expression_in_type_annotation] = STATE(3388),
    [sym__type_query_call_expression_in_type_annotation] = STATE(2938),
    [sym_type] = STATE(3850),
    [sym_constructor_type] = STATE(3007),
    [sym_primary_type] = STATE(2981),
    [sym_template_literal_type] = STATE(3039),
    [sym_infer_type] = STATE(3007),
    [sym_conditional_type] = STATE(3039),
    [sym_generic_type] = STATE(3039),
    [sym_type_query] = STATE(3039),
    [sym_index_type_query] = STATE(3039),
    [sym_lookup_type] = STATE(3039),
    [sym_literal_type] = STATE(3039),
    [sym__number] = STATE(3041),
    [sym_existential_type] = STATE(3039),
    [sym_flow_maybe_type] = STATE(3039),
    [sym_parenthesized_type] = STATE(3039),
    [sym_predefined_type] = STATE(3039),
    [sym_object_type] = STATE(3039),
    [sym_type_parameters] = STATE(5361),
    [sym_array_type] = STATE(3039),
    [sym_tuple_type] = STATE(3039),
    [sym_readonly_type] = STATE(3007),
    [sym_union_type] = STATE(3039),
    [sym_intersection_type] = STATE(3039),
    [sym_function_type] = STATE(3007),
    [sym_identifier] = ACTIONS(3263),
    [anon_sym_STAR] = ACTIONS(543),
    [anon_sym_LBRACE] = ACTIONS(3099),
    [anon_sym_typeof] = ACTIONS(3101),
    [anon_sym_import] = ACTIONS(1538),
    [anon_sym_const] = ACTIONS(133),
    [anon_sym_LPAREN] = ACTIONS(1540),
    [anon_sym_LBRACK] = ACTIONS(1542),
    [anon_sym_new] = ACTIONS(3103),
    [anon_sym_AMP] = ACTIONS(3105),
    [anon_sym_PIPE] = ACTIONS(3107),
    [anon_sym_PLUS] = ACTIONS(2497),
    [anon_sym_DASH] = ACTIONS(2497),
    [anon_sym_LT] = ACTIONS(2499),
    [anon_sym_void] = ACTIONS(216),
    [anon_sym_DQUOTE] = ACTIONS(3109),
    [anon_sym_SQUOTE] = ACTIONS(3111),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1554),
    [sym_number] = ACTIONS(1556),
    [sym_this] = ACTIONS(1558),
    [sym_true] = ACTIONS(1560),
    [sym_false] = ACTIONS(1560),
    [sym_null] = ACTIONS(1560),
    [sym_undefined] = ACTIONS(1560),
    [anon_sym_readonly] = ACTIONS(3115),
    [anon_sym_QMARK] = ACTIONS(3117),
    [anon_sym_any] = ACTIONS(216),
    [anon_sym_number] = ACTIONS(216),
    [anon_sym_boolean] = ACTIONS(216),
    [anon_sym_string] = ACTIONS(216),
    [anon_sym_symbol] = ACTIONS(216),
    [anon_sym_object] = ACTIONS(216),
    [anon_sym_abstract] = ACTIONS(3119),
    [anon_sym_infer] = ACTIONS(3123),
    [anon_sym_keyof] = ACTIONS(3125),
    [anon_sym_unique] = ACTIONS(214),
    [anon_sym_unknown] = ACTIONS(216),
    [anon_sym_never] = ACTIONS(216),
    [anon_sym_LBRACE_PIPE] = ACTIONS(3127),
    [sym_html_comment] = ACTIONS(5),
  },
  [1118] = {
    [sym_import] = STATE(4808),
    [sym_nested_identifier] = STATE(5474),
    [sym_string] = STATE(2994),
    [sym_formal_parameters] = STATE(5569),
    [sym_nested_type_identifier] = STATE(3487),
    [sym__type_query_member_expression_in_type_annotation] = STATE(3388),
    [sym__type_query_call_expression_in_type_annotation] = STATE(2938),
    [sym_type] = STATE(2947),
    [sym_constructor_type] = STATE(3007),
    [sym_primary_type] = STATE(2981),
    [sym_template_literal_type] = STATE(3039),
    [sym_infer_type] = STATE(3007),
    [sym_conditional_type] = STATE(3039),
    [sym_generic_type] = STATE(3039),
    [sym_type_query] = STATE(3039),
    [sym_index_type_query] = STATE(3039),
    [sym_lookup_type] = STATE(3039),
    [sym_literal_type] = STATE(3039),
    [sym__number] = STATE(3041),
    [sym_existential_type] = STATE(3039),
    [sym_flow_maybe_type] = STATE(3039),
    [sym_parenthesized_type] = STATE(3039),
    [sym_predefined_type] = STATE(3039),
    [sym_object_type] = STATE(3039),
    [sym_type_parameters] = STATE(5361),
    [sym_array_type] = STATE(3039),
    [sym_tuple_type] = STATE(3039),
    [sym_readonly_type] = STATE(3007),
    [sym_union_type] = STATE(3039),
    [sym_intersection_type] = STATE(3039),
    [sym_function_type] = STATE(3007),
    [sym_identifier] = ACTIONS(3263),
    [anon_sym_STAR] = ACTIONS(543),
    [anon_sym_LBRACE] = ACTIONS(3099),
    [anon_sym_typeof] = ACTIONS(3101),
    [anon_sym_import] = ACTIONS(1538),
    [anon_sym_const] = ACTIONS(133),
    [anon_sym_LPAREN] = ACTIONS(1540),
    [anon_sym_LBRACK] = ACTIONS(1542),
    [anon_sym_new] = ACTIONS(3103),
    [anon_sym_AMP] = ACTIONS(3105),
    [anon_sym_PIPE] = ACTIONS(3107),
    [anon_sym_PLUS] = ACTIONS(2497),
    [anon_sym_DASH] = ACTIONS(2497),
    [anon_sym_LT] = ACTIONS(2499),
    [anon_sym_void] = ACTIONS(216),
    [anon_sym_DQUOTE] = ACTIONS(3109),
    [anon_sym_SQUOTE] = ACTIONS(3111),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1554),
    [sym_number] = ACTIONS(1556),
    [sym_this] = ACTIONS(1558),
    [sym_true] = ACTIONS(1560),
    [sym_false] = ACTIONS(1560),
    [sym_null] = ACTIONS(1560),
    [sym_undefined] = ACTIONS(1560),
    [anon_sym_readonly] = ACTIONS(3115),
    [anon_sym_QMARK] = ACTIONS(3117),
    [anon_sym_any] = ACTIONS(216),
    [anon_sym_number] = ACTIONS(216),
    [anon_sym_boolean] = ACTIONS(216),
    [anon_sym_string] = ACTIONS(216),
    [anon_sym_symbol] = ACTIONS(216),
    [anon_sym_object] = ACTIONS(216),
    [anon_sym_abstract] = ACTIONS(3119),
    [anon_sym_infer] = ACTIONS(3123),
    [anon_sym_keyof] = ACTIONS(3125),
    [anon_sym_unique] = ACTIONS(214),
    [anon_sym_unknown] = ACTIONS(216),
    [anon_sym_never] = ACTIONS(216),
    [anon_sym_LBRACE_PIPE] = ACTIONS(3127),
    [sym_html_comment] = ACTIONS(5),
  },
  [1119] = {
    [sym_import] = STATE(4808),
    [sym_nested_identifier] = STATE(5474),
    [sym_string] = STATE(2994),
    [sym_formal_parameters] = STATE(5569),
    [sym_nested_type_identifier] = STATE(3487),
    [sym__type_query_member_expression_in_type_annotation] = STATE(3388),
    [sym__type_query_call_expression_in_type_annotation] = STATE(2938),
    [sym_type] = STATE(3824),
    [sym_constructor_type] = STATE(3007),
    [sym_primary_type] = STATE(2981),
    [sym_template_literal_type] = STATE(3039),
    [sym_infer_type] = STATE(3007),
    [sym_conditional_type] = STATE(3039),
    [sym_generic_type] = STATE(3039),
    [sym_type_query] = STATE(3039),
    [sym_index_type_query] = STATE(3039),
    [sym_lookup_type] = STATE(3039),
    [sym_literal_type] = STATE(3039),
    [sym__number] = STATE(3041),
    [sym_existential_type] = STATE(3039),
    [sym_flow_maybe_type] = STATE(3039),
    [sym_parenthesized_type] = STATE(3039),
    [sym_predefined_type] = STATE(3039),
    [sym_object_type] = STATE(3039),
    [sym_type_parameters] = STATE(5361),
    [sym_array_type] = STATE(3039),
    [sym_tuple_type] = STATE(3039),
    [sym_readonly_type] = STATE(3007),
    [sym_union_type] = STATE(3039),
    [sym_intersection_type] = STATE(3039),
    [sym_function_type] = STATE(3007),
    [sym_identifier] = ACTIONS(3263),
    [anon_sym_STAR] = ACTIONS(543),
    [anon_sym_LBRACE] = ACTIONS(3099),
    [anon_sym_typeof] = ACTIONS(3101),
    [anon_sym_import] = ACTIONS(1538),
    [anon_sym_const] = ACTIONS(133),
    [anon_sym_LPAREN] = ACTIONS(1540),
    [anon_sym_LBRACK] = ACTIONS(1542),
    [anon_sym_new] = ACTIONS(3103),
    [anon_sym_AMP] = ACTIONS(3105),
    [anon_sym_PIPE] = ACTIONS(3107),
    [anon_sym_PLUS] = ACTIONS(2497),
    [anon_sym_DASH] = ACTIONS(2497),
    [anon_sym_LT] = ACTIONS(2499),
    [anon_sym_void] = ACTIONS(216),
    [anon_sym_DQUOTE] = ACTIONS(3109),
    [anon_sym_SQUOTE] = ACTIONS(3111),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1554),
    [sym_number] = ACTIONS(1556),
    [sym_this] = ACTIONS(1558),
    [sym_true] = ACTIONS(1560),
    [sym_false] = ACTIONS(1560),
    [sym_null] = ACTIONS(1560),
    [sym_undefined] = ACTIONS(1560),
    [anon_sym_readonly] = ACTIONS(3115),
    [anon_sym_QMARK] = ACTIONS(3117),
    [anon_sym_any] = ACTIONS(216),
    [anon_sym_number] = ACTIONS(216),
    [anon_sym_boolean] = ACTIONS(216),
    [anon_sym_string] = ACTIONS(216),
    [anon_sym_symbol] = ACTIONS(216),
    [anon_sym_object] = ACTIONS(216),
    [anon_sym_abstract] = ACTIONS(3119),
    [anon_sym_infer] = ACTIONS(3123),
    [anon_sym_keyof] = ACTIONS(3125),
    [anon_sym_unique] = ACTIONS(214),
    [anon_sym_unknown] = ACTIONS(216),
    [anon_sym_never] = ACTIONS(216),
    [anon_sym_LBRACE_PIPE] = ACTIONS(3127),
    [sym_html_comment] = ACTIONS(5),
  },
  [1120] = {
    [sym_import] = STATE(4808),
    [sym_nested_identifier] = STATE(5474),
    [sym_string] = STATE(2994),
    [sym_formal_parameters] = STATE(5569),
    [sym_nested_type_identifier] = STATE(3487),
    [sym__type_query_member_expression_in_type_annotation] = STATE(3388),
    [sym__type_query_call_expression_in_type_annotation] = STATE(2938),
    [sym_type] = STATE(3763),
    [sym_constructor_type] = STATE(3007),
    [sym_primary_type] = STATE(2981),
    [sym_template_literal_type] = STATE(3039),
    [sym_infer_type] = STATE(3007),
    [sym_conditional_type] = STATE(3039),
    [sym_generic_type] = STATE(3039),
    [sym_type_query] = STATE(3039),
    [sym_index_type_query] = STATE(3039),
    [sym_lookup_type] = STATE(3039),
    [sym_literal_type] = STATE(3039),
    [sym__number] = STATE(3041),
    [sym_existential_type] = STATE(3039),
    [sym_flow_maybe_type] = STATE(3039),
    [sym_parenthesized_type] = STATE(3039),
    [sym_predefined_type] = STATE(3039),
    [sym_object_type] = STATE(3039),
    [sym_type_parameters] = STATE(5361),
    [sym_array_type] = STATE(3039),
    [sym_tuple_type] = STATE(3039),
    [sym_readonly_type] = STATE(3007),
    [sym_union_type] = STATE(3039),
    [sym_intersection_type] = STATE(3039),
    [sym_function_type] = STATE(3007),
    [sym_identifier] = ACTIONS(3263),
    [anon_sym_STAR] = ACTIONS(543),
    [anon_sym_LBRACE] = ACTIONS(3099),
    [anon_sym_typeof] = ACTIONS(3101),
    [anon_sym_import] = ACTIONS(1538),
    [anon_sym_const] = ACTIONS(133),
    [anon_sym_LPAREN] = ACTIONS(1540),
    [anon_sym_LBRACK] = ACTIONS(1542),
    [anon_sym_new] = ACTIONS(3103),
    [anon_sym_AMP] = ACTIONS(3105),
    [anon_sym_PIPE] = ACTIONS(3107),
    [anon_sym_PLUS] = ACTIONS(2497),
    [anon_sym_DASH] = ACTIONS(2497),
    [anon_sym_LT] = ACTIONS(2499),
    [anon_sym_void] = ACTIONS(216),
    [anon_sym_DQUOTE] = ACTIONS(3109),
    [anon_sym_SQUOTE] = ACTIONS(3111),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1554),
    [sym_number] = ACTIONS(1556),
    [sym_this] = ACTIONS(1558),
    [sym_true] = ACTIONS(1560),
    [sym_false] = ACTIONS(1560),
    [sym_null] = ACTIONS(1560),
    [sym_undefined] = ACTIONS(1560),
    [anon_sym_readonly] = ACTIONS(3115),
    [anon_sym_QMARK] = ACTIONS(3117),
    [anon_sym_any] = ACTIONS(216),
    [anon_sym_number] = ACTIONS(216),
    [anon_sym_boolean] = ACTIONS(216),
    [anon_sym_string] = ACTIONS(216),
    [anon_sym_symbol] = ACTIONS(216),
    [anon_sym_object] = ACTIONS(216),
    [anon_sym_abstract] = ACTIONS(3119),
    [anon_sym_infer] = ACTIONS(3123),
    [anon_sym_keyof] = ACTIONS(3125),
    [anon_sym_unique] = ACTIONS(214),
    [anon_sym_unknown] = ACTIONS(216),
    [anon_sym_never] = ACTIONS(216),
    [anon_sym_LBRACE_PIPE] = ACTIONS(3127),
    [sym_html_comment] = ACTIONS(5),
  },
  [1121] = {
    [sym_import] = STATE(4808),
    [sym_nested_identifier] = STATE(5474),
    [sym_string] = STATE(2994),
    [sym_formal_parameters] = STATE(5569),
    [sym_nested_type_identifier] = STATE(3487),
    [sym__type_query_member_expression_in_type_annotation] = STATE(3388),
    [sym__type_query_call_expression_in_type_annotation] = STATE(2938),
    [sym_type] = STATE(3766),
    [sym_constructor_type] = STATE(3007),
    [sym_primary_type] = STATE(2981),
    [sym_template_literal_type] = STATE(3039),
    [sym_infer_type] = STATE(3007),
    [sym_conditional_type] = STATE(3039),
    [sym_generic_type] = STATE(3039),
    [sym_type_query] = STATE(3039),
    [sym_index_type_query] = STATE(3039),
    [sym_lookup_type] = STATE(3039),
    [sym_literal_type] = STATE(3039),
    [sym__number] = STATE(3041),
    [sym_existential_type] = STATE(3039),
    [sym_flow_maybe_type] = STATE(3039),
    [sym_parenthesized_type] = STATE(3039),
    [sym_predefined_type] = STATE(3039),
    [sym_object_type] = STATE(3039),
    [sym_type_parameters] = STATE(5361),
    [sym_array_type] = STATE(3039),
    [sym_tuple_type] = STATE(3039),
    [sym_readonly_type] = STATE(3007),
    [sym_union_type] = STATE(3039),
    [sym_intersection_type] = STATE(3039),
    [sym_function_type] = STATE(3007),
    [sym_identifier] = ACTIONS(3263),
    [anon_sym_STAR] = ACTIONS(543),
    [anon_sym_LBRACE] = ACTIONS(3099),
    [anon_sym_typeof] = ACTIONS(3101),
    [anon_sym_import] = ACTIONS(1538),
    [anon_sym_const] = ACTIONS(133),
    [anon_sym_LPAREN] = ACTIONS(1540),
    [anon_sym_LBRACK] = ACTIONS(1542),
    [anon_sym_new] = ACTIONS(3103),
    [anon_sym_AMP] = ACTIONS(3105),
    [anon_sym_PIPE] = ACTIONS(3107),
    [anon_sym_PLUS] = ACTIONS(2497),
    [anon_sym_DASH] = ACTIONS(2497),
    [anon_sym_LT] = ACTIONS(2499),
    [anon_sym_void] = ACTIONS(216),
    [anon_sym_DQUOTE] = ACTIONS(3109),
    [anon_sym_SQUOTE] = ACTIONS(3111),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1554),
    [sym_number] = ACTIONS(1556),
    [sym_this] = ACTIONS(1558),
    [sym_true] = ACTIONS(1560),
    [sym_false] = ACTIONS(1560),
    [sym_null] = ACTIONS(1560),
    [sym_undefined] = ACTIONS(1560),
    [anon_sym_readonly] = ACTIONS(3115),
    [anon_sym_QMARK] = ACTIONS(3117),
    [anon_sym_any] = ACTIONS(216),
    [anon_sym_number] = ACTIONS(216),
    [anon_sym_boolean] = ACTIONS(216),
    [anon_sym_string] = ACTIONS(216),
    [anon_sym_symbol] = ACTIONS(216),
    [anon_sym_object] = ACTIONS(216),
    [anon_sym_abstract] = ACTIONS(3119),
    [anon_sym_infer] = ACTIONS(3123),
    [anon_sym_keyof] = ACTIONS(3125),
    [anon_sym_unique] = ACTIONS(214),
    [anon_sym_unknown] = ACTIONS(216),
    [anon_sym_never] = ACTIONS(216),
    [anon_sym_LBRACE_PIPE] = ACTIONS(3127),
    [sym_html_comment] = ACTIONS(5),
  },
  [1122] = {
    [sym_import] = STATE(4808),
    [sym_nested_identifier] = STATE(5474),
    [sym_string] = STATE(2994),
    [sym_formal_parameters] = STATE(5569),
    [sym_nested_type_identifier] = STATE(3487),
    [sym__type_query_member_expression_in_type_annotation] = STATE(3388),
    [sym__type_query_call_expression_in_type_annotation] = STATE(2938),
    [sym_type] = STATE(2955),
    [sym_constructor_type] = STATE(3007),
    [sym_primary_type] = STATE(2981),
    [sym_template_literal_type] = STATE(3039),
    [sym_infer_type] = STATE(3007),
    [sym_conditional_type] = STATE(3039),
    [sym_generic_type] = STATE(3039),
    [sym_type_query] = STATE(3039),
    [sym_index_type_query] = STATE(3039),
    [sym_lookup_type] = STATE(3039),
    [sym_literal_type] = STATE(3039),
    [sym__number] = STATE(3041),
    [sym_existential_type] = STATE(3039),
    [sym_flow_maybe_type] = STATE(3039),
    [sym_parenthesized_type] = STATE(3039),
    [sym_predefined_type] = STATE(3039),
    [sym_object_type] = STATE(3039),
    [sym_type_parameters] = STATE(5361),
    [sym_array_type] = STATE(3039),
    [sym_tuple_type] = STATE(3039),
    [sym_readonly_type] = STATE(3007),
    [sym_union_type] = STATE(3039),
    [sym_intersection_type] = STATE(3039),
    [sym_function_type] = STATE(3007),
    [sym_identifier] = ACTIONS(3263),
    [anon_sym_STAR] = ACTIONS(543),
    [anon_sym_LBRACE] = ACTIONS(3099),
    [anon_sym_typeof] = ACTIONS(3101),
    [anon_sym_import] = ACTIONS(1538),
    [anon_sym_const] = ACTIONS(133),
    [anon_sym_LPAREN] = ACTIONS(1540),
    [anon_sym_LBRACK] = ACTIONS(1542),
    [anon_sym_new] = ACTIONS(3103),
    [anon_sym_AMP] = ACTIONS(3105),
    [anon_sym_PIPE] = ACTIONS(3107),
    [anon_sym_PLUS] = ACTIONS(2497),
    [anon_sym_DASH] = ACTIONS(2497),
    [anon_sym_LT] = ACTIONS(2499),
    [anon_sym_void] = ACTIONS(216),
    [anon_sym_DQUOTE] = ACTIONS(3109),
    [anon_sym_SQUOTE] = ACTIONS(3111),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1554),
    [sym_number] = ACTIONS(1556),
    [sym_this] = ACTIONS(1558),
    [sym_true] = ACTIONS(1560),
    [sym_false] = ACTIONS(1560),
    [sym_null] = ACTIONS(1560),
    [sym_undefined] = ACTIONS(1560),
    [anon_sym_readonly] = ACTIONS(3115),
    [anon_sym_QMARK] = ACTIONS(3117),
    [anon_sym_any] = ACTIONS(216),
    [anon_sym_number] = ACTIONS(216),
    [anon_sym_boolean] = ACTIONS(216),
    [anon_sym_string] = ACTIONS(216),
    [anon_sym_symbol] = ACTIONS(216),
    [anon_sym_object] = ACTIONS(216),
    [anon_sym_abstract] = ACTIONS(3119),
    [anon_sym_infer] = ACTIONS(3123),
    [anon_sym_keyof] = ACTIONS(3125),
    [anon_sym_unique] = ACTIONS(214),
    [anon_sym_unknown] = ACTIONS(216),
    [anon_sym_never] = ACTIONS(216),
    [anon_sym_LBRACE_PIPE] = ACTIONS(3127),
    [sym_html_comment] = ACTIONS(5),
  },
  [1123] = {
    [sym_import] = STATE(4808),
    [sym_nested_identifier] = STATE(5474),
    [sym_string] = STATE(2994),
    [sym_formal_parameters] = STATE(5569),
    [sym_nested_type_identifier] = STATE(3487),
    [sym__type_query_member_expression_in_type_annotation] = STATE(3388),
    [sym__type_query_call_expression_in_type_annotation] = STATE(2938),
    [sym_type] = STATE(2972),
    [sym_constructor_type] = STATE(3007),
    [sym_primary_type] = STATE(2981),
    [sym_template_literal_type] = STATE(3039),
    [sym_infer_type] = STATE(3007),
    [sym_conditional_type] = STATE(3039),
    [sym_generic_type] = STATE(3039),
    [sym_type_query] = STATE(3039),
    [sym_index_type_query] = STATE(3039),
    [sym_lookup_type] = STATE(3039),
    [sym_literal_type] = STATE(3039),
    [sym__number] = STATE(3041),
    [sym_existential_type] = STATE(3039),
    [sym_flow_maybe_type] = STATE(3039),
    [sym_parenthesized_type] = STATE(3039),
    [sym_predefined_type] = STATE(3039),
    [sym_object_type] = STATE(3039),
    [sym_type_parameters] = STATE(5361),
    [sym_array_type] = STATE(3039),
    [sym_tuple_type] = STATE(3039),
    [sym_readonly_type] = STATE(3007),
    [sym_union_type] = STATE(3039),
    [sym_intersection_type] = STATE(3039),
    [sym_function_type] = STATE(3007),
    [sym_identifier] = ACTIONS(3263),
    [anon_sym_STAR] = ACTIONS(543),
    [anon_sym_LBRACE] = ACTIONS(3099),
    [anon_sym_typeof] = ACTIONS(3101),
    [anon_sym_import] = ACTIONS(1538),
    [anon_sym_const] = ACTIONS(133),
    [anon_sym_LPAREN] = ACTIONS(1540),
    [anon_sym_LBRACK] = ACTIONS(1542),
    [anon_sym_new] = ACTIONS(3103),
    [anon_sym_AMP] = ACTIONS(3105),
    [anon_sym_PIPE] = ACTIONS(3107),
    [anon_sym_PLUS] = ACTIONS(2497),
    [anon_sym_DASH] = ACTIONS(2497),
    [anon_sym_LT] = ACTIONS(2499),
    [anon_sym_void] = ACTIONS(216),
    [anon_sym_DQUOTE] = ACTIONS(3109),
    [anon_sym_SQUOTE] = ACTIONS(3111),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1554),
    [sym_number] = ACTIONS(1556),
    [sym_this] = ACTIONS(1558),
    [sym_true] = ACTIONS(1560),
    [sym_false] = ACTIONS(1560),
    [sym_null] = ACTIONS(1560),
    [sym_undefined] = ACTIONS(1560),
    [anon_sym_readonly] = ACTIONS(3115),
    [anon_sym_QMARK] = ACTIONS(3117),
    [anon_sym_any] = ACTIONS(216),
    [anon_sym_number] = ACTIONS(216),
    [anon_sym_boolean] = ACTIONS(216),
    [anon_sym_string] = ACTIONS(216),
    [anon_sym_symbol] = ACTIONS(216),
    [anon_sym_object] = ACTIONS(216),
    [anon_sym_abstract] = ACTIONS(3119),
    [anon_sym_infer] = ACTIONS(3123),
    [anon_sym_keyof] = ACTIONS(3125),
    [anon_sym_unique] = ACTIONS(214),
    [anon_sym_unknown] = ACTIONS(216),
    [anon_sym_never] = ACTIONS(216),
    [anon_sym_LBRACE_PIPE] = ACTIONS(3127),
    [sym_html_comment] = ACTIONS(5),
  },
  [1124] = {
    [sym_import] = STATE(4878),
    [sym_nested_identifier] = STATE(5474),
    [sym_string] = STATE(2994),
    [sym_formal_parameters] = STATE(5475),
    [sym_nested_type_identifier] = STATE(2939),
    [sym__type_query_member_expression_in_type_annotation] = STATE(2937),
    [sym__type_query_call_expression_in_type_annotation] = STATE(2938),
    [sym_type] = STATE(3856),
    [sym_constructor_type] = STATE(3007),
    [sym_primary_type] = STATE(2981),
    [sym_template_literal_type] = STATE(3039),
    [sym_infer_type] = STATE(3007),
    [sym_conditional_type] = STATE(3039),
    [sym_generic_type] = STATE(3039),
    [sym_type_query] = STATE(3039),
    [sym_index_type_query] = STATE(3039),
    [sym_lookup_type] = STATE(3039),
    [sym_literal_type] = STATE(3039),
    [sym__number] = STATE(3041),
    [sym_existential_type] = STATE(3039),
    [sym_flow_maybe_type] = STATE(3039),
    [sym_parenthesized_type] = STATE(3039),
    [sym_predefined_type] = STATE(3039),
    [sym_object_type] = STATE(3039),
    [sym_type_parameters] = STATE(5248),
    [sym_array_type] = STATE(3039),
    [sym_tuple_type] = STATE(3039),
    [sym_readonly_type] = STATE(3007),
    [sym_union_type] = STATE(3039),
    [sym_intersection_type] = STATE(3039),
    [sym_function_type] = STATE(3007),
    [sym_identifier] = ACTIONS(1532),
    [anon_sym_STAR] = ACTIONS(543),
    [anon_sym_LBRACE] = ACTIONS(1534),
    [anon_sym_typeof] = ACTIONS(1536),
    [anon_sym_import] = ACTIONS(1538),
    [anon_sym_const] = ACTIONS(133),
    [anon_sym_LPAREN] = ACTIONS(1540),
    [anon_sym_LBRACK] = ACTIONS(1542),
    [anon_sym_new] = ACTIONS(1544),
    [anon_sym_AMP] = ACTIONS(748),
    [anon_sym_PIPE] = ACTIONS(750),
    [anon_sym_PLUS] = ACTIONS(2497),
    [anon_sym_DASH] = ACTIONS(2497),
    [anon_sym_LT] = ACTIONS(2499),
    [anon_sym_void] = ACTIONS(216),
    [anon_sym_DQUOTE] = ACTIONS(1550),
    [anon_sym_SQUOTE] = ACTIONS(1552),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1554),
    [sym_number] = ACTIONS(1556),
    [sym_this] = ACTIONS(1558),
    [sym_true] = ACTIONS(1560),
    [sym_false] = ACTIONS(1560),
    [sym_null] = ACTIONS(1560),
    [sym_undefined] = ACTIONS(1560),
    [anon_sym_readonly] = ACTIONS(1562),
    [anon_sym_QMARK] = ACTIONS(774),
    [anon_sym_any] = ACTIONS(216),
    [anon_sym_number] = ACTIONS(216),
    [anon_sym_boolean] = ACTIONS(216),
    [anon_sym_string] = ACTIONS(216),
    [anon_sym_symbol] = ACTIONS(216),
    [anon_sym_object] = ACTIONS(216),
    [anon_sym_abstract] = ACTIONS(208),
    [anon_sym_infer] = ACTIONS(210),
    [anon_sym_keyof] = ACTIONS(212),
    [anon_sym_unique] = ACTIONS(214),
    [anon_sym_unknown] = ACTIONS(216),
    [anon_sym_never] = ACTIONS(216),
    [anon_sym_LBRACE_PIPE] = ACTIONS(218),
    [sym_html_comment] = ACTIONS(5),
  },
  [1125] = {
    [sym_import] = STATE(4878),
    [sym_nested_identifier] = STATE(5474),
    [sym_string] = STATE(2994),
    [sym_formal_parameters] = STATE(5475),
    [sym_nested_type_identifier] = STATE(2939),
    [sym__type_query_member_expression_in_type_annotation] = STATE(2937),
    [sym__type_query_call_expression_in_type_annotation] = STATE(2938),
    [sym_type] = STATE(4422),
    [sym_constructor_type] = STATE(3007),
    [sym_primary_type] = STATE(2981),
    [sym_template_literal_type] = STATE(3039),
    [sym_infer_type] = STATE(3007),
    [sym_conditional_type] = STATE(3039),
    [sym_generic_type] = STATE(3039),
    [sym_type_query] = STATE(3039),
    [sym_index_type_query] = STATE(3039),
    [sym_lookup_type] = STATE(3039),
    [sym_literal_type] = STATE(3039),
    [sym__number] = STATE(3041),
    [sym_existential_type] = STATE(3039),
    [sym_flow_maybe_type] = STATE(3039),
    [sym_parenthesized_type] = STATE(3039),
    [sym_predefined_type] = STATE(3039),
    [sym_object_type] = STATE(3039),
    [sym_type_parameters] = STATE(5248),
    [sym_array_type] = STATE(3039),
    [sym_tuple_type] = STATE(3039),
    [sym_readonly_type] = STATE(3007),
    [sym_union_type] = STATE(3039),
    [sym_intersection_type] = STATE(3039),
    [sym_function_type] = STATE(3007),
    [sym_identifier] = ACTIONS(1532),
    [anon_sym_STAR] = ACTIONS(543),
    [anon_sym_LBRACE] = ACTIONS(1534),
    [anon_sym_typeof] = ACTIONS(1536),
    [anon_sym_import] = ACTIONS(1538),
    [anon_sym_const] = ACTIONS(133),
    [anon_sym_LPAREN] = ACTIONS(1540),
    [anon_sym_LBRACK] = ACTIONS(1542),
    [anon_sym_new] = ACTIONS(1544),
    [anon_sym_AMP] = ACTIONS(748),
    [anon_sym_PIPE] = ACTIONS(750),
    [anon_sym_PLUS] = ACTIONS(2497),
    [anon_sym_DASH] = ACTIONS(2497),
    [anon_sym_LT] = ACTIONS(2499),
    [anon_sym_void] = ACTIONS(216),
    [anon_sym_DQUOTE] = ACTIONS(1550),
    [anon_sym_SQUOTE] = ACTIONS(1552),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1554),
    [sym_number] = ACTIONS(1556),
    [sym_this] = ACTIONS(1558),
    [sym_true] = ACTIONS(1560),
    [sym_false] = ACTIONS(1560),
    [sym_null] = ACTIONS(1560),
    [sym_undefined] = ACTIONS(1560),
    [anon_sym_readonly] = ACTIONS(1562),
    [anon_sym_QMARK] = ACTIONS(774),
    [anon_sym_any] = ACTIONS(216),
    [anon_sym_number] = ACTIONS(216),
    [anon_sym_boolean] = ACTIONS(216),
    [anon_sym_string] = ACTIONS(216),
    [anon_sym_symbol] = ACTIONS(216),
    [anon_sym_object] = ACTIONS(216),
    [anon_sym_abstract] = ACTIONS(208),
    [anon_sym_infer] = ACTIONS(210),
    [anon_sym_keyof] = ACTIONS(212),
    [anon_sym_unique] = ACTIONS(214),
    [anon_sym_unknown] = ACTIONS(216),
    [anon_sym_never] = ACTIONS(216),
    [anon_sym_LBRACE_PIPE] = ACTIONS(218),
    [sym_html_comment] = ACTIONS(5),
  },
  [1126] = {
    [sym_import] = STATE(4808),
    [sym_nested_identifier] = STATE(5474),
    [sym_string] = STATE(2994),
    [sym_formal_parameters] = STATE(5569),
    [sym_nested_type_identifier] = STATE(3487),
    [sym__type_query_member_expression_in_type_annotation] = STATE(3388),
    [sym__type_query_call_expression_in_type_annotation] = STATE(2938),
    [sym_type] = STATE(4306),
    [sym_constructor_type] = STATE(3007),
    [sym_primary_type] = STATE(2981),
    [sym_template_literal_type] = STATE(3039),
    [sym_infer_type] = STATE(3007),
    [sym_conditional_type] = STATE(3039),
    [sym_generic_type] = STATE(3039),
    [sym_type_query] = STATE(3039),
    [sym_index_type_query] = STATE(3039),
    [sym_lookup_type] = STATE(3039),
    [sym_literal_type] = STATE(3039),
    [sym__number] = STATE(3041),
    [sym_existential_type] = STATE(3039),
    [sym_flow_maybe_type] = STATE(3039),
    [sym_parenthesized_type] = STATE(3039),
    [sym_predefined_type] = STATE(3039),
    [sym_object_type] = STATE(3039),
    [sym_type_parameters] = STATE(5361),
    [sym_array_type] = STATE(3039),
    [sym_tuple_type] = STATE(3039),
    [sym_readonly_type] = STATE(3007),
    [sym_union_type] = STATE(3039),
    [sym_intersection_type] = STATE(3039),
    [sym_function_type] = STATE(3007),
    [sym_identifier] = ACTIONS(3263),
    [anon_sym_STAR] = ACTIONS(543),
    [anon_sym_LBRACE] = ACTIONS(3099),
    [anon_sym_typeof] = ACTIONS(3101),
    [anon_sym_import] = ACTIONS(1538),
    [anon_sym_const] = ACTIONS(133),
    [anon_sym_LPAREN] = ACTIONS(1540),
    [anon_sym_LBRACK] = ACTIONS(1542),
    [anon_sym_new] = ACTIONS(3103),
    [anon_sym_AMP] = ACTIONS(3105),
    [anon_sym_PIPE] = ACTIONS(3107),
    [anon_sym_PLUS] = ACTIONS(2497),
    [anon_sym_DASH] = ACTIONS(2497),
    [anon_sym_LT] = ACTIONS(2499),
    [anon_sym_void] = ACTIONS(216),
    [anon_sym_DQUOTE] = ACTIONS(3109),
    [anon_sym_SQUOTE] = ACTIONS(3111),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1554),
    [sym_number] = ACTIONS(1556),
    [sym_this] = ACTIONS(1558),
    [sym_true] = ACTIONS(1560),
    [sym_false] = ACTIONS(1560),
    [sym_null] = ACTIONS(1560),
    [sym_undefined] = ACTIONS(1560),
    [anon_sym_readonly] = ACTIONS(3115),
    [anon_sym_QMARK] = ACTIONS(3117),
    [anon_sym_any] = ACTIONS(216),
    [anon_sym_number] = ACTIONS(216),
    [anon_sym_boolean] = ACTIONS(216),
    [anon_sym_string] = ACTIONS(216),
    [anon_sym_symbol] = ACTIONS(216),
    [anon_sym_object] = ACTIONS(216),
    [anon_sym_abstract] = ACTIONS(3119),
    [anon_sym_infer] = ACTIONS(3123),
    [anon_sym_keyof] = ACTIONS(3125),
    [anon_sym_unique] = ACTIONS(214),
    [anon_sym_unknown] = ACTIONS(216),
    [anon_sym_never] = ACTIONS(216),
    [anon_sym_LBRACE_PIPE] = ACTIONS(3127),
    [sym_html_comment] = ACTIONS(5),
  },
  [1127] = {
    [sym_import] = STATE(4808),
    [sym_nested_identifier] = STATE(5474),
    [sym_string] = STATE(2994),
    [sym_formal_parameters] = STATE(5569),
    [sym_nested_type_identifier] = STATE(3487),
    [sym__type_query_member_expression_in_type_annotation] = STATE(3388),
    [sym__type_query_call_expression_in_type_annotation] = STATE(2938),
    [sym_type] = STATE(2962),
    [sym_constructor_type] = STATE(3007),
    [sym_primary_type] = STATE(2981),
    [sym_template_literal_type] = STATE(3039),
    [sym_infer_type] = STATE(3007),
    [sym_conditional_type] = STATE(3039),
    [sym_generic_type] = STATE(3039),
    [sym_type_query] = STATE(3039),
    [sym_index_type_query] = STATE(3039),
    [sym_lookup_type] = STATE(3039),
    [sym_literal_type] = STATE(3039),
    [sym__number] = STATE(3041),
    [sym_existential_type] = STATE(3039),
    [sym_flow_maybe_type] = STATE(3039),
    [sym_parenthesized_type] = STATE(3039),
    [sym_predefined_type] = STATE(3039),
    [sym_object_type] = STATE(3039),
    [sym_type_parameters] = STATE(5361),
    [sym_array_type] = STATE(3039),
    [sym_tuple_type] = STATE(3039),
    [sym_readonly_type] = STATE(3007),
    [sym_union_type] = STATE(3039),
    [sym_intersection_type] = STATE(3039),
    [sym_function_type] = STATE(3007),
    [sym_identifier] = ACTIONS(3263),
    [anon_sym_STAR] = ACTIONS(543),
    [anon_sym_LBRACE] = ACTIONS(3099),
    [anon_sym_typeof] = ACTIONS(3101),
    [anon_sym_import] = ACTIONS(1538),
    [anon_sym_const] = ACTIONS(133),
    [anon_sym_LPAREN] = ACTIONS(1540),
    [anon_sym_LBRACK] = ACTIONS(1542),
    [anon_sym_new] = ACTIONS(3103),
    [anon_sym_AMP] = ACTIONS(3105),
    [anon_sym_PIPE] = ACTIONS(3107),
    [anon_sym_PLUS] = ACTIONS(2497),
    [anon_sym_DASH] = ACTIONS(2497),
    [anon_sym_LT] = ACTIONS(2499),
    [anon_sym_void] = ACTIONS(216),
    [anon_sym_DQUOTE] = ACTIONS(3109),
    [anon_sym_SQUOTE] = ACTIONS(3111),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1554),
    [sym_number] = ACTIONS(1556),
    [sym_this] = ACTIONS(1558),
    [sym_true] = ACTIONS(1560),
    [sym_false] = ACTIONS(1560),
    [sym_null] = ACTIONS(1560),
    [sym_undefined] = ACTIONS(1560),
    [anon_sym_readonly] = ACTIONS(3115),
    [anon_sym_QMARK] = ACTIONS(3117),
    [anon_sym_any] = ACTIONS(216),
    [anon_sym_number] = ACTIONS(216),
    [anon_sym_boolean] = ACTIONS(216),
    [anon_sym_string] = ACTIONS(216),
    [anon_sym_symbol] = ACTIONS(216),
    [anon_sym_object] = ACTIONS(216),
    [anon_sym_abstract] = ACTIONS(3119),
    [anon_sym_infer] = ACTIONS(3123),
    [anon_sym_keyof] = ACTIONS(3125),
    [anon_sym_unique] = ACTIONS(214),
    [anon_sym_unknown] = ACTIONS(216),
    [anon_sym_never] = ACTIONS(216),
    [anon_sym_LBRACE_PIPE] = ACTIONS(3127),
    [sym_html_comment] = ACTIONS(5),
  },
  [1128] = {
    [sym_import] = STATE(4878),
    [sym_nested_identifier] = STATE(5474),
    [sym_string] = STATE(2994),
    [sym_formal_parameters] = STATE(5475),
    [sym_nested_type_identifier] = STATE(2939),
    [sym__type_query_member_expression_in_type_annotation] = STATE(2937),
    [sym__type_query_call_expression_in_type_annotation] = STATE(2938),
    [sym_type] = STATE(4424),
    [sym_constructor_type] = STATE(3007),
    [sym_primary_type] = STATE(2981),
    [sym_template_literal_type] = STATE(3039),
    [sym_infer_type] = STATE(3007),
    [sym_conditional_type] = STATE(3039),
    [sym_generic_type] = STATE(3039),
    [sym_type_query] = STATE(3039),
    [sym_index_type_query] = STATE(3039),
    [sym_lookup_type] = STATE(3039),
    [sym_literal_type] = STATE(3039),
    [sym__number] = STATE(3041),
    [sym_existential_type] = STATE(3039),
    [sym_flow_maybe_type] = STATE(3039),
    [sym_parenthesized_type] = STATE(3039),
    [sym_predefined_type] = STATE(3039),
    [sym_object_type] = STATE(3039),
    [sym_type_parameters] = STATE(5248),
    [sym_array_type] = STATE(3039),
    [sym_tuple_type] = STATE(3039),
    [sym_readonly_type] = STATE(3007),
    [sym_union_type] = STATE(3039),
    [sym_intersection_type] = STATE(3039),
    [sym_function_type] = STATE(3007),
    [sym_identifier] = ACTIONS(1532),
    [anon_sym_STAR] = ACTIONS(543),
    [anon_sym_LBRACE] = ACTIONS(1534),
    [anon_sym_typeof] = ACTIONS(1536),
    [anon_sym_import] = ACTIONS(1538),
    [anon_sym_const] = ACTIONS(133),
    [anon_sym_LPAREN] = ACTIONS(1540),
    [anon_sym_LBRACK] = ACTIONS(1542),
    [anon_sym_new] = ACTIONS(1544),
    [anon_sym_AMP] = ACTIONS(748),
    [anon_sym_PIPE] = ACTIONS(750),
    [anon_sym_PLUS] = ACTIONS(2497),
    [anon_sym_DASH] = ACTIONS(2497),
    [anon_sym_LT] = ACTIONS(2499),
    [anon_sym_void] = ACTIONS(216),
    [anon_sym_DQUOTE] = ACTIONS(1550),
    [anon_sym_SQUOTE] = ACTIONS(1552),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1554),
    [sym_number] = ACTIONS(1556),
    [sym_this] = ACTIONS(1558),
    [sym_true] = ACTIONS(1560),
    [sym_false] = ACTIONS(1560),
    [sym_null] = ACTIONS(1560),
    [sym_undefined] = ACTIONS(1560),
    [anon_sym_readonly] = ACTIONS(1562),
    [anon_sym_QMARK] = ACTIONS(774),
    [anon_sym_any] = ACTIONS(216),
    [anon_sym_number] = ACTIONS(216),
    [anon_sym_boolean] = ACTIONS(216),
    [anon_sym_string] = ACTIONS(216),
    [anon_sym_symbol] = ACTIONS(216),
    [anon_sym_object] = ACTIONS(216),
    [anon_sym_abstract] = ACTIONS(208),
    [anon_sym_infer] = ACTIONS(210),
    [anon_sym_keyof] = ACTIONS(212),
    [anon_sym_unique] = ACTIONS(214),
    [anon_sym_unknown] = ACTIONS(216),
    [anon_sym_never] = ACTIONS(216),
    [anon_sym_LBRACE_PIPE] = ACTIONS(218),
    [sym_html_comment] = ACTIONS(5),
  },
  [1129] = {
    [sym_import] = STATE(4808),
    [sym_nested_identifier] = STATE(5474),
    [sym_string] = STATE(2994),
    [sym_formal_parameters] = STATE(5569),
    [sym_nested_type_identifier] = STATE(3487),
    [sym__type_query_member_expression_in_type_annotation] = STATE(3388),
    [sym__type_query_call_expression_in_type_annotation] = STATE(2938),
    [sym_type] = STATE(3838),
    [sym_constructor_type] = STATE(3007),
    [sym_primary_type] = STATE(2981),
    [sym_template_literal_type] = STATE(3039),
    [sym_infer_type] = STATE(3007),
    [sym_conditional_type] = STATE(3039),
    [sym_generic_type] = STATE(3039),
    [sym_type_query] = STATE(3039),
    [sym_index_type_query] = STATE(3039),
    [sym_lookup_type] = STATE(3039),
    [sym_literal_type] = STATE(3039),
    [sym__number] = STATE(3041),
    [sym_existential_type] = STATE(3039),
    [sym_flow_maybe_type] = STATE(3039),
    [sym_parenthesized_type] = STATE(3039),
    [sym_predefined_type] = STATE(3039),
    [sym_object_type] = STATE(3039),
    [sym_type_parameters] = STATE(5361),
    [sym_array_type] = STATE(3039),
    [sym_tuple_type] = STATE(3039),
    [sym_readonly_type] = STATE(3007),
    [sym_union_type] = STATE(3039),
    [sym_intersection_type] = STATE(3039),
    [sym_function_type] = STATE(3007),
    [sym_identifier] = ACTIONS(3263),
    [anon_sym_STAR] = ACTIONS(543),
    [anon_sym_LBRACE] = ACTIONS(3099),
    [anon_sym_typeof] = ACTIONS(3101),
    [anon_sym_import] = ACTIONS(1538),
    [anon_sym_const] = ACTIONS(133),
    [anon_sym_LPAREN] = ACTIONS(1540),
    [anon_sym_LBRACK] = ACTIONS(1542),
    [anon_sym_new] = ACTIONS(3103),
    [anon_sym_AMP] = ACTIONS(3105),
    [anon_sym_PIPE] = ACTIONS(3107),
    [anon_sym_PLUS] = ACTIONS(2497),
    [anon_sym_DASH] = ACTIONS(2497),
    [anon_sym_LT] = ACTIONS(2499),
    [anon_sym_void] = ACTIONS(216),
    [anon_sym_DQUOTE] = ACTIONS(3109),
    [anon_sym_SQUOTE] = ACTIONS(3111),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1554),
    [sym_number] = ACTIONS(1556),
    [sym_this] = ACTIONS(1558),
    [sym_true] = ACTIONS(1560),
    [sym_false] = ACTIONS(1560),
    [sym_null] = ACTIONS(1560),
    [sym_undefined] = ACTIONS(1560),
    [anon_sym_readonly] = ACTIONS(3115),
    [anon_sym_QMARK] = ACTIONS(3117),
    [anon_sym_any] = ACTIONS(216),
    [anon_sym_number] = ACTIONS(216),
    [anon_sym_boolean] = ACTIONS(216),
    [anon_sym_string] = ACTIONS(216),
    [anon_sym_symbol] = ACTIONS(216),
    [anon_sym_object] = ACTIONS(216),
    [anon_sym_abstract] = ACTIONS(3119),
    [anon_sym_infer] = ACTIONS(3123),
    [anon_sym_keyof] = ACTIONS(3125),
    [anon_sym_unique] = ACTIONS(214),
    [anon_sym_unknown] = ACTIONS(216),
    [anon_sym_never] = ACTIONS(216),
    [anon_sym_LBRACE_PIPE] = ACTIONS(3127),
    [sym_html_comment] = ACTIONS(5),
  },
  [1130] = {
    [sym_import] = STATE(4681),
    [sym_nested_identifier] = STATE(5474),
    [sym_string] = STATE(2994),
    [sym_formal_parameters] = STATE(5619),
    [sym_nested_type_identifier] = STATE(2939),
    [sym__type_query_member_expression_in_type_annotation] = STATE(3303),
    [sym__type_query_call_expression_in_type_annotation] = STATE(2938),
    [sym_type] = STATE(3019),
    [sym_constructor_type] = STATE(3007),
    [sym_primary_type] = STATE(2981),
    [sym_template_literal_type] = STATE(3039),
    [sym_infer_type] = STATE(3007),
    [sym_conditional_type] = STATE(3039),
    [sym_generic_type] = STATE(3039),
    [sym_type_query] = STATE(3039),
    [sym_index_type_query] = STATE(3039),
    [sym_lookup_type] = STATE(3039),
    [sym_literal_type] = STATE(3039),
    [sym__number] = STATE(3041),
    [sym_existential_type] = STATE(3039),
    [sym_flow_maybe_type] = STATE(3039),
    [sym_parenthesized_type] = STATE(3039),
    [sym_predefined_type] = STATE(3039),
    [sym_object_type] = STATE(3039),
    [sym_type_parameters] = STATE(5454),
    [sym_array_type] = STATE(3039),
    [sym_tuple_type] = STATE(3039),
    [sym_readonly_type] = STATE(3007),
    [sym_union_type] = STATE(3039),
    [sym_intersection_type] = STATE(3039),
    [sym_function_type] = STATE(3007),
    [sym_identifier] = ACTIONS(1532),
    [anon_sym_STAR] = ACTIONS(543),
    [anon_sym_LBRACE] = ACTIONS(1534),
    [anon_sym_typeof] = ACTIONS(1536),
    [anon_sym_import] = ACTIONS(1538),
    [anon_sym_const] = ACTIONS(133),
    [anon_sym_LPAREN] = ACTIONS(1540),
    [anon_sym_LBRACK] = ACTIONS(1542),
    [anon_sym_new] = ACTIONS(1642),
    [anon_sym_AMP] = ACTIONS(571),
    [anon_sym_PIPE] = ACTIONS(573),
    [anon_sym_PLUS] = ACTIONS(2497),
    [anon_sym_DASH] = ACTIONS(2497),
    [anon_sym_LT] = ACTIONS(2499),
    [anon_sym_void] = ACTIONS(216),
    [anon_sym_DQUOTE] = ACTIONS(1550),
    [anon_sym_SQUOTE] = ACTIONS(1552),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1554),
    [sym_number] = ACTIONS(1556),
    [sym_this] = ACTIONS(1558),
    [sym_true] = ACTIONS(1560),
    [sym_false] = ACTIONS(1560),
    [sym_null] = ACTIONS(1560),
    [sym_undefined] = ACTIONS(1560),
    [anon_sym_readonly] = ACTIONS(1648),
    [anon_sym_QMARK] = ACTIONS(593),
    [anon_sym_any] = ACTIONS(216),
    [anon_sym_number] = ACTIONS(216),
    [anon_sym_boolean] = ACTIONS(216),
    [anon_sym_string] = ACTIONS(216),
    [anon_sym_symbol] = ACTIONS(216),
    [anon_sym_object] = ACTIONS(216),
    [anon_sym_abstract] = ACTIONS(597),
    [anon_sym_infer] = ACTIONS(599),
    [anon_sym_keyof] = ACTIONS(601),
    [anon_sym_unique] = ACTIONS(214),
    [anon_sym_unknown] = ACTIONS(216),
    [anon_sym_never] = ACTIONS(216),
    [anon_sym_LBRACE_PIPE] = ACTIONS(218),
    [sym_html_comment] = ACTIONS(5),
  },
  [1131] = {
    [sym_import] = STATE(4681),
    [sym_nested_identifier] = STATE(5474),
    [sym_string] = STATE(2994),
    [sym_formal_parameters] = STATE(5619),
    [sym_nested_type_identifier] = STATE(2939),
    [sym__type_query_member_expression_in_type_annotation] = STATE(3303),
    [sym__type_query_call_expression_in_type_annotation] = STATE(2938),
    [sym_type] = STATE(3660),
    [sym_constructor_type] = STATE(3007),
    [sym_primary_type] = STATE(2981),
    [sym_template_literal_type] = STATE(3039),
    [sym_infer_type] = STATE(3007),
    [sym_conditional_type] = STATE(3039),
    [sym_generic_type] = STATE(3039),
    [sym_type_query] = STATE(3039),
    [sym_index_type_query] = STATE(3039),
    [sym_lookup_type] = STATE(3039),
    [sym_literal_type] = STATE(3039),
    [sym__number] = STATE(3041),
    [sym_existential_type] = STATE(3039),
    [sym_flow_maybe_type] = STATE(3039),
    [sym_parenthesized_type] = STATE(3039),
    [sym_predefined_type] = STATE(3039),
    [sym_object_type] = STATE(3039),
    [sym_type_parameters] = STATE(5454),
    [sym_array_type] = STATE(3039),
    [sym_tuple_type] = STATE(3039),
    [sym_readonly_type] = STATE(3007),
    [sym_union_type] = STATE(3039),
    [sym_intersection_type] = STATE(3039),
    [sym_function_type] = STATE(3007),
    [sym_identifier] = ACTIONS(1532),
    [anon_sym_STAR] = ACTIONS(543),
    [anon_sym_LBRACE] = ACTIONS(1534),
    [anon_sym_typeof] = ACTIONS(1536),
    [anon_sym_import] = ACTIONS(1538),
    [anon_sym_const] = ACTIONS(133),
    [anon_sym_LPAREN] = ACTIONS(1540),
    [anon_sym_LBRACK] = ACTIONS(1542),
    [anon_sym_new] = ACTIONS(1642),
    [anon_sym_AMP] = ACTIONS(571),
    [anon_sym_PIPE] = ACTIONS(573),
    [anon_sym_PLUS] = ACTIONS(2497),
    [anon_sym_DASH] = ACTIONS(2497),
    [anon_sym_LT] = ACTIONS(2499),
    [anon_sym_void] = ACTIONS(216),
    [anon_sym_DQUOTE] = ACTIONS(1550),
    [anon_sym_SQUOTE] = ACTIONS(1552),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1554),
    [sym_number] = ACTIONS(1556),
    [sym_this] = ACTIONS(1558),
    [sym_true] = ACTIONS(1560),
    [sym_false] = ACTIONS(1560),
    [sym_null] = ACTIONS(1560),
    [sym_undefined] = ACTIONS(1560),
    [anon_sym_readonly] = ACTIONS(1648),
    [anon_sym_QMARK] = ACTIONS(593),
    [anon_sym_any] = ACTIONS(216),
    [anon_sym_number] = ACTIONS(216),
    [anon_sym_boolean] = ACTIONS(216),
    [anon_sym_string] = ACTIONS(216),
    [anon_sym_symbol] = ACTIONS(216),
    [anon_sym_object] = ACTIONS(216),
    [anon_sym_abstract] = ACTIONS(597),
    [anon_sym_infer] = ACTIONS(599),
    [anon_sym_keyof] = ACTIONS(601),
    [anon_sym_unique] = ACTIONS(214),
    [anon_sym_unknown] = ACTIONS(216),
    [anon_sym_never] = ACTIONS(216),
    [anon_sym_LBRACE_PIPE] = ACTIONS(218),
    [sym_html_comment] = ACTIONS(5),
  },
  [1132] = {
    [sym_import] = STATE(4681),
    [sym_nested_identifier] = STATE(5474),
    [sym_string] = STATE(2994),
    [sym_formal_parameters] = STATE(5619),
    [sym_nested_type_identifier] = STATE(2939),
    [sym__type_query_member_expression_in_type_annotation] = STATE(3303),
    [sym__type_query_call_expression_in_type_annotation] = STATE(2938),
    [sym_type] = STATE(3661),
    [sym_constructor_type] = STATE(3007),
    [sym_primary_type] = STATE(2981),
    [sym_template_literal_type] = STATE(3039),
    [sym_infer_type] = STATE(3007),
    [sym_conditional_type] = STATE(3039),
    [sym_generic_type] = STATE(3039),
    [sym_type_query] = STATE(3039),
    [sym_index_type_query] = STATE(3039),
    [sym_lookup_type] = STATE(3039),
    [sym_literal_type] = STATE(3039),
    [sym__number] = STATE(3041),
    [sym_existential_type] = STATE(3039),
    [sym_flow_maybe_type] = STATE(3039),
    [sym_parenthesized_type] = STATE(3039),
    [sym_predefined_type] = STATE(3039),
    [sym_object_type] = STATE(3039),
    [sym_type_parameters] = STATE(5454),
    [sym_array_type] = STATE(3039),
    [sym_tuple_type] = STATE(3039),
    [sym_readonly_type] = STATE(3007),
    [sym_union_type] = STATE(3039),
    [sym_intersection_type] = STATE(3039),
    [sym_function_type] = STATE(3007),
    [sym_identifier] = ACTIONS(1532),
    [anon_sym_STAR] = ACTIONS(543),
    [anon_sym_LBRACE] = ACTIONS(1534),
    [anon_sym_typeof] = ACTIONS(1536),
    [anon_sym_import] = ACTIONS(1538),
    [anon_sym_const] = ACTIONS(133),
    [anon_sym_LPAREN] = ACTIONS(1540),
    [anon_sym_LBRACK] = ACTIONS(1542),
    [anon_sym_new] = ACTIONS(1642),
    [anon_sym_AMP] = ACTIONS(571),
    [anon_sym_PIPE] = ACTIONS(573),
    [anon_sym_PLUS] = ACTIONS(2497),
    [anon_sym_DASH] = ACTIONS(2497),
    [anon_sym_LT] = ACTIONS(2499),
    [anon_sym_void] = ACTIONS(216),
    [anon_sym_DQUOTE] = ACTIONS(1550),
    [anon_sym_SQUOTE] = ACTIONS(1552),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1554),
    [sym_number] = ACTIONS(1556),
    [sym_this] = ACTIONS(1558),
    [sym_true] = ACTIONS(1560),
    [sym_false] = ACTIONS(1560),
    [sym_null] = ACTIONS(1560),
    [sym_undefined] = ACTIONS(1560),
    [anon_sym_readonly] = ACTIONS(1648),
    [anon_sym_QMARK] = ACTIONS(593),
    [anon_sym_any] = ACTIONS(216),
    [anon_sym_number] = ACTIONS(216),
    [anon_sym_boolean] = ACTIONS(216),
    [anon_sym_string] = ACTIONS(216),
    [anon_sym_symbol] = ACTIONS(216),
    [anon_sym_object] = ACTIONS(216),
    [anon_sym_abstract] = ACTIONS(597),
    [anon_sym_infer] = ACTIONS(599),
    [anon_sym_keyof] = ACTIONS(601),
    [anon_sym_unique] = ACTIONS(214),
    [anon_sym_unknown] = ACTIONS(216),
    [anon_sym_never] = ACTIONS(216),
    [anon_sym_LBRACE_PIPE] = ACTIONS(218),
    [sym_html_comment] = ACTIONS(5),
  },
  [1133] = {
    [sym_import] = STATE(4878),
    [sym_nested_identifier] = STATE(5474),
    [sym_string] = STATE(2994),
    [sym_formal_parameters] = STATE(5475),
    [sym_nested_type_identifier] = STATE(2939),
    [sym__type_query_member_expression_in_type_annotation] = STATE(2937),
    [sym__type_query_call_expression_in_type_annotation] = STATE(2938),
    [sym_type] = STATE(5022),
    [sym_constructor_type] = STATE(3007),
    [sym_primary_type] = STATE(2949),
    [sym_template_literal_type] = STATE(3039),
    [sym_infer_type] = STATE(3007),
    [sym_conditional_type] = STATE(3039),
    [sym_generic_type] = STATE(3039),
    [sym_type_query] = STATE(3039),
    [sym_index_type_query] = STATE(3039),
    [sym_lookup_type] = STATE(3039),
    [sym_literal_type] = STATE(3039),
    [sym__number] = STATE(3041),
    [sym_existential_type] = STATE(3039),
    [sym_flow_maybe_type] = STATE(3039),
    [sym_parenthesized_type] = STATE(3039),
    [sym_predefined_type] = STATE(3039),
    [sym_object_type] = STATE(3039),
    [sym_type_parameters] = STATE(5248),
    [sym_array_type] = STATE(3039),
    [sym_tuple_type] = STATE(3039),
    [sym_readonly_type] = STATE(3007),
    [sym_union_type] = STATE(3039),
    [sym_intersection_type] = STATE(3039),
    [sym_function_type] = STATE(3007),
    [sym_identifier] = ACTIONS(1532),
    [anon_sym_STAR] = ACTIONS(543),
    [anon_sym_LBRACE] = ACTIONS(1534),
    [anon_sym_typeof] = ACTIONS(1536),
    [anon_sym_import] = ACTIONS(1538),
    [anon_sym_const] = ACTIONS(133),
    [anon_sym_LPAREN] = ACTIONS(1540),
    [anon_sym_LBRACK] = ACTIONS(1542),
    [anon_sym_new] = ACTIONS(1544),
    [anon_sym_AMP] = ACTIONS(571),
    [anon_sym_PIPE] = ACTIONS(573),
    [anon_sym_PLUS] = ACTIONS(2497),
    [anon_sym_DASH] = ACTIONS(2497),
    [anon_sym_LT] = ACTIONS(2499),
    [anon_sym_void] = ACTIONS(216),
    [anon_sym_DQUOTE] = ACTIONS(1550),
    [anon_sym_SQUOTE] = ACTIONS(1552),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1554),
    [sym_number] = ACTIONS(1556),
    [sym_this] = ACTIONS(1558),
    [sym_true] = ACTIONS(1560),
    [sym_false] = ACTIONS(1560),
    [sym_null] = ACTIONS(1560),
    [sym_undefined] = ACTIONS(1560),
    [anon_sym_readonly] = ACTIONS(1562),
    [anon_sym_QMARK] = ACTIONS(593),
    [anon_sym_any] = ACTIONS(216),
    [anon_sym_number] = ACTIONS(216),
    [anon_sym_boolean] = ACTIONS(216),
    [anon_sym_string] = ACTIONS(216),
    [anon_sym_symbol] = ACTIONS(216),
    [anon_sym_object] = ACTIONS(216),
    [anon_sym_abstract] = ACTIONS(208),
    [anon_sym_infer] = ACTIONS(210),
    [anon_sym_keyof] = ACTIONS(601),
    [anon_sym_unique] = ACTIONS(214),
    [anon_sym_unknown] = ACTIONS(216),
    [anon_sym_never] = ACTIONS(216),
    [anon_sym_LBRACE_PIPE] = ACTIONS(218),
    [sym_html_comment] = ACTIONS(5),
  },
  [1134] = {
    [sym_import] = STATE(4878),
    [sym_nested_identifier] = STATE(5474),
    [sym_string] = STATE(2994),
    [sym_formal_parameters] = STATE(5475),
    [sym_nested_type_identifier] = STATE(2939),
    [sym__type_query_member_expression_in_type_annotation] = STATE(2937),
    [sym__type_query_call_expression_in_type_annotation] = STATE(2938),
    [sym_type] = STATE(5022),
    [sym_constructor_type] = STATE(3007),
    [sym_primary_type] = STATE(2971),
    [sym_template_literal_type] = STATE(3039),
    [sym_infer_type] = STATE(3007),
    [sym_conditional_type] = STATE(3039),
    [sym_generic_type] = STATE(3039),
    [sym_type_query] = STATE(3039),
    [sym_index_type_query] = STATE(3039),
    [sym_lookup_type] = STATE(3039),
    [sym_literal_type] = STATE(3039),
    [sym__number] = STATE(3041),
    [sym_existential_type] = STATE(3039),
    [sym_flow_maybe_type] = STATE(3039),
    [sym_parenthesized_type] = STATE(3039),
    [sym_predefined_type] = STATE(3039),
    [sym_object_type] = STATE(3039),
    [sym_type_parameters] = STATE(5248),
    [sym_array_type] = STATE(3039),
    [sym_tuple_type] = STATE(3039),
    [sym_readonly_type] = STATE(3007),
    [sym_union_type] = STATE(3039),
    [sym_intersection_type] = STATE(3039),
    [sym_function_type] = STATE(3007),
    [sym_identifier] = ACTIONS(1532),
    [anon_sym_STAR] = ACTIONS(543),
    [anon_sym_LBRACE] = ACTIONS(1534),
    [anon_sym_typeof] = ACTIONS(1536),
    [anon_sym_import] = ACTIONS(1538),
    [anon_sym_const] = ACTIONS(133),
    [anon_sym_LPAREN] = ACTIONS(1540),
    [anon_sym_LBRACK] = ACTIONS(1542),
    [anon_sym_new] = ACTIONS(1544),
    [anon_sym_AMP] = ACTIONS(571),
    [anon_sym_PIPE] = ACTIONS(573),
    [anon_sym_PLUS] = ACTIONS(2497),
    [anon_sym_DASH] = ACTIONS(2497),
    [anon_sym_LT] = ACTIONS(2499),
    [anon_sym_void] = ACTIONS(216),
    [anon_sym_DQUOTE] = ACTIONS(1550),
    [anon_sym_SQUOTE] = ACTIONS(1552),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1554),
    [sym_number] = ACTIONS(1556),
    [sym_this] = ACTIONS(1558),
    [sym_true] = ACTIONS(1560),
    [sym_false] = ACTIONS(1560),
    [sym_null] = ACTIONS(1560),
    [sym_undefined] = ACTIONS(1560),
    [anon_sym_readonly] = ACTIONS(1562),
    [anon_sym_QMARK] = ACTIONS(593),
    [anon_sym_any] = ACTIONS(216),
    [anon_sym_number] = ACTIONS(216),
    [anon_sym_boolean] = ACTIONS(216),
    [anon_sym_string] = ACTIONS(216),
    [anon_sym_symbol] = ACTIONS(216),
    [anon_sym_object] = ACTIONS(216),
    [anon_sym_abstract] = ACTIONS(208),
    [anon_sym_infer] = ACTIONS(210),
    [anon_sym_keyof] = ACTIONS(601),
    [anon_sym_unique] = ACTIONS(214),
    [anon_sym_unknown] = ACTIONS(216),
    [anon_sym_never] = ACTIONS(216),
    [anon_sym_LBRACE_PIPE] = ACTIONS(218),
    [sym_html_comment] = ACTIONS(5),
  },
  [1135] = {
    [sym_import] = STATE(4878),
    [sym_nested_identifier] = STATE(5474),
    [sym_string] = STATE(2994),
    [sym_formal_parameters] = STATE(5475),
    [sym_nested_type_identifier] = STATE(2939),
    [sym__type_query_member_expression_in_type_annotation] = STATE(2937),
    [sym__type_query_call_expression_in_type_annotation] = STATE(2938),
    [sym_type] = STATE(4391),
    [sym_constructor_type] = STATE(3007),
    [sym_primary_type] = STATE(2981),
    [sym_template_literal_type] = STATE(3039),
    [sym_infer_type] = STATE(3007),
    [sym_conditional_type] = STATE(3039),
    [sym_generic_type] = STATE(3039),
    [sym_type_query] = STATE(3039),
    [sym_index_type_query] = STATE(3039),
    [sym_lookup_type] = STATE(3039),
    [sym_literal_type] = STATE(3039),
    [sym__number] = STATE(3041),
    [sym_existential_type] = STATE(3039),
    [sym_flow_maybe_type] = STATE(3039),
    [sym_parenthesized_type] = STATE(3039),
    [sym_predefined_type] = STATE(3039),
    [sym_object_type] = STATE(3039),
    [sym_type_parameters] = STATE(5248),
    [sym_array_type] = STATE(3039),
    [sym_tuple_type] = STATE(3039),
    [sym_readonly_type] = STATE(3007),
    [sym_union_type] = STATE(3039),
    [sym_intersection_type] = STATE(3039),
    [sym_function_type] = STATE(3007),
    [sym_identifier] = ACTIONS(1532),
    [anon_sym_STAR] = ACTIONS(543),
    [anon_sym_LBRACE] = ACTIONS(1534),
    [anon_sym_typeof] = ACTIONS(1536),
    [anon_sym_import] = ACTIONS(1538),
    [anon_sym_const] = ACTIONS(133),
    [anon_sym_LPAREN] = ACTIONS(1540),
    [anon_sym_LBRACK] = ACTIONS(1542),
    [anon_sym_new] = ACTIONS(1544),
    [anon_sym_AMP] = ACTIONS(748),
    [anon_sym_PIPE] = ACTIONS(750),
    [anon_sym_PLUS] = ACTIONS(2497),
    [anon_sym_DASH] = ACTIONS(2497),
    [anon_sym_LT] = ACTIONS(2499),
    [anon_sym_void] = ACTIONS(216),
    [anon_sym_DQUOTE] = ACTIONS(1550),
    [anon_sym_SQUOTE] = ACTIONS(1552),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1554),
    [sym_number] = ACTIONS(1556),
    [sym_this] = ACTIONS(1558),
    [sym_true] = ACTIONS(1560),
    [sym_false] = ACTIONS(1560),
    [sym_null] = ACTIONS(1560),
    [sym_undefined] = ACTIONS(1560),
    [anon_sym_readonly] = ACTIONS(1562),
    [anon_sym_QMARK] = ACTIONS(774),
    [anon_sym_any] = ACTIONS(216),
    [anon_sym_number] = ACTIONS(216),
    [anon_sym_boolean] = ACTIONS(216),
    [anon_sym_string] = ACTIONS(216),
    [anon_sym_symbol] = ACTIONS(216),
    [anon_sym_object] = ACTIONS(216),
    [anon_sym_abstract] = ACTIONS(208),
    [anon_sym_infer] = ACTIONS(210),
    [anon_sym_keyof] = ACTIONS(212),
    [anon_sym_unique] = ACTIONS(214),
    [anon_sym_unknown] = ACTIONS(216),
    [anon_sym_never] = ACTIONS(216),
    [anon_sym_LBRACE_PIPE] = ACTIONS(218),
    [sym_html_comment] = ACTIONS(5),
  },
  [1136] = {
    [sym_import] = STATE(4950),
    [sym_nested_identifier] = STATE(5535),
    [sym_string] = STATE(3265),
    [sym_formal_parameters] = STATE(5840),
    [sym_nested_type_identifier] = STATE(3151),
    [sym__type_query_member_expression_in_type_annotation] = STATE(3076),
    [sym__type_query_call_expression_in_type_annotation] = STATE(3200),
    [sym_type] = STATE(3276),
    [sym_constructor_type] = STATE(3271),
    [sym_primary_type] = STATE(3272),
    [sym_template_literal_type] = STATE(3273),
    [sym_infer_type] = STATE(3271),
    [sym_conditional_type] = STATE(3273),
    [sym_generic_type] = STATE(3273),
    [sym_type_query] = STATE(3273),
    [sym_index_type_query] = STATE(3273),
    [sym_lookup_type] = STATE(3273),
    [sym_literal_type] = STATE(3273),
    [sym__number] = STATE(3274),
    [sym_existential_type] = STATE(3273),
    [sym_flow_maybe_type] = STATE(3273),
    [sym_parenthesized_type] = STATE(3273),
    [sym_predefined_type] = STATE(3273),
    [sym_object_type] = STATE(3273),
    [sym_type_parameters] = STATE(5146),
    [sym_array_type] = STATE(3273),
    [sym_tuple_type] = STATE(3273),
    [sym_readonly_type] = STATE(3271),
    [sym_union_type] = STATE(3273),
    [sym_intersection_type] = STATE(3273),
    [sym_function_type] = STATE(3271),
    [sym_identifier] = ACTIONS(1606),
    [anon_sym_STAR] = ACTIONS(986),
    [anon_sym_LBRACE] = ACTIONS(1610),
    [anon_sym_typeof] = ACTIONS(1612),
    [anon_sym_import] = ACTIONS(1538),
    [anon_sym_const] = ACTIONS(992),
    [anon_sym_LPAREN] = ACTIONS(1614),
    [anon_sym_LBRACK] = ACTIONS(1616),
    [anon_sym_new] = ACTIONS(1618),
    [anon_sym_AMP] = ACTIONS(1000),
    [anon_sym_PIPE] = ACTIONS(1002),
    [anon_sym_PLUS] = ACTIONS(2983),
    [anon_sym_DASH] = ACTIONS(2983),
    [anon_sym_LT] = ACTIONS(2499),
    [anon_sym_void] = ACTIONS(1032),
    [anon_sym_DQUOTE] = ACTIONS(1626),
    [anon_sym_SQUOTE] = ACTIONS(1628),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1630),
    [sym_number] = ACTIONS(1632),
    [sym_this] = ACTIONS(1634),
    [sym_true] = ACTIONS(1636),
    [sym_false] = ACTIONS(1636),
    [sym_null] = ACTIONS(1636),
    [sym_undefined] = ACTIONS(1636),
    [anon_sym_readonly] = ACTIONS(1638),
    [anon_sym_QMARK] = ACTIONS(1020),
    [anon_sym_any] = ACTIONS(1032),
    [anon_sym_number] = ACTIONS(1032),
    [anon_sym_boolean] = ACTIONS(1032),
    [anon_sym_string] = ACTIONS(1032),
    [anon_sym_symbol] = ACTIONS(1032),
    [anon_sym_object] = ACTIONS(1032),
    [anon_sym_abstract] = ACTIONS(1024),
    [anon_sym_infer] = ACTIONS(1026),
    [anon_sym_keyof] = ACTIONS(1028),
    [anon_sym_unique] = ACTIONS(1030),
    [anon_sym_unknown] = ACTIONS(1032),
    [anon_sym_never] = ACTIONS(1032),
    [anon_sym_LBRACE_PIPE] = ACTIONS(1034),
    [sym_html_comment] = ACTIONS(5),
  },
  [1137] = {
    [sym_import] = STATE(4950),
    [sym_nested_identifier] = STATE(5535),
    [sym_string] = STATE(3265),
    [sym_formal_parameters] = STATE(5840),
    [sym_nested_type_identifier] = STATE(3151),
    [sym__type_query_member_expression_in_type_annotation] = STATE(3076),
    [sym__type_query_call_expression_in_type_annotation] = STATE(3200),
    [sym_type] = STATE(3251),
    [sym_constructor_type] = STATE(3271),
    [sym_primary_type] = STATE(3272),
    [sym_template_literal_type] = STATE(3273),
    [sym_infer_type] = STATE(3271),
    [sym_conditional_type] = STATE(3273),
    [sym_generic_type] = STATE(3273),
    [sym_type_query] = STATE(3273),
    [sym_index_type_query] = STATE(3273),
    [sym_lookup_type] = STATE(3273),
    [sym_literal_type] = STATE(3273),
    [sym__number] = STATE(3274),
    [sym_existential_type] = STATE(3273),
    [sym_flow_maybe_type] = STATE(3273),
    [sym_parenthesized_type] = STATE(3273),
    [sym_predefined_type] = STATE(3273),
    [sym_object_type] = STATE(3273),
    [sym_type_parameters] = STATE(5146),
    [sym_array_type] = STATE(3273),
    [sym_tuple_type] = STATE(3273),
    [sym_readonly_type] = STATE(3271),
    [sym_union_type] = STATE(3273),
    [sym_intersection_type] = STATE(3273),
    [sym_function_type] = STATE(3271),
    [sym_identifier] = ACTIONS(1606),
    [anon_sym_STAR] = ACTIONS(986),
    [anon_sym_LBRACE] = ACTIONS(1610),
    [anon_sym_typeof] = ACTIONS(1612),
    [anon_sym_import] = ACTIONS(1538),
    [anon_sym_const] = ACTIONS(992),
    [anon_sym_LPAREN] = ACTIONS(1614),
    [anon_sym_LBRACK] = ACTIONS(1616),
    [anon_sym_new] = ACTIONS(1618),
    [anon_sym_AMP] = ACTIONS(1000),
    [anon_sym_PIPE] = ACTIONS(1002),
    [anon_sym_PLUS] = ACTIONS(2983),
    [anon_sym_DASH] = ACTIONS(2983),
    [anon_sym_LT] = ACTIONS(2499),
    [anon_sym_void] = ACTIONS(1032),
    [anon_sym_DQUOTE] = ACTIONS(1626),
    [anon_sym_SQUOTE] = ACTIONS(1628),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1630),
    [sym_number] = ACTIONS(1632),
    [sym_this] = ACTIONS(1634),
    [sym_true] = ACTIONS(1636),
    [sym_false] = ACTIONS(1636),
    [sym_null] = ACTIONS(1636),
    [sym_undefined] = ACTIONS(1636),
    [anon_sym_readonly] = ACTIONS(1638),
    [anon_sym_QMARK] = ACTIONS(1020),
    [anon_sym_any] = ACTIONS(1032),
    [anon_sym_number] = ACTIONS(1032),
    [anon_sym_boolean] = ACTIONS(1032),
    [anon_sym_string] = ACTIONS(1032),
    [anon_sym_symbol] = ACTIONS(1032),
    [anon_sym_object] = ACTIONS(1032),
    [anon_sym_abstract] = ACTIONS(1024),
    [anon_sym_infer] = ACTIONS(1026),
    [anon_sym_keyof] = ACTIONS(1028),
    [anon_sym_unique] = ACTIONS(1030),
    [anon_sym_unknown] = ACTIONS(1032),
    [anon_sym_never] = ACTIONS(1032),
    [anon_sym_LBRACE_PIPE] = ACTIONS(1034),
    [sym_html_comment] = ACTIONS(5),
  },
  [1138] = {
    [sym_import] = STATE(4650),
    [sym_nested_identifier] = STATE(5567),
    [sym_string] = STATE(1975),
    [sym_formal_parameters] = STATE(5527),
    [sym_nested_type_identifier] = STATE(1865),
    [sym__type_query_member_expression_in_type_annotation] = STATE(1781),
    [sym__type_query_call_expression_in_type_annotation] = STATE(1911),
    [sym_type] = STATE(1925),
    [sym_constructor_type] = STATE(1912),
    [sym_primary_type] = STATE(1915),
    [sym_template_literal_type] = STATE(1916),
    [sym_infer_type] = STATE(1912),
    [sym_conditional_type] = STATE(1916),
    [sym_generic_type] = STATE(1916),
    [sym_type_query] = STATE(1916),
    [sym_index_type_query] = STATE(1916),
    [sym_lookup_type] = STATE(1916),
    [sym_literal_type] = STATE(1916),
    [sym__number] = STATE(1918),
    [sym_existential_type] = STATE(1916),
    [sym_flow_maybe_type] = STATE(1916),
    [sym_parenthesized_type] = STATE(1916),
    [sym_predefined_type] = STATE(1916),
    [sym_object_type] = STATE(1916),
    [sym_type_parameters] = STATE(5243),
    [sym_array_type] = STATE(1916),
    [sym_tuple_type] = STATE(1916),
    [sym_readonly_type] = STATE(1912),
    [sym_union_type] = STATE(1916),
    [sym_intersection_type] = STATE(1916),
    [sym_function_type] = STATE(1912),
    [sym_identifier] = ACTIONS(3255),
    [anon_sym_STAR] = ACTIONS(3047),
    [anon_sym_LBRACE] = ACTIONS(3049),
    [anon_sym_typeof] = ACTIONS(3051),
    [anon_sym_import] = ACTIONS(1538),
    [anon_sym_const] = ACTIONS(3053),
    [anon_sym_LPAREN] = ACTIONS(3055),
    [anon_sym_LBRACK] = ACTIONS(3057),
    [anon_sym_new] = ACTIONS(3059),
    [anon_sym_AMP] = ACTIONS(3061),
    [anon_sym_PIPE] = ACTIONS(3063),
    [anon_sym_PLUS] = ACTIONS(3065),
    [anon_sym_DASH] = ACTIONS(3065),
    [anon_sym_LT] = ACTIONS(2499),
    [anon_sym_void] = ACTIONS(3067),
    [anon_sym_DQUOTE] = ACTIONS(83),
    [anon_sym_SQUOTE] = ACTIONS(85),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(3069),
    [sym_number] = ACTIONS(3071),
    [sym_this] = ACTIONS(3257),
    [sym_true] = ACTIONS(3075),
    [sym_false] = ACTIONS(3075),
    [sym_null] = ACTIONS(3075),
    [sym_undefined] = ACTIONS(3075),
    [anon_sym_readonly] = ACTIONS(3077),
    [anon_sym_QMARK] = ACTIONS(3079),
    [anon_sym_any] = ACTIONS(3067),
    [anon_sym_number] = ACTIONS(3067),
    [anon_sym_boolean] = ACTIONS(3067),
    [anon_sym_string] = ACTIONS(3067),
    [anon_sym_symbol] = ACTIONS(3067),
    [anon_sym_object] = ACTIONS(3067),
    [anon_sym_abstract] = ACTIONS(3081),
    [anon_sym_infer] = ACTIONS(3085),
    [anon_sym_keyof] = ACTIONS(3087),
    [anon_sym_unique] = ACTIONS(3089),
    [anon_sym_unknown] = ACTIONS(3067),
    [anon_sym_never] = ACTIONS(3067),
    [anon_sym_LBRACE_PIPE] = ACTIONS(3091),
    [sym_html_comment] = ACTIONS(5),
  },
  [1139] = {
    [sym_import] = STATE(4650),
    [sym_nested_identifier] = STATE(5567),
    [sym_string] = STATE(1975),
    [sym_formal_parameters] = STATE(5527),
    [sym_nested_type_identifier] = STATE(1865),
    [sym__type_query_member_expression_in_type_annotation] = STATE(1781),
    [sym__type_query_call_expression_in_type_annotation] = STATE(1911),
    [sym_type] = STATE(2110),
    [sym_constructor_type] = STATE(1912),
    [sym_primary_type] = STATE(1915),
    [sym_template_literal_type] = STATE(1916),
    [sym_infer_type] = STATE(1912),
    [sym_conditional_type] = STATE(1916),
    [sym_generic_type] = STATE(1916),
    [sym_type_query] = STATE(1916),
    [sym_index_type_query] = STATE(1916),
    [sym_lookup_type] = STATE(1916),
    [sym_literal_type] = STATE(1916),
    [sym__number] = STATE(1918),
    [sym_existential_type] = STATE(1916),
    [sym_flow_maybe_type] = STATE(1916),
    [sym_parenthesized_type] = STATE(1916),
    [sym_predefined_type] = STATE(1916),
    [sym_object_type] = STATE(1916),
    [sym_type_parameters] = STATE(5243),
    [sym_array_type] = STATE(1916),
    [sym_tuple_type] = STATE(1916),
    [sym_readonly_type] = STATE(1912),
    [sym_union_type] = STATE(1916),
    [sym_intersection_type] = STATE(1916),
    [sym_function_type] = STATE(1912),
    [sym_identifier] = ACTIONS(3255),
    [anon_sym_STAR] = ACTIONS(3047),
    [anon_sym_LBRACE] = ACTIONS(3049),
    [anon_sym_typeof] = ACTIONS(3051),
    [anon_sym_import] = ACTIONS(1538),
    [anon_sym_const] = ACTIONS(3053),
    [anon_sym_LPAREN] = ACTIONS(3055),
    [anon_sym_LBRACK] = ACTIONS(3057),
    [anon_sym_new] = ACTIONS(3059),
    [anon_sym_AMP] = ACTIONS(3061),
    [anon_sym_PIPE] = ACTIONS(3063),
    [anon_sym_PLUS] = ACTIONS(3065),
    [anon_sym_DASH] = ACTIONS(3065),
    [anon_sym_LT] = ACTIONS(2499),
    [anon_sym_void] = ACTIONS(3067),
    [anon_sym_DQUOTE] = ACTIONS(83),
    [anon_sym_SQUOTE] = ACTIONS(85),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(3069),
    [sym_number] = ACTIONS(3071),
    [sym_this] = ACTIONS(3257),
    [sym_true] = ACTIONS(3075),
    [sym_false] = ACTIONS(3075),
    [sym_null] = ACTIONS(3075),
    [sym_undefined] = ACTIONS(3075),
    [anon_sym_readonly] = ACTIONS(3077),
    [anon_sym_QMARK] = ACTIONS(3079),
    [anon_sym_any] = ACTIONS(3067),
    [anon_sym_number] = ACTIONS(3067),
    [anon_sym_boolean] = ACTIONS(3067),
    [anon_sym_string] = ACTIONS(3067),
    [anon_sym_symbol] = ACTIONS(3067),
    [anon_sym_object] = ACTIONS(3067),
    [anon_sym_abstract] = ACTIONS(3081),
    [anon_sym_infer] = ACTIONS(3085),
    [anon_sym_keyof] = ACTIONS(3087),
    [anon_sym_unique] = ACTIONS(3089),
    [anon_sym_unknown] = ACTIONS(3067),
    [anon_sym_never] = ACTIONS(3067),
    [anon_sym_LBRACE_PIPE] = ACTIONS(3091),
    [sym_html_comment] = ACTIONS(5),
  },
  [1140] = {
    [sym_import] = STATE(4650),
    [sym_nested_identifier] = STATE(5567),
    [sym_string] = STATE(1975),
    [sym_formal_parameters] = STATE(5527),
    [sym_nested_type_identifier] = STATE(1865),
    [sym__type_query_member_expression_in_type_annotation] = STATE(1781),
    [sym__type_query_call_expression_in_type_annotation] = STATE(1911),
    [sym_type] = STATE(2006),
    [sym_constructor_type] = STATE(1912),
    [sym_primary_type] = STATE(1915),
    [sym_template_literal_type] = STATE(1916),
    [sym_infer_type] = STATE(1912),
    [sym_conditional_type] = STATE(1916),
    [sym_generic_type] = STATE(1916),
    [sym_type_query] = STATE(1916),
    [sym_index_type_query] = STATE(1916),
    [sym_lookup_type] = STATE(1916),
    [sym_literal_type] = STATE(1916),
    [sym__number] = STATE(1918),
    [sym_existential_type] = STATE(1916),
    [sym_flow_maybe_type] = STATE(1916),
    [sym_parenthesized_type] = STATE(1916),
    [sym_predefined_type] = STATE(1916),
    [sym_object_type] = STATE(1916),
    [sym_type_parameters] = STATE(5243),
    [sym_array_type] = STATE(1916),
    [sym_tuple_type] = STATE(1916),
    [sym_readonly_type] = STATE(1912),
    [sym_union_type] = STATE(1916),
    [sym_intersection_type] = STATE(1916),
    [sym_function_type] = STATE(1912),
    [sym_identifier] = ACTIONS(3255),
    [anon_sym_STAR] = ACTIONS(3047),
    [anon_sym_LBRACE] = ACTIONS(3049),
    [anon_sym_typeof] = ACTIONS(3051),
    [anon_sym_import] = ACTIONS(1538),
    [anon_sym_const] = ACTIONS(3053),
    [anon_sym_LPAREN] = ACTIONS(3055),
    [anon_sym_LBRACK] = ACTIONS(3057),
    [anon_sym_new] = ACTIONS(3059),
    [anon_sym_AMP] = ACTIONS(3061),
    [anon_sym_PIPE] = ACTIONS(3063),
    [anon_sym_PLUS] = ACTIONS(3065),
    [anon_sym_DASH] = ACTIONS(3065),
    [anon_sym_LT] = ACTIONS(2499),
    [anon_sym_void] = ACTIONS(3067),
    [anon_sym_DQUOTE] = ACTIONS(83),
    [anon_sym_SQUOTE] = ACTIONS(85),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(3069),
    [sym_number] = ACTIONS(3071),
    [sym_this] = ACTIONS(3257),
    [sym_true] = ACTIONS(3075),
    [sym_false] = ACTIONS(3075),
    [sym_null] = ACTIONS(3075),
    [sym_undefined] = ACTIONS(3075),
    [anon_sym_readonly] = ACTIONS(3077),
    [anon_sym_QMARK] = ACTIONS(3079),
    [anon_sym_any] = ACTIONS(3067),
    [anon_sym_number] = ACTIONS(3067),
    [anon_sym_boolean] = ACTIONS(3067),
    [anon_sym_string] = ACTIONS(3067),
    [anon_sym_symbol] = ACTIONS(3067),
    [anon_sym_object] = ACTIONS(3067),
    [anon_sym_abstract] = ACTIONS(3081),
    [anon_sym_infer] = ACTIONS(3085),
    [anon_sym_keyof] = ACTIONS(3087),
    [anon_sym_unique] = ACTIONS(3089),
    [anon_sym_unknown] = ACTIONS(3067),
    [anon_sym_never] = ACTIONS(3067),
    [anon_sym_LBRACE_PIPE] = ACTIONS(3091),
    [sym_html_comment] = ACTIONS(5),
  },
  [1141] = {
    [sym_import] = STATE(4650),
    [sym_nested_identifier] = STATE(5567),
    [sym_string] = STATE(1975),
    [sym_formal_parameters] = STATE(5527),
    [sym_nested_type_identifier] = STATE(1865),
    [sym__type_query_member_expression_in_type_annotation] = STATE(1781),
    [sym__type_query_call_expression_in_type_annotation] = STATE(1911),
    [sym_type] = STATE(2042),
    [sym_constructor_type] = STATE(1912),
    [sym_primary_type] = STATE(1915),
    [sym_template_literal_type] = STATE(1916),
    [sym_infer_type] = STATE(1912),
    [sym_conditional_type] = STATE(1916),
    [sym_generic_type] = STATE(1916),
    [sym_type_query] = STATE(1916),
    [sym_index_type_query] = STATE(1916),
    [sym_lookup_type] = STATE(1916),
    [sym_literal_type] = STATE(1916),
    [sym__number] = STATE(1918),
    [sym_existential_type] = STATE(1916),
    [sym_flow_maybe_type] = STATE(1916),
    [sym_parenthesized_type] = STATE(1916),
    [sym_predefined_type] = STATE(1916),
    [sym_object_type] = STATE(1916),
    [sym_type_parameters] = STATE(5243),
    [sym_array_type] = STATE(1916),
    [sym_tuple_type] = STATE(1916),
    [sym_readonly_type] = STATE(1912),
    [sym_union_type] = STATE(1916),
    [sym_intersection_type] = STATE(1916),
    [sym_function_type] = STATE(1912),
    [sym_identifier] = ACTIONS(3255),
    [anon_sym_STAR] = ACTIONS(3047),
    [anon_sym_LBRACE] = ACTIONS(3049),
    [anon_sym_typeof] = ACTIONS(3051),
    [anon_sym_import] = ACTIONS(1538),
    [anon_sym_const] = ACTIONS(3053),
    [anon_sym_LPAREN] = ACTIONS(3055),
    [anon_sym_LBRACK] = ACTIONS(3057),
    [anon_sym_new] = ACTIONS(3059),
    [anon_sym_AMP] = ACTIONS(3061),
    [anon_sym_PIPE] = ACTIONS(3063),
    [anon_sym_PLUS] = ACTIONS(3065),
    [anon_sym_DASH] = ACTIONS(3065),
    [anon_sym_LT] = ACTIONS(2499),
    [anon_sym_void] = ACTIONS(3067),
    [anon_sym_DQUOTE] = ACTIONS(83),
    [anon_sym_SQUOTE] = ACTIONS(85),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(3069),
    [sym_number] = ACTIONS(3071),
    [sym_this] = ACTIONS(3257),
    [sym_true] = ACTIONS(3075),
    [sym_false] = ACTIONS(3075),
    [sym_null] = ACTIONS(3075),
    [sym_undefined] = ACTIONS(3075),
    [anon_sym_readonly] = ACTIONS(3077),
    [anon_sym_QMARK] = ACTIONS(3079),
    [anon_sym_any] = ACTIONS(3067),
    [anon_sym_number] = ACTIONS(3067),
    [anon_sym_boolean] = ACTIONS(3067),
    [anon_sym_string] = ACTIONS(3067),
    [anon_sym_symbol] = ACTIONS(3067),
    [anon_sym_object] = ACTIONS(3067),
    [anon_sym_abstract] = ACTIONS(3081),
    [anon_sym_infer] = ACTIONS(3085),
    [anon_sym_keyof] = ACTIONS(3087),
    [anon_sym_unique] = ACTIONS(3089),
    [anon_sym_unknown] = ACTIONS(3067),
    [anon_sym_never] = ACTIONS(3067),
    [anon_sym_LBRACE_PIPE] = ACTIONS(3091),
    [sym_html_comment] = ACTIONS(5),
  },
  [1142] = {
    [sym_import] = STATE(4878),
    [sym_nested_identifier] = STATE(5567),
    [sym_string] = STATE(1975),
    [sym_formal_parameters] = STATE(5475),
    [sym_nested_type_identifier] = STATE(1865),
    [sym__type_query_member_expression_in_type_annotation] = STATE(2937),
    [sym__type_query_call_expression_in_type_annotation] = STATE(2938),
    [sym_type] = STATE(4981),
    [sym_constructor_type] = STATE(3007),
    [sym_primary_type] = STATE(2043),
    [sym_template_literal_type] = STATE(1916),
    [sym_infer_type] = STATE(3007),
    [sym_conditional_type] = STATE(1916),
    [sym_generic_type] = STATE(1916),
    [sym_type_query] = STATE(1916),
    [sym_index_type_query] = STATE(1916),
    [sym_lookup_type] = STATE(1916),
    [sym_literal_type] = STATE(1916),
    [sym__number] = STATE(1918),
    [sym_existential_type] = STATE(1916),
    [sym_flow_maybe_type] = STATE(1916),
    [sym_parenthesized_type] = STATE(1916),
    [sym_predefined_type] = STATE(1916),
    [sym_object_type] = STATE(1916),
    [sym_type_parameters] = STATE(5248),
    [sym_array_type] = STATE(1916),
    [sym_tuple_type] = STATE(1916),
    [sym_readonly_type] = STATE(3007),
    [sym_union_type] = STATE(1916),
    [sym_intersection_type] = STATE(1916),
    [sym_function_type] = STATE(3007),
    [sym_identifier] = ACTIONS(3255),
    [anon_sym_STAR] = ACTIONS(3047),
    [anon_sym_LBRACE] = ACTIONS(3049),
    [anon_sym_typeof] = ACTIONS(3051),
    [anon_sym_import] = ACTIONS(1538),
    [anon_sym_const] = ACTIONS(3053),
    [anon_sym_LPAREN] = ACTIONS(3055),
    [anon_sym_LBRACK] = ACTIONS(3057),
    [anon_sym_new] = ACTIONS(1544),
    [anon_sym_AMP] = ACTIONS(3061),
    [anon_sym_PIPE] = ACTIONS(3063),
    [anon_sym_PLUS] = ACTIONS(3065),
    [anon_sym_DASH] = ACTIONS(3065),
    [anon_sym_LT] = ACTIONS(2499),
    [anon_sym_void] = ACTIONS(3067),
    [anon_sym_DQUOTE] = ACTIONS(83),
    [anon_sym_SQUOTE] = ACTIONS(85),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(3069),
    [sym_number] = ACTIONS(3071),
    [sym_this] = ACTIONS(3257),
    [sym_true] = ACTIONS(3075),
    [sym_false] = ACTIONS(3075),
    [sym_null] = ACTIONS(3075),
    [sym_undefined] = ACTIONS(3075),
    [anon_sym_readonly] = ACTIONS(1562),
    [anon_sym_QMARK] = ACTIONS(3079),
    [anon_sym_any] = ACTIONS(3067),
    [anon_sym_number] = ACTIONS(3067),
    [anon_sym_boolean] = ACTIONS(3067),
    [anon_sym_string] = ACTIONS(3067),
    [anon_sym_symbol] = ACTIONS(3067),
    [anon_sym_object] = ACTIONS(3067),
    [anon_sym_abstract] = ACTIONS(208),
    [anon_sym_infer] = ACTIONS(210),
    [anon_sym_keyof] = ACTIONS(3087),
    [anon_sym_unique] = ACTIONS(3089),
    [anon_sym_unknown] = ACTIONS(3067),
    [anon_sym_never] = ACTIONS(3067),
    [anon_sym_LBRACE_PIPE] = ACTIONS(3091),
    [sym_html_comment] = ACTIONS(5),
  },
  [1143] = {
    [sym_import] = STATE(4681),
    [sym_nested_identifier] = STATE(5474),
    [sym_string] = STATE(2994),
    [sym_formal_parameters] = STATE(5619),
    [sym_nested_type_identifier] = STATE(2939),
    [sym__type_query_member_expression_in_type_annotation] = STATE(3303),
    [sym__type_query_call_expression_in_type_annotation] = STATE(2938),
    [sym_type] = STATE(4448),
    [sym_constructor_type] = STATE(3007),
    [sym_primary_type] = STATE(2981),
    [sym_template_literal_type] = STATE(3039),
    [sym_infer_type] = STATE(3007),
    [sym_conditional_type] = STATE(3039),
    [sym_generic_type] = STATE(3039),
    [sym_type_query] = STATE(3039),
    [sym_index_type_query] = STATE(3039),
    [sym_lookup_type] = STATE(3039),
    [sym_literal_type] = STATE(3039),
    [sym__number] = STATE(3041),
    [sym_existential_type] = STATE(3039),
    [sym_flow_maybe_type] = STATE(3039),
    [sym_parenthesized_type] = STATE(3039),
    [sym_predefined_type] = STATE(3039),
    [sym_object_type] = STATE(3039),
    [sym_type_parameters] = STATE(5454),
    [sym_array_type] = STATE(3039),
    [sym_tuple_type] = STATE(3039),
    [sym_readonly_type] = STATE(3007),
    [sym_union_type] = STATE(3039),
    [sym_intersection_type] = STATE(3039),
    [sym_function_type] = STATE(3007),
    [sym_identifier] = ACTIONS(1532),
    [anon_sym_STAR] = ACTIONS(543),
    [anon_sym_LBRACE] = ACTIONS(1534),
    [anon_sym_typeof] = ACTIONS(1536),
    [anon_sym_import] = ACTIONS(1538),
    [anon_sym_const] = ACTIONS(133),
    [anon_sym_LPAREN] = ACTIONS(1540),
    [anon_sym_LBRACK] = ACTIONS(1542),
    [anon_sym_new] = ACTIONS(1642),
    [anon_sym_AMP] = ACTIONS(571),
    [anon_sym_PIPE] = ACTIONS(573),
    [anon_sym_PLUS] = ACTIONS(2497),
    [anon_sym_DASH] = ACTIONS(2497),
    [anon_sym_LT] = ACTIONS(2499),
    [anon_sym_void] = ACTIONS(216),
    [anon_sym_DQUOTE] = ACTIONS(1550),
    [anon_sym_SQUOTE] = ACTIONS(1552),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1554),
    [sym_number] = ACTIONS(1556),
    [sym_this] = ACTIONS(1558),
    [sym_true] = ACTIONS(1560),
    [sym_false] = ACTIONS(1560),
    [sym_null] = ACTIONS(1560),
    [sym_undefined] = ACTIONS(1560),
    [anon_sym_readonly] = ACTIONS(1648),
    [anon_sym_QMARK] = ACTIONS(593),
    [anon_sym_any] = ACTIONS(216),
    [anon_sym_number] = ACTIONS(216),
    [anon_sym_boolean] = ACTIONS(216),
    [anon_sym_string] = ACTIONS(216),
    [anon_sym_symbol] = ACTIONS(216),
    [anon_sym_object] = ACTIONS(216),
    [anon_sym_abstract] = ACTIONS(597),
    [anon_sym_infer] = ACTIONS(599),
    [anon_sym_keyof] = ACTIONS(601),
    [anon_sym_unique] = ACTIONS(214),
    [anon_sym_unknown] = ACTIONS(216),
    [anon_sym_never] = ACTIONS(216),
    [anon_sym_LBRACE_PIPE] = ACTIONS(218),
    [sym_html_comment] = ACTIONS(5),
  },
  [1144] = {
    [sym_import] = STATE(4878),
    [sym_nested_identifier] = STATE(5474),
    [sym_string] = STATE(2994),
    [sym_formal_parameters] = STATE(5475),
    [sym_nested_type_identifier] = STATE(2939),
    [sym__type_query_member_expression_in_type_annotation] = STATE(2937),
    [sym__type_query_call_expression_in_type_annotation] = STATE(2938),
    [sym_type] = STATE(4454),
    [sym_constructor_type] = STATE(3007),
    [sym_primary_type] = STATE(2981),
    [sym_template_literal_type] = STATE(3039),
    [sym_infer_type] = STATE(3007),
    [sym_conditional_type] = STATE(3039),
    [sym_generic_type] = STATE(3039),
    [sym_type_query] = STATE(3039),
    [sym_index_type_query] = STATE(3039),
    [sym_lookup_type] = STATE(3039),
    [sym_literal_type] = STATE(3039),
    [sym__number] = STATE(3041),
    [sym_existential_type] = STATE(3039),
    [sym_flow_maybe_type] = STATE(3039),
    [sym_parenthesized_type] = STATE(3039),
    [sym_predefined_type] = STATE(3039),
    [sym_object_type] = STATE(3039),
    [sym_type_parameters] = STATE(5248),
    [sym_array_type] = STATE(3039),
    [sym_tuple_type] = STATE(3039),
    [sym_readonly_type] = STATE(3007),
    [sym_union_type] = STATE(3039),
    [sym_intersection_type] = STATE(3039),
    [sym_function_type] = STATE(3007),
    [sym_identifier] = ACTIONS(1532),
    [anon_sym_STAR] = ACTIONS(543),
    [anon_sym_LBRACE] = ACTIONS(1534),
    [anon_sym_typeof] = ACTIONS(1536),
    [anon_sym_import] = ACTIONS(1538),
    [anon_sym_const] = ACTIONS(133),
    [anon_sym_LPAREN] = ACTIONS(1540),
    [anon_sym_LBRACK] = ACTIONS(1542),
    [anon_sym_new] = ACTIONS(1544),
    [anon_sym_AMP] = ACTIONS(748),
    [anon_sym_PIPE] = ACTIONS(750),
    [anon_sym_PLUS] = ACTIONS(2497),
    [anon_sym_DASH] = ACTIONS(2497),
    [anon_sym_LT] = ACTIONS(2499),
    [anon_sym_void] = ACTIONS(216),
    [anon_sym_DQUOTE] = ACTIONS(1550),
    [anon_sym_SQUOTE] = ACTIONS(1552),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1554),
    [sym_number] = ACTIONS(1556),
    [sym_this] = ACTIONS(1558),
    [sym_true] = ACTIONS(1560),
    [sym_false] = ACTIONS(1560),
    [sym_null] = ACTIONS(1560),
    [sym_undefined] = ACTIONS(1560),
    [anon_sym_readonly] = ACTIONS(1562),
    [anon_sym_QMARK] = ACTIONS(774),
    [anon_sym_any] = ACTIONS(216),
    [anon_sym_number] = ACTIONS(216),
    [anon_sym_boolean] = ACTIONS(216),
    [anon_sym_string] = ACTIONS(216),
    [anon_sym_symbol] = ACTIONS(216),
    [anon_sym_object] = ACTIONS(216),
    [anon_sym_abstract] = ACTIONS(208),
    [anon_sym_infer] = ACTIONS(210),
    [anon_sym_keyof] = ACTIONS(212),
    [anon_sym_unique] = ACTIONS(214),
    [anon_sym_unknown] = ACTIONS(216),
    [anon_sym_never] = ACTIONS(216),
    [anon_sym_LBRACE_PIPE] = ACTIONS(218),
    [sym_html_comment] = ACTIONS(5),
  },
  [1145] = {
    [sym_import] = STATE(4878),
    [sym_nested_identifier] = STATE(5567),
    [sym_string] = STATE(1975),
    [sym_formal_parameters] = STATE(5475),
    [sym_nested_type_identifier] = STATE(1865),
    [sym__type_query_member_expression_in_type_annotation] = STATE(2937),
    [sym__type_query_call_expression_in_type_annotation] = STATE(2938),
    [sym_type] = STATE(4981),
    [sym_constructor_type] = STATE(3007),
    [sym_primary_type] = STATE(2045),
    [sym_template_literal_type] = STATE(1916),
    [sym_infer_type] = STATE(3007),
    [sym_conditional_type] = STATE(1916),
    [sym_generic_type] = STATE(1916),
    [sym_type_query] = STATE(1916),
    [sym_index_type_query] = STATE(1916),
    [sym_lookup_type] = STATE(1916),
    [sym_literal_type] = STATE(1916),
    [sym__number] = STATE(1918),
    [sym_existential_type] = STATE(1916),
    [sym_flow_maybe_type] = STATE(1916),
    [sym_parenthesized_type] = STATE(1916),
    [sym_predefined_type] = STATE(1916),
    [sym_object_type] = STATE(1916),
    [sym_type_parameters] = STATE(5248),
    [sym_array_type] = STATE(1916),
    [sym_tuple_type] = STATE(1916),
    [sym_readonly_type] = STATE(3007),
    [sym_union_type] = STATE(1916),
    [sym_intersection_type] = STATE(1916),
    [sym_function_type] = STATE(3007),
    [sym_identifier] = ACTIONS(3255),
    [anon_sym_STAR] = ACTIONS(3047),
    [anon_sym_LBRACE] = ACTIONS(3049),
    [anon_sym_typeof] = ACTIONS(3051),
    [anon_sym_import] = ACTIONS(1538),
    [anon_sym_const] = ACTIONS(3053),
    [anon_sym_LPAREN] = ACTIONS(3055),
    [anon_sym_LBRACK] = ACTIONS(3057),
    [anon_sym_new] = ACTIONS(1544),
    [anon_sym_AMP] = ACTIONS(3061),
    [anon_sym_PIPE] = ACTIONS(3063),
    [anon_sym_PLUS] = ACTIONS(3065),
    [anon_sym_DASH] = ACTIONS(3065),
    [anon_sym_LT] = ACTIONS(2499),
    [anon_sym_void] = ACTIONS(3067),
    [anon_sym_DQUOTE] = ACTIONS(83),
    [anon_sym_SQUOTE] = ACTIONS(85),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(3069),
    [sym_number] = ACTIONS(3071),
    [sym_this] = ACTIONS(3257),
    [sym_true] = ACTIONS(3075),
    [sym_false] = ACTIONS(3075),
    [sym_null] = ACTIONS(3075),
    [sym_undefined] = ACTIONS(3075),
    [anon_sym_readonly] = ACTIONS(1562),
    [anon_sym_QMARK] = ACTIONS(3079),
    [anon_sym_any] = ACTIONS(3067),
    [anon_sym_number] = ACTIONS(3067),
    [anon_sym_boolean] = ACTIONS(3067),
    [anon_sym_string] = ACTIONS(3067),
    [anon_sym_symbol] = ACTIONS(3067),
    [anon_sym_object] = ACTIONS(3067),
    [anon_sym_abstract] = ACTIONS(208),
    [anon_sym_infer] = ACTIONS(210),
    [anon_sym_keyof] = ACTIONS(3087),
    [anon_sym_unique] = ACTIONS(3089),
    [anon_sym_unknown] = ACTIONS(3067),
    [anon_sym_never] = ACTIONS(3067),
    [anon_sym_LBRACE_PIPE] = ACTIONS(3091),
    [sym_html_comment] = ACTIONS(5),
  },
  [1146] = {
    [sym_import] = STATE(4681),
    [sym_nested_identifier] = STATE(5474),
    [sym_string] = STATE(2994),
    [sym_formal_parameters] = STATE(5619),
    [sym_nested_type_identifier] = STATE(2939),
    [sym__type_query_member_expression_in_type_annotation] = STATE(3303),
    [sym__type_query_call_expression_in_type_annotation] = STATE(2938),
    [sym_type] = STATE(4489),
    [sym_constructor_type] = STATE(3007),
    [sym_primary_type] = STATE(2981),
    [sym_template_literal_type] = STATE(3039),
    [sym_infer_type] = STATE(3007),
    [sym_conditional_type] = STATE(3039),
    [sym_generic_type] = STATE(3039),
    [sym_type_query] = STATE(3039),
    [sym_index_type_query] = STATE(3039),
    [sym_lookup_type] = STATE(3039),
    [sym_literal_type] = STATE(3039),
    [sym__number] = STATE(3041),
    [sym_existential_type] = STATE(3039),
    [sym_flow_maybe_type] = STATE(3039),
    [sym_parenthesized_type] = STATE(3039),
    [sym_predefined_type] = STATE(3039),
    [sym_object_type] = STATE(3039),
    [sym_type_parameters] = STATE(5454),
    [sym_array_type] = STATE(3039),
    [sym_tuple_type] = STATE(3039),
    [sym_readonly_type] = STATE(3007),
    [sym_union_type] = STATE(3039),
    [sym_intersection_type] = STATE(3039),
    [sym_function_type] = STATE(3007),
    [sym_identifier] = ACTIONS(1532),
    [anon_sym_STAR] = ACTIONS(543),
    [anon_sym_LBRACE] = ACTIONS(1534),
    [anon_sym_typeof] = ACTIONS(1536),
    [anon_sym_import] = ACTIONS(1538),
    [anon_sym_const] = ACTIONS(133),
    [anon_sym_LPAREN] = ACTIONS(1540),
    [anon_sym_LBRACK] = ACTIONS(1542),
    [anon_sym_new] = ACTIONS(1642),
    [anon_sym_AMP] = ACTIONS(571),
    [anon_sym_PIPE] = ACTIONS(573),
    [anon_sym_PLUS] = ACTIONS(2497),
    [anon_sym_DASH] = ACTIONS(2497),
    [anon_sym_LT] = ACTIONS(2499),
    [anon_sym_void] = ACTIONS(216),
    [anon_sym_DQUOTE] = ACTIONS(1550),
    [anon_sym_SQUOTE] = ACTIONS(1552),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1554),
    [sym_number] = ACTIONS(1556),
    [sym_this] = ACTIONS(1558),
    [sym_true] = ACTIONS(1560),
    [sym_false] = ACTIONS(1560),
    [sym_null] = ACTIONS(1560),
    [sym_undefined] = ACTIONS(1560),
    [anon_sym_readonly] = ACTIONS(1648),
    [anon_sym_QMARK] = ACTIONS(593),
    [anon_sym_any] = ACTIONS(216),
    [anon_sym_number] = ACTIONS(216),
    [anon_sym_boolean] = ACTIONS(216),
    [anon_sym_string] = ACTIONS(216),
    [anon_sym_symbol] = ACTIONS(216),
    [anon_sym_object] = ACTIONS(216),
    [anon_sym_abstract] = ACTIONS(597),
    [anon_sym_infer] = ACTIONS(599),
    [anon_sym_keyof] = ACTIONS(601),
    [anon_sym_unique] = ACTIONS(214),
    [anon_sym_unknown] = ACTIONS(216),
    [anon_sym_never] = ACTIONS(216),
    [anon_sym_LBRACE_PIPE] = ACTIONS(218),
    [sym_html_comment] = ACTIONS(5),
  },
  [1147] = {
    [sym_import] = STATE(4681),
    [sym_nested_identifier] = STATE(5474),
    [sym_string] = STATE(2994),
    [sym_formal_parameters] = STATE(5619),
    [sym_nested_type_identifier] = STATE(2939),
    [sym__type_query_member_expression_in_type_annotation] = STATE(3303),
    [sym__type_query_call_expression_in_type_annotation] = STATE(2938),
    [sym_type] = STATE(4492),
    [sym_constructor_type] = STATE(3007),
    [sym_primary_type] = STATE(2981),
    [sym_template_literal_type] = STATE(3039),
    [sym_infer_type] = STATE(3007),
    [sym_conditional_type] = STATE(3039),
    [sym_generic_type] = STATE(3039),
    [sym_type_query] = STATE(3039),
    [sym_index_type_query] = STATE(3039),
    [sym_lookup_type] = STATE(3039),
    [sym_literal_type] = STATE(3039),
    [sym__number] = STATE(3041),
    [sym_existential_type] = STATE(3039),
    [sym_flow_maybe_type] = STATE(3039),
    [sym_parenthesized_type] = STATE(3039),
    [sym_predefined_type] = STATE(3039),
    [sym_object_type] = STATE(3039),
    [sym_type_parameters] = STATE(5454),
    [sym_array_type] = STATE(3039),
    [sym_tuple_type] = STATE(3039),
    [sym_readonly_type] = STATE(3007),
    [sym_union_type] = STATE(3039),
    [sym_intersection_type] = STATE(3039),
    [sym_function_type] = STATE(3007),
    [sym_identifier] = ACTIONS(1532),
    [anon_sym_STAR] = ACTIONS(543),
    [anon_sym_LBRACE] = ACTIONS(1534),
    [anon_sym_typeof] = ACTIONS(1536),
    [anon_sym_import] = ACTIONS(1538),
    [anon_sym_const] = ACTIONS(133),
    [anon_sym_LPAREN] = ACTIONS(1540),
    [anon_sym_LBRACK] = ACTIONS(1542),
    [anon_sym_new] = ACTIONS(1642),
    [anon_sym_AMP] = ACTIONS(571),
    [anon_sym_PIPE] = ACTIONS(573),
    [anon_sym_PLUS] = ACTIONS(2497),
    [anon_sym_DASH] = ACTIONS(2497),
    [anon_sym_LT] = ACTIONS(2499),
    [anon_sym_void] = ACTIONS(216),
    [anon_sym_DQUOTE] = ACTIONS(1550),
    [anon_sym_SQUOTE] = ACTIONS(1552),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1554),
    [sym_number] = ACTIONS(1556),
    [sym_this] = ACTIONS(1558),
    [sym_true] = ACTIONS(1560),
    [sym_false] = ACTIONS(1560),
    [sym_null] = ACTIONS(1560),
    [sym_undefined] = ACTIONS(1560),
    [anon_sym_readonly] = ACTIONS(1648),
    [anon_sym_QMARK] = ACTIONS(593),
    [anon_sym_any] = ACTIONS(216),
    [anon_sym_number] = ACTIONS(216),
    [anon_sym_boolean] = ACTIONS(216),
    [anon_sym_string] = ACTIONS(216),
    [anon_sym_symbol] = ACTIONS(216),
    [anon_sym_object] = ACTIONS(216),
    [anon_sym_abstract] = ACTIONS(597),
    [anon_sym_infer] = ACTIONS(599),
    [anon_sym_keyof] = ACTIONS(601),
    [anon_sym_unique] = ACTIONS(214),
    [anon_sym_unknown] = ACTIONS(216),
    [anon_sym_never] = ACTIONS(216),
    [anon_sym_LBRACE_PIPE] = ACTIONS(218),
    [sym_html_comment] = ACTIONS(5),
  },
  [1148] = {
    [sym_import] = STATE(4681),
    [sym_nested_identifier] = STATE(5474),
    [sym_string] = STATE(2994),
    [sym_formal_parameters] = STATE(5619),
    [sym_nested_type_identifier] = STATE(2939),
    [sym__type_query_member_expression_in_type_annotation] = STATE(3303),
    [sym__type_query_call_expression_in_type_annotation] = STATE(2938),
    [sym_type] = STATE(4497),
    [sym_constructor_type] = STATE(3007),
    [sym_primary_type] = STATE(2981),
    [sym_template_literal_type] = STATE(3039),
    [sym_infer_type] = STATE(3007),
    [sym_conditional_type] = STATE(3039),
    [sym_generic_type] = STATE(3039),
    [sym_type_query] = STATE(3039),
    [sym_index_type_query] = STATE(3039),
    [sym_lookup_type] = STATE(3039),
    [sym_literal_type] = STATE(3039),
    [sym__number] = STATE(3041),
    [sym_existential_type] = STATE(3039),
    [sym_flow_maybe_type] = STATE(3039),
    [sym_parenthesized_type] = STATE(3039),
    [sym_predefined_type] = STATE(3039),
    [sym_object_type] = STATE(3039),
    [sym_type_parameters] = STATE(5454),
    [sym_array_type] = STATE(3039),
    [sym_tuple_type] = STATE(3039),
    [sym_readonly_type] = STATE(3007),
    [sym_union_type] = STATE(3039),
    [sym_intersection_type] = STATE(3039),
    [sym_function_type] = STATE(3007),
    [sym_identifier] = ACTIONS(1532),
    [anon_sym_STAR] = ACTIONS(543),
    [anon_sym_LBRACE] = ACTIONS(1534),
    [anon_sym_typeof] = ACTIONS(1536),
    [anon_sym_import] = ACTIONS(1538),
    [anon_sym_const] = ACTIONS(133),
    [anon_sym_LPAREN] = ACTIONS(1540),
    [anon_sym_LBRACK] = ACTIONS(1542),
    [anon_sym_new] = ACTIONS(1642),
    [anon_sym_AMP] = ACTIONS(571),
    [anon_sym_PIPE] = ACTIONS(573),
    [anon_sym_PLUS] = ACTIONS(2497),
    [anon_sym_DASH] = ACTIONS(2497),
    [anon_sym_LT] = ACTIONS(2499),
    [anon_sym_void] = ACTIONS(216),
    [anon_sym_DQUOTE] = ACTIONS(1550),
    [anon_sym_SQUOTE] = ACTIONS(1552),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1554),
    [sym_number] = ACTIONS(1556),
    [sym_this] = ACTIONS(1558),
    [sym_true] = ACTIONS(1560),
    [sym_false] = ACTIONS(1560),
    [sym_null] = ACTIONS(1560),
    [sym_undefined] = ACTIONS(1560),
    [anon_sym_readonly] = ACTIONS(1648),
    [anon_sym_QMARK] = ACTIONS(593),
    [anon_sym_any] = ACTIONS(216),
    [anon_sym_number] = ACTIONS(216),
    [anon_sym_boolean] = ACTIONS(216),
    [anon_sym_string] = ACTIONS(216),
    [anon_sym_symbol] = ACTIONS(216),
    [anon_sym_object] = ACTIONS(216),
    [anon_sym_abstract] = ACTIONS(597),
    [anon_sym_infer] = ACTIONS(599),
    [anon_sym_keyof] = ACTIONS(601),
    [anon_sym_unique] = ACTIONS(214),
    [anon_sym_unknown] = ACTIONS(216),
    [anon_sym_never] = ACTIONS(216),
    [anon_sym_LBRACE_PIPE] = ACTIONS(218),
    [sym_html_comment] = ACTIONS(5),
  },
  [1149] = {
    [sym_import] = STATE(4681),
    [sym_nested_identifier] = STATE(5474),
    [sym_string] = STATE(2994),
    [sym_formal_parameters] = STATE(5619),
    [sym_nested_type_identifier] = STATE(2939),
    [sym__type_query_member_expression_in_type_annotation] = STATE(3303),
    [sym__type_query_call_expression_in_type_annotation] = STATE(2938),
    [sym_type] = STATE(4510),
    [sym_constructor_type] = STATE(3007),
    [sym_primary_type] = STATE(2981),
    [sym_template_literal_type] = STATE(3039),
    [sym_infer_type] = STATE(3007),
    [sym_conditional_type] = STATE(3039),
    [sym_generic_type] = STATE(3039),
    [sym_type_query] = STATE(3039),
    [sym_index_type_query] = STATE(3039),
    [sym_lookup_type] = STATE(3039),
    [sym_literal_type] = STATE(3039),
    [sym__number] = STATE(3041),
    [sym_existential_type] = STATE(3039),
    [sym_flow_maybe_type] = STATE(3039),
    [sym_parenthesized_type] = STATE(3039),
    [sym_predefined_type] = STATE(3039),
    [sym_object_type] = STATE(3039),
    [sym_type_parameters] = STATE(5454),
    [sym_array_type] = STATE(3039),
    [sym_tuple_type] = STATE(3039),
    [sym_readonly_type] = STATE(3007),
    [sym_union_type] = STATE(3039),
    [sym_intersection_type] = STATE(3039),
    [sym_function_type] = STATE(3007),
    [sym_identifier] = ACTIONS(1532),
    [anon_sym_STAR] = ACTIONS(543),
    [anon_sym_LBRACE] = ACTIONS(1534),
    [anon_sym_typeof] = ACTIONS(1536),
    [anon_sym_import] = ACTIONS(1538),
    [anon_sym_const] = ACTIONS(133),
    [anon_sym_LPAREN] = ACTIONS(1540),
    [anon_sym_LBRACK] = ACTIONS(1542),
    [anon_sym_new] = ACTIONS(1642),
    [anon_sym_AMP] = ACTIONS(571),
    [anon_sym_PIPE] = ACTIONS(573),
    [anon_sym_PLUS] = ACTIONS(2497),
    [anon_sym_DASH] = ACTIONS(2497),
    [anon_sym_LT] = ACTIONS(2499),
    [anon_sym_void] = ACTIONS(216),
    [anon_sym_DQUOTE] = ACTIONS(1550),
    [anon_sym_SQUOTE] = ACTIONS(1552),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(1554),
    [sym_number] = ACTIONS(1556),
    [sym_this] = ACTIONS(1558),
    [sym_true] = ACTIONS(1560),
    [sym_false] = ACTIONS(1560),
    [sym_null] = ACTIONS(1560),
    [sym_undefined] = ACTIONS(1560),
    [anon_sym_readonly] = ACTIONS(1648),
    [anon_sym_QMARK] = ACTIONS(593),
    [anon_sym_any] = ACTIONS(216),
    [anon_sym_number] = ACTIONS(216),
    [anon_sym_boolean] = ACTIONS(216),
    [anon_sym_string] = ACTIONS(216),
    [anon_sym_symbol] = ACTIONS(216),
    [anon_sym_object] = ACTIONS(216),
    [anon_sym_abstract] = ACTIONS(597),
    [anon_sym_infer] = ACTIONS(599),
    [anon_sym_keyof] = ACTIONS(601),
    [anon_sym_unique] = ACTIONS(214),
    [anon_sym_unknown] = ACTIONS(216),
    [anon_sym_never] = ACTIONS(216),
    [anon_sym_LBRACE_PIPE] = ACTIONS(218),
    [sym_html_comment] = ACTIONS(5),
  },
  [1150] = {
    [sym_import] = STATE(4878),
    [sym_nested_identifier] = STATE(5796),
    [sym_string] = STATE(3437),
    [sym_formal_parameters] = STATE(5475),
    [sym_nested_type_identifier] = STATE(3278),
    [sym__type_query_member_expression_in_type_annotation] = STATE(2937),
    [sym__type_query_call_expression_in_type_annotation] = STATE(2938),
    [sym_type] = STATE(4587),
    [sym_constructor_type] = STATE(3007),
    [sym_primary_type] = STATE(3347),
    [sym_template_literal_type] = STATE(3453),
    [sym_infer_type] = STATE(3007),
    [sym_conditional_type] = STATE(3453),
    [sym_generic_type] = STATE(3453),
    [sym_type_query] = STATE(3453),
    [sym_index_type_query] = STATE(3453),
    [sym_lookup_type] = STATE(3453),
    [sym_literal_type] = STATE(3453),
    [sym__number] = STATE(3454),
    [sym_existential_type] = STATE(3453),
    [sym_flow_maybe_type] = STATE(3453),
    [sym_parenthesized_type] = STATE(3453),
    [sym_predefined_type] = STATE(3453),
    [sym_object_type] = STATE(3453),
    [sym_type_parameters] = STATE(5248),
    [sym_array_type] = STATE(3453),
    [sym_tuple_type] = STATE(3453),
    [sym_readonly_type] = STATE(3007),
    [sym_union_type] = STATE(3453),
    [sym_intersection_type] = STATE(3453),
    [sym_function_type] = STATE(3007),
    [sym_identifier] = ACTIONS(3259),
    [anon_sym_STAR] = ACTIONS(2995),
    [anon_sym_LBRACE] = ACTIONS(2997),
    [anon_sym_typeof] = ACTIONS(2999),
    [anon_sym_import] = ACTIONS(1538),
    [anon_sym_const] = ACTIONS(3001),
    [anon_sym_LPAREN] = ACTIONS(3003),
    [anon_sym_LBRACK] = ACTIONS(3005),
    [anon_sym_new] = ACTIONS(1544),
    [anon_sym_AMP] = ACTIONS(3009),
    [anon_sym_PIPE] = ACTIONS(3011),
    [anon_sym_PLUS] = ACTIONS(3013),
    [anon_sym_DASH] = ACTIONS(3013),
    [anon_sym_LT] = ACTIONS(2499),
    [anon_sym_void] = ACTIONS(3015),
    [anon_sym_DQUOTE] = ACTIONS(3017),
    [anon_sym_SQUOTE] = ACTIONS(3019),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(3021),
    [sym_number] = ACTIONS(3023),
    [sym_this] = ACTIONS(3261),
    [sym_true] = ACTIONS(3027),
    [sym_false] = ACTIONS(3027),
    [sym_null] = ACTIONS(3027),
    [sym_undefined] = ACTIONS(3027),
    [anon_sym_readonly] = ACTIONS(1562),
    [anon_sym_QMARK] = ACTIONS(3031),
    [anon_sym_any] = ACTIONS(3015),
    [anon_sym_number] = ACTIONS(3015),
    [anon_sym_boolean] = ACTIONS(3015),
    [anon_sym_string] = ACTIONS(3015),
    [anon_sym_symbol] = ACTIONS(3015),
    [anon_sym_object] = ACTIONS(3015),
    [anon_sym_abstract] = ACTIONS(208),
    [anon_sym_infer] = ACTIONS(210),
    [anon_sym_keyof] = ACTIONS(3039),
    [anon_sym_unique] = ACTIONS(3041),
    [anon_sym_unknown] = ACTIONS(3015),
    [anon_sym_never] = ACTIONS(3015),
    [anon_sym_LBRACE_PIPE] = ACTIONS(3043),
    [sym_html_comment] = ACTIONS(5),
  },
  [1151] = {
    [sym_export_statement] = STATE(3815),
    [sym_object_pattern] = STATE(5536),
    [sym_object_assignment_pattern] = STATE(4555),
    [sym_array_pattern] = STATE(5536),
    [sym__call_signature] = STATE(3910),
    [sym__destructuring_pattern] = STATE(5536),
    [sym_spread_element] = STATE(4721),
    [sym_string] = STATE(3085),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3315),
    [sym_rest_pattern] = STATE(4555),
    [sym_method_definition] = STATE(4721),
    [sym_pair] = STATE(4721),
    [sym_pair_pattern] = STATE(4555),
    [sym__property_name] = STATE(3085),
    [sym_computed_property_name] = STATE(3085),
    [sym_method_signature] = STATE(3815),
    [sym_accessibility_modifier] = STATE(2771),
    [sym_override_modifier] = STATE(2792),
    [sym_call_signature] = STATE(3815),
    [sym_property_signature] = STATE(3815),
    [sym_type_parameters] = STATE(5233),
    [sym_construct_signature] = STATE(3815),
    [sym_index_signature] = STATE(3815),
    [aux_sym_export_statement_repeat1] = STATE(4481),
    [aux_sym_object_repeat1] = STATE(4734),
    [aux_sym_object_pattern_repeat1] = STATE(4745),
    [sym_identifier] = ACTIONS(3269),
    [anon_sym_export] = ACTIONS(3271),
    [anon_sym_STAR] = ACTIONS(3273),
    [anon_sym_type] = ACTIONS(3269),
    [anon_sym_namespace] = ACTIONS(3269),
    [anon_sym_LBRACE] = ACTIONS(3275),
    [anon_sym_COMMA] = ACTIONS(3277),
    [anon_sym_RBRACE] = ACTIONS(3279),
    [anon_sym_let] = ACTIONS(3269),
    [anon_sym_LPAREN] = ACTIONS(3281),
    [anon_sym_SEMI] = ACTIONS(3283),
    [anon_sym_LBRACK] = ACTIONS(3285),
    [anon_sym_async] = ACTIONS(3287),
    [anon_sym_new] = ACTIONS(3289),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(249),
    [anon_sym_PLUS] = ACTIONS(3291),
    [anon_sym_DASH] = ACTIONS(3291),
    [anon_sym_LT] = ACTIONS(2499),
    [anon_sym_DQUOTE] = ACTIONS(1626),
    [anon_sym_SQUOTE] = ACTIONS(1628),
    [sym_comment] = ACTIONS(5),
    [sym_number] = ACTIONS(3293),
    [sym_private_property_identifier] = ACTIONS(3293),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(3295),
    [anon_sym_readonly] = ACTIONS(3297),
    [anon_sym_get] = ACTIONS(3299),
    [anon_sym_set] = ACTIONS(3299),
    [anon_sym_declare] = ACTIONS(3269),
    [anon_sym_public] = ACTIONS(3301),
    [anon_sym_private] = ACTIONS(3301),
    [anon_sym_protected] = ACTIONS(3301),
    [anon_sym_override] = ACTIONS(3303),
    [anon_sym_module] = ACTIONS(3269),
    [anon_sym_any] = ACTIONS(3269),
    [anon_sym_number] = ACTIONS(3269),
    [anon_sym_boolean] = ACTIONS(3269),
    [anon_sym_string] = ACTIONS(3269),
    [anon_sym_symbol] = ACTIONS(3269),
    [anon_sym_object] = ACTIONS(3269),
    [anon_sym_abstract] = ACTIONS(3305),
    [anon_sym_PIPE_RBRACE] = ACTIONS(3307),
    [sym_html_comment] = ACTIONS(5),
  },
  [1152] = {
    [sym_export_statement] = STATE(3815),
    [sym_object_pattern] = STATE(5536),
    [sym_object_assignment_pattern] = STATE(4555),
    [sym_array_pattern] = STATE(5536),
    [sym__call_signature] = STATE(3910),
    [sym__destructuring_pattern] = STATE(5536),
    [sym_spread_element] = STATE(4721),
    [sym_string] = STATE(3085),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3315),
    [sym_rest_pattern] = STATE(4555),
    [sym_method_definition] = STATE(4721),
    [sym_pair] = STATE(4721),
    [sym_pair_pattern] = STATE(4555),
    [sym__property_name] = STATE(3085),
    [sym_computed_property_name] = STATE(3085),
    [sym_method_signature] = STATE(3815),
    [sym_accessibility_modifier] = STATE(2771),
    [sym_override_modifier] = STATE(2792),
    [sym_call_signature] = STATE(3815),
    [sym_property_signature] = STATE(3815),
    [sym_type_parameters] = STATE(5233),
    [sym_construct_signature] = STATE(3815),
    [sym_index_signature] = STATE(3815),
    [aux_sym_export_statement_repeat1] = STATE(4481),
    [aux_sym_object_repeat1] = STATE(4734),
    [aux_sym_object_pattern_repeat1] = STATE(4745),
    [sym_identifier] = ACTIONS(3269),
    [anon_sym_export] = ACTIONS(3271),
    [anon_sym_STAR] = ACTIONS(3273),
    [anon_sym_type] = ACTIONS(3269),
    [anon_sym_namespace] = ACTIONS(3269),
    [anon_sym_LBRACE] = ACTIONS(3275),
    [anon_sym_COMMA] = ACTIONS(3277),
    [anon_sym_RBRACE] = ACTIONS(3309),
    [anon_sym_let] = ACTIONS(3269),
    [anon_sym_LPAREN] = ACTIONS(3281),
    [anon_sym_SEMI] = ACTIONS(3283),
    [anon_sym_LBRACK] = ACTIONS(3285),
    [anon_sym_async] = ACTIONS(3287),
    [anon_sym_new] = ACTIONS(3289),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(249),
    [anon_sym_PLUS] = ACTIONS(3291),
    [anon_sym_DASH] = ACTIONS(3291),
    [anon_sym_LT] = ACTIONS(2499),
    [anon_sym_DQUOTE] = ACTIONS(1626),
    [anon_sym_SQUOTE] = ACTIONS(1628),
    [sym_comment] = ACTIONS(5),
    [sym_number] = ACTIONS(3293),
    [sym_private_property_identifier] = ACTIONS(3293),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(3295),
    [anon_sym_readonly] = ACTIONS(3297),
    [anon_sym_get] = ACTIONS(3299),
    [anon_sym_set] = ACTIONS(3299),
    [anon_sym_declare] = ACTIONS(3269),
    [anon_sym_public] = ACTIONS(3301),
    [anon_sym_private] = ACTIONS(3301),
    [anon_sym_protected] = ACTIONS(3301),
    [anon_sym_override] = ACTIONS(3303),
    [anon_sym_module] = ACTIONS(3269),
    [anon_sym_any] = ACTIONS(3269),
    [anon_sym_number] = ACTIONS(3269),
    [anon_sym_boolean] = ACTIONS(3269),
    [anon_sym_string] = ACTIONS(3269),
    [anon_sym_symbol] = ACTIONS(3269),
    [anon_sym_object] = ACTIONS(3269),
    [anon_sym_abstract] = ACTIONS(3305),
    [anon_sym_PIPE_RBRACE] = ACTIONS(3307),
    [sym_html_comment] = ACTIONS(5),
  },
  [1153] = {
    [sym_export_statement] = STATE(3815),
    [sym_object_pattern] = STATE(5536),
    [sym_object_assignment_pattern] = STATE(4555),
    [sym_array_pattern] = STATE(5536),
    [sym__call_signature] = STATE(3910),
    [sym__destructuring_pattern] = STATE(5536),
    [sym_spread_element] = STATE(4721),
    [sym_string] = STATE(3085),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3315),
    [sym_rest_pattern] = STATE(4555),
    [sym_method_definition] = STATE(4721),
    [sym_pair] = STATE(4721),
    [sym_pair_pattern] = STATE(4555),
    [sym__property_name] = STATE(3085),
    [sym_computed_property_name] = STATE(3085),
    [sym_method_signature] = STATE(3815),
    [sym_accessibility_modifier] = STATE(2771),
    [sym_override_modifier] = STATE(2792),
    [sym_call_signature] = STATE(3815),
    [sym_property_signature] = STATE(3815),
    [sym_type_parameters] = STATE(5233),
    [sym_construct_signature] = STATE(3815),
    [sym_index_signature] = STATE(3815),
    [aux_sym_export_statement_repeat1] = STATE(4481),
    [aux_sym_object_repeat1] = STATE(4734),
    [aux_sym_object_pattern_repeat1] = STATE(4745),
    [sym_identifier] = ACTIONS(3269),
    [anon_sym_export] = ACTIONS(3271),
    [anon_sym_STAR] = ACTIONS(3273),
    [anon_sym_type] = ACTIONS(3269),
    [anon_sym_namespace] = ACTIONS(3269),
    [anon_sym_LBRACE] = ACTIONS(3275),
    [anon_sym_COMMA] = ACTIONS(3277),
    [anon_sym_RBRACE] = ACTIONS(3311),
    [anon_sym_let] = ACTIONS(3269),
    [anon_sym_LPAREN] = ACTIONS(3281),
    [anon_sym_SEMI] = ACTIONS(3283),
    [anon_sym_LBRACK] = ACTIONS(3285),
    [anon_sym_async] = ACTIONS(3287),
    [anon_sym_new] = ACTIONS(3289),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(249),
    [anon_sym_PLUS] = ACTIONS(3291),
    [anon_sym_DASH] = ACTIONS(3291),
    [anon_sym_LT] = ACTIONS(2499),
    [anon_sym_DQUOTE] = ACTIONS(1626),
    [anon_sym_SQUOTE] = ACTIONS(1628),
    [sym_comment] = ACTIONS(5),
    [sym_number] = ACTIONS(3293),
    [sym_private_property_identifier] = ACTIONS(3293),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(3295),
    [anon_sym_readonly] = ACTIONS(3297),
    [anon_sym_get] = ACTIONS(3299),
    [anon_sym_set] = ACTIONS(3299),
    [anon_sym_declare] = ACTIONS(3269),
    [anon_sym_public] = ACTIONS(3301),
    [anon_sym_private] = ACTIONS(3301),
    [anon_sym_protected] = ACTIONS(3301),
    [anon_sym_override] = ACTIONS(3303),
    [anon_sym_module] = ACTIONS(3269),
    [anon_sym_any] = ACTIONS(3269),
    [anon_sym_number] = ACTIONS(3269),
    [anon_sym_boolean] = ACTIONS(3269),
    [anon_sym_string] = ACTIONS(3269),
    [anon_sym_symbol] = ACTIONS(3269),
    [anon_sym_object] = ACTIONS(3269),
    [anon_sym_abstract] = ACTIONS(3305),
    [anon_sym_PIPE_RBRACE] = ACTIONS(3307),
    [sym_html_comment] = ACTIONS(5),
  },
  [1154] = {
    [sym_export_statement] = STATE(3815),
    [sym_object_pattern] = STATE(5536),
    [sym_object_assignment_pattern] = STATE(4555),
    [sym_array_pattern] = STATE(5536),
    [sym__call_signature] = STATE(3910),
    [sym__destructuring_pattern] = STATE(5536),
    [sym_spread_element] = STATE(4721),
    [sym_string] = STATE(3085),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3315),
    [sym_rest_pattern] = STATE(4555),
    [sym_method_definition] = STATE(4721),
    [sym_pair] = STATE(4721),
    [sym_pair_pattern] = STATE(4555),
    [sym__property_name] = STATE(3085),
    [sym_computed_property_name] = STATE(3085),
    [sym_method_signature] = STATE(3815),
    [sym_accessibility_modifier] = STATE(2771),
    [sym_override_modifier] = STATE(2792),
    [sym_call_signature] = STATE(3815),
    [sym_property_signature] = STATE(3815),
    [sym_type_parameters] = STATE(5233),
    [sym_construct_signature] = STATE(3815),
    [sym_index_signature] = STATE(3815),
    [aux_sym_export_statement_repeat1] = STATE(4481),
    [aux_sym_object_repeat1] = STATE(4734),
    [aux_sym_object_pattern_repeat1] = STATE(4745),
    [sym_identifier] = ACTIONS(3313),
    [anon_sym_export] = ACTIONS(3315),
    [anon_sym_STAR] = ACTIONS(3273),
    [anon_sym_type] = ACTIONS(3313),
    [anon_sym_namespace] = ACTIONS(3313),
    [anon_sym_LBRACE] = ACTIONS(3275),
    [anon_sym_COMMA] = ACTIONS(3277),
    [anon_sym_RBRACE] = ACTIONS(3317),
    [anon_sym_let] = ACTIONS(3313),
    [anon_sym_LPAREN] = ACTIONS(3281),
    [anon_sym_SEMI] = ACTIONS(3283),
    [anon_sym_LBRACK] = ACTIONS(3285),
    [anon_sym_async] = ACTIONS(3319),
    [anon_sym_new] = ACTIONS(3321),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(249),
    [anon_sym_PLUS] = ACTIONS(3291),
    [anon_sym_DASH] = ACTIONS(3291),
    [anon_sym_LT] = ACTIONS(2499),
    [anon_sym_DQUOTE] = ACTIONS(1626),
    [anon_sym_SQUOTE] = ACTIONS(1628),
    [sym_comment] = ACTIONS(5),
    [sym_number] = ACTIONS(3293),
    [sym_private_property_identifier] = ACTIONS(3293),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(3323),
    [anon_sym_readonly] = ACTIONS(3325),
    [anon_sym_get] = ACTIONS(3327),
    [anon_sym_set] = ACTIONS(3327),
    [anon_sym_declare] = ACTIONS(3313),
    [anon_sym_public] = ACTIONS(3329),
    [anon_sym_private] = ACTIONS(3329),
    [anon_sym_protected] = ACTIONS(3329),
    [anon_sym_override] = ACTIONS(3331),
    [anon_sym_module] = ACTIONS(3313),
    [anon_sym_any] = ACTIONS(3313),
    [anon_sym_number] = ACTIONS(3313),
    [anon_sym_boolean] = ACTIONS(3313),
    [anon_sym_string] = ACTIONS(3313),
    [anon_sym_symbol] = ACTIONS(3313),
    [anon_sym_object] = ACTIONS(3313),
    [anon_sym_abstract] = ACTIONS(3305),
    [anon_sym_PIPE_RBRACE] = ACTIONS(3307),
    [sym_html_comment] = ACTIONS(5),
  },
  [1155] = {
    [sym_export_statement] = STATE(3815),
    [sym_object_pattern] = STATE(5536),
    [sym_object_assignment_pattern] = STATE(4555),
    [sym_array_pattern] = STATE(5536),
    [sym__call_signature] = STATE(3910),
    [sym__destructuring_pattern] = STATE(5536),
    [sym_spread_element] = STATE(4576),
    [sym_string] = STATE(3085),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3315),
    [sym_rest_pattern] = STATE(4555),
    [sym_method_definition] = STATE(4576),
    [sym_pair] = STATE(4576),
    [sym_pair_pattern] = STATE(4555),
    [sym__property_name] = STATE(3085),
    [sym_computed_property_name] = STATE(3085),
    [sym_method_signature] = STATE(3815),
    [sym_accessibility_modifier] = STATE(2771),
    [sym_override_modifier] = STATE(2792),
    [sym_call_signature] = STATE(3815),
    [sym_property_signature] = STATE(3815),
    [sym_type_parameters] = STATE(5233),
    [sym_construct_signature] = STATE(3815),
    [sym_index_signature] = STATE(3815),
    [aux_sym_export_statement_repeat1] = STATE(4481),
    [aux_sym_object_repeat1] = STATE(4744),
    [aux_sym_object_pattern_repeat1] = STATE(4745),
    [sym_identifier] = ACTIONS(3333),
    [anon_sym_export] = ACTIONS(3335),
    [anon_sym_STAR] = ACTIONS(3273),
    [anon_sym_type] = ACTIONS(3333),
    [anon_sym_namespace] = ACTIONS(3333),
    [anon_sym_LBRACE] = ACTIONS(3275),
    [anon_sym_COMMA] = ACTIONS(3277),
    [anon_sym_RBRACE] = ACTIONS(3337),
    [anon_sym_let] = ACTIONS(3333),
    [anon_sym_LPAREN] = ACTIONS(3281),
    [anon_sym_SEMI] = ACTIONS(3283),
    [anon_sym_LBRACK] = ACTIONS(3285),
    [anon_sym_async] = ACTIONS(3339),
    [anon_sym_new] = ACTIONS(3341),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(249),
    [anon_sym_PLUS] = ACTIONS(3291),
    [anon_sym_DASH] = ACTIONS(3291),
    [anon_sym_LT] = ACTIONS(2499),
    [anon_sym_DQUOTE] = ACTIONS(1626),
    [anon_sym_SQUOTE] = ACTIONS(1628),
    [sym_comment] = ACTIONS(5),
    [sym_number] = ACTIONS(3293),
    [sym_private_property_identifier] = ACTIONS(3293),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(3343),
    [anon_sym_readonly] = ACTIONS(3345),
    [anon_sym_get] = ACTIONS(3347),
    [anon_sym_set] = ACTIONS(3347),
    [anon_sym_declare] = ACTIONS(3333),
    [anon_sym_public] = ACTIONS(3349),
    [anon_sym_private] = ACTIONS(3349),
    [anon_sym_protected] = ACTIONS(3349),
    [anon_sym_override] = ACTIONS(3351),
    [anon_sym_module] = ACTIONS(3333),
    [anon_sym_any] = ACTIONS(3333),
    [anon_sym_number] = ACTIONS(3333),
    [anon_sym_boolean] = ACTIONS(3333),
    [anon_sym_string] = ACTIONS(3333),
    [anon_sym_symbol] = ACTIONS(3333),
    [anon_sym_object] = ACTIONS(3333),
    [anon_sym_abstract] = ACTIONS(3305),
    [anon_sym_PIPE_RBRACE] = ACTIONS(3307),
    [sym_html_comment] = ACTIONS(5),
  },
  [1156] = {
    [sym_export_statement] = STATE(3815),
    [sym_object_pattern] = STATE(5536),
    [sym_object_assignment_pattern] = STATE(4555),
    [sym_array_pattern] = STATE(5536),
    [sym__call_signature] = STATE(3910),
    [sym__destructuring_pattern] = STATE(5536),
    [sym_spread_element] = STATE(4721),
    [sym_string] = STATE(3085),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3315),
    [sym_rest_pattern] = STATE(4555),
    [sym_method_definition] = STATE(4721),
    [sym_pair] = STATE(4721),
    [sym_pair_pattern] = STATE(4555),
    [sym__property_name] = STATE(3085),
    [sym_computed_property_name] = STATE(3085),
    [sym_method_signature] = STATE(3815),
    [sym_accessibility_modifier] = STATE(2771),
    [sym_override_modifier] = STATE(2792),
    [sym_call_signature] = STATE(3815),
    [sym_property_signature] = STATE(3815),
    [sym_type_parameters] = STATE(5233),
    [sym_construct_signature] = STATE(3815),
    [sym_index_signature] = STATE(3815),
    [aux_sym_export_statement_repeat1] = STATE(4481),
    [aux_sym_object_repeat1] = STATE(4734),
    [aux_sym_object_pattern_repeat1] = STATE(4745),
    [sym_identifier] = ACTIONS(3353),
    [anon_sym_export] = ACTIONS(3355),
    [anon_sym_STAR] = ACTIONS(3273),
    [anon_sym_type] = ACTIONS(3353),
    [anon_sym_namespace] = ACTIONS(3353),
    [anon_sym_LBRACE] = ACTIONS(3275),
    [anon_sym_COMMA] = ACTIONS(3277),
    [anon_sym_RBRACE] = ACTIONS(3309),
    [anon_sym_let] = ACTIONS(3353),
    [anon_sym_LPAREN] = ACTIONS(3281),
    [anon_sym_SEMI] = ACTIONS(3283),
    [anon_sym_LBRACK] = ACTIONS(3285),
    [anon_sym_async] = ACTIONS(3357),
    [anon_sym_new] = ACTIONS(3359),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(249),
    [anon_sym_PLUS] = ACTIONS(3291),
    [anon_sym_DASH] = ACTIONS(3291),
    [anon_sym_LT] = ACTIONS(2499),
    [anon_sym_DQUOTE] = ACTIONS(1626),
    [anon_sym_SQUOTE] = ACTIONS(1628),
    [sym_comment] = ACTIONS(5),
    [sym_number] = ACTIONS(3293),
    [sym_private_property_identifier] = ACTIONS(3293),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(3361),
    [anon_sym_readonly] = ACTIONS(3363),
    [anon_sym_get] = ACTIONS(3365),
    [anon_sym_set] = ACTIONS(3365),
    [anon_sym_declare] = ACTIONS(3353),
    [anon_sym_public] = ACTIONS(3367),
    [anon_sym_private] = ACTIONS(3367),
    [anon_sym_protected] = ACTIONS(3367),
    [anon_sym_override] = ACTIONS(3369),
    [anon_sym_module] = ACTIONS(3353),
    [anon_sym_any] = ACTIONS(3353),
    [anon_sym_number] = ACTIONS(3353),
    [anon_sym_boolean] = ACTIONS(3353),
    [anon_sym_string] = ACTIONS(3353),
    [anon_sym_symbol] = ACTIONS(3353),
    [anon_sym_object] = ACTIONS(3353),
    [anon_sym_abstract] = ACTIONS(3305),
    [anon_sym_PIPE_RBRACE] = ACTIONS(3307),
    [sym_html_comment] = ACTIONS(5),
  },
  [1157] = {
    [sym_export_statement] = STATE(3815),
    [sym_object_pattern] = STATE(5536),
    [sym_object_assignment_pattern] = STATE(4555),
    [sym_array_pattern] = STATE(5536),
    [sym__call_signature] = STATE(3910),
    [sym__destructuring_pattern] = STATE(5536),
    [sym_spread_element] = STATE(4721),
    [sym_string] = STATE(3085),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3315),
    [sym_rest_pattern] = STATE(4555),
    [sym_method_definition] = STATE(4721),
    [sym_pair] = STATE(4721),
    [sym_pair_pattern] = STATE(4555),
    [sym__property_name] = STATE(3085),
    [sym_computed_property_name] = STATE(3085),
    [sym_method_signature] = STATE(3815),
    [sym_accessibility_modifier] = STATE(2771),
    [sym_override_modifier] = STATE(2792),
    [sym_call_signature] = STATE(3815),
    [sym_property_signature] = STATE(3815),
    [sym_type_parameters] = STATE(5233),
    [sym_construct_signature] = STATE(3815),
    [sym_index_signature] = STATE(3815),
    [aux_sym_export_statement_repeat1] = STATE(4481),
    [aux_sym_object_repeat1] = STATE(4734),
    [aux_sym_object_pattern_repeat1] = STATE(4745),
    [sym_identifier] = ACTIONS(3313),
    [anon_sym_export] = ACTIONS(3315),
    [anon_sym_STAR] = ACTIONS(3273),
    [anon_sym_type] = ACTIONS(3313),
    [anon_sym_namespace] = ACTIONS(3313),
    [anon_sym_LBRACE] = ACTIONS(3275),
    [anon_sym_COMMA] = ACTIONS(3277),
    [anon_sym_RBRACE] = ACTIONS(3371),
    [anon_sym_let] = ACTIONS(3313),
    [anon_sym_LPAREN] = ACTIONS(3281),
    [anon_sym_SEMI] = ACTIONS(3283),
    [anon_sym_LBRACK] = ACTIONS(3285),
    [anon_sym_async] = ACTIONS(3319),
    [anon_sym_new] = ACTIONS(3321),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(249),
    [anon_sym_PLUS] = ACTIONS(3291),
    [anon_sym_DASH] = ACTIONS(3291),
    [anon_sym_LT] = ACTIONS(2499),
    [anon_sym_DQUOTE] = ACTIONS(1626),
    [anon_sym_SQUOTE] = ACTIONS(1628),
    [sym_comment] = ACTIONS(5),
    [sym_number] = ACTIONS(3293),
    [sym_private_property_identifier] = ACTIONS(3293),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(3323),
    [anon_sym_readonly] = ACTIONS(3325),
    [anon_sym_get] = ACTIONS(3327),
    [anon_sym_set] = ACTIONS(3327),
    [anon_sym_declare] = ACTIONS(3313),
    [anon_sym_public] = ACTIONS(3329),
    [anon_sym_private] = ACTIONS(3329),
    [anon_sym_protected] = ACTIONS(3329),
    [anon_sym_override] = ACTIONS(3331),
    [anon_sym_module] = ACTIONS(3313),
    [anon_sym_any] = ACTIONS(3313),
    [anon_sym_number] = ACTIONS(3313),
    [anon_sym_boolean] = ACTIONS(3313),
    [anon_sym_string] = ACTIONS(3313),
    [anon_sym_symbol] = ACTIONS(3313),
    [anon_sym_object] = ACTIONS(3313),
    [anon_sym_abstract] = ACTIONS(3305),
    [anon_sym_PIPE_RBRACE] = ACTIONS(3307),
    [sym_html_comment] = ACTIONS(5),
  },
  [1158] = {
    [sym_export_statement] = STATE(3815),
    [sym_object_pattern] = STATE(5536),
    [sym_object_assignment_pattern] = STATE(4555),
    [sym_array_pattern] = STATE(5536),
    [sym__call_signature] = STATE(3910),
    [sym__destructuring_pattern] = STATE(5536),
    [sym_spread_element] = STATE(4721),
    [sym_string] = STATE(3085),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3315),
    [sym_rest_pattern] = STATE(4555),
    [sym_method_definition] = STATE(4721),
    [sym_pair] = STATE(4721),
    [sym_pair_pattern] = STATE(4555),
    [sym__property_name] = STATE(3085),
    [sym_computed_property_name] = STATE(3085),
    [sym_method_signature] = STATE(3815),
    [sym_accessibility_modifier] = STATE(2771),
    [sym_override_modifier] = STATE(2792),
    [sym_call_signature] = STATE(3815),
    [sym_property_signature] = STATE(3815),
    [sym_type_parameters] = STATE(5233),
    [sym_construct_signature] = STATE(3815),
    [sym_index_signature] = STATE(3815),
    [aux_sym_export_statement_repeat1] = STATE(4481),
    [aux_sym_object_repeat1] = STATE(4734),
    [aux_sym_object_pattern_repeat1] = STATE(4745),
    [sym_identifier] = ACTIONS(3373),
    [anon_sym_export] = ACTIONS(3375),
    [anon_sym_STAR] = ACTIONS(3273),
    [anon_sym_type] = ACTIONS(3373),
    [anon_sym_namespace] = ACTIONS(3373),
    [anon_sym_LBRACE] = ACTIONS(3275),
    [anon_sym_COMMA] = ACTIONS(3277),
    [anon_sym_RBRACE] = ACTIONS(3377),
    [anon_sym_let] = ACTIONS(3373),
    [anon_sym_LPAREN] = ACTIONS(3281),
    [anon_sym_SEMI] = ACTIONS(3283),
    [anon_sym_LBRACK] = ACTIONS(3285),
    [anon_sym_async] = ACTIONS(3379),
    [anon_sym_new] = ACTIONS(3381),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(249),
    [anon_sym_PLUS] = ACTIONS(3291),
    [anon_sym_DASH] = ACTIONS(3291),
    [anon_sym_LT] = ACTIONS(2499),
    [anon_sym_DQUOTE] = ACTIONS(1626),
    [anon_sym_SQUOTE] = ACTIONS(1628),
    [sym_comment] = ACTIONS(5),
    [sym_number] = ACTIONS(3293),
    [sym_private_property_identifier] = ACTIONS(3293),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(3383),
    [anon_sym_readonly] = ACTIONS(3385),
    [anon_sym_get] = ACTIONS(3387),
    [anon_sym_set] = ACTIONS(3387),
    [anon_sym_declare] = ACTIONS(3373),
    [anon_sym_public] = ACTIONS(3389),
    [anon_sym_private] = ACTIONS(3389),
    [anon_sym_protected] = ACTIONS(3389),
    [anon_sym_override] = ACTIONS(3391),
    [anon_sym_module] = ACTIONS(3373),
    [anon_sym_any] = ACTIONS(3373),
    [anon_sym_number] = ACTIONS(3373),
    [anon_sym_boolean] = ACTIONS(3373),
    [anon_sym_string] = ACTIONS(3373),
    [anon_sym_symbol] = ACTIONS(3373),
    [anon_sym_object] = ACTIONS(3373),
    [anon_sym_abstract] = ACTIONS(3305),
    [anon_sym_PIPE_RBRACE] = ACTIONS(3307),
    [sym_html_comment] = ACTIONS(5),
  },
  [1159] = {
    [sym_export_statement] = STATE(3815),
    [sym_object_pattern] = STATE(5536),
    [sym_object_assignment_pattern] = STATE(4555),
    [sym_array_pattern] = STATE(5536),
    [sym__call_signature] = STATE(3910),
    [sym__destructuring_pattern] = STATE(5536),
    [sym_spread_element] = STATE(4721),
    [sym_string] = STATE(3085),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3315),
    [sym_rest_pattern] = STATE(4555),
    [sym_method_definition] = STATE(4721),
    [sym_pair] = STATE(4721),
    [sym_pair_pattern] = STATE(4555),
    [sym__property_name] = STATE(3085),
    [sym_computed_property_name] = STATE(3085),
    [sym_method_signature] = STATE(3815),
    [sym_accessibility_modifier] = STATE(2771),
    [sym_override_modifier] = STATE(2792),
    [sym_call_signature] = STATE(3815),
    [sym_property_signature] = STATE(3815),
    [sym_type_parameters] = STATE(5233),
    [sym_construct_signature] = STATE(3815),
    [sym_index_signature] = STATE(3815),
    [aux_sym_export_statement_repeat1] = STATE(4481),
    [aux_sym_object_repeat1] = STATE(4734),
    [aux_sym_object_pattern_repeat1] = STATE(4745),
    [sym_identifier] = ACTIONS(3373),
    [anon_sym_export] = ACTIONS(3375),
    [anon_sym_STAR] = ACTIONS(3273),
    [anon_sym_type] = ACTIONS(3373),
    [anon_sym_namespace] = ACTIONS(3373),
    [anon_sym_LBRACE] = ACTIONS(3275),
    [anon_sym_COMMA] = ACTIONS(3277),
    [anon_sym_RBRACE] = ACTIONS(3311),
    [anon_sym_let] = ACTIONS(3373),
    [anon_sym_LPAREN] = ACTIONS(3281),
    [anon_sym_SEMI] = ACTIONS(3283),
    [anon_sym_LBRACK] = ACTIONS(3285),
    [anon_sym_async] = ACTIONS(3379),
    [anon_sym_new] = ACTIONS(3381),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(249),
    [anon_sym_PLUS] = ACTIONS(3291),
    [anon_sym_DASH] = ACTIONS(3291),
    [anon_sym_LT] = ACTIONS(2499),
    [anon_sym_DQUOTE] = ACTIONS(1626),
    [anon_sym_SQUOTE] = ACTIONS(1628),
    [sym_comment] = ACTIONS(5),
    [sym_number] = ACTIONS(3293),
    [sym_private_property_identifier] = ACTIONS(3293),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(3383),
    [anon_sym_readonly] = ACTIONS(3385),
    [anon_sym_get] = ACTIONS(3387),
    [anon_sym_set] = ACTIONS(3387),
    [anon_sym_declare] = ACTIONS(3373),
    [anon_sym_public] = ACTIONS(3389),
    [anon_sym_private] = ACTIONS(3389),
    [anon_sym_protected] = ACTIONS(3389),
    [anon_sym_override] = ACTIONS(3391),
    [anon_sym_module] = ACTIONS(3373),
    [anon_sym_any] = ACTIONS(3373),
    [anon_sym_number] = ACTIONS(3373),
    [anon_sym_boolean] = ACTIONS(3373),
    [anon_sym_string] = ACTIONS(3373),
    [anon_sym_symbol] = ACTIONS(3373),
    [anon_sym_object] = ACTIONS(3373),
    [anon_sym_abstract] = ACTIONS(3305),
    [anon_sym_PIPE_RBRACE] = ACTIONS(3307),
    [sym_html_comment] = ACTIONS(5),
  },
  [1160] = {
    [sym_export_statement] = STATE(3815),
    [sym_object_pattern] = STATE(5536),
    [sym_object_assignment_pattern] = STATE(4555),
    [sym_array_pattern] = STATE(5536),
    [sym__call_signature] = STATE(3910),
    [sym__destructuring_pattern] = STATE(5536),
    [sym_spread_element] = STATE(4721),
    [sym_string] = STATE(3085),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3315),
    [sym_rest_pattern] = STATE(4555),
    [sym_method_definition] = STATE(4721),
    [sym_pair] = STATE(4721),
    [sym_pair_pattern] = STATE(4555),
    [sym__property_name] = STATE(3085),
    [sym_computed_property_name] = STATE(3085),
    [sym_method_signature] = STATE(3815),
    [sym_accessibility_modifier] = STATE(2771),
    [sym_override_modifier] = STATE(2792),
    [sym_call_signature] = STATE(3815),
    [sym_property_signature] = STATE(3815),
    [sym_type_parameters] = STATE(5233),
    [sym_construct_signature] = STATE(3815),
    [sym_index_signature] = STATE(3815),
    [aux_sym_export_statement_repeat1] = STATE(4481),
    [aux_sym_object_repeat1] = STATE(4734),
    [aux_sym_object_pattern_repeat1] = STATE(4745),
    [sym_identifier] = ACTIONS(3373),
    [anon_sym_export] = ACTIONS(3375),
    [anon_sym_STAR] = ACTIONS(3273),
    [anon_sym_type] = ACTIONS(3373),
    [anon_sym_namespace] = ACTIONS(3373),
    [anon_sym_LBRACE] = ACTIONS(3275),
    [anon_sym_COMMA] = ACTIONS(3277),
    [anon_sym_RBRACE] = ACTIONS(3393),
    [anon_sym_let] = ACTIONS(3373),
    [anon_sym_LPAREN] = ACTIONS(3281),
    [anon_sym_SEMI] = ACTIONS(3283),
    [anon_sym_LBRACK] = ACTIONS(3285),
    [anon_sym_async] = ACTIONS(3379),
    [anon_sym_new] = ACTIONS(3381),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(249),
    [anon_sym_PLUS] = ACTIONS(3291),
    [anon_sym_DASH] = ACTIONS(3291),
    [anon_sym_LT] = ACTIONS(2499),
    [anon_sym_DQUOTE] = ACTIONS(1626),
    [anon_sym_SQUOTE] = ACTIONS(1628),
    [sym_comment] = ACTIONS(5),
    [sym_number] = ACTIONS(3293),
    [sym_private_property_identifier] = ACTIONS(3293),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(3383),
    [anon_sym_readonly] = ACTIONS(3385),
    [anon_sym_get] = ACTIONS(3387),
    [anon_sym_set] = ACTIONS(3387),
    [anon_sym_declare] = ACTIONS(3373),
    [anon_sym_public] = ACTIONS(3389),
    [anon_sym_private] = ACTIONS(3389),
    [anon_sym_protected] = ACTIONS(3389),
    [anon_sym_override] = ACTIONS(3391),
    [anon_sym_module] = ACTIONS(3373),
    [anon_sym_any] = ACTIONS(3373),
    [anon_sym_number] = ACTIONS(3373),
    [anon_sym_boolean] = ACTIONS(3373),
    [anon_sym_string] = ACTIONS(3373),
    [anon_sym_symbol] = ACTIONS(3373),
    [anon_sym_object] = ACTIONS(3373),
    [anon_sym_abstract] = ACTIONS(3305),
    [anon_sym_PIPE_RBRACE] = ACTIONS(3307),
    [sym_html_comment] = ACTIONS(5),
  },
  [1161] = {
    [sym_export_statement] = STATE(3844),
    [sym_object_pattern] = STATE(5536),
    [sym_object_assignment_pattern] = STATE(4555),
    [sym_array_pattern] = STATE(5536),
    [sym__call_signature] = STATE(3910),
    [sym__destructuring_pattern] = STATE(5536),
    [sym_spread_element] = STATE(4721),
    [sym_string] = STATE(3085),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3315),
    [sym_rest_pattern] = STATE(4555),
    [sym_method_definition] = STATE(4721),
    [sym_pair] = STATE(4721),
    [sym_pair_pattern] = STATE(4555),
    [sym__property_name] = STATE(3085),
    [sym_computed_property_name] = STATE(3085),
    [sym_method_signature] = STATE(3844),
    [sym_accessibility_modifier] = STATE(2771),
    [sym_override_modifier] = STATE(2792),
    [sym_call_signature] = STATE(3844),
    [sym_property_signature] = STATE(3844),
    [sym_type_parameters] = STATE(5233),
    [sym_construct_signature] = STATE(3844),
    [sym_index_signature] = STATE(3844),
    [aux_sym_export_statement_repeat1] = STATE(4481),
    [aux_sym_object_repeat1] = STATE(4734),
    [aux_sym_object_pattern_repeat1] = STATE(4745),
    [sym_identifier] = ACTIONS(3269),
    [anon_sym_export] = ACTIONS(3271),
    [anon_sym_STAR] = ACTIONS(3273),
    [anon_sym_type] = ACTIONS(3269),
    [anon_sym_namespace] = ACTIONS(3269),
    [anon_sym_LBRACE] = ACTIONS(3275),
    [anon_sym_COMMA] = ACTIONS(3395),
    [anon_sym_RBRACE] = ACTIONS(3397),
    [anon_sym_let] = ACTIONS(3269),
    [anon_sym_LPAREN] = ACTIONS(3281),
    [anon_sym_SEMI] = ACTIONS(3399),
    [anon_sym_LBRACK] = ACTIONS(3285),
    [anon_sym_async] = ACTIONS(3287),
    [anon_sym_new] = ACTIONS(3289),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(249),
    [anon_sym_PLUS] = ACTIONS(3291),
    [anon_sym_DASH] = ACTIONS(3291),
    [anon_sym_LT] = ACTIONS(2499),
    [anon_sym_DQUOTE] = ACTIONS(1626),
    [anon_sym_SQUOTE] = ACTIONS(1628),
    [sym_comment] = ACTIONS(5),
    [sym_number] = ACTIONS(3293),
    [sym_private_property_identifier] = ACTIONS(3293),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(3295),
    [anon_sym_readonly] = ACTIONS(3297),
    [anon_sym_get] = ACTIONS(3299),
    [anon_sym_set] = ACTIONS(3299),
    [anon_sym_declare] = ACTIONS(3269),
    [anon_sym_public] = ACTIONS(3301),
    [anon_sym_private] = ACTIONS(3301),
    [anon_sym_protected] = ACTIONS(3301),
    [anon_sym_override] = ACTIONS(3303),
    [anon_sym_module] = ACTIONS(3269),
    [anon_sym_any] = ACTIONS(3269),
    [anon_sym_number] = ACTIONS(3269),
    [anon_sym_boolean] = ACTIONS(3269),
    [anon_sym_string] = ACTIONS(3269),
    [anon_sym_symbol] = ACTIONS(3269),
    [anon_sym_object] = ACTIONS(3269),
    [anon_sym_abstract] = ACTIONS(3305),
    [anon_sym_PIPE_RBRACE] = ACTIONS(3401),
    [sym_html_comment] = ACTIONS(5),
  },
  [1162] = {
    [sym_export_statement] = STATE(3815),
    [sym_object_pattern] = STATE(5536),
    [sym_object_assignment_pattern] = STATE(4555),
    [sym_array_pattern] = STATE(5536),
    [sym__call_signature] = STATE(3910),
    [sym__destructuring_pattern] = STATE(5536),
    [sym_spread_element] = STATE(4576),
    [sym_string] = STATE(3085),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3315),
    [sym_rest_pattern] = STATE(4555),
    [sym_method_definition] = STATE(4576),
    [sym_pair] = STATE(4576),
    [sym_pair_pattern] = STATE(4555),
    [sym__property_name] = STATE(3085),
    [sym_computed_property_name] = STATE(3085),
    [sym_method_signature] = STATE(3815),
    [sym_accessibility_modifier] = STATE(2771),
    [sym_override_modifier] = STATE(2792),
    [sym_call_signature] = STATE(3815),
    [sym_property_signature] = STATE(3815),
    [sym_type_parameters] = STATE(5233),
    [sym_construct_signature] = STATE(3815),
    [sym_index_signature] = STATE(3815),
    [aux_sym_export_statement_repeat1] = STATE(4481),
    [aux_sym_object_repeat1] = STATE(4744),
    [aux_sym_object_pattern_repeat1] = STATE(4745),
    [sym_identifier] = ACTIONS(3333),
    [anon_sym_export] = ACTIONS(3335),
    [anon_sym_STAR] = ACTIONS(3273),
    [anon_sym_type] = ACTIONS(3333),
    [anon_sym_namespace] = ACTIONS(3333),
    [anon_sym_LBRACE] = ACTIONS(3275),
    [anon_sym_COMMA] = ACTIONS(3277),
    [anon_sym_RBRACE] = ACTIONS(3403),
    [anon_sym_let] = ACTIONS(3333),
    [anon_sym_LPAREN] = ACTIONS(3281),
    [anon_sym_SEMI] = ACTIONS(3283),
    [anon_sym_LBRACK] = ACTIONS(3285),
    [anon_sym_async] = ACTIONS(3339),
    [anon_sym_new] = ACTIONS(3341),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(249),
    [anon_sym_PLUS] = ACTIONS(3291),
    [anon_sym_DASH] = ACTIONS(3291),
    [anon_sym_LT] = ACTIONS(2499),
    [anon_sym_DQUOTE] = ACTIONS(1626),
    [anon_sym_SQUOTE] = ACTIONS(1628),
    [sym_comment] = ACTIONS(5),
    [sym_number] = ACTIONS(3293),
    [sym_private_property_identifier] = ACTIONS(3293),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(3343),
    [anon_sym_readonly] = ACTIONS(3345),
    [anon_sym_get] = ACTIONS(3347),
    [anon_sym_set] = ACTIONS(3347),
    [anon_sym_declare] = ACTIONS(3333),
    [anon_sym_public] = ACTIONS(3349),
    [anon_sym_private] = ACTIONS(3349),
    [anon_sym_protected] = ACTIONS(3349),
    [anon_sym_override] = ACTIONS(3351),
    [anon_sym_module] = ACTIONS(3333),
    [anon_sym_any] = ACTIONS(3333),
    [anon_sym_number] = ACTIONS(3333),
    [anon_sym_boolean] = ACTIONS(3333),
    [anon_sym_string] = ACTIONS(3333),
    [anon_sym_symbol] = ACTIONS(3333),
    [anon_sym_object] = ACTIONS(3333),
    [anon_sym_abstract] = ACTIONS(3305),
    [anon_sym_PIPE_RBRACE] = ACTIONS(3307),
    [sym_html_comment] = ACTIONS(5),
  },
  [1163] = {
    [sym_variable_declarator] = STATE(4416),
    [sym_object_pattern] = STATE(3718),
    [sym_array_pattern] = STATE(3718),
    [sym__destructuring_pattern] = STATE(3718),
    [aux_sym_object_repeat1] = STATE(4810),
    [aux_sym_object_pattern_repeat1] = STATE(4815),
    [sym_identifier] = ACTIONS(3405),
    [anon_sym_STAR] = ACTIONS(120),
    [anon_sym_EQ] = ACTIONS(661),
    [anon_sym_as] = ACTIONS(120),
    [anon_sym_LBRACE] = ACTIONS(3407),
    [anon_sym_COMMA] = ACTIONS(154),
    [anon_sym_RBRACE] = ACTIONS(692),
    [anon_sym_BANG] = ACTIONS(120),
    [anon_sym_LPAREN] = ACTIONS(2149),
    [anon_sym_SEMI] = ACTIONS(154),
    [anon_sym_in] = ACTIONS(120),
    [anon_sym_COLON] = ACTIONS(671),
    [anon_sym_LBRACK] = ACTIONS(3409),
    [anon_sym_DOT] = ACTIONS(154),
    [anon_sym_EQ_GT] = ACTIONS(682),
    [anon_sym_QMARK_DOT] = ACTIONS(154),
    [anon_sym_PLUS_EQ] = ACTIONS(160),
    [anon_sym_DASH_EQ] = ACTIONS(160),
    [anon_sym_STAR_EQ] = ACTIONS(160),
    [anon_sym_SLASH_EQ] = ACTIONS(160),
    [anon_sym_PERCENT_EQ] = ACTIONS(160),
    [anon_sym_CARET_EQ] = ACTIONS(160),
    [anon_sym_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_LT_LT_EQ] = ACTIONS(160),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(160),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP] = ACTIONS(120),
    [anon_sym_PIPE_PIPE] = ACTIONS(120),
    [anon_sym_GT_GT] = ACTIONS(120),
    [anon_sym_GT_GT_GT] = ACTIONS(120),
    [anon_sym_LT_LT] = ACTIONS(120),
    [anon_sym_AMP] = ACTIONS(120),
    [anon_sym_CARET] = ACTIONS(120),
    [anon_sym_PIPE] = ACTIONS(120),
    [anon_sym_PLUS] = ACTIONS(120),
    [anon_sym_DASH] = ACTIONS(120),
    [anon_sym_SLASH] = ACTIONS(120),
    [anon_sym_PERCENT] = ACTIONS(120),
    [anon_sym_STAR_STAR] = ACTIONS(120),
    [anon_sym_LT] = ACTIONS(2158),
    [anon_sym_LT_EQ] = ACTIONS(154),
    [anon_sym_EQ_EQ] = ACTIONS(120),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(154),
    [anon_sym_BANG_EQ] = ACTIONS(120),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(154),
    [anon_sym_GT_EQ] = ACTIONS(154),
    [anon_sym_GT] = ACTIONS(120),
    [anon_sym_QMARK_QMARK] = ACTIONS(120),
    [anon_sym_instanceof] = ACTIONS(120),
    [anon_sym_PLUS_PLUS] = ACTIONS(154),
    [anon_sym_DASH_DASH] = ACTIONS(154),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(154),
    [anon_sym_QMARK] = ACTIONS(690),
    [anon_sym_satisfies] = ACTIONS(120),
    [sym__automatic_semicolon] = ACTIONS(154),
    [sym__ternary_qmark] = ACTIONS(154),
    [sym_html_comment] = ACTIONS(5),
  },
  [1164] = {
    [sym_nested_identifier] = STATE(201),
    [sym_string] = STATE(203),
    [sym__module] = STATE(231),
    [aux_sym_object_repeat1] = STATE(4792),
    [aux_sym_object_pattern_repeat1] = STATE(4815),
    [sym_identifier] = ACTIONS(3411),
    [anon_sym_STAR] = ACTIONS(120),
    [anon_sym_EQ] = ACTIONS(661),
    [anon_sym_as] = ACTIONS(120),
    [anon_sym_COMMA] = ACTIONS(154),
    [anon_sym_RBRACE] = ACTIONS(667),
    [anon_sym_BANG] = ACTIONS(120),
    [anon_sym_LPAREN] = ACTIONS(2149),
    [anon_sym_SEMI] = ACTIONS(154),
    [anon_sym_in] = ACTIONS(120),
    [anon_sym_COLON] = ACTIONS(671),
    [anon_sym_LBRACK] = ACTIONS(154),
    [anon_sym_DOT] = ACTIONS(154),
    [anon_sym_EQ_GT] = ACTIONS(682),
    [anon_sym_QMARK_DOT] = ACTIONS(154),
    [anon_sym_PLUS_EQ] = ACTIONS(160),
    [anon_sym_DASH_EQ] = ACTIONS(160),
    [anon_sym_STAR_EQ] = ACTIONS(160),
    [anon_sym_SLASH_EQ] = ACTIONS(160),
    [anon_sym_PERCENT_EQ] = ACTIONS(160),
    [anon_sym_CARET_EQ] = ACTIONS(160),
    [anon_sym_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_LT_LT_EQ] = ACTIONS(160),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(160),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP] = ACTIONS(120),
    [anon_sym_PIPE_PIPE] = ACTIONS(120),
    [anon_sym_GT_GT] = ACTIONS(120),
    [anon_sym_GT_GT_GT] = ACTIONS(120),
    [anon_sym_LT_LT] = ACTIONS(120),
    [anon_sym_AMP] = ACTIONS(120),
    [anon_sym_CARET] = ACTIONS(120),
    [anon_sym_PIPE] = ACTIONS(120),
    [anon_sym_PLUS] = ACTIONS(120),
    [anon_sym_DASH] = ACTIONS(120),
    [anon_sym_SLASH] = ACTIONS(120),
    [anon_sym_PERCENT] = ACTIONS(120),
    [anon_sym_STAR_STAR] = ACTIONS(120),
    [anon_sym_LT] = ACTIONS(2158),
    [anon_sym_LT_EQ] = ACTIONS(154),
    [anon_sym_EQ_EQ] = ACTIONS(120),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(154),
    [anon_sym_BANG_EQ] = ACTIONS(120),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(154),
    [anon_sym_GT_EQ] = ACTIONS(154),
    [anon_sym_GT] = ACTIONS(120),
    [anon_sym_QMARK_QMARK] = ACTIONS(120),
    [anon_sym_instanceof] = ACTIONS(120),
    [anon_sym_PLUS_PLUS] = ACTIONS(154),
    [anon_sym_DASH_DASH] = ACTIONS(154),
    [anon_sym_DQUOTE] = ACTIONS(3413),
    [anon_sym_SQUOTE] = ACTIONS(3415),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(154),
    [anon_sym_QMARK] = ACTIONS(690),
    [anon_sym_satisfies] = ACTIONS(120),
    [sym__automatic_semicolon] = ACTIONS(154),
    [sym__ternary_qmark] = ACTIONS(154),
    [sym_html_comment] = ACTIONS(5),
  },
  [1165] = {
    [sym_variable_declarator] = STATE(4416),
    [sym_object_pattern] = STATE(3718),
    [sym_array_pattern] = STATE(3718),
    [sym__destructuring_pattern] = STATE(3718),
    [aux_sym_object_repeat1] = STATE(4792),
    [aux_sym_object_pattern_repeat1] = STATE(4815),
    [sym_identifier] = ACTIONS(3405),
    [anon_sym_STAR] = ACTIONS(120),
    [anon_sym_EQ] = ACTIONS(661),
    [anon_sym_as] = ACTIONS(120),
    [anon_sym_LBRACE] = ACTIONS(3407),
    [anon_sym_COMMA] = ACTIONS(154),
    [anon_sym_RBRACE] = ACTIONS(694),
    [anon_sym_BANG] = ACTIONS(120),
    [anon_sym_LPAREN] = ACTIONS(2149),
    [anon_sym_SEMI] = ACTIONS(154),
    [anon_sym_in] = ACTIONS(120),
    [anon_sym_COLON] = ACTIONS(671),
    [anon_sym_LBRACK] = ACTIONS(3409),
    [anon_sym_DOT] = ACTIONS(154),
    [anon_sym_EQ_GT] = ACTIONS(682),
    [anon_sym_QMARK_DOT] = ACTIONS(154),
    [anon_sym_PLUS_EQ] = ACTIONS(160),
    [anon_sym_DASH_EQ] = ACTIONS(160),
    [anon_sym_STAR_EQ] = ACTIONS(160),
    [anon_sym_SLASH_EQ] = ACTIONS(160),
    [anon_sym_PERCENT_EQ] = ACTIONS(160),
    [anon_sym_CARET_EQ] = ACTIONS(160),
    [anon_sym_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_LT_LT_EQ] = ACTIONS(160),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(160),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP] = ACTIONS(120),
    [anon_sym_PIPE_PIPE] = ACTIONS(120),
    [anon_sym_GT_GT] = ACTIONS(120),
    [anon_sym_GT_GT_GT] = ACTIONS(120),
    [anon_sym_LT_LT] = ACTIONS(120),
    [anon_sym_AMP] = ACTIONS(120),
    [anon_sym_CARET] = ACTIONS(120),
    [anon_sym_PIPE] = ACTIONS(120),
    [anon_sym_PLUS] = ACTIONS(120),
    [anon_sym_DASH] = ACTIONS(120),
    [anon_sym_SLASH] = ACTIONS(120),
    [anon_sym_PERCENT] = ACTIONS(120),
    [anon_sym_STAR_STAR] = ACTIONS(120),
    [anon_sym_LT] = ACTIONS(2158),
    [anon_sym_LT_EQ] = ACTIONS(154),
    [anon_sym_EQ_EQ] = ACTIONS(120),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(154),
    [anon_sym_BANG_EQ] = ACTIONS(120),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(154),
    [anon_sym_GT_EQ] = ACTIONS(154),
    [anon_sym_GT] = ACTIONS(120),
    [anon_sym_QMARK_QMARK] = ACTIONS(120),
    [anon_sym_instanceof] = ACTIONS(120),
    [anon_sym_PLUS_PLUS] = ACTIONS(154),
    [anon_sym_DASH_DASH] = ACTIONS(154),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(154),
    [anon_sym_QMARK] = ACTIONS(690),
    [anon_sym_satisfies] = ACTIONS(120),
    [sym__automatic_semicolon] = ACTIONS(154),
    [sym__ternary_qmark] = ACTIONS(154),
    [sym_html_comment] = ACTIONS(5),
  },
  [1166] = {
    [sym_identifier] = ACTIONS(3417),
    [anon_sym_export] = ACTIONS(3417),
    [anon_sym_type] = ACTIONS(3417),
    [anon_sym_EQ] = ACTIONS(3417),
    [anon_sym_namespace] = ACTIONS(3417),
    [anon_sym_LBRACE] = ACTIONS(3419),
    [anon_sym_COMMA] = ACTIONS(3419),
    [anon_sym_RBRACE] = ACTIONS(3419),
    [anon_sym_typeof] = ACTIONS(3417),
    [anon_sym_import] = ACTIONS(3417),
    [anon_sym_let] = ACTIONS(3417),
    [anon_sym_BANG] = ACTIONS(3419),
    [anon_sym_LPAREN] = ACTIONS(3419),
    [anon_sym_RPAREN] = ACTIONS(3419),
    [anon_sym_await] = ACTIONS(3417),
    [anon_sym_COLON] = ACTIONS(3419),
    [anon_sym_yield] = ACTIONS(3417),
    [anon_sym_LBRACK] = ACTIONS(3419),
    [anon_sym_RBRACK] = ACTIONS(3419),
    [anon_sym_class] = ACTIONS(3417),
    [anon_sym_async] = ACTIONS(3417),
    [anon_sym_function] = ACTIONS(3417),
    [anon_sym_EQ_GT] = ACTIONS(3419),
    [anon_sym_new] = ACTIONS(3417),
    [anon_sym_using] = ACTIONS(3417),
    [anon_sym_AMP] = ACTIONS(3419),
    [anon_sym_PIPE] = ACTIONS(3419),
    [anon_sym_PLUS] = ACTIONS(3417),
    [anon_sym_DASH] = ACTIONS(3417),
    [anon_sym_SLASH] = ACTIONS(3417),
    [anon_sym_LT] = ACTIONS(3419),
    [anon_sym_GT] = ACTIONS(3419),
    [anon_sym_TILDE] = ACTIONS(3419),
    [anon_sym_void] = ACTIONS(3417),
    [anon_sym_delete] = ACTIONS(3417),
    [anon_sym_PLUS_PLUS] = ACTIONS(3419),
    [anon_sym_DASH_DASH] = ACTIONS(3419),
    [anon_sym_DQUOTE] = ACTIONS(3419),
    [anon_sym_SQUOTE] = ACTIONS(3419),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(3419),
    [sym_number] = ACTIONS(3419),
    [sym_private_property_identifier] = ACTIONS(3419),
    [sym_this] = ACTIONS(3417),
    [sym_super] = ACTIONS(3417),
    [sym_true] = ACTIONS(3417),
    [sym_false] = ACTIONS(3417),
    [sym_null] = ACTIONS(3417),
    [sym_undefined] = ACTIONS(3417),
    [anon_sym_AT] = ACTIONS(3419),
    [anon_sym_static] = ACTIONS(3417),
    [anon_sym_readonly] = ACTIONS(3417),
    [anon_sym_get] = ACTIONS(3417),
    [anon_sym_set] = ACTIONS(3417),
    [anon_sym_QMARK] = ACTIONS(3419),
    [anon_sym_declare] = ACTIONS(3417),
    [anon_sym_public] = ACTIONS(3417),
    [anon_sym_private] = ACTIONS(3417),
    [anon_sym_protected] = ACTIONS(3417),
    [anon_sym_override] = ACTIONS(3417),
    [anon_sym_module] = ACTIONS(3417),
    [anon_sym_any] = ACTIONS(3417),
    [anon_sym_number] = ACTIONS(3417),
    [anon_sym_boolean] = ACTIONS(3417),
    [anon_sym_string] = ACTIONS(3417),
    [anon_sym_symbol] = ACTIONS(3417),
    [anon_sym_object] = ACTIONS(3417),
    [anon_sym_extends] = ACTIONS(3417),
    [sym_html_comment] = ACTIONS(5),
  },
  [1167] = {
    [sym_nested_identifier] = STATE(783),
    [sym_string] = STATE(798),
    [sym__module] = STATE(878),
    [aux_sym_object_repeat1] = STATE(4792),
    [aux_sym_object_pattern_repeat1] = STATE(4815),
    [sym_identifier] = ACTIONS(3421),
    [anon_sym_STAR] = ACTIONS(120),
    [anon_sym_EQ] = ACTIONS(661),
    [anon_sym_as] = ACTIONS(120),
    [anon_sym_COMMA] = ACTIONS(154),
    [anon_sym_RBRACE] = ACTIONS(694),
    [anon_sym_BANG] = ACTIONS(120),
    [anon_sym_LPAREN] = ACTIONS(2149),
    [anon_sym_SEMI] = ACTIONS(154),
    [anon_sym_in] = ACTIONS(120),
    [anon_sym_COLON] = ACTIONS(671),
    [anon_sym_LBRACK] = ACTIONS(154),
    [anon_sym_DOT] = ACTIONS(154),
    [anon_sym_EQ_GT] = ACTIONS(682),
    [anon_sym_QMARK_DOT] = ACTIONS(154),
    [anon_sym_PLUS_EQ] = ACTIONS(160),
    [anon_sym_DASH_EQ] = ACTIONS(160),
    [anon_sym_STAR_EQ] = ACTIONS(160),
    [anon_sym_SLASH_EQ] = ACTIONS(160),
    [anon_sym_PERCENT_EQ] = ACTIONS(160),
    [anon_sym_CARET_EQ] = ACTIONS(160),
    [anon_sym_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_LT_LT_EQ] = ACTIONS(160),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(160),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP] = ACTIONS(120),
    [anon_sym_PIPE_PIPE] = ACTIONS(120),
    [anon_sym_GT_GT] = ACTIONS(120),
    [anon_sym_GT_GT_GT] = ACTIONS(120),
    [anon_sym_LT_LT] = ACTIONS(120),
    [anon_sym_AMP] = ACTIONS(120),
    [anon_sym_CARET] = ACTIONS(120),
    [anon_sym_PIPE] = ACTIONS(120),
    [anon_sym_PLUS] = ACTIONS(120),
    [anon_sym_DASH] = ACTIONS(120),
    [anon_sym_SLASH] = ACTIONS(120),
    [anon_sym_PERCENT] = ACTIONS(120),
    [anon_sym_STAR_STAR] = ACTIONS(120),
    [anon_sym_LT] = ACTIONS(2158),
    [anon_sym_LT_EQ] = ACTIONS(154),
    [anon_sym_EQ_EQ] = ACTIONS(120),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(154),
    [anon_sym_BANG_EQ] = ACTIONS(120),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(154),
    [anon_sym_GT_EQ] = ACTIONS(154),
    [anon_sym_GT] = ACTIONS(120),
    [anon_sym_QMARK_QMARK] = ACTIONS(120),
    [anon_sym_instanceof] = ACTIONS(120),
    [anon_sym_PLUS_PLUS] = ACTIONS(154),
    [anon_sym_DASH_DASH] = ACTIONS(154),
    [anon_sym_DQUOTE] = ACTIONS(1550),
    [anon_sym_SQUOTE] = ACTIONS(1552),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(154),
    [anon_sym_QMARK] = ACTIONS(690),
    [anon_sym_satisfies] = ACTIONS(120),
    [sym__automatic_semicolon] = ACTIONS(154),
    [sym__ternary_qmark] = ACTIONS(154),
    [sym_html_comment] = ACTIONS(5),
  },
  [1168] = {
    [sym_nested_identifier] = STATE(201),
    [sym_string] = STATE(203),
    [sym__module] = STATE(231),
    [aux_sym_object_repeat1] = STATE(4792),
    [aux_sym_object_pattern_repeat1] = STATE(4815),
    [sym_identifier] = ACTIONS(3411),
    [anon_sym_STAR] = ACTIONS(120),
    [anon_sym_EQ] = ACTIONS(661),
    [anon_sym_as] = ACTIONS(120),
    [anon_sym_COMMA] = ACTIONS(154),
    [anon_sym_RBRACE] = ACTIONS(694),
    [anon_sym_BANG] = ACTIONS(120),
    [anon_sym_LPAREN] = ACTIONS(2149),
    [anon_sym_SEMI] = ACTIONS(154),
    [anon_sym_in] = ACTIONS(120),
    [anon_sym_COLON] = ACTIONS(671),
    [anon_sym_LBRACK] = ACTIONS(154),
    [anon_sym_DOT] = ACTIONS(154),
    [anon_sym_EQ_GT] = ACTIONS(682),
    [anon_sym_QMARK_DOT] = ACTIONS(154),
    [anon_sym_PLUS_EQ] = ACTIONS(160),
    [anon_sym_DASH_EQ] = ACTIONS(160),
    [anon_sym_STAR_EQ] = ACTIONS(160),
    [anon_sym_SLASH_EQ] = ACTIONS(160),
    [anon_sym_PERCENT_EQ] = ACTIONS(160),
    [anon_sym_CARET_EQ] = ACTIONS(160),
    [anon_sym_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_LT_LT_EQ] = ACTIONS(160),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(160),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP] = ACTIONS(120),
    [anon_sym_PIPE_PIPE] = ACTIONS(120),
    [anon_sym_GT_GT] = ACTIONS(120),
    [anon_sym_GT_GT_GT] = ACTIONS(120),
    [anon_sym_LT_LT] = ACTIONS(120),
    [anon_sym_AMP] = ACTIONS(120),
    [anon_sym_CARET] = ACTIONS(120),
    [anon_sym_PIPE] = ACTIONS(120),
    [anon_sym_PLUS] = ACTIONS(120),
    [anon_sym_DASH] = ACTIONS(120),
    [anon_sym_SLASH] = ACTIONS(120),
    [anon_sym_PERCENT] = ACTIONS(120),
    [anon_sym_STAR_STAR] = ACTIONS(120),
    [anon_sym_LT] = ACTIONS(2158),
    [anon_sym_LT_EQ] = ACTIONS(154),
    [anon_sym_EQ_EQ] = ACTIONS(120),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(154),
    [anon_sym_BANG_EQ] = ACTIONS(120),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(154),
    [anon_sym_GT_EQ] = ACTIONS(154),
    [anon_sym_GT] = ACTIONS(120),
    [anon_sym_QMARK_QMARK] = ACTIONS(120),
    [anon_sym_instanceof] = ACTIONS(120),
    [anon_sym_PLUS_PLUS] = ACTIONS(154),
    [anon_sym_DASH_DASH] = ACTIONS(154),
    [anon_sym_DQUOTE] = ACTIONS(3413),
    [anon_sym_SQUOTE] = ACTIONS(3415),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(154),
    [anon_sym_QMARK] = ACTIONS(690),
    [anon_sym_satisfies] = ACTIONS(120),
    [sym__automatic_semicolon] = ACTIONS(154),
    [sym__ternary_qmark] = ACTIONS(154),
    [sym_html_comment] = ACTIONS(5),
  },
  [1169] = {
    [sym_variable_declarator] = STATE(4416),
    [sym_object_pattern] = STATE(3718),
    [sym_array_pattern] = STATE(3718),
    [sym__destructuring_pattern] = STATE(3718),
    [aux_sym_object_repeat1] = STATE(4792),
    [aux_sym_object_pattern_repeat1] = STATE(4815),
    [sym_identifier] = ACTIONS(3405),
    [anon_sym_STAR] = ACTIONS(120),
    [anon_sym_EQ] = ACTIONS(661),
    [anon_sym_as] = ACTIONS(120),
    [anon_sym_LBRACE] = ACTIONS(3407),
    [anon_sym_COMMA] = ACTIONS(154),
    [anon_sym_RBRACE] = ACTIONS(667),
    [anon_sym_BANG] = ACTIONS(120),
    [anon_sym_LPAREN] = ACTIONS(2149),
    [anon_sym_SEMI] = ACTIONS(154),
    [anon_sym_in] = ACTIONS(120),
    [anon_sym_COLON] = ACTIONS(671),
    [anon_sym_LBRACK] = ACTIONS(3409),
    [anon_sym_DOT] = ACTIONS(154),
    [anon_sym_EQ_GT] = ACTIONS(682),
    [anon_sym_QMARK_DOT] = ACTIONS(154),
    [anon_sym_PLUS_EQ] = ACTIONS(160),
    [anon_sym_DASH_EQ] = ACTIONS(160),
    [anon_sym_STAR_EQ] = ACTIONS(160),
    [anon_sym_SLASH_EQ] = ACTIONS(160),
    [anon_sym_PERCENT_EQ] = ACTIONS(160),
    [anon_sym_CARET_EQ] = ACTIONS(160),
    [anon_sym_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_LT_LT_EQ] = ACTIONS(160),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(160),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP] = ACTIONS(120),
    [anon_sym_PIPE_PIPE] = ACTIONS(120),
    [anon_sym_GT_GT] = ACTIONS(120),
    [anon_sym_GT_GT_GT] = ACTIONS(120),
    [anon_sym_LT_LT] = ACTIONS(120),
    [anon_sym_AMP] = ACTIONS(120),
    [anon_sym_CARET] = ACTIONS(120),
    [anon_sym_PIPE] = ACTIONS(120),
    [anon_sym_PLUS] = ACTIONS(120),
    [anon_sym_DASH] = ACTIONS(120),
    [anon_sym_SLASH] = ACTIONS(120),
    [anon_sym_PERCENT] = ACTIONS(120),
    [anon_sym_STAR_STAR] = ACTIONS(120),
    [anon_sym_LT] = ACTIONS(2158),
    [anon_sym_LT_EQ] = ACTIONS(154),
    [anon_sym_EQ_EQ] = ACTIONS(120),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(154),
    [anon_sym_BANG_EQ] = ACTIONS(120),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(154),
    [anon_sym_GT_EQ] = ACTIONS(154),
    [anon_sym_GT] = ACTIONS(120),
    [anon_sym_QMARK_QMARK] = ACTIONS(120),
    [anon_sym_instanceof] = ACTIONS(120),
    [anon_sym_PLUS_PLUS] = ACTIONS(154),
    [anon_sym_DASH_DASH] = ACTIONS(154),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(154),
    [anon_sym_QMARK] = ACTIONS(690),
    [anon_sym_satisfies] = ACTIONS(120),
    [sym__automatic_semicolon] = ACTIONS(154),
    [sym__ternary_qmark] = ACTIONS(154),
    [sym_html_comment] = ACTIONS(5),
  },
  [1170] = {
    [sym_identifier] = ACTIONS(3423),
    [anon_sym_export] = ACTIONS(3423),
    [anon_sym_type] = ACTIONS(3423),
    [anon_sym_EQ] = ACTIONS(3423),
    [anon_sym_namespace] = ACTIONS(3423),
    [anon_sym_LBRACE] = ACTIONS(3425),
    [anon_sym_COMMA] = ACTIONS(3425),
    [anon_sym_RBRACE] = ACTIONS(3425),
    [anon_sym_typeof] = ACTIONS(3423),
    [anon_sym_import] = ACTIONS(3423),
    [anon_sym_let] = ACTIONS(3423),
    [anon_sym_BANG] = ACTIONS(3425),
    [anon_sym_LPAREN] = ACTIONS(3425),
    [anon_sym_RPAREN] = ACTIONS(3425),
    [anon_sym_await] = ACTIONS(3423),
    [anon_sym_COLON] = ACTIONS(3425),
    [anon_sym_yield] = ACTIONS(3423),
    [anon_sym_LBRACK] = ACTIONS(3425),
    [anon_sym_RBRACK] = ACTIONS(3425),
    [anon_sym_class] = ACTIONS(3423),
    [anon_sym_async] = ACTIONS(3423),
    [anon_sym_function] = ACTIONS(3423),
    [anon_sym_EQ_GT] = ACTIONS(3425),
    [anon_sym_new] = ACTIONS(3423),
    [anon_sym_using] = ACTIONS(3423),
    [anon_sym_AMP] = ACTIONS(3425),
    [anon_sym_PIPE] = ACTIONS(3425),
    [anon_sym_PLUS] = ACTIONS(3423),
    [anon_sym_DASH] = ACTIONS(3423),
    [anon_sym_SLASH] = ACTIONS(3423),
    [anon_sym_LT] = ACTIONS(3425),
    [anon_sym_GT] = ACTIONS(3425),
    [anon_sym_TILDE] = ACTIONS(3425),
    [anon_sym_void] = ACTIONS(3423),
    [anon_sym_delete] = ACTIONS(3423),
    [anon_sym_PLUS_PLUS] = ACTIONS(3425),
    [anon_sym_DASH_DASH] = ACTIONS(3425),
    [anon_sym_DQUOTE] = ACTIONS(3425),
    [anon_sym_SQUOTE] = ACTIONS(3425),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(3425),
    [sym_number] = ACTIONS(3425),
    [sym_private_property_identifier] = ACTIONS(3425),
    [sym_this] = ACTIONS(3423),
    [sym_super] = ACTIONS(3423),
    [sym_true] = ACTIONS(3423),
    [sym_false] = ACTIONS(3423),
    [sym_null] = ACTIONS(3423),
    [sym_undefined] = ACTIONS(3423),
    [anon_sym_AT] = ACTIONS(3425),
    [anon_sym_static] = ACTIONS(3423),
    [anon_sym_readonly] = ACTIONS(3423),
    [anon_sym_get] = ACTIONS(3423),
    [anon_sym_set] = ACTIONS(3423),
    [anon_sym_QMARK] = ACTIONS(3425),
    [anon_sym_declare] = ACTIONS(3423),
    [anon_sym_public] = ACTIONS(3423),
    [anon_sym_private] = ACTIONS(3423),
    [anon_sym_protected] = ACTIONS(3423),
    [anon_sym_override] = ACTIONS(3423),
    [anon_sym_module] = ACTIONS(3423),
    [anon_sym_any] = ACTIONS(3423),
    [anon_sym_number] = ACTIONS(3423),
    [anon_sym_boolean] = ACTIONS(3423),
    [anon_sym_string] = ACTIONS(3423),
    [anon_sym_symbol] = ACTIONS(3423),
    [anon_sym_object] = ACTIONS(3423),
    [anon_sym_extends] = ACTIONS(3423),
    [sym_html_comment] = ACTIONS(5),
  },
  [1171] = {
    [sym_identifier] = ACTIONS(3427),
    [anon_sym_export] = ACTIONS(3427),
    [anon_sym_type] = ACTIONS(3427),
    [anon_sym_EQ] = ACTIONS(3427),
    [anon_sym_namespace] = ACTIONS(3427),
    [anon_sym_LBRACE] = ACTIONS(3429),
    [anon_sym_COMMA] = ACTIONS(3429),
    [anon_sym_RBRACE] = ACTIONS(3429),
    [anon_sym_typeof] = ACTIONS(3427),
    [anon_sym_import] = ACTIONS(3427),
    [anon_sym_let] = ACTIONS(3427),
    [anon_sym_BANG] = ACTIONS(3429),
    [anon_sym_LPAREN] = ACTIONS(3429),
    [anon_sym_RPAREN] = ACTIONS(3429),
    [anon_sym_await] = ACTIONS(3427),
    [anon_sym_COLON] = ACTIONS(3429),
    [anon_sym_yield] = ACTIONS(3427),
    [anon_sym_LBRACK] = ACTIONS(3429),
    [anon_sym_RBRACK] = ACTIONS(3429),
    [anon_sym_class] = ACTIONS(3427),
    [anon_sym_async] = ACTIONS(3427),
    [anon_sym_function] = ACTIONS(3427),
    [anon_sym_EQ_GT] = ACTIONS(3429),
    [anon_sym_new] = ACTIONS(3427),
    [anon_sym_using] = ACTIONS(3427),
    [anon_sym_AMP] = ACTIONS(3429),
    [anon_sym_PIPE] = ACTIONS(3429),
    [anon_sym_PLUS] = ACTIONS(3427),
    [anon_sym_DASH] = ACTIONS(3427),
    [anon_sym_SLASH] = ACTIONS(3427),
    [anon_sym_LT] = ACTIONS(3429),
    [anon_sym_GT] = ACTIONS(3429),
    [anon_sym_TILDE] = ACTIONS(3429),
    [anon_sym_void] = ACTIONS(3427),
    [anon_sym_delete] = ACTIONS(3427),
    [anon_sym_PLUS_PLUS] = ACTIONS(3429),
    [anon_sym_DASH_DASH] = ACTIONS(3429),
    [anon_sym_DQUOTE] = ACTIONS(3429),
    [anon_sym_SQUOTE] = ACTIONS(3429),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(3429),
    [sym_number] = ACTIONS(3429),
    [sym_private_property_identifier] = ACTIONS(3429),
    [sym_this] = ACTIONS(3427),
    [sym_super] = ACTIONS(3427),
    [sym_true] = ACTIONS(3427),
    [sym_false] = ACTIONS(3427),
    [sym_null] = ACTIONS(3427),
    [sym_undefined] = ACTIONS(3427),
    [anon_sym_AT] = ACTIONS(3429),
    [anon_sym_static] = ACTIONS(3427),
    [anon_sym_readonly] = ACTIONS(3427),
    [anon_sym_get] = ACTIONS(3427),
    [anon_sym_set] = ACTIONS(3427),
    [anon_sym_QMARK] = ACTIONS(3429),
    [anon_sym_declare] = ACTIONS(3427),
    [anon_sym_public] = ACTIONS(3427),
    [anon_sym_private] = ACTIONS(3427),
    [anon_sym_protected] = ACTIONS(3427),
    [anon_sym_override] = ACTIONS(3427),
    [anon_sym_module] = ACTIONS(3427),
    [anon_sym_any] = ACTIONS(3427),
    [anon_sym_number] = ACTIONS(3427),
    [anon_sym_boolean] = ACTIONS(3427),
    [anon_sym_string] = ACTIONS(3427),
    [anon_sym_symbol] = ACTIONS(3427),
    [anon_sym_object] = ACTIONS(3427),
    [anon_sym_extends] = ACTIONS(3427),
    [sym_html_comment] = ACTIONS(5),
  },
  [1172] = {
    [sym_nested_identifier] = STATE(783),
    [sym_string] = STATE(798),
    [sym__module] = STATE(878),
    [aux_sym_object_repeat1] = STATE(4792),
    [aux_sym_object_pattern_repeat1] = STATE(4815),
    [sym_identifier] = ACTIONS(3421),
    [anon_sym_STAR] = ACTIONS(120),
    [anon_sym_EQ] = ACTIONS(661),
    [anon_sym_as] = ACTIONS(120),
    [anon_sym_COMMA] = ACTIONS(154),
    [anon_sym_RBRACE] = ACTIONS(667),
    [anon_sym_BANG] = ACTIONS(120),
    [anon_sym_LPAREN] = ACTIONS(2149),
    [anon_sym_SEMI] = ACTIONS(154),
    [anon_sym_in] = ACTIONS(120),
    [anon_sym_COLON] = ACTIONS(671),
    [anon_sym_LBRACK] = ACTIONS(154),
    [anon_sym_DOT] = ACTIONS(154),
    [anon_sym_EQ_GT] = ACTIONS(682),
    [anon_sym_QMARK_DOT] = ACTIONS(154),
    [anon_sym_PLUS_EQ] = ACTIONS(160),
    [anon_sym_DASH_EQ] = ACTIONS(160),
    [anon_sym_STAR_EQ] = ACTIONS(160),
    [anon_sym_SLASH_EQ] = ACTIONS(160),
    [anon_sym_PERCENT_EQ] = ACTIONS(160),
    [anon_sym_CARET_EQ] = ACTIONS(160),
    [anon_sym_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_LT_LT_EQ] = ACTIONS(160),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(160),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP] = ACTIONS(120),
    [anon_sym_PIPE_PIPE] = ACTIONS(120),
    [anon_sym_GT_GT] = ACTIONS(120),
    [anon_sym_GT_GT_GT] = ACTIONS(120),
    [anon_sym_LT_LT] = ACTIONS(120),
    [anon_sym_AMP] = ACTIONS(120),
    [anon_sym_CARET] = ACTIONS(120),
    [anon_sym_PIPE] = ACTIONS(120),
    [anon_sym_PLUS] = ACTIONS(120),
    [anon_sym_DASH] = ACTIONS(120),
    [anon_sym_SLASH] = ACTIONS(120),
    [anon_sym_PERCENT] = ACTIONS(120),
    [anon_sym_STAR_STAR] = ACTIONS(120),
    [anon_sym_LT] = ACTIONS(2158),
    [anon_sym_LT_EQ] = ACTIONS(154),
    [anon_sym_EQ_EQ] = ACTIONS(120),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(154),
    [anon_sym_BANG_EQ] = ACTIONS(120),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(154),
    [anon_sym_GT_EQ] = ACTIONS(154),
    [anon_sym_GT] = ACTIONS(120),
    [anon_sym_QMARK_QMARK] = ACTIONS(120),
    [anon_sym_instanceof] = ACTIONS(120),
    [anon_sym_PLUS_PLUS] = ACTIONS(154),
    [anon_sym_DASH_DASH] = ACTIONS(154),
    [anon_sym_DQUOTE] = ACTIONS(1550),
    [anon_sym_SQUOTE] = ACTIONS(1552),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(154),
    [anon_sym_QMARK] = ACTIONS(690),
    [anon_sym_satisfies] = ACTIONS(120),
    [sym__automatic_semicolon] = ACTIONS(154),
    [sym__ternary_qmark] = ACTIONS(154),
    [sym_html_comment] = ACTIONS(5),
  },
  [1173] = {
    [sym_nested_identifier] = STATE(783),
    [sym_string] = STATE(798),
    [sym__module] = STATE(878),
    [aux_sym_object_repeat1] = STATE(4810),
    [aux_sym_object_pattern_repeat1] = STATE(4815),
    [sym_identifier] = ACTIONS(3421),
    [anon_sym_STAR] = ACTIONS(120),
    [anon_sym_EQ] = ACTIONS(661),
    [anon_sym_as] = ACTIONS(120),
    [anon_sym_COMMA] = ACTIONS(154),
    [anon_sym_RBRACE] = ACTIONS(692),
    [anon_sym_BANG] = ACTIONS(120),
    [anon_sym_LPAREN] = ACTIONS(2149),
    [anon_sym_SEMI] = ACTIONS(154),
    [anon_sym_in] = ACTIONS(120),
    [anon_sym_COLON] = ACTIONS(671),
    [anon_sym_LBRACK] = ACTIONS(154),
    [anon_sym_DOT] = ACTIONS(154),
    [anon_sym_EQ_GT] = ACTIONS(682),
    [anon_sym_QMARK_DOT] = ACTIONS(154),
    [anon_sym_PLUS_EQ] = ACTIONS(160),
    [anon_sym_DASH_EQ] = ACTIONS(160),
    [anon_sym_STAR_EQ] = ACTIONS(160),
    [anon_sym_SLASH_EQ] = ACTIONS(160),
    [anon_sym_PERCENT_EQ] = ACTIONS(160),
    [anon_sym_CARET_EQ] = ACTIONS(160),
    [anon_sym_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_LT_LT_EQ] = ACTIONS(160),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(160),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP] = ACTIONS(120),
    [anon_sym_PIPE_PIPE] = ACTIONS(120),
    [anon_sym_GT_GT] = ACTIONS(120),
    [anon_sym_GT_GT_GT] = ACTIONS(120),
    [anon_sym_LT_LT] = ACTIONS(120),
    [anon_sym_AMP] = ACTIONS(120),
    [anon_sym_CARET] = ACTIONS(120),
    [anon_sym_PIPE] = ACTIONS(120),
    [anon_sym_PLUS] = ACTIONS(120),
    [anon_sym_DASH] = ACTIONS(120),
    [anon_sym_SLASH] = ACTIONS(120),
    [anon_sym_PERCENT] = ACTIONS(120),
    [anon_sym_STAR_STAR] = ACTIONS(120),
    [anon_sym_LT] = ACTIONS(2158),
    [anon_sym_LT_EQ] = ACTIONS(154),
    [anon_sym_EQ_EQ] = ACTIONS(120),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(154),
    [anon_sym_BANG_EQ] = ACTIONS(120),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(154),
    [anon_sym_GT_EQ] = ACTIONS(154),
    [anon_sym_GT] = ACTIONS(120),
    [anon_sym_QMARK_QMARK] = ACTIONS(120),
    [anon_sym_instanceof] = ACTIONS(120),
    [anon_sym_PLUS_PLUS] = ACTIONS(154),
    [anon_sym_DASH_DASH] = ACTIONS(154),
    [anon_sym_DQUOTE] = ACTIONS(1550),
    [anon_sym_SQUOTE] = ACTIONS(1552),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(154),
    [anon_sym_QMARK] = ACTIONS(690),
    [anon_sym_satisfies] = ACTIONS(120),
    [sym__automatic_semicolon] = ACTIONS(154),
    [sym__ternary_qmark] = ACTIONS(154),
    [sym_html_comment] = ACTIONS(5),
  },
  [1174] = {
    [sym_nested_identifier] = STATE(201),
    [sym_string] = STATE(203),
    [sym__module] = STATE(231),
    [aux_sym_object_repeat1] = STATE(4810),
    [aux_sym_object_pattern_repeat1] = STATE(4815),
    [sym_identifier] = ACTIONS(3411),
    [anon_sym_STAR] = ACTIONS(120),
    [anon_sym_EQ] = ACTIONS(661),
    [anon_sym_as] = ACTIONS(120),
    [anon_sym_COMMA] = ACTIONS(154),
    [anon_sym_RBRACE] = ACTIONS(692),
    [anon_sym_BANG] = ACTIONS(120),
    [anon_sym_LPAREN] = ACTIONS(2149),
    [anon_sym_SEMI] = ACTIONS(154),
    [anon_sym_in] = ACTIONS(120),
    [anon_sym_COLON] = ACTIONS(671),
    [anon_sym_LBRACK] = ACTIONS(154),
    [anon_sym_DOT] = ACTIONS(154),
    [anon_sym_EQ_GT] = ACTIONS(682),
    [anon_sym_QMARK_DOT] = ACTIONS(154),
    [anon_sym_PLUS_EQ] = ACTIONS(160),
    [anon_sym_DASH_EQ] = ACTIONS(160),
    [anon_sym_STAR_EQ] = ACTIONS(160),
    [anon_sym_SLASH_EQ] = ACTIONS(160),
    [anon_sym_PERCENT_EQ] = ACTIONS(160),
    [anon_sym_CARET_EQ] = ACTIONS(160),
    [anon_sym_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_LT_LT_EQ] = ACTIONS(160),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(160),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP] = ACTIONS(120),
    [anon_sym_PIPE_PIPE] = ACTIONS(120),
    [anon_sym_GT_GT] = ACTIONS(120),
    [anon_sym_GT_GT_GT] = ACTIONS(120),
    [anon_sym_LT_LT] = ACTIONS(120),
    [anon_sym_AMP] = ACTIONS(120),
    [anon_sym_CARET] = ACTIONS(120),
    [anon_sym_PIPE] = ACTIONS(120),
    [anon_sym_PLUS] = ACTIONS(120),
    [anon_sym_DASH] = ACTIONS(120),
    [anon_sym_SLASH] = ACTIONS(120),
    [anon_sym_PERCENT] = ACTIONS(120),
    [anon_sym_STAR_STAR] = ACTIONS(120),
    [anon_sym_LT] = ACTIONS(2158),
    [anon_sym_LT_EQ] = ACTIONS(154),
    [anon_sym_EQ_EQ] = ACTIONS(120),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(154),
    [anon_sym_BANG_EQ] = ACTIONS(120),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(154),
    [anon_sym_GT_EQ] = ACTIONS(154),
    [anon_sym_GT] = ACTIONS(120),
    [anon_sym_QMARK_QMARK] = ACTIONS(120),
    [anon_sym_instanceof] = ACTIONS(120),
    [anon_sym_PLUS_PLUS] = ACTIONS(154),
    [anon_sym_DASH_DASH] = ACTIONS(154),
    [anon_sym_DQUOTE] = ACTIONS(3413),
    [anon_sym_SQUOTE] = ACTIONS(3415),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(154),
    [anon_sym_QMARK] = ACTIONS(690),
    [anon_sym_satisfies] = ACTIONS(120),
    [sym__automatic_semicolon] = ACTIONS(154),
    [sym__ternary_qmark] = ACTIONS(154),
    [sym_html_comment] = ACTIONS(5),
  },
  [1175] = {
    [sym_nested_identifier] = STATE(1616),
    [sym_string] = STATE(1617),
    [sym__module] = STATE(1711),
    [sym_identifier] = ACTIONS(3431),
    [anon_sym_STAR] = ACTIONS(120),
    [anon_sym_EQ] = ACTIONS(824),
    [anon_sym_as] = ACTIONS(120),
    [anon_sym_COMMA] = ACTIONS(826),
    [anon_sym_RBRACE] = ACTIONS(826),
    [anon_sym_BANG] = ACTIONS(120),
    [anon_sym_LPAREN] = ACTIONS(154),
    [anon_sym_RPAREN] = ACTIONS(826),
    [anon_sym_in] = ACTIONS(120),
    [anon_sym_COLON] = ACTIONS(826),
    [anon_sym_LBRACK] = ACTIONS(154),
    [anon_sym_RBRACK] = ACTIONS(826),
    [anon_sym_DOT] = ACTIONS(154),
    [anon_sym_EQ_GT] = ACTIONS(225),
    [anon_sym_QMARK_DOT] = ACTIONS(154),
    [anon_sym_PLUS_EQ] = ACTIONS(160),
    [anon_sym_DASH_EQ] = ACTIONS(160),
    [anon_sym_STAR_EQ] = ACTIONS(160),
    [anon_sym_SLASH_EQ] = ACTIONS(160),
    [anon_sym_PERCENT_EQ] = ACTIONS(160),
    [anon_sym_CARET_EQ] = ACTIONS(160),
    [anon_sym_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_LT_LT_EQ] = ACTIONS(160),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(160),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP] = ACTIONS(120),
    [anon_sym_PIPE_PIPE] = ACTIONS(120),
    [anon_sym_GT_GT] = ACTIONS(120),
    [anon_sym_GT_GT_GT] = ACTIONS(120),
    [anon_sym_LT_LT] = ACTIONS(120),
    [anon_sym_AMP] = ACTIONS(120),
    [anon_sym_CARET] = ACTIONS(120),
    [anon_sym_PIPE] = ACTIONS(120),
    [anon_sym_PLUS] = ACTIONS(120),
    [anon_sym_DASH] = ACTIONS(120),
    [anon_sym_SLASH] = ACTIONS(120),
    [anon_sym_PERCENT] = ACTIONS(120),
    [anon_sym_STAR_STAR] = ACTIONS(120),
    [anon_sym_LT] = ACTIONS(120),
    [anon_sym_LT_EQ] = ACTIONS(154),
    [anon_sym_EQ_EQ] = ACTIONS(120),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(154),
    [anon_sym_BANG_EQ] = ACTIONS(120),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(154),
    [anon_sym_GT_EQ] = ACTIONS(154),
    [anon_sym_GT] = ACTIONS(120),
    [anon_sym_QMARK_QMARK] = ACTIONS(120),
    [anon_sym_instanceof] = ACTIONS(120),
    [anon_sym_PLUS_PLUS] = ACTIONS(154),
    [anon_sym_DASH_DASH] = ACTIONS(154),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(154),
    [anon_sym_QMARK] = ACTIONS(828),
    [anon_sym_satisfies] = ACTIONS(120),
    [sym__ternary_qmark] = ACTIONS(154),
    [sym_html_comment] = ACTIONS(5),
  },
  [1176] = {
    [sym_nested_identifier] = STATE(1616),
    [sym_string] = STATE(1617),
    [sym__module] = STATE(1711),
    [sym_identifier] = ACTIONS(3431),
    [anon_sym_STAR] = ACTIONS(120),
    [anon_sym_EQ] = ACTIONS(220),
    [anon_sym_as] = ACTIONS(120),
    [anon_sym_COMMA] = ACTIONS(223),
    [anon_sym_RBRACE] = ACTIONS(223),
    [anon_sym_BANG] = ACTIONS(120),
    [anon_sym_LPAREN] = ACTIONS(154),
    [anon_sym_RPAREN] = ACTIONS(223),
    [anon_sym_in] = ACTIONS(120),
    [anon_sym_COLON] = ACTIONS(223),
    [anon_sym_LBRACK] = ACTIONS(154),
    [anon_sym_RBRACK] = ACTIONS(223),
    [anon_sym_DOT] = ACTIONS(154),
    [anon_sym_EQ_GT] = ACTIONS(225),
    [anon_sym_QMARK_DOT] = ACTIONS(154),
    [anon_sym_PLUS_EQ] = ACTIONS(160),
    [anon_sym_DASH_EQ] = ACTIONS(160),
    [anon_sym_STAR_EQ] = ACTIONS(160),
    [anon_sym_SLASH_EQ] = ACTIONS(160),
    [anon_sym_PERCENT_EQ] = ACTIONS(160),
    [anon_sym_CARET_EQ] = ACTIONS(160),
    [anon_sym_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_LT_LT_EQ] = ACTIONS(160),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(160),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP] = ACTIONS(120),
    [anon_sym_PIPE_PIPE] = ACTIONS(120),
    [anon_sym_GT_GT] = ACTIONS(120),
    [anon_sym_GT_GT_GT] = ACTIONS(120),
    [anon_sym_LT_LT] = ACTIONS(120),
    [anon_sym_AMP] = ACTIONS(120),
    [anon_sym_CARET] = ACTIONS(120),
    [anon_sym_PIPE] = ACTIONS(120),
    [anon_sym_PLUS] = ACTIONS(120),
    [anon_sym_DASH] = ACTIONS(120),
    [anon_sym_SLASH] = ACTIONS(120),
    [anon_sym_PERCENT] = ACTIONS(120),
    [anon_sym_STAR_STAR] = ACTIONS(120),
    [anon_sym_LT] = ACTIONS(120),
    [anon_sym_LT_EQ] = ACTIONS(154),
    [anon_sym_EQ_EQ] = ACTIONS(120),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(154),
    [anon_sym_BANG_EQ] = ACTIONS(120),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(154),
    [anon_sym_GT_EQ] = ACTIONS(154),
    [anon_sym_GT] = ACTIONS(120),
    [anon_sym_QMARK_QMARK] = ACTIONS(120),
    [anon_sym_instanceof] = ACTIONS(120),
    [anon_sym_PLUS_PLUS] = ACTIONS(154),
    [anon_sym_DASH_DASH] = ACTIONS(154),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(154),
    [anon_sym_QMARK] = ACTIONS(720),
    [anon_sym_satisfies] = ACTIONS(120),
    [sym__ternary_qmark] = ACTIONS(154),
    [sym_html_comment] = ACTIONS(5),
  },
  [1177] = {
    [sym_nested_identifier] = STATE(1616),
    [sym_string] = STATE(1617),
    [sym__module] = STATE(1711),
    [sym_identifier] = ACTIONS(3431),
    [anon_sym_STAR] = ACTIONS(120),
    [anon_sym_EQ] = ACTIONS(834),
    [anon_sym_as] = ACTIONS(120),
    [anon_sym_COMMA] = ACTIONS(154),
    [anon_sym_RBRACE] = ACTIONS(154),
    [anon_sym_BANG] = ACTIONS(120),
    [anon_sym_LPAREN] = ACTIONS(154),
    [anon_sym_SEMI] = ACTIONS(154),
    [anon_sym_in] = ACTIONS(120),
    [anon_sym_COLON] = ACTIONS(154),
    [anon_sym_LBRACK] = ACTIONS(154),
    [anon_sym_RBRACK] = ACTIONS(154),
    [anon_sym_DOT] = ACTIONS(154),
    [anon_sym_EQ_GT] = ACTIONS(844),
    [anon_sym_QMARK_DOT] = ACTIONS(154),
    [anon_sym_PLUS_EQ] = ACTIONS(160),
    [anon_sym_DASH_EQ] = ACTIONS(160),
    [anon_sym_STAR_EQ] = ACTIONS(160),
    [anon_sym_SLASH_EQ] = ACTIONS(160),
    [anon_sym_PERCENT_EQ] = ACTIONS(160),
    [anon_sym_CARET_EQ] = ACTIONS(160),
    [anon_sym_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_LT_LT_EQ] = ACTIONS(160),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(160),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP] = ACTIONS(120),
    [anon_sym_PIPE_PIPE] = ACTIONS(120),
    [anon_sym_GT_GT] = ACTIONS(120),
    [anon_sym_GT_GT_GT] = ACTIONS(120),
    [anon_sym_LT_LT] = ACTIONS(120),
    [anon_sym_AMP] = ACTIONS(120),
    [anon_sym_CARET] = ACTIONS(120),
    [anon_sym_PIPE] = ACTIONS(120),
    [anon_sym_PLUS] = ACTIONS(120),
    [anon_sym_DASH] = ACTIONS(120),
    [anon_sym_SLASH] = ACTIONS(120),
    [anon_sym_PERCENT] = ACTIONS(120),
    [anon_sym_STAR_STAR] = ACTIONS(120),
    [anon_sym_LT] = ACTIONS(120),
    [anon_sym_LT_EQ] = ACTIONS(154),
    [anon_sym_EQ_EQ] = ACTIONS(120),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(154),
    [anon_sym_BANG_EQ] = ACTIONS(120),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(154),
    [anon_sym_GT_EQ] = ACTIONS(154),
    [anon_sym_GT] = ACTIONS(120),
    [anon_sym_QMARK_QMARK] = ACTIONS(120),
    [anon_sym_instanceof] = ACTIONS(120),
    [anon_sym_PLUS_PLUS] = ACTIONS(154),
    [anon_sym_DASH_DASH] = ACTIONS(154),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(154),
    [anon_sym_satisfies] = ACTIONS(120),
    [sym__ternary_qmark] = ACTIONS(154),
    [sym_html_comment] = ACTIONS(5),
  },
  [1178] = {
    [sym_nested_identifier] = STATE(1616),
    [sym_string] = STATE(1617),
    [sym__module] = STATE(1711),
    [sym_identifier] = ACTIONS(3431),
    [anon_sym_STAR] = ACTIONS(120),
    [anon_sym_EQ] = ACTIONS(824),
    [anon_sym_as] = ACTIONS(120),
    [anon_sym_COMMA] = ACTIONS(154),
    [anon_sym_RBRACE] = ACTIONS(154),
    [anon_sym_BANG] = ACTIONS(120),
    [anon_sym_LPAREN] = ACTIONS(154),
    [anon_sym_SEMI] = ACTIONS(154),
    [anon_sym_in] = ACTIONS(120),
    [anon_sym_COLON] = ACTIONS(154),
    [anon_sym_LBRACK] = ACTIONS(154),
    [anon_sym_RBRACK] = ACTIONS(154),
    [anon_sym_DOT] = ACTIONS(154),
    [anon_sym_EQ_GT] = ACTIONS(844),
    [anon_sym_QMARK_DOT] = ACTIONS(154),
    [anon_sym_PLUS_EQ] = ACTIONS(160),
    [anon_sym_DASH_EQ] = ACTIONS(160),
    [anon_sym_STAR_EQ] = ACTIONS(160),
    [anon_sym_SLASH_EQ] = ACTIONS(160),
    [anon_sym_PERCENT_EQ] = ACTIONS(160),
    [anon_sym_CARET_EQ] = ACTIONS(160),
    [anon_sym_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_LT_LT_EQ] = ACTIONS(160),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(160),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP] = ACTIONS(120),
    [anon_sym_PIPE_PIPE] = ACTIONS(120),
    [anon_sym_GT_GT] = ACTIONS(120),
    [anon_sym_GT_GT_GT] = ACTIONS(120),
    [anon_sym_LT_LT] = ACTIONS(120),
    [anon_sym_AMP] = ACTIONS(120),
    [anon_sym_CARET] = ACTIONS(120),
    [anon_sym_PIPE] = ACTIONS(120),
    [anon_sym_PLUS] = ACTIONS(120),
    [anon_sym_DASH] = ACTIONS(120),
    [anon_sym_SLASH] = ACTIONS(120),
    [anon_sym_PERCENT] = ACTIONS(120),
    [anon_sym_STAR_STAR] = ACTIONS(120),
    [anon_sym_LT] = ACTIONS(120),
    [anon_sym_LT_EQ] = ACTIONS(154),
    [anon_sym_EQ_EQ] = ACTIONS(120),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(154),
    [anon_sym_BANG_EQ] = ACTIONS(120),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(154),
    [anon_sym_GT_EQ] = ACTIONS(154),
    [anon_sym_GT] = ACTIONS(120),
    [anon_sym_QMARK_QMARK] = ACTIONS(120),
    [anon_sym_instanceof] = ACTIONS(120),
    [anon_sym_PLUS_PLUS] = ACTIONS(154),
    [anon_sym_DASH_DASH] = ACTIONS(154),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(154),
    [anon_sym_satisfies] = ACTIONS(120),
    [sym__ternary_qmark] = ACTIONS(154),
    [sym_html_comment] = ACTIONS(5),
  },
  [1179] = {
    [sym_export_statement] = STATE(3814),
    [sym_object_pattern] = STATE(5536),
    [sym_object_assignment_pattern] = STATE(5225),
    [sym_array_pattern] = STATE(5536),
    [sym__call_signature] = STATE(3910),
    [sym__destructuring_pattern] = STATE(5536),
    [sym_spread_element] = STATE(5230),
    [sym_string] = STATE(3085),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3315),
    [sym_rest_pattern] = STATE(5225),
    [sym_method_definition] = STATE(5230),
    [sym_pair] = STATE(5230),
    [sym_pair_pattern] = STATE(5225),
    [sym__property_name] = STATE(3085),
    [sym_computed_property_name] = STATE(3085),
    [sym_method_signature] = STATE(3814),
    [sym_accessibility_modifier] = STATE(2771),
    [sym_override_modifier] = STATE(2792),
    [sym_call_signature] = STATE(3814),
    [sym_property_signature] = STATE(3814),
    [sym_type_parameters] = STATE(5233),
    [sym_construct_signature] = STATE(3814),
    [sym_index_signature] = STATE(3814),
    [aux_sym_export_statement_repeat1] = STATE(4481),
    [sym_identifier] = ACTIONS(3433),
    [anon_sym_export] = ACTIONS(3435),
    [anon_sym_STAR] = ACTIONS(3273),
    [anon_sym_type] = ACTIONS(3433),
    [anon_sym_namespace] = ACTIONS(3433),
    [anon_sym_LBRACE] = ACTIONS(3275),
    [anon_sym_COMMA] = ACTIONS(3437),
    [anon_sym_RBRACE] = ACTIONS(3437),
    [anon_sym_let] = ACTIONS(3433),
    [anon_sym_LPAREN] = ACTIONS(3281),
    [anon_sym_LBRACK] = ACTIONS(3285),
    [anon_sym_async] = ACTIONS(3440),
    [anon_sym_new] = ACTIONS(3442),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(249),
    [anon_sym_PLUS] = ACTIONS(3291),
    [anon_sym_DASH] = ACTIONS(3291),
    [anon_sym_LT] = ACTIONS(2499),
    [anon_sym_DQUOTE] = ACTIONS(1626),
    [anon_sym_SQUOTE] = ACTIONS(1628),
    [sym_comment] = ACTIONS(5),
    [sym_number] = ACTIONS(3293),
    [sym_private_property_identifier] = ACTIONS(3293),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(3444),
    [anon_sym_readonly] = ACTIONS(3446),
    [anon_sym_get] = ACTIONS(3448),
    [anon_sym_set] = ACTIONS(3448),
    [anon_sym_declare] = ACTIONS(3433),
    [anon_sym_public] = ACTIONS(3450),
    [anon_sym_private] = ACTIONS(3450),
    [anon_sym_protected] = ACTIONS(3450),
    [anon_sym_override] = ACTIONS(3452),
    [anon_sym_module] = ACTIONS(3433),
    [anon_sym_any] = ACTIONS(3433),
    [anon_sym_number] = ACTIONS(3433),
    [anon_sym_boolean] = ACTIONS(3433),
    [anon_sym_string] = ACTIONS(3433),
    [anon_sym_symbol] = ACTIONS(3433),
    [anon_sym_object] = ACTIONS(3433),
    [anon_sym_abstract] = ACTIONS(3305),
    [sym_html_comment] = ACTIONS(5),
  },
  [1180] = {
    [sym_export_statement] = STATE(3790),
    [sym_object_pattern] = STATE(5536),
    [sym_object_assignment_pattern] = STATE(5225),
    [sym_array_pattern] = STATE(5536),
    [sym__call_signature] = STATE(3910),
    [sym__destructuring_pattern] = STATE(5536),
    [sym_spread_element] = STATE(5230),
    [sym_string] = STATE(3085),
    [sym_decorator] = STATE(1344),
    [sym_formal_parameters] = STATE(3315),
    [sym_rest_pattern] = STATE(5225),
    [sym_method_definition] = STATE(5230),
    [sym_pair] = STATE(5230),
    [sym_pair_pattern] = STATE(5225),
    [sym__property_name] = STATE(3085),
    [sym_computed_property_name] = STATE(3085),
    [sym_method_signature] = STATE(3790),
    [sym_accessibility_modifier] = STATE(2771),
    [sym_override_modifier] = STATE(2792),
    [sym_call_signature] = STATE(3790),
    [sym_property_signature] = STATE(3790),
    [sym_type_parameters] = STATE(5233),
    [sym_construct_signature] = STATE(3790),
    [sym_index_signature] = STATE(3790),
    [aux_sym_export_statement_repeat1] = STATE(4481),
    [sym_identifier] = ACTIONS(3433),
    [anon_sym_export] = ACTIONS(3435),
    [anon_sym_STAR] = ACTIONS(3273),
    [anon_sym_type] = ACTIONS(3433),
    [anon_sym_namespace] = ACTIONS(3433),
    [anon_sym_LBRACE] = ACTIONS(3275),
    [anon_sym_COMMA] = ACTIONS(3437),
    [anon_sym_RBRACE] = ACTIONS(3437),
    [anon_sym_let] = ACTIONS(3433),
    [anon_sym_LPAREN] = ACTIONS(3281),
    [anon_sym_LBRACK] = ACTIONS(3285),
    [anon_sym_async] = ACTIONS(3440),
    [anon_sym_new] = ACTIONS(3442),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(249),
    [anon_sym_PLUS] = ACTIONS(3291),
    [anon_sym_DASH] = ACTIONS(3291),
    [anon_sym_LT] = ACTIONS(2499),
    [anon_sym_DQUOTE] = ACTIONS(1626),
    [anon_sym_SQUOTE] = ACTIONS(1628),
    [sym_comment] = ACTIONS(5),
    [sym_number] = ACTIONS(3293),
    [sym_private_property_identifier] = ACTIONS(3293),
    [anon_sym_AT] = ACTIONS(97),
    [anon_sym_static] = ACTIONS(3444),
    [anon_sym_readonly] = ACTIONS(3446),
    [anon_sym_get] = ACTIONS(3448),
    [anon_sym_set] = ACTIONS(3448),
    [anon_sym_declare] = ACTIONS(3433),
    [anon_sym_public] = ACTIONS(3450),
    [anon_sym_private] = ACTIONS(3450),
    [anon_sym_protected] = ACTIONS(3450),
    [anon_sym_override] = ACTIONS(3452),
    [anon_sym_module] = ACTIONS(3433),
    [anon_sym_any] = ACTIONS(3433),
    [anon_sym_number] = ACTIONS(3433),
    [anon_sym_boolean] = ACTIONS(3433),
    [anon_sym_string] = ACTIONS(3433),
    [anon_sym_symbol] = ACTIONS(3433),
    [anon_sym_object] = ACTIONS(3433),
    [anon_sym_abstract] = ACTIONS(3305),
    [sym_html_comment] = ACTIONS(5),
  },
  [1181] = {
    [sym_nested_identifier] = STATE(1616),
    [sym_string] = STATE(1617),
    [sym__module] = STATE(1711),
    [sym_identifier] = ACTIONS(3431),
    [anon_sym_STAR] = ACTIONS(120),
    [anon_sym_EQ] = ACTIONS(824),
    [anon_sym_as] = ACTIONS(120),
    [anon_sym_COMMA] = ACTIONS(154),
    [anon_sym_RBRACE] = ACTIONS(154),
    [anon_sym_BANG] = ACTIONS(120),
    [anon_sym_LPAREN] = ACTIONS(154),
    [anon_sym_SEMI] = ACTIONS(154),
    [anon_sym_in] = ACTIONS(120),
    [anon_sym_LBRACK] = ACTIONS(154),
    [anon_sym_DOT] = ACTIONS(154),
    [anon_sym_EQ_GT] = ACTIONS(682),
    [anon_sym_QMARK_DOT] = ACTIONS(154),
    [anon_sym_PLUS_EQ] = ACTIONS(160),
    [anon_sym_DASH_EQ] = ACTIONS(160),
    [anon_sym_STAR_EQ] = ACTIONS(160),
    [anon_sym_SLASH_EQ] = ACTIONS(160),
    [anon_sym_PERCENT_EQ] = ACTIONS(160),
    [anon_sym_CARET_EQ] = ACTIONS(160),
    [anon_sym_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_LT_LT_EQ] = ACTIONS(160),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(160),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP] = ACTIONS(120),
    [anon_sym_PIPE_PIPE] = ACTIONS(120),
    [anon_sym_GT_GT] = ACTIONS(120),
    [anon_sym_GT_GT_GT] = ACTIONS(120),
    [anon_sym_LT_LT] = ACTIONS(120),
    [anon_sym_AMP] = ACTIONS(120),
    [anon_sym_CARET] = ACTIONS(120),
    [anon_sym_PIPE] = ACTIONS(120),
    [anon_sym_PLUS] = ACTIONS(120),
    [anon_sym_DASH] = ACTIONS(120),
    [anon_sym_SLASH] = ACTIONS(120),
    [anon_sym_PERCENT] = ACTIONS(120),
    [anon_sym_STAR_STAR] = ACTIONS(120),
    [anon_sym_LT] = ACTIONS(120),
    [anon_sym_LT_EQ] = ACTIONS(154),
    [anon_sym_EQ_EQ] = ACTIONS(120),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(154),
    [anon_sym_BANG_EQ] = ACTIONS(120),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(154),
    [anon_sym_GT_EQ] = ACTIONS(154),
    [anon_sym_GT] = ACTIONS(120),
    [anon_sym_QMARK_QMARK] = ACTIONS(120),
    [anon_sym_instanceof] = ACTIONS(120),
    [anon_sym_PLUS_PLUS] = ACTIONS(154),
    [anon_sym_DASH_DASH] = ACTIONS(154),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(154),
    [anon_sym_satisfies] = ACTIONS(120),
    [sym__automatic_semicolon] = ACTIONS(154),
    [sym__ternary_qmark] = ACTIONS(154),
    [sym_html_comment] = ACTIONS(5),
  },
  [1182] = {
    [sym_variable_declarator] = STATE(4416),
    [sym_object_pattern] = STATE(3718),
    [sym_array_pattern] = STATE(3718),
    [sym__destructuring_pattern] = STATE(3718),
    [sym_identifier] = ACTIONS(3405),
    [anon_sym_STAR] = ACTIONS(120),
    [anon_sym_EQ] = ACTIONS(858),
    [anon_sym_as] = ACTIONS(120),
    [anon_sym_LBRACE] = ACTIONS(3407),
    [anon_sym_COMMA] = ACTIONS(154),
    [anon_sym_BANG] = ACTIONS(120),
    [anon_sym_LPAREN] = ACTIONS(154),
    [anon_sym_SEMI] = ACTIONS(154),
    [anon_sym_in] = ACTIONS(120),
    [anon_sym_COLON] = ACTIONS(878),
    [anon_sym_LBRACK] = ACTIONS(3409),
    [anon_sym_DOT] = ACTIONS(154),
    [anon_sym_EQ_GT] = ACTIONS(682),
    [anon_sym_QMARK_DOT] = ACTIONS(154),
    [anon_sym_PLUS_EQ] = ACTIONS(160),
    [anon_sym_DASH_EQ] = ACTIONS(160),
    [anon_sym_STAR_EQ] = ACTIONS(160),
    [anon_sym_SLASH_EQ] = ACTIONS(160),
    [anon_sym_PERCENT_EQ] = ACTIONS(160),
    [anon_sym_CARET_EQ] = ACTIONS(160),
    [anon_sym_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_LT_LT_EQ] = ACTIONS(160),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(160),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP] = ACTIONS(120),
    [anon_sym_PIPE_PIPE] = ACTIONS(120),
    [anon_sym_GT_GT] = ACTIONS(120),
    [anon_sym_GT_GT_GT] = ACTIONS(120),
    [anon_sym_LT_LT] = ACTIONS(120),
    [anon_sym_AMP] = ACTIONS(120),
    [anon_sym_CARET] = ACTIONS(120),
    [anon_sym_PIPE] = ACTIONS(120),
    [anon_sym_PLUS] = ACTIONS(120),
    [anon_sym_DASH] = ACTIONS(120),
    [anon_sym_SLASH] = ACTIONS(120),
    [anon_sym_PERCENT] = ACTIONS(120),
    [anon_sym_STAR_STAR] = ACTIONS(120),
    [anon_sym_LT] = ACTIONS(120),
    [anon_sym_LT_EQ] = ACTIONS(154),
    [anon_sym_EQ_EQ] = ACTIONS(120),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(154),
    [anon_sym_BANG_EQ] = ACTIONS(120),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(154),
    [anon_sym_GT_EQ] = ACTIONS(154),
    [anon_sym_GT] = ACTIONS(120),
    [anon_sym_QMARK_QMARK] = ACTIONS(120),
    [anon_sym_instanceof] = ACTIONS(120),
    [anon_sym_PLUS_PLUS] = ACTIONS(154),
    [anon_sym_DASH_DASH] = ACTIONS(154),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(154),
    [anon_sym_satisfies] = ACTIONS(120),
    [sym__automatic_semicolon] = ACTIONS(154),
    [sym__ternary_qmark] = ACTIONS(154),
    [sym_html_comment] = ACTIONS(5),
  },
  [1183] = {
    [sym_nested_identifier] = STATE(783),
    [sym_string] = STATE(798),
    [sym__module] = STATE(878),
    [sym_identifier] = ACTIONS(3421),
    [anon_sym_STAR] = ACTIONS(120),
    [anon_sym_EQ] = ACTIONS(858),
    [anon_sym_as] = ACTIONS(120),
    [anon_sym_COMMA] = ACTIONS(154),
    [anon_sym_BANG] = ACTIONS(120),
    [anon_sym_LPAREN] = ACTIONS(154),
    [anon_sym_SEMI] = ACTIONS(154),
    [anon_sym_in] = ACTIONS(120),
    [anon_sym_COLON] = ACTIONS(878),
    [anon_sym_LBRACK] = ACTIONS(154),
    [anon_sym_DOT] = ACTIONS(154),
    [anon_sym_EQ_GT] = ACTIONS(682),
    [anon_sym_QMARK_DOT] = ACTIONS(154),
    [anon_sym_PLUS_EQ] = ACTIONS(160),
    [anon_sym_DASH_EQ] = ACTIONS(160),
    [anon_sym_STAR_EQ] = ACTIONS(160),
    [anon_sym_SLASH_EQ] = ACTIONS(160),
    [anon_sym_PERCENT_EQ] = ACTIONS(160),
    [anon_sym_CARET_EQ] = ACTIONS(160),
    [anon_sym_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_LT_LT_EQ] = ACTIONS(160),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(160),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP] = ACTIONS(120),
    [anon_sym_PIPE_PIPE] = ACTIONS(120),
    [anon_sym_GT_GT] = ACTIONS(120),
    [anon_sym_GT_GT_GT] = ACTIONS(120),
    [anon_sym_LT_LT] = ACTIONS(120),
    [anon_sym_AMP] = ACTIONS(120),
    [anon_sym_CARET] = ACTIONS(120),
    [anon_sym_PIPE] = ACTIONS(120),
    [anon_sym_PLUS] = ACTIONS(120),
    [anon_sym_DASH] = ACTIONS(120),
    [anon_sym_SLASH] = ACTIONS(120),
    [anon_sym_PERCENT] = ACTIONS(120),
    [anon_sym_STAR_STAR] = ACTIONS(120),
    [anon_sym_LT] = ACTIONS(120),
    [anon_sym_LT_EQ] = ACTIONS(154),
    [anon_sym_EQ_EQ] = ACTIONS(120),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(154),
    [anon_sym_BANG_EQ] = ACTIONS(120),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(154),
    [anon_sym_GT_EQ] = ACTIONS(154),
    [anon_sym_GT] = ACTIONS(120),
    [anon_sym_QMARK_QMARK] = ACTIONS(120),
    [anon_sym_instanceof] = ACTIONS(120),
    [anon_sym_PLUS_PLUS] = ACTIONS(154),
    [anon_sym_DASH_DASH] = ACTIONS(154),
    [anon_sym_DQUOTE] = ACTIONS(1550),
    [anon_sym_SQUOTE] = ACTIONS(1552),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(154),
    [anon_sym_satisfies] = ACTIONS(120),
    [sym__automatic_semicolon] = ACTIONS(154),
    [sym__ternary_qmark] = ACTIONS(154),
    [sym_html_comment] = ACTIONS(5),
  },
  [1184] = {
    [sym_nested_identifier] = STATE(1608),
    [sym_string] = STATE(1612),
    [sym__module] = STATE(1771),
    [sym_identifier] = ACTIONS(3454),
    [anon_sym_STAR] = ACTIONS(120),
    [anon_sym_EQ] = ACTIONS(858),
    [anon_sym_as] = ACTIONS(120),
    [anon_sym_COMMA] = ACTIONS(154),
    [anon_sym_BANG] = ACTIONS(120),
    [anon_sym_LPAREN] = ACTIONS(154),
    [anon_sym_SEMI] = ACTIONS(154),
    [anon_sym_in] = ACTIONS(120),
    [anon_sym_COLON] = ACTIONS(878),
    [anon_sym_LBRACK] = ACTIONS(154),
    [anon_sym_DOT] = ACTIONS(154),
    [anon_sym_EQ_GT] = ACTIONS(682),
    [anon_sym_QMARK_DOT] = ACTIONS(154),
    [anon_sym_PLUS_EQ] = ACTIONS(160),
    [anon_sym_DASH_EQ] = ACTIONS(160),
    [anon_sym_STAR_EQ] = ACTIONS(160),
    [anon_sym_SLASH_EQ] = ACTIONS(160),
    [anon_sym_PERCENT_EQ] = ACTIONS(160),
    [anon_sym_CARET_EQ] = ACTIONS(160),
    [anon_sym_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_LT_LT_EQ] = ACTIONS(160),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(160),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP] = ACTIONS(120),
    [anon_sym_PIPE_PIPE] = ACTIONS(120),
    [anon_sym_GT_GT] = ACTIONS(120),
    [anon_sym_GT_GT_GT] = ACTIONS(120),
    [anon_sym_LT_LT] = ACTIONS(120),
    [anon_sym_AMP] = ACTIONS(120),
    [anon_sym_CARET] = ACTIONS(120),
    [anon_sym_PIPE] = ACTIONS(120),
    [anon_sym_PLUS] = ACTIONS(120),
    [anon_sym_DASH] = ACTIONS(120),
    [anon_sym_SLASH] = ACTIONS(120),
    [anon_sym_PERCENT] = ACTIONS(120),
    [anon_sym_STAR_STAR] = ACTIONS(120),
    [anon_sym_LT] = ACTIONS(120),
    [anon_sym_LT_EQ] = ACTIONS(154),
    [anon_sym_EQ_EQ] = ACTIONS(120),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(154),
    [anon_sym_BANG_EQ] = ACTIONS(120),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(154),
    [anon_sym_GT_EQ] = ACTIONS(154),
    [anon_sym_GT] = ACTIONS(120),
    [anon_sym_QMARK_QMARK] = ACTIONS(120),
    [anon_sym_instanceof] = ACTIONS(120),
    [anon_sym_PLUS_PLUS] = ACTIONS(154),
    [anon_sym_DASH_DASH] = ACTIONS(154),
    [anon_sym_DQUOTE] = ACTIONS(83),
    [anon_sym_SQUOTE] = ACTIONS(85),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(154),
    [anon_sym_satisfies] = ACTIONS(120),
    [sym__automatic_semicolon] = ACTIONS(154),
    [sym__ternary_qmark] = ACTIONS(154),
    [sym_html_comment] = ACTIONS(5),
  },
  [1185] = {
    [sym_nested_identifier] = STATE(1616),
    [sym_string] = STATE(1617),
    [sym__module] = STATE(1711),
    [sym_identifier] = ACTIONS(3431),
    [anon_sym_STAR] = ACTIONS(120),
    [anon_sym_EQ] = ACTIONS(834),
    [anon_sym_as] = ACTIONS(120),
    [anon_sym_COMMA] = ACTIONS(899),
    [anon_sym_RBRACE] = ACTIONS(899),
    [anon_sym_BANG] = ACTIONS(120),
    [anon_sym_LPAREN] = ACTIONS(154),
    [anon_sym_in] = ACTIONS(120),
    [anon_sym_COLON] = ACTIONS(826),
    [anon_sym_LBRACK] = ACTIONS(154),
    [anon_sym_RBRACK] = ACTIONS(899),
    [anon_sym_DOT] = ACTIONS(154),
    [anon_sym_EQ_GT] = ACTIONS(844),
    [anon_sym_QMARK_DOT] = ACTIONS(154),
    [anon_sym_PLUS_EQ] = ACTIONS(160),
    [anon_sym_DASH_EQ] = ACTIONS(160),
    [anon_sym_STAR_EQ] = ACTIONS(160),
    [anon_sym_SLASH_EQ] = ACTIONS(160),
    [anon_sym_PERCENT_EQ] = ACTIONS(160),
    [anon_sym_CARET_EQ] = ACTIONS(160),
    [anon_sym_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_LT_LT_EQ] = ACTIONS(160),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(160),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP] = ACTIONS(120),
    [anon_sym_PIPE_PIPE] = ACTIONS(120),
    [anon_sym_GT_GT] = ACTIONS(120),
    [anon_sym_GT_GT_GT] = ACTIONS(120),
    [anon_sym_LT_LT] = ACTIONS(120),
    [anon_sym_AMP] = ACTIONS(120),
    [anon_sym_CARET] = ACTIONS(120),
    [anon_sym_PIPE] = ACTIONS(120),
    [anon_sym_PLUS] = ACTIONS(120),
    [anon_sym_DASH] = ACTIONS(120),
    [anon_sym_SLASH] = ACTIONS(120),
    [anon_sym_PERCENT] = ACTIONS(120),
    [anon_sym_STAR_STAR] = ACTIONS(120),
    [anon_sym_LT] = ACTIONS(120),
    [anon_sym_LT_EQ] = ACTIONS(154),
    [anon_sym_EQ_EQ] = ACTIONS(120),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(154),
    [anon_sym_BANG_EQ] = ACTIONS(120),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(154),
    [anon_sym_GT_EQ] = ACTIONS(154),
    [anon_sym_GT] = ACTIONS(120),
    [anon_sym_QMARK_QMARK] = ACTIONS(120),
    [anon_sym_instanceof] = ACTIONS(120),
    [anon_sym_PLUS_PLUS] = ACTIONS(154),
    [anon_sym_DASH_DASH] = ACTIONS(154),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(154),
    [anon_sym_satisfies] = ACTIONS(120),
    [sym__ternary_qmark] = ACTIONS(154),
    [sym_html_comment] = ACTIONS(5),
  },
  [1186] = {
    [sym_nested_identifier] = STATE(1616),
    [sym_string] = STATE(1617),
    [sym__module] = STATE(1711),
    [sym_identifier] = ACTIONS(3431),
    [anon_sym_STAR] = ACTIONS(120),
    [anon_sym_EQ] = ACTIONS(117),
    [anon_sym_as] = ACTIONS(120),
    [anon_sym_COMMA] = ACTIONS(126),
    [anon_sym_BANG] = ACTIONS(120),
    [anon_sym_LPAREN] = ACTIONS(154),
    [anon_sym_RPAREN] = ACTIONS(126),
    [anon_sym_in] = ACTIONS(120),
    [anon_sym_COLON] = ACTIONS(126),
    [anon_sym_LBRACK] = ACTIONS(154),
    [anon_sym_DOT] = ACTIONS(154),
    [anon_sym_EQ_GT] = ACTIONS(152),
    [anon_sym_QMARK_DOT] = ACTIONS(154),
    [anon_sym_PLUS_EQ] = ACTIONS(160),
    [anon_sym_DASH_EQ] = ACTIONS(160),
    [anon_sym_STAR_EQ] = ACTIONS(160),
    [anon_sym_SLASH_EQ] = ACTIONS(160),
    [anon_sym_PERCENT_EQ] = ACTIONS(160),
    [anon_sym_CARET_EQ] = ACTIONS(160),
    [anon_sym_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_LT_LT_EQ] = ACTIONS(160),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(160),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP] = ACTIONS(120),
    [anon_sym_PIPE_PIPE] = ACTIONS(120),
    [anon_sym_GT_GT] = ACTIONS(120),
    [anon_sym_GT_GT_GT] = ACTIONS(120),
    [anon_sym_LT_LT] = ACTIONS(120),
    [anon_sym_AMP] = ACTIONS(120),
    [anon_sym_CARET] = ACTIONS(120),
    [anon_sym_PIPE] = ACTIONS(120),
    [anon_sym_PLUS] = ACTIONS(120),
    [anon_sym_DASH] = ACTIONS(120),
    [anon_sym_SLASH] = ACTIONS(120),
    [anon_sym_PERCENT] = ACTIONS(120),
    [anon_sym_STAR_STAR] = ACTIONS(120),
    [anon_sym_LT] = ACTIONS(120),
    [anon_sym_LT_EQ] = ACTIONS(154),
    [anon_sym_EQ_EQ] = ACTIONS(120),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(154),
    [anon_sym_BANG_EQ] = ACTIONS(120),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(154),
    [anon_sym_GT_EQ] = ACTIONS(154),
    [anon_sym_GT] = ACTIONS(120),
    [anon_sym_QMARK_QMARK] = ACTIONS(120),
    [anon_sym_instanceof] = ACTIONS(120),
    [anon_sym_PLUS_PLUS] = ACTIONS(154),
    [anon_sym_DASH_DASH] = ACTIONS(154),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(154),
    [anon_sym_QMARK] = ACTIONS(720),
    [anon_sym_satisfies] = ACTIONS(120),
    [sym__ternary_qmark] = ACTIONS(154),
    [sym_html_comment] = ACTIONS(5),
  },
  [1187] = {
    [sym_nested_identifier] = STATE(1608),
    [sym_string] = STATE(1612),
    [sym__module] = STATE(1771),
    [sym_identifier] = ACTIONS(3454),
    [anon_sym_STAR] = ACTIONS(120),
    [anon_sym_EQ] = ACTIONS(866),
    [anon_sym_as] = ACTIONS(120),
    [anon_sym_COMMA] = ACTIONS(154),
    [anon_sym_BANG] = ACTIONS(120),
    [anon_sym_LPAREN] = ACTIONS(154),
    [anon_sym_SEMI] = ACTIONS(154),
    [anon_sym_in] = ACTIONS(120),
    [anon_sym_of] = ACTIONS(120),
    [anon_sym_LBRACK] = ACTIONS(154),
    [anon_sym_DOT] = ACTIONS(154),
    [anon_sym_EQ_GT] = ACTIONS(872),
    [anon_sym_QMARK_DOT] = ACTIONS(154),
    [anon_sym_PLUS_EQ] = ACTIONS(160),
    [anon_sym_DASH_EQ] = ACTIONS(160),
    [anon_sym_STAR_EQ] = ACTIONS(160),
    [anon_sym_SLASH_EQ] = ACTIONS(160),
    [anon_sym_PERCENT_EQ] = ACTIONS(160),
    [anon_sym_CARET_EQ] = ACTIONS(160),
    [anon_sym_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_LT_LT_EQ] = ACTIONS(160),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(160),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP] = ACTIONS(120),
    [anon_sym_PIPE_PIPE] = ACTIONS(120),
    [anon_sym_GT_GT] = ACTIONS(120),
    [anon_sym_GT_GT_GT] = ACTIONS(120),
    [anon_sym_LT_LT] = ACTIONS(120),
    [anon_sym_AMP] = ACTIONS(120),
    [anon_sym_CARET] = ACTIONS(120),
    [anon_sym_PIPE] = ACTIONS(120),
    [anon_sym_PLUS] = ACTIONS(120),
    [anon_sym_DASH] = ACTIONS(120),
    [anon_sym_SLASH] = ACTIONS(120),
    [anon_sym_PERCENT] = ACTIONS(120),
    [anon_sym_STAR_STAR] = ACTIONS(120),
    [anon_sym_LT] = ACTIONS(120),
    [anon_sym_LT_EQ] = ACTIONS(154),
    [anon_sym_EQ_EQ] = ACTIONS(120),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(154),
    [anon_sym_BANG_EQ] = ACTIONS(120),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(154),
    [anon_sym_GT_EQ] = ACTIONS(154),
    [anon_sym_GT] = ACTIONS(120),
    [anon_sym_QMARK_QMARK] = ACTIONS(120),
    [anon_sym_instanceof] = ACTIONS(120),
    [anon_sym_PLUS_PLUS] = ACTIONS(154),
    [anon_sym_DASH_DASH] = ACTIONS(154),
    [anon_sym_DQUOTE] = ACTIONS(83),
    [anon_sym_SQUOTE] = ACTIONS(85),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(154),
    [anon_sym_satisfies] = ACTIONS(120),
    [sym__automatic_semicolon] = ACTIONS(154),
    [sym__ternary_qmark] = ACTIONS(154),
    [sym_html_comment] = ACTIONS(5),
  },
  [1188] = {
    [sym_nested_identifier] = STATE(1616),
    [sym_string] = STATE(1617),
    [sym__module] = STATE(1711),
    [sym_identifier] = ACTIONS(3431),
    [anon_sym_STAR] = ACTIONS(120),
    [anon_sym_EQ] = ACTIONS(824),
    [anon_sym_as] = ACTIONS(120),
    [anon_sym_COMMA] = ACTIONS(154),
    [anon_sym_BANG] = ACTIONS(120),
    [anon_sym_LPAREN] = ACTIONS(154),
    [anon_sym_SEMI] = ACTIONS(154),
    [anon_sym_in] = ACTIONS(120),
    [anon_sym_of] = ACTIONS(120),
    [anon_sym_LBRACK] = ACTIONS(154),
    [anon_sym_DOT] = ACTIONS(154),
    [anon_sym_EQ_GT] = ACTIONS(872),
    [anon_sym_QMARK_DOT] = ACTIONS(154),
    [anon_sym_PLUS_EQ] = ACTIONS(160),
    [anon_sym_DASH_EQ] = ACTIONS(160),
    [anon_sym_STAR_EQ] = ACTIONS(160),
    [anon_sym_SLASH_EQ] = ACTIONS(160),
    [anon_sym_PERCENT_EQ] = ACTIONS(160),
    [anon_sym_CARET_EQ] = ACTIONS(160),
    [anon_sym_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_LT_LT_EQ] = ACTIONS(160),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(160),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP] = ACTIONS(120),
    [anon_sym_PIPE_PIPE] = ACTIONS(120),
    [anon_sym_GT_GT] = ACTIONS(120),
    [anon_sym_GT_GT_GT] = ACTIONS(120),
    [anon_sym_LT_LT] = ACTIONS(120),
    [anon_sym_AMP] = ACTIONS(120),
    [anon_sym_CARET] = ACTIONS(120),
    [anon_sym_PIPE] = ACTIONS(120),
    [anon_sym_PLUS] = ACTIONS(120),
    [anon_sym_DASH] = ACTIONS(120),
    [anon_sym_SLASH] = ACTIONS(120),
    [anon_sym_PERCENT] = ACTIONS(120),
    [anon_sym_STAR_STAR] = ACTIONS(120),
    [anon_sym_LT] = ACTIONS(120),
    [anon_sym_LT_EQ] = ACTIONS(154),
    [anon_sym_EQ_EQ] = ACTIONS(120),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(154),
    [anon_sym_BANG_EQ] = ACTIONS(120),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(154),
    [anon_sym_GT_EQ] = ACTIONS(154),
    [anon_sym_GT] = ACTIONS(120),
    [anon_sym_QMARK_QMARK] = ACTIONS(120),
    [anon_sym_instanceof] = ACTIONS(120),
    [anon_sym_PLUS_PLUS] = ACTIONS(154),
    [anon_sym_DASH_DASH] = ACTIONS(154),
    [anon_sym_DQUOTE] = ACTIONS(184),
    [anon_sym_SQUOTE] = ACTIONS(186),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(154),
    [anon_sym_satisfies] = ACTIONS(120),
    [sym__automatic_semicolon] = ACTIONS(154),
    [sym__ternary_qmark] = ACTIONS(154),
    [sym_html_comment] = ACTIONS(5),
  },
  [1189] = {
    [sym_nested_identifier] = STATE(1608),
    [sym_string] = STATE(1612),
    [sym__module] = STATE(1771),
    [sym_identifier] = ACTIONS(3454),
    [anon_sym_STAR] = ACTIONS(120),
    [anon_sym_EQ] = ACTIONS(858),
    [anon_sym_as] = ACTIONS(120),
    [anon_sym_COMMA] = ACTIONS(154),
    [anon_sym_RBRACE] = ACTIONS(154),
    [anon_sym_BANG] = ACTIONS(120),
    [anon_sym_LPAREN] = ACTIONS(154),
    [anon_sym_SEMI] = ACTIONS(154),
    [anon_sym_in] = ACTIONS(120),
    [anon_sym_LBRACK] = ACTIONS(154),
    [anon_sym_DOT] = ACTIONS(154),
    [anon_sym_EQ_GT] = ACTIONS(682),
    [anon_sym_QMARK_DOT] = ACTIONS(154),
    [anon_sym_PLUS_EQ] = ACTIONS(160),
    [anon_sym_DASH_EQ] = ACTIONS(160),
    [anon_sym_STAR_EQ] = ACTIONS(160),
    [anon_sym_SLASH_EQ] = ACTIONS(160),
    [anon_sym_PERCENT_EQ] = ACTIONS(160),
    [anon_sym_CARET_EQ] = ACTIONS(160),
    [anon_sym_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_LT_LT_EQ] = ACTIONS(160),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(160),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP] = ACTIONS(120),
    [anon_sym_PIPE_PIPE] = ACTIONS(120),
    [anon_sym_GT_GT] = ACTIONS(120),
    [anon_sym_GT_GT_GT] = ACTIONS(120),
    [anon_sym_LT_LT] = ACTIONS(120),
    [anon_sym_AMP] = ACTIONS(120),
    [anon_sym_CARET] = ACTIONS(120),
    [anon_sym_PIPE] = ACTIONS(120),
    [anon_sym_PLUS] = ACTIONS(120),
    [anon_sym_DASH] = ACTIONS(120),
    [anon_sym_SLASH] = ACTIONS(120),
    [anon_sym_PERCENT] = ACTIONS(120),
    [anon_sym_STAR_STAR] = ACTIONS(120),
    [anon_sym_LT] = ACTIONS(120),
    [anon_sym_LT_EQ] = ACTIONS(154),
    [anon_sym_EQ_EQ] = ACTIONS(120),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(154),
    [anon_sym_BANG_EQ] = ACTIONS(120),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(154),
    [anon_sym_GT_EQ] = ACTIONS(154),
    [anon_sym_GT] = ACTIONS(120),
    [anon_sym_QMARK_QMARK] = ACTIONS(120),
    [anon_sym_instanceof] = ACTIONS(120),
    [anon_sym_PLUS_PLUS] = ACTIONS(154),
    [anon_sym_DASH_DASH] = ACTIONS(154),
    [anon_sym_DQUOTE] = ACTIONS(83),
    [anon_sym_SQUOTE] = ACTIONS(85),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(154),
    [anon_sym_satisfies] = ACTIONS(120),
    [sym__automatic_semicolon] = ACTIONS(154),
    [sym__ternary_qmark] = ACTIONS(154),
    [sym_html_comment] = ACTIONS(5),
  },
  [1190] = {
    [sym_nested_identifier] = STATE(201),
    [sym_string] = STATE(203),
    [sym__module] = STATE(231),
    [sym_identifier] = ACTIONS(3411),
    [anon_sym_STAR] = ACTIONS(120),
    [anon_sym_EQ] = ACTIONS(858),
    [anon_sym_as] = ACTIONS(120),
    [anon_sym_COMMA] = ACTIONS(154),
    [anon_sym_BANG] = ACTIONS(120),
    [anon_sym_LPAREN] = ACTIONS(154),
    [anon_sym_SEMI] = ACTIONS(154),
    [anon_sym_in] = ACTIONS(120),
    [anon_sym_COLON] = ACTIONS(860),
    [anon_sym_LBRACK] = ACTIONS(154),
    [anon_sym_DOT] = ACTIONS(154),
    [anon_sym_EQ_GT] = ACTIONS(682),
    [anon_sym_QMARK_DOT] = ACTIONS(154),
    [anon_sym_PLUS_EQ] = ACTIONS(160),
    [anon_sym_DASH_EQ] = ACTIONS(160),
    [anon_sym_STAR_EQ] = ACTIONS(160),
    [anon_sym_SLASH_EQ] = ACTIONS(160),
    [anon_sym_PERCENT_EQ] = ACTIONS(160),
    [anon_sym_CARET_EQ] = ACTIONS(160),
    [anon_sym_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_LT_LT_EQ] = ACTIONS(160),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(160),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP] = ACTIONS(120),
    [anon_sym_PIPE_PIPE] = ACTIONS(120),
    [anon_sym_GT_GT] = ACTIONS(120),
    [anon_sym_GT_GT_GT] = ACTIONS(120),
    [anon_sym_LT_LT] = ACTIONS(120),
    [anon_sym_AMP] = ACTIONS(120),
    [anon_sym_CARET] = ACTIONS(120),
    [anon_sym_PIPE] = ACTIONS(120),
    [anon_sym_PLUS] = ACTIONS(120),
    [anon_sym_DASH] = ACTIONS(120),
    [anon_sym_SLASH] = ACTIONS(120),
    [anon_sym_PERCENT] = ACTIONS(120),
    [anon_sym_STAR_STAR] = ACTIONS(120),
    [anon_sym_LT] = ACTIONS(120),
    [anon_sym_LT_EQ] = ACTIONS(154),
    [anon_sym_EQ_EQ] = ACTIONS(120),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(154),
    [anon_sym_BANG_EQ] = ACTIONS(120),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(154),
    [anon_sym_GT_EQ] = ACTIONS(154),
    [anon_sym_GT] = ACTIONS(120),
    [anon_sym_QMARK_QMARK] = ACTIONS(120),
    [anon_sym_instanceof] = ACTIONS(120),
    [anon_sym_PLUS_PLUS] = ACTIONS(154),
    [anon_sym_DASH_DASH] = ACTIONS(154),
    [anon_sym_DQUOTE] = ACTIONS(3413),
    [anon_sym_SQUOTE] = ACTIONS(3415),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(154),
    [anon_sym_satisfies] = ACTIONS(120),
    [sym__automatic_semicolon] = ACTIONS(154),
    [sym__ternary_qmark] = ACTIONS(154),
    [sym_html_comment] = ACTIONS(5),
  },
  [1191] = {
    [sym_nested_identifier] = STATE(783),
    [sym_string] = STATE(798),
    [sym__module] = STATE(878),
    [sym_identifier] = ACTIONS(3421),
    [anon_sym_STAR] = ACTIONS(120),
    [anon_sym_EQ] = ACTIONS(858),
    [anon_sym_as] = ACTIONS(120),
    [anon_sym_COMMA] = ACTIONS(154),
    [anon_sym_BANG] = ACTIONS(120),
    [anon_sym_LPAREN] = ACTIONS(154),
    [anon_sym_SEMI] = ACTIONS(154),
    [anon_sym_in] = ACTIONS(120),
    [anon_sym_COLON] = ACTIONS(860),
    [anon_sym_LBRACK] = ACTIONS(154),
    [anon_sym_DOT] = ACTIONS(154),
    [anon_sym_EQ_GT] = ACTIONS(682),
    [anon_sym_QMARK_DOT] = ACTIONS(154),
    [anon_sym_PLUS_EQ] = ACTIONS(160),
    [anon_sym_DASH_EQ] = ACTIONS(160),
    [anon_sym_STAR_EQ] = ACTIONS(160),
    [anon_sym_SLASH_EQ] = ACTIONS(160),
    [anon_sym_PERCENT_EQ] = ACTIONS(160),
    [anon_sym_CARET_EQ] = ACTIONS(160),
    [anon_sym_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_LT_LT_EQ] = ACTIONS(160),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(160),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP] = ACTIONS(120),
    [anon_sym_PIPE_PIPE] = ACTIONS(120),
    [anon_sym_GT_GT] = ACTIONS(120),
    [anon_sym_GT_GT_GT] = ACTIONS(120),
    [anon_sym_LT_LT] = ACTIONS(120),
    [anon_sym_AMP] = ACTIONS(120),
    [anon_sym_CARET] = ACTIONS(120),
    [anon_sym_PIPE] = ACTIONS(120),
    [anon_sym_PLUS] = ACTIONS(120),
    [anon_sym_DASH] = ACTIONS(120),
    [anon_sym_SLASH] = ACTIONS(120),
    [anon_sym_PERCENT] = ACTIONS(120),
    [anon_sym_STAR_STAR] = ACTIONS(120),
    [anon_sym_LT] = ACTIONS(120),
    [anon_sym_LT_EQ] = ACTIONS(154),
    [anon_sym_EQ_EQ] = ACTIONS(120),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(154),
    [anon_sym_BANG_EQ] = ACTIONS(120),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(154),
    [anon_sym_GT_EQ] = ACTIONS(154),
    [anon_sym_GT] = ACTIONS(120),
    [anon_sym_QMARK_QMARK] = ACTIONS(120),
    [anon_sym_instanceof] = ACTIONS(120),
    [anon_sym_PLUS_PLUS] = ACTIONS(154),
    [anon_sym_DASH_DASH] = ACTIONS(154),
    [anon_sym_DQUOTE] = ACTIONS(1550),
    [anon_sym_SQUOTE] = ACTIONS(1552),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(154),
    [anon_sym_satisfies] = ACTIONS(120),
    [sym__automatic_semicolon] = ACTIONS(154),
    [sym__ternary_qmark] = ACTIONS(154),
    [sym_html_comment] = ACTIONS(5),
  },
  [1192] = {
    [sym_variable_declarator] = STATE(4416),
    [sym_object_pattern] = STATE(3718),
    [sym_array_pattern] = STATE(3718),
    [sym__destructuring_pattern] = STATE(3718),
    [sym_identifier] = ACTIONS(3405),
    [anon_sym_STAR] = ACTIONS(120),
    [anon_sym_EQ] = ACTIONS(858),
    [anon_sym_as] = ACTIONS(120),
    [anon_sym_LBRACE] = ACTIONS(3407),
    [anon_sym_COMMA] = ACTIONS(154),
    [anon_sym_BANG] = ACTIONS(120),
    [anon_sym_LPAREN] = ACTIONS(154),
    [anon_sym_SEMI] = ACTIONS(154),
    [anon_sym_in] = ACTIONS(120),
    [anon_sym_COLON] = ACTIONS(860),
    [anon_sym_LBRACK] = ACTIONS(3409),
    [anon_sym_DOT] = ACTIONS(154),
    [anon_sym_EQ_GT] = ACTIONS(682),
    [anon_sym_QMARK_DOT] = ACTIONS(154),
    [anon_sym_PLUS_EQ] = ACTIONS(160),
    [anon_sym_DASH_EQ] = ACTIONS(160),
    [anon_sym_STAR_EQ] = ACTIONS(160),
    [anon_sym_SLASH_EQ] = ACTIONS(160),
    [anon_sym_PERCENT_EQ] = ACTIONS(160),
    [anon_sym_CARET_EQ] = ACTIONS(160),
    [anon_sym_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(160),
    [anon_sym_LT_LT_EQ] = ACTIONS(160),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(160),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(160),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(160),
    [anon_sym_AMP_AMP] = ACTIONS(120),
    [anon_sym_PIPE_PIPE] = ACTIONS(120),
    [anon_sym_GT_GT] = ACTIONS(120),
    [anon_sym_GT_GT_GT] = ACTIONS(120),
    [anon_sym_LT_LT] = ACTIONS(120),
    [anon_sym_AMP] = ACTIONS(120),
    [anon_sym_CARET] = ACTIONS(120),
    [anon_sym_PIPE] = ACTIONS(120),
    [anon_sym_PLUS] = ACTIONS(120),
    [anon_sym_DASH] = ACTIONS(120),
    [anon_sym_SLASH] = ACTIONS(120),
    [anon_sym_PERCENT] = ACTIONS(120),
    [anon_sym_STAR_STAR] = ACTIONS(120),
    [anon_sym_LT] = ACTIONS(120),
    [anon_sym_LT_EQ] = ACTIONS(154),
    [anon_sym_EQ_EQ] = ACTIONS(120),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(154),
    [anon_sym_BANG_EQ] = ACTIONS(120),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(154),
    [anon_sym_GT_EQ] = ACTIONS(154),
    [anon_sym_GT] = ACTIONS(120),
    [anon_sym_QMARK_QMARK] = ACTIONS(120),
    [anon_sym_instanceof] = ACTIONS(120),
    [anon_sym_PLUS_PLUS] = ACTIONS(154),
    [anon_sym_DASH_DASH] = ACTIONS(154),
    [sym_comment] = ACTIONS(5),
    [anon_sym_BQUOTE] = ACTIONS(154),
    [anon_sym_satisfies] = ACTIONS(120),
    [sym__automatic_semicolon] = ACTIONS(154),
    [sym__ternary_qmark] = ACTIONS(154),
    [sym_html_comment] = ACTIONS(5),
  },
};

static const uint16_t ts_small_parse_table[] = {
  [0] = 14,
    ACTIONS(661), 1,
      anon_sym_EQ,
    ACTIONS(671), 1,
      anon_sym_COLON,
    ACTIONS(682), 1,
      anon_sym_EQ_GT,
    ACTIONS(690), 1,
      anon_sym_QMARK,
    ACTIONS(694), 1,
      anon_sym_RBRACE,
    ACTIONS(2149), 1,
      anon_sym_LPAREN,
    ACTIONS(2158), 1,
      anon_sym_LT,
    ACTIONS(3456), 1,
      sym_identifier,
    STATE(4792), 1,
      aux_sym_object_repeat1,
    STATE(4815), 1,
      aux_sym_object_pattern_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(154), 14,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
    ACTIONS(160), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
    ACTIONS(120), 23,
      anon_sym_STAR,
      anon_sym_as,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_satisfies,
  [93] = 14,
    ACTIONS(661), 1,
      anon_sym_EQ,
    ACTIONS(667), 1,
      anon_sym_RBRACE,
    ACTIONS(671), 1,
      anon_sym_COLON,
    ACTIONS(682), 1,
      anon_sym_EQ_GT,
    ACTIONS(690), 1,
      anon_sym_QMARK,
    ACTIONS(2149), 1,
      anon_sym_LPAREN,
    ACTIONS(2158), 1,
      anon_sym_LT,
    ACTIONS(3456), 1,
      sym_identifier,
    STATE(4792), 1,
      aux_sym_object_repeat1,
    STATE(4815), 1,
      aux_sym_object_pattern_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(154), 14,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
    ACTIONS(160), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
    ACTIONS(120), 23,
      anon_sym_STAR,
      anon_sym_as,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_satisfies,
  [186] = 15,
    ACTIONS(126), 1,
      anon_sym_RBRACK,
    ACTIONS(184), 1,
      anon_sym_DQUOTE,
    ACTIONS(186), 1,
      anon_sym_SQUOTE,
    ACTIONS(223), 1,
      anon_sym_COMMA,
    ACTIONS(886), 1,
      anon_sym_EQ,
    ACTIONS(891), 1,
      anon_sym_COLON,
    ACTIONS(895), 1,
      anon_sym_EQ_GT,
    ACTIONS(3431), 1,
      sym_identifier,
    STATE(1616), 1,
      sym_nested_identifier,
    STATE(1617), 1,
      sym_string,
    STATE(1711), 1,
      sym__module,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(154), 12,
      sym__ternary_qmark,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
    ACTIONS(160), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
    ACTIONS(120), 24,
      anon_sym_STAR,
      anon_sym_as,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_satisfies,
  [281] = 14,
    ACTIONS(661), 1,
      anon_sym_EQ,
    ACTIONS(671), 1,
      anon_sym_COLON,
    ACTIONS(682), 1,
      anon_sym_EQ_GT,
    ACTIONS(690), 1,
      anon_sym_QMARK,
    ACTIONS(692), 1,
      anon_sym_RBRACE,
    ACTIONS(2149), 1,
      anon_sym_LPAREN,
    ACTIONS(2158), 1,
      anon_sym_LT,
    ACTIONS(3456), 1,
      sym_identifier,
    STATE(4810), 1,
      aux_sym_object_repeat1,
    STATE(4815), 1,
      aux_sym_object_pattern_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(154), 14,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
    ACTIONS(160), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
    ACTIONS(120), 23,
      anon_sym_STAR,
      anon_sym_as,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_satisfies,
  [374] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3458), 23,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK,
    ACTIONS(3460), 39,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_of,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_implements,
  [445] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3462), 23,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK,
    ACTIONS(3464), 39,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_of,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_implements,
  [516] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3466), 23,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK,
    ACTIONS(3468), 39,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_of,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_implements,
  [587] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3470), 23,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK,
    ACTIONS(3472), 39,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_of,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_implements,
  [658] = 12,
    ACTIONS(184), 1,
      anon_sym_DQUOTE,
    ACTIONS(186), 1,
      anon_sym_SQUOTE,
    ACTIONS(932), 1,
      anon_sym_EQ,
    ACTIONS(938), 1,
      anon_sym_EQ_GT,
    ACTIONS(3431), 1,
      sym_identifier,
    STATE(1616), 1,
      sym_nested_identifier,
    STATE(1617), 1,
      sym_string,
    STATE(1711), 1,
      sym__module,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(154), 14,
      sym__ternary_qmark,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
    ACTIONS(160), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
    ACTIONS(120), 25,
      anon_sym_STAR,
      anon_sym_as,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_satisfies,
      anon_sym_implements,
  [747] = 4,
    ACTIONS(3474), 1,
      anon_sym_extends,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3458), 23,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK,
    ACTIONS(3460), 38,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_implements,
  [820] = 14,
    ACTIONS(184), 1,
      anon_sym_DQUOTE,
    ACTIONS(186), 1,
      anon_sym_SQUOTE,
    ACTIONS(834), 1,
      anon_sym_EQ,
    ACTIONS(844), 1,
      anon_sym_EQ_GT,
    ACTIONS(902), 1,
      anon_sym_in,
    ACTIONS(905), 1,
      anon_sym_of,
    ACTIONS(3431), 1,
      sym_identifier,
    STATE(1616), 1,
      sym_nested_identifier,
    STATE(1617), 1,
      sym_string,
    STATE(1711), 1,
      sym__module,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(154), 14,
      sym__ternary_qmark,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
    ACTIONS(160), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
    ACTIONS(120), 23,
      anon_sym_STAR,
      anon_sym_as,
      anon_sym_BANG,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_satisfies,
  [913] = 13,
    ACTIONS(834), 1,
      anon_sym_EQ,
    ACTIONS(844), 1,
      anon_sym_EQ_GT,
    ACTIONS(902), 1,
      anon_sym_in,
    ACTIONS(905), 1,
      anon_sym_of,
    ACTIONS(3407), 1,
      anon_sym_LBRACE,
    ACTIONS(3409), 1,
      anon_sym_LBRACK,
    ACTIONS(3476), 1,
      sym_identifier,
    STATE(4416), 1,
      sym_variable_declarator,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    STATE(3387), 3,
      sym_object_pattern,
      sym_array_pattern,
      sym__destructuring_pattern,
    ACTIONS(154), 13,
      sym__ternary_qmark,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
    ACTIONS(160), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
    ACTIONS(120), 23,
      anon_sym_STAR,
      anon_sym_as,
      anon_sym_BANG,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_satisfies,
  [1004] = 4,
    ACTIONS(3478), 1,
      anon_sym_extends,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3462), 23,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK,
    ACTIONS(3464), 38,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_implements,
  [1077] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3480), 23,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK,
    ACTIONS(3482), 39,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_of,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_implements,
  [1148] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3484), 23,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK,
    ACTIONS(3486), 39,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_of,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_implements,
  [1219] = 12,
    ACTIONS(152), 1,
      anon_sym_EQ_GT,
    ACTIONS(184), 1,
      anon_sym_DQUOTE,
    ACTIONS(186), 1,
      anon_sym_SQUOTE,
    ACTIONS(880), 1,
      anon_sym_EQ,
    ACTIONS(3431), 1,
      sym_identifier,
    STATE(1616), 1,
      sym_nested_identifier,
    STATE(1617), 1,
      sym_string,
    STATE(1711), 1,
      sym__module,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(154), 15,
      sym__ternary_qmark,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
    ACTIONS(160), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
    ACTIONS(120), 24,
      anon_sym_STAR,
      anon_sym_as,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_satisfies,
  [1308] = 12,
    ACTIONS(184), 1,
      anon_sym_DQUOTE,
    ACTIONS(186), 1,
      anon_sym_SQUOTE,
    ACTIONS(824), 1,
      anon_sym_EQ,
    ACTIONS(938), 1,
      anon_sym_EQ_GT,
    ACTIONS(3431), 1,
      sym_identifier,
    STATE(1616), 1,
      sym_nested_identifier,
    STATE(1617), 1,
      sym_string,
    STATE(1711), 1,
      sym__module,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(154), 14,
      sym__ternary_qmark,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
    ACTIONS(160), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
    ACTIONS(120), 25,
      anon_sym_STAR,
      anon_sym_as,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_satisfies,
      anon_sym_implements,
  [1397] = 13,
    ACTIONS(184), 1,
      anon_sym_DQUOTE,
    ACTIONS(186), 1,
      anon_sym_SQUOTE,
    ACTIONS(844), 1,
      anon_sym_EQ_GT,
    ACTIONS(907), 1,
      anon_sym_EQ,
    ACTIONS(3431), 1,
      sym_identifier,
    STATE(1616), 1,
      sym_nested_identifier,
    STATE(1617), 1,
      sym_string,
    STATE(1711), 1,
      sym__module,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(126), 3,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_RBRACK,
    ACTIONS(154), 12,
      sym__ternary_qmark,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
    ACTIONS(160), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
    ACTIONS(120), 24,
      anon_sym_STAR,
      anon_sym_as,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_satisfies,
  [1488] = 12,
    ACTIONS(152), 1,
      anon_sym_EQ_GT,
    ACTIONS(184), 1,
      anon_sym_DQUOTE,
    ACTIONS(186), 1,
      anon_sym_SQUOTE,
    ACTIONS(824), 1,
      anon_sym_EQ,
    ACTIONS(3431), 1,
      sym_identifier,
    STATE(1616), 1,
      sym_nested_identifier,
    STATE(1617), 1,
      sym_string,
    STATE(1711), 1,
      sym__module,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(154), 15,
      sym__ternary_qmark,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
    ACTIONS(160), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
    ACTIONS(120), 24,
      anon_sym_STAR,
      anon_sym_as,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_satisfies,
  [1577] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3488), 23,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK,
    ACTIONS(3490), 39,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_of,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_implements,
  [1648] = 5,
    ACTIONS(3494), 1,
      anon_sym_EQ,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3498), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
    ACTIONS(3492), 21,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK_QMARK,
    ACTIONS(3496), 24,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_of,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_implements,
  [1722] = 13,
    ACTIONS(184), 1,
      anon_sym_DQUOTE,
    ACTIONS(186), 1,
      anon_sym_SQUOTE,
    ACTIONS(891), 1,
      anon_sym_COLON,
    ACTIONS(895), 1,
      anon_sym_EQ_GT,
    ACTIONS(910), 1,
      anon_sym_EQ,
    ACTIONS(3431), 1,
      sym_identifier,
    STATE(1616), 1,
      sym_nested_identifier,
    STATE(1617), 1,
      sym_string,
    STATE(1711), 1,
      sym__module,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(154), 13,
      sym__ternary_qmark,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
    ACTIONS(160), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
    ACTIONS(120), 24,
      anon_sym_STAR,
      anon_sym_as,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_satisfies,
  [1812] = 13,
    ACTIONS(661), 1,
      anon_sym_EQ,
    ACTIONS(671), 1,
      anon_sym_COLON,
    ACTIONS(682), 1,
      anon_sym_EQ_GT,
    ACTIONS(690), 1,
      anon_sym_QMARK,
    ACTIONS(694), 1,
      anon_sym_RBRACE,
    ACTIONS(2149), 1,
      anon_sym_LPAREN,
    ACTIONS(2158), 1,
      anon_sym_LT,
    STATE(4792), 1,
      aux_sym_object_repeat1,
    STATE(4815), 1,
      aux_sym_object_pattern_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(160), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
    ACTIONS(154), 17,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
    ACTIONS(120), 20,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK_QMARK,
  [1902] = 13,
    ACTIONS(671), 1,
      anon_sym_COLON,
    ACTIONS(690), 1,
      anon_sym_QMARK,
    ACTIONS(692), 1,
      anon_sym_RBRACE,
    ACTIONS(3500), 1,
      anon_sym_EQ,
    ACTIONS(3502), 1,
      anon_sym_LPAREN,
    ACTIONS(3505), 1,
      anon_sym_EQ_GT,
    ACTIONS(3507), 1,
      anon_sym_LT,
    STATE(4810), 1,
      aux_sym_object_repeat1,
    STATE(4815), 1,
      aux_sym_object_pattern_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3498), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
    ACTIONS(3496), 17,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
    ACTIONS(3492), 20,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK_QMARK,
  [1992] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(2509), 22,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK_QMARK,
    ACTIONS(2507), 39,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_of,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_implements,
  [2062] = 12,
    ACTIONS(184), 1,
      anon_sym_DQUOTE,
    ACTIONS(186), 1,
      anon_sym_SQUOTE,
    ACTIONS(824), 1,
      anon_sym_EQ,
    ACTIONS(924), 1,
      anon_sym_EQ_GT,
    ACTIONS(3431), 1,
      sym_identifier,
    STATE(1616), 1,
      sym_nested_identifier,
    STATE(1617), 1,
      sym_string,
    STATE(1711), 1,
      sym__module,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(154), 14,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
    ACTIONS(160), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
    ACTIONS(120), 24,
      anon_sym_STAR,
      anon_sym_as,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_satisfies,
  [2150] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(2531), 22,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK_QMARK,
    ACTIONS(2529), 39,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_of,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_implements,
  [2220] = 12,
    ACTIONS(83), 1,
      anon_sym_DQUOTE,
    ACTIONS(85), 1,
      anon_sym_SQUOTE,
    ACTIONS(918), 1,
      anon_sym_EQ,
    ACTIONS(924), 1,
      anon_sym_EQ_GT,
    ACTIONS(3454), 1,
      sym_identifier,
    STATE(1608), 1,
      sym_nested_identifier,
    STATE(1612), 1,
      sym_string,
    STATE(1771), 1,
      sym__module,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(154), 14,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
    ACTIONS(160), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
    ACTIONS(120), 24,
      anon_sym_STAR,
      anon_sym_as,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_satisfies,
  [2308] = 11,
    ACTIONS(918), 1,
      anon_sym_EQ,
    ACTIONS(924), 1,
      anon_sym_EQ_GT,
    ACTIONS(3405), 1,
      sym_identifier,
    ACTIONS(3407), 1,
      anon_sym_LBRACE,
    ACTIONS(3409), 1,
      anon_sym_LBRACK,
    STATE(4416), 1,
      sym_variable_declarator,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    STATE(3718), 3,
      sym_object_pattern,
      sym_array_pattern,
      sym__destructuring_pattern,
    ACTIONS(154), 13,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
    ACTIONS(160), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
    ACTIONS(120), 24,
      anon_sym_STAR,
      anon_sym_as,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_satisfies,
  [2394] = 11,
    ACTIONS(918), 1,
      anon_sym_EQ,
    ACTIONS(924), 1,
      anon_sym_EQ_GT,
    ACTIONS(3405), 1,
      sym_identifier,
    ACTIONS(3407), 1,
      anon_sym_LBRACE,
    ACTIONS(3409), 1,
      anon_sym_LBRACK,
    STATE(4451), 1,
      sym_variable_declarator,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    STATE(3718), 3,
      sym_object_pattern,
      sym_array_pattern,
      sym__destructuring_pattern,
    ACTIONS(154), 13,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
    ACTIONS(160), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
    ACTIONS(120), 24,
      anon_sym_STAR,
      anon_sym_as,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_satisfies,
  [2480] = 14,
    ACTIONS(3510), 1,
      anon_sym_EQ,
    ACTIONS(3514), 1,
      anon_sym_LPAREN,
    ACTIONS(3516), 1,
      anon_sym_DOT,
    ACTIONS(3518), 1,
      anon_sym_EQ_GT,
    ACTIONS(3520), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(3524), 1,
      anon_sym_LT,
    STATE(2917), 1,
      sym_arguments,
    STATE(3015), 1,
      sym_type_arguments,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3512), 3,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_extends,
    ACTIONS(3522), 3,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_GT,
    ACTIONS(3496), 15,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_RBRACK,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
    ACTIONS(3498), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
    ACTIONS(3492), 17,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_QMARK_QMARK,
  [2572] = 12,
    ACTIONS(918), 1,
      anon_sym_EQ,
    ACTIONS(924), 1,
      anon_sym_EQ_GT,
    ACTIONS(1626), 1,
      anon_sym_DQUOTE,
    ACTIONS(1628), 1,
      anon_sym_SQUOTE,
    ACTIONS(3526), 1,
      sym_identifier,
    STATE(3500), 1,
      sym_nested_identifier,
    STATE(3698), 1,
      sym_string,
    STATE(4311), 1,
      sym__module,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(154), 14,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
    ACTIONS(160), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
    ACTIONS(120), 24,
      anon_sym_STAR,
      anon_sym_as,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_satisfies,
  [2660] = 13,
    ACTIONS(184), 1,
      anon_sym_DQUOTE,
    ACTIONS(186), 1,
      anon_sym_SQUOTE,
    ACTIONS(895), 1,
      anon_sym_EQ_GT,
    ACTIONS(910), 1,
      anon_sym_EQ,
    ACTIONS(912), 1,
      anon_sym_COLON,
    ACTIONS(3431), 1,
      sym_identifier,
    STATE(1616), 1,
      sym_nested_identifier,
    STATE(1617), 1,
      sym_string,
    STATE(1711), 1,
      sym__module,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(154), 13,
      sym__ternary_qmark,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
    ACTIONS(160), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
    ACTIONS(120), 24,
      anon_sym_STAR,
      anon_sym_as,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_satisfies,
  [2750] = 12,
    ACTIONS(918), 1,
      anon_sym_EQ,
    ACTIONS(924), 1,
      anon_sym_EQ_GT,
    ACTIONS(1550), 1,
      anon_sym_DQUOTE,
    ACTIONS(1552), 1,
      anon_sym_SQUOTE,
    ACTIONS(3421), 1,
      sym_identifier,
    STATE(783), 1,
      sym_nested_identifier,
    STATE(798), 1,
      sym_string,
    STATE(878), 1,
      sym__module,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(154), 14,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
    ACTIONS(160), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
    ACTIONS(120), 24,
      anon_sym_STAR,
      anon_sym_as,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_satisfies,
  [2838] = 13,
    ACTIONS(671), 1,
      anon_sym_COLON,
    ACTIONS(690), 1,
      anon_sym_QMARK,
    ACTIONS(694), 1,
      anon_sym_RBRACE,
    ACTIONS(3500), 1,
      anon_sym_EQ,
    ACTIONS(3502), 1,
      anon_sym_LPAREN,
    ACTIONS(3505), 1,
      anon_sym_EQ_GT,
    ACTIONS(3507), 1,
      anon_sym_LT,
    STATE(4792), 1,
      aux_sym_object_repeat1,
    STATE(4815), 1,
      aux_sym_object_pattern_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3498), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
    ACTIONS(3496), 17,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
    ACTIONS(3492), 20,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK_QMARK,
  [2928] = 13,
    ACTIONS(667), 1,
      anon_sym_RBRACE,
    ACTIONS(671), 1,
      anon_sym_COLON,
    ACTIONS(690), 1,
      anon_sym_QMARK,
    ACTIONS(3500), 1,
      anon_sym_EQ,
    ACTIONS(3502), 1,
      anon_sym_LPAREN,
    ACTIONS(3505), 1,
      anon_sym_EQ_GT,
    ACTIONS(3507), 1,
      anon_sym_LT,
    STATE(4792), 1,
      aux_sym_object_repeat1,
    STATE(4815), 1,
      aux_sym_object_pattern_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3498), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
    ACTIONS(3496), 17,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
    ACTIONS(3492), 20,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK_QMARK,
  [3018] = 14,
    ACTIONS(126), 1,
      anon_sym_RBRACK,
    ACTIONS(184), 1,
      anon_sym_DQUOTE,
    ACTIONS(186), 1,
      anon_sym_SQUOTE,
    ACTIONS(223), 1,
      anon_sym_COMMA,
    ACTIONS(886), 1,
      anon_sym_EQ,
    ACTIONS(895), 1,
      anon_sym_EQ_GT,
    ACTIONS(3431), 1,
      sym_identifier,
    STATE(1616), 1,
      sym_nested_identifier,
    STATE(1617), 1,
      sym_string,
    STATE(1711), 1,
      sym__module,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(154), 12,
      sym__ternary_qmark,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
    ACTIONS(160), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
    ACTIONS(120), 24,
      anon_sym_STAR,
      anon_sym_as,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_satisfies,
  [3110] = 12,
    ACTIONS(918), 1,
      anon_sym_EQ,
    ACTIONS(924), 1,
      anon_sym_EQ_GT,
    ACTIONS(3411), 1,
      sym_identifier,
    ACTIONS(3413), 1,
      anon_sym_DQUOTE,
    ACTIONS(3415), 1,
      anon_sym_SQUOTE,
    STATE(201), 1,
      sym_nested_identifier,
    STATE(203), 1,
      sym_string,
    STATE(231), 1,
      sym__module,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(154), 14,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
    ACTIONS(160), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
    ACTIONS(120), 24,
      anon_sym_STAR,
      anon_sym_as,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_satisfies,
  [3198] = 14,
    ACTIONS(3510), 1,
      anon_sym_EQ,
    ACTIONS(3518), 1,
      anon_sym_EQ_GT,
    ACTIONS(3528), 1,
      anon_sym_LPAREN,
    ACTIONS(3530), 1,
      anon_sym_DOT,
    ACTIONS(3532), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(3534), 1,
      anon_sym_LT,
    STATE(3086), 1,
      sym_arguments,
    STATE(3215), 1,
      sym_type_arguments,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3522), 2,
      anon_sym_AMP,
      anon_sym_PIPE,
    ACTIONS(3512), 7,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_extends,
      anon_sym_PIPE_RBRACE,
    ACTIONS(3496), 11,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
    ACTIONS(3498), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
    ACTIONS(3492), 18,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK_QMARK,
  [3290] = 13,
    ACTIONS(661), 1,
      anon_sym_EQ,
    ACTIONS(671), 1,
      anon_sym_COLON,
    ACTIONS(682), 1,
      anon_sym_EQ_GT,
    ACTIONS(690), 1,
      anon_sym_QMARK,
    ACTIONS(692), 1,
      anon_sym_RBRACE,
    ACTIONS(2149), 1,
      anon_sym_LPAREN,
    ACTIONS(2158), 1,
      anon_sym_LT,
    STATE(4810), 1,
      aux_sym_object_repeat1,
    STATE(4815), 1,
      aux_sym_object_pattern_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(160), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
    ACTIONS(154), 17,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
    ACTIONS(120), 20,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK_QMARK,
  [3380] = 13,
    ACTIONS(661), 1,
      anon_sym_EQ,
    ACTIONS(667), 1,
      anon_sym_RBRACE,
    ACTIONS(671), 1,
      anon_sym_COLON,
    ACTIONS(682), 1,
      anon_sym_EQ_GT,
    ACTIONS(690), 1,
      anon_sym_QMARK,
    ACTIONS(2149), 1,
      anon_sym_LPAREN,
    ACTIONS(2158), 1,
      anon_sym_LT,
    STATE(4792), 1,
      aux_sym_object_repeat1,
    STATE(4815), 1,
      aux_sym_object_pattern_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(160), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
    ACTIONS(154), 17,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
    ACTIONS(120), 20,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK_QMARK,
  [3470] = 12,
    ACTIONS(184), 1,
      anon_sym_DQUOTE,
    ACTIONS(186), 1,
      anon_sym_SQUOTE,
    ACTIONS(895), 1,
      anon_sym_EQ_GT,
    ACTIONS(910), 1,
      anon_sym_EQ,
    ACTIONS(3431), 1,
      sym_identifier,
    STATE(1616), 1,
      sym_nested_identifier,
    STATE(1617), 1,
      sym_string,
    STATE(1711), 1,
      sym__module,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(154), 13,
      sym__ternary_qmark,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
    ACTIONS(160), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
    ACTIONS(120), 24,
      anon_sym_STAR,
      anon_sym_as,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_satisfies,
  [3557] = 12,
    ACTIONS(184), 1,
      anon_sym_DQUOTE,
    ACTIONS(186), 1,
      anon_sym_SQUOTE,
    ACTIONS(964), 1,
      anon_sym_EQ,
    ACTIONS(970), 1,
      anon_sym_EQ_GT,
    ACTIONS(3431), 1,
      sym_identifier,
    STATE(1616), 1,
      sym_nested_identifier,
    STATE(1617), 1,
      sym_string,
    STATE(1711), 1,
      sym__module,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(154), 13,
      sym__ternary_qmark,
      anon_sym_LPAREN,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
    ACTIONS(160), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
    ACTIONS(120), 24,
      anon_sym_STAR,
      anon_sym_as,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_satisfies,
  [3644] = 12,
    ACTIONS(184), 1,
      anon_sym_DQUOTE,
    ACTIONS(186), 1,
      anon_sym_SQUOTE,
    ACTIONS(824), 1,
      anon_sym_EQ,
    ACTIONS(970), 1,
      anon_sym_EQ_GT,
    ACTIONS(3431), 1,
      sym_identifier,
    STATE(1616), 1,
      sym_nested_identifier,
    STATE(1617), 1,
      sym_string,
    STATE(1711), 1,
      sym__module,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(154), 13,
      sym__ternary_qmark,
      anon_sym_LPAREN,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
    ACTIONS(160), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
    ACTIONS(120), 24,
      anon_sym_STAR,
      anon_sym_as,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_satisfies,
  [3731] = 12,
    ACTIONS(184), 1,
      anon_sym_DQUOTE,
    ACTIONS(186), 1,
      anon_sym_SQUOTE,
    ACTIONS(824), 1,
      anon_sym_EQ,
    ACTIONS(895), 1,
      anon_sym_EQ_GT,
    ACTIONS(3431), 1,
      sym_identifier,
    STATE(1616), 1,
      sym_nested_identifier,
    STATE(1617), 1,
      sym_string,
    STATE(1711), 1,
      sym__module,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(154), 13,
      sym__ternary_qmark,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
    ACTIONS(160), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
    ACTIONS(120), 24,
      anon_sym_STAR,
      anon_sym_as,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_satisfies,
  [3818] = 12,
    ACTIONS(3510), 1,
      anon_sym_EQ,
    ACTIONS(3518), 1,
      anon_sym_EQ_GT,
    ACTIONS(3539), 1,
      anon_sym_DOT,
    ACTIONS(3545), 1,
      anon_sym_LT,
    ACTIONS(3548), 1,
      anon_sym_extends,
    STATE(2964), 1,
      sym_type_arguments,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3536), 2,
      anon_sym_COMMA,
      anon_sym_LBRACK,
    ACTIONS(3542), 3,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_GT,
    ACTIONS(3498), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
    ACTIONS(3492), 17,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_QMARK_QMARK,
    ACTIONS(3496), 17,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_RBRACK,
      anon_sym_QMARK_DOT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [3905] = 12,
    ACTIONS(184), 1,
      anon_sym_DQUOTE,
    ACTIONS(186), 1,
      anon_sym_SQUOTE,
    ACTIONS(948), 1,
      anon_sym_EQ,
    ACTIONS(954), 1,
      anon_sym_EQ_GT,
    ACTIONS(3431), 1,
      sym_identifier,
    STATE(1616), 1,
      sym_nested_identifier,
    STATE(1617), 1,
      sym_string,
    STATE(1711), 1,
      sym__module,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(154), 12,
      sym__ternary_qmark,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
    ACTIONS(160), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
    ACTIONS(120), 25,
      anon_sym_STAR,
      anon_sym_as,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_of,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_satisfies,
  [3992] = 12,
    ACTIONS(184), 1,
      anon_sym_DQUOTE,
    ACTIONS(186), 1,
      anon_sym_SQUOTE,
    ACTIONS(824), 1,
      anon_sym_EQ,
    ACTIONS(954), 1,
      anon_sym_EQ_GT,
    ACTIONS(3431), 1,
      sym_identifier,
    STATE(1616), 1,
      sym_nested_identifier,
    STATE(1617), 1,
      sym_string,
    STATE(1711), 1,
      sym__module,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(154), 12,
      sym__ternary_qmark,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
    ACTIONS(160), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
    ACTIONS(120), 25,
      anon_sym_STAR,
      anon_sym_as,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_of,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_satisfies,
  [4079] = 16,
    ACTIONS(3518), 1,
      anon_sym_EQ_GT,
    ACTIONS(3536), 1,
      anon_sym_LBRACK,
    ACTIONS(3539), 1,
      anon_sym_DOT,
    ACTIONS(3545), 1,
      anon_sym_LT,
    ACTIONS(3548), 1,
      anon_sym_extends,
    ACTIONS(3550), 1,
      anon_sym_EQ,
    ACTIONS(3557), 1,
      anon_sym_COLON,
    ACTIONS(3559), 1,
      anon_sym_QMARK,
    STATE(2964), 1,
      sym_type_arguments,
    STATE(5159), 1,
      sym_type_annotation,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3542), 2,
      anon_sym_AMP,
      anon_sym_PIPE,
    ACTIONS(3553), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK,
    ACTIONS(3496), 13,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_QMARK_DOT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
    ACTIONS(3498), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
    ACTIONS(3492), 18,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK_QMARK,
  [4174] = 13,
    ACTIONS(184), 1,
      anon_sym_DQUOTE,
    ACTIONS(186), 1,
      anon_sym_SQUOTE,
    ACTIONS(225), 1,
      anon_sym_EQ_GT,
    ACTIONS(824), 1,
      anon_sym_EQ,
    ACTIONS(826), 1,
      anon_sym_COLON,
    ACTIONS(3431), 1,
      sym_identifier,
    STATE(1616), 1,
      sym_nested_identifier,
    STATE(1617), 1,
      sym_string,
    STATE(1711), 1,
      sym__module,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(154), 12,
      sym__ternary_qmark,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
    ACTIONS(160), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
    ACTIONS(120), 24,
      anon_sym_STAR,
      anon_sym_as,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_satisfies,
  [4263] = 14,
    ACTIONS(184), 1,
      anon_sym_DQUOTE,
    ACTIONS(186), 1,
      anon_sym_SQUOTE,
    ACTIONS(225), 1,
      anon_sym_EQ_GT,
    ACTIONS(824), 1,
      anon_sym_EQ,
    ACTIONS(902), 1,
      anon_sym_in,
    ACTIONS(905), 1,
      anon_sym_of,
    ACTIONS(3431), 1,
      sym_identifier,
    STATE(1616), 1,
      sym_nested_identifier,
    STATE(1617), 1,
      sym_string,
    STATE(1711), 1,
      sym__module,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(154), 12,
      sym__ternary_qmark,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
    ACTIONS(160), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
    ACTIONS(120), 23,
      anon_sym_STAR,
      anon_sym_as,
      anon_sym_BANG,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_satisfies,
  [4354] = 14,
    ACTIONS(3505), 1,
      anon_sym_EQ_GT,
    ACTIONS(3514), 1,
      anon_sym_LPAREN,
    ACTIONS(3516), 1,
      anon_sym_DOT,
    ACTIONS(3520), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(3524), 1,
      anon_sym_LT,
    ACTIONS(3562), 1,
      anon_sym_EQ,
    STATE(2917), 1,
      sym_arguments,
    STATE(3015), 1,
      sym_type_arguments,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3512), 3,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_extends,
    ACTIONS(3522), 3,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_GT,
    ACTIONS(3496), 14,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
    ACTIONS(3498), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
    ACTIONS(3492), 17,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_QMARK_QMARK,
  [4445] = 13,
    ACTIONS(3518), 1,
      anon_sym_EQ_GT,
    ACTIONS(3536), 1,
      anon_sym_LBRACK,
    ACTIONS(3550), 1,
      anon_sym_EQ,
    ACTIONS(3564), 1,
      anon_sym_DOT,
    ACTIONS(3567), 1,
      anon_sym_LT,
    STATE(3250), 1,
      sym_type_arguments,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3542), 2,
      anon_sym_AMP,
      anon_sym_PIPE,
    ACTIONS(3553), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
    ACTIONS(3548), 4,
      sym__automatic_semicolon,
      anon_sym_SEMI,
      anon_sym_extends,
      anon_sym_PIPE_RBRACE,
    ACTIONS(3496), 13,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_QMARK_DOT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
    ACTIONS(3498), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
    ACTIONS(3492), 18,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK_QMARK,
  [4534] = 8,
    ACTIONS(3514), 1,
      anon_sym_LPAREN,
    ACTIONS(3574), 1,
      anon_sym_DOT,
    ACTIONS(3576), 1,
      anon_sym_LT,
    STATE(1288), 1,
      sym_arguments,
    STATE(5440), 1,
      sym_type_arguments,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3572), 13,
      anon_sym_LBRACE,
      anon_sym_BANG,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_DOT,
      anon_sym_TILDE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      anon_sym_BQUOTE,
      sym_number,
      sym_private_property_identifier,
      anon_sym_AT,
    ACTIONS(3570), 42,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_typeof,
      anon_sym_import,
      anon_sym_let,
      anon_sym_await,
      anon_sym_yield,
      anon_sym_class,
      anon_sym_async,
      anon_sym_function,
      anon_sym_new,
      anon_sym_using,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_void,
      anon_sym_delete,
      sym_identifier,
      sym_this,
      sym_super,
      sym_true,
      sym_false,
      sym_null,
      sym_undefined,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
      anon_sym_abstract,
  [4613] = 14,
    ACTIONS(3514), 1,
      anon_sym_LPAREN,
    ACTIONS(3516), 1,
      anon_sym_DOT,
    ACTIONS(3520), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(3524), 1,
      anon_sym_LT,
    ACTIONS(3578), 1,
      anon_sym_EQ,
    ACTIONS(3580), 1,
      anon_sym_EQ_GT,
    STATE(2917), 1,
      sym_arguments,
    STATE(3015), 1,
      sym_type_arguments,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3512), 3,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_extends,
    ACTIONS(3522), 3,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_GT,
    ACTIONS(3496), 14,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
    ACTIONS(3498), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
    ACTIONS(3492), 17,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_QMARK_QMARK,
  [4704] = 12,
    ACTIONS(184), 1,
      anon_sym_DQUOTE,
    ACTIONS(186), 1,
      anon_sym_SQUOTE,
    ACTIONS(225), 1,
      anon_sym_EQ_GT,
    ACTIONS(1040), 1,
      anon_sym_EQ,
    ACTIONS(3431), 1,
      sym_identifier,
    STATE(1616), 1,
      sym_nested_identifier,
    STATE(1617), 1,
      sym_string,
    STATE(1711), 1,
      sym__module,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(154), 12,
      sym__ternary_qmark,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
    ACTIONS(160), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
    ACTIONS(120), 24,
      anon_sym_STAR,
      anon_sym_as,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_satisfies,
  [4790] = 14,
    ACTIONS(3514), 1,
      anon_sym_LPAREN,
    ACTIONS(3516), 1,
      anon_sym_DOT,
    ACTIONS(3520), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(3524), 1,
      anon_sym_LT,
    ACTIONS(3582), 1,
      anon_sym_EQ,
    ACTIONS(3584), 1,
      anon_sym_EQ_GT,
    STATE(2917), 1,
      sym_arguments,
    STATE(3015), 1,
      sym_type_arguments,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3512), 3,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_extends,
    ACTIONS(3522), 3,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_GT,
    ACTIONS(3496), 13,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_SEMI,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
    ACTIONS(3498), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
    ACTIONS(3492), 17,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_QMARK_QMARK,
  [4880] = 12,
    ACTIONS(184), 1,
      anon_sym_DQUOTE,
    ACTIONS(186), 1,
      anon_sym_SQUOTE,
    ACTIONS(225), 1,
      anon_sym_EQ_GT,
    ACTIONS(978), 1,
      anon_sym_EQ,
    ACTIONS(3431), 1,
      sym_identifier,
    STATE(1616), 1,
      sym_nested_identifier,
    STATE(1617), 1,
      sym_string,
    STATE(1711), 1,
      sym__module,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(154), 12,
      sym__ternary_qmark,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
    ACTIONS(160), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
    ACTIONS(120), 24,
      anon_sym_STAR,
      anon_sym_as,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_satisfies,
  [4966] = 12,
    ACTIONS(184), 1,
      anon_sym_DQUOTE,
    ACTIONS(186), 1,
      anon_sym_SQUOTE,
    ACTIONS(225), 1,
      anon_sym_EQ_GT,
    ACTIONS(982), 1,
      anon_sym_EQ,
    ACTIONS(3431), 1,
      sym_identifier,
    STATE(1616), 1,
      sym_nested_identifier,
    STATE(1617), 1,
      sym_string,
    STATE(1711), 1,
      sym__module,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(154), 12,
      sym__ternary_qmark,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
    ACTIONS(160), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
    ACTIONS(120), 24,
      anon_sym_STAR,
      anon_sym_as,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_satisfies,
  [5052] = 8,
    ACTIONS(3494), 1,
      anon_sym_EQ,
    ACTIONS(3588), 1,
      anon_sym_EQ_GT,
    ACTIONS(3590), 1,
      anon_sym_QMARK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3586), 5,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_RBRACK,
    ACTIONS(3496), 15,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
    ACTIONS(3498), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
    ACTIONS(3492), 21,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK_QMARK,
  [5130] = 12,
    ACTIONS(184), 1,
      anon_sym_DQUOTE,
    ACTIONS(186), 1,
      anon_sym_SQUOTE,
    ACTIONS(225), 1,
      anon_sym_EQ_GT,
    ACTIONS(1044), 1,
      anon_sym_EQ,
    ACTIONS(3431), 1,
      sym_identifier,
    STATE(1616), 1,
      sym_nested_identifier,
    STATE(1617), 1,
      sym_string,
    STATE(1711), 1,
      sym__module,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(154), 12,
      sym__ternary_qmark,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
    ACTIONS(160), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
    ACTIONS(120), 24,
      anon_sym_STAR,
      anon_sym_as,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_satisfies,
  [5216] = 14,
    ACTIONS(3514), 1,
      anon_sym_LPAREN,
    ACTIONS(3516), 1,
      anon_sym_DOT,
    ACTIONS(3520), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(3524), 1,
      anon_sym_LT,
    ACTIONS(3592), 1,
      anon_sym_EQ,
    ACTIONS(3594), 1,
      anon_sym_EQ_GT,
    STATE(2917), 1,
      sym_arguments,
    STATE(3015), 1,
      sym_type_arguments,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3512), 3,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_extends,
    ACTIONS(3522), 3,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_GT,
    ACTIONS(3496), 13,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_implements,
    ACTIONS(3498), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
    ACTIONS(3492), 17,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_QMARK_QMARK,
  [5306] = 12,
    ACTIONS(225), 1,
      anon_sym_EQ_GT,
    ACTIONS(824), 1,
      anon_sym_EQ,
    ACTIONS(902), 1,
      anon_sym_in,
    ACTIONS(905), 1,
      anon_sym_of,
    ACTIONS(3407), 1,
      anon_sym_LBRACE,
    ACTIONS(3596), 1,
      sym_identifier,
    ACTIONS(3598), 1,
      anon_sym_LBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    STATE(4813), 3,
      sym_object_pattern,
      sym_array_pattern,
      sym__destructuring_pattern,
    ACTIONS(154), 11,
      sym__ternary_qmark,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
    ACTIONS(160), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
    ACTIONS(120), 23,
      anon_sym_STAR,
      anon_sym_as,
      anon_sym_BANG,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_satisfies,
  [5392] = 12,
    ACTIONS(3505), 1,
      anon_sym_EQ_GT,
    ACTIONS(3539), 1,
      anon_sym_DOT,
    ACTIONS(3545), 1,
      anon_sym_LT,
    ACTIONS(3548), 1,
      anon_sym_extends,
    ACTIONS(3562), 1,
      anon_sym_EQ,
    STATE(2964), 1,
      sym_type_arguments,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3536), 2,
      anon_sym_COMMA,
      anon_sym_LBRACK,
    ACTIONS(3542), 3,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_GT,
    ACTIONS(3498), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
    ACTIONS(3496), 16,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK_DOT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
    ACTIONS(3492), 17,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_QMARK_QMARK,
  [5478] = 12,
    ACTIONS(184), 1,
      anon_sym_DQUOTE,
    ACTIONS(186), 1,
      anon_sym_SQUOTE,
    ACTIONS(225), 1,
      anon_sym_EQ_GT,
    ACTIONS(1038), 1,
      anon_sym_EQ,
    ACTIONS(3431), 1,
      sym_identifier,
    STATE(1616), 1,
      sym_nested_identifier,
    STATE(1617), 1,
      sym_string,
    STATE(1711), 1,
      sym__module,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(154), 12,
      sym__ternary_qmark,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
    ACTIONS(160), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
    ACTIONS(120), 24,
      anon_sym_STAR,
      anon_sym_as,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_satisfies,
  [5564] = 14,
    ACTIONS(3514), 1,
      anon_sym_LPAREN,
    ACTIONS(3516), 1,
      anon_sym_DOT,
    ACTIONS(3520), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(3524), 1,
      anon_sym_LT,
    ACTIONS(3601), 1,
      anon_sym_EQ,
    ACTIONS(3603), 1,
      anon_sym_EQ_GT,
    STATE(2917), 1,
      sym_arguments,
    STATE(3015), 1,
      sym_type_arguments,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3512), 3,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_extends,
    ACTIONS(3522), 3,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_GT,
    ACTIONS(3496), 13,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
    ACTIONS(3498), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
    ACTIONS(3492), 17,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_QMARK_QMARK,
  [5654] = 12,
    ACTIONS(184), 1,
      anon_sym_DQUOTE,
    ACTIONS(186), 1,
      anon_sym_SQUOTE,
    ACTIONS(225), 1,
      anon_sym_EQ_GT,
    ACTIONS(974), 1,
      anon_sym_EQ,
    ACTIONS(3431), 1,
      sym_identifier,
    STATE(1616), 1,
      sym_nested_identifier,
    STATE(1617), 1,
      sym_string,
    STATE(1711), 1,
      sym__module,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(154), 12,
      sym__ternary_qmark,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
    ACTIONS(160), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
    ACTIONS(120), 24,
      anon_sym_STAR,
      anon_sym_as,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_satisfies,
  [5740] = 8,
    ACTIONS(220), 1,
      anon_sym_EQ,
    ACTIONS(225), 1,
      anon_sym_EQ_GT,
    ACTIONS(720), 1,
      anon_sym_QMARK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(223), 5,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_RBRACK,
    ACTIONS(154), 15,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
    ACTIONS(160), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
    ACTIONS(120), 21,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK_QMARK,
  [5818] = 14,
    ACTIONS(3514), 1,
      anon_sym_LPAREN,
    ACTIONS(3516), 1,
      anon_sym_DOT,
    ACTIONS(3520), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(3524), 1,
      anon_sym_LT,
    ACTIONS(3601), 1,
      anon_sym_EQ,
    ACTIONS(3603), 1,
      anon_sym_EQ_GT,
    STATE(2917), 1,
      sym_arguments,
    STATE(3015), 1,
      sym_type_arguments,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3522), 2,
      anon_sym_AMP,
      anon_sym_PIPE,
    ACTIONS(3512), 3,
      anon_sym_RPAREN,
      anon_sym_LBRACK,
      anon_sym_extends,
    ACTIONS(3496), 13,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
    ACTIONS(3498), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
    ACTIONS(3492), 18,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK_QMARK,
  [5908] = 9,
    ACTIONS(844), 1,
      anon_sym_EQ_GT,
    ACTIONS(907), 1,
      anon_sym_EQ,
    ACTIONS(3605), 1,
      anon_sym_LBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3608), 2,
      anon_sym_AMP,
      anon_sym_PIPE,
    ACTIONS(1898), 6,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_extends,
      anon_sym_PIPE_RBRACE,
    ACTIONS(154), 14,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
    ACTIONS(160), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
    ACTIONS(120), 19,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK_QMARK,
  [5988] = 14,
    ACTIONS(3510), 1,
      anon_sym_EQ,
    ACTIONS(3514), 1,
      anon_sym_LPAREN,
    ACTIONS(3516), 1,
      anon_sym_DOT,
    ACTIONS(3518), 1,
      anon_sym_EQ_GT,
    ACTIONS(3520), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(3524), 1,
      anon_sym_LT,
    STATE(2917), 1,
      sym_arguments,
    STATE(3015), 1,
      sym_type_arguments,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3522), 3,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_QMARK,
    ACTIONS(3512), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_extends,
    ACTIONS(3496), 11,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
    ACTIONS(3498), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
    ACTIONS(3492), 18,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK_QMARK,
  [6078] = 15,
    ACTIONS(3536), 1,
      anon_sym_LBRACK,
    ACTIONS(3539), 1,
      anon_sym_DOT,
    ACTIONS(3545), 1,
      anon_sym_LT,
    ACTIONS(3548), 1,
      anon_sym_extends,
    ACTIONS(3553), 1,
      anon_sym_RPAREN,
    ACTIONS(3603), 1,
      anon_sym_EQ_GT,
    ACTIONS(3611), 1,
      anon_sym_EQ,
    ACTIONS(3617), 1,
      anon_sym_QMARK,
    STATE(2964), 1,
      sym_type_arguments,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3542), 2,
      anon_sym_AMP,
      anon_sym_PIPE,
    ACTIONS(3614), 2,
      anon_sym_COMMA,
      anon_sym_COLON,
    ACTIONS(3496), 13,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_QMARK_DOT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
    ACTIONS(3498), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
    ACTIONS(3492), 18,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK_QMARK,
  [6170] = 8,
    ACTIONS(3588), 1,
      anon_sym_EQ_GT,
    ACTIONS(3617), 1,
      anon_sym_QMARK,
    ACTIONS(3619), 1,
      anon_sym_EQ,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3622), 5,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_RBRACK,
    ACTIONS(3496), 15,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
    ACTIONS(3498), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
    ACTIONS(3492), 21,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK_QMARK,
  [6248] = 12,
    ACTIONS(184), 1,
      anon_sym_DQUOTE,
    ACTIONS(186), 1,
      anon_sym_SQUOTE,
    ACTIONS(225), 1,
      anon_sym_EQ_GT,
    ACTIONS(1042), 1,
      anon_sym_EQ,
    ACTIONS(3431), 1,
      sym_identifier,
    STATE(1616), 1,
      sym_nested_identifier,
    STATE(1617), 1,
      sym_string,
    STATE(1711), 1,
      sym__module,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(154), 12,
      sym__ternary_qmark,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
    ACTIONS(160), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
    ACTIONS(120), 24,
      anon_sym_STAR,
      anon_sym_as,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_satisfies,
  [6334] = 12,
    ACTIONS(184), 1,
      anon_sym_DQUOTE,
    ACTIONS(186), 1,
      anon_sym_SQUOTE,
    ACTIONS(225), 1,
      anon_sym_EQ_GT,
    ACTIONS(824), 1,
      anon_sym_EQ,
    ACTIONS(3431), 1,
      sym_identifier,
    STATE(1616), 1,
      sym_nested_identifier,
    STATE(1617), 1,
      sym_string,
    STATE(1711), 1,
      sym__module,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(154), 12,
      sym__ternary_qmark,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
    ACTIONS(160), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
    ACTIONS(120), 24,
      anon_sym_STAR,
      anon_sym_as,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_satisfies,
  [6420] = 12,
    ACTIONS(184), 1,
      anon_sym_DQUOTE,
    ACTIONS(186), 1,
      anon_sym_SQUOTE,
    ACTIONS(225), 1,
      anon_sym_EQ_GT,
    ACTIONS(976), 1,
      anon_sym_EQ,
    ACTIONS(3431), 1,
      sym_identifier,
    STATE(1616), 1,
      sym_nested_identifier,
    STATE(1617), 1,
      sym_string,
    STATE(1711), 1,
      sym__module,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(154), 12,
      sym__ternary_qmark,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
    ACTIONS(160), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
    ACTIONS(120), 24,
      anon_sym_STAR,
      anon_sym_as,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_satisfies,
  [6506] = 6,
    ACTIONS(3628), 1,
      anon_sym_AT,
    STATE(1269), 1,
      aux_sym_export_statement_repeat1,
    STATE(1344), 1,
      sym_decorator,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3626), 14,
      anon_sym_LBRACE,
      anon_sym_BANG,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_DOT,
      anon_sym_LT,
      anon_sym_TILDE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      anon_sym_BQUOTE,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(3624), 42,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_typeof,
      anon_sym_import,
      anon_sym_let,
      anon_sym_await,
      anon_sym_yield,
      anon_sym_class,
      anon_sym_async,
      anon_sym_function,
      anon_sym_new,
      anon_sym_using,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_void,
      anon_sym_delete,
      sym_identifier,
      sym_this,
      sym_super,
      sym_true,
      sym_false,
      sym_null,
      sym_undefined,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
      anon_sym_abstract,
  [6580] = 12,
    ACTIONS(3539), 1,
      anon_sym_DOT,
    ACTIONS(3545), 1,
      anon_sym_LT,
    ACTIONS(3548), 1,
      anon_sym_extends,
    ACTIONS(3578), 1,
      anon_sym_EQ,
    ACTIONS(3580), 1,
      anon_sym_EQ_GT,
    STATE(2964), 1,
      sym_type_arguments,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3536), 2,
      anon_sym_COMMA,
      anon_sym_LBRACK,
    ACTIONS(3542), 3,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_GT,
    ACTIONS(3498), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
    ACTIONS(3496), 16,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_QMARK_DOT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
    ACTIONS(3492), 17,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_QMARK_QMARK,
  [6666] = 12,
    ACTIONS(184), 1,
      anon_sym_DQUOTE,
    ACTIONS(186), 1,
      anon_sym_SQUOTE,
    ACTIONS(225), 1,
      anon_sym_EQ_GT,
    ACTIONS(1036), 1,
      anon_sym_EQ,
    ACTIONS(3431), 1,
      sym_identifier,
    STATE(1616), 1,
      sym_nested_identifier,
    STATE(1617), 1,
      sym_string,
    STATE(1711), 1,
      sym__module,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(154), 12,
      sym__ternary_qmark,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
    ACTIONS(160), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
    ACTIONS(120), 24,
      anon_sym_STAR,
      anon_sym_as,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_satisfies,
  [6752] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3633), 16,
      anon_sym_LBRACE,
      anon_sym_BANG,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_DOT,
      anon_sym_LT,
      anon_sym_TILDE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      anon_sym_BQUOTE,
      sym_number,
      sym_private_property_identifier,
      anon_sym_AT,
    ACTIONS(3631), 43,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_typeof,
      anon_sym_import,
      anon_sym_let,
      anon_sym_await,
      anon_sym_yield,
      anon_sym_DOT,
      anon_sym_class,
      anon_sym_async,
      anon_sym_function,
      anon_sym_new,
      anon_sym_using,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_void,
      anon_sym_delete,
      sym_identifier,
      sym_this,
      sym_super,
      sym_true,
      sym_false,
      sym_null,
      sym_undefined,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
      anon_sym_abstract,
  [6820] = 8,
    ACTIONS(225), 1,
      anon_sym_EQ_GT,
    ACTIONS(824), 1,
      anon_sym_EQ,
    ACTIONS(828), 1,
      anon_sym_QMARK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(826), 5,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_RBRACK,
    ACTIONS(154), 15,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
    ACTIONS(160), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
    ACTIONS(120), 21,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK_QMARK,
  [6898] = 12,
    ACTIONS(184), 1,
      anon_sym_DQUOTE,
    ACTIONS(186), 1,
      anon_sym_SQUOTE,
    ACTIONS(225), 1,
      anon_sym_EQ_GT,
    ACTIONS(980), 1,
      anon_sym_EQ,
    ACTIONS(3431), 1,
      sym_identifier,
    STATE(1616), 1,
      sym_nested_identifier,
    STATE(1617), 1,
      sym_string,
    STATE(1711), 1,
      sym__module,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(154), 12,
      sym__ternary_qmark,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
    ACTIONS(160), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
    ACTIONS(120), 24,
      anon_sym_STAR,
      anon_sym_as,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_satisfies,
  [6984] = 15,
    ACTIONS(3536), 1,
      anon_sym_LBRACK,
    ACTIONS(3539), 1,
      anon_sym_DOT,
    ACTIONS(3545), 1,
      anon_sym_LT,
    ACTIONS(3548), 1,
      anon_sym_extends,
    ACTIONS(3588), 1,
      anon_sym_EQ_GT,
    ACTIONS(3617), 1,
      anon_sym_QMARK,
    ACTIONS(3619), 1,
      anon_sym_EQ,
    ACTIONS(3635), 1,
      anon_sym_RPAREN,
    STATE(2964), 1,
      sym_type_arguments,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3542), 2,
      anon_sym_AMP,
      anon_sym_PIPE,
    ACTIONS(3622), 2,
      anon_sym_COMMA,
      anon_sym_COLON,
    ACTIONS(3496), 13,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_QMARK_DOT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
    ACTIONS(3498), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
    ACTIONS(3492), 18,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK_QMARK,
  [7076] = 9,
    ACTIONS(834), 1,
      anon_sym_EQ,
    ACTIONS(844), 1,
      anon_sym_EQ_GT,
    ACTIONS(1898), 1,
      anon_sym_extends,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3605), 2,
      anon_sym_COMMA,
      anon_sym_LBRACK,
    ACTIONS(3608), 3,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_GT,
    ACTIONS(160), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
    ACTIONS(120), 18,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_QMARK_QMARK,
    ACTIONS(154), 18,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [7156] = 6,
    ACTIONS(3510), 1,
      anon_sym_EQ,
    ACTIONS(3518), 1,
      anon_sym_EQ_GT,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3498), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
    ACTIONS(3496), 20,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
    ACTIONS(3492), 21,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK_QMARK,
  [7229] = 7,
    ACTIONS(3494), 1,
      anon_sym_EQ,
    ACTIONS(3590), 1,
      anon_sym_QMARK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3586), 5,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_RBRACK,
    ACTIONS(3496), 15,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
    ACTIONS(3498), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
    ACTIONS(3492), 21,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK_QMARK,
  [7304] = 14,
    ACTIONS(3510), 1,
      anon_sym_EQ,
    ACTIONS(3518), 1,
      anon_sym_EQ_GT,
    ACTIONS(3536), 1,
      anon_sym_LBRACK,
    ACTIONS(3539), 1,
      anon_sym_DOT,
    ACTIONS(3545), 1,
      anon_sym_LT,
    ACTIONS(3548), 1,
      anon_sym_extends,
    ACTIONS(3586), 1,
      anon_sym_COLON,
    STATE(2964), 1,
      sym_type_arguments,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3542), 2,
      anon_sym_AMP,
      anon_sym_PIPE,
    ACTIONS(3638), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK,
    ACTIONS(3496), 13,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_QMARK_DOT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
    ACTIONS(3498), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
    ACTIONS(3492), 18,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK_QMARK,
  [7393] = 13,
    ACTIONS(3494), 1,
      anon_sym_EQ,
    ACTIONS(3536), 1,
      anon_sym_LBRACK,
    ACTIONS(3539), 1,
      anon_sym_DOT,
    ACTIONS(3545), 1,
      anon_sym_LT,
    ACTIONS(3586), 1,
      anon_sym_COLON,
    ACTIONS(3588), 1,
      anon_sym_EQ_GT,
    STATE(2964), 1,
      sym_type_arguments,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3542), 2,
      anon_sym_AMP,
      anon_sym_PIPE,
    ACTIONS(3548), 3,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_extends,
    ACTIONS(3496), 13,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_QMARK_DOT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
    ACTIONS(3498), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
    ACTIONS(3492), 18,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK_QMARK,
  [7480] = 14,
    ACTIONS(3514), 1,
      anon_sym_LPAREN,
    ACTIONS(3516), 1,
      anon_sym_DOT,
    ACTIONS(3520), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(3524), 1,
      anon_sym_LT,
    ACTIONS(3642), 1,
      anon_sym_EQ,
    ACTIONS(3644), 1,
      anon_sym_EQ_GT,
    STATE(2917), 1,
      sym_arguments,
    STATE(3015), 1,
      sym_type_arguments,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3512), 3,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_extends,
    ACTIONS(3522), 3,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_GT,
    ACTIONS(3496), 12,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COLON,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
    ACTIONS(3498), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
    ACTIONS(3492), 17,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_QMARK_QMARK,
  [7569] = 4,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3474), 4,
      sym__automatic_semicolon,
      anon_sym_SEMI,
      anon_sym_extends,
      anon_sym_PIPE_RBRACE,
    ACTIONS(3458), 22,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK_QMARK,
    ACTIONS(3460), 32,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [7638] = 14,
    ACTIONS(3514), 1,
      anon_sym_LPAREN,
    ACTIONS(3516), 1,
      anon_sym_DOT,
    ACTIONS(3520), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(3524), 1,
      anon_sym_LT,
    ACTIONS(3646), 1,
      anon_sym_EQ,
    ACTIONS(3648), 1,
      anon_sym_EQ_GT,
    STATE(2917), 1,
      sym_arguments,
    STATE(3015), 1,
      sym_type_arguments,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3512), 3,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_extends,
    ACTIONS(3522), 3,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_GT,
    ACTIONS(3496), 12,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_of,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
    ACTIONS(3498), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
    ACTIONS(3492), 17,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_QMARK_QMARK,
  [7727] = 4,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3478), 4,
      sym__automatic_semicolon,
      anon_sym_SEMI,
      anon_sym_extends,
      anon_sym_PIPE_RBRACE,
    ACTIONS(3462), 22,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK_QMARK,
    ACTIONS(3464), 32,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [7796] = 8,
    ACTIONS(682), 1,
      anon_sym_EQ_GT,
    ACTIONS(858), 1,
      anon_sym_EQ,
    ACTIONS(860), 1,
      anon_sym_COLON,
    ACTIONS(3456), 1,
      sym_identifier,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(154), 15,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
    ACTIONS(160), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
    ACTIONS(120), 24,
      anon_sym_STAR,
      anon_sym_as,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_satisfies,
  [7873] = 11,
    ACTIONS(220), 1,
      anon_sym_EQ,
    ACTIONS(225), 1,
      anon_sym_EQ_GT,
    ACTIONS(720), 1,
      anon_sym_QMARK,
    ACTIONS(3605), 1,
      anon_sym_LBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(223), 2,
      anon_sym_COMMA,
      anon_sym_COLON,
    ACTIONS(1898), 2,
      anon_sym_RPAREN,
      anon_sym_extends,
    ACTIONS(3608), 2,
      anon_sym_AMP,
      anon_sym_PIPE,
    ACTIONS(154), 14,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
    ACTIONS(160), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
    ACTIONS(120), 19,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK_QMARK,
  [7956] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3652), 16,
      anon_sym_LBRACE,
      anon_sym_BANG,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_DOT,
      anon_sym_LT,
      anon_sym_TILDE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      anon_sym_BQUOTE,
      sym_number,
      sym_private_property_identifier,
      anon_sym_AT,
    ACTIONS(3650), 42,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_typeof,
      anon_sym_import,
      anon_sym_let,
      anon_sym_await,
      anon_sym_yield,
      anon_sym_class,
      anon_sym_async,
      anon_sym_function,
      anon_sym_new,
      anon_sym_using,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_void,
      anon_sym_delete,
      sym_identifier,
      sym_this,
      sym_super,
      sym_true,
      sym_false,
      sym_null,
      sym_undefined,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
      anon_sym_abstract,
  [8023] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3656), 16,
      anon_sym_LBRACE,
      anon_sym_BANG,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_DOT,
      anon_sym_LT,
      anon_sym_TILDE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      anon_sym_BQUOTE,
      sym_number,
      sym_private_property_identifier,
      anon_sym_AT,
    ACTIONS(3654), 42,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_typeof,
      anon_sym_import,
      anon_sym_let,
      anon_sym_await,
      anon_sym_yield,
      anon_sym_class,
      anon_sym_async,
      anon_sym_function,
      anon_sym_new,
      anon_sym_using,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_void,
      anon_sym_delete,
      sym_identifier,
      sym_this,
      sym_super,
      sym_true,
      sym_false,
      sym_null,
      sym_undefined,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
      anon_sym_abstract,
  [8090] = 12,
    ACTIONS(3539), 1,
      anon_sym_DOT,
    ACTIONS(3545), 1,
      anon_sym_LT,
    ACTIONS(3548), 1,
      anon_sym_extends,
    ACTIONS(3601), 1,
      anon_sym_EQ,
    ACTIONS(3603), 1,
      anon_sym_EQ_GT,
    STATE(2964), 1,
      sym_type_arguments,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3536), 2,
      anon_sym_COMMA,
      anon_sym_LBRACK,
    ACTIONS(3542), 3,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_GT,
    ACTIONS(3496), 15,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_QMARK_DOT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
    ACTIONS(3498), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
    ACTIONS(3492), 17,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_QMARK_QMARK,
  [8175] = 4,
    ACTIONS(3474), 1,
      anon_sym_extends,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3458), 22,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK_QMARK,
    ACTIONS(3460), 35,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [8244] = 4,
    ACTIONS(3478), 1,
      anon_sym_extends,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3462), 22,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK_QMARK,
    ACTIONS(3464), 35,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [8313] = 8,
    ACTIONS(682), 1,
      anon_sym_EQ_GT,
    ACTIONS(858), 1,
      anon_sym_EQ,
    ACTIONS(878), 1,
      anon_sym_COLON,
    ACTIONS(3456), 1,
      sym_identifier,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(154), 15,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
    ACTIONS(160), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
    ACTIONS(120), 24,
      anon_sym_STAR,
      anon_sym_as,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_satisfies,
  [8390] = 14,
    ACTIONS(3494), 1,
      anon_sym_EQ,
    ACTIONS(3514), 1,
      anon_sym_LPAREN,
    ACTIONS(3516), 1,
      anon_sym_DOT,
    ACTIONS(3520), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(3524), 1,
      anon_sym_LT,
    ACTIONS(3588), 1,
      anon_sym_EQ_GT,
    STATE(2917), 1,
      sym_arguments,
    STATE(3015), 1,
      sym_type_arguments,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3522), 2,
      anon_sym_AMP,
      anon_sym_PIPE,
    ACTIONS(3512), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_extends,
    ACTIONS(3496), 11,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
    ACTIONS(3498), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
    ACTIONS(3492), 18,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK_QMARK,
  [8479] = 12,
    ACTIONS(3536), 1,
      anon_sym_LBRACK,
    ACTIONS(3539), 1,
      anon_sym_DOT,
    ACTIONS(3545), 1,
      anon_sym_LT,
    ACTIONS(3582), 1,
      anon_sym_EQ,
    ACTIONS(3584), 1,
      anon_sym_EQ_GT,
    STATE(2964), 1,
      sym_type_arguments,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3548), 2,
      anon_sym_COMMA,
      anon_sym_extends,
    ACTIONS(3542), 3,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_GT,
    ACTIONS(3496), 15,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK_DOT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
    ACTIONS(3498), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
    ACTIONS(3492), 17,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_QMARK_QMARK,
  [8564] = 7,
    ACTIONS(3617), 1,
      anon_sym_QMARK,
    ACTIONS(3619), 1,
      anon_sym_EQ,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3622), 5,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_RBRACK,
    ACTIONS(3496), 15,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
    ACTIONS(3498), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
    ACTIONS(3492), 21,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK_QMARK,
  [8639] = 14,
    ACTIONS(3514), 1,
      anon_sym_LPAREN,
    ACTIONS(3516), 1,
      anon_sym_DOT,
    ACTIONS(3520), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(3524), 1,
      anon_sym_LT,
    ACTIONS(3658), 1,
      anon_sym_EQ,
    ACTIONS(3660), 1,
      anon_sym_EQ_GT,
    STATE(2917), 1,
      sym_arguments,
    STATE(3015), 1,
      sym_type_arguments,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3512), 3,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_extends,
    ACTIONS(3522), 3,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_GT,
    ACTIONS(3496), 12,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_RBRACK,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
    ACTIONS(3498), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
    ACTIONS(3492), 17,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_QMARK_QMARK,
  [8728] = 7,
    ACTIONS(3628), 1,
      anon_sym_AT,
    ACTIONS(3662), 1,
      anon_sym_class,
    STATE(1269), 1,
      aux_sym_export_statement_repeat1,
    STATE(1344), 1,
      sym_decorator,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3626), 14,
      anon_sym_LBRACE,
      anon_sym_BANG,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_DOT,
      anon_sym_LT,
      anon_sym_TILDE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      anon_sym_BQUOTE,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(3624), 40,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_typeof,
      anon_sym_import,
      anon_sym_let,
      anon_sym_await,
      anon_sym_yield,
      anon_sym_async,
      anon_sym_function,
      anon_sym_new,
      anon_sym_using,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_void,
      anon_sym_delete,
      sym_identifier,
      sym_this,
      sym_super,
      sym_true,
      sym_false,
      sym_null,
      sym_undefined,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [8803] = 14,
    ACTIONS(3510), 1,
      anon_sym_EQ,
    ACTIONS(3514), 1,
      anon_sym_LPAREN,
    ACTIONS(3516), 1,
      anon_sym_DOT,
    ACTIONS(3518), 1,
      anon_sym_EQ_GT,
    ACTIONS(3520), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(3524), 1,
      anon_sym_LT,
    STATE(2917), 1,
      sym_arguments,
    STATE(3015), 1,
      sym_type_arguments,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3522), 2,
      anon_sym_AMP,
      anon_sym_PIPE,
    ACTIONS(3512), 3,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_extends,
    ACTIONS(3496), 12,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
    ACTIONS(3498), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
    ACTIONS(3492), 18,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK_QMARK,
  [8892] = 6,
    ACTIONS(824), 1,
      anon_sym_EQ,
    ACTIONS(844), 1,
      anon_sym_EQ_GT,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(160), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
    ACTIONS(154), 20,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
    ACTIONS(120), 21,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK_QMARK,
  [8965] = 9,
    ACTIONS(866), 1,
      anon_sym_EQ,
    ACTIONS(872), 1,
      anon_sym_EQ_GT,
    ACTIONS(1898), 1,
      anon_sym_extends,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3605), 2,
      anon_sym_COMMA,
      anon_sym_LBRACK,
    ACTIONS(3608), 3,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_GT,
    ACTIONS(160), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
    ACTIONS(154), 17,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
    ACTIONS(120), 18,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_QMARK_QMARK,
  [9044] = 6,
    ACTIONS(3494), 1,
      anon_sym_EQ,
    ACTIONS(3518), 1,
      anon_sym_EQ_GT,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3498), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
    ACTIONS(3496), 20,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
    ACTIONS(3492), 21,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK_QMARK,
  [9117] = 12,
    ACTIONS(3539), 1,
      anon_sym_DOT,
    ACTIONS(3545), 1,
      anon_sym_LT,
    ACTIONS(3548), 1,
      anon_sym_extends,
    ACTIONS(3592), 1,
      anon_sym_EQ,
    ACTIONS(3594), 1,
      anon_sym_EQ_GT,
    STATE(2964), 1,
      sym_type_arguments,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3536), 2,
      anon_sym_COMMA,
      anon_sym_LBRACK,
    ACTIONS(3542), 3,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_GT,
    ACTIONS(3496), 15,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_QMARK_DOT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_implements,
    ACTIONS(3498), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
    ACTIONS(3492), 17,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_QMARK_QMARK,
  [9202] = 9,
    ACTIONS(682), 1,
      anon_sym_EQ_GT,
    ACTIONS(858), 1,
      anon_sym_EQ,
    ACTIONS(1898), 1,
      anon_sym_extends,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3605), 2,
      anon_sym_COMMA,
      anon_sym_LBRACK,
    ACTIONS(3608), 3,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_GT,
    ACTIONS(160), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
    ACTIONS(154), 17,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
    ACTIONS(120), 18,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_QMARK_QMARK,
  [9281] = 6,
    ACTIONS(834), 1,
      anon_sym_EQ,
    ACTIONS(844), 1,
      anon_sym_EQ_GT,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(160), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
    ACTIONS(154), 20,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
    ACTIONS(120), 21,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK_QMARK,
  [9354] = 11,
    ACTIONS(117), 1,
      anon_sym_EQ,
    ACTIONS(152), 1,
      anon_sym_EQ_GT,
    ACTIONS(720), 1,
      anon_sym_QMARK,
    ACTIONS(3605), 1,
      anon_sym_LBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(126), 2,
      anon_sym_COMMA,
      anon_sym_COLON,
    ACTIONS(1898), 2,
      anon_sym_RPAREN,
      anon_sym_extends,
    ACTIONS(3608), 2,
      anon_sym_AMP,
      anon_sym_PIPE,
    ACTIONS(154), 14,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
    ACTIONS(160), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
    ACTIONS(120), 19,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK_QMARK,
  [9437] = 9,
    ACTIONS(152), 1,
      anon_sym_EQ_GT,
    ACTIONS(880), 1,
      anon_sym_EQ,
    ACTIONS(1898), 1,
      anon_sym_extends,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3605), 2,
      anon_sym_COMMA,
      anon_sym_LBRACK,
    ACTIONS(3608), 3,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_GT,
    ACTIONS(160), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
    ACTIONS(154), 16,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
    ACTIONS(120), 18,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_QMARK_QMARK,
  [9515] = 6,
    ACTIONS(682), 1,
      anon_sym_EQ_GT,
    ACTIONS(858), 1,
      anon_sym_EQ,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(160), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
    ACTIONS(154), 19,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
    ACTIONS(120), 21,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK_QMARK,
  [9587] = 6,
    ACTIONS(682), 1,
      anon_sym_EQ_GT,
    ACTIONS(824), 1,
      anon_sym_EQ,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(160), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
    ACTIONS(154), 19,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
    ACTIONS(120), 21,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK_QMARK,
  [9659] = 12,
    ACTIONS(3510), 1,
      anon_sym_EQ,
    ACTIONS(3518), 1,
      anon_sym_EQ_GT,
    ACTIONS(3539), 1,
      anon_sym_DOT,
    ACTIONS(3545), 1,
      anon_sym_LT,
    ACTIONS(3548), 1,
      anon_sym_extends,
    STATE(2964), 1,
      sym_type_arguments,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3536), 2,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
    ACTIONS(3542), 2,
      anon_sym_AMP,
      anon_sym_PIPE,
    ACTIONS(3496), 14,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_QMARK_DOT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
    ACTIONS(3498), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
    ACTIONS(3492), 18,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK_QMARK,
  [9743] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3480), 22,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK_QMARK,
    ACTIONS(3482), 35,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [9809] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3484), 22,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK_QMARK,
    ACTIONS(3486), 35,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [9875] = 6,
    ACTIONS(866), 1,
      anon_sym_EQ,
    ACTIONS(872), 1,
      anon_sym_EQ_GT,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(160), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
    ACTIONS(154), 19,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
    ACTIONS(120), 21,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK_QMARK,
  [9947] = 6,
    ACTIONS(3494), 1,
      anon_sym_EQ,
    ACTIONS(3580), 1,
      anon_sym_EQ_GT,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3498), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
    ACTIONS(3496), 19,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
    ACTIONS(3492), 21,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK_QMARK,
  [10019] = 8,
    ACTIONS(3603), 1,
      anon_sym_EQ_GT,
    ACTIONS(3611), 1,
      anon_sym_EQ,
    ACTIONS(3617), 1,
      anon_sym_QMARK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3614), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_COLON,
    ACTIONS(3496), 15,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
    ACTIONS(3498), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
    ACTIONS(3492), 21,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK_QMARK,
  [10095] = 7,
    ACTIONS(878), 1,
      anon_sym_COLON,
    ACTIONS(3505), 1,
      anon_sym_EQ_GT,
    ACTIONS(3562), 1,
      anon_sym_EQ,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3498), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
    ACTIONS(3496), 18,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
    ACTIONS(3492), 21,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK_QMARK,
  [10169] = 7,
    ACTIONS(682), 1,
      anon_sym_EQ_GT,
    ACTIONS(858), 1,
      anon_sym_EQ,
    ACTIONS(878), 1,
      anon_sym_COLON,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(160), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
    ACTIONS(154), 18,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
    ACTIONS(120), 21,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK_QMARK,
  [10243] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3572), 15,
      anon_sym_LBRACE,
      anon_sym_BANG,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_DOT,
      anon_sym_LT,
      anon_sym_TILDE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      anon_sym_BQUOTE,
      sym_number,
      sym_private_property_identifier,
      anon_sym_AT,
    ACTIONS(3570), 42,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_typeof,
      anon_sym_import,
      anon_sym_let,
      anon_sym_await,
      anon_sym_yield,
      anon_sym_class,
      anon_sym_async,
      anon_sym_function,
      anon_sym_new,
      anon_sym_using,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_void,
      anon_sym_delete,
      sym_identifier,
      sym_this,
      sym_super,
      sym_true,
      sym_false,
      sym_null,
      sym_undefined,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
      anon_sym_abstract,
  [10309] = 10,
    ACTIONS(225), 1,
      anon_sym_EQ_GT,
    ACTIONS(824), 1,
      anon_sym_EQ,
    ACTIONS(826), 1,
      anon_sym_COLON,
    ACTIONS(3605), 1,
      anon_sym_LBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3608), 2,
      anon_sym_AMP,
      anon_sym_PIPE,
    ACTIONS(1898), 3,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_extends,
    ACTIONS(154), 14,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
    ACTIONS(160), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
    ACTIONS(120), 19,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK_QMARK,
  [10389] = 8,
    ACTIONS(117), 1,
      anon_sym_EQ,
    ACTIONS(152), 1,
      anon_sym_EQ_GT,
    ACTIONS(720), 1,
      anon_sym_QMARK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(126), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_COLON,
    ACTIONS(154), 15,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
    ACTIONS(160), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
    ACTIONS(120), 21,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK_QMARK,
  [10465] = 6,
    ACTIONS(3494), 1,
      anon_sym_EQ,
    ACTIONS(3505), 1,
      anon_sym_EQ_GT,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3498), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
    ACTIONS(3496), 19,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
    ACTIONS(3492), 21,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK_QMARK,
  [10537] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3458), 22,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK_QMARK,
    ACTIONS(3460), 35,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [10603] = 5,
    ACTIONS(3510), 1,
      anon_sym_EQ,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3498), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
    ACTIONS(3496), 20,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
    ACTIONS(3492), 21,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK_QMARK,
  [10673] = 12,
    ACTIONS(3536), 1,
      anon_sym_LBRACK,
    ACTIONS(3539), 1,
      anon_sym_DOT,
    ACTIONS(3545), 1,
      anon_sym_LT,
    ACTIONS(3642), 1,
      anon_sym_EQ,
    ACTIONS(3644), 1,
      anon_sym_EQ_GT,
    STATE(2964), 1,
      sym_type_arguments,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3548), 2,
      anon_sym_COMMA,
      anon_sym_extends,
    ACTIONS(3542), 3,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_GT,
    ACTIONS(3496), 14,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_COLON,
      anon_sym_QMARK_DOT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
    ACTIONS(3498), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
    ACTIONS(3492), 17,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_QMARK_QMARK,
  [10757] = 6,
    ACTIONS(3505), 1,
      anon_sym_EQ_GT,
    ACTIONS(3562), 1,
      anon_sym_EQ,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3498), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
    ACTIONS(3496), 19,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
    ACTIONS(3492), 21,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK_QMARK,
  [10829] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3462), 22,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK_QMARK,
    ACTIONS(3464), 35,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [10895] = 7,
    ACTIONS(682), 1,
      anon_sym_EQ_GT,
    ACTIONS(858), 1,
      anon_sym_EQ,
    ACTIONS(860), 1,
      anon_sym_COLON,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(160), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
    ACTIONS(154), 18,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
    ACTIONS(120), 21,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK_QMARK,
  [10969] = 14,
    ACTIONS(3494), 1,
      anon_sym_EQ,
    ACTIONS(3514), 1,
      anon_sym_LPAREN,
    ACTIONS(3516), 1,
      anon_sym_DOT,
    ACTIONS(3520), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(3524), 1,
      anon_sym_LT,
    ACTIONS(3588), 1,
      anon_sym_EQ_GT,
    STATE(2917), 1,
      sym_arguments,
    STATE(3015), 1,
      sym_type_arguments,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3522), 2,
      anon_sym_AMP,
      anon_sym_PIPE,
    ACTIONS(3512), 3,
      anon_sym_RPAREN,
      anon_sym_LBRACK,
      anon_sym_extends,
    ACTIONS(3496), 11,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
    ACTIONS(3498), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
    ACTIONS(3492), 18,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK_QMARK,
  [11057] = 9,
    ACTIONS(918), 1,
      anon_sym_EQ,
    ACTIONS(924), 1,
      anon_sym_EQ_GT,
    ACTIONS(3605), 1,
      anon_sym_LBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(1898), 2,
      anon_sym_COMMA,
      anon_sym_extends,
    ACTIONS(3608), 3,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_GT,
    ACTIONS(160), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
    ACTIONS(154), 16,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
    ACTIONS(120), 18,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_QMARK_QMARK,
  [11135] = 6,
    ACTIONS(3578), 1,
      anon_sym_EQ,
    ACTIONS(3580), 1,
      anon_sym_EQ_GT,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3498), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
    ACTIONS(3496), 19,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
    ACTIONS(3492), 21,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK_QMARK,
  [11207] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3470), 22,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK_QMARK,
    ACTIONS(3472), 35,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [11273] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(2509), 22,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK_QMARK,
    ACTIONS(2507), 35,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [11339] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3667), 15,
      anon_sym_LBRACE,
      anon_sym_BANG,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_DOT,
      anon_sym_LT,
      anon_sym_TILDE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      anon_sym_BQUOTE,
      sym_number,
      sym_private_property_identifier,
      anon_sym_AT,
    ACTIONS(3665), 42,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_typeof,
      anon_sym_import,
      anon_sym_let,
      anon_sym_await,
      anon_sym_yield,
      anon_sym_class,
      anon_sym_async,
      anon_sym_function,
      anon_sym_new,
      anon_sym_using,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_void,
      anon_sym_delete,
      sym_identifier,
      sym_this,
      sym_super,
      sym_true,
      sym_false,
      sym_null,
      sym_undefined,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
      anon_sym_abstract,
  [11405] = 11,
    ACTIONS(826), 1,
      anon_sym_COLON,
    ACTIONS(834), 1,
      anon_sym_EQ,
    ACTIONS(844), 1,
      anon_sym_EQ_GT,
    ACTIONS(1898), 1,
      anon_sym_extends,
    ACTIONS(3605), 1,
      anon_sym_LBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3608), 2,
      anon_sym_AMP,
      anon_sym_PIPE,
    ACTIONS(3669), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK,
    ACTIONS(154), 14,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
    ACTIONS(160), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
    ACTIONS(120), 19,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK_QMARK,
  [11487] = 5,
    ACTIONS(3494), 1,
      anon_sym_EQ,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3498), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
    ACTIONS(3496), 20,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
    ACTIONS(3492), 21,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK_QMARK,
  [11557] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(2531), 22,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK_QMARK,
    ACTIONS(2529), 35,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [11623] = 12,
    ACTIONS(3536), 1,
      anon_sym_LBRACK,
    ACTIONS(3539), 1,
      anon_sym_DOT,
    ACTIONS(3545), 1,
      anon_sym_LT,
    ACTIONS(3658), 1,
      anon_sym_EQ,
    ACTIONS(3660), 1,
      anon_sym_EQ_GT,
    STATE(2964), 1,
      sym_type_arguments,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3548), 2,
      anon_sym_COMMA,
      anon_sym_extends,
    ACTIONS(3542), 3,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_GT,
    ACTIONS(3496), 14,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_QMARK_DOT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
    ACTIONS(3498), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
    ACTIONS(3492), 17,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_QMARK_QMARK,
  [11707] = 6,
    ACTIONS(824), 1,
      anon_sym_EQ,
    ACTIONS(872), 1,
      anon_sym_EQ_GT,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(160), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
    ACTIONS(154), 19,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
    ACTIONS(120), 21,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK_QMARK,
  [11779] = 10,
    ACTIONS(844), 1,
      anon_sym_EQ_GT,
    ACTIONS(907), 1,
      anon_sym_EQ,
    ACTIONS(1900), 1,
      anon_sym_QMARK,
    ACTIONS(3605), 1,
      anon_sym_LBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3608), 2,
      anon_sym_AMP,
      anon_sym_PIPE,
    ACTIONS(1898), 3,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_extends,
    ACTIONS(154), 14,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
    ACTIONS(160), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
    ACTIONS(120), 19,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK_QMARK,
  [11859] = 4,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3474), 3,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_extends,
    ACTIONS(3458), 22,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK_QMARK,
    ACTIONS(3460), 32,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_of,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [11927] = 12,
    ACTIONS(3536), 1,
      anon_sym_LBRACK,
    ACTIONS(3539), 1,
      anon_sym_DOT,
    ACTIONS(3545), 1,
      anon_sym_LT,
    ACTIONS(3646), 1,
      anon_sym_EQ,
    ACTIONS(3648), 1,
      anon_sym_EQ_GT,
    STATE(2964), 1,
      sym_type_arguments,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3548), 2,
      anon_sym_COMMA,
      anon_sym_extends,
    ACTIONS(3542), 3,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_GT,
    ACTIONS(3496), 14,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_of,
      anon_sym_QMARK_DOT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
    ACTIONS(3498), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
    ACTIONS(3492), 17,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_QMARK_QMARK,
  [12011] = 8,
    ACTIONS(826), 1,
      anon_sym_COLON,
    ACTIONS(834), 1,
      anon_sym_EQ,
    ACTIONS(844), 1,
      anon_sym_EQ_GT,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(899), 3,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_RBRACK,
    ACTIONS(154), 15,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
    ACTIONS(160), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
    ACTIONS(120), 21,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK_QMARK,
  [12087] = 7,
    ACTIONS(860), 1,
      anon_sym_COLON,
    ACTIONS(3505), 1,
      anon_sym_EQ_GT,
    ACTIONS(3562), 1,
      anon_sym_EQ,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3498), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
    ACTIONS(3496), 18,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
    ACTIONS(3492), 21,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK_QMARK,
  [12161] = 9,
    ACTIONS(932), 1,
      anon_sym_EQ,
    ACTIONS(938), 1,
      anon_sym_EQ_GT,
    ACTIONS(1898), 1,
      anon_sym_extends,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3605), 2,
      anon_sym_COMMA,
      anon_sym_LBRACK,
    ACTIONS(3608), 3,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_GT,
    ACTIONS(160), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
    ACTIONS(154), 16,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_implements,
    ACTIONS(120), 18,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_QMARK_QMARK,
  [12239] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3675), 15,
      anon_sym_LBRACE,
      anon_sym_BANG,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_DOT,
      anon_sym_LT,
      anon_sym_TILDE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      anon_sym_BQUOTE,
      sym_number,
      sym_private_property_identifier,
      anon_sym_AT,
    ACTIONS(3673), 42,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_typeof,
      anon_sym_import,
      anon_sym_let,
      anon_sym_await,
      anon_sym_yield,
      anon_sym_class,
      anon_sym_async,
      anon_sym_function,
      anon_sym_new,
      anon_sym_using,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_void,
      anon_sym_delete,
      sym_identifier,
      sym_this,
      sym_super,
      sym_true,
      sym_false,
      sym_null,
      sym_undefined,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
      anon_sym_abstract,
  [12305] = 4,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3478), 3,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_extends,
    ACTIONS(3462), 22,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK_QMARK,
    ACTIONS(3464), 32,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_of,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [12373] = 14,
    ACTIONS(3494), 1,
      anon_sym_EQ,
    ACTIONS(3514), 1,
      anon_sym_LPAREN,
    ACTIONS(3516), 1,
      anon_sym_DOT,
    ACTIONS(3520), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(3524), 1,
      anon_sym_LT,
    ACTIONS(3588), 1,
      anon_sym_EQ_GT,
    STATE(2917), 1,
      sym_arguments,
    STATE(3015), 1,
      sym_type_arguments,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3512), 3,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_extends,
    ACTIONS(3522), 3,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_GT,
    ACTIONS(3496), 11,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
    ACTIONS(3498), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
    ACTIONS(3492), 17,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_QMARK_QMARK,
  [12461] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3488), 22,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK_QMARK,
    ACTIONS(3490), 35,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [12527] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3466), 22,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK_QMARK,
    ACTIONS(3468), 35,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [12593] = 6,
    ACTIONS(3601), 1,
      anon_sym_EQ,
    ACTIONS(3603), 1,
      anon_sym_EQ_GT,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3498), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
    ACTIONS(3496), 18,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
    ACTIONS(3492), 21,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK_QMARK,
  [12664] = 4,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3474), 2,
      anon_sym_COMMA,
      anon_sym_extends,
    ACTIONS(3458), 22,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK_QMARK,
    ACTIONS(3460), 32,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [12731] = 7,
    ACTIONS(918), 1,
      anon_sym_EQ,
    ACTIONS(924), 1,
      anon_sym_EQ_GT,
    ACTIONS(3677), 1,
      sym_identifier,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(154), 14,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
    ACTIONS(160), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
    ACTIONS(120), 24,
      anon_sym_STAR,
      anon_sym_as,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_satisfies,
  [12804] = 7,
    ACTIONS(3611), 1,
      anon_sym_EQ,
    ACTIONS(3617), 1,
      anon_sym_QMARK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3614), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_COLON,
    ACTIONS(3496), 15,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
    ACTIONS(3498), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
    ACTIONS(3492), 21,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK_QMARK,
  [12877] = 6,
    ACTIONS(824), 1,
      anon_sym_EQ,
    ACTIONS(938), 1,
      anon_sym_EQ_GT,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(160), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
    ACTIONS(154), 18,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_implements,
    ACTIONS(120), 21,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK_QMARK,
  [12948] = 5,
    ACTIONS(3478), 1,
      anon_sym_extends,
    ACTIONS(3679), 1,
      anon_sym_QMARK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3462), 22,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK_QMARK,
    ACTIONS(3464), 32,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [13017] = 6,
    ACTIONS(932), 1,
      anon_sym_EQ,
    ACTIONS(938), 1,
      anon_sym_EQ_GT,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(160), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
    ACTIONS(154), 18,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_implements,
    ACTIONS(120), 21,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK_QMARK,
  [13088] = 8,
    ACTIONS(3510), 1,
      anon_sym_EQ,
    ACTIONS(3518), 1,
      anon_sym_EQ_GT,
    ACTIONS(3681), 1,
      anon_sym_in,
    ACTIONS(3684), 1,
      anon_sym_of,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3498), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
    ACTIONS(3496), 17,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
    ACTIONS(3492), 20,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK_QMARK,
  [13163] = 12,
    ACTIONS(3494), 1,
      anon_sym_EQ,
    ACTIONS(3536), 1,
      anon_sym_LBRACK,
    ACTIONS(3539), 1,
      anon_sym_DOT,
    ACTIONS(3545), 1,
      anon_sym_LT,
    ACTIONS(3588), 1,
      anon_sym_EQ_GT,
    STATE(2964), 1,
      sym_type_arguments,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3548), 2,
      anon_sym_COMMA,
      anon_sym_extends,
    ACTIONS(3542), 3,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_GT,
    ACTIONS(3496), 13,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_QMARK_DOT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
    ACTIONS(3498), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
    ACTIONS(3492), 17,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_QMARK_QMARK,
  [13246] = 7,
    ACTIONS(3510), 1,
      anon_sym_EQ,
    ACTIONS(3518), 1,
      anon_sym_EQ_GT,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3686), 3,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_RBRACK,
    ACTIONS(3496), 15,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
    ACTIONS(3498), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
    ACTIONS(3492), 21,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK_QMARK,
  [13319] = 7,
    ACTIONS(918), 1,
      anon_sym_EQ,
    ACTIONS(924), 1,
      anon_sym_EQ_GT,
    ACTIONS(3456), 1,
      sym_identifier,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(154), 14,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
    ACTIONS(160), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
    ACTIONS(120), 24,
      anon_sym_STAR,
      anon_sym_as,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_satisfies,
  [13392] = 6,
    ACTIONS(3494), 1,
      anon_sym_EQ,
    ACTIONS(3603), 1,
      anon_sym_EQ_GT,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3498), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
    ACTIONS(3496), 18,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
    ACTIONS(3492), 21,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK_QMARK,
  [13463] = 9,
    ACTIONS(964), 1,
      anon_sym_EQ,
    ACTIONS(970), 1,
      anon_sym_EQ_GT,
    ACTIONS(3605), 1,
      anon_sym_LBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(1898), 2,
      anon_sym_COMMA,
      anon_sym_extends,
    ACTIONS(3608), 3,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_GT,
    ACTIONS(154), 15,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
    ACTIONS(160), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
    ACTIONS(120), 18,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_QMARK_QMARK,
  [13540] = 5,
    ACTIONS(3562), 1,
      anon_sym_EQ,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3498), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
    ACTIONS(3496), 19,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
    ACTIONS(3492), 21,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK_QMARK,
  [13609] = 7,
    ACTIONS(3510), 1,
      anon_sym_EQ,
    ACTIONS(3586), 1,
      anon_sym_COLON,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3686), 3,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_RBRACK,
    ACTIONS(3496), 15,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
    ACTIONS(3498), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
    ACTIONS(3492), 21,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK_QMARK,
  [13682] = 5,
    ACTIONS(3578), 1,
      anon_sym_EQ,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3498), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
    ACTIONS(3496), 19,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
    ACTIONS(3492), 21,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK_QMARK,
  [13751] = 8,
    ACTIONS(834), 1,
      anon_sym_EQ,
    ACTIONS(844), 1,
      anon_sym_EQ_GT,
    ACTIONS(902), 1,
      anon_sym_in,
    ACTIONS(3689), 1,
      anon_sym_of,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(160), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
    ACTIONS(154), 17,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
    ACTIONS(120), 20,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK_QMARK,
  [13826] = 6,
    ACTIONS(152), 1,
      anon_sym_EQ_GT,
    ACTIONS(824), 1,
      anon_sym_EQ,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(160), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
    ACTIONS(154), 18,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
    ACTIONS(120), 21,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK_QMARK,
  [13897] = 4,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3478), 2,
      anon_sym_COMMA,
      anon_sym_extends,
    ACTIONS(3462), 22,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK_QMARK,
    ACTIONS(3464), 32,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [13964] = 6,
    ACTIONS(152), 1,
      anon_sym_EQ_GT,
    ACTIONS(880), 1,
      anon_sym_EQ,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(160), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
    ACTIONS(154), 18,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
    ACTIONS(120), 21,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK_QMARK,
  [14035] = 5,
    ACTIONS(3474), 1,
      anon_sym_extends,
    ACTIONS(3691), 1,
      anon_sym_QMARK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3458), 22,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK_QMARK,
    ACTIONS(3460), 32,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [14104] = 9,
    ACTIONS(895), 1,
      anon_sym_EQ_GT,
    ACTIONS(910), 1,
      anon_sym_EQ,
    ACTIONS(3605), 1,
      anon_sym_LBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(1898), 2,
      anon_sym_COMMA,
      anon_sym_extends,
    ACTIONS(3608), 3,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_GT,
    ACTIONS(154), 15,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
    ACTIONS(160), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
    ACTIONS(120), 18,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_QMARK_QMARK,
  [14181] = 7,
    ACTIONS(844), 1,
      anon_sym_EQ_GT,
    ACTIONS(907), 1,
      anon_sym_EQ,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(126), 3,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_RBRACK,
    ACTIONS(154), 15,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
    ACTIONS(160), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
    ACTIONS(120), 21,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK_QMARK,
  [14254] = 10,
    ACTIONS(3614), 1,
      anon_sym_RBRACK,
    ACTIONS(3622), 1,
      anon_sym_COMMA,
    ACTIONS(3660), 1,
      anon_sym_EQ_GT,
    ACTIONS(3693), 1,
      anon_sym_EQ,
    ACTIONS(3696), 1,
      anon_sym_in,
    ACTIONS(3698), 1,
      anon_sym_COLON,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3496), 15,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
    ACTIONS(3498), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
    ACTIONS(3492), 20,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK_QMARK,
  [14333] = 9,
    ACTIONS(948), 1,
      anon_sym_EQ,
    ACTIONS(954), 1,
      anon_sym_EQ_GT,
    ACTIONS(3605), 1,
      anon_sym_LBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(1898), 2,
      anon_sym_COMMA,
      anon_sym_extends,
    ACTIONS(3608), 3,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_GT,
    ACTIONS(154), 15,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_of,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
    ACTIONS(160), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
    ACTIONS(120), 18,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_QMARK_QMARK,
  [14410] = 6,
    ACTIONS(3592), 1,
      anon_sym_EQ,
    ACTIONS(3594), 1,
      anon_sym_EQ_GT,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3498), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
    ACTIONS(3496), 18,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_implements,
    ACTIONS(3492), 21,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK_QMARK,
  [14481] = 6,
    ACTIONS(3494), 1,
      anon_sym_EQ,
    ACTIONS(3594), 1,
      anon_sym_EQ_GT,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3498), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
    ACTIONS(3496), 18,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_implements,
    ACTIONS(3492), 21,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK_QMARK,
  [14552] = 7,
    ACTIONS(3518), 1,
      anon_sym_EQ_GT,
    ACTIONS(3550), 1,
      anon_sym_EQ,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3614), 3,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_RBRACK,
    ACTIONS(3496), 15,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
    ACTIONS(3498), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
    ACTIONS(3492), 21,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK_QMARK,
  [14625] = 9,
    ACTIONS(126), 1,
      anon_sym_RBRACK,
    ACTIONS(223), 1,
      anon_sym_COMMA,
    ACTIONS(886), 1,
      anon_sym_EQ,
    ACTIONS(891), 1,
      anon_sym_COLON,
    ACTIONS(895), 1,
      anon_sym_EQ_GT,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(154), 15,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
    ACTIONS(160), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
    ACTIONS(120), 21,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK_QMARK,
  [14702] = 9,
    ACTIONS(834), 1,
      anon_sym_EQ,
    ACTIONS(844), 1,
      anon_sym_EQ_GT,
    ACTIONS(1898), 1,
      anon_sym_extends,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3605), 2,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
    ACTIONS(3608), 2,
      anon_sym_AMP,
      anon_sym_PIPE,
    ACTIONS(154), 15,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
    ACTIONS(160), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
    ACTIONS(120), 19,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK_QMARK,
  [14779] = 7,
    ACTIONS(895), 1,
      anon_sym_EQ_GT,
    ACTIONS(910), 1,
      anon_sym_EQ,
    ACTIONS(912), 1,
      anon_sym_COLON,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(160), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
    ACTIONS(154), 16,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
    ACTIONS(120), 21,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK_QMARK,
  [14851] = 31,
    ACTIONS(97), 1,
      anon_sym_AT,
    ACTIONS(1626), 1,
      anon_sym_DQUOTE,
    ACTIONS(1628), 1,
      anon_sym_SQUOTE,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(3281), 1,
      anon_sym_LPAREN,
    ACTIONS(3305), 1,
      anon_sym_abstract,
    ACTIONS(3702), 1,
      anon_sym_export,
    ACTIONS(3704), 1,
      anon_sym_STAR,
    ACTIONS(3706), 1,
      anon_sym_LBRACK,
    ACTIONS(3708), 1,
      anon_sym_async,
    ACTIONS(3710), 1,
      anon_sym_new,
    ACTIONS(3714), 1,
      anon_sym_static,
    ACTIONS(3716), 1,
      anon_sym_readonly,
    ACTIONS(3722), 1,
      anon_sym_override,
    STATE(1344), 1,
      sym_decorator,
    STATE(2773), 1,
      sym_accessibility_modifier,
    STATE(2800), 1,
      sym_override_modifier,
    STATE(3315), 1,
      sym_formal_parameters,
    STATE(3910), 1,
      sym__call_signature,
    STATE(4481), 1,
      aux_sym_export_statement_repeat1,
    STATE(5233), 1,
      sym_type_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3283), 2,
      anon_sym_COMMA,
      anon_sym_SEMI,
    ACTIONS(3291), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(3307), 2,
      anon_sym_RBRACE,
      anon_sym_PIPE_RBRACE,
    ACTIONS(3712), 2,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(3718), 2,
      anon_sym_get,
      anon_sym_set,
    ACTIONS(3720), 3,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
    STATE(3111), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    STATE(3815), 6,
      sym_export_statement,
      sym_method_signature,
      sym_call_signature,
      sym_property_signature,
      sym_construct_signature,
      sym_index_signature,
    ACTIONS(3700), 12,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      sym_identifier,
      anon_sym_declare,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [14971] = 7,
    ACTIONS(3510), 1,
      anon_sym_EQ,
    ACTIONS(3681), 1,
      anon_sym_in,
    ACTIONS(3684), 1,
      anon_sym_of,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3498), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
    ACTIONS(3496), 17,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
    ACTIONS(3492), 20,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK_QMARK,
  [15043] = 31,
    ACTIONS(97), 1,
      anon_sym_AT,
    ACTIONS(1626), 1,
      anon_sym_DQUOTE,
    ACTIONS(1628), 1,
      anon_sym_SQUOTE,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(3281), 1,
      anon_sym_LPAREN,
    ACTIONS(3305), 1,
      anon_sym_abstract,
    ACTIONS(3702), 1,
      anon_sym_export,
    ACTIONS(3704), 1,
      anon_sym_STAR,
    ACTIONS(3706), 1,
      anon_sym_LBRACK,
    ACTIONS(3708), 1,
      anon_sym_async,
    ACTIONS(3710), 1,
      anon_sym_new,
    ACTIONS(3714), 1,
      anon_sym_static,
    ACTIONS(3716), 1,
      anon_sym_readonly,
    ACTIONS(3722), 1,
      anon_sym_override,
    STATE(1344), 1,
      sym_decorator,
    STATE(2773), 1,
      sym_accessibility_modifier,
    STATE(2800), 1,
      sym_override_modifier,
    STATE(3315), 1,
      sym_formal_parameters,
    STATE(3910), 1,
      sym__call_signature,
    STATE(4481), 1,
      aux_sym_export_statement_repeat1,
    STATE(5233), 1,
      sym_type_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3291), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(3712), 2,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(3718), 2,
      anon_sym_get,
      anon_sym_set,
    ACTIONS(3724), 2,
      anon_sym_COMMA,
      anon_sym_SEMI,
    ACTIONS(3726), 2,
      anon_sym_RBRACE,
      anon_sym_PIPE_RBRACE,
    ACTIONS(3720), 3,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
    STATE(3111), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    STATE(3810), 6,
      sym_export_statement,
      sym_method_signature,
      sym_call_signature,
      sym_property_signature,
      sym_construct_signature,
      sym_index_signature,
    ACTIONS(3700), 12,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      sym_identifier,
      anon_sym_declare,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [15163] = 6,
    ACTIONS(824), 1,
      anon_sym_EQ,
    ACTIONS(924), 1,
      anon_sym_EQ_GT,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(160), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
    ACTIONS(154), 17,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
    ACTIONS(120), 21,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK_QMARK,
  [15233] = 6,
    ACTIONS(3582), 1,
      anon_sym_EQ,
    ACTIONS(3584), 1,
      anon_sym_EQ_GT,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3498), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
    ACTIONS(3496), 17,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
    ACTIONS(3492), 21,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK_QMARK,
  [15303] = 6,
    ACTIONS(918), 1,
      anon_sym_EQ,
    ACTIONS(924), 1,
      anon_sym_EQ_GT,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(160), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
    ACTIONS(154), 17,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
    ACTIONS(120), 21,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK_QMARK,
  [15373] = 31,
    ACTIONS(97), 1,
      anon_sym_AT,
    ACTIONS(1626), 1,
      anon_sym_DQUOTE,
    ACTIONS(1628), 1,
      anon_sym_SQUOTE,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(3281), 1,
      anon_sym_LPAREN,
    ACTIONS(3305), 1,
      anon_sym_abstract,
    ACTIONS(3702), 1,
      anon_sym_export,
    ACTIONS(3704), 1,
      anon_sym_STAR,
    ACTIONS(3706), 1,
      anon_sym_LBRACK,
    ACTIONS(3708), 1,
      anon_sym_async,
    ACTIONS(3710), 1,
      anon_sym_new,
    ACTIONS(3714), 1,
      anon_sym_static,
    ACTIONS(3716), 1,
      anon_sym_readonly,
    ACTIONS(3722), 1,
      anon_sym_override,
    STATE(1344), 1,
      sym_decorator,
    STATE(2773), 1,
      sym_accessibility_modifier,
    STATE(2800), 1,
      sym_override_modifier,
    STATE(3315), 1,
      sym_formal_parameters,
    STATE(3910), 1,
      sym__call_signature,
    STATE(4481), 1,
      aux_sym_export_statement_repeat1,
    STATE(5233), 1,
      sym_type_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3291), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(3712), 2,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(3718), 2,
      anon_sym_get,
      anon_sym_set,
    ACTIONS(3728), 2,
      anon_sym_COMMA,
      anon_sym_SEMI,
    ACTIONS(3730), 2,
      anon_sym_RBRACE,
      anon_sym_PIPE_RBRACE,
    ACTIONS(3720), 3,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
    STATE(3111), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    STATE(3887), 6,
      sym_export_statement,
      sym_method_signature,
      sym_call_signature,
      sym_property_signature,
      sym_construct_signature,
      sym_index_signature,
    ACTIONS(3700), 12,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      sym_identifier,
      anon_sym_declare,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [15493] = 5,
    ACTIONS(3592), 1,
      anon_sym_EQ,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3498), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
    ACTIONS(3496), 18,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_implements,
    ACTIONS(3492), 21,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK_QMARK,
  [15561] = 8,
    ACTIONS(3658), 1,
      anon_sym_EQ,
    ACTIONS(3660), 1,
      anon_sym_EQ_GT,
    ACTIONS(3696), 1,
      anon_sym_in,
    ACTIONS(3698), 1,
      anon_sym_COLON,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3498), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
    ACTIONS(3496), 16,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
    ACTIONS(3492), 20,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK_QMARK,
  [15635] = 31,
    ACTIONS(97), 1,
      anon_sym_AT,
    ACTIONS(1626), 1,
      anon_sym_DQUOTE,
    ACTIONS(1628), 1,
      anon_sym_SQUOTE,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(3281), 1,
      anon_sym_LPAREN,
    ACTIONS(3305), 1,
      anon_sym_abstract,
    ACTIONS(3702), 1,
      anon_sym_export,
    ACTIONS(3704), 1,
      anon_sym_STAR,
    ACTIONS(3706), 1,
      anon_sym_LBRACK,
    ACTIONS(3708), 1,
      anon_sym_async,
    ACTIONS(3710), 1,
      anon_sym_new,
    ACTIONS(3714), 1,
      anon_sym_static,
    ACTIONS(3716), 1,
      anon_sym_readonly,
    ACTIONS(3722), 1,
      anon_sym_override,
    STATE(1344), 1,
      sym_decorator,
    STATE(2773), 1,
      sym_accessibility_modifier,
    STATE(2800), 1,
      sym_override_modifier,
    STATE(3315), 1,
      sym_formal_parameters,
    STATE(3910), 1,
      sym__call_signature,
    STATE(4481), 1,
      aux_sym_export_statement_repeat1,
    STATE(5233), 1,
      sym_type_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3291), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(3712), 2,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(3718), 2,
      anon_sym_get,
      anon_sym_set,
    ACTIONS(3732), 2,
      anon_sym_COMMA,
      anon_sym_SEMI,
    ACTIONS(3734), 2,
      anon_sym_RBRACE,
      anon_sym_PIPE_RBRACE,
    ACTIONS(3720), 3,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
    STATE(3111), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    STATE(3777), 6,
      sym_export_statement,
      sym_method_signature,
      sym_call_signature,
      sym_property_signature,
      sym_construct_signature,
      sym_index_signature,
    ACTIONS(3700), 12,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      sym_identifier,
      anon_sym_declare,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [15755] = 8,
    ACTIONS(126), 1,
      anon_sym_RBRACK,
    ACTIONS(223), 1,
      anon_sym_COMMA,
    ACTIONS(886), 1,
      anon_sym_EQ,
    ACTIONS(895), 1,
      anon_sym_EQ_GT,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(154), 15,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
    ACTIONS(160), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
    ACTIONS(120), 21,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK_QMARK,
  [15829] = 8,
    ACTIONS(3614), 1,
      anon_sym_RBRACK,
    ACTIONS(3622), 1,
      anon_sym_COMMA,
    ACTIONS(3660), 1,
      anon_sym_EQ_GT,
    ACTIONS(3693), 1,
      anon_sym_EQ,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3496), 15,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
    ACTIONS(3498), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
    ACTIONS(3492), 21,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK_QMARK,
  [15903] = 8,
    ACTIONS(3658), 1,
      anon_sym_EQ,
    ACTIONS(3660), 1,
      anon_sym_EQ_GT,
    ACTIONS(3696), 1,
      anon_sym_in,
    ACTIONS(3736), 1,
      anon_sym_COLON,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3498), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
    ACTIONS(3496), 16,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
    ACTIONS(3492), 20,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK_QMARK,
  [15977] = 9,
    ACTIONS(225), 1,
      anon_sym_EQ_GT,
    ACTIONS(824), 1,
      anon_sym_EQ,
    ACTIONS(3605), 1,
      anon_sym_LBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(1898), 2,
      anon_sym_COMMA,
      anon_sym_extends,
    ACTIONS(3608), 3,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_GT,
    ACTIONS(154), 14,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
    ACTIONS(160), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
    ACTIONS(120), 18,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_QMARK_QMARK,
  [16053] = 31,
    ACTIONS(97), 1,
      anon_sym_AT,
    ACTIONS(1626), 1,
      anon_sym_DQUOTE,
    ACTIONS(1628), 1,
      anon_sym_SQUOTE,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(3281), 1,
      anon_sym_LPAREN,
    ACTIONS(3305), 1,
      anon_sym_abstract,
    ACTIONS(3702), 1,
      anon_sym_export,
    ACTIONS(3704), 1,
      anon_sym_STAR,
    ACTIONS(3706), 1,
      anon_sym_LBRACK,
    ACTIONS(3708), 1,
      anon_sym_async,
    ACTIONS(3710), 1,
      anon_sym_new,
    ACTIONS(3714), 1,
      anon_sym_static,
    ACTIONS(3716), 1,
      anon_sym_readonly,
    ACTIONS(3722), 1,
      anon_sym_override,
    STATE(1344), 1,
      sym_decorator,
    STATE(2773), 1,
      sym_accessibility_modifier,
    STATE(2800), 1,
      sym_override_modifier,
    STATE(3315), 1,
      sym_formal_parameters,
    STATE(3910), 1,
      sym__call_signature,
    STATE(4481), 1,
      aux_sym_export_statement_repeat1,
    STATE(5233), 1,
      sym_type_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3291), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(3399), 2,
      anon_sym_COMMA,
      anon_sym_SEMI,
    ACTIONS(3401), 2,
      anon_sym_RBRACE,
      anon_sym_PIPE_RBRACE,
    ACTIONS(3712), 2,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(3718), 2,
      anon_sym_get,
      anon_sym_set,
    ACTIONS(3720), 3,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
    STATE(3111), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    STATE(3844), 6,
      sym_export_statement,
      sym_method_signature,
      sym_call_signature,
      sym_property_signature,
      sym_construct_signature,
      sym_index_signature,
    ACTIONS(3700), 12,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      sym_identifier,
      anon_sym_declare,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [16173] = 31,
    ACTIONS(97), 1,
      anon_sym_AT,
    ACTIONS(1626), 1,
      anon_sym_DQUOTE,
    ACTIONS(1628), 1,
      anon_sym_SQUOTE,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(3281), 1,
      anon_sym_LPAREN,
    ACTIONS(3305), 1,
      anon_sym_abstract,
    ACTIONS(3702), 1,
      anon_sym_export,
    ACTIONS(3704), 1,
      anon_sym_STAR,
    ACTIONS(3706), 1,
      anon_sym_LBRACK,
    ACTIONS(3708), 1,
      anon_sym_async,
    ACTIONS(3710), 1,
      anon_sym_new,
    ACTIONS(3714), 1,
      anon_sym_static,
    ACTIONS(3716), 1,
      anon_sym_readonly,
    ACTIONS(3722), 1,
      anon_sym_override,
    STATE(1344), 1,
      sym_decorator,
    STATE(2773), 1,
      sym_accessibility_modifier,
    STATE(2800), 1,
      sym_override_modifier,
    STATE(3315), 1,
      sym_formal_parameters,
    STATE(3910), 1,
      sym__call_signature,
    STATE(4481), 1,
      aux_sym_export_statement_repeat1,
    STATE(5233), 1,
      sym_type_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3291), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(3712), 2,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(3718), 2,
      anon_sym_get,
      anon_sym_set,
    ACTIONS(3738), 2,
      anon_sym_COMMA,
      anon_sym_SEMI,
    ACTIONS(3740), 2,
      anon_sym_RBRACE,
      anon_sym_PIPE_RBRACE,
    ACTIONS(3720), 3,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
    STATE(3111), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    STATE(3809), 6,
      sym_export_statement,
      sym_method_signature,
      sym_call_signature,
      sym_property_signature,
      sym_construct_signature,
      sym_index_signature,
    ACTIONS(3700), 12,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      sym_identifier,
      anon_sym_declare,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [16293] = 6,
    ACTIONS(3550), 1,
      anon_sym_EQ,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3614), 3,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_RBRACK,
    ACTIONS(3496), 15,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
    ACTIONS(3498), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
    ACTIONS(3492), 21,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK_QMARK,
  [16363] = 4,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3474), 2,
      anon_sym_COMMA,
      anon_sym_extends,
    ACTIONS(3458), 22,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK_QMARK,
    ACTIONS(3460), 31,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [16429] = 5,
    ACTIONS(3601), 1,
      anon_sym_EQ,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3498), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
    ACTIONS(3496), 18,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
    ACTIONS(3492), 21,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK_QMARK,
  [16497] = 7,
    ACTIONS(891), 1,
      anon_sym_COLON,
    ACTIONS(895), 1,
      anon_sym_EQ_GT,
    ACTIONS(910), 1,
      anon_sym_EQ,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(160), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
    ACTIONS(154), 16,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
    ACTIONS(120), 21,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK_QMARK,
  [16569] = 6,
    ACTIONS(3494), 1,
      anon_sym_EQ,
    ACTIONS(3584), 1,
      anon_sym_EQ_GT,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3498), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
    ACTIONS(3496), 17,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
    ACTIONS(3492), 21,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK_QMARK,
  [16639] = 4,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3478), 2,
      anon_sym_COMMA,
      anon_sym_extends,
    ACTIONS(3462), 22,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK_QMARK,
    ACTIONS(3464), 31,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [16705] = 6,
    ACTIONS(3642), 1,
      anon_sym_EQ,
    ACTIONS(3644), 1,
      anon_sym_EQ_GT,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3498), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
    ACTIONS(3496), 16,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
    ACTIONS(3492), 21,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK_QMARK,
  [16774] = 6,
    ACTIONS(3658), 1,
      anon_sym_EQ,
    ACTIONS(3660), 1,
      anon_sym_EQ_GT,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3498), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
    ACTIONS(3496), 16,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
    ACTIONS(3492), 21,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK_QMARK,
  [16843] = 6,
    ACTIONS(948), 1,
      anon_sym_EQ,
    ACTIONS(954), 1,
      anon_sym_EQ_GT,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(160), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
    ACTIONS(154), 16,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_of,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
    ACTIONS(120), 21,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK_QMARK,
  [16912] = 6,
    ACTIONS(3494), 1,
      anon_sym_EQ,
    ACTIONS(3644), 1,
      anon_sym_EQ_GT,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3498), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
    ACTIONS(3496), 16,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
    ACTIONS(3492), 21,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK_QMARK,
  [16981] = 6,
    ACTIONS(3494), 1,
      anon_sym_EQ,
    ACTIONS(3660), 1,
      anon_sym_EQ_GT,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3498), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
    ACTIONS(3496), 16,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
    ACTIONS(3492), 21,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK_QMARK,
  [17050] = 6,
    ACTIONS(3646), 1,
      anon_sym_EQ,
    ACTIONS(3648), 1,
      anon_sym_EQ_GT,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3498), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
    ACTIONS(3496), 16,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_of,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
    ACTIONS(3492), 21,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK_QMARK,
  [17119] = 6,
    ACTIONS(3494), 1,
      anon_sym_EQ,
    ACTIONS(3648), 1,
      anon_sym_EQ_GT,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3498), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
    ACTIONS(3496), 16,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_of,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
    ACTIONS(3492), 21,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK_QMARK,
  [17188] = 7,
    ACTIONS(225), 1,
      anon_sym_EQ_GT,
    ACTIONS(824), 1,
      anon_sym_EQ,
    ACTIONS(826), 1,
      anon_sym_COLON,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(154), 15,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
    ACTIONS(160), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
    ACTIONS(120), 21,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK_QMARK,
  [17259] = 5,
    ACTIONS(3582), 1,
      anon_sym_EQ,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3498), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
    ACTIONS(3496), 17,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
    ACTIONS(3492), 21,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK_QMARK,
  [17326] = 8,
    ACTIONS(3494), 1,
      anon_sym_EQ,
    ACTIONS(3588), 1,
      anon_sym_EQ_GT,
    ACTIONS(3681), 1,
      anon_sym_in,
    ACTIONS(3684), 1,
      anon_sym_of,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3496), 15,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
    ACTIONS(3498), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
    ACTIONS(3492), 20,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK_QMARK,
  [17399] = 6,
    ACTIONS(824), 1,
      anon_sym_EQ,
    ACTIONS(970), 1,
      anon_sym_EQ_GT,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(160), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
    ACTIONS(154), 16,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
    ACTIONS(120), 21,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK_QMARK,
  [17468] = 8,
    ACTIONS(225), 1,
      anon_sym_EQ_GT,
    ACTIONS(824), 1,
      anon_sym_EQ,
    ACTIONS(902), 1,
      anon_sym_in,
    ACTIONS(3689), 1,
      anon_sym_of,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(154), 15,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
    ACTIONS(160), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
    ACTIONS(120), 20,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK_QMARK,
  [17541] = 7,
    ACTIONS(3614), 1,
      anon_sym_RBRACK,
    ACTIONS(3622), 1,
      anon_sym_COMMA,
    ACTIONS(3693), 1,
      anon_sym_EQ,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3496), 15,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
    ACTIONS(3498), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
    ACTIONS(3492), 21,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK_QMARK,
  [17612] = 6,
    ACTIONS(824), 1,
      anon_sym_EQ,
    ACTIONS(895), 1,
      anon_sym_EQ_GT,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(160), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
    ACTIONS(154), 16,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
    ACTIONS(120), 21,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK_QMARK,
  [17681] = 6,
    ACTIONS(895), 1,
      anon_sym_EQ_GT,
    ACTIONS(910), 1,
      anon_sym_EQ,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(160), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
    ACTIONS(154), 16,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
    ACTIONS(120), 21,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK_QMARK,
  [17750] = 6,
    ACTIONS(964), 1,
      anon_sym_EQ,
    ACTIONS(970), 1,
      anon_sym_EQ_GT,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(160), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
    ACTIONS(154), 16,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
    ACTIONS(120), 21,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK_QMARK,
  [17819] = 6,
    ACTIONS(824), 1,
      anon_sym_EQ,
    ACTIONS(954), 1,
      anon_sym_EQ_GT,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(160), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
    ACTIONS(154), 16,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_of,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
    ACTIONS(120), 21,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK_QMARK,
  [17888] = 30,
    ACTIONS(97), 1,
      anon_sym_AT,
    ACTIONS(1626), 1,
      anon_sym_DQUOTE,
    ACTIONS(1628), 1,
      anon_sym_SQUOTE,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(3281), 1,
      anon_sym_LPAREN,
    ACTIONS(3305), 1,
      anon_sym_abstract,
    ACTIONS(3702), 1,
      anon_sym_export,
    ACTIONS(3704), 1,
      anon_sym_STAR,
    ACTIONS(3706), 1,
      anon_sym_LBRACK,
    ACTIONS(3708), 1,
      anon_sym_async,
    ACTIONS(3710), 1,
      anon_sym_new,
    ACTIONS(3714), 1,
      anon_sym_static,
    ACTIONS(3716), 1,
      anon_sym_readonly,
    ACTIONS(3722), 1,
      anon_sym_override,
    STATE(1344), 1,
      sym_decorator,
    STATE(2773), 1,
      sym_accessibility_modifier,
    STATE(2800), 1,
      sym_override_modifier,
    STATE(3315), 1,
      sym_formal_parameters,
    STATE(3910), 1,
      sym__call_signature,
    STATE(4481), 1,
      aux_sym_export_statement_repeat1,
    STATE(5233), 1,
      sym_type_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3291), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(3712), 2,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(3718), 2,
      anon_sym_get,
      anon_sym_set,
    ACTIONS(3742), 2,
      anon_sym_RBRACE,
      anon_sym_PIPE_RBRACE,
    ACTIONS(3720), 3,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
    STATE(3111), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    STATE(4265), 6,
      sym_export_statement,
      sym_method_signature,
      sym_call_signature,
      sym_property_signature,
      sym_construct_signature,
      sym_index_signature,
    ACTIONS(3700), 12,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      sym_identifier,
      anon_sym_declare,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [18004] = 6,
    ACTIONS(3588), 1,
      anon_sym_EQ_GT,
    ACTIONS(3744), 1,
      anon_sym_EQ,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3496), 15,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
    ACTIONS(3498), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
    ACTIONS(3492), 21,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK_QMARK,
  [18072] = 6,
    ACTIONS(225), 1,
      anon_sym_EQ_GT,
    ACTIONS(1036), 1,
      anon_sym_EQ,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(154), 15,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
    ACTIONS(160), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
    ACTIONS(120), 21,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK_QMARK,
  [18140] = 6,
    ACTIONS(3588), 1,
      anon_sym_EQ_GT,
    ACTIONS(3746), 1,
      anon_sym_EQ,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3496), 15,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
    ACTIONS(3498), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
    ACTIONS(3492), 21,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK_QMARK,
  [18208] = 30,
    ACTIONS(97), 1,
      anon_sym_AT,
    ACTIONS(1626), 1,
      anon_sym_DQUOTE,
    ACTIONS(1628), 1,
      anon_sym_SQUOTE,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(3281), 1,
      anon_sym_LPAREN,
    ACTIONS(3305), 1,
      anon_sym_abstract,
    ACTIONS(3702), 1,
      anon_sym_export,
    ACTIONS(3704), 1,
      anon_sym_STAR,
    ACTIONS(3706), 1,
      anon_sym_LBRACK,
    ACTIONS(3708), 1,
      anon_sym_async,
    ACTIONS(3710), 1,
      anon_sym_new,
    ACTIONS(3714), 1,
      anon_sym_static,
    ACTIONS(3716), 1,
      anon_sym_readonly,
    ACTIONS(3722), 1,
      anon_sym_override,
    STATE(1344), 1,
      sym_decorator,
    STATE(2773), 1,
      sym_accessibility_modifier,
    STATE(2800), 1,
      sym_override_modifier,
    STATE(3315), 1,
      sym_formal_parameters,
    STATE(3910), 1,
      sym__call_signature,
    STATE(4481), 1,
      aux_sym_export_statement_repeat1,
    STATE(5233), 1,
      sym_type_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3291), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(3712), 2,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(3718), 2,
      anon_sym_get,
      anon_sym_set,
    ACTIONS(3748), 2,
      anon_sym_RBRACE,
      anon_sym_PIPE_RBRACE,
    ACTIONS(3720), 3,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
    STATE(3111), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    STATE(4265), 6,
      sym_export_statement,
      sym_method_signature,
      sym_call_signature,
      sym_property_signature,
      sym_construct_signature,
      sym_index_signature,
    ACTIONS(3700), 12,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      sym_identifier,
      anon_sym_declare,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [18324] = 30,
    ACTIONS(97), 1,
      anon_sym_AT,
    ACTIONS(1626), 1,
      anon_sym_DQUOTE,
    ACTIONS(1628), 1,
      anon_sym_SQUOTE,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(3281), 1,
      anon_sym_LPAREN,
    ACTIONS(3305), 1,
      anon_sym_abstract,
    ACTIONS(3702), 1,
      anon_sym_export,
    ACTIONS(3704), 1,
      anon_sym_STAR,
    ACTIONS(3706), 1,
      anon_sym_LBRACK,
    ACTIONS(3708), 1,
      anon_sym_async,
    ACTIONS(3710), 1,
      anon_sym_new,
    ACTIONS(3714), 1,
      anon_sym_static,
    ACTIONS(3716), 1,
      anon_sym_readonly,
    ACTIONS(3722), 1,
      anon_sym_override,
    STATE(1344), 1,
      sym_decorator,
    STATE(2773), 1,
      sym_accessibility_modifier,
    STATE(2800), 1,
      sym_override_modifier,
    STATE(3315), 1,
      sym_formal_parameters,
    STATE(3910), 1,
      sym__call_signature,
    STATE(4481), 1,
      aux_sym_export_statement_repeat1,
    STATE(5233), 1,
      sym_type_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3291), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(3712), 2,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(3718), 2,
      anon_sym_get,
      anon_sym_set,
    ACTIONS(3750), 2,
      anon_sym_RBRACE,
      anon_sym_PIPE_RBRACE,
    ACTIONS(3720), 3,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
    STATE(3111), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    STATE(4265), 6,
      sym_export_statement,
      sym_method_signature,
      sym_call_signature,
      sym_property_signature,
      sym_construct_signature,
      sym_index_signature,
    ACTIONS(3700), 12,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      sym_identifier,
      anon_sym_declare,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [18440] = 6,
    ACTIONS(225), 1,
      anon_sym_EQ_GT,
    ACTIONS(1040), 1,
      anon_sym_EQ,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(154), 15,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
    ACTIONS(160), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
    ACTIONS(120), 21,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK_QMARK,
  [18508] = 30,
    ACTIONS(97), 1,
      anon_sym_AT,
    ACTIONS(1626), 1,
      anon_sym_DQUOTE,
    ACTIONS(1628), 1,
      anon_sym_SQUOTE,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(3281), 1,
      anon_sym_LPAREN,
    ACTIONS(3305), 1,
      anon_sym_abstract,
    ACTIONS(3702), 1,
      anon_sym_export,
    ACTIONS(3704), 1,
      anon_sym_STAR,
    ACTIONS(3706), 1,
      anon_sym_LBRACK,
    ACTIONS(3708), 1,
      anon_sym_async,
    ACTIONS(3710), 1,
      anon_sym_new,
    ACTIONS(3714), 1,
      anon_sym_static,
    ACTIONS(3716), 1,
      anon_sym_readonly,
    ACTIONS(3722), 1,
      anon_sym_override,
    STATE(1344), 1,
      sym_decorator,
    STATE(2773), 1,
      sym_accessibility_modifier,
    STATE(2800), 1,
      sym_override_modifier,
    STATE(3315), 1,
      sym_formal_parameters,
    STATE(3910), 1,
      sym__call_signature,
    STATE(4481), 1,
      aux_sym_export_statement_repeat1,
    STATE(5233), 1,
      sym_type_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3291), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(3712), 2,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(3718), 2,
      anon_sym_get,
      anon_sym_set,
    ACTIONS(3752), 2,
      anon_sym_RBRACE,
      anon_sym_PIPE_RBRACE,
    ACTIONS(3720), 3,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
    STATE(3111), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    STATE(4265), 6,
      sym_export_statement,
      sym_method_signature,
      sym_call_signature,
      sym_property_signature,
      sym_construct_signature,
      sym_index_signature,
    ACTIONS(3700), 12,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      sym_identifier,
      anon_sym_declare,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [18624] = 6,
    ACTIONS(225), 1,
      anon_sym_EQ_GT,
    ACTIONS(824), 1,
      anon_sym_EQ,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(154), 15,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
    ACTIONS(160), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
    ACTIONS(120), 21,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK_QMARK,
  [18692] = 6,
    ACTIONS(225), 1,
      anon_sym_EQ_GT,
    ACTIONS(980), 1,
      anon_sym_EQ,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(154), 15,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
    ACTIONS(160), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
    ACTIONS(120), 21,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK_QMARK,
  [18760] = 6,
    ACTIONS(225), 1,
      anon_sym_EQ_GT,
    ACTIONS(1038), 1,
      anon_sym_EQ,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(154), 15,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
    ACTIONS(160), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
    ACTIONS(120), 21,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK_QMARK,
  [18828] = 6,
    ACTIONS(3588), 1,
      anon_sym_EQ_GT,
    ACTIONS(3754), 1,
      anon_sym_EQ,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3496), 15,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
    ACTIONS(3498), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
    ACTIONS(3492), 21,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK_QMARK,
  [18896] = 6,
    ACTIONS(3588), 1,
      anon_sym_EQ_GT,
    ACTIONS(3756), 1,
      anon_sym_EQ,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3496), 15,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
    ACTIONS(3498), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
    ACTIONS(3492), 21,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK_QMARK,
  [18964] = 30,
    ACTIONS(97), 1,
      anon_sym_AT,
    ACTIONS(1626), 1,
      anon_sym_DQUOTE,
    ACTIONS(1628), 1,
      anon_sym_SQUOTE,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(3281), 1,
      anon_sym_LPAREN,
    ACTIONS(3305), 1,
      anon_sym_abstract,
    ACTIONS(3702), 1,
      anon_sym_export,
    ACTIONS(3704), 1,
      anon_sym_STAR,
    ACTIONS(3706), 1,
      anon_sym_LBRACK,
    ACTIONS(3708), 1,
      anon_sym_async,
    ACTIONS(3710), 1,
      anon_sym_new,
    ACTIONS(3714), 1,
      anon_sym_static,
    ACTIONS(3716), 1,
      anon_sym_readonly,
    ACTIONS(3722), 1,
      anon_sym_override,
    STATE(1344), 1,
      sym_decorator,
    STATE(2773), 1,
      sym_accessibility_modifier,
    STATE(2800), 1,
      sym_override_modifier,
    STATE(3315), 1,
      sym_formal_parameters,
    STATE(3910), 1,
      sym__call_signature,
    STATE(4481), 1,
      aux_sym_export_statement_repeat1,
    STATE(5233), 1,
      sym_type_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3291), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(3712), 2,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(3718), 2,
      anon_sym_get,
      anon_sym_set,
    ACTIONS(3758), 2,
      anon_sym_RBRACE,
      anon_sym_PIPE_RBRACE,
    ACTIONS(3720), 3,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
    STATE(3111), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    STATE(4265), 6,
      sym_export_statement,
      sym_method_signature,
      sym_call_signature,
      sym_property_signature,
      sym_construct_signature,
      sym_index_signature,
    ACTIONS(3700), 12,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      sym_identifier,
      anon_sym_declare,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [19080] = 30,
    ACTIONS(97), 1,
      anon_sym_AT,
    ACTIONS(1626), 1,
      anon_sym_DQUOTE,
    ACTIONS(1628), 1,
      anon_sym_SQUOTE,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(3281), 1,
      anon_sym_LPAREN,
    ACTIONS(3305), 1,
      anon_sym_abstract,
    ACTIONS(3702), 1,
      anon_sym_export,
    ACTIONS(3704), 1,
      anon_sym_STAR,
    ACTIONS(3706), 1,
      anon_sym_LBRACK,
    ACTIONS(3708), 1,
      anon_sym_async,
    ACTIONS(3710), 1,
      anon_sym_new,
    ACTIONS(3714), 1,
      anon_sym_static,
    ACTIONS(3716), 1,
      anon_sym_readonly,
    ACTIONS(3722), 1,
      anon_sym_override,
    STATE(1344), 1,
      sym_decorator,
    STATE(2773), 1,
      sym_accessibility_modifier,
    STATE(2800), 1,
      sym_override_modifier,
    STATE(3315), 1,
      sym_formal_parameters,
    STATE(3910), 1,
      sym__call_signature,
    STATE(4481), 1,
      aux_sym_export_statement_repeat1,
    STATE(5233), 1,
      sym_type_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3291), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(3712), 2,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(3718), 2,
      anon_sym_get,
      anon_sym_set,
    ACTIONS(3760), 2,
      anon_sym_RBRACE,
      anon_sym_PIPE_RBRACE,
    ACTIONS(3720), 3,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
    STATE(3111), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    STATE(4265), 6,
      sym_export_statement,
      sym_method_signature,
      sym_call_signature,
      sym_property_signature,
      sym_construct_signature,
      sym_index_signature,
    ACTIONS(3700), 12,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      sym_identifier,
      anon_sym_declare,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [19196] = 6,
    ACTIONS(225), 1,
      anon_sym_EQ_GT,
    ACTIONS(974), 1,
      anon_sym_EQ,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(154), 15,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
    ACTIONS(160), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
    ACTIONS(120), 21,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK_QMARK,
  [19264] = 6,
    ACTIONS(3588), 1,
      anon_sym_EQ_GT,
    ACTIONS(3762), 1,
      anon_sym_EQ,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3496), 15,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
    ACTIONS(3498), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
    ACTIONS(3492), 21,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK_QMARK,
  [19332] = 30,
    ACTIONS(97), 1,
      anon_sym_AT,
    ACTIONS(1626), 1,
      anon_sym_DQUOTE,
    ACTIONS(1628), 1,
      anon_sym_SQUOTE,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(3281), 1,
      anon_sym_LPAREN,
    ACTIONS(3305), 1,
      anon_sym_abstract,
    ACTIONS(3702), 1,
      anon_sym_export,
    ACTIONS(3704), 1,
      anon_sym_STAR,
    ACTIONS(3706), 1,
      anon_sym_LBRACK,
    ACTIONS(3708), 1,
      anon_sym_async,
    ACTIONS(3710), 1,
      anon_sym_new,
    ACTIONS(3714), 1,
      anon_sym_static,
    ACTIONS(3716), 1,
      anon_sym_readonly,
    ACTIONS(3722), 1,
      anon_sym_override,
    STATE(1344), 1,
      sym_decorator,
    STATE(2773), 1,
      sym_accessibility_modifier,
    STATE(2800), 1,
      sym_override_modifier,
    STATE(3315), 1,
      sym_formal_parameters,
    STATE(3910), 1,
      sym__call_signature,
    STATE(4481), 1,
      aux_sym_export_statement_repeat1,
    STATE(5233), 1,
      sym_type_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3291), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(3712), 2,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(3718), 2,
      anon_sym_get,
      anon_sym_set,
    ACTIONS(3764), 2,
      anon_sym_RBRACE,
      anon_sym_PIPE_RBRACE,
    ACTIONS(3720), 3,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
    STATE(3111), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    STATE(4265), 6,
      sym_export_statement,
      sym_method_signature,
      sym_call_signature,
      sym_property_signature,
      sym_construct_signature,
      sym_index_signature,
    ACTIONS(3700), 12,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      sym_identifier,
      anon_sym_declare,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [19448] = 30,
    ACTIONS(97), 1,
      anon_sym_AT,
    ACTIONS(1626), 1,
      anon_sym_DQUOTE,
    ACTIONS(1628), 1,
      anon_sym_SQUOTE,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(3281), 1,
      anon_sym_LPAREN,
    ACTIONS(3305), 1,
      anon_sym_abstract,
    ACTIONS(3702), 1,
      anon_sym_export,
    ACTIONS(3704), 1,
      anon_sym_STAR,
    ACTIONS(3706), 1,
      anon_sym_LBRACK,
    ACTIONS(3708), 1,
      anon_sym_async,
    ACTIONS(3710), 1,
      anon_sym_new,
    ACTIONS(3714), 1,
      anon_sym_static,
    ACTIONS(3716), 1,
      anon_sym_readonly,
    ACTIONS(3722), 1,
      anon_sym_override,
    STATE(1344), 1,
      sym_decorator,
    STATE(2773), 1,
      sym_accessibility_modifier,
    STATE(2800), 1,
      sym_override_modifier,
    STATE(3315), 1,
      sym_formal_parameters,
    STATE(3910), 1,
      sym__call_signature,
    STATE(4481), 1,
      aux_sym_export_statement_repeat1,
    STATE(5233), 1,
      sym_type_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3291), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(3712), 2,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(3718), 2,
      anon_sym_get,
      anon_sym_set,
    ACTIONS(3766), 2,
      anon_sym_RBRACE,
      anon_sym_PIPE_RBRACE,
    ACTIONS(3720), 3,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
    STATE(3111), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    STATE(4265), 6,
      sym_export_statement,
      sym_method_signature,
      sym_call_signature,
      sym_property_signature,
      sym_construct_signature,
      sym_index_signature,
    ACTIONS(3700), 12,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      sym_identifier,
      anon_sym_declare,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [19564] = 6,
    ACTIONS(225), 1,
      anon_sym_EQ_GT,
    ACTIONS(978), 1,
      anon_sym_EQ,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(154), 15,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
    ACTIONS(160), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
    ACTIONS(120), 21,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK_QMARK,
  [19632] = 30,
    ACTIONS(97), 1,
      anon_sym_AT,
    ACTIONS(1626), 1,
      anon_sym_DQUOTE,
    ACTIONS(1628), 1,
      anon_sym_SQUOTE,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(3281), 1,
      anon_sym_LPAREN,
    ACTIONS(3305), 1,
      anon_sym_abstract,
    ACTIONS(3702), 1,
      anon_sym_export,
    ACTIONS(3704), 1,
      anon_sym_STAR,
    ACTIONS(3706), 1,
      anon_sym_LBRACK,
    ACTIONS(3708), 1,
      anon_sym_async,
    ACTIONS(3710), 1,
      anon_sym_new,
    ACTIONS(3714), 1,
      anon_sym_static,
    ACTIONS(3716), 1,
      anon_sym_readonly,
    ACTIONS(3722), 1,
      anon_sym_override,
    STATE(1344), 1,
      sym_decorator,
    STATE(2773), 1,
      sym_accessibility_modifier,
    STATE(2800), 1,
      sym_override_modifier,
    STATE(3315), 1,
      sym_formal_parameters,
    STATE(3910), 1,
      sym__call_signature,
    STATE(4481), 1,
      aux_sym_export_statement_repeat1,
    STATE(5233), 1,
      sym_type_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3291), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(3712), 2,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(3718), 2,
      anon_sym_get,
      anon_sym_set,
    ACTIONS(3768), 2,
      anon_sym_RBRACE,
      anon_sym_PIPE_RBRACE,
    ACTIONS(3720), 3,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
    STATE(3111), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    STATE(4265), 6,
      sym_export_statement,
      sym_method_signature,
      sym_call_signature,
      sym_property_signature,
      sym_construct_signature,
      sym_index_signature,
    ACTIONS(3700), 12,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      sym_identifier,
      anon_sym_declare,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [19748] = 6,
    ACTIONS(3588), 1,
      anon_sym_EQ_GT,
    ACTIONS(3770), 1,
      anon_sym_EQ,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3496), 15,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
    ACTIONS(3498), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
    ACTIONS(3492), 21,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK_QMARK,
  [19816] = 30,
    ACTIONS(97), 1,
      anon_sym_AT,
    ACTIONS(1626), 1,
      anon_sym_DQUOTE,
    ACTIONS(1628), 1,
      anon_sym_SQUOTE,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(3281), 1,
      anon_sym_LPAREN,
    ACTIONS(3305), 1,
      anon_sym_abstract,
    ACTIONS(3702), 1,
      anon_sym_export,
    ACTIONS(3704), 1,
      anon_sym_STAR,
    ACTIONS(3706), 1,
      anon_sym_LBRACK,
    ACTIONS(3708), 1,
      anon_sym_async,
    ACTIONS(3710), 1,
      anon_sym_new,
    ACTIONS(3714), 1,
      anon_sym_static,
    ACTIONS(3716), 1,
      anon_sym_readonly,
    ACTIONS(3722), 1,
      anon_sym_override,
    STATE(1344), 1,
      sym_decorator,
    STATE(2773), 1,
      sym_accessibility_modifier,
    STATE(2800), 1,
      sym_override_modifier,
    STATE(3315), 1,
      sym_formal_parameters,
    STATE(3910), 1,
      sym__call_signature,
    STATE(4481), 1,
      aux_sym_export_statement_repeat1,
    STATE(5233), 1,
      sym_type_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3291), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(3712), 2,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(3718), 2,
      anon_sym_get,
      anon_sym_set,
    ACTIONS(3772), 2,
      anon_sym_RBRACE,
      anon_sym_PIPE_RBRACE,
    ACTIONS(3720), 3,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
    STATE(3111), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    STATE(4265), 6,
      sym_export_statement,
      sym_method_signature,
      sym_call_signature,
      sym_property_signature,
      sym_construct_signature,
      sym_index_signature,
    ACTIONS(3700), 12,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      sym_identifier,
      anon_sym_declare,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [19932] = 30,
    ACTIONS(97), 1,
      anon_sym_AT,
    ACTIONS(1626), 1,
      anon_sym_DQUOTE,
    ACTIONS(1628), 1,
      anon_sym_SQUOTE,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(3281), 1,
      anon_sym_LPAREN,
    ACTIONS(3305), 1,
      anon_sym_abstract,
    ACTIONS(3702), 1,
      anon_sym_export,
    ACTIONS(3704), 1,
      anon_sym_STAR,
    ACTIONS(3706), 1,
      anon_sym_LBRACK,
    ACTIONS(3708), 1,
      anon_sym_async,
    ACTIONS(3710), 1,
      anon_sym_new,
    ACTIONS(3714), 1,
      anon_sym_static,
    ACTIONS(3716), 1,
      anon_sym_readonly,
    ACTIONS(3722), 1,
      anon_sym_override,
    STATE(1344), 1,
      sym_decorator,
    STATE(2773), 1,
      sym_accessibility_modifier,
    STATE(2800), 1,
      sym_override_modifier,
    STATE(3315), 1,
      sym_formal_parameters,
    STATE(3910), 1,
      sym__call_signature,
    STATE(4481), 1,
      aux_sym_export_statement_repeat1,
    STATE(5233), 1,
      sym_type_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3291), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(3712), 2,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(3718), 2,
      anon_sym_get,
      anon_sym_set,
    ACTIONS(3774), 2,
      anon_sym_RBRACE,
      anon_sym_PIPE_RBRACE,
    ACTIONS(3720), 3,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
    STATE(3111), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    STATE(4265), 6,
      sym_export_statement,
      sym_method_signature,
      sym_call_signature,
      sym_property_signature,
      sym_construct_signature,
      sym_index_signature,
    ACTIONS(3700), 12,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      sym_identifier,
      anon_sym_declare,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [20048] = 30,
    ACTIONS(97), 1,
      anon_sym_AT,
    ACTIONS(1626), 1,
      anon_sym_DQUOTE,
    ACTIONS(1628), 1,
      anon_sym_SQUOTE,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(3281), 1,
      anon_sym_LPAREN,
    ACTIONS(3305), 1,
      anon_sym_abstract,
    ACTIONS(3702), 1,
      anon_sym_export,
    ACTIONS(3704), 1,
      anon_sym_STAR,
    ACTIONS(3706), 1,
      anon_sym_LBRACK,
    ACTIONS(3708), 1,
      anon_sym_async,
    ACTIONS(3710), 1,
      anon_sym_new,
    ACTIONS(3714), 1,
      anon_sym_static,
    ACTIONS(3716), 1,
      anon_sym_readonly,
    ACTIONS(3722), 1,
      anon_sym_override,
    STATE(1344), 1,
      sym_decorator,
    STATE(2773), 1,
      sym_accessibility_modifier,
    STATE(2800), 1,
      sym_override_modifier,
    STATE(3315), 1,
      sym_formal_parameters,
    STATE(3910), 1,
      sym__call_signature,
    STATE(4481), 1,
      aux_sym_export_statement_repeat1,
    STATE(5233), 1,
      sym_type_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3291), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(3712), 2,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(3718), 2,
      anon_sym_get,
      anon_sym_set,
    ACTIONS(3776), 2,
      anon_sym_RBRACE,
      anon_sym_PIPE_RBRACE,
    ACTIONS(3720), 3,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
    STATE(3111), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    STATE(4265), 6,
      sym_export_statement,
      sym_method_signature,
      sym_call_signature,
      sym_property_signature,
      sym_construct_signature,
      sym_index_signature,
    ACTIONS(3700), 12,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      sym_identifier,
      anon_sym_declare,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [20164] = 6,
    ACTIONS(225), 1,
      anon_sym_EQ_GT,
    ACTIONS(1044), 1,
      anon_sym_EQ,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(154), 15,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
    ACTIONS(160), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
    ACTIONS(120), 21,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK_QMARK,
  [20232] = 6,
    ACTIONS(3588), 1,
      anon_sym_EQ_GT,
    ACTIONS(3778), 1,
      anon_sym_EQ,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3496), 15,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
    ACTIONS(3498), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
    ACTIONS(3492), 21,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK_QMARK,
  [20300] = 6,
    ACTIONS(3494), 1,
      anon_sym_EQ,
    ACTIONS(3586), 1,
      anon_sym_COLON,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3496), 15,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
    ACTIONS(3498), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
    ACTIONS(3492), 21,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK_QMARK,
  [20368] = 7,
    ACTIONS(3494), 1,
      anon_sym_EQ,
    ACTIONS(3681), 1,
      anon_sym_in,
    ACTIONS(3684), 1,
      anon_sym_of,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3496), 15,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
    ACTIONS(3498), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
    ACTIONS(3492), 20,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK_QMARK,
  [20438] = 6,
    ACTIONS(225), 1,
      anon_sym_EQ_GT,
    ACTIONS(1042), 1,
      anon_sym_EQ,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(154), 15,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
    ACTIONS(160), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
    ACTIONS(120), 21,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK_QMARK,
  [20506] = 6,
    ACTIONS(225), 1,
      anon_sym_EQ_GT,
    ACTIONS(982), 1,
      anon_sym_EQ,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(154), 15,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
    ACTIONS(160), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
    ACTIONS(120), 21,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK_QMARK,
  [20574] = 30,
    ACTIONS(97), 1,
      anon_sym_AT,
    ACTIONS(1626), 1,
      anon_sym_DQUOTE,
    ACTIONS(1628), 1,
      anon_sym_SQUOTE,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(3281), 1,
      anon_sym_LPAREN,
    ACTIONS(3305), 1,
      anon_sym_abstract,
    ACTIONS(3702), 1,
      anon_sym_export,
    ACTIONS(3704), 1,
      anon_sym_STAR,
    ACTIONS(3706), 1,
      anon_sym_LBRACK,
    ACTIONS(3708), 1,
      anon_sym_async,
    ACTIONS(3710), 1,
      anon_sym_new,
    ACTIONS(3714), 1,
      anon_sym_static,
    ACTIONS(3716), 1,
      anon_sym_readonly,
    ACTIONS(3722), 1,
      anon_sym_override,
    STATE(1344), 1,
      sym_decorator,
    STATE(2773), 1,
      sym_accessibility_modifier,
    STATE(2800), 1,
      sym_override_modifier,
    STATE(3315), 1,
      sym_formal_parameters,
    STATE(3910), 1,
      sym__call_signature,
    STATE(4481), 1,
      aux_sym_export_statement_repeat1,
    STATE(5233), 1,
      sym_type_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3291), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(3712), 2,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(3718), 2,
      anon_sym_get,
      anon_sym_set,
    ACTIONS(3780), 2,
      anon_sym_RBRACE,
      anon_sym_PIPE_RBRACE,
    ACTIONS(3720), 3,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
    STATE(3111), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    STATE(4265), 6,
      sym_export_statement,
      sym_method_signature,
      sym_call_signature,
      sym_property_signature,
      sym_construct_signature,
      sym_index_signature,
    ACTIONS(3700), 12,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      sym_identifier,
      anon_sym_declare,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [20690] = 6,
    ACTIONS(3588), 1,
      anon_sym_EQ_GT,
    ACTIONS(3782), 1,
      anon_sym_EQ,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3496), 15,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
    ACTIONS(3498), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
    ACTIONS(3492), 21,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK_QMARK,
  [20758] = 6,
    ACTIONS(225), 1,
      anon_sym_EQ_GT,
    ACTIONS(976), 1,
      anon_sym_EQ,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(154), 15,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
    ACTIONS(160), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
    ACTIONS(120), 21,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK_QMARK,
  [20826] = 6,
    ACTIONS(3588), 1,
      anon_sym_EQ_GT,
    ACTIONS(3784), 1,
      anon_sym_EQ,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3496), 15,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
    ACTIONS(3498), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
    ACTIONS(3492), 21,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK_QMARK,
  [20894] = 30,
    ACTIONS(97), 1,
      anon_sym_AT,
    ACTIONS(1626), 1,
      anon_sym_DQUOTE,
    ACTIONS(1628), 1,
      anon_sym_SQUOTE,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(3281), 1,
      anon_sym_LPAREN,
    ACTIONS(3305), 1,
      anon_sym_abstract,
    ACTIONS(3702), 1,
      anon_sym_export,
    ACTIONS(3704), 1,
      anon_sym_STAR,
    ACTIONS(3706), 1,
      anon_sym_LBRACK,
    ACTIONS(3708), 1,
      anon_sym_async,
    ACTIONS(3710), 1,
      anon_sym_new,
    ACTIONS(3714), 1,
      anon_sym_static,
    ACTIONS(3716), 1,
      anon_sym_readonly,
    ACTIONS(3722), 1,
      anon_sym_override,
    STATE(1344), 1,
      sym_decorator,
    STATE(2773), 1,
      sym_accessibility_modifier,
    STATE(2800), 1,
      sym_override_modifier,
    STATE(3315), 1,
      sym_formal_parameters,
    STATE(3910), 1,
      sym__call_signature,
    STATE(4481), 1,
      aux_sym_export_statement_repeat1,
    STATE(5233), 1,
      sym_type_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3291), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(3712), 2,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(3718), 2,
      anon_sym_get,
      anon_sym_set,
    ACTIONS(3786), 2,
      anon_sym_RBRACE,
      anon_sym_PIPE_RBRACE,
    ACTIONS(3720), 3,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
    STATE(3111), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    STATE(4265), 6,
      sym_export_statement,
      sym_method_signature,
      sym_call_signature,
      sym_property_signature,
      sym_construct_signature,
      sym_index_signature,
    ACTIONS(3700), 12,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      sym_identifier,
      anon_sym_declare,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [21010] = 30,
    ACTIONS(97), 1,
      anon_sym_AT,
    ACTIONS(1626), 1,
      anon_sym_DQUOTE,
    ACTIONS(1628), 1,
      anon_sym_SQUOTE,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(3281), 1,
      anon_sym_LPAREN,
    ACTIONS(3305), 1,
      anon_sym_abstract,
    ACTIONS(3702), 1,
      anon_sym_export,
    ACTIONS(3704), 1,
      anon_sym_STAR,
    ACTIONS(3706), 1,
      anon_sym_LBRACK,
    ACTIONS(3708), 1,
      anon_sym_async,
    ACTIONS(3710), 1,
      anon_sym_new,
    ACTIONS(3714), 1,
      anon_sym_static,
    ACTIONS(3716), 1,
      anon_sym_readonly,
    ACTIONS(3722), 1,
      anon_sym_override,
    STATE(1344), 1,
      sym_decorator,
    STATE(2773), 1,
      sym_accessibility_modifier,
    STATE(2800), 1,
      sym_override_modifier,
    STATE(3315), 1,
      sym_formal_parameters,
    STATE(3910), 1,
      sym__call_signature,
    STATE(4481), 1,
      aux_sym_export_statement_repeat1,
    STATE(5233), 1,
      sym_type_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3291), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(3712), 2,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(3718), 2,
      anon_sym_get,
      anon_sym_set,
    ACTIONS(3788), 2,
      anon_sym_RBRACE,
      anon_sym_PIPE_RBRACE,
    ACTIONS(3720), 3,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
    STATE(3111), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    STATE(4265), 6,
      sym_export_statement,
      sym_method_signature,
      sym_call_signature,
      sym_property_signature,
      sym_construct_signature,
      sym_index_signature,
    ACTIONS(3700), 12,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      sym_identifier,
      anon_sym_declare,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [21126] = 5,
    ACTIONS(3642), 1,
      anon_sym_EQ,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3498), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
    ACTIONS(3496), 16,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
    ACTIONS(3492), 21,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK_QMARK,
  [21192] = 5,
    ACTIONS(3658), 1,
      anon_sym_EQ,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3498), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
    ACTIONS(3496), 16,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
    ACTIONS(3492), 21,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK_QMARK,
  [21258] = 6,
    ACTIONS(3494), 1,
      anon_sym_EQ,
    ACTIONS(3588), 1,
      anon_sym_EQ_GT,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3496), 15,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
    ACTIONS(3498), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
    ACTIONS(3492), 21,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK_QMARK,
  [21326] = 5,
    ACTIONS(3646), 1,
      anon_sym_EQ,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3498), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
    ACTIONS(3496), 16,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_of,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
    ACTIONS(3492), 21,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK_QMARK,
  [21392] = 30,
    ACTIONS(97), 1,
      anon_sym_AT,
    ACTIONS(1626), 1,
      anon_sym_DQUOTE,
    ACTIONS(1628), 1,
      anon_sym_SQUOTE,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(3281), 1,
      anon_sym_LPAREN,
    ACTIONS(3305), 1,
      anon_sym_abstract,
    ACTIONS(3702), 1,
      anon_sym_export,
    ACTIONS(3704), 1,
      anon_sym_STAR,
    ACTIONS(3706), 1,
      anon_sym_LBRACK,
    ACTIONS(3708), 1,
      anon_sym_async,
    ACTIONS(3710), 1,
      anon_sym_new,
    ACTIONS(3714), 1,
      anon_sym_static,
    ACTIONS(3716), 1,
      anon_sym_readonly,
    ACTIONS(3722), 1,
      anon_sym_override,
    STATE(1344), 1,
      sym_decorator,
    STATE(2773), 1,
      sym_accessibility_modifier,
    STATE(2800), 1,
      sym_override_modifier,
    STATE(3315), 1,
      sym_formal_parameters,
    STATE(3910), 1,
      sym__call_signature,
    STATE(4481), 1,
      aux_sym_export_statement_repeat1,
    STATE(5233), 1,
      sym_type_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3291), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(3712), 2,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(3718), 2,
      anon_sym_get,
      anon_sym_set,
    ACTIONS(3790), 2,
      anon_sym_RBRACE,
      anon_sym_PIPE_RBRACE,
    ACTIONS(3720), 3,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
    STATE(3111), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    STATE(4265), 6,
      sym_export_statement,
      sym_method_signature,
      sym_call_signature,
      sym_property_signature,
      sym_construct_signature,
      sym_index_signature,
    ACTIONS(3700), 12,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      sym_identifier,
      anon_sym_declare,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [21508] = 6,
    ACTIONS(3588), 1,
      anon_sym_EQ_GT,
    ACTIONS(3792), 1,
      anon_sym_EQ,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3496), 15,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
    ACTIONS(3498), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
    ACTIONS(3492), 21,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK_QMARK,
  [21576] = 30,
    ACTIONS(97), 1,
      anon_sym_AT,
    ACTIONS(1626), 1,
      anon_sym_DQUOTE,
    ACTIONS(1628), 1,
      anon_sym_SQUOTE,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(3281), 1,
      anon_sym_LPAREN,
    ACTIONS(3305), 1,
      anon_sym_abstract,
    ACTIONS(3702), 1,
      anon_sym_export,
    ACTIONS(3704), 1,
      anon_sym_STAR,
    ACTIONS(3706), 1,
      anon_sym_LBRACK,
    ACTIONS(3708), 1,
      anon_sym_async,
    ACTIONS(3710), 1,
      anon_sym_new,
    ACTIONS(3714), 1,
      anon_sym_static,
    ACTIONS(3716), 1,
      anon_sym_readonly,
    ACTIONS(3722), 1,
      anon_sym_override,
    STATE(1344), 1,
      sym_decorator,
    STATE(2773), 1,
      sym_accessibility_modifier,
    STATE(2800), 1,
      sym_override_modifier,
    STATE(3315), 1,
      sym_formal_parameters,
    STATE(3910), 1,
      sym__call_signature,
    STATE(4481), 1,
      aux_sym_export_statement_repeat1,
    STATE(5233), 1,
      sym_type_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3291), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(3712), 2,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(3718), 2,
      anon_sym_get,
      anon_sym_set,
    ACTIONS(3794), 2,
      anon_sym_RBRACE,
      anon_sym_PIPE_RBRACE,
    ACTIONS(3720), 3,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
    STATE(3111), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    STATE(4265), 6,
      sym_export_statement,
      sym_method_signature,
      sym_call_signature,
      sym_property_signature,
      sym_construct_signature,
      sym_index_signature,
    ACTIONS(3700), 12,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      sym_identifier,
      anon_sym_declare,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [21692] = 30,
    ACTIONS(97), 1,
      anon_sym_AT,
    ACTIONS(1626), 1,
      anon_sym_DQUOTE,
    ACTIONS(1628), 1,
      anon_sym_SQUOTE,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(3281), 1,
      anon_sym_LPAREN,
    ACTIONS(3305), 1,
      anon_sym_abstract,
    ACTIONS(3702), 1,
      anon_sym_export,
    ACTIONS(3704), 1,
      anon_sym_STAR,
    ACTIONS(3706), 1,
      anon_sym_LBRACK,
    ACTIONS(3708), 1,
      anon_sym_async,
    ACTIONS(3710), 1,
      anon_sym_new,
    ACTIONS(3714), 1,
      anon_sym_static,
    ACTIONS(3716), 1,
      anon_sym_readonly,
    ACTIONS(3722), 1,
      anon_sym_override,
    STATE(1344), 1,
      sym_decorator,
    STATE(2773), 1,
      sym_accessibility_modifier,
    STATE(2800), 1,
      sym_override_modifier,
    STATE(3315), 1,
      sym_formal_parameters,
    STATE(3910), 1,
      sym__call_signature,
    STATE(4481), 1,
      aux_sym_export_statement_repeat1,
    STATE(5233), 1,
      sym_type_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3291), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(3712), 2,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(3718), 2,
      anon_sym_get,
      anon_sym_set,
    ACTIONS(3796), 2,
      anon_sym_RBRACE,
      anon_sym_PIPE_RBRACE,
    ACTIONS(3720), 3,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
    STATE(3111), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    STATE(4265), 6,
      sym_export_statement,
      sym_method_signature,
      sym_call_signature,
      sym_property_signature,
      sym_construct_signature,
      sym_index_signature,
    ACTIONS(3700), 12,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      sym_identifier,
      anon_sym_declare,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [21808] = 5,
    ACTIONS(3782), 1,
      anon_sym_EQ,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3496), 15,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
    ACTIONS(3498), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
    ACTIONS(3492), 21,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK_QMARK,
  [21873] = 5,
    ACTIONS(3770), 1,
      anon_sym_EQ,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3496), 15,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
    ACTIONS(3498), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
    ACTIONS(3492), 21,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK_QMARK,
  [21938] = 5,
    ACTIONS(3744), 1,
      anon_sym_EQ,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3496), 15,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
    ACTIONS(3498), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
    ACTIONS(3492), 21,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK_QMARK,
  [22003] = 5,
    ACTIONS(3778), 1,
      anon_sym_EQ,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3496), 15,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
    ACTIONS(3498), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
    ACTIONS(3492), 21,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK_QMARK,
  [22068] = 5,
    ACTIONS(3792), 1,
      anon_sym_EQ,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3496), 15,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
    ACTIONS(3498), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
    ACTIONS(3492), 21,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK_QMARK,
  [22133] = 5,
    ACTIONS(3746), 1,
      anon_sym_EQ,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3496), 15,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
    ACTIONS(3498), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
    ACTIONS(3492), 21,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK_QMARK,
  [22198] = 5,
    ACTIONS(3756), 1,
      anon_sym_EQ,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3496), 15,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
    ACTIONS(3498), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
    ACTIONS(3492), 21,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK_QMARK,
  [22263] = 5,
    ACTIONS(3754), 1,
      anon_sym_EQ,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3496), 15,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
    ACTIONS(3498), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
    ACTIONS(3492), 21,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK_QMARK,
  [22328] = 5,
    ACTIONS(3784), 1,
      anon_sym_EQ,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3496), 15,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
    ACTIONS(3498), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
    ACTIONS(3492), 21,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK_QMARK,
  [22393] = 5,
    ACTIONS(3762), 1,
      anon_sym_EQ,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3496), 15,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
    ACTIONS(3498), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
    ACTIONS(3492), 21,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK_QMARK,
  [22458] = 29,
    ACTIONS(97), 1,
      anon_sym_AT,
    ACTIONS(1626), 1,
      anon_sym_DQUOTE,
    ACTIONS(1628), 1,
      anon_sym_SQUOTE,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(3281), 1,
      anon_sym_LPAREN,
    ACTIONS(3305), 1,
      anon_sym_abstract,
    ACTIONS(3702), 1,
      anon_sym_export,
    ACTIONS(3704), 1,
      anon_sym_STAR,
    ACTIONS(3706), 1,
      anon_sym_LBRACK,
    ACTIONS(3708), 1,
      anon_sym_async,
    ACTIONS(3710), 1,
      anon_sym_new,
    ACTIONS(3714), 1,
      anon_sym_static,
    ACTIONS(3716), 1,
      anon_sym_readonly,
    ACTIONS(3722), 1,
      anon_sym_override,
    STATE(1344), 1,
      sym_decorator,
    STATE(2773), 1,
      sym_accessibility_modifier,
    STATE(2800), 1,
      sym_override_modifier,
    STATE(3315), 1,
      sym_formal_parameters,
    STATE(3910), 1,
      sym__call_signature,
    STATE(4481), 1,
      aux_sym_export_statement_repeat1,
    STATE(5233), 1,
      sym_type_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3291), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(3712), 2,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(3718), 2,
      anon_sym_get,
      anon_sym_set,
    ACTIONS(3720), 3,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
    STATE(3111), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    STATE(3790), 6,
      sym_export_statement,
      sym_method_signature,
      sym_call_signature,
      sym_property_signature,
      sym_construct_signature,
      sym_index_signature,
    ACTIONS(3700), 12,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      sym_identifier,
      anon_sym_declare,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [22570] = 29,
    ACTIONS(97), 1,
      anon_sym_AT,
    ACTIONS(1626), 1,
      anon_sym_DQUOTE,
    ACTIONS(1628), 1,
      anon_sym_SQUOTE,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(3281), 1,
      anon_sym_LPAREN,
    ACTIONS(3305), 1,
      anon_sym_abstract,
    ACTIONS(3702), 1,
      anon_sym_export,
    ACTIONS(3704), 1,
      anon_sym_STAR,
    ACTIONS(3706), 1,
      anon_sym_LBRACK,
    ACTIONS(3708), 1,
      anon_sym_async,
    ACTIONS(3710), 1,
      anon_sym_new,
    ACTIONS(3714), 1,
      anon_sym_static,
    ACTIONS(3716), 1,
      anon_sym_readonly,
    ACTIONS(3722), 1,
      anon_sym_override,
    STATE(1344), 1,
      sym_decorator,
    STATE(2773), 1,
      sym_accessibility_modifier,
    STATE(2800), 1,
      sym_override_modifier,
    STATE(3315), 1,
      sym_formal_parameters,
    STATE(3910), 1,
      sym__call_signature,
    STATE(4481), 1,
      aux_sym_export_statement_repeat1,
    STATE(5233), 1,
      sym_type_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3291), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(3712), 2,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(3718), 2,
      anon_sym_get,
      anon_sym_set,
    ACTIONS(3720), 3,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
    STATE(3111), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    STATE(3786), 6,
      sym_export_statement,
      sym_method_signature,
      sym_call_signature,
      sym_property_signature,
      sym_construct_signature,
      sym_index_signature,
    ACTIONS(3700), 12,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      sym_identifier,
      anon_sym_declare,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [22682] = 29,
    ACTIONS(97), 1,
      anon_sym_AT,
    ACTIONS(1626), 1,
      anon_sym_DQUOTE,
    ACTIONS(1628), 1,
      anon_sym_SQUOTE,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(3281), 1,
      anon_sym_LPAREN,
    ACTIONS(3305), 1,
      anon_sym_abstract,
    ACTIONS(3702), 1,
      anon_sym_export,
    ACTIONS(3704), 1,
      anon_sym_STAR,
    ACTIONS(3706), 1,
      anon_sym_LBRACK,
    ACTIONS(3708), 1,
      anon_sym_async,
    ACTIONS(3710), 1,
      anon_sym_new,
    ACTIONS(3714), 1,
      anon_sym_static,
    ACTIONS(3716), 1,
      anon_sym_readonly,
    ACTIONS(3722), 1,
      anon_sym_override,
    STATE(1344), 1,
      sym_decorator,
    STATE(2773), 1,
      sym_accessibility_modifier,
    STATE(2800), 1,
      sym_override_modifier,
    STATE(3315), 1,
      sym_formal_parameters,
    STATE(3910), 1,
      sym__call_signature,
    STATE(4481), 1,
      aux_sym_export_statement_repeat1,
    STATE(5233), 1,
      sym_type_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3291), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(3712), 2,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(3718), 2,
      anon_sym_get,
      anon_sym_set,
    ACTIONS(3720), 3,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
    STATE(3111), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    STATE(3875), 6,
      sym_export_statement,
      sym_method_signature,
      sym_call_signature,
      sym_property_signature,
      sym_construct_signature,
      sym_index_signature,
    ACTIONS(3700), 12,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      sym_identifier,
      anon_sym_declare,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [22794] = 29,
    ACTIONS(97), 1,
      anon_sym_AT,
    ACTIONS(1626), 1,
      anon_sym_DQUOTE,
    ACTIONS(1628), 1,
      anon_sym_SQUOTE,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(3281), 1,
      anon_sym_LPAREN,
    ACTIONS(3305), 1,
      anon_sym_abstract,
    ACTIONS(3702), 1,
      anon_sym_export,
    ACTIONS(3704), 1,
      anon_sym_STAR,
    ACTIONS(3706), 1,
      anon_sym_LBRACK,
    ACTIONS(3708), 1,
      anon_sym_async,
    ACTIONS(3710), 1,
      anon_sym_new,
    ACTIONS(3714), 1,
      anon_sym_static,
    ACTIONS(3716), 1,
      anon_sym_readonly,
    ACTIONS(3722), 1,
      anon_sym_override,
    STATE(1344), 1,
      sym_decorator,
    STATE(2773), 1,
      sym_accessibility_modifier,
    STATE(2800), 1,
      sym_override_modifier,
    STATE(3315), 1,
      sym_formal_parameters,
    STATE(3910), 1,
      sym__call_signature,
    STATE(4481), 1,
      aux_sym_export_statement_repeat1,
    STATE(5233), 1,
      sym_type_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3291), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(3712), 2,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(3718), 2,
      anon_sym_get,
      anon_sym_set,
    ACTIONS(3720), 3,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
    STATE(3111), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    STATE(4265), 6,
      sym_export_statement,
      sym_method_signature,
      sym_call_signature,
      sym_property_signature,
      sym_construct_signature,
      sym_index_signature,
    ACTIONS(3700), 12,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      sym_identifier,
      anon_sym_declare,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [22906] = 29,
    ACTIONS(97), 1,
      anon_sym_AT,
    ACTIONS(1626), 1,
      anon_sym_DQUOTE,
    ACTIONS(1628), 1,
      anon_sym_SQUOTE,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(3281), 1,
      anon_sym_LPAREN,
    ACTIONS(3305), 1,
      anon_sym_abstract,
    ACTIONS(3702), 1,
      anon_sym_export,
    ACTIONS(3704), 1,
      anon_sym_STAR,
    ACTIONS(3706), 1,
      anon_sym_LBRACK,
    ACTIONS(3708), 1,
      anon_sym_async,
    ACTIONS(3710), 1,
      anon_sym_new,
    ACTIONS(3714), 1,
      anon_sym_static,
    ACTIONS(3716), 1,
      anon_sym_readonly,
    ACTIONS(3722), 1,
      anon_sym_override,
    STATE(1344), 1,
      sym_decorator,
    STATE(2773), 1,
      sym_accessibility_modifier,
    STATE(2800), 1,
      sym_override_modifier,
    STATE(3315), 1,
      sym_formal_parameters,
    STATE(3910), 1,
      sym__call_signature,
    STATE(4481), 1,
      aux_sym_export_statement_repeat1,
    STATE(5233), 1,
      sym_type_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3291), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(3712), 2,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(3718), 2,
      anon_sym_get,
      anon_sym_set,
    ACTIONS(3720), 3,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
    STATE(3111), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    STATE(3793), 6,
      sym_export_statement,
      sym_method_signature,
      sym_call_signature,
      sym_property_signature,
      sym_construct_signature,
      sym_index_signature,
    ACTIONS(3700), 12,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      sym_identifier,
      anon_sym_declare,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [23018] = 29,
    ACTIONS(97), 1,
      anon_sym_AT,
    ACTIONS(1626), 1,
      anon_sym_DQUOTE,
    ACTIONS(1628), 1,
      anon_sym_SQUOTE,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(3281), 1,
      anon_sym_LPAREN,
    ACTIONS(3305), 1,
      anon_sym_abstract,
    ACTIONS(3702), 1,
      anon_sym_export,
    ACTIONS(3704), 1,
      anon_sym_STAR,
    ACTIONS(3706), 1,
      anon_sym_LBRACK,
    ACTIONS(3708), 1,
      anon_sym_async,
    ACTIONS(3710), 1,
      anon_sym_new,
    ACTIONS(3714), 1,
      anon_sym_static,
    ACTIONS(3716), 1,
      anon_sym_readonly,
    ACTIONS(3722), 1,
      anon_sym_override,
    STATE(1344), 1,
      sym_decorator,
    STATE(2773), 1,
      sym_accessibility_modifier,
    STATE(2800), 1,
      sym_override_modifier,
    STATE(3315), 1,
      sym_formal_parameters,
    STATE(3910), 1,
      sym__call_signature,
    STATE(4481), 1,
      aux_sym_export_statement_repeat1,
    STATE(5233), 1,
      sym_type_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3291), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(3712), 2,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(3718), 2,
      anon_sym_get,
      anon_sym_set,
    ACTIONS(3720), 3,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
    STATE(3111), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    STATE(3814), 6,
      sym_export_statement,
      sym_method_signature,
      sym_call_signature,
      sym_property_signature,
      sym_construct_signature,
      sym_index_signature,
    ACTIONS(3700), 12,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      sym_identifier,
      anon_sym_declare,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [23130] = 29,
    ACTIONS(97), 1,
      anon_sym_AT,
    ACTIONS(1626), 1,
      anon_sym_DQUOTE,
    ACTIONS(1628), 1,
      anon_sym_SQUOTE,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(3281), 1,
      anon_sym_LPAREN,
    ACTIONS(3305), 1,
      anon_sym_abstract,
    ACTIONS(3702), 1,
      anon_sym_export,
    ACTIONS(3704), 1,
      anon_sym_STAR,
    ACTIONS(3706), 1,
      anon_sym_LBRACK,
    ACTIONS(3708), 1,
      anon_sym_async,
    ACTIONS(3710), 1,
      anon_sym_new,
    ACTIONS(3714), 1,
      anon_sym_static,
    ACTIONS(3716), 1,
      anon_sym_readonly,
    ACTIONS(3722), 1,
      anon_sym_override,
    STATE(1344), 1,
      sym_decorator,
    STATE(2773), 1,
      sym_accessibility_modifier,
    STATE(2800), 1,
      sym_override_modifier,
    STATE(3315), 1,
      sym_formal_parameters,
    STATE(3910), 1,
      sym__call_signature,
    STATE(4481), 1,
      aux_sym_export_statement_repeat1,
    STATE(5233), 1,
      sym_type_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3291), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(3712), 2,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(3718), 2,
      anon_sym_get,
      anon_sym_set,
    ACTIONS(3720), 3,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
    STATE(3111), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    STATE(3884), 6,
      sym_export_statement,
      sym_method_signature,
      sym_call_signature,
      sym_property_signature,
      sym_construct_signature,
      sym_index_signature,
    ACTIONS(3700), 12,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      sym_identifier,
      anon_sym_declare,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [23242] = 33,
    ACTIONS(97), 1,
      anon_sym_AT,
    ACTIONS(2139), 1,
      anon_sym_LBRACE,
    ACTIONS(2383), 1,
      anon_sym_namespace,
    ACTIONS(2385), 1,
      anon_sym_import,
    ACTIONS(2387), 1,
      anon_sym_var,
    ACTIONS(2389), 1,
      anon_sym_let,
    ACTIONS(2391), 1,
      anon_sym_const,
    ACTIONS(2393), 1,
      anon_sym_class,
    ACTIONS(2395), 1,
      anon_sym_async,
    ACTIONS(2397), 1,
      anon_sym_function,
    ACTIONS(2399), 1,
      anon_sym_declare,
    ACTIONS(2403), 1,
      anon_sym_abstract,
    ACTIONS(2407), 1,
      anon_sym_interface,
    ACTIONS(2409), 1,
      anon_sym_enum,
    ACTIONS(3798), 1,
      anon_sym_STAR,
    ACTIONS(3800), 1,
      anon_sym_default,
    ACTIONS(3802), 1,
      anon_sym_type,
    ACTIONS(3804), 1,
      anon_sym_EQ,
    ACTIONS(3806), 1,
      anon_sym_as,
    ACTIONS(3808), 1,
      anon_sym_COMMA,
    ACTIONS(3811), 1,
      anon_sym_RBRACE,
    ACTIONS(3816), 1,
      anon_sym_module,
    STATE(1344), 1,
      sym_decorator,
    STATE(4286), 1,
      sym_declaration,
    STATE(4287), 1,
      sym_internal_module,
    STATE(4304), 1,
      aux_sym_export_statement_repeat1,
    STATE(4460), 1,
      sym_export_clause,
    STATE(4792), 1,
      aux_sym_object_repeat1,
    STATE(4815), 1,
      aux_sym_object_pattern_repeat1,
    STATE(5202), 1,
      sym_namespace_export,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3814), 7,
      sym__automatic_semicolon,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_QMARK,
      anon_sym_PIPE_RBRACE,
    STATE(4275), 13,
      sym_variable_declaration,
      sym_lexical_declaration,
      sym_class_declaration,
      sym_function_declaration,
      sym_generator_function_declaration,
      sym_function_signature,
      sym_ambient_declaration,
      sym_abstract_class_declaration,
      sym_module,
      sym_import_alias,
      sym_interface_declaration,
      sym_enum_declaration,
      sym_type_alias_declaration,
  [23361] = 29,
    ACTIONS(1626), 1,
      anon_sym_DQUOTE,
    ACTIONS(1628), 1,
      anon_sym_SQUOTE,
    ACTIONS(3706), 1,
      anon_sym_LBRACK,
    ACTIONS(3722), 1,
      anon_sym_override,
    ACTIONS(3818), 1,
      anon_sym_STAR,
    ACTIONS(3820), 1,
      anon_sym_RBRACE,
    ACTIONS(3822), 1,
      anon_sym_SEMI,
    ACTIONS(3824), 1,
      anon_sym_async,
    ACTIONS(3828), 1,
      anon_sym_AT,
    ACTIONS(3830), 1,
      anon_sym_static,
    ACTIONS(3832), 1,
      anon_sym_readonly,
    ACTIONS(3836), 1,
      anon_sym_declare,
    ACTIONS(3838), 1,
      anon_sym_abstract,
    ACTIONS(3840), 1,
      anon_sym_accessor,
    STATE(2478), 1,
      aux_sym_export_statement_repeat1,
    STATE(2700), 1,
      sym_method_definition,
    STATE(2736), 1,
      sym_accessibility_modifier,
    STATE(2795), 1,
      sym_override_modifier,
    STATE(2802), 1,
      sym_decorator,
    STATE(4440), 1,
      sym_method_signature,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3291), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(3826), 2,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(3834), 2,
      anon_sym_get,
      anon_sym_set,
    STATE(1490), 2,
      sym_class_static_block,
      aux_sym_class_body_repeat1,
    ACTIONS(3720), 3,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
    STATE(3062), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    STATE(5021), 3,
      sym_public_field_definition,
      sym_abstract_method_signature,
      sym_index_signature,
    ACTIONS(3700), 13,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_new,
      sym_identifier,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [23472] = 29,
    ACTIONS(1626), 1,
      anon_sym_DQUOTE,
    ACTIONS(1628), 1,
      anon_sym_SQUOTE,
    ACTIONS(3706), 1,
      anon_sym_LBRACK,
    ACTIONS(3722), 1,
      anon_sym_override,
    ACTIONS(3818), 1,
      anon_sym_STAR,
    ACTIONS(3824), 1,
      anon_sym_async,
    ACTIONS(3828), 1,
      anon_sym_AT,
    ACTIONS(3830), 1,
      anon_sym_static,
    ACTIONS(3832), 1,
      anon_sym_readonly,
    ACTIONS(3836), 1,
      anon_sym_declare,
    ACTIONS(3838), 1,
      anon_sym_abstract,
    ACTIONS(3840), 1,
      anon_sym_accessor,
    ACTIONS(3842), 1,
      anon_sym_RBRACE,
    ACTIONS(3844), 1,
      anon_sym_SEMI,
    STATE(2478), 1,
      aux_sym_export_statement_repeat1,
    STATE(2700), 1,
      sym_method_definition,
    STATE(2736), 1,
      sym_accessibility_modifier,
    STATE(2795), 1,
      sym_override_modifier,
    STATE(2802), 1,
      sym_decorator,
    STATE(4440), 1,
      sym_method_signature,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3291), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(3826), 2,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(3834), 2,
      anon_sym_get,
      anon_sym_set,
    STATE(1485), 2,
      sym_class_static_block,
      aux_sym_class_body_repeat1,
    ACTIONS(3720), 3,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
    STATE(3062), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    STATE(5021), 3,
      sym_public_field_definition,
      sym_abstract_method_signature,
      sym_index_signature,
    ACTIONS(3700), 13,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_new,
      sym_identifier,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [23583] = 29,
    ACTIONS(1626), 1,
      anon_sym_DQUOTE,
    ACTIONS(1628), 1,
      anon_sym_SQUOTE,
    ACTIONS(3706), 1,
      anon_sym_LBRACK,
    ACTIONS(3722), 1,
      anon_sym_override,
    ACTIONS(3818), 1,
      anon_sym_STAR,
    ACTIONS(3824), 1,
      anon_sym_async,
    ACTIONS(3828), 1,
      anon_sym_AT,
    ACTIONS(3830), 1,
      anon_sym_static,
    ACTIONS(3832), 1,
      anon_sym_readonly,
    ACTIONS(3836), 1,
      anon_sym_declare,
    ACTIONS(3838), 1,
      anon_sym_abstract,
    ACTIONS(3840), 1,
      anon_sym_accessor,
    ACTIONS(3846), 1,
      anon_sym_RBRACE,
    ACTIONS(3848), 1,
      anon_sym_SEMI,
    STATE(2478), 1,
      aux_sym_export_statement_repeat1,
    STATE(2700), 1,
      sym_method_definition,
    STATE(2736), 1,
      sym_accessibility_modifier,
    STATE(2795), 1,
      sym_override_modifier,
    STATE(2802), 1,
      sym_decorator,
    STATE(4440), 1,
      sym_method_signature,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3291), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(3826), 2,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(3834), 2,
      anon_sym_get,
      anon_sym_set,
    STATE(1492), 2,
      sym_class_static_block,
      aux_sym_class_body_repeat1,
    ACTIONS(3720), 3,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
    STATE(3062), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    STATE(5021), 3,
      sym_public_field_definition,
      sym_abstract_method_signature,
      sym_index_signature,
    ACTIONS(3700), 13,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_new,
      sym_identifier,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [23694] = 29,
    ACTIONS(3853), 1,
      anon_sym_STAR,
    ACTIONS(3856), 1,
      anon_sym_RBRACE,
    ACTIONS(3858), 1,
      anon_sym_SEMI,
    ACTIONS(3861), 1,
      anon_sym_LBRACK,
    ACTIONS(3864), 1,
      anon_sym_async,
    ACTIONS(3870), 1,
      anon_sym_DQUOTE,
    ACTIONS(3873), 1,
      anon_sym_SQUOTE,
    ACTIONS(3879), 1,
      anon_sym_AT,
    ACTIONS(3882), 1,
      anon_sym_static,
    ACTIONS(3885), 1,
      anon_sym_readonly,
    ACTIONS(3891), 1,
      anon_sym_declare,
    ACTIONS(3897), 1,
      anon_sym_override,
    ACTIONS(3900), 1,
      anon_sym_abstract,
    ACTIONS(3903), 1,
      anon_sym_accessor,
    STATE(2478), 1,
      aux_sym_export_statement_repeat1,
    STATE(2700), 1,
      sym_method_definition,
    STATE(2736), 1,
      sym_accessibility_modifier,
    STATE(2795), 1,
      sym_override_modifier,
    STATE(2802), 1,
      sym_decorator,
    STATE(4440), 1,
      sym_method_signature,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3867), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(3876), 2,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(3888), 2,
      anon_sym_get,
      anon_sym_set,
    STATE(1485), 2,
      sym_class_static_block,
      aux_sym_class_body_repeat1,
    ACTIONS(3894), 3,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
    STATE(3062), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    STATE(5021), 3,
      sym_public_field_definition,
      sym_abstract_method_signature,
      sym_index_signature,
    ACTIONS(3850), 13,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_new,
      sym_identifier,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [23805] = 33,
    ACTIONS(97), 1,
      anon_sym_AT,
    ACTIONS(2139), 1,
      anon_sym_LBRACE,
    ACTIONS(2383), 1,
      anon_sym_namespace,
    ACTIONS(2385), 1,
      anon_sym_import,
    ACTIONS(2387), 1,
      anon_sym_var,
    ACTIONS(2389), 1,
      anon_sym_let,
    ACTIONS(2391), 1,
      anon_sym_const,
    ACTIONS(2393), 1,
      anon_sym_class,
    ACTIONS(2395), 1,
      anon_sym_async,
    ACTIONS(2397), 1,
      anon_sym_function,
    ACTIONS(2399), 1,
      anon_sym_declare,
    ACTIONS(2403), 1,
      anon_sym_abstract,
    ACTIONS(2407), 1,
      anon_sym_interface,
    ACTIONS(2409), 1,
      anon_sym_enum,
    ACTIONS(3798), 1,
      anon_sym_STAR,
    ACTIONS(3800), 1,
      anon_sym_default,
    ACTIONS(3802), 1,
      anon_sym_type,
    ACTIONS(3804), 1,
      anon_sym_EQ,
    ACTIONS(3806), 1,
      anon_sym_as,
    ACTIONS(3808), 1,
      anon_sym_COMMA,
    ACTIONS(3816), 1,
      anon_sym_module,
    ACTIONS(3906), 1,
      anon_sym_RBRACE,
    STATE(1344), 1,
      sym_decorator,
    STATE(4286), 1,
      sym_declaration,
    STATE(4287), 1,
      sym_internal_module,
    STATE(4304), 1,
      aux_sym_export_statement_repeat1,
    STATE(4460), 1,
      sym_export_clause,
    STATE(4810), 1,
      aux_sym_object_repeat1,
    STATE(4815), 1,
      aux_sym_object_pattern_repeat1,
    STATE(5202), 1,
      sym_namespace_export,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3814), 7,
      sym__automatic_semicolon,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_QMARK,
      anon_sym_PIPE_RBRACE,
    STATE(4275), 13,
      sym_variable_declaration,
      sym_lexical_declaration,
      sym_class_declaration,
      sym_function_declaration,
      sym_generator_function_declaration,
      sym_function_signature,
      sym_ambient_declaration,
      sym_abstract_class_declaration,
      sym_module,
      sym_import_alias,
      sym_interface_declaration,
      sym_enum_declaration,
      sym_type_alias_declaration,
  [23924] = 33,
    ACTIONS(97), 1,
      anon_sym_AT,
    ACTIONS(2139), 1,
      anon_sym_LBRACE,
    ACTIONS(2383), 1,
      anon_sym_namespace,
    ACTIONS(2385), 1,
      anon_sym_import,
    ACTIONS(2387), 1,
      anon_sym_var,
    ACTIONS(2389), 1,
      anon_sym_let,
    ACTIONS(2391), 1,
      anon_sym_const,
    ACTIONS(2393), 1,
      anon_sym_class,
    ACTIONS(2395), 1,
      anon_sym_async,
    ACTIONS(2397), 1,
      anon_sym_function,
    ACTIONS(2399), 1,
      anon_sym_declare,
    ACTIONS(2403), 1,
      anon_sym_abstract,
    ACTIONS(2407), 1,
      anon_sym_interface,
    ACTIONS(2409), 1,
      anon_sym_enum,
    ACTIONS(3798), 1,
      anon_sym_STAR,
    ACTIONS(3800), 1,
      anon_sym_default,
    ACTIONS(3802), 1,
      anon_sym_type,
    ACTIONS(3804), 1,
      anon_sym_EQ,
    ACTIONS(3806), 1,
      anon_sym_as,
    ACTIONS(3808), 1,
      anon_sym_COMMA,
    ACTIONS(3816), 1,
      anon_sym_module,
    ACTIONS(3909), 1,
      anon_sym_RBRACE,
    STATE(1344), 1,
      sym_decorator,
    STATE(4286), 1,
      sym_declaration,
    STATE(4287), 1,
      sym_internal_module,
    STATE(4304), 1,
      aux_sym_export_statement_repeat1,
    STATE(4460), 1,
      sym_export_clause,
    STATE(4792), 1,
      aux_sym_object_repeat1,
    STATE(4815), 1,
      aux_sym_object_pattern_repeat1,
    STATE(5202), 1,
      sym_namespace_export,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3814), 7,
      sym__automatic_semicolon,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_QMARK,
      anon_sym_PIPE_RBRACE,
    STATE(4275), 13,
      sym_variable_declaration,
      sym_lexical_declaration,
      sym_class_declaration,
      sym_function_declaration,
      sym_generator_function_declaration,
      sym_function_signature,
      sym_ambient_declaration,
      sym_abstract_class_declaration,
      sym_module,
      sym_import_alias,
      sym_interface_declaration,
      sym_enum_declaration,
      sym_type_alias_declaration,
  [24043] = 33,
    ACTIONS(97), 1,
      anon_sym_AT,
    ACTIONS(2139), 1,
      anon_sym_LBRACE,
    ACTIONS(2383), 1,
      anon_sym_namespace,
    ACTIONS(2385), 1,
      anon_sym_import,
    ACTIONS(2387), 1,
      anon_sym_var,
    ACTIONS(2389), 1,
      anon_sym_let,
    ACTIONS(2391), 1,
      anon_sym_const,
    ACTIONS(2393), 1,
      anon_sym_class,
    ACTIONS(2395), 1,
      anon_sym_async,
    ACTIONS(2397), 1,
      anon_sym_function,
    ACTIONS(2399), 1,
      anon_sym_declare,
    ACTIONS(2403), 1,
      anon_sym_abstract,
    ACTIONS(2407), 1,
      anon_sym_interface,
    ACTIONS(2409), 1,
      anon_sym_enum,
    ACTIONS(3798), 1,
      anon_sym_STAR,
    ACTIONS(3800), 1,
      anon_sym_default,
    ACTIONS(3802), 1,
      anon_sym_type,
    ACTIONS(3804), 1,
      anon_sym_EQ,
    ACTIONS(3806), 1,
      anon_sym_as,
    ACTIONS(3808), 1,
      anon_sym_COMMA,
    ACTIONS(3816), 1,
      anon_sym_module,
    ACTIONS(3912), 1,
      anon_sym_RBRACE,
    STATE(1344), 1,
      sym_decorator,
    STATE(4286), 1,
      sym_declaration,
    STATE(4287), 1,
      sym_internal_module,
    STATE(4304), 1,
      aux_sym_export_statement_repeat1,
    STATE(4460), 1,
      sym_export_clause,
    STATE(4792), 1,
      aux_sym_object_repeat1,
    STATE(4815), 1,
      aux_sym_object_pattern_repeat1,
    STATE(5202), 1,
      sym_namespace_export,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3814), 7,
      sym__automatic_semicolon,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_QMARK,
      anon_sym_PIPE_RBRACE,
    STATE(4275), 13,
      sym_variable_declaration,
      sym_lexical_declaration,
      sym_class_declaration,
      sym_function_declaration,
      sym_generator_function_declaration,
      sym_function_signature,
      sym_ambient_declaration,
      sym_abstract_class_declaration,
      sym_module,
      sym_import_alias,
      sym_interface_declaration,
      sym_enum_declaration,
      sym_type_alias_declaration,
  [24162] = 29,
    ACTIONS(1626), 1,
      anon_sym_DQUOTE,
    ACTIONS(1628), 1,
      anon_sym_SQUOTE,
    ACTIONS(3706), 1,
      anon_sym_LBRACK,
    ACTIONS(3722), 1,
      anon_sym_override,
    ACTIONS(3818), 1,
      anon_sym_STAR,
    ACTIONS(3824), 1,
      anon_sym_async,
    ACTIONS(3828), 1,
      anon_sym_AT,
    ACTIONS(3830), 1,
      anon_sym_static,
    ACTIONS(3832), 1,
      anon_sym_readonly,
    ACTIONS(3836), 1,
      anon_sym_declare,
    ACTIONS(3838), 1,
      anon_sym_abstract,
    ACTIONS(3840), 1,
      anon_sym_accessor,
    ACTIONS(3844), 1,
      anon_sym_SEMI,
    ACTIONS(3915), 1,
      anon_sym_RBRACE,
    STATE(2478), 1,
      aux_sym_export_statement_repeat1,
    STATE(2700), 1,
      sym_method_definition,
    STATE(2736), 1,
      sym_accessibility_modifier,
    STATE(2795), 1,
      sym_override_modifier,
    STATE(2802), 1,
      sym_decorator,
    STATE(4440), 1,
      sym_method_signature,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3291), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(3826), 2,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(3834), 2,
      anon_sym_get,
      anon_sym_set,
    STATE(1485), 2,
      sym_class_static_block,
      aux_sym_class_body_repeat1,
    ACTIONS(3720), 3,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
    STATE(3062), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    STATE(5021), 3,
      sym_public_field_definition,
      sym_abstract_method_signature,
      sym_index_signature,
    ACTIONS(3700), 13,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_new,
      sym_identifier,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [24273] = 29,
    ACTIONS(1626), 1,
      anon_sym_DQUOTE,
    ACTIONS(1628), 1,
      anon_sym_SQUOTE,
    ACTIONS(3706), 1,
      anon_sym_LBRACK,
    ACTIONS(3722), 1,
      anon_sym_override,
    ACTIONS(3818), 1,
      anon_sym_STAR,
    ACTIONS(3824), 1,
      anon_sym_async,
    ACTIONS(3828), 1,
      anon_sym_AT,
    ACTIONS(3830), 1,
      anon_sym_static,
    ACTIONS(3832), 1,
      anon_sym_readonly,
    ACTIONS(3836), 1,
      anon_sym_declare,
    ACTIONS(3838), 1,
      anon_sym_abstract,
    ACTIONS(3840), 1,
      anon_sym_accessor,
    ACTIONS(3844), 1,
      anon_sym_SEMI,
    ACTIONS(3917), 1,
      anon_sym_RBRACE,
    STATE(2478), 1,
      aux_sym_export_statement_repeat1,
    STATE(2700), 1,
      sym_method_definition,
    STATE(2736), 1,
      sym_accessibility_modifier,
    STATE(2795), 1,
      sym_override_modifier,
    STATE(2802), 1,
      sym_decorator,
    STATE(4440), 1,
      sym_method_signature,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3291), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(3826), 2,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(3834), 2,
      anon_sym_get,
      anon_sym_set,
    STATE(1485), 2,
      sym_class_static_block,
      aux_sym_class_body_repeat1,
    ACTIONS(3720), 3,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
    STATE(3062), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    STATE(5021), 3,
      sym_public_field_definition,
      sym_abstract_method_signature,
      sym_index_signature,
    ACTIONS(3700), 13,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_new,
      sym_identifier,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [24384] = 29,
    ACTIONS(1626), 1,
      anon_sym_DQUOTE,
    ACTIONS(1628), 1,
      anon_sym_SQUOTE,
    ACTIONS(3706), 1,
      anon_sym_LBRACK,
    ACTIONS(3722), 1,
      anon_sym_override,
    ACTIONS(3818), 1,
      anon_sym_STAR,
    ACTIONS(3824), 1,
      anon_sym_async,
    ACTIONS(3828), 1,
      anon_sym_AT,
    ACTIONS(3830), 1,
      anon_sym_static,
    ACTIONS(3832), 1,
      anon_sym_readonly,
    ACTIONS(3836), 1,
      anon_sym_declare,
    ACTIONS(3838), 1,
      anon_sym_abstract,
    ACTIONS(3840), 1,
      anon_sym_accessor,
    ACTIONS(3919), 1,
      anon_sym_RBRACE,
    ACTIONS(3921), 1,
      anon_sym_SEMI,
    STATE(2478), 1,
      aux_sym_export_statement_repeat1,
    STATE(2700), 1,
      sym_method_definition,
    STATE(2736), 1,
      sym_accessibility_modifier,
    STATE(2795), 1,
      sym_override_modifier,
    STATE(2802), 1,
      sym_decorator,
    STATE(4440), 1,
      sym_method_signature,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3291), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(3826), 2,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(3834), 2,
      anon_sym_get,
      anon_sym_set,
    STATE(1494), 2,
      sym_class_static_block,
      aux_sym_class_body_repeat1,
    ACTIONS(3720), 3,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
    STATE(3062), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    STATE(5021), 3,
      sym_public_field_definition,
      sym_abstract_method_signature,
      sym_index_signature,
    ACTIONS(3700), 13,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_new,
      sym_identifier,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [24495] = 29,
    ACTIONS(1626), 1,
      anon_sym_DQUOTE,
    ACTIONS(1628), 1,
      anon_sym_SQUOTE,
    ACTIONS(3706), 1,
      anon_sym_LBRACK,
    ACTIONS(3722), 1,
      anon_sym_override,
    ACTIONS(3818), 1,
      anon_sym_STAR,
    ACTIONS(3824), 1,
      anon_sym_async,
    ACTIONS(3828), 1,
      anon_sym_AT,
    ACTIONS(3830), 1,
      anon_sym_static,
    ACTIONS(3832), 1,
      anon_sym_readonly,
    ACTIONS(3836), 1,
      anon_sym_declare,
    ACTIONS(3838), 1,
      anon_sym_abstract,
    ACTIONS(3840), 1,
      anon_sym_accessor,
    ACTIONS(3844), 1,
      anon_sym_SEMI,
    ACTIONS(3923), 1,
      anon_sym_RBRACE,
    STATE(2478), 1,
      aux_sym_export_statement_repeat1,
    STATE(2700), 1,
      sym_method_definition,
    STATE(2736), 1,
      sym_accessibility_modifier,
    STATE(2795), 1,
      sym_override_modifier,
    STATE(2802), 1,
      sym_decorator,
    STATE(4440), 1,
      sym_method_signature,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3291), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(3826), 2,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(3834), 2,
      anon_sym_get,
      anon_sym_set,
    STATE(1485), 2,
      sym_class_static_block,
      aux_sym_class_body_repeat1,
    ACTIONS(3720), 3,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
    STATE(3062), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    STATE(5021), 3,
      sym_public_field_definition,
      sym_abstract_method_signature,
      sym_index_signature,
    ACTIONS(3700), 13,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_new,
      sym_identifier,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [24606] = 33,
    ACTIONS(97), 1,
      anon_sym_AT,
    ACTIONS(2139), 1,
      anon_sym_LBRACE,
    ACTIONS(2383), 1,
      anon_sym_namespace,
    ACTIONS(2385), 1,
      anon_sym_import,
    ACTIONS(2387), 1,
      anon_sym_var,
    ACTIONS(2389), 1,
      anon_sym_let,
    ACTIONS(2391), 1,
      anon_sym_const,
    ACTIONS(2393), 1,
      anon_sym_class,
    ACTIONS(2395), 1,
      anon_sym_async,
    ACTIONS(2397), 1,
      anon_sym_function,
    ACTIONS(2399), 1,
      anon_sym_declare,
    ACTIONS(2403), 1,
      anon_sym_abstract,
    ACTIONS(2407), 1,
      anon_sym_interface,
    ACTIONS(2409), 1,
      anon_sym_enum,
    ACTIONS(3798), 1,
      anon_sym_STAR,
    ACTIONS(3800), 1,
      anon_sym_default,
    ACTIONS(3802), 1,
      anon_sym_type,
    ACTIONS(3804), 1,
      anon_sym_EQ,
    ACTIONS(3806), 1,
      anon_sym_as,
    ACTIONS(3808), 1,
      anon_sym_COMMA,
    ACTIONS(3816), 1,
      anon_sym_module,
    ACTIONS(3925), 1,
      anon_sym_RBRACE,
    STATE(1344), 1,
      sym_decorator,
    STATE(4286), 1,
      sym_declaration,
    STATE(4287), 1,
      sym_internal_module,
    STATE(4304), 1,
      aux_sym_export_statement_repeat1,
    STATE(4460), 1,
      sym_export_clause,
    STATE(4792), 1,
      aux_sym_object_repeat1,
    STATE(4815), 1,
      aux_sym_object_pattern_repeat1,
    STATE(5202), 1,
      sym_namespace_export,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3814), 7,
      sym__automatic_semicolon,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_QMARK,
      anon_sym_PIPE_RBRACE,
    STATE(4275), 13,
      sym_variable_declaration,
      sym_lexical_declaration,
      sym_class_declaration,
      sym_function_declaration,
      sym_generator_function_declaration,
      sym_function_signature,
      sym_ambient_declaration,
      sym_abstract_class_declaration,
      sym_module,
      sym_import_alias,
      sym_interface_declaration,
      sym_enum_declaration,
      sym_type_alias_declaration,
  [24725] = 29,
    ACTIONS(1626), 1,
      anon_sym_DQUOTE,
    ACTIONS(1628), 1,
      anon_sym_SQUOTE,
    ACTIONS(3706), 1,
      anon_sym_LBRACK,
    ACTIONS(3722), 1,
      anon_sym_override,
    ACTIONS(3818), 1,
      anon_sym_STAR,
    ACTIONS(3824), 1,
      anon_sym_async,
    ACTIONS(3828), 1,
      anon_sym_AT,
    ACTIONS(3830), 1,
      anon_sym_static,
    ACTIONS(3832), 1,
      anon_sym_readonly,
    ACTIONS(3836), 1,
      anon_sym_declare,
    ACTIONS(3838), 1,
      anon_sym_abstract,
    ACTIONS(3840), 1,
      anon_sym_accessor,
    ACTIONS(3844), 1,
      anon_sym_SEMI,
    ACTIONS(3928), 1,
      anon_sym_RBRACE,
    STATE(2478), 1,
      aux_sym_export_statement_repeat1,
    STATE(2700), 1,
      sym_method_definition,
    STATE(2736), 1,
      sym_accessibility_modifier,
    STATE(2795), 1,
      sym_override_modifier,
    STATE(2802), 1,
      sym_decorator,
    STATE(4440), 1,
      sym_method_signature,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3291), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(3826), 2,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(3834), 2,
      anon_sym_get,
      anon_sym_set,
    STATE(1485), 2,
      sym_class_static_block,
      aux_sym_class_body_repeat1,
    ACTIONS(3720), 3,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
    STATE(3062), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    STATE(5021), 3,
      sym_public_field_definition,
      sym_abstract_method_signature,
      sym_index_signature,
    ACTIONS(3700), 13,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_new,
      sym_identifier,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [24836] = 29,
    ACTIONS(1626), 1,
      anon_sym_DQUOTE,
    ACTIONS(1628), 1,
      anon_sym_SQUOTE,
    ACTIONS(3706), 1,
      anon_sym_LBRACK,
    ACTIONS(3722), 1,
      anon_sym_override,
    ACTIONS(3818), 1,
      anon_sym_STAR,
    ACTIONS(3824), 1,
      anon_sym_async,
    ACTIONS(3828), 1,
      anon_sym_AT,
    ACTIONS(3830), 1,
      anon_sym_static,
    ACTIONS(3832), 1,
      anon_sym_readonly,
    ACTIONS(3836), 1,
      anon_sym_declare,
    ACTIONS(3838), 1,
      anon_sym_abstract,
    ACTIONS(3840), 1,
      anon_sym_accessor,
    ACTIONS(3930), 1,
      anon_sym_RBRACE,
    ACTIONS(3932), 1,
      anon_sym_SEMI,
    STATE(2478), 1,
      aux_sym_export_statement_repeat1,
    STATE(2700), 1,
      sym_method_definition,
    STATE(2736), 1,
      sym_accessibility_modifier,
    STATE(2795), 1,
      sym_override_modifier,
    STATE(2802), 1,
      sym_decorator,
    STATE(4440), 1,
      sym_method_signature,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3291), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(3826), 2,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(3834), 2,
      anon_sym_get,
      anon_sym_set,
    STATE(1483), 2,
      sym_class_static_block,
      aux_sym_class_body_repeat1,
    ACTIONS(3720), 3,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
    STATE(3062), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    STATE(5021), 3,
      sym_public_field_definition,
      sym_abstract_method_signature,
      sym_index_signature,
    ACTIONS(3700), 13,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_new,
      sym_identifier,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [24947] = 29,
    ACTIONS(1626), 1,
      anon_sym_DQUOTE,
    ACTIONS(1628), 1,
      anon_sym_SQUOTE,
    ACTIONS(3706), 1,
      anon_sym_LBRACK,
    ACTIONS(3722), 1,
      anon_sym_override,
    ACTIONS(3818), 1,
      anon_sym_STAR,
    ACTIONS(3824), 1,
      anon_sym_async,
    ACTIONS(3828), 1,
      anon_sym_AT,
    ACTIONS(3830), 1,
      anon_sym_static,
    ACTIONS(3832), 1,
      anon_sym_readonly,
    ACTIONS(3836), 1,
      anon_sym_declare,
    ACTIONS(3838), 1,
      anon_sym_abstract,
    ACTIONS(3840), 1,
      anon_sym_accessor,
    ACTIONS(3934), 1,
      anon_sym_RBRACE,
    ACTIONS(3936), 1,
      anon_sym_SEMI,
    STATE(2478), 1,
      aux_sym_export_statement_repeat1,
    STATE(2700), 1,
      sym_method_definition,
    STATE(2736), 1,
      sym_accessibility_modifier,
    STATE(2795), 1,
      sym_override_modifier,
    STATE(2802), 1,
      sym_decorator,
    STATE(4440), 1,
      sym_method_signature,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3291), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(3826), 2,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(3834), 2,
      anon_sym_get,
      anon_sym_set,
    STATE(1489), 2,
      sym_class_static_block,
      aux_sym_class_body_repeat1,
    ACTIONS(3720), 3,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
    STATE(3062), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    STATE(5021), 3,
      sym_public_field_definition,
      sym_abstract_method_signature,
      sym_index_signature,
    ACTIONS(3700), 13,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_new,
      sym_identifier,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [25058] = 25,
    ACTIONS(231), 1,
      anon_sym_STAR,
    ACTIONS(237), 1,
      anon_sym_COMMA,
    ACTIONS(249), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1550), 1,
      anon_sym_DQUOTE,
    ACTIONS(1552), 1,
      anon_sym_SQUOTE,
    ACTIONS(3275), 1,
      anon_sym_LBRACE,
    ACTIONS(3940), 1,
      anon_sym_RBRACE,
    ACTIONS(3942), 1,
      anon_sym_LBRACK,
    ACTIONS(3944), 1,
      anon_sym_async,
    ACTIONS(3948), 1,
      anon_sym_static,
    ACTIONS(3950), 1,
      anon_sym_readonly,
    ACTIONS(3956), 1,
      anon_sym_override,
    STATE(2786), 1,
      sym_accessibility_modifier,
    STATE(2808), 1,
      sym_override_modifier,
    STATE(4744), 1,
      aux_sym_object_repeat1,
    STATE(4745), 1,
      aux_sym_object_pattern_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3946), 2,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(3952), 2,
      anon_sym_get,
      anon_sym_set,
    ACTIONS(3954), 3,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
    STATE(3648), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    STATE(4555), 3,
      sym_object_assignment_pattern,
      sym_rest_pattern,
      sym_pair_pattern,
    STATE(4576), 3,
      sym_spread_element,
      sym_method_definition,
      sym_pair,
    STATE(5536), 3,
      sym_object_pattern,
      sym_array_pattern,
      sym__destructuring_pattern,
    ACTIONS(3938), 14,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_new,
      sym_identifier,
      anon_sym_declare,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [25160] = 25,
    ACTIONS(231), 1,
      anon_sym_STAR,
    ACTIONS(237), 1,
      anon_sym_COMMA,
    ACTIONS(249), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1550), 1,
      anon_sym_DQUOTE,
    ACTIONS(1552), 1,
      anon_sym_SQUOTE,
    ACTIONS(3275), 1,
      anon_sym_LBRACE,
    ACTIONS(3942), 1,
      anon_sym_LBRACK,
    ACTIONS(3960), 1,
      anon_sym_RBRACE,
    ACTIONS(3962), 1,
      anon_sym_async,
    ACTIONS(3964), 1,
      anon_sym_static,
    ACTIONS(3966), 1,
      anon_sym_readonly,
    ACTIONS(3972), 1,
      anon_sym_override,
    STATE(2786), 1,
      sym_accessibility_modifier,
    STATE(2808), 1,
      sym_override_modifier,
    STATE(4734), 1,
      aux_sym_object_repeat1,
    STATE(4745), 1,
      aux_sym_object_pattern_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3946), 2,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(3968), 2,
      anon_sym_get,
      anon_sym_set,
    ACTIONS(3970), 3,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
    STATE(3648), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    STATE(4555), 3,
      sym_object_assignment_pattern,
      sym_rest_pattern,
      sym_pair_pattern,
    STATE(4721), 3,
      sym_spread_element,
      sym_method_definition,
      sym_pair,
    STATE(5536), 3,
      sym_object_pattern,
      sym_array_pattern,
      sym__destructuring_pattern,
    ACTIONS(3958), 14,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_new,
      sym_identifier,
      anon_sym_declare,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [25262] = 25,
    ACTIONS(231), 1,
      anon_sym_STAR,
    ACTIONS(237), 1,
      anon_sym_COMMA,
    ACTIONS(249), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1550), 1,
      anon_sym_DQUOTE,
    ACTIONS(1552), 1,
      anon_sym_SQUOTE,
    ACTIONS(3275), 1,
      anon_sym_LBRACE,
    ACTIONS(3942), 1,
      anon_sym_LBRACK,
    ACTIONS(3976), 1,
      anon_sym_RBRACE,
    ACTIONS(3978), 1,
      anon_sym_async,
    ACTIONS(3980), 1,
      anon_sym_static,
    ACTIONS(3982), 1,
      anon_sym_readonly,
    ACTIONS(3988), 1,
      anon_sym_override,
    STATE(2786), 1,
      sym_accessibility_modifier,
    STATE(2808), 1,
      sym_override_modifier,
    STATE(4734), 1,
      aux_sym_object_repeat1,
    STATE(4745), 1,
      aux_sym_object_pattern_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3946), 2,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(3984), 2,
      anon_sym_get,
      anon_sym_set,
    ACTIONS(3986), 3,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
    STATE(3648), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    STATE(4555), 3,
      sym_object_assignment_pattern,
      sym_rest_pattern,
      sym_pair_pattern,
    STATE(4721), 3,
      sym_spread_element,
      sym_method_definition,
      sym_pair,
    STATE(5536), 3,
      sym_object_pattern,
      sym_array_pattern,
      sym__destructuring_pattern,
    ACTIONS(3974), 14,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_new,
      sym_identifier,
      anon_sym_declare,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [25364] = 25,
    ACTIONS(231), 1,
      anon_sym_STAR,
    ACTIONS(237), 1,
      anon_sym_COMMA,
    ACTIONS(249), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1550), 1,
      anon_sym_DQUOTE,
    ACTIONS(1552), 1,
      anon_sym_SQUOTE,
    ACTIONS(3275), 1,
      anon_sym_LBRACE,
    ACTIONS(3942), 1,
      anon_sym_LBRACK,
    ACTIONS(3992), 1,
      anon_sym_RBRACE,
    ACTIONS(3994), 1,
      anon_sym_async,
    ACTIONS(3996), 1,
      anon_sym_static,
    ACTIONS(3998), 1,
      anon_sym_readonly,
    ACTIONS(4004), 1,
      anon_sym_override,
    STATE(2786), 1,
      sym_accessibility_modifier,
    STATE(2808), 1,
      sym_override_modifier,
    STATE(4734), 1,
      aux_sym_object_repeat1,
    STATE(4745), 1,
      aux_sym_object_pattern_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3946), 2,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(4000), 2,
      anon_sym_get,
      anon_sym_set,
    ACTIONS(4002), 3,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
    STATE(3648), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    STATE(4555), 3,
      sym_object_assignment_pattern,
      sym_rest_pattern,
      sym_pair_pattern,
    STATE(4721), 3,
      sym_spread_element,
      sym_method_definition,
      sym_pair,
    STATE(5536), 3,
      sym_object_pattern,
      sym_array_pattern,
      sym__destructuring_pattern,
    ACTIONS(3990), 14,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_new,
      sym_identifier,
      anon_sym_declare,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [25466] = 13,
    ACTIONS(820), 1,
      anon_sym_BQUOTE,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4016), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4018), 1,
      anon_sym_LT,
    STATE(1627), 1,
      sym_type_arguments,
    STATE(1657), 1,
      sym_template_string,
    STATE(1666), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4006), 12,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4008), 27,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_of,
      anon_sym_COLON,
      anon_sym_RBRACK,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_satisfies,
      anon_sym_implements,
  [25544] = 25,
    ACTIONS(231), 1,
      anon_sym_STAR,
    ACTIONS(237), 1,
      anon_sym_COMMA,
    ACTIONS(249), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1550), 1,
      anon_sym_DQUOTE,
    ACTIONS(1552), 1,
      anon_sym_SQUOTE,
    ACTIONS(3275), 1,
      anon_sym_LBRACE,
    ACTIONS(3942), 1,
      anon_sym_LBRACK,
    ACTIONS(4022), 1,
      anon_sym_RBRACE,
    ACTIONS(4024), 1,
      anon_sym_async,
    ACTIONS(4026), 1,
      anon_sym_static,
    ACTIONS(4028), 1,
      anon_sym_readonly,
    ACTIONS(4034), 1,
      anon_sym_override,
    STATE(2786), 1,
      sym_accessibility_modifier,
    STATE(2808), 1,
      sym_override_modifier,
    STATE(4734), 1,
      aux_sym_object_repeat1,
    STATE(4745), 1,
      aux_sym_object_pattern_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3946), 2,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(4030), 2,
      anon_sym_get,
      anon_sym_set,
    ACTIONS(4032), 3,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
    STATE(3648), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    STATE(4555), 3,
      sym_object_assignment_pattern,
      sym_rest_pattern,
      sym_pair_pattern,
    STATE(4721), 3,
      sym_spread_element,
      sym_method_definition,
      sym_pair,
    STATE(5536), 3,
      sym_object_pattern,
      sym_array_pattern,
      sym__destructuring_pattern,
    ACTIONS(4020), 14,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_new,
      sym_identifier,
      anon_sym_declare,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [25646] = 25,
    ACTIONS(231), 1,
      anon_sym_STAR,
    ACTIONS(237), 1,
      anon_sym_COMMA,
    ACTIONS(249), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1550), 1,
      anon_sym_DQUOTE,
    ACTIONS(1552), 1,
      anon_sym_SQUOTE,
    ACTIONS(3275), 1,
      anon_sym_LBRACE,
    ACTIONS(3942), 1,
      anon_sym_LBRACK,
    ACTIONS(4038), 1,
      anon_sym_RBRACE,
    ACTIONS(4040), 1,
      anon_sym_async,
    ACTIONS(4042), 1,
      anon_sym_static,
    ACTIONS(4044), 1,
      anon_sym_readonly,
    ACTIONS(4050), 1,
      anon_sym_override,
    STATE(2786), 1,
      sym_accessibility_modifier,
    STATE(2808), 1,
      sym_override_modifier,
    STATE(4734), 1,
      aux_sym_object_repeat1,
    STATE(4745), 1,
      aux_sym_object_pattern_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3946), 2,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(4046), 2,
      anon_sym_get,
      anon_sym_set,
    ACTIONS(4048), 3,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
    STATE(3648), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    STATE(4555), 3,
      sym_object_assignment_pattern,
      sym_rest_pattern,
      sym_pair_pattern,
    STATE(4721), 3,
      sym_spread_element,
      sym_method_definition,
      sym_pair,
    STATE(5536), 3,
      sym_object_pattern,
      sym_array_pattern,
      sym__destructuring_pattern,
    ACTIONS(4036), 14,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_new,
      sym_identifier,
      anon_sym_declare,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [25748] = 8,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4018), 1,
      anon_sym_LT,
    ACTIONS(4052), 1,
      anon_sym_DOT,
    STATE(1602), 1,
      sym_arguments,
    STATE(1603), 1,
      sym_type_arguments,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3522), 12,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(3512), 31,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_of,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_extends,
      anon_sym_implements,
  [25815] = 7,
    ACTIONS(4018), 1,
      anon_sym_LT,
    ACTIONS(4056), 1,
      anon_sym_DOT,
    ACTIONS(4058), 1,
      anon_sym_is,
    STATE(1626), 1,
      sym_type_arguments,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4054), 12,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(3548), 32,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_of,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_extends,
      anon_sym_implements,
  [25880] = 8,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4018), 1,
      anon_sym_LT,
    ACTIONS(4064), 1,
      anon_sym_DOT,
    STATE(1610), 1,
      sym_arguments,
    STATE(1611), 1,
      sym_type_arguments,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4060), 12,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4062), 31,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_of,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_extends,
      anon_sym_implements,
  [25947] = 29,
    ACTIONS(97), 1,
      anon_sym_AT,
    ACTIONS(2139), 1,
      anon_sym_LBRACE,
    ACTIONS(2383), 1,
      anon_sym_namespace,
    ACTIONS(2385), 1,
      anon_sym_import,
    ACTIONS(2387), 1,
      anon_sym_var,
    ACTIONS(2389), 1,
      anon_sym_let,
    ACTIONS(2391), 1,
      anon_sym_const,
    ACTIONS(2393), 1,
      anon_sym_class,
    ACTIONS(2395), 1,
      anon_sym_async,
    ACTIONS(2397), 1,
      anon_sym_function,
    ACTIONS(2399), 1,
      anon_sym_declare,
    ACTIONS(2403), 1,
      anon_sym_abstract,
    ACTIONS(2407), 1,
      anon_sym_interface,
    ACTIONS(2409), 1,
      anon_sym_enum,
    ACTIONS(3798), 1,
      anon_sym_STAR,
    ACTIONS(3800), 1,
      anon_sym_default,
    ACTIONS(3802), 1,
      anon_sym_type,
    ACTIONS(3806), 1,
      anon_sym_as,
    ACTIONS(3816), 1,
      anon_sym_module,
    ACTIONS(4066), 1,
      anon_sym_EQ,
    STATE(1344), 1,
      sym_decorator,
    STATE(4286), 1,
      sym_declaration,
    STATE(4287), 1,
      sym_internal_module,
    STATE(4304), 1,
      aux_sym_export_statement_repeat1,
    STATE(4460), 1,
      sym_export_clause,
    STATE(5202), 1,
      sym_namespace_export,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3814), 9,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_QMARK,
      anon_sym_PIPE_RBRACE,
    STATE(4275), 13,
      sym_variable_declaration,
      sym_lexical_declaration,
      sym_class_declaration,
      sym_function_declaration,
      sym_generator_function_declaration,
      sym_function_signature,
      sym_ambient_declaration,
      sym_abstract_class_declaration,
      sym_module,
      sym_import_alias,
      sym_interface_declaration,
      sym_enum_declaration,
      sym_type_alias_declaration,
  [26056] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(1756), 14,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK,
    ACTIONS(1754), 34,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_else,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_while,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_extends,
      anon_sym_PIPE_RBRACE,
  [26113] = 8,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4018), 1,
      anon_sym_LT,
    ACTIONS(4072), 1,
      anon_sym_DOT,
    STATE(1604), 1,
      sym_arguments,
    STATE(1609), 1,
      sym_type_arguments,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4068), 12,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4070), 31,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_of,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_extends,
      anon_sym_implements,
  [26180] = 30,
    ACTIONS(97), 1,
      anon_sym_AT,
    ACTIONS(2139), 1,
      anon_sym_LBRACE,
    ACTIONS(2383), 1,
      anon_sym_namespace,
    ACTIONS(2385), 1,
      anon_sym_import,
    ACTIONS(2387), 1,
      anon_sym_var,
    ACTIONS(2389), 1,
      anon_sym_let,
    ACTIONS(2391), 1,
      anon_sym_const,
    ACTIONS(2393), 1,
      anon_sym_class,
    ACTIONS(2395), 1,
      anon_sym_async,
    ACTIONS(2397), 1,
      anon_sym_function,
    ACTIONS(2399), 1,
      anon_sym_declare,
    ACTIONS(2403), 1,
      anon_sym_abstract,
    ACTIONS(2407), 1,
      anon_sym_interface,
    ACTIONS(2409), 1,
      anon_sym_enum,
    ACTIONS(3798), 1,
      anon_sym_STAR,
    ACTIONS(3800), 1,
      anon_sym_default,
    ACTIONS(3802), 1,
      anon_sym_type,
    ACTIONS(3804), 1,
      anon_sym_EQ,
    ACTIONS(3806), 1,
      anon_sym_as,
    ACTIONS(3816), 1,
      anon_sym_module,
    STATE(1344), 1,
      sym_decorator,
    STATE(4286), 1,
      sym_declaration,
    STATE(4287), 1,
      sym_internal_module,
    STATE(4304), 1,
      aux_sym_export_statement_repeat1,
    STATE(4460), 1,
      sym_export_clause,
    STATE(5202), 1,
      sym_namespace_export,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4074), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
    ACTIONS(3814), 7,
      sym__automatic_semicolon,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_QMARK,
      anon_sym_PIPE_RBRACE,
    STATE(4275), 13,
      sym_variable_declaration,
      sym_lexical_declaration,
      sym_class_declaration,
      sym_function_declaration,
      sym_generator_function_declaration,
      sym_function_signature,
      sym_ambient_declaration,
      sym_abstract_class_declaration,
      sym_module,
      sym_import_alias,
      sym_interface_declaration,
      sym_enum_declaration,
      sym_type_alias_declaration,
  [26291] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(1728), 14,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK,
    ACTIONS(1726), 34,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_else,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_while,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_extends,
      anon_sym_PIPE_RBRACE,
  [26348] = 6,
    ACTIONS(4018), 1,
      anon_sym_LT,
    ACTIONS(4056), 1,
      anon_sym_DOT,
    STATE(1626), 1,
      sym_type_arguments,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4054), 12,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(3548), 32,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_of,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_extends,
      anon_sym_implements,
  [26410] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3225), 14,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK,
    ACTIONS(3227), 33,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_of,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_extends,
      anon_sym_implements,
  [26466] = 6,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4082), 1,
      anon_sym_DOT,
    STATE(1548), 1,
      sym_arguments,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4078), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4080), 31,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_of,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_extends,
      anon_sym_implements,
  [26528] = 9,
    ACTIONS(820), 1,
      anon_sym_BQUOTE,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4016), 1,
      anon_sym_QMARK_DOT,
    STATE(1657), 1,
      sym_template_string,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(1734), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(1736), 28,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_of,
      anon_sym_COLON,
      anon_sym_RBRACK,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_satisfies,
      anon_sym_implements,
  [26596] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4084), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4086), 34,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_of,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_extends,
      anon_sym_implements,
      anon_sym_is,
  [26652] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(1728), 14,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK,
    ACTIONS(1726), 33,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_of,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_extends,
      anon_sym_implements,
  [26708] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3237), 14,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK,
    ACTIONS(3239), 33,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_of,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_extends,
      anon_sym_implements,
  [26764] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(1756), 14,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK,
    ACTIONS(1754), 33,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_of,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_extends,
      anon_sym_implements,
  [26820] = 22,
    ACTIONS(231), 1,
      anon_sym_STAR,
    ACTIONS(249), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1550), 1,
      anon_sym_DQUOTE,
    ACTIONS(1552), 1,
      anon_sym_SQUOTE,
    ACTIONS(3275), 1,
      anon_sym_LBRACE,
    ACTIONS(3942), 1,
      anon_sym_LBRACK,
    ACTIONS(4090), 1,
      anon_sym_async,
    ACTIONS(4092), 1,
      anon_sym_static,
    ACTIONS(4094), 1,
      anon_sym_readonly,
    ACTIONS(4100), 1,
      anon_sym_override,
    STATE(2786), 1,
      sym_accessibility_modifier,
    STATE(2808), 1,
      sym_override_modifier,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3437), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
    ACTIONS(3946), 2,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(4096), 2,
      anon_sym_get,
      anon_sym_set,
    ACTIONS(4098), 3,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
    STATE(3648), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    STATE(5225), 3,
      sym_object_assignment_pattern,
      sym_rest_pattern,
      sym_pair_pattern,
    STATE(5230), 3,
      sym_spread_element,
      sym_method_definition,
      sym_pair,
    STATE(5536), 3,
      sym_object_pattern,
      sym_array_pattern,
      sym__destructuring_pattern,
    ACTIONS(4088), 14,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_new,
      sym_identifier,
      anon_sym_declare,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [26914] = 5,
    ACTIONS(1696), 1,
      anon_sym_EQ,
    ACTIONS(4102), 1,
      sym__automatic_semicolon,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(1692), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(1690), 32,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_of,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_implements,
  [26974] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(1900), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(1898), 34,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_of,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_extends,
      anon_sym_implements,
      anon_sym_is,
  [27030] = 4,
    ACTIONS(4058), 1,
      anon_sym_is,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4104), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4106), 33,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_of,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_extends,
      anon_sym_implements,
  [27088] = 4,
    ACTIONS(4112), 1,
      anon_sym_is,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4108), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4110), 33,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_of,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_extends,
      anon_sym_implements,
  [27146] = 4,
    ACTIONS(4058), 1,
      anon_sym_is,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4114), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4116), 33,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_of,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_extends,
      anon_sym_implements,
  [27204] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3233), 14,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_QMARK,
    ACTIONS(3235), 33,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_of,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_extends,
      anon_sym_implements,
  [27260] = 5,
    ACTIONS(4018), 1,
      anon_sym_LT,
    STATE(1545), 1,
      sym_type_arguments,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4108), 12,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4110), 33,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_of,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_extends,
      anon_sym_implements,
  [27320] = 4,
    ACTIONS(3494), 1,
      anon_sym_EQ,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3492), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(3496), 32,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_of,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_implements,
  [27377] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4118), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4120), 33,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_of,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_extends,
      anon_sym_implements,
  [27432] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4122), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4124), 33,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_of,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_extends,
      anon_sym_implements,
  [27487] = 7,
    ACTIONS(1696), 1,
      anon_sym_EQ,
    ACTIONS(2373), 1,
      anon_sym_extends,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4126), 2,
      anon_sym_COMMA,
      anon_sym_LBRACK,
    ACTIONS(4129), 3,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_GT,
    ACTIONS(1694), 10,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1698), 29,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_implements,
  [27550] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4132), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4134), 33,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_of,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_extends,
      anon_sym_implements,
  [27605] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4136), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4138), 33,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_of,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_extends,
      anon_sym_implements,
  [27660] = 4,
    ACTIONS(4102), 1,
      sym__automatic_semicolon,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(1692), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(1690), 32,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_of,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_implements,
  [27717] = 7,
    ACTIONS(3516), 1,
      anon_sym_DOT,
    ACTIONS(3520), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3512), 3,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_extends,
    ACTIONS(3522), 3,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_GT,
    ACTIONS(3492), 10,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(3496), 28,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_of,
      anon_sym_COLON,
      anon_sym_RBRACK,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_implements,
  [27780] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4140), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4142), 33,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_of,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_extends,
      anon_sym_implements,
  [27835] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4132), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4134), 33,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_of,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_extends,
      anon_sym_implements,
  [27890] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4136), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4138), 33,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_of,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_extends,
      anon_sym_implements,
  [27945] = 7,
    ACTIONS(4146), 1,
      anon_sym_EQ,
    ACTIONS(4156), 1,
      anon_sym_extends,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4150), 2,
      anon_sym_COMMA,
      anon_sym_LBRACK,
    ACTIONS(4153), 3,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_GT,
    ACTIONS(4144), 10,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4148), 29,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_implements,
  [28008] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4158), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4160), 33,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_of,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_extends,
      anon_sym_implements,
  [28063] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(2375), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(2373), 33,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_of,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_extends,
      anon_sym_implements,
  [28118] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4162), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4164), 33,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_of,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_extends,
      anon_sym_implements,
  [28173] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4166), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4168), 33,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_of,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_extends,
      anon_sym_implements,
  [28228] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4170), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4172), 33,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_of,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_extends,
      anon_sym_implements,
  [28283] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4174), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4176), 33,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_of,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_extends,
      anon_sym_implements,
  [28338] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4162), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4164), 33,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_of,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_extends,
      anon_sym_implements,
  [28393] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4166), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4168), 33,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_of,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_extends,
      anon_sym_implements,
  [28448] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4178), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4180), 33,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_of,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_extends,
      anon_sym_implements,
  [28503] = 5,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4182), 3,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_extends,
    ACTIONS(4184), 3,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_GT,
    ACTIONS(3492), 10,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(3496), 30,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_of,
      anon_sym_COLON,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_implements,
  [28562] = 4,
    ACTIONS(4052), 1,
      anon_sym_DOT,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3522), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(3512), 32,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_of,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_extends,
      anon_sym_implements,
  [28619] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4186), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4188), 33,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_of,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_extends,
      anon_sym_implements,
  [28674] = 4,
    ACTIONS(4194), 1,
      anon_sym_extends,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4190), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4192), 32,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_of,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_implements,
  [28731] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4196), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4198), 33,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_of,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_extends,
      anon_sym_implements,
  [28786] = 4,
    ACTIONS(4200), 1,
      anon_sym_LBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4170), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4172), 32,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_of,
      anon_sym_COLON,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_extends,
      anon_sym_implements,
  [28843] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3417), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(3419), 33,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_of,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_extends,
      anon_sym_implements,
  [28898] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4108), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4110), 33,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_of,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_extends,
      anon_sym_implements,
  [28953] = 6,
    ACTIONS(4206), 1,
      anon_sym_AMP,
    ACTIONS(4208), 1,
      anon_sym_PIPE,
    ACTIONS(4210), 1,
      anon_sym_extends,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4202), 11,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4204), 32,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_of,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_implements,
  [29014] = 4,
    ACTIONS(4200), 1,
      anon_sym_LBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4212), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4214), 32,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_of,
      anon_sym_COLON,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_extends,
      anon_sym_implements,
  [29071] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4216), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4218), 33,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_of,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_extends,
      anon_sym_implements,
  [29126] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4220), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4222), 33,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_of,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_extends,
      anon_sym_implements,
  [29181] = 6,
    ACTIONS(4206), 1,
      anon_sym_AMP,
    ACTIONS(4208), 1,
      anon_sym_PIPE,
    ACTIONS(4210), 1,
      anon_sym_extends,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4220), 11,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4222), 32,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_of,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_implements,
  [29242] = 4,
    ACTIONS(4228), 1,
      anon_sym_DOT,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4224), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4226), 32,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_of,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_extends,
      anon_sym_implements,
  [29299] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4230), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4232), 33,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_of,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_extends,
      anon_sym_implements,
  [29354] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(2371), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(2369), 33,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_of,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_extends,
      anon_sym_implements,
  [29409] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4234), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4236), 33,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_of,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_extends,
      anon_sym_implements,
  [29464] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4238), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4240), 33,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_of,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_extends,
      anon_sym_implements,
  [29519] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4238), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4240), 33,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_of,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_extends,
      anon_sym_implements,
  [29574] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4238), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4240), 33,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_of,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_extends,
      anon_sym_implements,
  [29629] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4242), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4244), 33,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_of,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_extends,
      anon_sym_implements,
  [29684] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4242), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4244), 33,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_of,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_extends,
      anon_sym_implements,
  [29739] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4242), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4244), 33,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_of,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_extends,
      anon_sym_implements,
  [29794] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4246), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4248), 33,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_of,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_extends,
      anon_sym_implements,
  [29849] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4246), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4248), 33,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_of,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_extends,
      anon_sym_implements,
  [29904] = 4,
    ACTIONS(4254), 1,
      anon_sym_DOT,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4250), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4252), 32,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_of,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_extends,
      anon_sym_implements,
  [29961] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4246), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4248), 33,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_of,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_extends,
      anon_sym_implements,
  [30016] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4256), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4258), 33,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_of,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_extends,
      anon_sym_implements,
  [30071] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4260), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4262), 33,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_of,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_extends,
      anon_sym_implements,
  [30126] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4264), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4266), 33,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_of,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_extends,
      anon_sym_implements,
  [30181] = 4,
    ACTIONS(4268), 1,
      sym__automatic_semicolon,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(1880), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(1878), 32,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_of,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_implements,
  [30238] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4270), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4156), 33,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_of,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_extends,
      anon_sym_implements,
  [30293] = 6,
    ACTIONS(4206), 1,
      anon_sym_AMP,
    ACTIONS(4208), 1,
      anon_sym_PIPE,
    ACTIONS(4210), 1,
      anon_sym_extends,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4272), 11,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4274), 32,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_of,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_implements,
  [30354] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(2363), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(2361), 33,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_of,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_extends,
      anon_sym_implements,
  [30409] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4276), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4278), 33,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_of,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_extends,
      anon_sym_implements,
  [30464] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4280), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4282), 33,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_of,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_extends,
      anon_sym_implements,
  [30519] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4280), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4282), 33,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_of,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_extends,
      anon_sym_implements,
  [30574] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4280), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4282), 33,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_of,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_extends,
      anon_sym_implements,
  [30629] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4284), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4286), 33,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_of,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_extends,
      anon_sym_implements,
  [30684] = 5,
    ACTIONS(4118), 1,
      anon_sym_QMARK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4120), 2,
      anon_sym_RPAREN,
      anon_sym_extends,
    ACTIONS(4288), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4290), 30,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_implements,
  [30743] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4284), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4286), 33,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_of,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_extends,
      anon_sym_implements,
  [30798] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3423), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(3425), 33,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_of,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_extends,
      anon_sym_implements,
  [30853] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4284), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4286), 33,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_of,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_extends,
      anon_sym_implements,
  [30908] = 6,
    ACTIONS(4206), 1,
      anon_sym_AMP,
    ACTIONS(4208), 1,
      anon_sym_PIPE,
    ACTIONS(4210), 1,
      anon_sym_extends,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4292), 11,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4294), 32,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_of,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_implements,
  [30969] = 4,
    ACTIONS(4110), 1,
      anon_sym_extends,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4296), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4298), 32,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_of,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_implements,
  [31026] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4300), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4302), 33,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_of,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_extends,
      anon_sym_implements,
  [31081] = 4,
    ACTIONS(4206), 1,
      anon_sym_AMP,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4304), 12,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4306), 33,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_of,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_extends,
      anon_sym_implements,
  [31138] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4308), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4310), 33,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_of,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_extends,
      anon_sym_implements,
  [31193] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4308), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4310), 33,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_of,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_extends,
      anon_sym_implements,
  [31248] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4184), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4182), 33,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_of,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_extends,
      anon_sym_implements,
  [31303] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4312), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4314), 33,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_of,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_extends,
      anon_sym_implements,
  [31358] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4316), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4318), 33,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_of,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_extends,
      anon_sym_implements,
  [31413] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(2379), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(2377), 33,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_of,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_extends,
      anon_sym_implements,
  [31468] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4320), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4322), 33,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_of,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_extends,
      anon_sym_implements,
  [31523] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4324), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4326), 33,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_of,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_extends,
      anon_sym_implements,
  [31578] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4328), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4330), 33,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_of,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_extends,
      anon_sym_implements,
  [31633] = 6,
    ACTIONS(4206), 1,
      anon_sym_AMP,
    ACTIONS(4208), 1,
      anon_sym_PIPE,
    ACTIONS(4210), 1,
      anon_sym_extends,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4332), 11,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4334), 32,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_of,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_implements,
  [31694] = 6,
    ACTIONS(4336), 1,
      anon_sym_LBRACE,
    ACTIONS(4338), 1,
      anon_sym_DOT,
    STATE(1750), 1,
      sym_statement_block,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(1676), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(1674), 30,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_else,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_while,
      anon_sym_LBRACK,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_PIPE_RBRACE,
  [31755] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3427), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(3429), 33,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_of,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_extends,
      anon_sym_implements,
  [31810] = 6,
    ACTIONS(4336), 1,
      anon_sym_LBRACE,
    ACTIONS(4340), 1,
      anon_sym_DOT,
    STATE(1750), 1,
      sym_statement_block,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(1676), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(1674), 30,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_else,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_while,
      anon_sym_LBRACK,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_PIPE_RBRACE,
  [31871] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4342), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4344), 33,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_of,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_extends,
      anon_sym_implements,
  [31926] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4346), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4348), 33,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_of,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_extends,
      anon_sym_implements,
  [31981] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4350), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4352), 33,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_of,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_extends,
      anon_sym_implements,
  [32036] = 5,
    ACTIONS(4336), 1,
      anon_sym_LBRACE,
    STATE(1750), 1,
      sym_statement_block,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(1676), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(1674), 31,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_else,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_while,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_PIPE_RBRACE,
  [32095] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4354), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4356), 33,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_of,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_extends,
      anon_sym_implements,
  [32150] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4358), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4360), 33,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_of,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_extends,
      anon_sym_implements,
  [32205] = 6,
    ACTIONS(4362), 1,
      anon_sym_LBRACE,
    ACTIONS(4364), 1,
      anon_sym_DOT,
    STATE(1712), 1,
      sym_statement_block,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(1676), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(1674), 30,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_of,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_implements,
  [32266] = 6,
    ACTIONS(4362), 1,
      anon_sym_LBRACE,
    ACTIONS(4366), 1,
      anon_sym_DOT,
    STATE(1712), 1,
      sym_statement_block,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(1676), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(1674), 30,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_of,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_implements,
  [32327] = 5,
    ACTIONS(4362), 1,
      anon_sym_LBRACE,
    STATE(1712), 1,
      sym_statement_block,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(1676), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(1674), 31,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_of,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_implements,
  [32386] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(2367), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(2365), 33,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_of,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_extends,
      anon_sym_implements,
  [32441] = 6,
    ACTIONS(4206), 1,
      anon_sym_AMP,
    ACTIONS(4208), 1,
      anon_sym_PIPE,
    ACTIONS(4210), 1,
      anon_sym_extends,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4296), 11,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4298), 32,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_of,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_implements,
  [32502] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4368), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4370), 33,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_of,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_extends,
      anon_sym_implements,
  [32557] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4372), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4374), 33,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_of,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_extends,
      anon_sym_implements,
  [32612] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4376), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4378), 33,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_of,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_extends,
      anon_sym_implements,
  [32667] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4380), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4382), 33,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_of,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_extends,
      anon_sym_implements,
  [32722] = 4,
    ACTIONS(4388), 1,
      anon_sym_DOT,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4384), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4386), 32,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_of,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_extends,
      anon_sym_implements,
  [32779] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4122), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4124), 33,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_of,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_extends,
      anon_sym_implements,
  [32834] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4391), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4393), 33,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_of,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_extends,
      anon_sym_implements,
  [32889] = 5,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    STATE(1685), 1,
      sym_arguments,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4395), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4397), 31,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_of,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_implements,
  [32948] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3691), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(3474), 33,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_of,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_extends,
      anon_sym_implements,
  [33003] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3679), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(3478), 33,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_of,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_extends,
      anon_sym_implements,
  [33058] = 4,
    ACTIONS(4399), 1,
      anon_sym_DOT,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4384), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4386), 32,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_of,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_extends,
      anon_sym_implements,
  [33115] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4402), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4404), 33,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_of,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_extends,
      anon_sym_implements,
  [33170] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4406), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4408), 33,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_of,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_extends,
      anon_sym_implements,
  [33225] = 5,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    STATE(1669), 1,
      sym_arguments,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4410), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4412), 31,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_of,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_implements,
  [33284] = 6,
    ACTIONS(4206), 1,
      anon_sym_AMP,
    ACTIONS(4208), 1,
      anon_sym_PIPE,
    ACTIONS(4210), 1,
      anon_sym_extends,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4402), 11,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4404), 32,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_of,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_implements,
  [33345] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4104), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4106), 33,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_of,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_extends,
      anon_sym_implements,
  [33400] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4380), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4382), 33,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_of,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_extends,
      anon_sym_implements,
  [33455] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4114), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4116), 33,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_of,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_extends,
      anon_sym_implements,
  [33510] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4414), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4416), 33,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_of,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_extends,
      anon_sym_implements,
  [33565] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4418), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4420), 33,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_of,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_extends,
      anon_sym_implements,
  [33620] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4422), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4424), 33,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_of,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_extends,
      anon_sym_implements,
  [33675] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4426), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4428), 33,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_of,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_extends,
      anon_sym_implements,
  [33730] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4430), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4432), 33,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_of,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_extends,
      anon_sym_implements,
  [33785] = 6,
    ACTIONS(4206), 1,
      anon_sym_AMP,
    ACTIONS(4208), 1,
      anon_sym_PIPE,
    ACTIONS(4210), 1,
      anon_sym_extends,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4434), 11,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4436), 32,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_of,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_implements,
  [33846] = 4,
    ACTIONS(4206), 1,
      anon_sym_AMP,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4438), 12,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4440), 33,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_of,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_extends,
      anon_sym_implements,
  [33903] = 6,
    ACTIONS(4206), 1,
      anon_sym_AMP,
    ACTIONS(4208), 1,
      anon_sym_PIPE,
    ACTIONS(4210), 1,
      anon_sym_extends,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4442), 11,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4444), 32,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_of,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_implements,
  [33964] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4446), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4448), 33,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_of,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_extends,
      anon_sym_implements,
  [34019] = 5,
    ACTIONS(4320), 1,
      anon_sym_QMARK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4322), 2,
      anon_sym_RPAREN,
      anon_sym_extends,
    ACTIONS(4288), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4290), 30,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_implements,
  [34078] = 5,
    ACTIONS(820), 1,
      anon_sym_BQUOTE,
    STATE(1657), 1,
      sym_template_string,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(1734), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(1736), 31,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_of,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_satisfies,
      anon_sym_implements,
  [34137] = 6,
    ACTIONS(4172), 1,
      anon_sym_extends,
    ACTIONS(4200), 1,
      anon_sym_LBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4170), 2,
      anon_sym_AMP,
      anon_sym_PIPE,
    ACTIONS(4450), 11,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4452), 31,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_of,
      anon_sym_COLON,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_implements,
  [34198] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4308), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4310), 33,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_of,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_extends,
      anon_sym_implements,
  [34253] = 4,
    ACTIONS(1696), 1,
      anon_sym_EQ,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(1694), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(1698), 31,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_implements,
  [34309] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(1734), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(1736), 32,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_of,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_implements,
  [34363] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4454), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4456), 32,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_of,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_implements,
  [34417] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4458), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4460), 32,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_of,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_implements,
  [34471] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4288), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4290), 32,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_of,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_implements,
  [34525] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4462), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4464), 32,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_of,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_implements,
  [34579] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4288), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4290), 32,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_of,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_implements,
  [34633] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4466), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4468), 32,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_of,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_implements,
  [34687] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4470), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4472), 32,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_of,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_implements,
  [34741] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4474), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4476), 32,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_of,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_implements,
  [34795] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4478), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4480), 32,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_of,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_implements,
  [34849] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(1886), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(1884), 32,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_of,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_implements,
  [34903] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4482), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4484), 32,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_of,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_implements,
  [34957] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4486), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4488), 32,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_of,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_implements,
  [35011] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4490), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4492), 32,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_of,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_implements,
  [35065] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4494), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4496), 32,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_of,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_implements,
  [35119] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4498), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4500), 32,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_of,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_implements,
  [35173] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4502), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4504), 32,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_of,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_implements,
  [35227] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4506), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4508), 32,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_of,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_implements,
  [35281] = 6,
    ACTIONS(4106), 1,
      anon_sym_extends,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4510), 2,
      anon_sym_COMMA,
      anon_sym_LBRACK,
    ACTIONS(4513), 3,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_GT,
    ACTIONS(3492), 10,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(3496), 29,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_implements,
  [35341] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4516), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4518), 32,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_of,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_implements,
  [35395] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4520), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4522), 32,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_of,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_implements,
  [35449] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4524), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4526), 32,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_of,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_implements,
  [35503] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4528), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4530), 32,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_of,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_implements,
  [35557] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4532), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4534), 32,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_of,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_implements,
  [35611] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(1846), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(1848), 32,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_of,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_implements,
  [35665] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4536), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4538), 32,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_of,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_implements,
  [35719] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(1722), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(1720), 32,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_of,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_implements,
  [35773] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4540), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4542), 32,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_of,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_implements,
  [35827] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4544), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4546), 32,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_of,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_implements,
  [35881] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4548), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4550), 32,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_of,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_implements,
  [35935] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4552), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4554), 32,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_of,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_implements,
  [35989] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4556), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4558), 32,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_of,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_implements,
  [36043] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4560), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4562), 32,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_of,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_implements,
  [36097] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4564), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4566), 32,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_of,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_implements,
  [36151] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4568), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4570), 32,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_of,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_implements,
  [36205] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3492), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(3496), 32,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_of,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_implements,
  [36259] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4572), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4574), 32,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_of,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_implements,
  [36313] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4576), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4578), 32,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_of,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_implements,
  [36367] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4580), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4582), 32,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_of,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_implements,
  [36421] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(1794), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(1796), 32,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_of,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_implements,
  [36475] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(1804), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(1806), 32,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_of,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_implements,
  [36529] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(1814), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(1816), 32,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_of,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_implements,
  [36583] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(1710), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(1712), 32,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_of,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_implements,
  [36637] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4584), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4586), 32,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_of,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_implements,
  [36691] = 13,
    ACTIONS(87), 1,
      anon_sym_BQUOTE,
    ACTIONS(4588), 1,
      anon_sym_LPAREN,
    ACTIONS(4590), 1,
      anon_sym_LBRACK,
    ACTIONS(4592), 1,
      anon_sym_DOT,
    ACTIONS(4594), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4596), 1,
      anon_sym_LT,
    STATE(2001), 1,
      sym_type_arguments,
    STATE(2228), 1,
      sym_template_string,
    STATE(2333), 1,
      sym_arguments,
    STATE(4524), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4006), 12,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4008), 23,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_satisfies,
  [36765] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4598), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4600), 32,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_of,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_implements,
  [36819] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(1762), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(1764), 32,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_of,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_implements,
  [36873] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(1774), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(1776), 32,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_of,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_implements,
  [36927] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(1784), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(1786), 32,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_of,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_implements,
  [36981] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(1824), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(1826), 32,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_of,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_implements,
  [37035] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(1834), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(1836), 32,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_of,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_implements,
  [37089] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(1860), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(1862), 32,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_of,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_implements,
  [37143] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(1870), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(1872), 32,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_of,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_implements,
  [37197] = 4,
    ACTIONS(4146), 1,
      anon_sym_EQ,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4144), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4148), 31,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_implements,
  [37253] = 4,
    ACTIONS(4604), 1,
      anon_sym_EQ,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4602), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4606), 31,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_implements,
  [37309] = 6,
    ACTIONS(4408), 1,
      anon_sym_extends,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4608), 2,
      anon_sym_COMMA,
      anon_sym_LBRACK,
    ACTIONS(4611), 3,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_GT,
    ACTIONS(3492), 10,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(3496), 29,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_implements,
  [37369] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(1890), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(1888), 32,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_else,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_while,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_PIPE_RBRACE,
  [37423] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(1894), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(1892), 32,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_else,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_while,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_PIPE_RBRACE,
  [37477] = 6,
    ACTIONS(4378), 1,
      anon_sym_extends,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4614), 2,
      anon_sym_COMMA,
      anon_sym_LBRACK,
    ACTIONS(4617), 3,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_GT,
    ACTIONS(4458), 10,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4460), 29,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_implements,
  [37537] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(1854), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(1852), 32,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_of,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_implements,
  [37591] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(1752), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(1750), 32,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_of,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_implements,
  [37645] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(1880), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(1878), 32,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_of,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_implements,
  [37699] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(1890), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(1888), 32,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_of,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_implements,
  [37753] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(1894), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(1892), 32,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_of,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_implements,
  [37807] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(1718), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(1716), 32,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_of,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_implements,
  [37861] = 19,
    ACTIONS(1626), 1,
      anon_sym_DQUOTE,
    ACTIONS(1628), 1,
      anon_sym_SQUOTE,
    ACTIONS(3722), 1,
      anon_sym_override,
    ACTIONS(3808), 1,
      anon_sym_COMMA,
    ACTIONS(3912), 1,
      anon_sym_RBRACE,
    ACTIONS(4620), 1,
      anon_sym_STAR,
    ACTIONS(4622), 1,
      anon_sym_EQ,
    ACTIONS(4624), 1,
      anon_sym_LBRACK,
    ACTIONS(4626), 1,
      anon_sym_async,
    ACTIONS(4630), 1,
      anon_sym_readonly,
    STATE(2805), 1,
      sym_override_modifier,
    STATE(4792), 1,
      aux_sym_object_repeat1,
    STATE(4815), 1,
      aux_sym_object_pattern_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4628), 2,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(4632), 2,
      anon_sym_get,
      anon_sym_set,
    STATE(3144), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(3814), 7,
      sym__automatic_semicolon,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_QMARK,
      anon_sym_PIPE_RBRACE,
    ACTIONS(3700), 18,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [37947] = 19,
    ACTIONS(1626), 1,
      anon_sym_DQUOTE,
    ACTIONS(1628), 1,
      anon_sym_SQUOTE,
    ACTIONS(3722), 1,
      anon_sym_override,
    ACTIONS(3808), 1,
      anon_sym_COMMA,
    ACTIONS(3925), 1,
      anon_sym_RBRACE,
    ACTIONS(4620), 1,
      anon_sym_STAR,
    ACTIONS(4622), 1,
      anon_sym_EQ,
    ACTIONS(4624), 1,
      anon_sym_LBRACK,
    ACTIONS(4626), 1,
      anon_sym_async,
    ACTIONS(4630), 1,
      anon_sym_readonly,
    STATE(2805), 1,
      sym_override_modifier,
    STATE(4792), 1,
      aux_sym_object_repeat1,
    STATE(4815), 1,
      aux_sym_object_pattern_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4628), 2,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(4632), 2,
      anon_sym_get,
      anon_sym_set,
    STATE(3144), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(3814), 7,
      sym__automatic_semicolon,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_QMARK,
      anon_sym_PIPE_RBRACE,
    ACTIONS(3700), 18,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [38033] = 19,
    ACTIONS(1626), 1,
      anon_sym_DQUOTE,
    ACTIONS(1628), 1,
      anon_sym_SQUOTE,
    ACTIONS(3722), 1,
      anon_sym_override,
    ACTIONS(3808), 1,
      anon_sym_COMMA,
    ACTIONS(3811), 1,
      anon_sym_RBRACE,
    ACTIONS(4620), 1,
      anon_sym_STAR,
    ACTIONS(4622), 1,
      anon_sym_EQ,
    ACTIONS(4624), 1,
      anon_sym_LBRACK,
    ACTIONS(4626), 1,
      anon_sym_async,
    ACTIONS(4630), 1,
      anon_sym_readonly,
    STATE(2805), 1,
      sym_override_modifier,
    STATE(4792), 1,
      aux_sym_object_repeat1,
    STATE(4815), 1,
      aux_sym_object_pattern_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4628), 2,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(4632), 2,
      anon_sym_get,
      anon_sym_set,
    STATE(3144), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(3814), 7,
      sym__automatic_semicolon,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_QMARK,
      anon_sym_PIPE_RBRACE,
    ACTIONS(3700), 18,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [38119] = 19,
    ACTIONS(1626), 1,
      anon_sym_DQUOTE,
    ACTIONS(1628), 1,
      anon_sym_SQUOTE,
    ACTIONS(3722), 1,
      anon_sym_override,
    ACTIONS(3808), 1,
      anon_sym_COMMA,
    ACTIONS(3909), 1,
      anon_sym_RBRACE,
    ACTIONS(4620), 1,
      anon_sym_STAR,
    ACTIONS(4622), 1,
      anon_sym_EQ,
    ACTIONS(4624), 1,
      anon_sym_LBRACK,
    ACTIONS(4626), 1,
      anon_sym_async,
    ACTIONS(4630), 1,
      anon_sym_readonly,
    STATE(2805), 1,
      sym_override_modifier,
    STATE(4792), 1,
      aux_sym_object_repeat1,
    STATE(4815), 1,
      aux_sym_object_pattern_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4628), 2,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(4632), 2,
      anon_sym_get,
      anon_sym_set,
    STATE(3144), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(3814), 7,
      sym__automatic_semicolon,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_QMARK,
      anon_sym_PIPE_RBRACE,
    ACTIONS(3700), 18,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [38205] = 19,
    ACTIONS(1626), 1,
      anon_sym_DQUOTE,
    ACTIONS(1628), 1,
      anon_sym_SQUOTE,
    ACTIONS(3722), 1,
      anon_sym_override,
    ACTIONS(3808), 1,
      anon_sym_COMMA,
    ACTIONS(3906), 1,
      anon_sym_RBRACE,
    ACTIONS(4620), 1,
      anon_sym_STAR,
    ACTIONS(4622), 1,
      anon_sym_EQ,
    ACTIONS(4624), 1,
      anon_sym_LBRACK,
    ACTIONS(4626), 1,
      anon_sym_async,
    ACTIONS(4630), 1,
      anon_sym_readonly,
    STATE(2805), 1,
      sym_override_modifier,
    STATE(4810), 1,
      aux_sym_object_repeat1,
    STATE(4815), 1,
      aux_sym_object_pattern_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4628), 2,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(4632), 2,
      anon_sym_get,
      anon_sym_set,
    STATE(3144), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(3814), 7,
      sym__automatic_semicolon,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_QMARK,
      anon_sym_PIPE_RBRACE,
    ACTIONS(3700), 18,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [38291] = 15,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_as,
    ACTIONS(4640), 1,
      anon_sym_BANG,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4644), 1,
      anon_sym_LT,
    ACTIONS(4649), 1,
      anon_sym_satisfies,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4634), 11,
      anon_sym_STAR,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4638), 20,
      sym__ternary_qmark,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_RBRACK,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_BQUOTE,
  [38368] = 5,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4146), 2,
      anon_sym_EQ,
      anon_sym_QMARK,
    ACTIONS(4651), 5,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_RBRACK,
    ACTIONS(4144), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4148), 24,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_of,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [38425] = 4,
    ACTIONS(4654), 1,
      sym__automatic_semicolon,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(1692), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(1690), 30,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_else,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_while,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_PIPE_RBRACE,
  [38480] = 17,
    ACTIONS(1626), 1,
      anon_sym_DQUOTE,
    ACTIONS(1628), 1,
      anon_sym_SQUOTE,
    ACTIONS(3722), 1,
      anon_sym_override,
    ACTIONS(4624), 1,
      anon_sym_LBRACK,
    ACTIONS(4656), 1,
      anon_sym_STAR,
    ACTIONS(4658), 1,
      anon_sym_LBRACE,
    ACTIONS(4660), 1,
      anon_sym_async,
    ACTIONS(4664), 1,
      anon_sym_readonly,
    ACTIONS(4668), 1,
      sym__automatic_semicolon,
    STATE(2721), 1,
      sym_statement_block,
    STATE(2793), 1,
      sym_override_modifier,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4662), 2,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(4666), 2,
      anon_sym_get,
      anon_sym_set,
    STATE(3082), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(3814), 8,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_BANG,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_QMARK,
    ACTIONS(3700), 18,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [38561] = 5,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4604), 2,
      anon_sym_EQ,
      anon_sym_QMARK,
    ACTIONS(4671), 5,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_RBRACK,
    ACTIONS(4602), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4606), 24,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_of,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [38618] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(1880), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(1878), 31,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_else,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_while,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_PIPE_RBRACE,
  [38671] = 16,
    ACTIONS(1626), 1,
      anon_sym_DQUOTE,
    ACTIONS(1628), 1,
      anon_sym_SQUOTE,
    ACTIONS(3722), 1,
      anon_sym_override,
    ACTIONS(4624), 1,
      anon_sym_LBRACK,
    ACTIONS(4676), 1,
      anon_sym_static,
    ACTIONS(4678), 1,
      anon_sym_readonly,
    ACTIONS(4680), 1,
      anon_sym_abstract,
    ACTIONS(4682), 1,
      anon_sym_accessor,
    STATE(2767), 1,
      sym_accessibility_modifier,
    STATE(2829), 1,
      sym_override_modifier,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4674), 2,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(3720), 3,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
    STATE(3360), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(3814), 9,
      sym__automatic_semicolon,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_BANG,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_QMARK,
    ACTIONS(3700), 17,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [38750] = 4,
    ACTIONS(4684), 1,
      sym__automatic_semicolon,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(1880), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(1878), 30,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_else,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_while,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_PIPE_RBRACE,
  [38805] = 8,
    ACTIONS(4588), 1,
      anon_sym_LPAREN,
    ACTIONS(4596), 1,
      anon_sym_LT,
    ACTIONS(4686), 1,
      anon_sym_DOT,
    STATE(1964), 1,
      sym_arguments,
    STATE(1965), 1,
      sym_type_arguments,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3522), 12,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(3512), 27,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_LBRACK,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_extends,
  [38868] = 15,
    ACTIONS(1550), 1,
      anon_sym_DQUOTE,
    ACTIONS(1552), 1,
      anon_sym_SQUOTE,
    ACTIONS(3808), 1,
      anon_sym_COMMA,
    ACTIONS(3906), 1,
      anon_sym_RBRACE,
    ACTIONS(4620), 1,
      anon_sym_STAR,
    ACTIONS(4622), 1,
      anon_sym_EQ,
    ACTIONS(4688), 1,
      anon_sym_LBRACK,
    STATE(4810), 1,
      aux_sym_object_repeat1,
    STATE(4815), 1,
      aux_sym_object_pattern_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4690), 2,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(4692), 2,
      anon_sym_get,
      anon_sym_set,
    STATE(3866), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(3814), 7,
      sym__automatic_semicolon,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_QMARK,
      anon_sym_PIPE_RBRACE,
    ACTIONS(2351), 21,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [38945] = 7,
    ACTIONS(4596), 1,
      anon_sym_LT,
    ACTIONS(4694), 1,
      anon_sym_DOT,
    ACTIONS(4696), 1,
      anon_sym_is,
    STATE(2031), 1,
      sym_type_arguments,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4054), 12,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(3548), 28,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_LBRACK,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_extends,
  [39006] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(1718), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(1716), 31,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_else,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_while,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_PIPE_RBRACE,
  [39059] = 16,
    ACTIONS(1626), 1,
      anon_sym_DQUOTE,
    ACTIONS(1628), 1,
      anon_sym_SQUOTE,
    ACTIONS(3808), 1,
      anon_sym_COMMA,
    ACTIONS(3906), 1,
      anon_sym_RBRACE,
    ACTIONS(4620), 1,
      anon_sym_STAR,
    ACTIONS(4622), 1,
      anon_sym_EQ,
    ACTIONS(4626), 1,
      anon_sym_async,
    ACTIONS(4698), 1,
      anon_sym_LBRACK,
    STATE(4810), 1,
      aux_sym_object_repeat1,
    STATE(4815), 1,
      aux_sym_object_pattern_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4628), 2,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(4632), 2,
      anon_sym_get,
      anon_sym_set,
    STATE(3144), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(3814), 7,
      sym__automatic_semicolon,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_QMARK,
      anon_sym_PIPE_RBRACE,
    ACTIONS(3700), 20,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [39138] = 8,
    ACTIONS(4588), 1,
      anon_sym_LPAREN,
    ACTIONS(4596), 1,
      anon_sym_LT,
    ACTIONS(4700), 1,
      anon_sym_DOT,
    STATE(1966), 1,
      sym_arguments,
    STATE(1967), 1,
      sym_type_arguments,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4068), 12,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4070), 27,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_LBRACK,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_extends,
  [39201] = 15,
    ACTIONS(1550), 1,
      anon_sym_DQUOTE,
    ACTIONS(1552), 1,
      anon_sym_SQUOTE,
    ACTIONS(3808), 1,
      anon_sym_COMMA,
    ACTIONS(3912), 1,
      anon_sym_RBRACE,
    ACTIONS(4620), 1,
      anon_sym_STAR,
    ACTIONS(4622), 1,
      anon_sym_EQ,
    ACTIONS(4688), 1,
      anon_sym_LBRACK,
    STATE(4792), 1,
      aux_sym_object_repeat1,
    STATE(4815), 1,
      aux_sym_object_pattern_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4690), 2,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(4692), 2,
      anon_sym_get,
      anon_sym_set,
    STATE(3866), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(3814), 7,
      sym__automatic_semicolon,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_QMARK,
      anon_sym_PIPE_RBRACE,
    ACTIONS(2351), 21,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [39278] = 8,
    ACTIONS(4588), 1,
      anon_sym_LPAREN,
    ACTIONS(4596), 1,
      anon_sym_LT,
    ACTIONS(4702), 1,
      anon_sym_DOT,
    STATE(1970), 1,
      sym_arguments,
    STATE(1973), 1,
      sym_type_arguments,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4060), 12,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4062), 27,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_LBRACK,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_extends,
  [39341] = 16,
    ACTIONS(1626), 1,
      anon_sym_DQUOTE,
    ACTIONS(1628), 1,
      anon_sym_SQUOTE,
    ACTIONS(3808), 1,
      anon_sym_COMMA,
    ACTIONS(3912), 1,
      anon_sym_RBRACE,
    ACTIONS(4620), 1,
      anon_sym_STAR,
    ACTIONS(4622), 1,
      anon_sym_EQ,
    ACTIONS(4626), 1,
      anon_sym_async,
    ACTIONS(4698), 1,
      anon_sym_LBRACK,
    STATE(4792), 1,
      aux_sym_object_repeat1,
    STATE(4815), 1,
      aux_sym_object_pattern_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4628), 2,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(4632), 2,
      anon_sym_get,
      anon_sym_set,
    STATE(3144), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(3814), 7,
      sym__automatic_semicolon,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_QMARK,
      anon_sym_PIPE_RBRACE,
    ACTIONS(3700), 20,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [39420] = 8,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4708), 1,
      anon_sym_LT,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4704), 12,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4706), 27,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [39483] = 31,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_as,
    ACTIONS(4640), 1,
      anon_sym_BANG,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4649), 1,
      anon_sym_satisfies,
    ACTIONS(4708), 1,
      anon_sym_LT,
    ACTIONS(4714), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4716), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4718), 1,
      anon_sym_GT_GT,
    ACTIONS(4722), 1,
      anon_sym_AMP,
    ACTIONS(4724), 1,
      anon_sym_CARET,
    ACTIONS(4726), 1,
      anon_sym_PIPE,
    ACTIONS(4730), 1,
      anon_sym_PERCENT,
    ACTIONS(4732), 1,
      anon_sym_STAR_STAR,
    ACTIONS(4740), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(4742), 1,
      sym__ternary_qmark,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4710), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(4712), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(4720), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(4728), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4736), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4738), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(4734), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
    ACTIONS(4468), 6,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_RBRACK,
      anon_sym_BQUOTE,
  [39592] = 31,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_as,
    ACTIONS(4640), 1,
      anon_sym_BANG,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4649), 1,
      anon_sym_satisfies,
    ACTIONS(4708), 1,
      anon_sym_LT,
    ACTIONS(4714), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4716), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4718), 1,
      anon_sym_GT_GT,
    ACTIONS(4722), 1,
      anon_sym_AMP,
    ACTIONS(4724), 1,
      anon_sym_CARET,
    ACTIONS(4726), 1,
      anon_sym_PIPE,
    ACTIONS(4730), 1,
      anon_sym_PERCENT,
    ACTIONS(4732), 1,
      anon_sym_STAR_STAR,
    ACTIONS(4740), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(4742), 1,
      sym__ternary_qmark,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4710), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(4712), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(4720), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(4728), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4736), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4738), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(4734), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
    ACTIONS(4744), 6,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_RBRACK,
      anon_sym_BQUOTE,
  [39701] = 16,
    ACTIONS(1626), 1,
      anon_sym_DQUOTE,
    ACTIONS(1628), 1,
      anon_sym_SQUOTE,
    ACTIONS(3722), 1,
      anon_sym_override,
    ACTIONS(4624), 1,
      anon_sym_LBRACK,
    ACTIONS(4748), 1,
      anon_sym_static,
    ACTIONS(4750), 1,
      anon_sym_readonly,
    ACTIONS(4752), 1,
      anon_sym_abstract,
    ACTIONS(4754), 1,
      anon_sym_accessor,
    STATE(2766), 1,
      sym_accessibility_modifier,
    STATE(2853), 1,
      sym_override_modifier,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4746), 2,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(3720), 3,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
    STATE(3418), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(3814), 9,
      sym__automatic_semicolon,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_BANG,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_QMARK,
    ACTIONS(3700), 17,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [39780] = 31,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_as,
    ACTIONS(4640), 1,
      anon_sym_BANG,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4649), 1,
      anon_sym_satisfies,
    ACTIONS(4708), 1,
      anon_sym_LT,
    ACTIONS(4714), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4716), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4718), 1,
      anon_sym_GT_GT,
    ACTIONS(4722), 1,
      anon_sym_AMP,
    ACTIONS(4724), 1,
      anon_sym_CARET,
    ACTIONS(4726), 1,
      anon_sym_PIPE,
    ACTIONS(4730), 1,
      anon_sym_PERCENT,
    ACTIONS(4732), 1,
      anon_sym_STAR_STAR,
    ACTIONS(4740), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(4742), 1,
      sym__ternary_qmark,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4710), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(4712), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(4720), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(4728), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4736), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4738), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(4734), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
    ACTIONS(4756), 6,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_RBRACK,
      anon_sym_BQUOTE,
  [39889] = 31,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_as,
    ACTIONS(4640), 1,
      anon_sym_BANG,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4649), 1,
      anon_sym_satisfies,
    ACTIONS(4708), 1,
      anon_sym_LT,
    ACTIONS(4714), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4716), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4718), 1,
      anon_sym_GT_GT,
    ACTIONS(4722), 1,
      anon_sym_AMP,
    ACTIONS(4724), 1,
      anon_sym_CARET,
    ACTIONS(4726), 1,
      anon_sym_PIPE,
    ACTIONS(4730), 1,
      anon_sym_PERCENT,
    ACTIONS(4732), 1,
      anon_sym_STAR_STAR,
    ACTIONS(4740), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(4742), 1,
      sym__ternary_qmark,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4710), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(4712), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(4720), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(4728), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4736), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4738), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(4734), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
    ACTIONS(4758), 6,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_RBRACK,
      anon_sym_BQUOTE,
  [39998] = 31,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_as,
    ACTIONS(4640), 1,
      anon_sym_BANG,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4649), 1,
      anon_sym_satisfies,
    ACTIONS(4708), 1,
      anon_sym_LT,
    ACTIONS(4714), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4716), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4718), 1,
      anon_sym_GT_GT,
    ACTIONS(4722), 1,
      anon_sym_AMP,
    ACTIONS(4724), 1,
      anon_sym_CARET,
    ACTIONS(4726), 1,
      anon_sym_PIPE,
    ACTIONS(4730), 1,
      anon_sym_PERCENT,
    ACTIONS(4732), 1,
      anon_sym_STAR_STAR,
    ACTIONS(4740), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(4742), 1,
      sym__ternary_qmark,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4710), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(4712), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(4720), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(4728), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4736), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4738), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(4734), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
    ACTIONS(4504), 6,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_RBRACK,
      anon_sym_BQUOTE,
  [40107] = 18,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4708), 1,
      anon_sym_LT,
    ACTIONS(4718), 1,
      anon_sym_GT_GT,
    ACTIONS(4730), 1,
      anon_sym_PERCENT,
    ACTIONS(4732), 1,
      anon_sym_STAR_STAR,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4710), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(4720), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(4728), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4762), 7,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4760), 18,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_RBRACK,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [40190] = 13,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4732), 1,
      anon_sym_STAR_STAR,
    ACTIONS(4764), 1,
      anon_sym_LT,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4762), 12,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4760), 21,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_RBRACK,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [40263] = 25,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4708), 1,
      anon_sym_LT,
    ACTIONS(4718), 1,
      anon_sym_GT_GT,
    ACTIONS(4722), 1,
      anon_sym_AMP,
    ACTIONS(4724), 1,
      anon_sym_CARET,
    ACTIONS(4726), 1,
      anon_sym_PIPE,
    ACTIONS(4730), 1,
      anon_sym_PERCENT,
    ACTIONS(4732), 1,
      anon_sym_STAR_STAR,
    ACTIONS(4762), 1,
      anon_sym_BANG,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4710), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(4712), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(4720), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(4728), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4736), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4738), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(4734), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
    ACTIONS(4760), 12,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_RBRACK,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [40360] = 26,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4708), 1,
      anon_sym_LT,
    ACTIONS(4714), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4718), 1,
      anon_sym_GT_GT,
    ACTIONS(4722), 1,
      anon_sym_AMP,
    ACTIONS(4724), 1,
      anon_sym_CARET,
    ACTIONS(4726), 1,
      anon_sym_PIPE,
    ACTIONS(4730), 1,
      anon_sym_PERCENT,
    ACTIONS(4732), 1,
      anon_sym_STAR_STAR,
    ACTIONS(4762), 1,
      anon_sym_BANG,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4710), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(4712), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(4720), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(4728), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4736), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4738), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(4734), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
    ACTIONS(4760), 11,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_RBRACK,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [40459] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(1752), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(1750), 31,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_else,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_while,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_PIPE_RBRACE,
  [40512] = 22,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4708), 1,
      anon_sym_LT,
    ACTIONS(4718), 1,
      anon_sym_GT_GT,
    ACTIONS(4730), 1,
      anon_sym_PERCENT,
    ACTIONS(4732), 1,
      anon_sym_STAR_STAR,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4710), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(4712), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(4720), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(4728), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4736), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4738), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(4734), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
    ACTIONS(4762), 3,
      anon_sym_BANG,
      anon_sym_AMP,
      anon_sym_PIPE,
    ACTIONS(4760), 13,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_RBRACK,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_CARET,
      anon_sym_QMARK_QMARK,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [40603] = 23,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4708), 1,
      anon_sym_LT,
    ACTIONS(4718), 1,
      anon_sym_GT_GT,
    ACTIONS(4722), 1,
      anon_sym_AMP,
    ACTIONS(4730), 1,
      anon_sym_PERCENT,
    ACTIONS(4732), 1,
      anon_sym_STAR_STAR,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4710), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(4712), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(4720), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(4728), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4736), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4738), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(4762), 2,
      anon_sym_BANG,
      anon_sym_PIPE,
    ACTIONS(4734), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
    ACTIONS(4760), 13,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_RBRACK,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_CARET,
      anon_sym_QMARK_QMARK,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [40696] = 24,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4708), 1,
      anon_sym_LT,
    ACTIONS(4718), 1,
      anon_sym_GT_GT,
    ACTIONS(4722), 1,
      anon_sym_AMP,
    ACTIONS(4724), 1,
      anon_sym_CARET,
    ACTIONS(4730), 1,
      anon_sym_PERCENT,
    ACTIONS(4732), 1,
      anon_sym_STAR_STAR,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4710), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(4712), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(4720), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(4728), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4736), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4738), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(4762), 2,
      anon_sym_BANG,
      anon_sym_PIPE,
    ACTIONS(4734), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
    ACTIONS(4760), 12,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_RBRACK,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [40791] = 15,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4730), 1,
      anon_sym_PERCENT,
    ACTIONS(4732), 1,
      anon_sym_STAR_STAR,
    ACTIONS(4764), 1,
      anon_sym_LT,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4710), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(4762), 10,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4760), 20,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_RBRACK,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [40868] = 16,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_as,
    ACTIONS(4640), 1,
      anon_sym_BANG,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4649), 1,
      anon_sym_satisfies,
    ACTIONS(4732), 1,
      anon_sym_STAR_STAR,
    ACTIONS(4764), 1,
      anon_sym_LT,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4762), 11,
      anon_sym_STAR,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4760), 19,
      sym__ternary_qmark,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_RBRACK,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_BQUOTE,
  [40947] = 20,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4708), 1,
      anon_sym_LT,
    ACTIONS(4718), 1,
      anon_sym_GT_GT,
    ACTIONS(4730), 1,
      anon_sym_PERCENT,
    ACTIONS(4732), 1,
      anon_sym_STAR_STAR,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4710), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(4712), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(4720), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(4728), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4734), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
    ACTIONS(4762), 5,
      anon_sym_BANG,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4760), 15,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_RBRACK,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_CARET,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [41034] = 27,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4708), 1,
      anon_sym_LT,
    ACTIONS(4714), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4716), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4718), 1,
      anon_sym_GT_GT,
    ACTIONS(4722), 1,
      anon_sym_AMP,
    ACTIONS(4724), 1,
      anon_sym_CARET,
    ACTIONS(4726), 1,
      anon_sym_PIPE,
    ACTIONS(4730), 1,
      anon_sym_PERCENT,
    ACTIONS(4732), 1,
      anon_sym_STAR_STAR,
    ACTIONS(4762), 1,
      anon_sym_BANG,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4710), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(4712), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(4720), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(4728), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4736), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4738), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(4734), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
    ACTIONS(4760), 10,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_RBRACK,
      anon_sym_QMARK_QMARK,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [41135] = 31,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_as,
    ACTIONS(4640), 1,
      anon_sym_BANG,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4649), 1,
      anon_sym_satisfies,
    ACTIONS(4708), 1,
      anon_sym_LT,
    ACTIONS(4714), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4716), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4718), 1,
      anon_sym_GT_GT,
    ACTIONS(4722), 1,
      anon_sym_AMP,
    ACTIONS(4724), 1,
      anon_sym_CARET,
    ACTIONS(4726), 1,
      anon_sym_PIPE,
    ACTIONS(4730), 1,
      anon_sym_PERCENT,
    ACTIONS(4732), 1,
      anon_sym_STAR_STAR,
    ACTIONS(4740), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(4742), 1,
      sym__ternary_qmark,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4710), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(4712), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(4720), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(4728), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4736), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4738), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(4734), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
    ACTIONS(4522), 6,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_RBRACK,
      anon_sym_BQUOTE,
  [41244] = 31,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_as,
    ACTIONS(4640), 1,
      anon_sym_BANG,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4649), 1,
      anon_sym_satisfies,
    ACTIONS(4708), 1,
      anon_sym_LT,
    ACTIONS(4714), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4716), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4718), 1,
      anon_sym_GT_GT,
    ACTIONS(4722), 1,
      anon_sym_AMP,
    ACTIONS(4724), 1,
      anon_sym_CARET,
    ACTIONS(4726), 1,
      anon_sym_PIPE,
    ACTIONS(4730), 1,
      anon_sym_PERCENT,
    ACTIONS(4732), 1,
      anon_sym_STAR_STAR,
    ACTIONS(4740), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(4742), 1,
      sym__ternary_qmark,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4710), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(4712), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(4720), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(4728), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4736), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4738), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(4734), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
    ACTIONS(4767), 6,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_RBRACK,
      anon_sym_BQUOTE,
  [41353] = 31,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_as,
    ACTIONS(4640), 1,
      anon_sym_BANG,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4649), 1,
      anon_sym_satisfies,
    ACTIONS(4708), 1,
      anon_sym_LT,
    ACTIONS(4714), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4716), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4718), 1,
      anon_sym_GT_GT,
    ACTIONS(4722), 1,
      anon_sym_AMP,
    ACTIONS(4724), 1,
      anon_sym_CARET,
    ACTIONS(4726), 1,
      anon_sym_PIPE,
    ACTIONS(4730), 1,
      anon_sym_PERCENT,
    ACTIONS(4732), 1,
      anon_sym_STAR_STAR,
    ACTIONS(4740), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(4742), 1,
      sym__ternary_qmark,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4710), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(4712), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(4720), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(4728), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4736), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4738), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(4734), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
    ACTIONS(4546), 6,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_RBRACK,
      anon_sym_BQUOTE,
  [41462] = 31,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_as,
    ACTIONS(4640), 1,
      anon_sym_BANG,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4649), 1,
      anon_sym_satisfies,
    ACTIONS(4708), 1,
      anon_sym_LT,
    ACTIONS(4714), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4716), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4718), 1,
      anon_sym_GT_GT,
    ACTIONS(4722), 1,
      anon_sym_AMP,
    ACTIONS(4724), 1,
      anon_sym_CARET,
    ACTIONS(4726), 1,
      anon_sym_PIPE,
    ACTIONS(4730), 1,
      anon_sym_PERCENT,
    ACTIONS(4732), 1,
      anon_sym_STAR_STAR,
    ACTIONS(4740), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(4742), 1,
      sym__ternary_qmark,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4710), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(4712), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(4720), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(4728), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4736), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4738), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(4734), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
    ACTIONS(4554), 6,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_RBRACK,
      anon_sym_BQUOTE,
  [41571] = 31,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_as,
    ACTIONS(4640), 1,
      anon_sym_BANG,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4649), 1,
      anon_sym_satisfies,
    ACTIONS(4708), 1,
      anon_sym_LT,
    ACTIONS(4714), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4716), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4718), 1,
      anon_sym_GT_GT,
    ACTIONS(4722), 1,
      anon_sym_AMP,
    ACTIONS(4724), 1,
      anon_sym_CARET,
    ACTIONS(4726), 1,
      anon_sym_PIPE,
    ACTIONS(4730), 1,
      anon_sym_PERCENT,
    ACTIONS(4732), 1,
      anon_sym_STAR_STAR,
    ACTIONS(4740), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(4742), 1,
      sym__ternary_qmark,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4710), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(4712), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(4720), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(4728), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4736), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4738), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(4734), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
    ACTIONS(4558), 6,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_RBRACK,
      anon_sym_BQUOTE,
  [41680] = 31,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_as,
    ACTIONS(4640), 1,
      anon_sym_BANG,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4649), 1,
      anon_sym_satisfies,
    ACTIONS(4708), 1,
      anon_sym_LT,
    ACTIONS(4714), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4716), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4718), 1,
      anon_sym_GT_GT,
    ACTIONS(4722), 1,
      anon_sym_AMP,
    ACTIONS(4724), 1,
      anon_sym_CARET,
    ACTIONS(4726), 1,
      anon_sym_PIPE,
    ACTIONS(4730), 1,
      anon_sym_PERCENT,
    ACTIONS(4732), 1,
      anon_sym_STAR_STAR,
    ACTIONS(4740), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(4742), 1,
      sym__ternary_qmark,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4710), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(4712), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(4720), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(4728), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4736), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4738), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(4734), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
    ACTIONS(4769), 6,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_RBRACK,
      anon_sym_BQUOTE,
  [41789] = 31,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_as,
    ACTIONS(4640), 1,
      anon_sym_BANG,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4649), 1,
      anon_sym_satisfies,
    ACTIONS(4708), 1,
      anon_sym_LT,
    ACTIONS(4714), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4716), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4718), 1,
      anon_sym_GT_GT,
    ACTIONS(4722), 1,
      anon_sym_AMP,
    ACTIONS(4724), 1,
      anon_sym_CARET,
    ACTIONS(4726), 1,
      anon_sym_PIPE,
    ACTIONS(4730), 1,
      anon_sym_PERCENT,
    ACTIONS(4732), 1,
      anon_sym_STAR_STAR,
    ACTIONS(4740), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(4742), 1,
      sym__ternary_qmark,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4710), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(4712), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(4720), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(4728), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4736), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4738), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(4734), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
    ACTIONS(4771), 6,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_RBRACK,
      anon_sym_BQUOTE,
  [41898] = 31,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_as,
    ACTIONS(4640), 1,
      anon_sym_BANG,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4649), 1,
      anon_sym_satisfies,
    ACTIONS(4708), 1,
      anon_sym_LT,
    ACTIONS(4714), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4716), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4718), 1,
      anon_sym_GT_GT,
    ACTIONS(4722), 1,
      anon_sym_AMP,
    ACTIONS(4724), 1,
      anon_sym_CARET,
    ACTIONS(4726), 1,
      anon_sym_PIPE,
    ACTIONS(4730), 1,
      anon_sym_PERCENT,
    ACTIONS(4732), 1,
      anon_sym_STAR_STAR,
    ACTIONS(4740), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(4742), 1,
      sym__ternary_qmark,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4710), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(4712), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(4720), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(4728), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4736), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4738), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(4734), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
    ACTIONS(4773), 6,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_RBRACK,
      anon_sym_BQUOTE,
  [42007] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(1722), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(1720), 31,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_else,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_while,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_PIPE_RBRACE,
  [42060] = 15,
    ACTIONS(1550), 1,
      anon_sym_DQUOTE,
    ACTIONS(1552), 1,
      anon_sym_SQUOTE,
    ACTIONS(3808), 1,
      anon_sym_COMMA,
    ACTIONS(3925), 1,
      anon_sym_RBRACE,
    ACTIONS(4620), 1,
      anon_sym_STAR,
    ACTIONS(4622), 1,
      anon_sym_EQ,
    ACTIONS(4688), 1,
      anon_sym_LBRACK,
    STATE(4792), 1,
      aux_sym_object_repeat1,
    STATE(4815), 1,
      aux_sym_object_pattern_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4690), 2,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(4692), 2,
      anon_sym_get,
      anon_sym_set,
    STATE(3866), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(3814), 7,
      sym__automatic_semicolon,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_QMARK,
      anon_sym_PIPE_RBRACE,
    ACTIONS(2351), 21,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [42137] = 5,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(1696), 2,
      anon_sym_EQ,
      anon_sym_QMARK,
    ACTIONS(4775), 5,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_RBRACK,
    ACTIONS(1694), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(1698), 24,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_of,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [42194] = 16,
    ACTIONS(1626), 1,
      anon_sym_DQUOTE,
    ACTIONS(1628), 1,
      anon_sym_SQUOTE,
    ACTIONS(3808), 1,
      anon_sym_COMMA,
    ACTIONS(3925), 1,
      anon_sym_RBRACE,
    ACTIONS(4620), 1,
      anon_sym_STAR,
    ACTIONS(4622), 1,
      anon_sym_EQ,
    ACTIONS(4626), 1,
      anon_sym_async,
    ACTIONS(4698), 1,
      anon_sym_LBRACK,
    STATE(4792), 1,
      aux_sym_object_repeat1,
    STATE(4815), 1,
      aux_sym_object_pattern_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4628), 2,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(4632), 2,
      anon_sym_get,
      anon_sym_set,
    STATE(3144), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(3814), 7,
      sym__automatic_semicolon,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_QMARK,
      anon_sym_PIPE_RBRACE,
    ACTIONS(3700), 20,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [42273] = 15,
    ACTIONS(1550), 1,
      anon_sym_DQUOTE,
    ACTIONS(1552), 1,
      anon_sym_SQUOTE,
    ACTIONS(3808), 1,
      anon_sym_COMMA,
    ACTIONS(3811), 1,
      anon_sym_RBRACE,
    ACTIONS(4620), 1,
      anon_sym_STAR,
    ACTIONS(4622), 1,
      anon_sym_EQ,
    ACTIONS(4688), 1,
      anon_sym_LBRACK,
    STATE(4792), 1,
      aux_sym_object_repeat1,
    STATE(4815), 1,
      aux_sym_object_pattern_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4690), 2,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(4692), 2,
      anon_sym_get,
      anon_sym_set,
    STATE(3866), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(3814), 7,
      sym__automatic_semicolon,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_QMARK,
      anon_sym_PIPE_RBRACE,
    ACTIONS(2351), 21,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [42350] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(1854), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(1852), 31,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_else,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_while,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_PIPE_RBRACE,
  [42403] = 16,
    ACTIONS(1626), 1,
      anon_sym_DQUOTE,
    ACTIONS(1628), 1,
      anon_sym_SQUOTE,
    ACTIONS(3808), 1,
      anon_sym_COMMA,
    ACTIONS(3811), 1,
      anon_sym_RBRACE,
    ACTIONS(4620), 1,
      anon_sym_STAR,
    ACTIONS(4622), 1,
      anon_sym_EQ,
    ACTIONS(4626), 1,
      anon_sym_async,
    ACTIONS(4698), 1,
      anon_sym_LBRACK,
    STATE(4792), 1,
      aux_sym_object_repeat1,
    STATE(4815), 1,
      aux_sym_object_pattern_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4628), 2,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(4632), 2,
      anon_sym_get,
      anon_sym_set,
    STATE(3144), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(3814), 7,
      sym__automatic_semicolon,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_QMARK,
      anon_sym_PIPE_RBRACE,
    ACTIONS(3700), 20,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [42482] = 15,
    ACTIONS(1550), 1,
      anon_sym_DQUOTE,
    ACTIONS(1552), 1,
      anon_sym_SQUOTE,
    ACTIONS(3808), 1,
      anon_sym_COMMA,
    ACTIONS(3909), 1,
      anon_sym_RBRACE,
    ACTIONS(4620), 1,
      anon_sym_STAR,
    ACTIONS(4622), 1,
      anon_sym_EQ,
    ACTIONS(4688), 1,
      anon_sym_LBRACK,
    STATE(4792), 1,
      aux_sym_object_repeat1,
    STATE(4815), 1,
      aux_sym_object_pattern_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4690), 2,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(4692), 2,
      anon_sym_get,
      anon_sym_set,
    STATE(3866), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(3814), 7,
      sym__automatic_semicolon,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_QMARK,
      anon_sym_PIPE_RBRACE,
    ACTIONS(2351), 21,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [42559] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(1886), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(1884), 31,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_else,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_while,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_PIPE_RBRACE,
  [42612] = 16,
    ACTIONS(1626), 1,
      anon_sym_DQUOTE,
    ACTIONS(1628), 1,
      anon_sym_SQUOTE,
    ACTIONS(3808), 1,
      anon_sym_COMMA,
    ACTIONS(3909), 1,
      anon_sym_RBRACE,
    ACTIONS(4620), 1,
      anon_sym_STAR,
    ACTIONS(4622), 1,
      anon_sym_EQ,
    ACTIONS(4626), 1,
      anon_sym_async,
    ACTIONS(4698), 1,
      anon_sym_LBRACK,
    STATE(4792), 1,
      aux_sym_object_repeat1,
    STATE(4815), 1,
      aux_sym_object_pattern_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4628), 2,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(4632), 2,
      anon_sym_get,
      anon_sym_set,
    STATE(3144), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(3814), 7,
      sym__automatic_semicolon,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_QMARK,
      anon_sym_PIPE_RBRACE,
    ACTIONS(3700), 20,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [42691] = 12,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4782), 1,
      anon_sym_LT,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4778), 12,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4780), 22,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_RBRACK,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [42762] = 11,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4789), 1,
      anon_sym_LT,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4785), 12,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4787), 24,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_RBRACK,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [42831] = 31,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_as,
    ACTIONS(4640), 1,
      anon_sym_BANG,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4649), 1,
      anon_sym_satisfies,
    ACTIONS(4708), 1,
      anon_sym_LT,
    ACTIONS(4714), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4716), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4718), 1,
      anon_sym_GT_GT,
    ACTIONS(4722), 1,
      anon_sym_AMP,
    ACTIONS(4724), 1,
      anon_sym_CARET,
    ACTIONS(4726), 1,
      anon_sym_PIPE,
    ACTIONS(4730), 1,
      anon_sym_PERCENT,
    ACTIONS(4732), 1,
      anon_sym_STAR_STAR,
    ACTIONS(4740), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(4742), 1,
      sym__ternary_qmark,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4710), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(4712), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(4720), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(4728), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4736), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4738), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(4734), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
    ACTIONS(4792), 6,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_RBRACK,
      anon_sym_BQUOTE,
  [42940] = 16,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4730), 1,
      anon_sym_PERCENT,
    ACTIONS(4732), 1,
      anon_sym_STAR_STAR,
    ACTIONS(4764), 1,
      anon_sym_LT,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4710), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(4728), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4762), 8,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4760), 20,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_RBRACK,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [43019] = 4,
    ACTIONS(4696), 1,
      anon_sym_is,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4114), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4116), 29,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_extends,
  [43073] = 6,
    ACTIONS(4588), 1,
      anon_sym_LPAREN,
    ACTIONS(4794), 1,
      anon_sym_DOT,
    STATE(2067), 1,
      sym_arguments,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4078), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4080), 27,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_LBRACK,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_extends,
  [43131] = 31,
    ACTIONS(4588), 1,
      anon_sym_LPAREN,
    ACTIONS(4590), 1,
      anon_sym_LBRACK,
    ACTIONS(4592), 1,
      anon_sym_DOT,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4798), 1,
      anon_sym_as,
    ACTIONS(4800), 1,
      anon_sym_BANG,
    ACTIONS(4804), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4806), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4808), 1,
      anon_sym_GT_GT,
    ACTIONS(4812), 1,
      anon_sym_AMP,
    ACTIONS(4814), 1,
      anon_sym_CARET,
    ACTIONS(4816), 1,
      anon_sym_PIPE,
    ACTIONS(4820), 1,
      anon_sym_PERCENT,
    ACTIONS(4822), 1,
      anon_sym_STAR_STAR,
    ACTIONS(4824), 1,
      anon_sym_LT,
    ACTIONS(4832), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(4836), 1,
      anon_sym_satisfies,
    ACTIONS(4838), 1,
      sym__ternary_qmark,
    STATE(2019), 1,
      sym_type_arguments,
    STATE(2130), 1,
      sym_arguments,
    STATE(4524), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4796), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(4802), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(4810), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(4818), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4828), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4830), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(4834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4826), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
    ACTIONS(4756), 5,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_BQUOTE,
  [43239] = 13,
    ACTIONS(1550), 1,
      anon_sym_DQUOTE,
    ACTIONS(1552), 1,
      anon_sym_SQUOTE,
    ACTIONS(3808), 1,
      anon_sym_COMMA,
    ACTIONS(3912), 1,
      anon_sym_RBRACE,
    ACTIONS(4622), 1,
      anon_sym_EQ,
    ACTIONS(4688), 1,
      anon_sym_LBRACK,
    STATE(4792), 1,
      aux_sym_object_repeat1,
    STATE(4815), 1,
      aux_sym_object_pattern_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4690), 2,
      sym_number,
      sym_private_property_identifier,
    STATE(3866), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(3814), 7,
      sym__automatic_semicolon,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_QMARK,
      anon_sym_PIPE_RBRACE,
    ACTIONS(2351), 23,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [43311] = 14,
    ACTIONS(1626), 1,
      anon_sym_DQUOTE,
    ACTIONS(1628), 1,
      anon_sym_SQUOTE,
    ACTIONS(3722), 1,
      anon_sym_override,
    ACTIONS(4624), 1,
      anon_sym_LBRACK,
    ACTIONS(4842), 1,
      anon_sym_static,
    ACTIONS(4844), 1,
      anon_sym_readonly,
    ACTIONS(4846), 1,
      anon_sym_abstract,
    ACTIONS(4848), 1,
      anon_sym_accessor,
    STATE(2814), 1,
      sym_override_modifier,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4840), 2,
      sym_number,
      sym_private_property_identifier,
    STATE(3368), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(3814), 9,
      sym__automatic_semicolon,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_BANG,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_QMARK,
    ACTIONS(3700), 20,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [43385] = 7,
    ACTIONS(1696), 1,
      anon_sym_EQ,
    ACTIONS(2373), 1,
      anon_sym_extends,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4126), 2,
      anon_sym_COMMA,
      anon_sym_LBRACK,
    ACTIONS(4129), 3,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_GT,
    ACTIONS(1694), 10,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1698), 26,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [43445] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4084), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4086), 30,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_extends,
      anon_sym_is,
  [43497] = 6,
    ACTIONS(3617), 1,
      anon_sym_QMARK,
    ACTIONS(3619), 1,
      anon_sym_EQ,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3622), 5,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_RBRACK,
    ACTIONS(3492), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(3496), 23,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [43555] = 6,
    ACTIONS(4596), 1,
      anon_sym_LT,
    ACTIONS(4694), 1,
      anon_sym_DOT,
    STATE(2031), 1,
      sym_type_arguments,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4054), 12,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(3548), 28,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_LBRACK,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_extends,
  [43613] = 31,
    ACTIONS(4588), 1,
      anon_sym_LPAREN,
    ACTIONS(4590), 1,
      anon_sym_LBRACK,
    ACTIONS(4592), 1,
      anon_sym_DOT,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4798), 1,
      anon_sym_as,
    ACTIONS(4800), 1,
      anon_sym_BANG,
    ACTIONS(4804), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4806), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4808), 1,
      anon_sym_GT_GT,
    ACTIONS(4812), 1,
      anon_sym_AMP,
    ACTIONS(4814), 1,
      anon_sym_CARET,
    ACTIONS(4816), 1,
      anon_sym_PIPE,
    ACTIONS(4820), 1,
      anon_sym_PERCENT,
    ACTIONS(4822), 1,
      anon_sym_STAR_STAR,
    ACTIONS(4824), 1,
      anon_sym_LT,
    ACTIONS(4832), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(4836), 1,
      anon_sym_satisfies,
    ACTIONS(4838), 1,
      sym__ternary_qmark,
    STATE(2019), 1,
      sym_type_arguments,
    STATE(2130), 1,
      sym_arguments,
    STATE(4524), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4796), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(4802), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(4810), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(4818), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4828), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4830), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(4834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4826), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
    ACTIONS(4758), 5,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_BQUOTE,
  [43721] = 31,
    ACTIONS(4588), 1,
      anon_sym_LPAREN,
    ACTIONS(4590), 1,
      anon_sym_LBRACK,
    ACTIONS(4592), 1,
      anon_sym_DOT,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4798), 1,
      anon_sym_as,
    ACTIONS(4800), 1,
      anon_sym_BANG,
    ACTIONS(4804), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4806), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4808), 1,
      anon_sym_GT_GT,
    ACTIONS(4812), 1,
      anon_sym_AMP,
    ACTIONS(4814), 1,
      anon_sym_CARET,
    ACTIONS(4816), 1,
      anon_sym_PIPE,
    ACTIONS(4820), 1,
      anon_sym_PERCENT,
    ACTIONS(4822), 1,
      anon_sym_STAR_STAR,
    ACTIONS(4824), 1,
      anon_sym_LT,
    ACTIONS(4832), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(4836), 1,
      anon_sym_satisfies,
    ACTIONS(4838), 1,
      sym__ternary_qmark,
    STATE(2019), 1,
      sym_type_arguments,
    STATE(2130), 1,
      sym_arguments,
    STATE(4524), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4796), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(4802), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(4810), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(4818), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4828), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4830), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(4834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4826), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
    ACTIONS(4504), 5,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_BQUOTE,
  [43829] = 18,
    ACTIONS(4588), 1,
      anon_sym_LPAREN,
    ACTIONS(4590), 1,
      anon_sym_LBRACK,
    ACTIONS(4592), 1,
      anon_sym_DOT,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4808), 1,
      anon_sym_GT_GT,
    ACTIONS(4820), 1,
      anon_sym_PERCENT,
    ACTIONS(4822), 1,
      anon_sym_STAR_STAR,
    ACTIONS(4824), 1,
      anon_sym_LT,
    STATE(2019), 1,
      sym_type_arguments,
    STATE(2130), 1,
      sym_arguments,
    STATE(4524), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4796), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(4810), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(4818), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4762), 7,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4760), 17,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [43911] = 13,
    ACTIONS(1550), 1,
      anon_sym_DQUOTE,
    ACTIONS(1552), 1,
      anon_sym_SQUOTE,
    ACTIONS(3808), 1,
      anon_sym_COMMA,
    ACTIONS(3906), 1,
      anon_sym_RBRACE,
    ACTIONS(4622), 1,
      anon_sym_EQ,
    ACTIONS(4688), 1,
      anon_sym_LBRACK,
    STATE(4810), 1,
      aux_sym_object_repeat1,
    STATE(4815), 1,
      aux_sym_object_pattern_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4690), 2,
      sym_number,
      sym_private_property_identifier,
    STATE(3866), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(3814), 7,
      sym__automatic_semicolon,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_QMARK,
      anon_sym_PIPE_RBRACE,
    ACTIONS(2351), 23,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [43983] = 5,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4146), 2,
      anon_sym_EQ,
      anon_sym_QMARK,
    ACTIONS(4850), 5,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_RBRACK,
    ACTIONS(4144), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4148), 23,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [44039] = 31,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_as,
    ACTIONS(4640), 1,
      anon_sym_BANG,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4649), 1,
      anon_sym_satisfies,
    ACTIONS(4708), 1,
      anon_sym_LT,
    ACTIONS(4714), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4716), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4718), 1,
      anon_sym_GT_GT,
    ACTIONS(4722), 1,
      anon_sym_AMP,
    ACTIONS(4724), 1,
      anon_sym_CARET,
    ACTIONS(4726), 1,
      anon_sym_PIPE,
    ACTIONS(4730), 1,
      anon_sym_PERCENT,
    ACTIONS(4732), 1,
      anon_sym_STAR_STAR,
    ACTIONS(4740), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(4742), 1,
      sym__ternary_qmark,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4710), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(4712), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(4720), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(4728), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4736), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4738), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(4734), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
    ACTIONS(4852), 5,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_RBRACK,
  [44147] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3225), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(3227), 30,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_extends,
      anon_sym_PIPE_RBRACE,
  [44199] = 7,
    ACTIONS(4146), 1,
      anon_sym_EQ,
    ACTIONS(4156), 1,
      anon_sym_extends,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4150), 2,
      anon_sym_COMMA,
      anon_sym_LBRACK,
    ACTIONS(4153), 3,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_GT,
    ACTIONS(4144), 10,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4148), 26,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [44259] = 5,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4604), 2,
      anon_sym_EQ,
      anon_sym_QMARK,
    ACTIONS(4854), 5,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_RBRACK,
    ACTIONS(4602), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4606), 23,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [44315] = 15,
    ACTIONS(4588), 1,
      anon_sym_LPAREN,
    ACTIONS(4590), 1,
      anon_sym_LBRACK,
    ACTIONS(4592), 1,
      anon_sym_DOT,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4798), 1,
      anon_sym_as,
    ACTIONS(4800), 1,
      anon_sym_BANG,
    ACTIONS(4836), 1,
      anon_sym_satisfies,
    ACTIONS(4856), 1,
      anon_sym_LT,
    STATE(2019), 1,
      sym_type_arguments,
    STATE(2130), 1,
      sym_arguments,
    STATE(4524), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4634), 11,
      anon_sym_STAR,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4638), 19,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_BQUOTE,
  [44391] = 5,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(1696), 2,
      anon_sym_EQ,
      anon_sym_QMARK,
    ACTIONS(4859), 5,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_RBRACK,
    ACTIONS(1694), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(1698), 23,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [44447] = 13,
    ACTIONS(4588), 1,
      anon_sym_LPAREN,
    ACTIONS(4590), 1,
      anon_sym_LBRACK,
    ACTIONS(4592), 1,
      anon_sym_DOT,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4822), 1,
      anon_sym_STAR_STAR,
    ACTIONS(4861), 1,
      anon_sym_LT,
    STATE(2019), 1,
      sym_type_arguments,
    STATE(2130), 1,
      sym_arguments,
    STATE(4524), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4762), 12,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4760), 20,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [44519] = 7,
    ACTIONS(3550), 1,
      anon_sym_EQ,
    ACTIONS(4608), 1,
      anon_sym_LBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4611), 2,
      anon_sym_AMP,
      anon_sym_PIPE,
    ACTIONS(4408), 6,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_extends,
      anon_sym_PIPE_RBRACE,
    ACTIONS(3492), 11,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(3496), 22,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [44579] = 25,
    ACTIONS(4588), 1,
      anon_sym_LPAREN,
    ACTIONS(4590), 1,
      anon_sym_LBRACK,
    ACTIONS(4592), 1,
      anon_sym_DOT,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4762), 1,
      anon_sym_BANG,
    ACTIONS(4808), 1,
      anon_sym_GT_GT,
    ACTIONS(4812), 1,
      anon_sym_AMP,
    ACTIONS(4814), 1,
      anon_sym_CARET,
    ACTIONS(4816), 1,
      anon_sym_PIPE,
    ACTIONS(4820), 1,
      anon_sym_PERCENT,
    ACTIONS(4822), 1,
      anon_sym_STAR_STAR,
    ACTIONS(4824), 1,
      anon_sym_LT,
    STATE(2019), 1,
      sym_type_arguments,
    STATE(2130), 1,
      sym_arguments,
    STATE(4524), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4796), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(4802), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(4810), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(4818), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4828), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4830), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(4834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4826), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
    ACTIONS(4760), 11,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [44675] = 26,
    ACTIONS(4588), 1,
      anon_sym_LPAREN,
    ACTIONS(4590), 1,
      anon_sym_LBRACK,
    ACTIONS(4592), 1,
      anon_sym_DOT,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4762), 1,
      anon_sym_BANG,
    ACTIONS(4804), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4808), 1,
      anon_sym_GT_GT,
    ACTIONS(4812), 1,
      anon_sym_AMP,
    ACTIONS(4814), 1,
      anon_sym_CARET,
    ACTIONS(4816), 1,
      anon_sym_PIPE,
    ACTIONS(4820), 1,
      anon_sym_PERCENT,
    ACTIONS(4822), 1,
      anon_sym_STAR_STAR,
    ACTIONS(4824), 1,
      anon_sym_LT,
    STATE(2019), 1,
      sym_type_arguments,
    STATE(2130), 1,
      sym_arguments,
    STATE(4524), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4796), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(4802), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(4810), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(4818), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4828), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4830), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(4834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4826), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
    ACTIONS(4760), 10,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [44773] = 16,
    ACTIONS(4588), 1,
      anon_sym_LPAREN,
    ACTIONS(4590), 1,
      anon_sym_LBRACK,
    ACTIONS(4592), 1,
      anon_sym_DOT,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4820), 1,
      anon_sym_PERCENT,
    ACTIONS(4822), 1,
      anon_sym_STAR_STAR,
    ACTIONS(4861), 1,
      anon_sym_LT,
    STATE(2019), 1,
      sym_type_arguments,
    STATE(2130), 1,
      sym_arguments,
    STATE(4524), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4796), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(4818), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4762), 8,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4760), 19,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [44851] = 22,
    ACTIONS(4588), 1,
      anon_sym_LPAREN,
    ACTIONS(4590), 1,
      anon_sym_LBRACK,
    ACTIONS(4592), 1,
      anon_sym_DOT,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4808), 1,
      anon_sym_GT_GT,
    ACTIONS(4820), 1,
      anon_sym_PERCENT,
    ACTIONS(4822), 1,
      anon_sym_STAR_STAR,
    ACTIONS(4824), 1,
      anon_sym_LT,
    STATE(2019), 1,
      sym_type_arguments,
    STATE(2130), 1,
      sym_arguments,
    STATE(4524), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4796), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(4802), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(4810), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(4818), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4828), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4830), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(4834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4762), 3,
      anon_sym_BANG,
      anon_sym_AMP,
      anon_sym_PIPE,
    ACTIONS(4826), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
    ACTIONS(4760), 12,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_CARET,
      anon_sym_QMARK_QMARK,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [44941] = 23,
    ACTIONS(4588), 1,
      anon_sym_LPAREN,
    ACTIONS(4590), 1,
      anon_sym_LBRACK,
    ACTIONS(4592), 1,
      anon_sym_DOT,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4808), 1,
      anon_sym_GT_GT,
    ACTIONS(4812), 1,
      anon_sym_AMP,
    ACTIONS(4820), 1,
      anon_sym_PERCENT,
    ACTIONS(4822), 1,
      anon_sym_STAR_STAR,
    ACTIONS(4824), 1,
      anon_sym_LT,
    STATE(2019), 1,
      sym_type_arguments,
    STATE(2130), 1,
      sym_arguments,
    STATE(4524), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4762), 2,
      anon_sym_BANG,
      anon_sym_PIPE,
    ACTIONS(4796), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(4802), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(4810), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(4818), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4828), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4830), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(4834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4826), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
    ACTIONS(4760), 12,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_CARET,
      anon_sym_QMARK_QMARK,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [45033] = 24,
    ACTIONS(4588), 1,
      anon_sym_LPAREN,
    ACTIONS(4590), 1,
      anon_sym_LBRACK,
    ACTIONS(4592), 1,
      anon_sym_DOT,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4808), 1,
      anon_sym_GT_GT,
    ACTIONS(4812), 1,
      anon_sym_AMP,
    ACTIONS(4814), 1,
      anon_sym_CARET,
    ACTIONS(4820), 1,
      anon_sym_PERCENT,
    ACTIONS(4822), 1,
      anon_sym_STAR_STAR,
    ACTIONS(4824), 1,
      anon_sym_LT,
    STATE(2019), 1,
      sym_type_arguments,
    STATE(2130), 1,
      sym_arguments,
    STATE(4524), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4762), 2,
      anon_sym_BANG,
      anon_sym_PIPE,
    ACTIONS(4796), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(4802), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(4810), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(4818), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4828), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4830), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(4834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4826), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
    ACTIONS(4760), 11,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [45127] = 15,
    ACTIONS(4588), 1,
      anon_sym_LPAREN,
    ACTIONS(4590), 1,
      anon_sym_LBRACK,
    ACTIONS(4592), 1,
      anon_sym_DOT,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4820), 1,
      anon_sym_PERCENT,
    ACTIONS(4822), 1,
      anon_sym_STAR_STAR,
    ACTIONS(4861), 1,
      anon_sym_LT,
    STATE(2019), 1,
      sym_type_arguments,
    STATE(2130), 1,
      sym_arguments,
    STATE(4524), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4796), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(4834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4762), 10,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4760), 19,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [45203] = 16,
    ACTIONS(4588), 1,
      anon_sym_LPAREN,
    ACTIONS(4590), 1,
      anon_sym_LBRACK,
    ACTIONS(4592), 1,
      anon_sym_DOT,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4798), 1,
      anon_sym_as,
    ACTIONS(4800), 1,
      anon_sym_BANG,
    ACTIONS(4822), 1,
      anon_sym_STAR_STAR,
    ACTIONS(4836), 1,
      anon_sym_satisfies,
    ACTIONS(4861), 1,
      anon_sym_LT,
    STATE(2019), 1,
      sym_type_arguments,
    STATE(2130), 1,
      sym_arguments,
    STATE(4524), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4762), 11,
      anon_sym_STAR,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4760), 18,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_BQUOTE,
  [45281] = 9,
    ACTIONS(87), 1,
      anon_sym_BQUOTE,
    ACTIONS(4590), 1,
      anon_sym_LBRACK,
    ACTIONS(4592), 1,
      anon_sym_DOT,
    ACTIONS(4594), 1,
      anon_sym_QMARK_DOT,
    STATE(2228), 1,
      sym_template_string,
    STATE(4524), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(1734), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(1736), 24,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_satisfies,
  [45345] = 20,
    ACTIONS(4588), 1,
      anon_sym_LPAREN,
    ACTIONS(4590), 1,
      anon_sym_LBRACK,
    ACTIONS(4592), 1,
      anon_sym_DOT,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4808), 1,
      anon_sym_GT_GT,
    ACTIONS(4820), 1,
      anon_sym_PERCENT,
    ACTIONS(4822), 1,
      anon_sym_STAR_STAR,
    ACTIONS(4824), 1,
      anon_sym_LT,
    STATE(2019), 1,
      sym_type_arguments,
    STATE(2130), 1,
      sym_arguments,
    STATE(4524), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4796), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(4802), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(4810), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(4818), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4826), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
    ACTIONS(4762), 5,
      anon_sym_BANG,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4760), 14,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_CARET,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [45431] = 27,
    ACTIONS(4588), 1,
      anon_sym_LPAREN,
    ACTIONS(4590), 1,
      anon_sym_LBRACK,
    ACTIONS(4592), 1,
      anon_sym_DOT,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4762), 1,
      anon_sym_BANG,
    ACTIONS(4804), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4806), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4808), 1,
      anon_sym_GT_GT,
    ACTIONS(4812), 1,
      anon_sym_AMP,
    ACTIONS(4814), 1,
      anon_sym_CARET,
    ACTIONS(4816), 1,
      anon_sym_PIPE,
    ACTIONS(4820), 1,
      anon_sym_PERCENT,
    ACTIONS(4822), 1,
      anon_sym_STAR_STAR,
    ACTIONS(4824), 1,
      anon_sym_LT,
    STATE(2019), 1,
      sym_type_arguments,
    STATE(2130), 1,
      sym_arguments,
    STATE(4524), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4796), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(4802), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(4810), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(4818), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4828), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4830), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(4834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4826), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
    ACTIONS(4760), 9,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_QMARK_QMARK,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [45531] = 6,
    ACTIONS(3494), 1,
      anon_sym_EQ,
    ACTIONS(3590), 1,
      anon_sym_QMARK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3586), 5,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_RBRACK,
    ACTIONS(3492), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(3496), 23,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [45589] = 12,
    ACTIONS(4588), 1,
      anon_sym_LPAREN,
    ACTIONS(4590), 1,
      anon_sym_LBRACK,
    ACTIONS(4592), 1,
      anon_sym_DOT,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4864), 1,
      anon_sym_LT,
    STATE(2019), 1,
      sym_type_arguments,
    STATE(2130), 1,
      sym_arguments,
    STATE(4524), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4778), 12,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4780), 21,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [45659] = 31,
    ACTIONS(4588), 1,
      anon_sym_LPAREN,
    ACTIONS(4590), 1,
      anon_sym_LBRACK,
    ACTIONS(4592), 1,
      anon_sym_DOT,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4798), 1,
      anon_sym_as,
    ACTIONS(4800), 1,
      anon_sym_BANG,
    ACTIONS(4804), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4806), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4808), 1,
      anon_sym_GT_GT,
    ACTIONS(4812), 1,
      anon_sym_AMP,
    ACTIONS(4814), 1,
      anon_sym_CARET,
    ACTIONS(4816), 1,
      anon_sym_PIPE,
    ACTIONS(4820), 1,
      anon_sym_PERCENT,
    ACTIONS(4822), 1,
      anon_sym_STAR_STAR,
    ACTIONS(4824), 1,
      anon_sym_LT,
    ACTIONS(4832), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(4836), 1,
      anon_sym_satisfies,
    ACTIONS(4838), 1,
      sym__ternary_qmark,
    STATE(2019), 1,
      sym_type_arguments,
    STATE(2130), 1,
      sym_arguments,
    STATE(4524), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4796), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(4802), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(4810), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(4818), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4828), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4830), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(4834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4826), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
    ACTIONS(4546), 5,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_BQUOTE,
  [45767] = 35,
    ACTIONS(3557), 1,
      anon_sym_COLON,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_as,
    ACTIONS(4640), 1,
      anon_sym_BANG,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4649), 1,
      anon_sym_satisfies,
    ACTIONS(4869), 1,
      anon_sym_COMMA,
    ACTIONS(4871), 1,
      anon_sym_RPAREN,
    ACTIONS(4875), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4877), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4879), 1,
      anon_sym_GT_GT,
    ACTIONS(4883), 1,
      anon_sym_AMP,
    ACTIONS(4885), 1,
      anon_sym_CARET,
    ACTIONS(4887), 1,
      anon_sym_PIPE,
    ACTIONS(4891), 1,
      anon_sym_PERCENT,
    ACTIONS(4893), 1,
      anon_sym_STAR_STAR,
    ACTIONS(4895), 1,
      anon_sym_LT,
    ACTIONS(4903), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(4905), 1,
      sym__ternary_qmark,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    STATE(5026), 1,
      aux_sym_sequence_expression_repeat1,
    STATE(5470), 1,
      sym_type_annotation,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4867), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(4873), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(4881), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(4889), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4899), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4901), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(4897), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [45883] = 31,
    ACTIONS(4588), 1,
      anon_sym_LPAREN,
    ACTIONS(4590), 1,
      anon_sym_LBRACK,
    ACTIONS(4592), 1,
      anon_sym_DOT,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4798), 1,
      anon_sym_as,
    ACTIONS(4800), 1,
      anon_sym_BANG,
    ACTIONS(4804), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4806), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4808), 1,
      anon_sym_GT_GT,
    ACTIONS(4812), 1,
      anon_sym_AMP,
    ACTIONS(4814), 1,
      anon_sym_CARET,
    ACTIONS(4816), 1,
      anon_sym_PIPE,
    ACTIONS(4820), 1,
      anon_sym_PERCENT,
    ACTIONS(4822), 1,
      anon_sym_STAR_STAR,
    ACTIONS(4824), 1,
      anon_sym_LT,
    ACTIONS(4832), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(4836), 1,
      anon_sym_satisfies,
    ACTIONS(4838), 1,
      sym__ternary_qmark,
    STATE(2019), 1,
      sym_type_arguments,
    STATE(2130), 1,
      sym_arguments,
    STATE(4524), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4796), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(4802), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(4810), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(4818), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4828), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4830), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(4834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4826), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
    ACTIONS(4554), 5,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_BQUOTE,
  [45991] = 31,
    ACTIONS(4588), 1,
      anon_sym_LPAREN,
    ACTIONS(4590), 1,
      anon_sym_LBRACK,
    ACTIONS(4592), 1,
      anon_sym_DOT,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4798), 1,
      anon_sym_as,
    ACTIONS(4800), 1,
      anon_sym_BANG,
    ACTIONS(4804), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4806), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4808), 1,
      anon_sym_GT_GT,
    ACTIONS(4812), 1,
      anon_sym_AMP,
    ACTIONS(4814), 1,
      anon_sym_CARET,
    ACTIONS(4816), 1,
      anon_sym_PIPE,
    ACTIONS(4820), 1,
      anon_sym_PERCENT,
    ACTIONS(4822), 1,
      anon_sym_STAR_STAR,
    ACTIONS(4824), 1,
      anon_sym_LT,
    ACTIONS(4832), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(4836), 1,
      anon_sym_satisfies,
    ACTIONS(4838), 1,
      sym__ternary_qmark,
    STATE(2019), 1,
      sym_type_arguments,
    STATE(2130), 1,
      sym_arguments,
    STATE(4524), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4796), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(4802), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(4810), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(4818), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4828), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4830), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(4834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4826), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
    ACTIONS(4558), 5,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_BQUOTE,
  [46099] = 31,
    ACTIONS(4588), 1,
      anon_sym_LPAREN,
    ACTIONS(4590), 1,
      anon_sym_LBRACK,
    ACTIONS(4592), 1,
      anon_sym_DOT,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4798), 1,
      anon_sym_as,
    ACTIONS(4800), 1,
      anon_sym_BANG,
    ACTIONS(4804), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4806), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4808), 1,
      anon_sym_GT_GT,
    ACTIONS(4812), 1,
      anon_sym_AMP,
    ACTIONS(4814), 1,
      anon_sym_CARET,
    ACTIONS(4816), 1,
      anon_sym_PIPE,
    ACTIONS(4820), 1,
      anon_sym_PERCENT,
    ACTIONS(4822), 1,
      anon_sym_STAR_STAR,
    ACTIONS(4824), 1,
      anon_sym_LT,
    ACTIONS(4832), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(4836), 1,
      anon_sym_satisfies,
    ACTIONS(4838), 1,
      sym__ternary_qmark,
    STATE(2019), 1,
      sym_type_arguments,
    STATE(2130), 1,
      sym_arguments,
    STATE(4524), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4796), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(4802), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(4810), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(4818), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4828), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4830), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(4834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4826), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
    ACTIONS(4769), 5,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_BQUOTE,
  [46207] = 31,
    ACTIONS(4588), 1,
      anon_sym_LPAREN,
    ACTIONS(4590), 1,
      anon_sym_LBRACK,
    ACTIONS(4592), 1,
      anon_sym_DOT,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4798), 1,
      anon_sym_as,
    ACTIONS(4800), 1,
      anon_sym_BANG,
    ACTIONS(4804), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4806), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4808), 1,
      anon_sym_GT_GT,
    ACTIONS(4812), 1,
      anon_sym_AMP,
    ACTIONS(4814), 1,
      anon_sym_CARET,
    ACTIONS(4816), 1,
      anon_sym_PIPE,
    ACTIONS(4820), 1,
      anon_sym_PERCENT,
    ACTIONS(4822), 1,
      anon_sym_STAR_STAR,
    ACTIONS(4824), 1,
      anon_sym_LT,
    ACTIONS(4832), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(4836), 1,
      anon_sym_satisfies,
    ACTIONS(4838), 1,
      sym__ternary_qmark,
    STATE(2019), 1,
      sym_type_arguments,
    STATE(2130), 1,
      sym_arguments,
    STATE(4524), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4796), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(4802), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(4810), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(4818), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4828), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4830), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(4834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4826), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
    ACTIONS(4771), 5,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_BQUOTE,
  [46315] = 4,
    ACTIONS(4696), 1,
      anon_sym_is,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4104), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4106), 29,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_extends,
  [46369] = 4,
    ACTIONS(4907), 1,
      anon_sym_is,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4108), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4110), 29,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_extends,
  [46423] = 31,
    ACTIONS(4588), 1,
      anon_sym_LPAREN,
    ACTIONS(4590), 1,
      anon_sym_LBRACK,
    ACTIONS(4592), 1,
      anon_sym_DOT,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4798), 1,
      anon_sym_as,
    ACTIONS(4800), 1,
      anon_sym_BANG,
    ACTIONS(4804), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4806), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4808), 1,
      anon_sym_GT_GT,
    ACTIONS(4812), 1,
      anon_sym_AMP,
    ACTIONS(4814), 1,
      anon_sym_CARET,
    ACTIONS(4816), 1,
      anon_sym_PIPE,
    ACTIONS(4820), 1,
      anon_sym_PERCENT,
    ACTIONS(4822), 1,
      anon_sym_STAR_STAR,
    ACTIONS(4824), 1,
      anon_sym_LT,
    ACTIONS(4832), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(4836), 1,
      anon_sym_satisfies,
    ACTIONS(4838), 1,
      sym__ternary_qmark,
    STATE(2019), 1,
      sym_type_arguments,
    STATE(2130), 1,
      sym_arguments,
    STATE(4524), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4796), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(4802), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(4810), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(4818), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4828), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4830), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(4834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4826), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
    ACTIONS(4792), 5,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_BQUOTE,
  [46531] = 13,
    ACTIONS(1550), 1,
      anon_sym_DQUOTE,
    ACTIONS(1552), 1,
      anon_sym_SQUOTE,
    ACTIONS(3808), 1,
      anon_sym_COMMA,
    ACTIONS(3925), 1,
      anon_sym_RBRACE,
    ACTIONS(4622), 1,
      anon_sym_EQ,
    ACTIONS(4688), 1,
      anon_sym_LBRACK,
    STATE(4792), 1,
      aux_sym_object_repeat1,
    STATE(4815), 1,
      aux_sym_object_pattern_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4690), 2,
      sym_number,
      sym_private_property_identifier,
    STATE(3866), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(3814), 7,
      sym__automatic_semicolon,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_QMARK,
      anon_sym_PIPE_RBRACE,
    ACTIONS(2351), 23,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [46603] = 35,
    ACTIONS(3557), 1,
      anon_sym_COLON,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_as,
    ACTIONS(4640), 1,
      anon_sym_BANG,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4649), 1,
      anon_sym_satisfies,
    ACTIONS(4869), 1,
      anon_sym_COMMA,
    ACTIONS(4875), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4877), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4879), 1,
      anon_sym_GT_GT,
    ACTIONS(4883), 1,
      anon_sym_AMP,
    ACTIONS(4885), 1,
      anon_sym_CARET,
    ACTIONS(4887), 1,
      anon_sym_PIPE,
    ACTIONS(4891), 1,
      anon_sym_PERCENT,
    ACTIONS(4893), 1,
      anon_sym_STAR_STAR,
    ACTIONS(4895), 1,
      anon_sym_LT,
    ACTIONS(4903), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(4905), 1,
      sym__ternary_qmark,
    ACTIONS(4909), 1,
      anon_sym_RPAREN,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    STATE(5026), 1,
      aux_sym_sequence_expression_repeat1,
    STATE(5741), 1,
      sym_type_annotation,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4867), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(4873), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(4881), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(4889), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4899), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4901), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(4897), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [46719] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(1900), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(1898), 30,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_extends,
      anon_sym_is,
  [46771] = 4,
    ACTIONS(4915), 1,
      sym_regex_flags,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4911), 16,
      anon_sym_STAR,
      anon_sym_as,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_instanceof,
      anon_sym_satisfies,
    ACTIONS(4913), 26,
      sym__ternary_qmark,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
  [46825] = 31,
    ACTIONS(4588), 1,
      anon_sym_LPAREN,
    ACTIONS(4590), 1,
      anon_sym_LBRACK,
    ACTIONS(4592), 1,
      anon_sym_DOT,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4798), 1,
      anon_sym_as,
    ACTIONS(4800), 1,
      anon_sym_BANG,
    ACTIONS(4804), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4806), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4808), 1,
      anon_sym_GT_GT,
    ACTIONS(4812), 1,
      anon_sym_AMP,
    ACTIONS(4814), 1,
      anon_sym_CARET,
    ACTIONS(4816), 1,
      anon_sym_PIPE,
    ACTIONS(4820), 1,
      anon_sym_PERCENT,
    ACTIONS(4822), 1,
      anon_sym_STAR_STAR,
    ACTIONS(4824), 1,
      anon_sym_LT,
    ACTIONS(4832), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(4836), 1,
      anon_sym_satisfies,
    ACTIONS(4838), 1,
      sym__ternary_qmark,
    STATE(2019), 1,
      sym_type_arguments,
    STATE(2130), 1,
      sym_arguments,
    STATE(4524), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4796), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(4802), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(4810), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(4818), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4828), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4830), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(4834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4826), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
    ACTIONS(4522), 5,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_BQUOTE,
  [46933] = 13,
    ACTIONS(1550), 1,
      anon_sym_DQUOTE,
    ACTIONS(1552), 1,
      anon_sym_SQUOTE,
    ACTIONS(3808), 1,
      anon_sym_COMMA,
    ACTIONS(3811), 1,
      anon_sym_RBRACE,
    ACTIONS(4622), 1,
      anon_sym_EQ,
    ACTIONS(4688), 1,
      anon_sym_LBRACK,
    STATE(4792), 1,
      aux_sym_object_repeat1,
    STATE(4815), 1,
      aux_sym_object_pattern_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4690), 2,
      sym_number,
      sym_private_property_identifier,
    STATE(3866), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(3814), 7,
      sym__automatic_semicolon,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_QMARK,
      anon_sym_PIPE_RBRACE,
    ACTIONS(2351), 23,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [47005] = 31,
    ACTIONS(4588), 1,
      anon_sym_LPAREN,
    ACTIONS(4590), 1,
      anon_sym_LBRACK,
    ACTIONS(4592), 1,
      anon_sym_DOT,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4798), 1,
      anon_sym_as,
    ACTIONS(4800), 1,
      anon_sym_BANG,
    ACTIONS(4804), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4806), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4808), 1,
      anon_sym_GT_GT,
    ACTIONS(4812), 1,
      anon_sym_AMP,
    ACTIONS(4814), 1,
      anon_sym_CARET,
    ACTIONS(4816), 1,
      anon_sym_PIPE,
    ACTIONS(4820), 1,
      anon_sym_PERCENT,
    ACTIONS(4822), 1,
      anon_sym_STAR_STAR,
    ACTIONS(4824), 1,
      anon_sym_LT,
    ACTIONS(4832), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(4836), 1,
      anon_sym_satisfies,
    ACTIONS(4838), 1,
      sym__ternary_qmark,
    STATE(2019), 1,
      sym_type_arguments,
    STATE(2130), 1,
      sym_arguments,
    STATE(4524), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4796), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(4802), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(4810), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(4818), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4828), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4830), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(4834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4826), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
    ACTIONS(4767), 5,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_BQUOTE,
  [47113] = 11,
    ACTIONS(4588), 1,
      anon_sym_LPAREN,
    ACTIONS(4590), 1,
      anon_sym_LBRACK,
    ACTIONS(4592), 1,
      anon_sym_DOT,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4917), 1,
      anon_sym_LT,
    STATE(2019), 1,
      sym_type_arguments,
    STATE(2130), 1,
      sym_arguments,
    STATE(4524), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4785), 12,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4787), 23,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [47181] = 35,
    ACTIONS(3557), 1,
      anon_sym_COLON,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_as,
    ACTIONS(4640), 1,
      anon_sym_BANG,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4649), 1,
      anon_sym_satisfies,
    ACTIONS(4869), 1,
      anon_sym_COMMA,
    ACTIONS(4875), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4877), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4879), 1,
      anon_sym_GT_GT,
    ACTIONS(4883), 1,
      anon_sym_AMP,
    ACTIONS(4885), 1,
      anon_sym_CARET,
    ACTIONS(4887), 1,
      anon_sym_PIPE,
    ACTIONS(4891), 1,
      anon_sym_PERCENT,
    ACTIONS(4893), 1,
      anon_sym_STAR_STAR,
    ACTIONS(4895), 1,
      anon_sym_LT,
    ACTIONS(4903), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(4905), 1,
      sym__ternary_qmark,
    ACTIONS(4920), 1,
      anon_sym_RPAREN,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    STATE(5026), 1,
      aux_sym_sequence_expression_repeat1,
    STATE(5630), 1,
      sym_type_annotation,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4867), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(4873), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(4881), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(4889), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4899), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4901), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(4897), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [47297] = 13,
    ACTIONS(1550), 1,
      anon_sym_DQUOTE,
    ACTIONS(1552), 1,
      anon_sym_SQUOTE,
    ACTIONS(3808), 1,
      anon_sym_COMMA,
    ACTIONS(3909), 1,
      anon_sym_RBRACE,
    ACTIONS(4622), 1,
      anon_sym_EQ,
    ACTIONS(4688), 1,
      anon_sym_LBRACK,
    STATE(4792), 1,
      aux_sym_object_repeat1,
    STATE(4815), 1,
      aux_sym_object_pattern_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4690), 2,
      sym_number,
      sym_private_property_identifier,
    STATE(3866), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(3814), 7,
      sym__automatic_semicolon,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_QMARK,
      anon_sym_PIPE_RBRACE,
    ACTIONS(2351), 23,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [47369] = 8,
    ACTIONS(4588), 1,
      anon_sym_LPAREN,
    ACTIONS(4824), 1,
      anon_sym_LT,
    STATE(2019), 1,
      sym_type_arguments,
    STATE(2130), 1,
      sym_arguments,
    STATE(4524), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4704), 12,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4706), 26,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [47431] = 8,
    ACTIONS(4588), 1,
      anon_sym_LPAREN,
    ACTIONS(4922), 1,
      anon_sym_LT,
    STATE(2019), 1,
      sym_type_arguments,
    STATE(2130), 1,
      sym_arguments,
    STATE(4524), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4704), 12,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4706), 26,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [47493] = 31,
    ACTIONS(4588), 1,
      anon_sym_LPAREN,
    ACTIONS(4590), 1,
      anon_sym_LBRACK,
    ACTIONS(4592), 1,
      anon_sym_DOT,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4798), 1,
      anon_sym_as,
    ACTIONS(4800), 1,
      anon_sym_BANG,
    ACTIONS(4836), 1,
      anon_sym_satisfies,
    ACTIONS(4922), 1,
      anon_sym_LT,
    ACTIONS(4928), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4930), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4932), 1,
      anon_sym_GT_GT,
    ACTIONS(4936), 1,
      anon_sym_AMP,
    ACTIONS(4938), 1,
      anon_sym_CARET,
    ACTIONS(4940), 1,
      anon_sym_PIPE,
    ACTIONS(4944), 1,
      anon_sym_PERCENT,
    ACTIONS(4946), 1,
      anon_sym_STAR_STAR,
    ACTIONS(4954), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(4956), 1,
      sym__ternary_qmark,
    STATE(2019), 1,
      sym_type_arguments,
    STATE(2130), 1,
      sym_arguments,
    STATE(4524), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4924), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(4926), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(4934), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(4942), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4950), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4952), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(4948), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
    ACTIONS(4468), 5,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_BQUOTE,
  [47601] = 31,
    ACTIONS(4588), 1,
      anon_sym_LPAREN,
    ACTIONS(4590), 1,
      anon_sym_LBRACK,
    ACTIONS(4592), 1,
      anon_sym_DOT,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4798), 1,
      anon_sym_as,
    ACTIONS(4800), 1,
      anon_sym_BANG,
    ACTIONS(4836), 1,
      anon_sym_satisfies,
    ACTIONS(4922), 1,
      anon_sym_LT,
    ACTIONS(4928), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4930), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4932), 1,
      anon_sym_GT_GT,
    ACTIONS(4936), 1,
      anon_sym_AMP,
    ACTIONS(4938), 1,
      anon_sym_CARET,
    ACTIONS(4940), 1,
      anon_sym_PIPE,
    ACTIONS(4944), 1,
      anon_sym_PERCENT,
    ACTIONS(4946), 1,
      anon_sym_STAR_STAR,
    ACTIONS(4954), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(4956), 1,
      sym__ternary_qmark,
    STATE(2019), 1,
      sym_type_arguments,
    STATE(2130), 1,
      sym_arguments,
    STATE(4524), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4924), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(4926), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(4934), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(4942), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4950), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4952), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(4948), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
    ACTIONS(4744), 5,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_BQUOTE,
  [47709] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3233), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(3235), 30,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_extends,
      anon_sym_PIPE_RBRACE,
  [47761] = 31,
    ACTIONS(4588), 1,
      anon_sym_LPAREN,
    ACTIONS(4590), 1,
      anon_sym_LBRACK,
    ACTIONS(4592), 1,
      anon_sym_DOT,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4798), 1,
      anon_sym_as,
    ACTIONS(4800), 1,
      anon_sym_BANG,
    ACTIONS(4836), 1,
      anon_sym_satisfies,
    ACTIONS(4922), 1,
      anon_sym_LT,
    ACTIONS(4928), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4930), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4932), 1,
      anon_sym_GT_GT,
    ACTIONS(4936), 1,
      anon_sym_AMP,
    ACTIONS(4938), 1,
      anon_sym_CARET,
    ACTIONS(4940), 1,
      anon_sym_PIPE,
    ACTIONS(4944), 1,
      anon_sym_PERCENT,
    ACTIONS(4946), 1,
      anon_sym_STAR_STAR,
    ACTIONS(4954), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(4956), 1,
      sym__ternary_qmark,
    STATE(2019), 1,
      sym_type_arguments,
    STATE(2130), 1,
      sym_arguments,
    STATE(4524), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4924), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(4926), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(4934), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(4942), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4950), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4952), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(4948), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
    ACTIONS(4756), 5,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_BQUOTE,
  [47869] = 31,
    ACTIONS(4588), 1,
      anon_sym_LPAREN,
    ACTIONS(4590), 1,
      anon_sym_LBRACK,
    ACTIONS(4592), 1,
      anon_sym_DOT,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4798), 1,
      anon_sym_as,
    ACTIONS(4800), 1,
      anon_sym_BANG,
    ACTIONS(4836), 1,
      anon_sym_satisfies,
    ACTIONS(4922), 1,
      anon_sym_LT,
    ACTIONS(4928), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4930), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4932), 1,
      anon_sym_GT_GT,
    ACTIONS(4936), 1,
      anon_sym_AMP,
    ACTIONS(4938), 1,
      anon_sym_CARET,
    ACTIONS(4940), 1,
      anon_sym_PIPE,
    ACTIONS(4944), 1,
      anon_sym_PERCENT,
    ACTIONS(4946), 1,
      anon_sym_STAR_STAR,
    ACTIONS(4954), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(4956), 1,
      sym__ternary_qmark,
    STATE(2019), 1,
      sym_type_arguments,
    STATE(2130), 1,
      sym_arguments,
    STATE(4524), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4924), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(4926), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(4934), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(4942), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4950), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4952), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(4948), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
    ACTIONS(4758), 5,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_BQUOTE,
  [47977] = 31,
    ACTIONS(4588), 1,
      anon_sym_LPAREN,
    ACTIONS(4590), 1,
      anon_sym_LBRACK,
    ACTIONS(4592), 1,
      anon_sym_DOT,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4798), 1,
      anon_sym_as,
    ACTIONS(4800), 1,
      anon_sym_BANG,
    ACTIONS(4836), 1,
      anon_sym_satisfies,
    ACTIONS(4922), 1,
      anon_sym_LT,
    ACTIONS(4928), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4930), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4932), 1,
      anon_sym_GT_GT,
    ACTIONS(4936), 1,
      anon_sym_AMP,
    ACTIONS(4938), 1,
      anon_sym_CARET,
    ACTIONS(4940), 1,
      anon_sym_PIPE,
    ACTIONS(4944), 1,
      anon_sym_PERCENT,
    ACTIONS(4946), 1,
      anon_sym_STAR_STAR,
    ACTIONS(4954), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(4956), 1,
      sym__ternary_qmark,
    STATE(2019), 1,
      sym_type_arguments,
    STATE(2130), 1,
      sym_arguments,
    STATE(4524), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4924), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(4926), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(4934), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(4942), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4950), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4952), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(4948), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
    ACTIONS(4504), 5,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_BQUOTE,
  [48085] = 18,
    ACTIONS(4588), 1,
      anon_sym_LPAREN,
    ACTIONS(4590), 1,
      anon_sym_LBRACK,
    ACTIONS(4592), 1,
      anon_sym_DOT,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4922), 1,
      anon_sym_LT,
    ACTIONS(4932), 1,
      anon_sym_GT_GT,
    ACTIONS(4944), 1,
      anon_sym_PERCENT,
    ACTIONS(4946), 1,
      anon_sym_STAR_STAR,
    STATE(2019), 1,
      sym_type_arguments,
    STATE(2130), 1,
      sym_arguments,
    STATE(4524), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4924), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(4934), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(4942), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4762), 7,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4760), 17,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [48167] = 13,
    ACTIONS(4588), 1,
      anon_sym_LPAREN,
    ACTIONS(4590), 1,
      anon_sym_LBRACK,
    ACTIONS(4592), 1,
      anon_sym_DOT,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4946), 1,
      anon_sym_STAR_STAR,
    ACTIONS(4958), 1,
      anon_sym_LT,
    STATE(2019), 1,
      sym_type_arguments,
    STATE(2130), 1,
      sym_arguments,
    STATE(4524), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4762), 12,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4760), 20,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [48239] = 25,
    ACTIONS(4588), 1,
      anon_sym_LPAREN,
    ACTIONS(4590), 1,
      anon_sym_LBRACK,
    ACTIONS(4592), 1,
      anon_sym_DOT,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4762), 1,
      anon_sym_BANG,
    ACTIONS(4922), 1,
      anon_sym_LT,
    ACTIONS(4932), 1,
      anon_sym_GT_GT,
    ACTIONS(4936), 1,
      anon_sym_AMP,
    ACTIONS(4938), 1,
      anon_sym_CARET,
    ACTIONS(4940), 1,
      anon_sym_PIPE,
    ACTIONS(4944), 1,
      anon_sym_PERCENT,
    ACTIONS(4946), 1,
      anon_sym_STAR_STAR,
    STATE(2019), 1,
      sym_type_arguments,
    STATE(2130), 1,
      sym_arguments,
    STATE(4524), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4924), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(4926), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(4934), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(4942), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4950), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4952), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(4948), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
    ACTIONS(4760), 11,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [48335] = 26,
    ACTIONS(4588), 1,
      anon_sym_LPAREN,
    ACTIONS(4590), 1,
      anon_sym_LBRACK,
    ACTIONS(4592), 1,
      anon_sym_DOT,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4762), 1,
      anon_sym_BANG,
    ACTIONS(4922), 1,
      anon_sym_LT,
    ACTIONS(4928), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4932), 1,
      anon_sym_GT_GT,
    ACTIONS(4936), 1,
      anon_sym_AMP,
    ACTIONS(4938), 1,
      anon_sym_CARET,
    ACTIONS(4940), 1,
      anon_sym_PIPE,
    ACTIONS(4944), 1,
      anon_sym_PERCENT,
    ACTIONS(4946), 1,
      anon_sym_STAR_STAR,
    STATE(2019), 1,
      sym_type_arguments,
    STATE(2130), 1,
      sym_arguments,
    STATE(4524), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4924), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(4926), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(4934), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(4942), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4950), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4952), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(4948), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
    ACTIONS(4760), 10,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [48433] = 16,
    ACTIONS(4588), 1,
      anon_sym_LPAREN,
    ACTIONS(4590), 1,
      anon_sym_LBRACK,
    ACTIONS(4592), 1,
      anon_sym_DOT,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4944), 1,
      anon_sym_PERCENT,
    ACTIONS(4946), 1,
      anon_sym_STAR_STAR,
    ACTIONS(4958), 1,
      anon_sym_LT,
    STATE(2019), 1,
      sym_type_arguments,
    STATE(2130), 1,
      sym_arguments,
    STATE(4524), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4924), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(4942), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4762), 8,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4760), 19,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [48511] = 22,
    ACTIONS(4588), 1,
      anon_sym_LPAREN,
    ACTIONS(4590), 1,
      anon_sym_LBRACK,
    ACTIONS(4592), 1,
      anon_sym_DOT,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4922), 1,
      anon_sym_LT,
    ACTIONS(4932), 1,
      anon_sym_GT_GT,
    ACTIONS(4944), 1,
      anon_sym_PERCENT,
    ACTIONS(4946), 1,
      anon_sym_STAR_STAR,
    STATE(2019), 1,
      sym_type_arguments,
    STATE(2130), 1,
      sym_arguments,
    STATE(4524), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4924), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(4926), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(4934), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(4942), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4950), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4952), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(4762), 3,
      anon_sym_BANG,
      anon_sym_AMP,
      anon_sym_PIPE,
    ACTIONS(4948), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
    ACTIONS(4760), 12,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_CARET,
      anon_sym_QMARK_QMARK,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [48601] = 23,
    ACTIONS(4588), 1,
      anon_sym_LPAREN,
    ACTIONS(4590), 1,
      anon_sym_LBRACK,
    ACTIONS(4592), 1,
      anon_sym_DOT,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4922), 1,
      anon_sym_LT,
    ACTIONS(4932), 1,
      anon_sym_GT_GT,
    ACTIONS(4936), 1,
      anon_sym_AMP,
    ACTIONS(4944), 1,
      anon_sym_PERCENT,
    ACTIONS(4946), 1,
      anon_sym_STAR_STAR,
    STATE(2019), 1,
      sym_type_arguments,
    STATE(2130), 1,
      sym_arguments,
    STATE(4524), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4762), 2,
      anon_sym_BANG,
      anon_sym_PIPE,
    ACTIONS(4834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4924), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(4926), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(4934), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(4942), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4950), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4952), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(4948), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
    ACTIONS(4760), 12,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_CARET,
      anon_sym_QMARK_QMARK,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [48693] = 24,
    ACTIONS(4588), 1,
      anon_sym_LPAREN,
    ACTIONS(4590), 1,
      anon_sym_LBRACK,
    ACTIONS(4592), 1,
      anon_sym_DOT,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4922), 1,
      anon_sym_LT,
    ACTIONS(4932), 1,
      anon_sym_GT_GT,
    ACTIONS(4936), 1,
      anon_sym_AMP,
    ACTIONS(4938), 1,
      anon_sym_CARET,
    ACTIONS(4944), 1,
      anon_sym_PERCENT,
    ACTIONS(4946), 1,
      anon_sym_STAR_STAR,
    STATE(2019), 1,
      sym_type_arguments,
    STATE(2130), 1,
      sym_arguments,
    STATE(4524), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4762), 2,
      anon_sym_BANG,
      anon_sym_PIPE,
    ACTIONS(4834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4924), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(4926), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(4934), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(4942), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4950), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4952), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(4948), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
    ACTIONS(4760), 11,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [48787] = 15,
    ACTIONS(4588), 1,
      anon_sym_LPAREN,
    ACTIONS(4590), 1,
      anon_sym_LBRACK,
    ACTIONS(4592), 1,
      anon_sym_DOT,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4944), 1,
      anon_sym_PERCENT,
    ACTIONS(4946), 1,
      anon_sym_STAR_STAR,
    ACTIONS(4958), 1,
      anon_sym_LT,
    STATE(2019), 1,
      sym_type_arguments,
    STATE(2130), 1,
      sym_arguments,
    STATE(4524), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4924), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(4762), 10,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4760), 19,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [48863] = 16,
    ACTIONS(4588), 1,
      anon_sym_LPAREN,
    ACTIONS(4590), 1,
      anon_sym_LBRACK,
    ACTIONS(4592), 1,
      anon_sym_DOT,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4798), 1,
      anon_sym_as,
    ACTIONS(4800), 1,
      anon_sym_BANG,
    ACTIONS(4836), 1,
      anon_sym_satisfies,
    ACTIONS(4946), 1,
      anon_sym_STAR_STAR,
    ACTIONS(4958), 1,
      anon_sym_LT,
    STATE(2019), 1,
      sym_type_arguments,
    STATE(2130), 1,
      sym_arguments,
    STATE(4524), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4762), 11,
      anon_sym_STAR,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4760), 18,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_BQUOTE,
  [48941] = 20,
    ACTIONS(4588), 1,
      anon_sym_LPAREN,
    ACTIONS(4590), 1,
      anon_sym_LBRACK,
    ACTIONS(4592), 1,
      anon_sym_DOT,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4922), 1,
      anon_sym_LT,
    ACTIONS(4932), 1,
      anon_sym_GT_GT,
    ACTIONS(4944), 1,
      anon_sym_PERCENT,
    ACTIONS(4946), 1,
      anon_sym_STAR_STAR,
    STATE(2019), 1,
      sym_type_arguments,
    STATE(2130), 1,
      sym_arguments,
    STATE(4524), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4924), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(4926), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(4934), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(4942), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4948), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
    ACTIONS(4762), 5,
      anon_sym_BANG,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4760), 14,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_CARET,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [49027] = 27,
    ACTIONS(4588), 1,
      anon_sym_LPAREN,
    ACTIONS(4590), 1,
      anon_sym_LBRACK,
    ACTIONS(4592), 1,
      anon_sym_DOT,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4762), 1,
      anon_sym_BANG,
    ACTIONS(4922), 1,
      anon_sym_LT,
    ACTIONS(4928), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4930), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4932), 1,
      anon_sym_GT_GT,
    ACTIONS(4936), 1,
      anon_sym_AMP,
    ACTIONS(4938), 1,
      anon_sym_CARET,
    ACTIONS(4940), 1,
      anon_sym_PIPE,
    ACTIONS(4944), 1,
      anon_sym_PERCENT,
    ACTIONS(4946), 1,
      anon_sym_STAR_STAR,
    STATE(2019), 1,
      sym_type_arguments,
    STATE(2130), 1,
      sym_arguments,
    STATE(4524), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4924), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(4926), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(4934), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(4942), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4950), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4952), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(4948), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
    ACTIONS(4760), 9,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_QMARK_QMARK,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [49127] = 31,
    ACTIONS(4588), 1,
      anon_sym_LPAREN,
    ACTIONS(4590), 1,
      anon_sym_LBRACK,
    ACTIONS(4592), 1,
      anon_sym_DOT,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4798), 1,
      anon_sym_as,
    ACTIONS(4800), 1,
      anon_sym_BANG,
    ACTIONS(4836), 1,
      anon_sym_satisfies,
    ACTIONS(4922), 1,
      anon_sym_LT,
    ACTIONS(4928), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4930), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4932), 1,
      anon_sym_GT_GT,
    ACTIONS(4936), 1,
      anon_sym_AMP,
    ACTIONS(4938), 1,
      anon_sym_CARET,
    ACTIONS(4940), 1,
      anon_sym_PIPE,
    ACTIONS(4944), 1,
      anon_sym_PERCENT,
    ACTIONS(4946), 1,
      anon_sym_STAR_STAR,
    ACTIONS(4954), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(4956), 1,
      sym__ternary_qmark,
    STATE(2019), 1,
      sym_type_arguments,
    STATE(2130), 1,
      sym_arguments,
    STATE(4524), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4924), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(4926), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(4934), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(4942), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4950), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4952), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(4948), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
    ACTIONS(4522), 5,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_BQUOTE,
  [49235] = 31,
    ACTIONS(4588), 1,
      anon_sym_LPAREN,
    ACTIONS(4590), 1,
      anon_sym_LBRACK,
    ACTIONS(4592), 1,
      anon_sym_DOT,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4798), 1,
      anon_sym_as,
    ACTIONS(4800), 1,
      anon_sym_BANG,
    ACTIONS(4836), 1,
      anon_sym_satisfies,
    ACTIONS(4922), 1,
      anon_sym_LT,
    ACTIONS(4928), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4930), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4932), 1,
      anon_sym_GT_GT,
    ACTIONS(4936), 1,
      anon_sym_AMP,
    ACTIONS(4938), 1,
      anon_sym_CARET,
    ACTIONS(4940), 1,
      anon_sym_PIPE,
    ACTIONS(4944), 1,
      anon_sym_PERCENT,
    ACTIONS(4946), 1,
      anon_sym_STAR_STAR,
    ACTIONS(4954), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(4956), 1,
      sym__ternary_qmark,
    STATE(2019), 1,
      sym_type_arguments,
    STATE(2130), 1,
      sym_arguments,
    STATE(4524), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4924), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(4926), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(4934), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(4942), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4950), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4952), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(4948), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
    ACTIONS(4767), 5,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_BQUOTE,
  [49343] = 31,
    ACTIONS(4588), 1,
      anon_sym_LPAREN,
    ACTIONS(4590), 1,
      anon_sym_LBRACK,
    ACTIONS(4592), 1,
      anon_sym_DOT,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4798), 1,
      anon_sym_as,
    ACTIONS(4800), 1,
      anon_sym_BANG,
    ACTIONS(4836), 1,
      anon_sym_satisfies,
    ACTIONS(4922), 1,
      anon_sym_LT,
    ACTIONS(4928), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4930), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4932), 1,
      anon_sym_GT_GT,
    ACTIONS(4936), 1,
      anon_sym_AMP,
    ACTIONS(4938), 1,
      anon_sym_CARET,
    ACTIONS(4940), 1,
      anon_sym_PIPE,
    ACTIONS(4944), 1,
      anon_sym_PERCENT,
    ACTIONS(4946), 1,
      anon_sym_STAR_STAR,
    ACTIONS(4954), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(4956), 1,
      sym__ternary_qmark,
    STATE(2019), 1,
      sym_type_arguments,
    STATE(2130), 1,
      sym_arguments,
    STATE(4524), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4924), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(4926), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(4934), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(4942), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4950), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4952), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(4948), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
    ACTIONS(4546), 5,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_BQUOTE,
  [49451] = 31,
    ACTIONS(4588), 1,
      anon_sym_LPAREN,
    ACTIONS(4590), 1,
      anon_sym_LBRACK,
    ACTIONS(4592), 1,
      anon_sym_DOT,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4798), 1,
      anon_sym_as,
    ACTIONS(4800), 1,
      anon_sym_BANG,
    ACTIONS(4836), 1,
      anon_sym_satisfies,
    ACTIONS(4922), 1,
      anon_sym_LT,
    ACTIONS(4928), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4930), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4932), 1,
      anon_sym_GT_GT,
    ACTIONS(4936), 1,
      anon_sym_AMP,
    ACTIONS(4938), 1,
      anon_sym_CARET,
    ACTIONS(4940), 1,
      anon_sym_PIPE,
    ACTIONS(4944), 1,
      anon_sym_PERCENT,
    ACTIONS(4946), 1,
      anon_sym_STAR_STAR,
    ACTIONS(4954), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(4956), 1,
      sym__ternary_qmark,
    STATE(2019), 1,
      sym_type_arguments,
    STATE(2130), 1,
      sym_arguments,
    STATE(4524), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4924), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(4926), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(4934), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(4942), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4950), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4952), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(4948), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
    ACTIONS(4554), 5,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_BQUOTE,
  [49559] = 31,
    ACTIONS(4588), 1,
      anon_sym_LPAREN,
    ACTIONS(4590), 1,
      anon_sym_LBRACK,
    ACTIONS(4592), 1,
      anon_sym_DOT,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4798), 1,
      anon_sym_as,
    ACTIONS(4800), 1,
      anon_sym_BANG,
    ACTIONS(4836), 1,
      anon_sym_satisfies,
    ACTIONS(4922), 1,
      anon_sym_LT,
    ACTIONS(4928), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4930), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4932), 1,
      anon_sym_GT_GT,
    ACTIONS(4936), 1,
      anon_sym_AMP,
    ACTIONS(4938), 1,
      anon_sym_CARET,
    ACTIONS(4940), 1,
      anon_sym_PIPE,
    ACTIONS(4944), 1,
      anon_sym_PERCENT,
    ACTIONS(4946), 1,
      anon_sym_STAR_STAR,
    ACTIONS(4954), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(4956), 1,
      sym__ternary_qmark,
    STATE(2019), 1,
      sym_type_arguments,
    STATE(2130), 1,
      sym_arguments,
    STATE(4524), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4924), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(4926), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(4934), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(4942), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4950), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4952), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(4948), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
    ACTIONS(4558), 5,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_BQUOTE,
  [49667] = 31,
    ACTIONS(4588), 1,
      anon_sym_LPAREN,
    ACTIONS(4590), 1,
      anon_sym_LBRACK,
    ACTIONS(4592), 1,
      anon_sym_DOT,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4798), 1,
      anon_sym_as,
    ACTIONS(4800), 1,
      anon_sym_BANG,
    ACTIONS(4836), 1,
      anon_sym_satisfies,
    ACTIONS(4922), 1,
      anon_sym_LT,
    ACTIONS(4928), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4930), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4932), 1,
      anon_sym_GT_GT,
    ACTIONS(4936), 1,
      anon_sym_AMP,
    ACTIONS(4938), 1,
      anon_sym_CARET,
    ACTIONS(4940), 1,
      anon_sym_PIPE,
    ACTIONS(4944), 1,
      anon_sym_PERCENT,
    ACTIONS(4946), 1,
      anon_sym_STAR_STAR,
    ACTIONS(4954), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(4956), 1,
      sym__ternary_qmark,
    STATE(2019), 1,
      sym_type_arguments,
    STATE(2130), 1,
      sym_arguments,
    STATE(4524), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4924), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(4926), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(4934), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(4942), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4950), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4952), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(4948), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
    ACTIONS(4769), 5,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_BQUOTE,
  [49775] = 31,
    ACTIONS(4588), 1,
      anon_sym_LPAREN,
    ACTIONS(4590), 1,
      anon_sym_LBRACK,
    ACTIONS(4592), 1,
      anon_sym_DOT,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4798), 1,
      anon_sym_as,
    ACTIONS(4800), 1,
      anon_sym_BANG,
    ACTIONS(4836), 1,
      anon_sym_satisfies,
    ACTIONS(4922), 1,
      anon_sym_LT,
    ACTIONS(4928), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4930), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4932), 1,
      anon_sym_GT_GT,
    ACTIONS(4936), 1,
      anon_sym_AMP,
    ACTIONS(4938), 1,
      anon_sym_CARET,
    ACTIONS(4940), 1,
      anon_sym_PIPE,
    ACTIONS(4944), 1,
      anon_sym_PERCENT,
    ACTIONS(4946), 1,
      anon_sym_STAR_STAR,
    ACTIONS(4954), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(4956), 1,
      sym__ternary_qmark,
    STATE(2019), 1,
      sym_type_arguments,
    STATE(2130), 1,
      sym_arguments,
    STATE(4524), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4924), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(4926), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(4934), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(4942), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4950), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4952), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(4948), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
    ACTIONS(4771), 5,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_BQUOTE,
  [49883] = 31,
    ACTIONS(4588), 1,
      anon_sym_LPAREN,
    ACTIONS(4590), 1,
      anon_sym_LBRACK,
    ACTIONS(4592), 1,
      anon_sym_DOT,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4798), 1,
      anon_sym_as,
    ACTIONS(4800), 1,
      anon_sym_BANG,
    ACTIONS(4836), 1,
      anon_sym_satisfies,
    ACTIONS(4922), 1,
      anon_sym_LT,
    ACTIONS(4928), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4930), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4932), 1,
      anon_sym_GT_GT,
    ACTIONS(4936), 1,
      anon_sym_AMP,
    ACTIONS(4938), 1,
      anon_sym_CARET,
    ACTIONS(4940), 1,
      anon_sym_PIPE,
    ACTIONS(4944), 1,
      anon_sym_PERCENT,
    ACTIONS(4946), 1,
      anon_sym_STAR_STAR,
    ACTIONS(4954), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(4956), 1,
      sym__ternary_qmark,
    STATE(2019), 1,
      sym_type_arguments,
    STATE(2130), 1,
      sym_arguments,
    STATE(4524), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4924), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(4926), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(4934), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(4942), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4950), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4952), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(4948), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
    ACTIONS(4773), 5,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_BQUOTE,
  [49991] = 8,
    ACTIONS(1696), 1,
      anon_sym_EQ,
    ACTIONS(4126), 1,
      anon_sym_LBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4129), 2,
      anon_sym_AMP,
      anon_sym_PIPE,
    ACTIONS(4961), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
    ACTIONS(2373), 4,
      sym__automatic_semicolon,
      anon_sym_SEMI,
      anon_sym_extends,
      anon_sym_PIPE_RBRACE,
    ACTIONS(1694), 11,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(1698), 22,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [50053] = 8,
    ACTIONS(4146), 1,
      anon_sym_EQ,
    ACTIONS(4150), 1,
      anon_sym_LBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4153), 2,
      anon_sym_AMP,
      anon_sym_PIPE,
    ACTIONS(4965), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
    ACTIONS(4156), 4,
      sym__automatic_semicolon,
      anon_sym_SEMI,
      anon_sym_extends,
      anon_sym_PIPE_RBRACE,
    ACTIONS(4144), 11,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4148), 22,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [50115] = 35,
    ACTIONS(3557), 1,
      anon_sym_COLON,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_as,
    ACTIONS(4640), 1,
      anon_sym_BANG,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4649), 1,
      anon_sym_satisfies,
    ACTIONS(4869), 1,
      anon_sym_COMMA,
    ACTIONS(4875), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4877), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4879), 1,
      anon_sym_GT_GT,
    ACTIONS(4883), 1,
      anon_sym_AMP,
    ACTIONS(4885), 1,
      anon_sym_CARET,
    ACTIONS(4887), 1,
      anon_sym_PIPE,
    ACTIONS(4891), 1,
      anon_sym_PERCENT,
    ACTIONS(4893), 1,
      anon_sym_STAR_STAR,
    ACTIONS(4895), 1,
      anon_sym_LT,
    ACTIONS(4903), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(4905), 1,
      sym__ternary_qmark,
    ACTIONS(4969), 1,
      anon_sym_RPAREN,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    STATE(5026), 1,
      aux_sym_sequence_expression_repeat1,
    STATE(5636), 1,
      sym_type_annotation,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4867), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(4873), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(4881), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(4889), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4899), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4901), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(4897), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [50231] = 5,
    ACTIONS(4596), 1,
      anon_sym_LT,
    STATE(2063), 1,
      sym_type_arguments,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4108), 12,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4110), 29,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_extends,
  [50287] = 31,
    ACTIONS(4588), 1,
      anon_sym_LPAREN,
    ACTIONS(4590), 1,
      anon_sym_LBRACK,
    ACTIONS(4592), 1,
      anon_sym_DOT,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4798), 1,
      anon_sym_as,
    ACTIONS(4800), 1,
      anon_sym_BANG,
    ACTIONS(4804), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4806), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4808), 1,
      anon_sym_GT_GT,
    ACTIONS(4812), 1,
      anon_sym_AMP,
    ACTIONS(4814), 1,
      anon_sym_CARET,
    ACTIONS(4816), 1,
      anon_sym_PIPE,
    ACTIONS(4820), 1,
      anon_sym_PERCENT,
    ACTIONS(4822), 1,
      anon_sym_STAR_STAR,
    ACTIONS(4824), 1,
      anon_sym_LT,
    ACTIONS(4832), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(4836), 1,
      anon_sym_satisfies,
    ACTIONS(4838), 1,
      sym__ternary_qmark,
    STATE(2019), 1,
      sym_type_arguments,
    STATE(2130), 1,
      sym_arguments,
    STATE(4524), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4796), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(4802), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(4810), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(4818), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4828), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4830), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(4834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4826), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
    ACTIONS(4468), 5,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_BQUOTE,
  [50395] = 7,
    ACTIONS(3510), 1,
      anon_sym_EQ,
    ACTIONS(4408), 1,
      anon_sym_extends,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4608), 2,
      anon_sym_COMMA,
      anon_sym_LBRACK,
    ACTIONS(4611), 3,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_GT,
    ACTIONS(3492), 10,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(3496), 26,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [50455] = 31,
    ACTIONS(4588), 1,
      anon_sym_LPAREN,
    ACTIONS(4590), 1,
      anon_sym_LBRACK,
    ACTIONS(4592), 1,
      anon_sym_DOT,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4798), 1,
      anon_sym_as,
    ACTIONS(4800), 1,
      anon_sym_BANG,
    ACTIONS(4804), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4806), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4808), 1,
      anon_sym_GT_GT,
    ACTIONS(4812), 1,
      anon_sym_AMP,
    ACTIONS(4814), 1,
      anon_sym_CARET,
    ACTIONS(4816), 1,
      anon_sym_PIPE,
    ACTIONS(4820), 1,
      anon_sym_PERCENT,
    ACTIONS(4822), 1,
      anon_sym_STAR_STAR,
    ACTIONS(4824), 1,
      anon_sym_LT,
    ACTIONS(4832), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(4836), 1,
      anon_sym_satisfies,
    ACTIONS(4838), 1,
      sym__ternary_qmark,
    STATE(2019), 1,
      sym_type_arguments,
    STATE(2130), 1,
      sym_arguments,
    STATE(4524), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4796), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(4802), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(4810), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(4818), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4828), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4830), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(4834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4826), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
    ACTIONS(4744), 5,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_BQUOTE,
  [50563] = 14,
    ACTIONS(1626), 1,
      anon_sym_DQUOTE,
    ACTIONS(1628), 1,
      anon_sym_SQUOTE,
    ACTIONS(3722), 1,
      anon_sym_override,
    ACTIONS(4624), 1,
      anon_sym_LBRACK,
    ACTIONS(4973), 1,
      anon_sym_static,
    ACTIONS(4975), 1,
      anon_sym_readonly,
    ACTIONS(4977), 1,
      anon_sym_abstract,
    ACTIONS(4979), 1,
      anon_sym_accessor,
    STATE(2850), 1,
      sym_override_modifier,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4971), 2,
      sym_number,
      sym_private_property_identifier,
    STATE(3342), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(3814), 9,
      sym__automatic_semicolon,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_BANG,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_QMARK,
    ACTIONS(3700), 20,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [50637] = 16,
    ACTIONS(1626), 1,
      anon_sym_DQUOTE,
    ACTIONS(1628), 1,
      anon_sym_SQUOTE,
    ACTIONS(3722), 1,
      anon_sym_override,
    ACTIONS(4620), 1,
      anon_sym_STAR,
    ACTIONS(4622), 1,
      anon_sym_EQ,
    ACTIONS(4624), 1,
      anon_sym_LBRACK,
    ACTIONS(4626), 1,
      anon_sym_async,
    ACTIONS(4630), 1,
      anon_sym_readonly,
    STATE(2805), 1,
      sym_override_modifier,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4074), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
    ACTIONS(4628), 2,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(4632), 2,
      anon_sym_get,
      anon_sym_set,
    STATE(3144), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(3814), 7,
      sym__automatic_semicolon,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_QMARK,
      anon_sym_PIPE_RBRACE,
    ACTIONS(3700), 18,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [50715] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3237), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(3239), 30,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_extends,
      anon_sym_PIPE_RBRACE,
  [50767] = 31,
    ACTIONS(4588), 1,
      anon_sym_LPAREN,
    ACTIONS(4590), 1,
      anon_sym_LBRACK,
    ACTIONS(4592), 1,
      anon_sym_DOT,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4798), 1,
      anon_sym_as,
    ACTIONS(4800), 1,
      anon_sym_BANG,
    ACTIONS(4804), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4806), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4808), 1,
      anon_sym_GT_GT,
    ACTIONS(4812), 1,
      anon_sym_AMP,
    ACTIONS(4814), 1,
      anon_sym_CARET,
    ACTIONS(4816), 1,
      anon_sym_PIPE,
    ACTIONS(4820), 1,
      anon_sym_PERCENT,
    ACTIONS(4822), 1,
      anon_sym_STAR_STAR,
    ACTIONS(4824), 1,
      anon_sym_LT,
    ACTIONS(4832), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(4836), 1,
      anon_sym_satisfies,
    ACTIONS(4838), 1,
      sym__ternary_qmark,
    STATE(2019), 1,
      sym_type_arguments,
    STATE(2130), 1,
      sym_arguments,
    STATE(4524), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4796), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(4802), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(4810), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(4818), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4828), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4830), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(4834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4826), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
    ACTIONS(4773), 5,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_BQUOTE,
  [50875] = 12,
    ACTIONS(4588), 1,
      anon_sym_LPAREN,
    ACTIONS(4590), 1,
      anon_sym_LBRACK,
    ACTIONS(4592), 1,
      anon_sym_DOT,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4981), 1,
      anon_sym_LT,
    STATE(2019), 1,
      sym_type_arguments,
    STATE(2130), 1,
      sym_arguments,
    STATE(4524), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4778), 12,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4780), 21,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [50945] = 15,
    ACTIONS(4588), 1,
      anon_sym_LPAREN,
    ACTIONS(4590), 1,
      anon_sym_LBRACK,
    ACTIONS(4592), 1,
      anon_sym_DOT,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4798), 1,
      anon_sym_as,
    ACTIONS(4800), 1,
      anon_sym_BANG,
    ACTIONS(4836), 1,
      anon_sym_satisfies,
    ACTIONS(4984), 1,
      anon_sym_LT,
    STATE(2019), 1,
      sym_type_arguments,
    STATE(2130), 1,
      sym_arguments,
    STATE(4524), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4634), 11,
      anon_sym_STAR,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4638), 19,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_BQUOTE,
  [51021] = 31,
    ACTIONS(4588), 1,
      anon_sym_LPAREN,
    ACTIONS(4590), 1,
      anon_sym_LBRACK,
    ACTIONS(4592), 1,
      anon_sym_DOT,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4798), 1,
      anon_sym_as,
    ACTIONS(4800), 1,
      anon_sym_BANG,
    ACTIONS(4836), 1,
      anon_sym_satisfies,
    ACTIONS(4922), 1,
      anon_sym_LT,
    ACTIONS(4928), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4930), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4932), 1,
      anon_sym_GT_GT,
    ACTIONS(4936), 1,
      anon_sym_AMP,
    ACTIONS(4938), 1,
      anon_sym_CARET,
    ACTIONS(4940), 1,
      anon_sym_PIPE,
    ACTIONS(4944), 1,
      anon_sym_PERCENT,
    ACTIONS(4946), 1,
      anon_sym_STAR_STAR,
    ACTIONS(4954), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(4956), 1,
      sym__ternary_qmark,
    STATE(2019), 1,
      sym_type_arguments,
    STATE(2130), 1,
      sym_arguments,
    STATE(4524), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4924), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(4926), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(4934), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(4942), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4950), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4952), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(4948), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
    ACTIONS(4792), 5,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_BQUOTE,
  [51129] = 11,
    ACTIONS(4588), 1,
      anon_sym_LPAREN,
    ACTIONS(4590), 1,
      anon_sym_LBRACK,
    ACTIONS(4592), 1,
      anon_sym_DOT,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4987), 1,
      anon_sym_LT,
    STATE(2019), 1,
      sym_type_arguments,
    STATE(2130), 1,
      sym_arguments,
    STATE(4524), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4785), 12,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4787), 23,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [51197] = 19,
    ACTIONS(237), 1,
      anon_sym_COMMA,
    ACTIONS(1550), 1,
      anon_sym_DQUOTE,
    ACTIONS(1552), 1,
      anon_sym_SQUOTE,
    ACTIONS(2353), 1,
      anon_sym_async,
    ACTIONS(2355), 1,
      anon_sym_readonly,
    ACTIONS(2359), 1,
      anon_sym_override,
    ACTIONS(4622), 1,
      anon_sym_EQ,
    ACTIONS(4688), 1,
      anon_sym_LBRACK,
    ACTIONS(4990), 1,
      anon_sym_STAR,
    ACTIONS(4992), 1,
      anon_sym_RBRACE,
    STATE(2813), 1,
      sym_override_modifier,
    STATE(4792), 1,
      aux_sym_object_repeat1,
    STATE(4815), 1,
      aux_sym_object_pattern_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(2337), 2,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(2357), 2,
      anon_sym_get,
      anon_sym_set,
    STATE(3816), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(3814), 4,
      anon_sym_LPAREN,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_QMARK,
    ACTIONS(2351), 18,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [51280] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4284), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4286), 29,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_extends,
  [51331] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4308), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4310), 29,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_extends,
  [51382] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4308), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4310), 29,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_extends,
  [51433] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4308), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4310), 29,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_extends,
  [51484] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4316), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4318), 29,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_extends,
  [51535] = 6,
    ACTIONS(4994), 1,
      anon_sym_AMP,
    ACTIONS(4996), 1,
      anon_sym_PIPE,
    ACTIONS(4998), 1,
      anon_sym_extends,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4332), 11,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4334), 28,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [51592] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3423), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(3425), 29,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_extends,
  [51643] = 5,
    ACTIONS(1696), 1,
      anon_sym_EQ,
    ACTIONS(4654), 1,
      sym__automatic_semicolon,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(1692), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(1690), 27,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [51698] = 31,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_as,
    ACTIONS(4640), 1,
      anon_sym_BANG,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4649), 1,
      anon_sym_satisfies,
    ACTIONS(4875), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4877), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4879), 1,
      anon_sym_GT_GT,
    ACTIONS(4883), 1,
      anon_sym_AMP,
    ACTIONS(4885), 1,
      anon_sym_CARET,
    ACTIONS(4887), 1,
      anon_sym_PIPE,
    ACTIONS(4891), 1,
      anon_sym_PERCENT,
    ACTIONS(4893), 1,
      anon_sym_STAR_STAR,
    ACTIONS(4895), 1,
      anon_sym_LT,
    ACTIONS(4903), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(4905), 1,
      sym__ternary_qmark,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4867), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(4873), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(4881), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(4889), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4899), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4901), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(4897), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
    ACTIONS(4468), 4,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_BQUOTE,
  [51805] = 31,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_as,
    ACTIONS(4640), 1,
      anon_sym_BANG,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4649), 1,
      anon_sym_satisfies,
    ACTIONS(4875), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4877), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4879), 1,
      anon_sym_GT_GT,
    ACTIONS(4883), 1,
      anon_sym_AMP,
    ACTIONS(4885), 1,
      anon_sym_CARET,
    ACTIONS(4887), 1,
      anon_sym_PIPE,
    ACTIONS(4891), 1,
      anon_sym_PERCENT,
    ACTIONS(4893), 1,
      anon_sym_STAR_STAR,
    ACTIONS(4895), 1,
      anon_sym_LT,
    ACTIONS(4903), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(4905), 1,
      sym__ternary_qmark,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4867), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(4873), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(4881), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(4889), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4899), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4901), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(4897), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
    ACTIONS(4758), 4,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_BQUOTE,
  [51912] = 31,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_as,
    ACTIONS(4640), 1,
      anon_sym_BANG,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4649), 1,
      anon_sym_satisfies,
    ACTIONS(4875), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4877), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4879), 1,
      anon_sym_GT_GT,
    ACTIONS(4883), 1,
      anon_sym_AMP,
    ACTIONS(4885), 1,
      anon_sym_CARET,
    ACTIONS(4887), 1,
      anon_sym_PIPE,
    ACTIONS(4891), 1,
      anon_sym_PERCENT,
    ACTIONS(4893), 1,
      anon_sym_STAR_STAR,
    ACTIONS(4895), 1,
      anon_sym_LT,
    ACTIONS(4903), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(4905), 1,
      sym__ternary_qmark,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4867), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(4873), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(4881), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(4889), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4899), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4901), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(4897), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
    ACTIONS(4744), 4,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_BQUOTE,
  [52019] = 19,
    ACTIONS(237), 1,
      anon_sym_COMMA,
    ACTIONS(694), 1,
      anon_sym_RBRACE,
    ACTIONS(1550), 1,
      anon_sym_DQUOTE,
    ACTIONS(1552), 1,
      anon_sym_SQUOTE,
    ACTIONS(2353), 1,
      anon_sym_async,
    ACTIONS(2355), 1,
      anon_sym_readonly,
    ACTIONS(2359), 1,
      anon_sym_override,
    ACTIONS(4622), 1,
      anon_sym_EQ,
    ACTIONS(4688), 1,
      anon_sym_LBRACK,
    ACTIONS(4990), 1,
      anon_sym_STAR,
    STATE(2813), 1,
      sym_override_modifier,
    STATE(4792), 1,
      aux_sym_object_repeat1,
    STATE(4815), 1,
      aux_sym_object_pattern_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(2337), 2,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(2357), 2,
      anon_sym_get,
      anon_sym_set,
    STATE(3816), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(3814), 4,
      anon_sym_LPAREN,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_QMARK,
    ACTIONS(2351), 18,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [52102] = 31,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_as,
    ACTIONS(4640), 1,
      anon_sym_BANG,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4649), 1,
      anon_sym_satisfies,
    ACTIONS(4875), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4877), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4879), 1,
      anon_sym_GT_GT,
    ACTIONS(4883), 1,
      anon_sym_AMP,
    ACTIONS(4885), 1,
      anon_sym_CARET,
    ACTIONS(4887), 1,
      anon_sym_PIPE,
    ACTIONS(4891), 1,
      anon_sym_PERCENT,
    ACTIONS(4893), 1,
      anon_sym_STAR_STAR,
    ACTIONS(4895), 1,
      anon_sym_LT,
    ACTIONS(4903), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(4905), 1,
      sym__ternary_qmark,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4867), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(4873), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(4881), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(4889), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4899), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4901), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(4897), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
    ACTIONS(4504), 4,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_BQUOTE,
  [52209] = 18,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4879), 1,
      anon_sym_GT_GT,
    ACTIONS(4891), 1,
      anon_sym_PERCENT,
    ACTIONS(4893), 1,
      anon_sym_STAR_STAR,
    ACTIONS(4895), 1,
      anon_sym_LT,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4867), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(4881), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(4889), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4762), 7,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4760), 16,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [52290] = 14,
    ACTIONS(1626), 1,
      anon_sym_DQUOTE,
    ACTIONS(1628), 1,
      anon_sym_SQUOTE,
    ACTIONS(3722), 1,
      anon_sym_override,
    ACTIONS(4624), 1,
      anon_sym_LBRACK,
    ACTIONS(5000), 1,
      anon_sym_STAR,
    ACTIONS(5002), 1,
      anon_sym_async,
    ACTIONS(5006), 1,
      anon_sym_readonly,
    STATE(2789), 1,
      sym_override_modifier,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(5004), 2,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(5008), 2,
      anon_sym_get,
      anon_sym_set,
    STATE(3147), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(3814), 9,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_QMARK,
      anon_sym_PIPE_RBRACE,
    ACTIONS(3700), 18,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [52363] = 33,
    ACTIONS(4588), 1,
      anon_sym_LPAREN,
    ACTIONS(4590), 1,
      anon_sym_LBRACK,
    ACTIONS(4592), 1,
      anon_sym_DOT,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4798), 1,
      anon_sym_as,
    ACTIONS(4800), 1,
      anon_sym_BANG,
    ACTIONS(4804), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4806), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4808), 1,
      anon_sym_GT_GT,
    ACTIONS(4812), 1,
      anon_sym_AMP,
    ACTIONS(4814), 1,
      anon_sym_CARET,
    ACTIONS(4816), 1,
      anon_sym_PIPE,
    ACTIONS(4820), 1,
      anon_sym_PERCENT,
    ACTIONS(4822), 1,
      anon_sym_STAR_STAR,
    ACTIONS(4824), 1,
      anon_sym_LT,
    ACTIONS(4832), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(4836), 1,
      anon_sym_satisfies,
    ACTIONS(4838), 1,
      sym__ternary_qmark,
    ACTIONS(5010), 1,
      anon_sym_COMMA,
    STATE(2019), 1,
      sym_type_arguments,
    STATE(2130), 1,
      sym_arguments,
    STATE(4417), 1,
      aux_sym_sequence_expression_repeat1,
    STATE(4524), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4796), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(4802), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(4810), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(4818), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4828), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4830), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(4834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(5012), 2,
      sym__automatic_semicolon,
      anon_sym_SEMI,
    ACTIONS(4826), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [52474] = 32,
    ACTIONS(4588), 1,
      anon_sym_LPAREN,
    ACTIONS(4590), 1,
      anon_sym_LBRACK,
    ACTIONS(4592), 1,
      anon_sym_DOT,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4798), 1,
      anon_sym_as,
    ACTIONS(4800), 1,
      anon_sym_BANG,
    ACTIONS(4836), 1,
      anon_sym_satisfies,
    ACTIONS(4922), 1,
      anon_sym_LT,
    ACTIONS(4926), 1,
      anon_sym_GT,
    ACTIONS(4928), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4930), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4932), 1,
      anon_sym_GT_GT,
    ACTIONS(4936), 1,
      anon_sym_AMP,
    ACTIONS(4938), 1,
      anon_sym_CARET,
    ACTIONS(4940), 1,
      anon_sym_PIPE,
    ACTIONS(4944), 1,
      anon_sym_PERCENT,
    ACTIONS(4946), 1,
      anon_sym_STAR_STAR,
    ACTIONS(4954), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(4956), 1,
      sym__ternary_qmark,
    ACTIONS(5016), 1,
      anon_sym_in,
    STATE(2019), 1,
      sym_type_arguments,
    STATE(2130), 1,
      sym_arguments,
    STATE(4524), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4924), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(4934), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(4942), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4950), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4952), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(4948), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
    ACTIONS(5014), 4,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_of,
  [52583] = 13,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4893), 1,
      anon_sym_STAR_STAR,
    ACTIONS(5019), 1,
      anon_sym_LT,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4762), 12,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4760), 19,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [52654] = 25,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4762), 1,
      anon_sym_BANG,
    ACTIONS(4879), 1,
      anon_sym_GT_GT,
    ACTIONS(4883), 1,
      anon_sym_AMP,
    ACTIONS(4885), 1,
      anon_sym_CARET,
    ACTIONS(4887), 1,
      anon_sym_PIPE,
    ACTIONS(4891), 1,
      anon_sym_PERCENT,
    ACTIONS(4893), 1,
      anon_sym_STAR_STAR,
    ACTIONS(4895), 1,
      anon_sym_LT,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4867), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(4873), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(4881), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(4889), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4899), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4901), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(4897), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
    ACTIONS(4760), 10,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [52749] = 26,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4762), 1,
      anon_sym_BANG,
    ACTIONS(4875), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4879), 1,
      anon_sym_GT_GT,
    ACTIONS(4883), 1,
      anon_sym_AMP,
    ACTIONS(4885), 1,
      anon_sym_CARET,
    ACTIONS(4887), 1,
      anon_sym_PIPE,
    ACTIONS(4891), 1,
      anon_sym_PERCENT,
    ACTIONS(4893), 1,
      anon_sym_STAR_STAR,
    ACTIONS(4895), 1,
      anon_sym_LT,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4867), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(4873), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(4881), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(4889), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4899), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4901), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(4897), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
    ACTIONS(4760), 9,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [52846] = 16,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4891), 1,
      anon_sym_PERCENT,
    ACTIONS(4893), 1,
      anon_sym_STAR_STAR,
    ACTIONS(5019), 1,
      anon_sym_LT,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4867), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(4889), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4762), 8,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4760), 18,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [52923] = 22,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4879), 1,
      anon_sym_GT_GT,
    ACTIONS(4891), 1,
      anon_sym_PERCENT,
    ACTIONS(4893), 1,
      anon_sym_STAR_STAR,
    ACTIONS(4895), 1,
      anon_sym_LT,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4867), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(4873), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(4881), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(4889), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4899), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4901), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(4762), 3,
      anon_sym_BANG,
      anon_sym_AMP,
      anon_sym_PIPE,
    ACTIONS(4897), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
    ACTIONS(4760), 11,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_CARET,
      anon_sym_QMARK_QMARK,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [53012] = 23,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4879), 1,
      anon_sym_GT_GT,
    ACTIONS(4883), 1,
      anon_sym_AMP,
    ACTIONS(4891), 1,
      anon_sym_PERCENT,
    ACTIONS(4893), 1,
      anon_sym_STAR_STAR,
    ACTIONS(4895), 1,
      anon_sym_LT,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4762), 2,
      anon_sym_BANG,
      anon_sym_PIPE,
    ACTIONS(4867), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(4873), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(4881), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(4889), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4899), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4901), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(4897), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
    ACTIONS(4760), 11,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_CARET,
      anon_sym_QMARK_QMARK,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [53103] = 24,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4879), 1,
      anon_sym_GT_GT,
    ACTIONS(4883), 1,
      anon_sym_AMP,
    ACTIONS(4885), 1,
      anon_sym_CARET,
    ACTIONS(4891), 1,
      anon_sym_PERCENT,
    ACTIONS(4893), 1,
      anon_sym_STAR_STAR,
    ACTIONS(4895), 1,
      anon_sym_LT,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4762), 2,
      anon_sym_BANG,
      anon_sym_PIPE,
    ACTIONS(4867), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(4873), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(4881), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(4889), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4899), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4901), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(4897), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
    ACTIONS(4760), 10,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [53196] = 33,
    ACTIONS(4588), 1,
      anon_sym_LPAREN,
    ACTIONS(4590), 1,
      anon_sym_LBRACK,
    ACTIONS(4592), 1,
      anon_sym_DOT,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4798), 1,
      anon_sym_as,
    ACTIONS(4800), 1,
      anon_sym_BANG,
    ACTIONS(4804), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4806), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4808), 1,
      anon_sym_GT_GT,
    ACTIONS(4812), 1,
      anon_sym_AMP,
    ACTIONS(4814), 1,
      anon_sym_CARET,
    ACTIONS(4816), 1,
      anon_sym_PIPE,
    ACTIONS(4820), 1,
      anon_sym_PERCENT,
    ACTIONS(4822), 1,
      anon_sym_STAR_STAR,
    ACTIONS(4824), 1,
      anon_sym_LT,
    ACTIONS(4832), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(4836), 1,
      anon_sym_satisfies,
    ACTIONS(4838), 1,
      sym__ternary_qmark,
    ACTIONS(5010), 1,
      anon_sym_COMMA,
    STATE(2019), 1,
      sym_type_arguments,
    STATE(2130), 1,
      sym_arguments,
    STATE(4417), 1,
      aux_sym_sequence_expression_repeat1,
    STATE(4524), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4796), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(4802), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(4810), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(4818), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4828), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4830), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(4834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(5022), 2,
      sym__automatic_semicolon,
      anon_sym_SEMI,
    ACTIONS(4826), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [53307] = 15,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4891), 1,
      anon_sym_PERCENT,
    ACTIONS(4893), 1,
      anon_sym_STAR_STAR,
    ACTIONS(5019), 1,
      anon_sym_LT,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4867), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(4762), 10,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4760), 18,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [53382] = 16,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_as,
    ACTIONS(4640), 1,
      anon_sym_BANG,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4649), 1,
      anon_sym_satisfies,
    ACTIONS(4893), 1,
      anon_sym_STAR_STAR,
    ACTIONS(5019), 1,
      anon_sym_LT,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4762), 11,
      anon_sym_STAR,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4760), 17,
      sym__ternary_qmark,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_BQUOTE,
  [53459] = 33,
    ACTIONS(4588), 1,
      anon_sym_LPAREN,
    ACTIONS(4590), 1,
      anon_sym_LBRACK,
    ACTIONS(4592), 1,
      anon_sym_DOT,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4798), 1,
      anon_sym_as,
    ACTIONS(4800), 1,
      anon_sym_BANG,
    ACTIONS(4804), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4806), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4808), 1,
      anon_sym_GT_GT,
    ACTIONS(4812), 1,
      anon_sym_AMP,
    ACTIONS(4814), 1,
      anon_sym_CARET,
    ACTIONS(4816), 1,
      anon_sym_PIPE,
    ACTIONS(4820), 1,
      anon_sym_PERCENT,
    ACTIONS(4822), 1,
      anon_sym_STAR_STAR,
    ACTIONS(4824), 1,
      anon_sym_LT,
    ACTIONS(4832), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(4836), 1,
      anon_sym_satisfies,
    ACTIONS(4838), 1,
      sym__ternary_qmark,
    ACTIONS(5010), 1,
      anon_sym_COMMA,
    STATE(2019), 1,
      sym_type_arguments,
    STATE(2130), 1,
      sym_arguments,
    STATE(4417), 1,
      aux_sym_sequence_expression_repeat1,
    STATE(4524), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4796), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(4802), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(4810), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(4818), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4828), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4830), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(4834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(5024), 2,
      sym__automatic_semicolon,
      anon_sym_SEMI,
    ACTIONS(4826), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [53570] = 20,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4879), 1,
      anon_sym_GT_GT,
    ACTIONS(4891), 1,
      anon_sym_PERCENT,
    ACTIONS(4893), 1,
      anon_sym_STAR_STAR,
    ACTIONS(4895), 1,
      anon_sym_LT,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4867), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(4873), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(4881), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(4889), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4897), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
    ACTIONS(4762), 5,
      anon_sym_BANG,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4760), 13,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_CARET,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [53655] = 4,
    ACTIONS(3510), 1,
      anon_sym_EQ,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3492), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(3496), 28,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [53708] = 27,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4762), 1,
      anon_sym_BANG,
    ACTIONS(4875), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4877), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4879), 1,
      anon_sym_GT_GT,
    ACTIONS(4883), 1,
      anon_sym_AMP,
    ACTIONS(4885), 1,
      anon_sym_CARET,
    ACTIONS(4887), 1,
      anon_sym_PIPE,
    ACTIONS(4891), 1,
      anon_sym_PERCENT,
    ACTIONS(4893), 1,
      anon_sym_STAR_STAR,
    ACTIONS(4895), 1,
      anon_sym_LT,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4867), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(4873), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(4881), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(4889), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4899), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4901), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(4897), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
    ACTIONS(4760), 8,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_QMARK_QMARK,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [53807] = 4,
    ACTIONS(4110), 1,
      anon_sym_extends,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4296), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4298), 28,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [53860] = 6,
    ACTIONS(4994), 1,
      anon_sym_AMP,
    ACTIONS(4996), 1,
      anon_sym_PIPE,
    ACTIONS(4998), 1,
      anon_sym_extends,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4296), 11,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4298), 28,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [53917] = 4,
    ACTIONS(5026), 1,
      anon_sym_DOT,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4250), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4252), 28,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_LBRACK,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_extends,
  [53970] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4170), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4172), 29,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_extends,
  [54021] = 31,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_as,
    ACTIONS(4640), 1,
      anon_sym_BANG,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4649), 1,
      anon_sym_satisfies,
    ACTIONS(4875), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4877), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4879), 1,
      anon_sym_GT_GT,
    ACTIONS(4883), 1,
      anon_sym_AMP,
    ACTIONS(4885), 1,
      anon_sym_CARET,
    ACTIONS(4887), 1,
      anon_sym_PIPE,
    ACTIONS(4891), 1,
      anon_sym_PERCENT,
    ACTIONS(4893), 1,
      anon_sym_STAR_STAR,
    ACTIONS(4895), 1,
      anon_sym_LT,
    ACTIONS(4903), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(4905), 1,
      sym__ternary_qmark,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4867), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(4873), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(4881), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(4889), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4899), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4901), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(4897), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
    ACTIONS(4522), 4,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_BQUOTE,
  [54128] = 31,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_as,
    ACTIONS(4640), 1,
      anon_sym_BANG,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4649), 1,
      anon_sym_satisfies,
    ACTIONS(4875), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4877), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4879), 1,
      anon_sym_GT_GT,
    ACTIONS(4883), 1,
      anon_sym_AMP,
    ACTIONS(4885), 1,
      anon_sym_CARET,
    ACTIONS(4887), 1,
      anon_sym_PIPE,
    ACTIONS(4891), 1,
      anon_sym_PERCENT,
    ACTIONS(4893), 1,
      anon_sym_STAR_STAR,
    ACTIONS(4895), 1,
      anon_sym_LT,
    ACTIONS(4903), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(4905), 1,
      sym__ternary_qmark,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4867), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(4873), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(4881), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(4889), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4899), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4901), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(4897), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
    ACTIONS(4767), 4,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_BQUOTE,
  [54235] = 4,
    ACTIONS(5028), 1,
      anon_sym_LBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4170), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4172), 28,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_extends,
  [54288] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4108), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4110), 29,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_extends,
  [54339] = 19,
    ACTIONS(237), 1,
      anon_sym_COMMA,
    ACTIONS(667), 1,
      anon_sym_RBRACE,
    ACTIONS(1550), 1,
      anon_sym_DQUOTE,
    ACTIONS(1552), 1,
      anon_sym_SQUOTE,
    ACTIONS(2353), 1,
      anon_sym_async,
    ACTIONS(2355), 1,
      anon_sym_readonly,
    ACTIONS(2359), 1,
      anon_sym_override,
    ACTIONS(4622), 1,
      anon_sym_EQ,
    ACTIONS(4688), 1,
      anon_sym_LBRACK,
    ACTIONS(4990), 1,
      anon_sym_STAR,
    STATE(2813), 1,
      sym_override_modifier,
    STATE(4792), 1,
      aux_sym_object_repeat1,
    STATE(4815), 1,
      aux_sym_object_pattern_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(2337), 2,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(2357), 2,
      anon_sym_get,
      anon_sym_set,
    STATE(3816), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(3814), 4,
      anon_sym_LPAREN,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_QMARK,
    ACTIONS(2351), 18,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [54422] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4140), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4142), 29,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_extends,
  [54473] = 31,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_as,
    ACTIONS(4640), 1,
      anon_sym_BANG,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4649), 1,
      anon_sym_satisfies,
    ACTIONS(4875), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4877), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4879), 1,
      anon_sym_GT_GT,
    ACTIONS(4883), 1,
      anon_sym_AMP,
    ACTIONS(4885), 1,
      anon_sym_CARET,
    ACTIONS(4887), 1,
      anon_sym_PIPE,
    ACTIONS(4891), 1,
      anon_sym_PERCENT,
    ACTIONS(4893), 1,
      anon_sym_STAR_STAR,
    ACTIONS(4895), 1,
      anon_sym_LT,
    ACTIONS(4903), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(4905), 1,
      sym__ternary_qmark,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4867), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(4873), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(4881), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(4889), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4899), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4901), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(4897), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
    ACTIONS(4756), 4,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_BQUOTE,
  [54580] = 6,
    ACTIONS(4106), 1,
      anon_sym_extends,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4510), 2,
      anon_sym_COMMA,
      anon_sym_LBRACK,
    ACTIONS(4513), 3,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_GT,
    ACTIONS(3492), 10,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(3496), 26,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [54637] = 7,
    ACTIONS(3562), 1,
      anon_sym_EQ,
    ACTIONS(4408), 1,
      anon_sym_extends,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4608), 2,
      anon_sym_COMMA,
      anon_sym_LBRACK,
    ACTIONS(4611), 3,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_GT,
    ACTIONS(3492), 10,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(3496), 25,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [54696] = 11,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(5030), 1,
      anon_sym_LT,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4785), 12,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4787), 22,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [54763] = 15,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_as,
    ACTIONS(4640), 1,
      anon_sym_BANG,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4649), 1,
      anon_sym_satisfies,
    ACTIONS(5033), 1,
      anon_sym_LT,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4634), 11,
      anon_sym_STAR,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4638), 18,
      sym__ternary_qmark,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_BQUOTE,
  [54838] = 31,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_as,
    ACTIONS(4640), 1,
      anon_sym_BANG,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4649), 1,
      anon_sym_satisfies,
    ACTIONS(4875), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4877), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4879), 1,
      anon_sym_GT_GT,
    ACTIONS(4883), 1,
      anon_sym_AMP,
    ACTIONS(4885), 1,
      anon_sym_CARET,
    ACTIONS(4887), 1,
      anon_sym_PIPE,
    ACTIONS(4891), 1,
      anon_sym_PERCENT,
    ACTIONS(4893), 1,
      anon_sym_STAR_STAR,
    ACTIONS(4895), 1,
      anon_sym_LT,
    ACTIONS(4903), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(4905), 1,
      sym__ternary_qmark,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4867), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(4873), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(4881), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(4889), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4899), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4901), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(4897), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
    ACTIONS(4792), 4,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_BQUOTE,
  [54945] = 6,
    ACTIONS(4994), 1,
      anon_sym_AMP,
    ACTIONS(4996), 1,
      anon_sym_PIPE,
    ACTIONS(4998), 1,
      anon_sym_extends,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4272), 11,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4274), 28,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [55002] = 6,
    ACTIONS(1696), 1,
      anon_sym_EQ,
    ACTIONS(1700), 1,
      sym__automatic_semicolon,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(1690), 2,
      anon_sym_else,
      anon_sym_while,
    ACTIONS(1694), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(1698), 25,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [55059] = 31,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_as,
    ACTIONS(4640), 1,
      anon_sym_BANG,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4649), 1,
      anon_sym_satisfies,
    ACTIONS(4875), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4877), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4879), 1,
      anon_sym_GT_GT,
    ACTIONS(4883), 1,
      anon_sym_AMP,
    ACTIONS(4885), 1,
      anon_sym_CARET,
    ACTIONS(4887), 1,
      anon_sym_PIPE,
    ACTIONS(4891), 1,
      anon_sym_PERCENT,
    ACTIONS(4893), 1,
      anon_sym_STAR_STAR,
    ACTIONS(4895), 1,
      anon_sym_LT,
    ACTIONS(4903), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(4905), 1,
      sym__ternary_qmark,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4867), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(4873), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(4881), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(4889), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4899), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4901), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(4897), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
    ACTIONS(4546), 4,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_BQUOTE,
  [55166] = 4,
    ACTIONS(4146), 1,
      anon_sym_EQ,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4144), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4148), 28,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [55219] = 12,
    ACTIONS(1626), 1,
      anon_sym_DQUOTE,
    ACTIONS(1628), 1,
      anon_sym_SQUOTE,
    ACTIONS(4656), 1,
      anon_sym_STAR,
    ACTIONS(4660), 1,
      anon_sym_async,
    ACTIONS(4682), 1,
      anon_sym_abstract,
    ACTIONS(4698), 1,
      anon_sym_LBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4662), 2,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(4666), 2,
      anon_sym_get,
      anon_sym_set,
    STATE(3082), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(3814), 9,
      sym__automatic_semicolon,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_BANG,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_QMARK,
    ACTIONS(3700), 20,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [55288] = 31,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_as,
    ACTIONS(4640), 1,
      anon_sym_BANG,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4649), 1,
      anon_sym_satisfies,
    ACTIONS(4875), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4877), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4879), 1,
      anon_sym_GT_GT,
    ACTIONS(4883), 1,
      anon_sym_AMP,
    ACTIONS(4885), 1,
      anon_sym_CARET,
    ACTIONS(4887), 1,
      anon_sym_PIPE,
    ACTIONS(4891), 1,
      anon_sym_PERCENT,
    ACTIONS(4893), 1,
      anon_sym_STAR_STAR,
    ACTIONS(4895), 1,
      anon_sym_LT,
    ACTIONS(4903), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(4905), 1,
      sym__ternary_qmark,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4867), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(4873), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(4881), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(4889), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4899), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4901), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(4897), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
    ACTIONS(4554), 4,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_BQUOTE,
  [55395] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4368), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4370), 29,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_extends,
  [55446] = 31,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_as,
    ACTIONS(4640), 1,
      anon_sym_BANG,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4649), 1,
      anon_sym_satisfies,
    ACTIONS(4875), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4877), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4879), 1,
      anon_sym_GT_GT,
    ACTIONS(4883), 1,
      anon_sym_AMP,
    ACTIONS(4885), 1,
      anon_sym_CARET,
    ACTIONS(4887), 1,
      anon_sym_PIPE,
    ACTIONS(4891), 1,
      anon_sym_PERCENT,
    ACTIONS(4893), 1,
      anon_sym_STAR_STAR,
    ACTIONS(4895), 1,
      anon_sym_LT,
    ACTIONS(4903), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(4905), 1,
      sym__ternary_qmark,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4867), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(4873), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(4881), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(4889), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4899), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4901), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(4897), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
    ACTIONS(4558), 4,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_BQUOTE,
  [55553] = 4,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(1971), 6,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(3814), 11,
      sym__automatic_semicolon,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_BANG,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_QMARK,
      anon_sym_PIPE_RBRACE,
    ACTIONS(1969), 25,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
      anon_sym_abstract,
      anon_sym_accessor,
  [55606] = 7,
    ACTIONS(1696), 1,
      anon_sym_EQ,
    ACTIONS(4126), 1,
      anon_sym_LBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(2373), 2,
      anon_sym_COMMA,
      anon_sym_extends,
    ACTIONS(4129), 3,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_GT,
    ACTIONS(1694), 10,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1698), 25,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_of,
      anon_sym_COLON,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [55665] = 7,
    ACTIONS(3530), 1,
      anon_sym_DOT,
    ACTIONS(3532), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3522), 2,
      anon_sym_AMP,
      anon_sym_PIPE,
    ACTIONS(3512), 7,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_extends,
      anon_sym_PIPE_RBRACE,
    ACTIONS(3492), 11,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(3496), 20,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [55724] = 7,
    ACTIONS(4146), 1,
      anon_sym_EQ,
    ACTIONS(4150), 1,
      anon_sym_LBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4156), 2,
      anon_sym_COMMA,
      anon_sym_extends,
    ACTIONS(4153), 3,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_GT,
    ACTIONS(4144), 10,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4148), 25,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_of,
      anon_sym_COLON,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [55783] = 5,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4184), 2,
      anon_sym_AMP,
      anon_sym_PIPE,
    ACTIONS(4182), 7,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_extends,
      anon_sym_PIPE_RBRACE,
    ACTIONS(3492), 11,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(3496), 22,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [55838] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(2375), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(2373), 29,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_extends,
  [55889] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4114), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4116), 29,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_extends,
  [55940] = 33,
    ACTIONS(4588), 1,
      anon_sym_LPAREN,
    ACTIONS(4590), 1,
      anon_sym_LBRACK,
    ACTIONS(4592), 1,
      anon_sym_DOT,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4798), 1,
      anon_sym_as,
    ACTIONS(4800), 1,
      anon_sym_BANG,
    ACTIONS(4804), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4806), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4808), 1,
      anon_sym_GT_GT,
    ACTIONS(4812), 1,
      anon_sym_AMP,
    ACTIONS(4814), 1,
      anon_sym_CARET,
    ACTIONS(4816), 1,
      anon_sym_PIPE,
    ACTIONS(4820), 1,
      anon_sym_PERCENT,
    ACTIONS(4822), 1,
      anon_sym_STAR_STAR,
    ACTIONS(4824), 1,
      anon_sym_LT,
    ACTIONS(4832), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(4836), 1,
      anon_sym_satisfies,
    ACTIONS(4838), 1,
      sym__ternary_qmark,
    ACTIONS(5036), 1,
      anon_sym_COMMA,
    ACTIONS(5039), 1,
      anon_sym_RBRACE,
    STATE(2019), 1,
      sym_type_arguments,
    STATE(2130), 1,
      sym_arguments,
    STATE(4524), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4796), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(4802), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(4810), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(4818), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4828), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4830), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(4834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(5041), 2,
      sym__automatic_semicolon,
      anon_sym_SEMI,
    ACTIONS(4826), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [56051] = 6,
    ACTIONS(4994), 1,
      anon_sym_AMP,
    ACTIONS(4996), 1,
      anon_sym_PIPE,
    ACTIONS(4998), 1,
      anon_sym_extends,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4434), 11,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4436), 28,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [56108] = 6,
    ACTIONS(4994), 1,
      anon_sym_AMP,
    ACTIONS(4996), 1,
      anon_sym_PIPE,
    ACTIONS(4998), 1,
      anon_sym_extends,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4442), 11,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4444), 28,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [56165] = 33,
    ACTIONS(4588), 1,
      anon_sym_LPAREN,
    ACTIONS(4590), 1,
      anon_sym_LBRACK,
    ACTIONS(4592), 1,
      anon_sym_DOT,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4798), 1,
      anon_sym_as,
    ACTIONS(4800), 1,
      anon_sym_BANG,
    ACTIONS(4804), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4806), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4808), 1,
      anon_sym_GT_GT,
    ACTIONS(4812), 1,
      anon_sym_AMP,
    ACTIONS(4814), 1,
      anon_sym_CARET,
    ACTIONS(4816), 1,
      anon_sym_PIPE,
    ACTIONS(4820), 1,
      anon_sym_PERCENT,
    ACTIONS(4822), 1,
      anon_sym_STAR_STAR,
    ACTIONS(4824), 1,
      anon_sym_LT,
    ACTIONS(4832), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(4836), 1,
      anon_sym_satisfies,
    ACTIONS(4838), 1,
      sym__ternary_qmark,
    ACTIONS(5036), 1,
      anon_sym_COMMA,
    ACTIONS(5039), 1,
      anon_sym_RBRACE,
    STATE(2019), 1,
      sym_type_arguments,
    STATE(2130), 1,
      sym_arguments,
    STATE(4524), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4744), 2,
      sym__automatic_semicolon,
      anon_sym_SEMI,
    ACTIONS(4796), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(4802), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(4810), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(4818), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4828), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4830), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(4834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4826), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [56276] = 33,
    ACTIONS(4588), 1,
      anon_sym_LPAREN,
    ACTIONS(4590), 1,
      anon_sym_LBRACK,
    ACTIONS(4592), 1,
      anon_sym_DOT,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4798), 1,
      anon_sym_as,
    ACTIONS(4800), 1,
      anon_sym_BANG,
    ACTIONS(4804), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4806), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4808), 1,
      anon_sym_GT_GT,
    ACTIONS(4812), 1,
      anon_sym_AMP,
    ACTIONS(4814), 1,
      anon_sym_CARET,
    ACTIONS(4816), 1,
      anon_sym_PIPE,
    ACTIONS(4820), 1,
      anon_sym_PERCENT,
    ACTIONS(4822), 1,
      anon_sym_STAR_STAR,
    ACTIONS(4824), 1,
      anon_sym_LT,
    ACTIONS(4832), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(4836), 1,
      anon_sym_satisfies,
    ACTIONS(4838), 1,
      sym__ternary_qmark,
    ACTIONS(5039), 1,
      anon_sym_RBRACE,
    ACTIONS(5043), 1,
      anon_sym_COMMA,
    STATE(2019), 1,
      sym_type_arguments,
    STATE(2130), 1,
      sym_arguments,
    STATE(4524), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4758), 2,
      sym__automatic_semicolon,
      anon_sym_SEMI,
    ACTIONS(4796), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(4802), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(4810), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(4818), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4828), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4830), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(4834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4826), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [56387] = 33,
    ACTIONS(4588), 1,
      anon_sym_LPAREN,
    ACTIONS(4590), 1,
      anon_sym_LBRACK,
    ACTIONS(4592), 1,
      anon_sym_DOT,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4798), 1,
      anon_sym_as,
    ACTIONS(4800), 1,
      anon_sym_BANG,
    ACTIONS(4804), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4806), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4808), 1,
      anon_sym_GT_GT,
    ACTIONS(4812), 1,
      anon_sym_AMP,
    ACTIONS(4814), 1,
      anon_sym_CARET,
    ACTIONS(4816), 1,
      anon_sym_PIPE,
    ACTIONS(4820), 1,
      anon_sym_PERCENT,
    ACTIONS(4822), 1,
      anon_sym_STAR_STAR,
    ACTIONS(4824), 1,
      anon_sym_LT,
    ACTIONS(4832), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(4836), 1,
      anon_sym_satisfies,
    ACTIONS(4838), 1,
      sym__ternary_qmark,
    ACTIONS(5046), 1,
      anon_sym_COMMA,
    ACTIONS(5049), 1,
      anon_sym_RBRACE,
    STATE(2019), 1,
      sym_type_arguments,
    STATE(2130), 1,
      sym_arguments,
    STATE(4524), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4758), 2,
      sym__automatic_semicolon,
      anon_sym_SEMI,
    ACTIONS(4796), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(4802), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(4810), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(4818), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4828), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4830), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(4834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4826), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [56498] = 31,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_as,
    ACTIONS(4640), 1,
      anon_sym_BANG,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4649), 1,
      anon_sym_satisfies,
    ACTIONS(4875), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4877), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4879), 1,
      anon_sym_GT_GT,
    ACTIONS(4883), 1,
      anon_sym_AMP,
    ACTIONS(4885), 1,
      anon_sym_CARET,
    ACTIONS(4887), 1,
      anon_sym_PIPE,
    ACTIONS(4891), 1,
      anon_sym_PERCENT,
    ACTIONS(4893), 1,
      anon_sym_STAR_STAR,
    ACTIONS(4895), 1,
      anon_sym_LT,
    ACTIONS(4903), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(4905), 1,
      sym__ternary_qmark,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4867), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(4873), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(4881), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(4889), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4899), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4901), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(4897), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
    ACTIONS(4769), 4,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_BQUOTE,
  [56605] = 19,
    ACTIONS(237), 1,
      anon_sym_COMMA,
    ACTIONS(1550), 1,
      anon_sym_DQUOTE,
    ACTIONS(1552), 1,
      anon_sym_SQUOTE,
    ACTIONS(2353), 1,
      anon_sym_async,
    ACTIONS(2355), 1,
      anon_sym_readonly,
    ACTIONS(2359), 1,
      anon_sym_override,
    ACTIONS(4622), 1,
      anon_sym_EQ,
    ACTIONS(4688), 1,
      anon_sym_LBRACK,
    ACTIONS(4990), 1,
      anon_sym_STAR,
    ACTIONS(5051), 1,
      anon_sym_RBRACE,
    STATE(2813), 1,
      sym_override_modifier,
    STATE(4792), 1,
      aux_sym_object_repeat1,
    STATE(4815), 1,
      aux_sym_object_pattern_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(2337), 2,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(2357), 2,
      anon_sym_get,
      anon_sym_set,
    STATE(3816), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(3814), 4,
      anon_sym_LPAREN,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_QMARK,
    ACTIONS(2351), 18,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [56688] = 5,
    ACTIONS(87), 1,
      anon_sym_BQUOTE,
    STATE(2228), 1,
      sym_template_string,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(1734), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(1736), 27,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_satisfies,
  [56743] = 9,
    ACTIONS(2373), 1,
      anon_sym_extends,
    ACTIONS(4126), 1,
      anon_sym_LBRACK,
    ACTIONS(4961), 1,
      anon_sym_RPAREN,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(1696), 2,
      anon_sym_EQ,
      anon_sym_QMARK,
    ACTIONS(4129), 2,
      anon_sym_AMP,
      anon_sym_PIPE,
    ACTIONS(4775), 2,
      anon_sym_COMMA,
      anon_sym_COLON,
    ACTIONS(1694), 11,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(1698), 22,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [56806] = 9,
    ACTIONS(4150), 1,
      anon_sym_LBRACK,
    ACTIONS(4156), 1,
      anon_sym_extends,
    ACTIONS(4965), 1,
      anon_sym_RPAREN,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4146), 2,
      anon_sym_EQ,
      anon_sym_QMARK,
    ACTIONS(4153), 2,
      anon_sym_AMP,
      anon_sym_PIPE,
    ACTIONS(4651), 2,
      anon_sym_COMMA,
      anon_sym_COLON,
    ACTIONS(4144), 11,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4148), 22,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [56869] = 4,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4120), 4,
      sym__automatic_semicolon,
      anon_sym_SEMI,
      anon_sym_extends,
      anon_sym_PIPE_RBRACE,
    ACTIONS(4288), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4290), 25,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [56922] = 4,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4322), 4,
      sym__automatic_semicolon,
      anon_sym_SEMI,
      anon_sym_extends,
      anon_sym_PIPE_RBRACE,
    ACTIONS(4288), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4290), 25,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [56975] = 19,
    ACTIONS(237), 1,
      anon_sym_COMMA,
    ACTIONS(1550), 1,
      anon_sym_DQUOTE,
    ACTIONS(1552), 1,
      anon_sym_SQUOTE,
    ACTIONS(2353), 1,
      anon_sym_async,
    ACTIONS(2355), 1,
      anon_sym_readonly,
    ACTIONS(2359), 1,
      anon_sym_override,
    ACTIONS(4622), 1,
      anon_sym_EQ,
    ACTIONS(4688), 1,
      anon_sym_LBRACK,
    ACTIONS(4990), 1,
      anon_sym_STAR,
    ACTIONS(5053), 1,
      anon_sym_RBRACE,
    STATE(2813), 1,
      sym_override_modifier,
    STATE(4792), 1,
      aux_sym_object_repeat1,
    STATE(4815), 1,
      aux_sym_object_pattern_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(2337), 2,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(2357), 2,
      anon_sym_get,
      anon_sym_set,
    STATE(3816), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(3814), 4,
      anon_sym_LPAREN,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_QMARK,
    ACTIONS(2351), 18,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [57058] = 10,
    ACTIONS(1696), 1,
      anon_sym_EQ,
    ACTIONS(2373), 1,
      anon_sym_extends,
    ACTIONS(2375), 1,
      anon_sym_QMARK,
    ACTIONS(4126), 1,
      anon_sym_LBRACK,
    ACTIONS(4859), 1,
      anon_sym_COLON,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4129), 2,
      anon_sym_AMP,
      anon_sym_PIPE,
    ACTIONS(4961), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK,
    ACTIONS(1694), 11,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(1698), 22,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [57123] = 10,
    ACTIONS(4146), 1,
      anon_sym_EQ,
    ACTIONS(4150), 1,
      anon_sym_LBRACK,
    ACTIONS(4156), 1,
      anon_sym_extends,
    ACTIONS(4270), 1,
      anon_sym_QMARK,
    ACTIONS(4850), 1,
      anon_sym_COLON,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4153), 2,
      anon_sym_AMP,
      anon_sym_PIPE,
    ACTIONS(4965), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK,
    ACTIONS(4144), 11,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4148), 22,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [57188] = 6,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4611), 2,
      anon_sym_AMP,
      anon_sym_PIPE,
    ACTIONS(4608), 3,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
    ACTIONS(4408), 4,
      sym__automatic_semicolon,
      anon_sym_SEMI,
      anon_sym_extends,
      anon_sym_PIPE_RBRACE,
    ACTIONS(3492), 11,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(3496), 22,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [57245] = 6,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4617), 2,
      anon_sym_AMP,
      anon_sym_PIPE,
    ACTIONS(4614), 3,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
    ACTIONS(4378), 4,
      sym__automatic_semicolon,
      anon_sym_SEMI,
      anon_sym_extends,
      anon_sym_PIPE_RBRACE,
    ACTIONS(4458), 11,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4460), 22,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [57302] = 6,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4513), 2,
      anon_sym_AMP,
      anon_sym_PIPE,
    ACTIONS(4510), 3,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
    ACTIONS(4106), 4,
      sym__automatic_semicolon,
      anon_sym_SEMI,
      anon_sym_extends,
      anon_sym_PIPE_RBRACE,
    ACTIONS(3492), 11,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(3496), 22,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [57359] = 31,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_as,
    ACTIONS(4640), 1,
      anon_sym_BANG,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4649), 1,
      anon_sym_satisfies,
    ACTIONS(4875), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4877), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4879), 1,
      anon_sym_GT_GT,
    ACTIONS(4883), 1,
      anon_sym_AMP,
    ACTIONS(4885), 1,
      anon_sym_CARET,
    ACTIONS(4887), 1,
      anon_sym_PIPE,
    ACTIONS(4891), 1,
      anon_sym_PERCENT,
    ACTIONS(4893), 1,
      anon_sym_STAR_STAR,
    ACTIONS(4895), 1,
      anon_sym_LT,
    ACTIONS(4903), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(4905), 1,
      sym__ternary_qmark,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4867), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(4873), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(4881), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(4889), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4899), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4901), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(4897), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
    ACTIONS(4771), 4,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_BQUOTE,
  [57466] = 12,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(5055), 1,
      anon_sym_LT,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4778), 12,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4780), 20,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [57535] = 4,
    ACTIONS(3494), 1,
      anon_sym_EQ,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3492), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(3496), 28,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [57588] = 14,
    ACTIONS(162), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1550), 1,
      anon_sym_DQUOTE,
    ACTIONS(1552), 1,
      anon_sym_SQUOTE,
    ACTIONS(3275), 1,
      anon_sym_LBRACE,
    ACTIONS(3942), 1,
      anon_sym_LBRACK,
    ACTIONS(5060), 1,
      anon_sym_COMMA,
    ACTIONS(5062), 1,
      anon_sym_RBRACE,
    STATE(4745), 1,
      aux_sym_object_pattern_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(5064), 2,
      sym_number,
      sym_private_property_identifier,
    STATE(4555), 3,
      sym_object_assignment_pattern,
      sym_rest_pattern,
      sym_pair_pattern,
    STATE(5509), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    STATE(5536), 3,
      sym_object_pattern,
      sym_array_pattern,
      sym__destructuring_pattern,
    ACTIONS(5058), 23,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [57661] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(2379), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(2377), 29,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_extends,
  [57712] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4320), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4322), 29,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_extends,
  [57763] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4324), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4326), 29,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_extends,
  [57814] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4328), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4330), 29,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_extends,
  [57865] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4342), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4344), 29,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_extends,
  [57916] = 14,
    ACTIONS(1626), 1,
      anon_sym_DQUOTE,
    ACTIONS(1628), 1,
      anon_sym_SQUOTE,
    ACTIONS(3722), 1,
      anon_sym_override,
    ACTIONS(4624), 1,
      anon_sym_LBRACK,
    ACTIONS(5066), 1,
      anon_sym_STAR,
    ACTIONS(5068), 1,
      anon_sym_async,
    ACTIONS(5072), 1,
      anon_sym_readonly,
    STATE(2791), 1,
      sym_override_modifier,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(5070), 2,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(5074), 2,
      anon_sym_get,
      anon_sym_set,
    STATE(3064), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(3814), 9,
      sym__automatic_semicolon,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_BANG,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_QMARK,
    ACTIONS(3700), 18,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [57989] = 12,
    ACTIONS(1626), 1,
      anon_sym_DQUOTE,
    ACTIONS(1628), 1,
      anon_sym_SQUOTE,
    ACTIONS(4624), 1,
      anon_sym_LBRACK,
    ACTIONS(4848), 1,
      anon_sym_abstract,
    ACTIONS(5066), 1,
      anon_sym_STAR,
    ACTIONS(5068), 1,
      anon_sym_async,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(5070), 2,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(5074), 2,
      anon_sym_get,
      anon_sym_set,
    STATE(3064), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(3814), 9,
      sym__automatic_semicolon,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_BANG,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_QMARK,
    ACTIONS(3700), 20,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [58058] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4346), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4348), 29,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_extends,
  [58109] = 14,
    ACTIONS(1626), 1,
      anon_sym_DQUOTE,
    ACTIONS(1628), 1,
      anon_sym_SQUOTE,
    ACTIONS(3722), 1,
      anon_sym_override,
    ACTIONS(4624), 1,
      anon_sym_LBRACK,
    ACTIONS(5076), 1,
      anon_sym_STAR,
    ACTIONS(5078), 1,
      anon_sym_async,
    ACTIONS(5082), 1,
      anon_sym_readonly,
    STATE(2801), 1,
      sym_override_modifier,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(5080), 2,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(5084), 2,
      anon_sym_get,
      anon_sym_set,
    STATE(3066), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(3814), 9,
      sym__automatic_semicolon,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_BANG,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_QMARK,
    ACTIONS(3700), 18,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [58182] = 12,
    ACTIONS(1626), 1,
      anon_sym_DQUOTE,
    ACTIONS(1628), 1,
      anon_sym_SQUOTE,
    ACTIONS(4624), 1,
      anon_sym_LBRACK,
    ACTIONS(5076), 1,
      anon_sym_STAR,
    ACTIONS(5078), 1,
      anon_sym_async,
    ACTIONS(5088), 1,
      anon_sym_abstract,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(5084), 2,
      anon_sym_get,
      anon_sym_set,
    ACTIONS(5086), 2,
      sym_number,
      sym_private_property_identifier,
    STATE(3067), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(3814), 9,
      sym__automatic_semicolon,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_BANG,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_QMARK,
    ACTIONS(3700), 20,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [58251] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4350), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4352), 29,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_extends,
  [58302] = 4,
    ACTIONS(4686), 1,
      anon_sym_DOT,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3522), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(3512), 28,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_LBRACK,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_extends,
  [58355] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4406), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4408), 29,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_extends,
  [58406] = 8,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4895), 1,
      anon_sym_LT,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4704), 12,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4706), 25,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [58467] = 4,
    ACTIONS(5090), 1,
      anon_sym_DOT,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4224), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4226), 28,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_LBRACK,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_extends,
  [58520] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4230), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4232), 29,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_extends,
  [58571] = 7,
    ACTIONS(3516), 1,
      anon_sym_DOT,
    ACTIONS(3520), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3512), 3,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_extends,
    ACTIONS(3522), 3,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_GT,
    ACTIONS(3492), 10,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(3496), 24,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [58630] = 6,
    ACTIONS(4408), 1,
      anon_sym_extends,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4608), 2,
      anon_sym_COMMA,
      anon_sym_LBRACK,
    ACTIONS(4611), 3,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_GT,
    ACTIONS(3492), 10,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(3496), 26,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [58687] = 5,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4182), 3,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_extends,
    ACTIONS(4184), 3,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_GT,
    ACTIONS(3492), 10,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(3496), 26,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [58742] = 6,
    ACTIONS(4378), 1,
      anon_sym_extends,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4614), 2,
      anon_sym_COMMA,
      anon_sym_LBRACK,
    ACTIONS(4617), 3,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_GT,
    ACTIONS(4458), 10,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4460), 26,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [58799] = 4,
    ACTIONS(4120), 1,
      anon_sym_extends,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4288), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4290), 28,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [58852] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4354), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4356), 29,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_extends,
  [58903] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4358), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4360), 29,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_extends,
  [58954] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4372), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4374), 29,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_extends,
  [59005] = 4,
    ACTIONS(4388), 1,
      anon_sym_DOT,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4384), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4386), 28,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_LBRACK,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_extends,
  [59058] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3691), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(3474), 29,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_extends,
  [59109] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3679), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(3478), 29,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_extends,
  [59160] = 4,
    ACTIONS(4399), 1,
      anon_sym_DOT,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4384), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4386), 28,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_LBRACK,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_extends,
  [59213] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4402), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4404), 29,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_extends,
  [59264] = 6,
    ACTIONS(4994), 1,
      anon_sym_AMP,
    ACTIONS(4996), 1,
      anon_sym_PIPE,
    ACTIONS(4998), 1,
      anon_sym_extends,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4402), 11,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4404), 28,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [59321] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4414), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4416), 29,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_extends,
  [59372] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4418), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4420), 29,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_extends,
  [59423] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4422), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4424), 29,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_extends,
  [59474] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4426), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4428), 29,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_extends,
  [59525] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3417), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(3419), 29,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_extends,
  [59576] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4430), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4432), 29,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_extends,
  [59627] = 4,
    ACTIONS(4994), 1,
      anon_sym_AMP,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4438), 12,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4440), 29,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_extends,
  [59680] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4446), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4448), 29,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_extends,
  [59731] = 5,
    ACTIONS(4588), 1,
      anon_sym_LPAREN,
    STATE(2207), 1,
      sym_arguments,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4395), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4397), 27,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [59786] = 9,
    ACTIONS(4106), 1,
      anon_sym_extends,
    ACTIONS(4510), 1,
      anon_sym_LBRACK,
    ACTIONS(5097), 1,
      anon_sym_RPAREN,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4513), 2,
      anon_sym_AMP,
      anon_sym_PIPE,
    ACTIONS(5092), 2,
      anon_sym_EQ,
      anon_sym_QMARK,
    ACTIONS(5094), 2,
      anon_sym_COMMA,
      anon_sym_COLON,
    ACTIONS(3492), 11,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(3496), 22,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [59849] = 9,
    ACTIONS(3611), 1,
      anon_sym_EQ,
    ACTIONS(3617), 1,
      anon_sym_QMARK,
    ACTIONS(4608), 1,
      anon_sym_LBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3614), 2,
      anon_sym_COMMA,
      anon_sym_COLON,
    ACTIONS(4408), 2,
      anon_sym_RPAREN,
      anon_sym_extends,
    ACTIONS(4611), 2,
      anon_sym_AMP,
      anon_sym_PIPE,
    ACTIONS(3492), 11,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(3496), 22,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [59912] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4270), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4156), 29,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_extends,
  [59963] = 32,
    ACTIONS(4588), 1,
      anon_sym_LPAREN,
    ACTIONS(4590), 1,
      anon_sym_LBRACK,
    ACTIONS(4592), 1,
      anon_sym_DOT,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4798), 1,
      anon_sym_as,
    ACTIONS(4800), 1,
      anon_sym_BANG,
    ACTIONS(4804), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4806), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4808), 1,
      anon_sym_GT_GT,
    ACTIONS(4812), 1,
      anon_sym_AMP,
    ACTIONS(4814), 1,
      anon_sym_CARET,
    ACTIONS(4816), 1,
      anon_sym_PIPE,
    ACTIONS(4820), 1,
      anon_sym_PERCENT,
    ACTIONS(4822), 1,
      anon_sym_STAR_STAR,
    ACTIONS(4824), 1,
      anon_sym_LT,
    ACTIONS(4832), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(4836), 1,
      anon_sym_satisfies,
    ACTIONS(4838), 1,
      sym__ternary_qmark,
    STATE(2019), 1,
      sym_type_arguments,
    STATE(2130), 1,
      sym_arguments,
    STATE(4524), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4796), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(4802), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(4810), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(4818), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4828), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4830), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(4834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(5039), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
    ACTIONS(5101), 2,
      sym__automatic_semicolon,
      anon_sym_SEMI,
    ACTIONS(4826), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [60072] = 4,
    ACTIONS(4994), 1,
      anon_sym_AMP,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4304), 12,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4306), 29,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_extends,
  [60125] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4184), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4182), 29,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_extends,
  [60176] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4376), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4378), 29,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_extends,
  [60227] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(2367), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(2365), 29,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_extends,
  [60278] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4158), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4160), 29,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_extends,
  [60329] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4312), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4314), 29,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_extends,
  [60380] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4380), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4382), 29,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_extends,
  [60431] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4122), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4124), 29,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_extends,
  [60482] = 14,
    ACTIONS(1626), 1,
      anon_sym_DQUOTE,
    ACTIONS(1628), 1,
      anon_sym_SQUOTE,
    ACTIONS(3722), 1,
      anon_sym_override,
    ACTIONS(4624), 1,
      anon_sym_LBRACK,
    ACTIONS(5103), 1,
      anon_sym_STAR,
    ACTIONS(5105), 1,
      anon_sym_async,
    ACTIONS(5109), 1,
      anon_sym_readonly,
    STATE(2803), 1,
      sym_override_modifier,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(5107), 2,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(5111), 2,
      anon_sym_get,
      anon_sym_set,
    STATE(3135), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(3814), 9,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_QMARK,
      anon_sym_PIPE_RBRACE,
    ACTIONS(3700), 18,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [60555] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4380), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4382), 29,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_extends,
  [60606] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4122), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4124), 29,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_extends,
  [60657] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4132), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4134), 29,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_extends,
  [60708] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4136), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4138), 29,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_extends,
  [60759] = 5,
    ACTIONS(4588), 1,
      anon_sym_LPAREN,
    STATE(2220), 1,
      sym_arguments,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4410), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4412), 27,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [60814] = 9,
    ACTIONS(2373), 1,
      anon_sym_extends,
    ACTIONS(4126), 1,
      anon_sym_LBRACK,
    ACTIONS(5113), 1,
      anon_sym_RPAREN,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(1696), 2,
      anon_sym_EQ,
      anon_sym_QMARK,
    ACTIONS(4129), 2,
      anon_sym_AMP,
      anon_sym_PIPE,
    ACTIONS(4859), 2,
      anon_sym_COMMA,
      anon_sym_COLON,
    ACTIONS(1694), 11,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(1698), 22,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [60877] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4132), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4134), 29,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_extends,
  [60928] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4136), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4138), 29,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_extends,
  [60979] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4162), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4164), 29,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_extends,
  [61030] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4166), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4168), 29,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_extends,
  [61081] = 9,
    ACTIONS(4150), 1,
      anon_sym_LBRACK,
    ACTIONS(4156), 1,
      anon_sym_extends,
    ACTIONS(5116), 1,
      anon_sym_RPAREN,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4146), 2,
      anon_sym_EQ,
      anon_sym_QMARK,
    ACTIONS(4153), 2,
      anon_sym_AMP,
      anon_sym_PIPE,
    ACTIONS(4850), 2,
      anon_sym_COMMA,
      anon_sym_COLON,
    ACTIONS(4144), 11,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4148), 22,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [61144] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4162), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4164), 29,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_extends,
  [61195] = 9,
    ACTIONS(4106), 1,
      anon_sym_extends,
    ACTIONS(4510), 1,
      anon_sym_LBRACK,
    ACTIONS(5123), 1,
      anon_sym_RPAREN,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4513), 2,
      anon_sym_AMP,
      anon_sym_PIPE,
    ACTIONS(5119), 2,
      anon_sym_EQ,
      anon_sym_QMARK,
    ACTIONS(5121), 2,
      anon_sym_COMMA,
      anon_sym_COLON,
    ACTIONS(3492), 11,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(3496), 22,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [61258] = 14,
    ACTIONS(162), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1550), 1,
      anon_sym_DQUOTE,
    ACTIONS(1552), 1,
      anon_sym_SQUOTE,
    ACTIONS(3275), 1,
      anon_sym_LBRACE,
    ACTIONS(3942), 1,
      anon_sym_LBRACK,
    ACTIONS(5060), 1,
      anon_sym_COMMA,
    ACTIONS(5128), 1,
      anon_sym_RBRACE,
    STATE(4736), 1,
      aux_sym_object_pattern_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(5064), 2,
      sym_number,
      sym_private_property_identifier,
    STATE(4714), 3,
      sym_object_assignment_pattern,
      sym_rest_pattern,
      sym_pair_pattern,
    STATE(5509), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    STATE(5536), 3,
      sym_object_pattern,
      sym_array_pattern,
      sym__destructuring_pattern,
    ACTIONS(5126), 23,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [61331] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4166), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4168), 29,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_extends,
  [61382] = 4,
    ACTIONS(4322), 1,
      anon_sym_extends,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4288), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4290), 28,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [61435] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4391), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4393), 29,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_extends,
  [61486] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4186), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4188), 29,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_extends,
  [61537] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4196), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4198), 29,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_extends,
  [61588] = 9,
    ACTIONS(4106), 1,
      anon_sym_extends,
    ACTIONS(4510), 1,
      anon_sym_LBRACK,
    ACTIONS(5132), 1,
      anon_sym_RPAREN,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4513), 2,
      anon_sym_AMP,
      anon_sym_PIPE,
    ACTIONS(5092), 2,
      anon_sym_EQ,
      anon_sym_QMARK,
    ACTIONS(5130), 2,
      anon_sym_COMMA,
      anon_sym_COLON,
    ACTIONS(3492), 11,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(3496), 22,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [61651] = 9,
    ACTIONS(3617), 1,
      anon_sym_QMARK,
    ACTIONS(3619), 1,
      anon_sym_EQ,
    ACTIONS(4608), 1,
      anon_sym_LBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3622), 2,
      anon_sym_COMMA,
      anon_sym_COLON,
    ACTIONS(4408), 2,
      anon_sym_RPAREN,
      anon_sym_extends,
    ACTIONS(4611), 2,
      anon_sym_AMP,
      anon_sym_PIPE,
    ACTIONS(3492), 11,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(3496), 22,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [61714] = 6,
    ACTIONS(4994), 1,
      anon_sym_AMP,
    ACTIONS(4996), 1,
      anon_sym_PIPE,
    ACTIONS(4998), 1,
      anon_sym_extends,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4202), 11,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4204), 28,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [61771] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3427), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(3429), 29,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_extends,
  [61822] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4216), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4218), 29,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_extends,
  [61873] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4220), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4222), 29,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_extends,
  [61924] = 6,
    ACTIONS(4994), 1,
      anon_sym_AMP,
    ACTIONS(4996), 1,
      anon_sym_PIPE,
    ACTIONS(4998), 1,
      anon_sym_extends,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4220), 11,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4222), 28,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [61981] = 31,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_as,
    ACTIONS(4640), 1,
      anon_sym_BANG,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4649), 1,
      anon_sym_satisfies,
    ACTIONS(4875), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4877), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4879), 1,
      anon_sym_GT_GT,
    ACTIONS(4883), 1,
      anon_sym_AMP,
    ACTIONS(4885), 1,
      anon_sym_CARET,
    ACTIONS(4887), 1,
      anon_sym_PIPE,
    ACTIONS(4891), 1,
      anon_sym_PERCENT,
    ACTIONS(4893), 1,
      anon_sym_STAR_STAR,
    ACTIONS(4895), 1,
      anon_sym_LT,
    ACTIONS(4903), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(4905), 1,
      sym__ternary_qmark,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4867), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(4873), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(4881), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(4889), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4899), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4901), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(4897), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
    ACTIONS(4773), 4,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_BQUOTE,
  [62088] = 6,
    ACTIONS(4994), 1,
      anon_sym_AMP,
    ACTIONS(4996), 1,
      anon_sym_PIPE,
    ACTIONS(4998), 1,
      anon_sym_extends,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4292), 11,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4294), 28,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [62145] = 6,
    ACTIONS(4172), 1,
      anon_sym_extends,
    ACTIONS(5028), 1,
      anon_sym_LBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4170), 2,
      anon_sym_AMP,
      anon_sym_PIPE,
    ACTIONS(4450), 11,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4452), 27,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [62202] = 4,
    ACTIONS(5135), 1,
      anon_sym_extends,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4190), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4192), 28,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [62255] = 4,
    ACTIONS(5028), 1,
      anon_sym_LBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4212), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4214), 28,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_extends,
  [62308] = 7,
    ACTIONS(3578), 1,
      anon_sym_EQ,
    ACTIONS(4408), 1,
      anon_sym_extends,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4608), 2,
      anon_sym_COMMA,
      anon_sym_LBRACK,
    ACTIONS(4611), 3,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_GT,
    ACTIONS(3492), 10,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(3496), 25,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [62367] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4104), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4106), 29,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_extends,
  [62418] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4118), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4120), 29,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_extends,
  [62469] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(2371), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(2369), 29,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_extends,
  [62520] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4234), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4236), 29,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_extends,
  [62571] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4238), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4240), 29,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_extends,
  [62622] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4238), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4240), 29,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_extends,
  [62673] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4238), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4240), 29,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_extends,
  [62724] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4242), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4244), 29,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_extends,
  [62775] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4242), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4244), 29,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_extends,
  [62826] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4242), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4244), 29,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_extends,
  [62877] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4246), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4248), 29,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_extends,
  [62928] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4246), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4248), 29,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_extends,
  [62979] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4246), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4248), 29,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_extends,
  [63030] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4256), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4258), 29,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_extends,
  [63081] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4260), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4262), 29,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_extends,
  [63132] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4264), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4266), 29,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_extends,
  [63183] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4174), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4176), 29,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_extends,
  [63234] = 4,
    ACTIONS(4604), 1,
      anon_sym_EQ,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4602), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4606), 28,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [63287] = 14,
    ACTIONS(1626), 1,
      anon_sym_DQUOTE,
    ACTIONS(1628), 1,
      anon_sym_SQUOTE,
    ACTIONS(3722), 1,
      anon_sym_override,
    ACTIONS(4624), 1,
      anon_sym_LBRACK,
    ACTIONS(5137), 1,
      anon_sym_STAR,
    ACTIONS(5139), 1,
      anon_sym_async,
    ACTIONS(5143), 1,
      anon_sym_readonly,
    STATE(2797), 1,
      sym_override_modifier,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(5141), 2,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(5145), 2,
      anon_sym_get,
      anon_sym_set,
    STATE(3071), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(3814), 9,
      sym__automatic_semicolon,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_BANG,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_QMARK,
    ACTIONS(3700), 18,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [63360] = 12,
    ACTIONS(1626), 1,
      anon_sym_DQUOTE,
    ACTIONS(1628), 1,
      anon_sym_SQUOTE,
    ACTIONS(4624), 1,
      anon_sym_LBRACK,
    ACTIONS(5137), 1,
      anon_sym_STAR,
    ACTIONS(5139), 1,
      anon_sym_async,
    ACTIONS(5149), 1,
      anon_sym_abstract,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(5145), 2,
      anon_sym_get,
      anon_sym_set,
    ACTIONS(5147), 2,
      sym_number,
      sym_private_property_identifier,
    STATE(3083), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(3814), 9,
      sym__automatic_semicolon,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_BANG,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_QMARK,
    ACTIONS(3700), 20,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [63429] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4178), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4180), 29,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_extends,
  [63480] = 12,
    ACTIONS(1550), 1,
      anon_sym_DQUOTE,
    ACTIONS(1552), 1,
      anon_sym_SQUOTE,
    ACTIONS(4620), 1,
      anon_sym_STAR,
    ACTIONS(4622), 1,
      anon_sym_EQ,
    ACTIONS(4688), 1,
      anon_sym_LBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4074), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
    ACTIONS(4690), 2,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(4692), 2,
      anon_sym_get,
      anon_sym_set,
    STATE(3866), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(3814), 7,
      sym__automatic_semicolon,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_QMARK,
      anon_sym_PIPE_RBRACE,
    ACTIONS(2351), 21,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [63549] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(2363), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(2361), 29,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_extends,
  [63600] = 13,
    ACTIONS(1626), 1,
      anon_sym_DQUOTE,
    ACTIONS(1628), 1,
      anon_sym_SQUOTE,
    ACTIONS(4620), 1,
      anon_sym_STAR,
    ACTIONS(4622), 1,
      anon_sym_EQ,
    ACTIONS(4626), 1,
      anon_sym_async,
    ACTIONS(4698), 1,
      anon_sym_LBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4074), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
    ACTIONS(4628), 2,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(4632), 2,
      anon_sym_get,
      anon_sym_set,
    STATE(3144), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(3814), 7,
      sym__automatic_semicolon,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_QMARK,
      anon_sym_PIPE_RBRACE,
    ACTIONS(3700), 20,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [63671] = 14,
    ACTIONS(1626), 1,
      anon_sym_DQUOTE,
    ACTIONS(1628), 1,
      anon_sym_SQUOTE,
    ACTIONS(3722), 1,
      anon_sym_override,
    ACTIONS(4624), 1,
      anon_sym_LBRACK,
    ACTIONS(5151), 1,
      anon_sym_STAR,
    ACTIONS(5153), 1,
      anon_sym_async,
    ACTIONS(5157), 1,
      anon_sym_readonly,
    STATE(2809), 1,
      sym_override_modifier,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(5155), 2,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(5159), 2,
      anon_sym_get,
      anon_sym_set,
    STATE(3097), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(3814), 9,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_QMARK,
      anon_sym_PIPE_RBRACE,
    ACTIONS(3700), 18,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [63744] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4276), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4278), 29,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_extends,
  [63795] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4280), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4282), 29,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_extends,
  [63846] = 4,
    ACTIONS(1696), 1,
      anon_sym_EQ,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(1694), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(1698), 28,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [63899] = 19,
    ACTIONS(237), 1,
      anon_sym_COMMA,
    ACTIONS(692), 1,
      anon_sym_RBRACE,
    ACTIONS(1550), 1,
      anon_sym_DQUOTE,
    ACTIONS(1552), 1,
      anon_sym_SQUOTE,
    ACTIONS(2353), 1,
      anon_sym_async,
    ACTIONS(2355), 1,
      anon_sym_readonly,
    ACTIONS(2359), 1,
      anon_sym_override,
    ACTIONS(4622), 1,
      anon_sym_EQ,
    ACTIONS(4688), 1,
      anon_sym_LBRACK,
    ACTIONS(4990), 1,
      anon_sym_STAR,
    STATE(2813), 1,
      sym_override_modifier,
    STATE(4810), 1,
      aux_sym_object_repeat1,
    STATE(4815), 1,
      aux_sym_object_pattern_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(2337), 2,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(2357), 2,
      anon_sym_get,
      anon_sym_set,
    STATE(3816), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(3814), 4,
      anon_sym_LPAREN,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_QMARK,
    ACTIONS(2351), 18,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [63982] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4280), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4282), 29,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_extends,
  [64033] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4280), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4282), 29,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_extends,
  [64084] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4284), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4286), 29,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_extends,
  [64135] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4284), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4286), 29,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_extends,
  [64186] = 8,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(5161), 1,
      anon_sym_LT,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4704), 12,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4706), 25,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_implements,
  [64247] = 31,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_as,
    ACTIONS(4640), 1,
      anon_sym_BANG,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4649), 1,
      anon_sym_satisfies,
    ACTIONS(5161), 1,
      anon_sym_LT,
    ACTIONS(5167), 1,
      anon_sym_AMP_AMP,
    ACTIONS(5169), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(5171), 1,
      anon_sym_GT_GT,
    ACTIONS(5175), 1,
      anon_sym_AMP,
    ACTIONS(5177), 1,
      anon_sym_CARET,
    ACTIONS(5179), 1,
      anon_sym_PIPE,
    ACTIONS(5183), 1,
      anon_sym_PERCENT,
    ACTIONS(5185), 1,
      anon_sym_STAR_STAR,
    ACTIONS(5193), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(5195), 1,
      sym__ternary_qmark,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(5163), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(5165), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(5173), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(5181), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(5189), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(5191), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(5187), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
    ACTIONS(4468), 4,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_BQUOTE,
      anon_sym_implements,
  [64354] = 31,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_as,
    ACTIONS(4640), 1,
      anon_sym_BANG,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4649), 1,
      anon_sym_satisfies,
    ACTIONS(5161), 1,
      anon_sym_LT,
    ACTIONS(5167), 1,
      anon_sym_AMP_AMP,
    ACTIONS(5169), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(5171), 1,
      anon_sym_GT_GT,
    ACTIONS(5175), 1,
      anon_sym_AMP,
    ACTIONS(5177), 1,
      anon_sym_CARET,
    ACTIONS(5179), 1,
      anon_sym_PIPE,
    ACTIONS(5183), 1,
      anon_sym_PERCENT,
    ACTIONS(5185), 1,
      anon_sym_STAR_STAR,
    ACTIONS(5193), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(5195), 1,
      sym__ternary_qmark,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(5163), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(5165), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(5173), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(5181), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(5189), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(5191), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(5187), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
    ACTIONS(4744), 4,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_BQUOTE,
      anon_sym_implements,
  [64461] = 31,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_as,
    ACTIONS(4640), 1,
      anon_sym_BANG,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4649), 1,
      anon_sym_satisfies,
    ACTIONS(5161), 1,
      anon_sym_LT,
    ACTIONS(5167), 1,
      anon_sym_AMP_AMP,
    ACTIONS(5169), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(5171), 1,
      anon_sym_GT_GT,
    ACTIONS(5175), 1,
      anon_sym_AMP,
    ACTIONS(5177), 1,
      anon_sym_CARET,
    ACTIONS(5179), 1,
      anon_sym_PIPE,
    ACTIONS(5183), 1,
      anon_sym_PERCENT,
    ACTIONS(5185), 1,
      anon_sym_STAR_STAR,
    ACTIONS(5193), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(5195), 1,
      sym__ternary_qmark,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(5163), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(5165), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(5173), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(5181), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(5189), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(5191), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(5187), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
    ACTIONS(4756), 4,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_BQUOTE,
      anon_sym_implements,
  [64568] = 31,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_as,
    ACTIONS(4640), 1,
      anon_sym_BANG,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4649), 1,
      anon_sym_satisfies,
    ACTIONS(5161), 1,
      anon_sym_LT,
    ACTIONS(5167), 1,
      anon_sym_AMP_AMP,
    ACTIONS(5169), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(5171), 1,
      anon_sym_GT_GT,
    ACTIONS(5175), 1,
      anon_sym_AMP,
    ACTIONS(5177), 1,
      anon_sym_CARET,
    ACTIONS(5179), 1,
      anon_sym_PIPE,
    ACTIONS(5183), 1,
      anon_sym_PERCENT,
    ACTIONS(5185), 1,
      anon_sym_STAR_STAR,
    ACTIONS(5193), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(5195), 1,
      sym__ternary_qmark,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(5163), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(5165), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(5173), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(5181), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(5189), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(5191), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(5187), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
    ACTIONS(4758), 4,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_BQUOTE,
      anon_sym_implements,
  [64675] = 31,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_as,
    ACTIONS(4640), 1,
      anon_sym_BANG,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4649), 1,
      anon_sym_satisfies,
    ACTIONS(5161), 1,
      anon_sym_LT,
    ACTIONS(5167), 1,
      anon_sym_AMP_AMP,
    ACTIONS(5169), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(5171), 1,
      anon_sym_GT_GT,
    ACTIONS(5175), 1,
      anon_sym_AMP,
    ACTIONS(5177), 1,
      anon_sym_CARET,
    ACTIONS(5179), 1,
      anon_sym_PIPE,
    ACTIONS(5183), 1,
      anon_sym_PERCENT,
    ACTIONS(5185), 1,
      anon_sym_STAR_STAR,
    ACTIONS(5193), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(5195), 1,
      sym__ternary_qmark,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(5163), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(5165), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(5173), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(5181), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(5189), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(5191), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(5187), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
    ACTIONS(4504), 4,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_BQUOTE,
      anon_sym_implements,
  [64782] = 18,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(5161), 1,
      anon_sym_LT,
    ACTIONS(5171), 1,
      anon_sym_GT_GT,
    ACTIONS(5183), 1,
      anon_sym_PERCENT,
    ACTIONS(5185), 1,
      anon_sym_STAR_STAR,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(5163), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(5173), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(5181), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4762), 7,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4760), 16,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_implements,
  [64863] = 13,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(5185), 1,
      anon_sym_STAR_STAR,
    ACTIONS(5197), 1,
      anon_sym_LT,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4762), 12,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4760), 19,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_implements,
  [64934] = 25,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4762), 1,
      anon_sym_BANG,
    ACTIONS(5161), 1,
      anon_sym_LT,
    ACTIONS(5171), 1,
      anon_sym_GT_GT,
    ACTIONS(5175), 1,
      anon_sym_AMP,
    ACTIONS(5177), 1,
      anon_sym_CARET,
    ACTIONS(5179), 1,
      anon_sym_PIPE,
    ACTIONS(5183), 1,
      anon_sym_PERCENT,
    ACTIONS(5185), 1,
      anon_sym_STAR_STAR,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(5163), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(5165), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(5173), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(5181), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(5189), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(5191), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(5187), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
    ACTIONS(4760), 10,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_implements,
  [65029] = 26,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4762), 1,
      anon_sym_BANG,
    ACTIONS(5161), 1,
      anon_sym_LT,
    ACTIONS(5167), 1,
      anon_sym_AMP_AMP,
    ACTIONS(5171), 1,
      anon_sym_GT_GT,
    ACTIONS(5175), 1,
      anon_sym_AMP,
    ACTIONS(5177), 1,
      anon_sym_CARET,
    ACTIONS(5179), 1,
      anon_sym_PIPE,
    ACTIONS(5183), 1,
      anon_sym_PERCENT,
    ACTIONS(5185), 1,
      anon_sym_STAR_STAR,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(5163), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(5165), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(5173), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(5181), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(5189), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(5191), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(5187), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
    ACTIONS(4760), 9,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_implements,
  [65126] = 16,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(5183), 1,
      anon_sym_PERCENT,
    ACTIONS(5185), 1,
      anon_sym_STAR_STAR,
    ACTIONS(5197), 1,
      anon_sym_LT,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(5163), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(5181), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4762), 8,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4760), 18,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_implements,
  [65203] = 22,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(5161), 1,
      anon_sym_LT,
    ACTIONS(5171), 1,
      anon_sym_GT_GT,
    ACTIONS(5183), 1,
      anon_sym_PERCENT,
    ACTIONS(5185), 1,
      anon_sym_STAR_STAR,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(5163), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(5165), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(5173), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(5181), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(5189), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(5191), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(4762), 3,
      anon_sym_BANG,
      anon_sym_AMP,
      anon_sym_PIPE,
    ACTIONS(5187), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
    ACTIONS(4760), 11,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_CARET,
      anon_sym_QMARK_QMARK,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_implements,
  [65292] = 23,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(5161), 1,
      anon_sym_LT,
    ACTIONS(5171), 1,
      anon_sym_GT_GT,
    ACTIONS(5175), 1,
      anon_sym_AMP,
    ACTIONS(5183), 1,
      anon_sym_PERCENT,
    ACTIONS(5185), 1,
      anon_sym_STAR_STAR,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4762), 2,
      anon_sym_BANG,
      anon_sym_PIPE,
    ACTIONS(5163), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(5165), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(5173), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(5181), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(5189), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(5191), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(5187), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
    ACTIONS(4760), 11,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_CARET,
      anon_sym_QMARK_QMARK,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_implements,
  [65383] = 24,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(5161), 1,
      anon_sym_LT,
    ACTIONS(5171), 1,
      anon_sym_GT_GT,
    ACTIONS(5175), 1,
      anon_sym_AMP,
    ACTIONS(5177), 1,
      anon_sym_CARET,
    ACTIONS(5183), 1,
      anon_sym_PERCENT,
    ACTIONS(5185), 1,
      anon_sym_STAR_STAR,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4762), 2,
      anon_sym_BANG,
      anon_sym_PIPE,
    ACTIONS(5163), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(5165), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(5173), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(5181), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(5189), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(5191), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(5187), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
    ACTIONS(4760), 10,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_implements,
  [65476] = 15,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(5183), 1,
      anon_sym_PERCENT,
    ACTIONS(5185), 1,
      anon_sym_STAR_STAR,
    ACTIONS(5197), 1,
      anon_sym_LT,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(5163), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(4762), 10,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4760), 18,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_implements,
  [65551] = 16,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_as,
    ACTIONS(4640), 1,
      anon_sym_BANG,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4649), 1,
      anon_sym_satisfies,
    ACTIONS(5185), 1,
      anon_sym_STAR_STAR,
    ACTIONS(5197), 1,
      anon_sym_LT,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4762), 11,
      anon_sym_STAR,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4760), 17,
      sym__ternary_qmark,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_BQUOTE,
      anon_sym_implements,
  [65628] = 20,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(5161), 1,
      anon_sym_LT,
    ACTIONS(5171), 1,
      anon_sym_GT_GT,
    ACTIONS(5183), 1,
      anon_sym_PERCENT,
    ACTIONS(5185), 1,
      anon_sym_STAR_STAR,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(5163), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(5165), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(5173), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(5181), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(5187), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
    ACTIONS(4762), 5,
      anon_sym_BANG,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4760), 13,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_CARET,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_implements,
  [65713] = 27,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4762), 1,
      anon_sym_BANG,
    ACTIONS(5161), 1,
      anon_sym_LT,
    ACTIONS(5167), 1,
      anon_sym_AMP_AMP,
    ACTIONS(5169), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(5171), 1,
      anon_sym_GT_GT,
    ACTIONS(5175), 1,
      anon_sym_AMP,
    ACTIONS(5177), 1,
      anon_sym_CARET,
    ACTIONS(5179), 1,
      anon_sym_PIPE,
    ACTIONS(5183), 1,
      anon_sym_PERCENT,
    ACTIONS(5185), 1,
      anon_sym_STAR_STAR,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(5163), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(5165), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(5173), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(5181), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(5189), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(5191), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(5187), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
    ACTIONS(4760), 8,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_QMARK_QMARK,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_implements,
  [65812] = 31,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_as,
    ACTIONS(4640), 1,
      anon_sym_BANG,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4649), 1,
      anon_sym_satisfies,
    ACTIONS(5161), 1,
      anon_sym_LT,
    ACTIONS(5167), 1,
      anon_sym_AMP_AMP,
    ACTIONS(5169), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(5171), 1,
      anon_sym_GT_GT,
    ACTIONS(5175), 1,
      anon_sym_AMP,
    ACTIONS(5177), 1,
      anon_sym_CARET,
    ACTIONS(5179), 1,
      anon_sym_PIPE,
    ACTIONS(5183), 1,
      anon_sym_PERCENT,
    ACTIONS(5185), 1,
      anon_sym_STAR_STAR,
    ACTIONS(5193), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(5195), 1,
      sym__ternary_qmark,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(5163), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(5165), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(5173), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(5181), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(5189), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(5191), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(5187), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
    ACTIONS(4522), 4,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_BQUOTE,
      anon_sym_implements,
  [65919] = 31,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_as,
    ACTIONS(4640), 1,
      anon_sym_BANG,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4649), 1,
      anon_sym_satisfies,
    ACTIONS(5161), 1,
      anon_sym_LT,
    ACTIONS(5167), 1,
      anon_sym_AMP_AMP,
    ACTIONS(5169), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(5171), 1,
      anon_sym_GT_GT,
    ACTIONS(5175), 1,
      anon_sym_AMP,
    ACTIONS(5177), 1,
      anon_sym_CARET,
    ACTIONS(5179), 1,
      anon_sym_PIPE,
    ACTIONS(5183), 1,
      anon_sym_PERCENT,
    ACTIONS(5185), 1,
      anon_sym_STAR_STAR,
    ACTIONS(5193), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(5195), 1,
      sym__ternary_qmark,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(5163), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(5165), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(5173), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(5181), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(5189), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(5191), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(5187), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
    ACTIONS(4767), 4,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_BQUOTE,
      anon_sym_implements,
  [66026] = 31,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_as,
    ACTIONS(4640), 1,
      anon_sym_BANG,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4649), 1,
      anon_sym_satisfies,
    ACTIONS(5161), 1,
      anon_sym_LT,
    ACTIONS(5167), 1,
      anon_sym_AMP_AMP,
    ACTIONS(5169), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(5171), 1,
      anon_sym_GT_GT,
    ACTIONS(5175), 1,
      anon_sym_AMP,
    ACTIONS(5177), 1,
      anon_sym_CARET,
    ACTIONS(5179), 1,
      anon_sym_PIPE,
    ACTIONS(5183), 1,
      anon_sym_PERCENT,
    ACTIONS(5185), 1,
      anon_sym_STAR_STAR,
    ACTIONS(5193), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(5195), 1,
      sym__ternary_qmark,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(5163), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(5165), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(5173), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(5181), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(5189), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(5191), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(5187), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
    ACTIONS(4546), 4,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_BQUOTE,
      anon_sym_implements,
  [66133] = 31,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_as,
    ACTIONS(4640), 1,
      anon_sym_BANG,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4649), 1,
      anon_sym_satisfies,
    ACTIONS(5161), 1,
      anon_sym_LT,
    ACTIONS(5167), 1,
      anon_sym_AMP_AMP,
    ACTIONS(5169), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(5171), 1,
      anon_sym_GT_GT,
    ACTIONS(5175), 1,
      anon_sym_AMP,
    ACTIONS(5177), 1,
      anon_sym_CARET,
    ACTIONS(5179), 1,
      anon_sym_PIPE,
    ACTIONS(5183), 1,
      anon_sym_PERCENT,
    ACTIONS(5185), 1,
      anon_sym_STAR_STAR,
    ACTIONS(5193), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(5195), 1,
      sym__ternary_qmark,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(5163), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(5165), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(5173), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(5181), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(5189), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(5191), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(5187), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
    ACTIONS(4554), 4,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_BQUOTE,
      anon_sym_implements,
  [66240] = 31,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_as,
    ACTIONS(4640), 1,
      anon_sym_BANG,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4649), 1,
      anon_sym_satisfies,
    ACTIONS(5161), 1,
      anon_sym_LT,
    ACTIONS(5167), 1,
      anon_sym_AMP_AMP,
    ACTIONS(5169), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(5171), 1,
      anon_sym_GT_GT,
    ACTIONS(5175), 1,
      anon_sym_AMP,
    ACTIONS(5177), 1,
      anon_sym_CARET,
    ACTIONS(5179), 1,
      anon_sym_PIPE,
    ACTIONS(5183), 1,
      anon_sym_PERCENT,
    ACTIONS(5185), 1,
      anon_sym_STAR_STAR,
    ACTIONS(5193), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(5195), 1,
      sym__ternary_qmark,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(5163), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(5165), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(5173), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(5181), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(5189), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(5191), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(5187), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
    ACTIONS(4558), 4,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_BQUOTE,
      anon_sym_implements,
  [66347] = 31,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_as,
    ACTIONS(4640), 1,
      anon_sym_BANG,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4649), 1,
      anon_sym_satisfies,
    ACTIONS(5161), 1,
      anon_sym_LT,
    ACTIONS(5167), 1,
      anon_sym_AMP_AMP,
    ACTIONS(5169), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(5171), 1,
      anon_sym_GT_GT,
    ACTIONS(5175), 1,
      anon_sym_AMP,
    ACTIONS(5177), 1,
      anon_sym_CARET,
    ACTIONS(5179), 1,
      anon_sym_PIPE,
    ACTIONS(5183), 1,
      anon_sym_PERCENT,
    ACTIONS(5185), 1,
      anon_sym_STAR_STAR,
    ACTIONS(5193), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(5195), 1,
      sym__ternary_qmark,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(5163), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(5165), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(5173), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(5181), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(5189), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(5191), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(5187), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
    ACTIONS(4769), 4,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_BQUOTE,
      anon_sym_implements,
  [66454] = 31,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_as,
    ACTIONS(4640), 1,
      anon_sym_BANG,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4649), 1,
      anon_sym_satisfies,
    ACTIONS(5161), 1,
      anon_sym_LT,
    ACTIONS(5167), 1,
      anon_sym_AMP_AMP,
    ACTIONS(5169), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(5171), 1,
      anon_sym_GT_GT,
    ACTIONS(5175), 1,
      anon_sym_AMP,
    ACTIONS(5177), 1,
      anon_sym_CARET,
    ACTIONS(5179), 1,
      anon_sym_PIPE,
    ACTIONS(5183), 1,
      anon_sym_PERCENT,
    ACTIONS(5185), 1,
      anon_sym_STAR_STAR,
    ACTIONS(5193), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(5195), 1,
      sym__ternary_qmark,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(5163), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(5165), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(5173), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(5181), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(5189), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(5191), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(5187), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
    ACTIONS(4771), 4,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_BQUOTE,
      anon_sym_implements,
  [66561] = 31,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_as,
    ACTIONS(4640), 1,
      anon_sym_BANG,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4649), 1,
      anon_sym_satisfies,
    ACTIONS(5161), 1,
      anon_sym_LT,
    ACTIONS(5167), 1,
      anon_sym_AMP_AMP,
    ACTIONS(5169), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(5171), 1,
      anon_sym_GT_GT,
    ACTIONS(5175), 1,
      anon_sym_AMP,
    ACTIONS(5177), 1,
      anon_sym_CARET,
    ACTIONS(5179), 1,
      anon_sym_PIPE,
    ACTIONS(5183), 1,
      anon_sym_PERCENT,
    ACTIONS(5185), 1,
      anon_sym_STAR_STAR,
    ACTIONS(5193), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(5195), 1,
      sym__ternary_qmark,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(5163), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(5165), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(5173), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(5181), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(5189), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(5191), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(5187), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
    ACTIONS(4773), 4,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_BQUOTE,
      anon_sym_implements,
  [66668] = 12,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(5200), 1,
      anon_sym_LT,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4778), 12,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4780), 20,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_implements,
  [66737] = 15,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_as,
    ACTIONS(4640), 1,
      anon_sym_BANG,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4649), 1,
      anon_sym_satisfies,
    ACTIONS(5203), 1,
      anon_sym_LT,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4634), 11,
      anon_sym_STAR,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4638), 18,
      sym__ternary_qmark,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_BQUOTE,
      anon_sym_implements,
  [66812] = 31,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_as,
    ACTIONS(4640), 1,
      anon_sym_BANG,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4649), 1,
      anon_sym_satisfies,
    ACTIONS(5161), 1,
      anon_sym_LT,
    ACTIONS(5167), 1,
      anon_sym_AMP_AMP,
    ACTIONS(5169), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(5171), 1,
      anon_sym_GT_GT,
    ACTIONS(5175), 1,
      anon_sym_AMP,
    ACTIONS(5177), 1,
      anon_sym_CARET,
    ACTIONS(5179), 1,
      anon_sym_PIPE,
    ACTIONS(5183), 1,
      anon_sym_PERCENT,
    ACTIONS(5185), 1,
      anon_sym_STAR_STAR,
    ACTIONS(5193), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(5195), 1,
      sym__ternary_qmark,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(5163), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(5165), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(5173), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(5181), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(5189), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(5191), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(5187), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
    ACTIONS(4792), 4,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_BQUOTE,
      anon_sym_implements,
  [66919] = 11,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(5206), 1,
      anon_sym_LT,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4785), 12,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4787), 22,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_implements,
  [66986] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4300), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4302), 29,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_extends,
  [67037] = 10,
    ACTIONS(1550), 1,
      anon_sym_DQUOTE,
    ACTIONS(1552), 1,
      anon_sym_SQUOTE,
    ACTIONS(4622), 1,
      anon_sym_EQ,
    ACTIONS(4688), 1,
      anon_sym_LBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4074), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
    ACTIONS(4690), 2,
      sym_number,
      sym_private_property_identifier,
    STATE(3866), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(3814), 7,
      sym__automatic_semicolon,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_QMARK,
      anon_sym_PIPE_RBRACE,
    ACTIONS(2351), 23,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [67101] = 8,
    ACTIONS(1696), 1,
      anon_sym_EQ,
    ACTIONS(4126), 1,
      anon_sym_LBRACK,
    ACTIONS(4859), 1,
      anon_sym_COLON,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4129), 2,
      anon_sym_AMP,
      anon_sym_PIPE,
    ACTIONS(2373), 3,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_extends,
    ACTIONS(1694), 11,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(1698), 22,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [67161] = 8,
    ACTIONS(4146), 1,
      anon_sym_EQ,
    ACTIONS(4150), 1,
      anon_sym_LBRACK,
    ACTIONS(4850), 1,
      anon_sym_COLON,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4153), 2,
      anon_sym_AMP,
      anon_sym_PIPE,
    ACTIONS(4156), 3,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_extends,
    ACTIONS(4144), 11,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4148), 22,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [67221] = 10,
    ACTIONS(1550), 1,
      anon_sym_DQUOTE,
    ACTIONS(1552), 1,
      anon_sym_SQUOTE,
    ACTIONS(4688), 1,
      anon_sym_LBRACK,
    ACTIONS(5209), 1,
      anon_sym_STAR,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(5211), 2,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(5213), 2,
      anon_sym_get,
      anon_sym_set,
    STATE(3878), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(3814), 9,
      sym__automatic_semicolon,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_BANG,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_QMARK,
    ACTIONS(2351), 21,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [67285] = 7,
    ACTIONS(1696), 1,
      anon_sym_EQ,
    ACTIONS(4126), 1,
      anon_sym_LBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(2373), 2,
      anon_sym_COMMA,
      anon_sym_extends,
    ACTIONS(4129), 3,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_GT,
    ACTIONS(1694), 10,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1698), 24,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [67343] = 7,
    ACTIONS(4146), 1,
      anon_sym_EQ,
    ACTIONS(4150), 1,
      anon_sym_LBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4156), 2,
      anon_sym_COMMA,
      anon_sym_extends,
    ACTIONS(4153), 3,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_GT,
    ACTIONS(4144), 10,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4148), 24,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [67401] = 9,
    ACTIONS(3808), 1,
      anon_sym_COMMA,
    ACTIONS(3912), 1,
      anon_sym_RBRACE,
    ACTIONS(4622), 1,
      anon_sym_EQ,
    STATE(4792), 1,
      aux_sym_object_repeat1,
    STATE(4815), 1,
      aux_sym_object_pattern_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(1971), 6,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(3814), 7,
      sym__automatic_semicolon,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_QMARK,
      anon_sym_PIPE_RBRACE,
    ACTIONS(1969), 23,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [67463] = 9,
    ACTIONS(3808), 1,
      anon_sym_COMMA,
    ACTIONS(3912), 1,
      anon_sym_RBRACE,
    ACTIONS(4622), 1,
      anon_sym_EQ,
    STATE(4792), 1,
      aux_sym_object_repeat1,
    STATE(4815), 1,
      aux_sym_object_pattern_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(1975), 6,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(3814), 7,
      sym__automatic_semicolon,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_QMARK,
      anon_sym_PIPE_RBRACE,
    ACTIONS(1973), 23,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [67525] = 9,
    ACTIONS(3808), 1,
      anon_sym_COMMA,
    ACTIONS(3925), 1,
      anon_sym_RBRACE,
    ACTIONS(4622), 1,
      anon_sym_EQ,
    STATE(4792), 1,
      aux_sym_object_repeat1,
    STATE(4815), 1,
      aux_sym_object_pattern_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(1971), 6,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(3814), 7,
      sym__automatic_semicolon,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_QMARK,
      anon_sym_PIPE_RBRACE,
    ACTIONS(1969), 23,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [67587] = 9,
    ACTIONS(3808), 1,
      anon_sym_COMMA,
    ACTIONS(3925), 1,
      anon_sym_RBRACE,
    ACTIONS(4622), 1,
      anon_sym_EQ,
    STATE(4792), 1,
      aux_sym_object_repeat1,
    STATE(4815), 1,
      aux_sym_object_pattern_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(1975), 6,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(3814), 7,
      sym__automatic_semicolon,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_QMARK,
      anon_sym_PIPE_RBRACE,
    ACTIONS(1973), 23,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [67649] = 33,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_as,
    ACTIONS(4640), 1,
      anon_sym_BANG,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4649), 1,
      anon_sym_satisfies,
    ACTIONS(4869), 1,
      anon_sym_COMMA,
    ACTIONS(4875), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4877), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4879), 1,
      anon_sym_GT_GT,
    ACTIONS(4883), 1,
      anon_sym_AMP,
    ACTIONS(4885), 1,
      anon_sym_CARET,
    ACTIONS(4887), 1,
      anon_sym_PIPE,
    ACTIONS(4891), 1,
      anon_sym_PERCENT,
    ACTIONS(4893), 1,
      anon_sym_STAR_STAR,
    ACTIONS(4895), 1,
      anon_sym_LT,
    ACTIONS(4903), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(4905), 1,
      sym__ternary_qmark,
    ACTIONS(5215), 1,
      anon_sym_RPAREN,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    STATE(5026), 1,
      aux_sym_sequence_expression_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4867), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(4873), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(4881), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(4889), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4899), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4901), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(4897), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [67759] = 9,
    ACTIONS(3808), 1,
      anon_sym_COMMA,
    ACTIONS(3811), 1,
      anon_sym_RBRACE,
    ACTIONS(4622), 1,
      anon_sym_EQ,
    STATE(4792), 1,
      aux_sym_object_repeat1,
    STATE(4815), 1,
      aux_sym_object_pattern_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(1971), 6,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(3814), 7,
      sym__automatic_semicolon,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_QMARK,
      anon_sym_PIPE_RBRACE,
    ACTIONS(1969), 23,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [67821] = 9,
    ACTIONS(3808), 1,
      anon_sym_COMMA,
    ACTIONS(3811), 1,
      anon_sym_RBRACE,
    ACTIONS(4622), 1,
      anon_sym_EQ,
    STATE(4792), 1,
      aux_sym_object_repeat1,
    STATE(4815), 1,
      aux_sym_object_pattern_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(1975), 6,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(3814), 7,
      sym__automatic_semicolon,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_QMARK,
      anon_sym_PIPE_RBRACE,
    ACTIONS(1973), 23,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [67883] = 33,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_as,
    ACTIONS(4640), 1,
      anon_sym_BANG,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4649), 1,
      anon_sym_satisfies,
    ACTIONS(4708), 1,
      anon_sym_LT,
    ACTIONS(4714), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4716), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4718), 1,
      anon_sym_GT_GT,
    ACTIONS(4722), 1,
      anon_sym_AMP,
    ACTIONS(4724), 1,
      anon_sym_CARET,
    ACTIONS(4726), 1,
      anon_sym_PIPE,
    ACTIONS(4730), 1,
      anon_sym_PERCENT,
    ACTIONS(4732), 1,
      anon_sym_STAR_STAR,
    ACTIONS(4740), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(4742), 1,
      sym__ternary_qmark,
    ACTIONS(5217), 1,
      anon_sym_COMMA,
    ACTIONS(5219), 1,
      anon_sym_SEMI,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(3792), 1,
      aux_sym_sequence_expression_repeat1,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4710), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(4712), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(4720), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(4728), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4736), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4738), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(4734), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [67993] = 5,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(5221), 2,
      anon_sym_EQ,
      anon_sym_QMARK,
    ACTIONS(5223), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_COLON,
    ACTIONS(3492), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(3496), 23,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [68047] = 33,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_as,
    ACTIONS(4640), 1,
      anon_sym_BANG,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4649), 1,
      anon_sym_satisfies,
    ACTIONS(4708), 1,
      anon_sym_LT,
    ACTIONS(4714), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4716), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4718), 1,
      anon_sym_GT_GT,
    ACTIONS(4722), 1,
      anon_sym_AMP,
    ACTIONS(4724), 1,
      anon_sym_CARET,
    ACTIONS(4726), 1,
      anon_sym_PIPE,
    ACTIONS(4730), 1,
      anon_sym_PERCENT,
    ACTIONS(4732), 1,
      anon_sym_STAR_STAR,
    ACTIONS(4740), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(4742), 1,
      sym__ternary_qmark,
    ACTIONS(5225), 1,
      anon_sym_COMMA,
    ACTIONS(5227), 1,
      anon_sym_RBRACK,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    STATE(4879), 1,
      aux_sym_array_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4710), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(4712), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(4720), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(4728), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4736), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4738), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(4734), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [68157] = 5,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(5229), 2,
      anon_sym_EQ,
      anon_sym_QMARK,
    ACTIONS(5231), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_COLON,
    ACTIONS(3492), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(3496), 23,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [68211] = 5,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(5229), 2,
      anon_sym_EQ,
      anon_sym_QMARK,
    ACTIONS(5231), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_COLON,
    ACTIONS(3492), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(3496), 23,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [68265] = 5,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(5229), 2,
      anon_sym_EQ,
      anon_sym_QMARK,
    ACTIONS(5231), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_COLON,
    ACTIONS(3492), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(3496), 23,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [68319] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4288), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4290), 28,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [68369] = 8,
    ACTIONS(4588), 1,
      anon_sym_LPAREN,
    ACTIONS(5233), 1,
      anon_sym_LT,
    STATE(2019), 1,
      sym_type_arguments,
    STATE(2130), 1,
      sym_arguments,
    STATE(4524), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4704), 12,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4706), 24,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [68429] = 31,
    ACTIONS(4588), 1,
      anon_sym_LPAREN,
    ACTIONS(4590), 1,
      anon_sym_LBRACK,
    ACTIONS(4592), 1,
      anon_sym_DOT,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4798), 1,
      anon_sym_as,
    ACTIONS(4800), 1,
      anon_sym_BANG,
    ACTIONS(4836), 1,
      anon_sym_satisfies,
    ACTIONS(5233), 1,
      anon_sym_LT,
    ACTIONS(5239), 1,
      anon_sym_AMP_AMP,
    ACTIONS(5241), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(5243), 1,
      anon_sym_GT_GT,
    ACTIONS(5247), 1,
      anon_sym_AMP,
    ACTIONS(5249), 1,
      anon_sym_CARET,
    ACTIONS(5251), 1,
      anon_sym_PIPE,
    ACTIONS(5255), 1,
      anon_sym_PERCENT,
    ACTIONS(5257), 1,
      anon_sym_STAR_STAR,
    ACTIONS(5265), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(5267), 1,
      sym__ternary_qmark,
    STATE(2019), 1,
      sym_type_arguments,
    STATE(2130), 1,
      sym_arguments,
    STATE(4524), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(5235), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(5237), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(5245), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(5253), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(5261), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(5263), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(4468), 3,
      sym__automatic_semicolon,
      anon_sym_SEMI,
      anon_sym_BQUOTE,
    ACTIONS(5259), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [68535] = 31,
    ACTIONS(4588), 1,
      anon_sym_LPAREN,
    ACTIONS(4590), 1,
      anon_sym_LBRACK,
    ACTIONS(4592), 1,
      anon_sym_DOT,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4798), 1,
      anon_sym_as,
    ACTIONS(4800), 1,
      anon_sym_BANG,
    ACTIONS(4836), 1,
      anon_sym_satisfies,
    ACTIONS(5233), 1,
      anon_sym_LT,
    ACTIONS(5239), 1,
      anon_sym_AMP_AMP,
    ACTIONS(5241), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(5243), 1,
      anon_sym_GT_GT,
    ACTIONS(5247), 1,
      anon_sym_AMP,
    ACTIONS(5249), 1,
      anon_sym_CARET,
    ACTIONS(5251), 1,
      anon_sym_PIPE,
    ACTIONS(5255), 1,
      anon_sym_PERCENT,
    ACTIONS(5257), 1,
      anon_sym_STAR_STAR,
    ACTIONS(5265), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(5267), 1,
      sym__ternary_qmark,
    STATE(2019), 1,
      sym_type_arguments,
    STATE(2130), 1,
      sym_arguments,
    STATE(4524), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(5235), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(5237), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(5245), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(5253), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(5261), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(5263), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(4744), 3,
      sym__automatic_semicolon,
      anon_sym_SEMI,
      anon_sym_BQUOTE,
    ACTIONS(5259), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [68641] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4536), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4538), 28,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [68691] = 31,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_as,
    ACTIONS(4640), 1,
      anon_sym_BANG,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4649), 1,
      anon_sym_satisfies,
    ACTIONS(4708), 1,
      anon_sym_LT,
    ACTIONS(4714), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4716), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4718), 1,
      anon_sym_GT_GT,
    ACTIONS(4722), 1,
      anon_sym_AMP,
    ACTIONS(4724), 1,
      anon_sym_CARET,
    ACTIONS(4726), 1,
      anon_sym_PIPE,
    ACTIONS(4730), 1,
      anon_sym_PERCENT,
    ACTIONS(4732), 1,
      anon_sym_STAR_STAR,
    ACTIONS(4740), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(4742), 1,
      sym__ternary_qmark,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4710), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(4712), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(4720), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(4728), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4736), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4738), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(4734), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
    ACTIONS(5269), 3,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_RBRACK,
  [68797] = 31,
    ACTIONS(4588), 1,
      anon_sym_LPAREN,
    ACTIONS(4590), 1,
      anon_sym_LBRACK,
    ACTIONS(4592), 1,
      anon_sym_DOT,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4798), 1,
      anon_sym_as,
    ACTIONS(4800), 1,
      anon_sym_BANG,
    ACTIONS(4836), 1,
      anon_sym_satisfies,
    ACTIONS(5233), 1,
      anon_sym_LT,
    ACTIONS(5239), 1,
      anon_sym_AMP_AMP,
    ACTIONS(5241), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(5243), 1,
      anon_sym_GT_GT,
    ACTIONS(5247), 1,
      anon_sym_AMP,
    ACTIONS(5249), 1,
      anon_sym_CARET,
    ACTIONS(5251), 1,
      anon_sym_PIPE,
    ACTIONS(5255), 1,
      anon_sym_PERCENT,
    ACTIONS(5257), 1,
      anon_sym_STAR_STAR,
    ACTIONS(5265), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(5267), 1,
      sym__ternary_qmark,
    STATE(2019), 1,
      sym_type_arguments,
    STATE(2130), 1,
      sym_arguments,
    STATE(4524), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(5235), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(5237), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(5245), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(5253), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(5261), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(5263), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(4756), 3,
      sym__automatic_semicolon,
      anon_sym_SEMI,
      anon_sym_BQUOTE,
    ACTIONS(5259), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [68903] = 11,
    ACTIONS(1626), 1,
      anon_sym_DQUOTE,
    ACTIONS(1628), 1,
      anon_sym_SQUOTE,
    ACTIONS(4624), 1,
      anon_sym_LBRACK,
    ACTIONS(5271), 1,
      anon_sym_STAR,
    ACTIONS(5273), 1,
      anon_sym_async,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(5275), 2,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(5277), 2,
      anon_sym_get,
      anon_sym_set,
    STATE(3057), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(3814), 9,
      sym__automatic_semicolon,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_BANG,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_QMARK,
    ACTIONS(3700), 20,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [68969] = 10,
    ACTIONS(1550), 1,
      anon_sym_DQUOTE,
    ACTIONS(1552), 1,
      anon_sym_SQUOTE,
    ACTIONS(4688), 1,
      anon_sym_LBRACK,
    ACTIONS(5066), 1,
      anon_sym_STAR,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(5279), 2,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(5281), 2,
      anon_sym_get,
      anon_sym_set,
    STATE(3863), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(3814), 9,
      sym__automatic_semicolon,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_BANG,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_QMARK,
    ACTIONS(2351), 21,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [69033] = 31,
    ACTIONS(4588), 1,
      anon_sym_LPAREN,
    ACTIONS(4590), 1,
      anon_sym_LBRACK,
    ACTIONS(4592), 1,
      anon_sym_DOT,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4798), 1,
      anon_sym_as,
    ACTIONS(4800), 1,
      anon_sym_BANG,
    ACTIONS(4836), 1,
      anon_sym_satisfies,
    ACTIONS(5233), 1,
      anon_sym_LT,
    ACTIONS(5239), 1,
      anon_sym_AMP_AMP,
    ACTIONS(5241), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(5243), 1,
      anon_sym_GT_GT,
    ACTIONS(5247), 1,
      anon_sym_AMP,
    ACTIONS(5249), 1,
      anon_sym_CARET,
    ACTIONS(5251), 1,
      anon_sym_PIPE,
    ACTIONS(5255), 1,
      anon_sym_PERCENT,
    ACTIONS(5257), 1,
      anon_sym_STAR_STAR,
    ACTIONS(5265), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(5267), 1,
      sym__ternary_qmark,
    STATE(2019), 1,
      sym_type_arguments,
    STATE(2130), 1,
      sym_arguments,
    STATE(4524), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(5235), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(5237), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(5245), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(5253), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(5261), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(5263), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(4758), 3,
      sym__automatic_semicolon,
      anon_sym_SEMI,
      anon_sym_BQUOTE,
    ACTIONS(5259), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [69139] = 31,
    ACTIONS(4588), 1,
      anon_sym_LPAREN,
    ACTIONS(4590), 1,
      anon_sym_LBRACK,
    ACTIONS(4592), 1,
      anon_sym_DOT,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4798), 1,
      anon_sym_as,
    ACTIONS(4800), 1,
      anon_sym_BANG,
    ACTIONS(4836), 1,
      anon_sym_satisfies,
    ACTIONS(5233), 1,
      anon_sym_LT,
    ACTIONS(5239), 1,
      anon_sym_AMP_AMP,
    ACTIONS(5241), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(5243), 1,
      anon_sym_GT_GT,
    ACTIONS(5247), 1,
      anon_sym_AMP,
    ACTIONS(5249), 1,
      anon_sym_CARET,
    ACTIONS(5251), 1,
      anon_sym_PIPE,
    ACTIONS(5255), 1,
      anon_sym_PERCENT,
    ACTIONS(5257), 1,
      anon_sym_STAR_STAR,
    ACTIONS(5265), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(5267), 1,
      sym__ternary_qmark,
    STATE(2019), 1,
      sym_type_arguments,
    STATE(2130), 1,
      sym_arguments,
    STATE(4524), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(5235), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(5237), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(5245), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(5253), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(5261), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(5263), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(4504), 3,
      sym__automatic_semicolon,
      anon_sym_SEMI,
      anon_sym_BQUOTE,
    ACTIONS(5259), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [69245] = 18,
    ACTIONS(4588), 1,
      anon_sym_LPAREN,
    ACTIONS(4590), 1,
      anon_sym_LBRACK,
    ACTIONS(4592), 1,
      anon_sym_DOT,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(5233), 1,
      anon_sym_LT,
    ACTIONS(5243), 1,
      anon_sym_GT_GT,
    ACTIONS(5255), 1,
      anon_sym_PERCENT,
    ACTIONS(5257), 1,
      anon_sym_STAR_STAR,
    STATE(2019), 1,
      sym_type_arguments,
    STATE(2130), 1,
      sym_arguments,
    STATE(4524), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(5235), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(5245), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(5253), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4762), 7,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4760), 15,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_SEMI,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [69325] = 33,
    ACTIONS(1977), 1,
      anon_sym_COMMA,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_as,
    ACTIONS(4640), 1,
      anon_sym_BANG,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4649), 1,
      anon_sym_satisfies,
    ACTIONS(4875), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4877), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4879), 1,
      anon_sym_GT_GT,
    ACTIONS(4883), 1,
      anon_sym_AMP,
    ACTIONS(4885), 1,
      anon_sym_CARET,
    ACTIONS(4887), 1,
      anon_sym_PIPE,
    ACTIONS(4891), 1,
      anon_sym_PERCENT,
    ACTIONS(4893), 1,
      anon_sym_STAR_STAR,
    ACTIONS(4895), 1,
      anon_sym_LT,
    ACTIONS(4903), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(4905), 1,
      sym__ternary_qmark,
    ACTIONS(5283), 1,
      anon_sym_RPAREN,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4647), 1,
      aux_sym_array_repeat1,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4867), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(4873), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(4881), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(4889), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4899), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4901), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(4897), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [69435] = 13,
    ACTIONS(4588), 1,
      anon_sym_LPAREN,
    ACTIONS(4590), 1,
      anon_sym_LBRACK,
    ACTIONS(4592), 1,
      anon_sym_DOT,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(5257), 1,
      anon_sym_STAR_STAR,
    ACTIONS(5285), 1,
      anon_sym_LT,
    STATE(2019), 1,
      sym_type_arguments,
    STATE(2130), 1,
      sym_arguments,
    STATE(4524), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4762), 12,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4760), 18,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_SEMI,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [69505] = 33,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_as,
    ACTIONS(4640), 1,
      anon_sym_BANG,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4649), 1,
      anon_sym_satisfies,
    ACTIONS(4708), 1,
      anon_sym_LT,
    ACTIONS(4714), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4716), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4718), 1,
      anon_sym_GT_GT,
    ACTIONS(4722), 1,
      anon_sym_AMP,
    ACTIONS(4724), 1,
      anon_sym_CARET,
    ACTIONS(4726), 1,
      anon_sym_PIPE,
    ACTIONS(4730), 1,
      anon_sym_PERCENT,
    ACTIONS(4732), 1,
      anon_sym_STAR_STAR,
    ACTIONS(4740), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(4742), 1,
      sym__ternary_qmark,
    ACTIONS(5217), 1,
      anon_sym_COMMA,
    ACTIONS(5288), 1,
      anon_sym_RBRACK,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(3792), 1,
      aux_sym_sequence_expression_repeat1,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4710), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(4712), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(4720), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(4728), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4736), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4738), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(4734), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [69615] = 25,
    ACTIONS(4588), 1,
      anon_sym_LPAREN,
    ACTIONS(4590), 1,
      anon_sym_LBRACK,
    ACTIONS(4592), 1,
      anon_sym_DOT,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4762), 1,
      anon_sym_BANG,
    ACTIONS(5233), 1,
      anon_sym_LT,
    ACTIONS(5243), 1,
      anon_sym_GT_GT,
    ACTIONS(5247), 1,
      anon_sym_AMP,
    ACTIONS(5249), 1,
      anon_sym_CARET,
    ACTIONS(5251), 1,
      anon_sym_PIPE,
    ACTIONS(5255), 1,
      anon_sym_PERCENT,
    ACTIONS(5257), 1,
      anon_sym_STAR_STAR,
    STATE(2019), 1,
      sym_type_arguments,
    STATE(2130), 1,
      sym_arguments,
    STATE(4524), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(5235), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(5237), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(5245), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(5253), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(5261), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(5263), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(5259), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
    ACTIONS(4760), 9,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_SEMI,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [69709] = 26,
    ACTIONS(4588), 1,
      anon_sym_LPAREN,
    ACTIONS(4590), 1,
      anon_sym_LBRACK,
    ACTIONS(4592), 1,
      anon_sym_DOT,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4762), 1,
      anon_sym_BANG,
    ACTIONS(5233), 1,
      anon_sym_LT,
    ACTIONS(5239), 1,
      anon_sym_AMP_AMP,
    ACTIONS(5243), 1,
      anon_sym_GT_GT,
    ACTIONS(5247), 1,
      anon_sym_AMP,
    ACTIONS(5249), 1,
      anon_sym_CARET,
    ACTIONS(5251), 1,
      anon_sym_PIPE,
    ACTIONS(5255), 1,
      anon_sym_PERCENT,
    ACTIONS(5257), 1,
      anon_sym_STAR_STAR,
    STATE(2019), 1,
      sym_type_arguments,
    STATE(2130), 1,
      sym_arguments,
    STATE(4524), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(5235), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(5237), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(5245), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(5253), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(5261), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(5263), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(5259), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
    ACTIONS(4760), 8,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [69805] = 16,
    ACTIONS(4588), 1,
      anon_sym_LPAREN,
    ACTIONS(4590), 1,
      anon_sym_LBRACK,
    ACTIONS(4592), 1,
      anon_sym_DOT,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(5255), 1,
      anon_sym_PERCENT,
    ACTIONS(5257), 1,
      anon_sym_STAR_STAR,
    ACTIONS(5285), 1,
      anon_sym_LT,
    STATE(2019), 1,
      sym_type_arguments,
    STATE(2130), 1,
      sym_arguments,
    STATE(4524), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(5235), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(5253), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4762), 8,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4760), 17,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_SEMI,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [69881] = 22,
    ACTIONS(4588), 1,
      anon_sym_LPAREN,
    ACTIONS(4590), 1,
      anon_sym_LBRACK,
    ACTIONS(4592), 1,
      anon_sym_DOT,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(5233), 1,
      anon_sym_LT,
    ACTIONS(5243), 1,
      anon_sym_GT_GT,
    ACTIONS(5255), 1,
      anon_sym_PERCENT,
    ACTIONS(5257), 1,
      anon_sym_STAR_STAR,
    STATE(2019), 1,
      sym_type_arguments,
    STATE(2130), 1,
      sym_arguments,
    STATE(4524), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(5235), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(5237), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(5245), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(5253), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(5261), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(5263), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(4762), 3,
      anon_sym_BANG,
      anon_sym_AMP,
      anon_sym_PIPE,
    ACTIONS(5259), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
    ACTIONS(4760), 10,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_SEMI,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_CARET,
      anon_sym_QMARK_QMARK,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [69969] = 23,
    ACTIONS(4588), 1,
      anon_sym_LPAREN,
    ACTIONS(4590), 1,
      anon_sym_LBRACK,
    ACTIONS(4592), 1,
      anon_sym_DOT,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(5233), 1,
      anon_sym_LT,
    ACTIONS(5243), 1,
      anon_sym_GT_GT,
    ACTIONS(5247), 1,
      anon_sym_AMP,
    ACTIONS(5255), 1,
      anon_sym_PERCENT,
    ACTIONS(5257), 1,
      anon_sym_STAR_STAR,
    STATE(2019), 1,
      sym_type_arguments,
    STATE(2130), 1,
      sym_arguments,
    STATE(4524), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4762), 2,
      anon_sym_BANG,
      anon_sym_PIPE,
    ACTIONS(4834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(5235), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(5237), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(5245), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(5253), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(5261), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(5263), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(5259), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
    ACTIONS(4760), 10,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_SEMI,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_CARET,
      anon_sym_QMARK_QMARK,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [70059] = 24,
    ACTIONS(4588), 1,
      anon_sym_LPAREN,
    ACTIONS(4590), 1,
      anon_sym_LBRACK,
    ACTIONS(4592), 1,
      anon_sym_DOT,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(5233), 1,
      anon_sym_LT,
    ACTIONS(5243), 1,
      anon_sym_GT_GT,
    ACTIONS(5247), 1,
      anon_sym_AMP,
    ACTIONS(5249), 1,
      anon_sym_CARET,
    ACTIONS(5255), 1,
      anon_sym_PERCENT,
    ACTIONS(5257), 1,
      anon_sym_STAR_STAR,
    STATE(2019), 1,
      sym_type_arguments,
    STATE(2130), 1,
      sym_arguments,
    STATE(4524), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4762), 2,
      anon_sym_BANG,
      anon_sym_PIPE,
    ACTIONS(4834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(5235), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(5237), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(5245), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(5253), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(5261), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(5263), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(5259), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
    ACTIONS(4760), 9,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_SEMI,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [70151] = 15,
    ACTIONS(4588), 1,
      anon_sym_LPAREN,
    ACTIONS(4590), 1,
      anon_sym_LBRACK,
    ACTIONS(4592), 1,
      anon_sym_DOT,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(5255), 1,
      anon_sym_PERCENT,
    ACTIONS(5257), 1,
      anon_sym_STAR_STAR,
    ACTIONS(5285), 1,
      anon_sym_LT,
    STATE(2019), 1,
      sym_type_arguments,
    STATE(2130), 1,
      sym_arguments,
    STATE(4524), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(5235), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(4762), 10,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4760), 17,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_SEMI,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [70225] = 16,
    ACTIONS(4588), 1,
      anon_sym_LPAREN,
    ACTIONS(4590), 1,
      anon_sym_LBRACK,
    ACTIONS(4592), 1,
      anon_sym_DOT,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4798), 1,
      anon_sym_as,
    ACTIONS(4800), 1,
      anon_sym_BANG,
    ACTIONS(4836), 1,
      anon_sym_satisfies,
    ACTIONS(5257), 1,
      anon_sym_STAR_STAR,
    ACTIONS(5285), 1,
      anon_sym_LT,
    STATE(2019), 1,
      sym_type_arguments,
    STATE(2130), 1,
      sym_arguments,
    STATE(4524), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4762), 11,
      anon_sym_STAR,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4760), 16,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_SEMI,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_BQUOTE,
  [70301] = 20,
    ACTIONS(4588), 1,
      anon_sym_LPAREN,
    ACTIONS(4590), 1,
      anon_sym_LBRACK,
    ACTIONS(4592), 1,
      anon_sym_DOT,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(5233), 1,
      anon_sym_LT,
    ACTIONS(5243), 1,
      anon_sym_GT_GT,
    ACTIONS(5255), 1,
      anon_sym_PERCENT,
    ACTIONS(5257), 1,
      anon_sym_STAR_STAR,
    STATE(2019), 1,
      sym_type_arguments,
    STATE(2130), 1,
      sym_arguments,
    STATE(4524), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(5235), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(5237), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(5245), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(5253), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(5259), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
    ACTIONS(4762), 5,
      anon_sym_BANG,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4760), 12,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_SEMI,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_CARET,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [70385] = 27,
    ACTIONS(4588), 1,
      anon_sym_LPAREN,
    ACTIONS(4590), 1,
      anon_sym_LBRACK,
    ACTIONS(4592), 1,
      anon_sym_DOT,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4762), 1,
      anon_sym_BANG,
    ACTIONS(5233), 1,
      anon_sym_LT,
    ACTIONS(5239), 1,
      anon_sym_AMP_AMP,
    ACTIONS(5241), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(5243), 1,
      anon_sym_GT_GT,
    ACTIONS(5247), 1,
      anon_sym_AMP,
    ACTIONS(5249), 1,
      anon_sym_CARET,
    ACTIONS(5251), 1,
      anon_sym_PIPE,
    ACTIONS(5255), 1,
      anon_sym_PERCENT,
    ACTIONS(5257), 1,
      anon_sym_STAR_STAR,
    STATE(2019), 1,
      sym_type_arguments,
    STATE(2130), 1,
      sym_arguments,
    STATE(4524), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(5235), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(5237), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(5245), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(5253), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(5261), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(5263), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(5259), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
    ACTIONS(4760), 7,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_SEMI,
      anon_sym_QMARK_QMARK,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [70483] = 31,
    ACTIONS(4588), 1,
      anon_sym_LPAREN,
    ACTIONS(4590), 1,
      anon_sym_LBRACK,
    ACTIONS(4592), 1,
      anon_sym_DOT,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4798), 1,
      anon_sym_as,
    ACTIONS(4800), 1,
      anon_sym_BANG,
    ACTIONS(4836), 1,
      anon_sym_satisfies,
    ACTIONS(5233), 1,
      anon_sym_LT,
    ACTIONS(5239), 1,
      anon_sym_AMP_AMP,
    ACTIONS(5241), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(5243), 1,
      anon_sym_GT_GT,
    ACTIONS(5247), 1,
      anon_sym_AMP,
    ACTIONS(5249), 1,
      anon_sym_CARET,
    ACTIONS(5251), 1,
      anon_sym_PIPE,
    ACTIONS(5255), 1,
      anon_sym_PERCENT,
    ACTIONS(5257), 1,
      anon_sym_STAR_STAR,
    ACTIONS(5265), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(5267), 1,
      sym__ternary_qmark,
    STATE(2019), 1,
      sym_type_arguments,
    STATE(2130), 1,
      sym_arguments,
    STATE(4524), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(5235), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(5237), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(5245), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(5253), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(5261), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(5263), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(4522), 3,
      sym__automatic_semicolon,
      anon_sym_SEMI,
      anon_sym_BQUOTE,
    ACTIONS(5259), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [70589] = 31,
    ACTIONS(4588), 1,
      anon_sym_LPAREN,
    ACTIONS(4590), 1,
      anon_sym_LBRACK,
    ACTIONS(4592), 1,
      anon_sym_DOT,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4798), 1,
      anon_sym_as,
    ACTIONS(4800), 1,
      anon_sym_BANG,
    ACTIONS(4836), 1,
      anon_sym_satisfies,
    ACTIONS(5233), 1,
      anon_sym_LT,
    ACTIONS(5239), 1,
      anon_sym_AMP_AMP,
    ACTIONS(5241), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(5243), 1,
      anon_sym_GT_GT,
    ACTIONS(5247), 1,
      anon_sym_AMP,
    ACTIONS(5249), 1,
      anon_sym_CARET,
    ACTIONS(5251), 1,
      anon_sym_PIPE,
    ACTIONS(5255), 1,
      anon_sym_PERCENT,
    ACTIONS(5257), 1,
      anon_sym_STAR_STAR,
    ACTIONS(5265), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(5267), 1,
      sym__ternary_qmark,
    STATE(2019), 1,
      sym_type_arguments,
    STATE(2130), 1,
      sym_arguments,
    STATE(4524), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(5235), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(5237), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(5245), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(5253), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(5261), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(5263), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(4767), 3,
      sym__automatic_semicolon,
      anon_sym_SEMI,
      anon_sym_BQUOTE,
    ACTIONS(5259), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [70695] = 11,
    ACTIONS(1626), 1,
      anon_sym_DQUOTE,
    ACTIONS(1628), 1,
      anon_sym_SQUOTE,
    ACTIONS(4624), 1,
      anon_sym_LBRACK,
    ACTIONS(5066), 1,
      anon_sym_STAR,
    ACTIONS(5068), 1,
      anon_sym_async,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(5070), 2,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(5074), 2,
      anon_sym_get,
      anon_sym_set,
    STATE(3064), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(3814), 9,
      sym__automatic_semicolon,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_BANG,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_QMARK,
    ACTIONS(3700), 20,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [70761] = 31,
    ACTIONS(4588), 1,
      anon_sym_LPAREN,
    ACTIONS(4590), 1,
      anon_sym_LBRACK,
    ACTIONS(4592), 1,
      anon_sym_DOT,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4798), 1,
      anon_sym_as,
    ACTIONS(4800), 1,
      anon_sym_BANG,
    ACTIONS(4836), 1,
      anon_sym_satisfies,
    ACTIONS(5233), 1,
      anon_sym_LT,
    ACTIONS(5239), 1,
      anon_sym_AMP_AMP,
    ACTIONS(5241), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(5243), 1,
      anon_sym_GT_GT,
    ACTIONS(5247), 1,
      anon_sym_AMP,
    ACTIONS(5249), 1,
      anon_sym_CARET,
    ACTIONS(5251), 1,
      anon_sym_PIPE,
    ACTIONS(5255), 1,
      anon_sym_PERCENT,
    ACTIONS(5257), 1,
      anon_sym_STAR_STAR,
    ACTIONS(5265), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(5267), 1,
      sym__ternary_qmark,
    STATE(2019), 1,
      sym_type_arguments,
    STATE(2130), 1,
      sym_arguments,
    STATE(4524), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(5235), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(5237), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(5245), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(5253), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(5261), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(5263), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(4546), 3,
      sym__automatic_semicolon,
      anon_sym_SEMI,
      anon_sym_BQUOTE,
    ACTIONS(5259), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [70867] = 31,
    ACTIONS(4588), 1,
      anon_sym_LPAREN,
    ACTIONS(4590), 1,
      anon_sym_LBRACK,
    ACTIONS(4592), 1,
      anon_sym_DOT,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4798), 1,
      anon_sym_as,
    ACTIONS(4800), 1,
      anon_sym_BANG,
    ACTIONS(4836), 1,
      anon_sym_satisfies,
    ACTIONS(5233), 1,
      anon_sym_LT,
    ACTIONS(5239), 1,
      anon_sym_AMP_AMP,
    ACTIONS(5241), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(5243), 1,
      anon_sym_GT_GT,
    ACTIONS(5247), 1,
      anon_sym_AMP,
    ACTIONS(5249), 1,
      anon_sym_CARET,
    ACTIONS(5251), 1,
      anon_sym_PIPE,
    ACTIONS(5255), 1,
      anon_sym_PERCENT,
    ACTIONS(5257), 1,
      anon_sym_STAR_STAR,
    ACTIONS(5265), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(5267), 1,
      sym__ternary_qmark,
    STATE(2019), 1,
      sym_type_arguments,
    STATE(2130), 1,
      sym_arguments,
    STATE(4524), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(5235), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(5237), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(5245), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(5253), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(5261), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(5263), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(4554), 3,
      sym__automatic_semicolon,
      anon_sym_SEMI,
      anon_sym_BQUOTE,
    ACTIONS(5259), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [70973] = 31,
    ACTIONS(4588), 1,
      anon_sym_LPAREN,
    ACTIONS(4590), 1,
      anon_sym_LBRACK,
    ACTIONS(4592), 1,
      anon_sym_DOT,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4798), 1,
      anon_sym_as,
    ACTIONS(4800), 1,
      anon_sym_BANG,
    ACTIONS(4836), 1,
      anon_sym_satisfies,
    ACTIONS(5233), 1,
      anon_sym_LT,
    ACTIONS(5239), 1,
      anon_sym_AMP_AMP,
    ACTIONS(5241), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(5243), 1,
      anon_sym_GT_GT,
    ACTIONS(5247), 1,
      anon_sym_AMP,
    ACTIONS(5249), 1,
      anon_sym_CARET,
    ACTIONS(5251), 1,
      anon_sym_PIPE,
    ACTIONS(5255), 1,
      anon_sym_PERCENT,
    ACTIONS(5257), 1,
      anon_sym_STAR_STAR,
    ACTIONS(5265), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(5267), 1,
      sym__ternary_qmark,
    STATE(2019), 1,
      sym_type_arguments,
    STATE(2130), 1,
      sym_arguments,
    STATE(4524), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(5235), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(5237), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(5245), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(5253), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(5261), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(5263), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(4558), 3,
      sym__automatic_semicolon,
      anon_sym_SEMI,
      anon_sym_BQUOTE,
    ACTIONS(5259), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [71079] = 31,
    ACTIONS(4588), 1,
      anon_sym_LPAREN,
    ACTIONS(4590), 1,
      anon_sym_LBRACK,
    ACTIONS(4592), 1,
      anon_sym_DOT,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4798), 1,
      anon_sym_as,
    ACTIONS(4800), 1,
      anon_sym_BANG,
    ACTIONS(4836), 1,
      anon_sym_satisfies,
    ACTIONS(5233), 1,
      anon_sym_LT,
    ACTIONS(5239), 1,
      anon_sym_AMP_AMP,
    ACTIONS(5241), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(5243), 1,
      anon_sym_GT_GT,
    ACTIONS(5247), 1,
      anon_sym_AMP,
    ACTIONS(5249), 1,
      anon_sym_CARET,
    ACTIONS(5251), 1,
      anon_sym_PIPE,
    ACTIONS(5255), 1,
      anon_sym_PERCENT,
    ACTIONS(5257), 1,
      anon_sym_STAR_STAR,
    ACTIONS(5265), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(5267), 1,
      sym__ternary_qmark,
    STATE(2019), 1,
      sym_type_arguments,
    STATE(2130), 1,
      sym_arguments,
    STATE(4524), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(5235), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(5237), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(5245), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(5253), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(5261), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(5263), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(4769), 3,
      sym__automatic_semicolon,
      anon_sym_SEMI,
      anon_sym_BQUOTE,
    ACTIONS(5259), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [71185] = 31,
    ACTIONS(4588), 1,
      anon_sym_LPAREN,
    ACTIONS(4590), 1,
      anon_sym_LBRACK,
    ACTIONS(4592), 1,
      anon_sym_DOT,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4798), 1,
      anon_sym_as,
    ACTIONS(4800), 1,
      anon_sym_BANG,
    ACTIONS(4836), 1,
      anon_sym_satisfies,
    ACTIONS(5233), 1,
      anon_sym_LT,
    ACTIONS(5239), 1,
      anon_sym_AMP_AMP,
    ACTIONS(5241), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(5243), 1,
      anon_sym_GT_GT,
    ACTIONS(5247), 1,
      anon_sym_AMP,
    ACTIONS(5249), 1,
      anon_sym_CARET,
    ACTIONS(5251), 1,
      anon_sym_PIPE,
    ACTIONS(5255), 1,
      anon_sym_PERCENT,
    ACTIONS(5257), 1,
      anon_sym_STAR_STAR,
    ACTIONS(5265), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(5267), 1,
      sym__ternary_qmark,
    STATE(2019), 1,
      sym_type_arguments,
    STATE(2130), 1,
      sym_arguments,
    STATE(4524), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(5235), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(5237), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(5245), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(5253), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(5261), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(5263), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(4771), 3,
      sym__automatic_semicolon,
      anon_sym_SEMI,
      anon_sym_BQUOTE,
    ACTIONS(5259), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [71291] = 5,
    ACTIONS(1766), 1,
      sym__automatic_semicolon,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(1758), 2,
      anon_sym_else,
      anon_sym_while,
    ACTIONS(1762), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(1764), 25,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [71345] = 5,
    ACTIONS(1798), 1,
      sym__automatic_semicolon,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(1790), 2,
      anon_sym_else,
      anon_sym_while,
    ACTIONS(1794), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(1796), 25,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [71399] = 5,
    ACTIONS(1778), 1,
      sym__automatic_semicolon,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(1770), 2,
      anon_sym_else,
      anon_sym_while,
    ACTIONS(1774), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(1776), 25,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [71453] = 33,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_as,
    ACTIONS(4640), 1,
      anon_sym_BANG,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4649), 1,
      anon_sym_satisfies,
    ACTIONS(4708), 1,
      anon_sym_LT,
    ACTIONS(4714), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4716), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4718), 1,
      anon_sym_GT_GT,
    ACTIONS(4722), 1,
      anon_sym_AMP,
    ACTIONS(4724), 1,
      anon_sym_CARET,
    ACTIONS(4726), 1,
      anon_sym_PIPE,
    ACTIONS(4730), 1,
      anon_sym_PERCENT,
    ACTIONS(4732), 1,
      anon_sym_STAR_STAR,
    ACTIONS(4740), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(4742), 1,
      sym__ternary_qmark,
    ACTIONS(5217), 1,
      anon_sym_COMMA,
    ACTIONS(5290), 1,
      anon_sym_RBRACK,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(3792), 1,
      aux_sym_sequence_expression_repeat1,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4710), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(4712), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(4720), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(4728), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4736), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4738), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(4734), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [71563] = 31,
    ACTIONS(4588), 1,
      anon_sym_LPAREN,
    ACTIONS(4590), 1,
      anon_sym_LBRACK,
    ACTIONS(4592), 1,
      anon_sym_DOT,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4798), 1,
      anon_sym_as,
    ACTIONS(4800), 1,
      anon_sym_BANG,
    ACTIONS(4836), 1,
      anon_sym_satisfies,
    ACTIONS(5233), 1,
      anon_sym_LT,
    ACTIONS(5239), 1,
      anon_sym_AMP_AMP,
    ACTIONS(5241), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(5243), 1,
      anon_sym_GT_GT,
    ACTIONS(5247), 1,
      anon_sym_AMP,
    ACTIONS(5249), 1,
      anon_sym_CARET,
    ACTIONS(5251), 1,
      anon_sym_PIPE,
    ACTIONS(5255), 1,
      anon_sym_PERCENT,
    ACTIONS(5257), 1,
      anon_sym_STAR_STAR,
    ACTIONS(5265), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(5267), 1,
      sym__ternary_qmark,
    STATE(2019), 1,
      sym_type_arguments,
    STATE(2130), 1,
      sym_arguments,
    STATE(4524), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(5235), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(5237), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(5245), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(5253), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(5261), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(5263), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(4773), 3,
      sym__automatic_semicolon,
      anon_sym_SEMI,
      anon_sym_BQUOTE,
    ACTIONS(5259), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [71669] = 5,
    ACTIONS(1788), 1,
      sym__automatic_semicolon,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(1780), 2,
      anon_sym_else,
      anon_sym_while,
    ACTIONS(1784), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(1786), 25,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [71723] = 15,
    ACTIONS(237), 1,
      anon_sym_COMMA,
    ACTIONS(694), 1,
      anon_sym_RBRACE,
    ACTIONS(1550), 1,
      anon_sym_DQUOTE,
    ACTIONS(1552), 1,
      anon_sym_SQUOTE,
    ACTIONS(4622), 1,
      anon_sym_EQ,
    ACTIONS(4688), 1,
      anon_sym_LBRACK,
    ACTIONS(4990), 1,
      anon_sym_STAR,
    STATE(4792), 1,
      aux_sym_object_repeat1,
    STATE(4815), 1,
      aux_sym_object_pattern_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(2337), 2,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(2357), 2,
      anon_sym_get,
      anon_sym_set,
    STATE(3816), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(3814), 4,
      anon_sym_LPAREN,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_QMARK,
    ACTIONS(2351), 21,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [71797] = 5,
    ACTIONS(1808), 1,
      sym__automatic_semicolon,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(1800), 2,
      anon_sym_else,
      anon_sym_while,
    ACTIONS(1804), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(1806), 25,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [71851] = 10,
    ACTIONS(1550), 1,
      anon_sym_DQUOTE,
    ACTIONS(1552), 1,
      anon_sym_SQUOTE,
    ACTIONS(4688), 1,
      anon_sym_LBRACK,
    ACTIONS(5076), 1,
      anon_sym_STAR,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(5292), 2,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(5294), 2,
      anon_sym_get,
      anon_sym_set,
    STATE(3853), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(3814), 9,
      sym__automatic_semicolon,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_BANG,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_QMARK,
    ACTIONS(2351), 21,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [71915] = 16,
    ACTIONS(237), 1,
      anon_sym_COMMA,
    ACTIONS(694), 1,
      anon_sym_RBRACE,
    ACTIONS(1550), 1,
      anon_sym_DQUOTE,
    ACTIONS(1552), 1,
      anon_sym_SQUOTE,
    ACTIONS(2353), 1,
      anon_sym_async,
    ACTIONS(4622), 1,
      anon_sym_EQ,
    ACTIONS(4688), 1,
      anon_sym_LBRACK,
    ACTIONS(4990), 1,
      anon_sym_STAR,
    STATE(4792), 1,
      aux_sym_object_repeat1,
    STATE(4815), 1,
      aux_sym_object_pattern_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(2337), 2,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(2357), 2,
      anon_sym_get,
      anon_sym_set,
    STATE(3816), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(3814), 4,
      anon_sym_LPAREN,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_QMARK,
    ACTIONS(2351), 20,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [71991] = 4,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(1842), 5,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACE,
    ACTIONS(1846), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(1848), 23,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [72043] = 33,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_as,
    ACTIONS(4640), 1,
      anon_sym_BANG,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4649), 1,
      anon_sym_satisfies,
    ACTIONS(4869), 1,
      anon_sym_COMMA,
    ACTIONS(4875), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4877), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4879), 1,
      anon_sym_GT_GT,
    ACTIONS(4883), 1,
      anon_sym_AMP,
    ACTIONS(4885), 1,
      anon_sym_CARET,
    ACTIONS(4887), 1,
      anon_sym_PIPE,
    ACTIONS(4891), 1,
      anon_sym_PERCENT,
    ACTIONS(4893), 1,
      anon_sym_STAR_STAR,
    ACTIONS(4895), 1,
      anon_sym_LT,
    ACTIONS(4903), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(4905), 1,
      sym__ternary_qmark,
    ACTIONS(5296), 1,
      anon_sym_RPAREN,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    STATE(5026), 1,
      aux_sym_sequence_expression_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4867), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(4873), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(4881), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(4889), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4899), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4901), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(4897), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [72153] = 8,
    ACTIONS(3550), 1,
      anon_sym_EQ,
    ACTIONS(4406), 1,
      anon_sym_QMARK,
    ACTIONS(4608), 1,
      anon_sym_LBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4611), 2,
      anon_sym_AMP,
      anon_sym_PIPE,
    ACTIONS(4408), 3,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_extends,
    ACTIONS(3492), 11,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(3496), 22,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [72213] = 6,
    ACTIONS(4510), 1,
      anon_sym_LBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4106), 2,
      anon_sym_COMMA,
      anon_sym_extends,
    ACTIONS(4513), 3,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_GT,
    ACTIONS(3492), 10,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(3496), 25,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_of,
      anon_sym_COLON,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [72269] = 10,
    ACTIONS(1550), 1,
      anon_sym_DQUOTE,
    ACTIONS(1552), 1,
      anon_sym_SQUOTE,
    ACTIONS(4688), 1,
      anon_sym_LBRACK,
    ACTIONS(5298), 1,
      anon_sym_STAR,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(5300), 2,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(5302), 2,
      anon_sym_get,
      anon_sym_set,
    STATE(3780), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(3814), 9,
      sym__automatic_semicolon,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_BANG,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_QMARK,
    ACTIONS(2351), 21,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [72333] = 11,
    ACTIONS(1626), 1,
      anon_sym_DQUOTE,
    ACTIONS(1628), 1,
      anon_sym_SQUOTE,
    ACTIONS(4624), 1,
      anon_sym_LBRACK,
    ACTIONS(5209), 1,
      anon_sym_STAR,
    ACTIONS(5304), 1,
      anon_sym_async,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(5306), 2,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(5308), 2,
      anon_sym_get,
      anon_sym_set,
    STATE(3063), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(3814), 9,
      sym__automatic_semicolon,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_BANG,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_QMARK,
    ACTIONS(3700), 20,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [72399] = 11,
    ACTIONS(1626), 1,
      anon_sym_DQUOTE,
    ACTIONS(1628), 1,
      anon_sym_SQUOTE,
    ACTIONS(4624), 1,
      anon_sym_LBRACK,
    ACTIONS(5310), 1,
      anon_sym_STAR,
    ACTIONS(5312), 1,
      anon_sym_async,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(5314), 2,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(5316), 2,
      anon_sym_get,
      anon_sym_set,
    STATE(3105), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(3814), 9,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_QMARK,
      anon_sym_PIPE_RBRACE,
    ACTIONS(3700), 20,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [72465] = 4,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(1790), 5,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACE,
    ACTIONS(1794), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(1796), 23,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [72517] = 4,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(1800), 5,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACE,
    ACTIONS(1804), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(1806), 23,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [72569] = 5,
    ACTIONS(5318), 1,
      sym__automatic_semicolon,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(1810), 4,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACE,
    ACTIONS(1814), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(1816), 23,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [72623] = 31,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_as,
    ACTIONS(4640), 1,
      anon_sym_BANG,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4649), 1,
      anon_sym_satisfies,
    ACTIONS(5161), 1,
      anon_sym_LT,
    ACTIONS(5167), 1,
      anon_sym_AMP_AMP,
    ACTIONS(5169), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(5171), 1,
      anon_sym_GT_GT,
    ACTIONS(5175), 1,
      anon_sym_AMP,
    ACTIONS(5177), 1,
      anon_sym_CARET,
    ACTIONS(5179), 1,
      anon_sym_PIPE,
    ACTIONS(5183), 1,
      anon_sym_PERCENT,
    ACTIONS(5185), 1,
      anon_sym_STAR_STAR,
    ACTIONS(5193), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(5195), 1,
      sym__ternary_qmark,
    STATE(1655), 1,
      sym_arguments,
    STATE(2605), 1,
      sym_type_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(5163), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(5165), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(5173), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(5181), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(5189), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(5191), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(5187), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
    ACTIONS(5320), 3,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_implements,
  [72729] = 4,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(1706), 5,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACE,
    ACTIONS(1710), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(1712), 23,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [72781] = 4,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(1758), 5,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACE,
    ACTIONS(1762), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(1764), 23,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [72833] = 5,
    ACTIONS(5322), 1,
      sym__automatic_semicolon,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(1770), 4,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACE,
    ACTIONS(1774), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(1776), 23,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [72887] = 5,
    ACTIONS(5324), 1,
      sym__automatic_semicolon,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(1780), 4,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACE,
    ACTIONS(1784), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(1786), 23,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [72941] = 33,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_as,
    ACTIONS(4640), 1,
      anon_sym_BANG,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4649), 1,
      anon_sym_satisfies,
    ACTIONS(4708), 1,
      anon_sym_LT,
    ACTIONS(4714), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4716), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4718), 1,
      anon_sym_GT_GT,
    ACTIONS(4722), 1,
      anon_sym_AMP,
    ACTIONS(4724), 1,
      anon_sym_CARET,
    ACTIONS(4726), 1,
      anon_sym_PIPE,
    ACTIONS(4730), 1,
      anon_sym_PERCENT,
    ACTIONS(4732), 1,
      anon_sym_STAR_STAR,
    ACTIONS(4740), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(4742), 1,
      sym__ternary_qmark,
    ACTIONS(5217), 1,
      anon_sym_COMMA,
    ACTIONS(5326), 1,
      anon_sym_RBRACE,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(3792), 1,
      aux_sym_sequence_expression_repeat1,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4710), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(4712), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(4720), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(4728), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4736), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4738), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(4734), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [73051] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4498), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4500), 28,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [73101] = 4,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(1820), 5,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACE,
    ACTIONS(1824), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(1826), 23,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [73153] = 4,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(1830), 5,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACE,
    ACTIONS(1834), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(1836), 23,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [73205] = 5,
    ACTIONS(5328), 1,
      sym__automatic_semicolon,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(1856), 4,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACE,
    ACTIONS(1860), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(1862), 23,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [73259] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4478), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4480), 28,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [73309] = 4,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(1866), 5,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACE,
    ACTIONS(1870), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(1872), 23,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [73361] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4502), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4504), 28,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [73411] = 10,
    ACTIONS(1550), 1,
      anon_sym_DQUOTE,
    ACTIONS(1552), 1,
      anon_sym_SQUOTE,
    ACTIONS(4688), 1,
      anon_sym_LBRACK,
    ACTIONS(5137), 1,
      anon_sym_STAR,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(5330), 2,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(5332), 2,
      anon_sym_get,
      anon_sym_set,
    STATE(3822), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(3814), 9,
      sym__automatic_semicolon,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_BANG,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_QMARK,
    ACTIONS(2351), 21,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [73475] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4540), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4542), 28,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [73525] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4544), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4546), 28,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [73575] = 5,
    ACTIONS(1818), 1,
      sym__automatic_semicolon,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(1810), 2,
      anon_sym_else,
      anon_sym_while,
    ACTIONS(1814), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(1816), 25,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [73629] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4548), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4550), 28,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [73679] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4552), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4554), 28,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [73729] = 7,
    ACTIONS(5334), 1,
      anon_sym_LPAREN,
    ACTIONS(5337), 1,
      anon_sym_COLON,
    ACTIONS(5339), 1,
      anon_sym_LT,
    ACTIONS(5342), 1,
      anon_sym_QMARK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3492), 12,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(3496), 25,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [73787] = 10,
    ACTIONS(1550), 1,
      anon_sym_DQUOTE,
    ACTIONS(1552), 1,
      anon_sym_SQUOTE,
    ACTIONS(4688), 1,
      anon_sym_LBRACK,
    ACTIONS(5344), 1,
      anon_sym_STAR,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(5346), 2,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(5348), 2,
      anon_sym_get,
      anon_sym_set,
    STATE(3845), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(3814), 9,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_QMARK,
      anon_sym_PIPE_RBRACE,
    ACTIONS(2351), 21,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [73851] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4556), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4558), 28,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [73901] = 11,
    ACTIONS(1626), 1,
      anon_sym_DQUOTE,
    ACTIONS(1628), 1,
      anon_sym_SQUOTE,
    ACTIONS(4624), 1,
      anon_sym_LBRACK,
    ACTIONS(5350), 1,
      anon_sym_STAR,
    ACTIONS(5352), 1,
      anon_sym_async,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(5354), 2,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(5356), 2,
      anon_sym_get,
      anon_sym_set,
    STATE(3152), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(3814), 9,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_QMARK,
      anon_sym_PIPE_RBRACE,
    ACTIONS(3700), 20,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [73967] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4560), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4562), 28,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [74017] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4564), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4566), 28,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [74067] = 33,
    ACTIONS(1977), 1,
      anon_sym_COMMA,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_as,
    ACTIONS(4640), 1,
      anon_sym_BANG,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4649), 1,
      anon_sym_satisfies,
    ACTIONS(4875), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4877), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4879), 1,
      anon_sym_GT_GT,
    ACTIONS(4883), 1,
      anon_sym_AMP,
    ACTIONS(4885), 1,
      anon_sym_CARET,
    ACTIONS(4887), 1,
      anon_sym_PIPE,
    ACTIONS(4891), 1,
      anon_sym_PERCENT,
    ACTIONS(4893), 1,
      anon_sym_STAR_STAR,
    ACTIONS(4895), 1,
      anon_sym_LT,
    ACTIONS(4903), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(4905), 1,
      sym__ternary_qmark,
    ACTIONS(5358), 1,
      anon_sym_RPAREN,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4698), 1,
      aux_sym_array_repeat1,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4867), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(4873), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(4881), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(4889), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4899), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4901), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(4897), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [74177] = 4,
    ACTIONS(5360), 1,
      sym_regex_flags,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4911), 16,
      anon_sym_STAR,
      anon_sym_as,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_instanceof,
      anon_sym_satisfies,
    ACTIONS(4913), 24,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
  [74229] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4568), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4570), 28,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [74279] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4462), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4464), 28,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [74329] = 33,
    ACTIONS(1977), 1,
      anon_sym_COMMA,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_as,
    ACTIONS(4640), 1,
      anon_sym_BANG,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4649), 1,
      anon_sym_satisfies,
    ACTIONS(4875), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4877), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4879), 1,
      anon_sym_GT_GT,
    ACTIONS(4883), 1,
      anon_sym_AMP,
    ACTIONS(4885), 1,
      anon_sym_CARET,
    ACTIONS(4887), 1,
      anon_sym_PIPE,
    ACTIONS(4891), 1,
      anon_sym_PERCENT,
    ACTIONS(4893), 1,
      anon_sym_STAR_STAR,
    ACTIONS(4895), 1,
      anon_sym_LT,
    ACTIONS(4903), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(4905), 1,
      sym__ternary_qmark,
    ACTIONS(5362), 1,
      anon_sym_RPAREN,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    STATE(5062), 1,
      aux_sym_array_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4867), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(4873), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(4881), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(4889), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4899), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4901), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(4897), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [74439] = 7,
    ACTIONS(4406), 1,
      anon_sym_QMARK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4408), 2,
      anon_sym_RPAREN,
      anon_sym_extends,
    ACTIONS(4611), 2,
      anon_sym_AMP,
      anon_sym_PIPE,
    ACTIONS(4608), 3,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
    ACTIONS(3492), 11,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(3496), 22,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [74497] = 15,
    ACTIONS(237), 1,
      anon_sym_COMMA,
    ACTIONS(1550), 1,
      anon_sym_DQUOTE,
    ACTIONS(1552), 1,
      anon_sym_SQUOTE,
    ACTIONS(4622), 1,
      anon_sym_EQ,
    ACTIONS(4688), 1,
      anon_sym_LBRACK,
    ACTIONS(4990), 1,
      anon_sym_STAR,
    ACTIONS(4992), 1,
      anon_sym_RBRACE,
    STATE(4792), 1,
      aux_sym_object_repeat1,
    STATE(4815), 1,
      aux_sym_object_pattern_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(2337), 2,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(2357), 2,
      anon_sym_get,
      anon_sym_set,
    STATE(3816), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(3814), 4,
      anon_sym_LPAREN,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_QMARK,
    ACTIONS(2351), 21,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [74571] = 10,
    ACTIONS(1550), 1,
      anon_sym_DQUOTE,
    ACTIONS(1552), 1,
      anon_sym_SQUOTE,
    ACTIONS(4688), 1,
      anon_sym_LBRACK,
    ACTIONS(5103), 1,
      anon_sym_STAR,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(5364), 2,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(5366), 2,
      anon_sym_get,
      anon_sym_set,
    STATE(3798), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(3814), 9,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_QMARK,
      anon_sym_PIPE_RBRACE,
    ACTIONS(2351), 21,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [74635] = 11,
    ACTIONS(1626), 1,
      anon_sym_DQUOTE,
    ACTIONS(1628), 1,
      anon_sym_SQUOTE,
    ACTIONS(4624), 1,
      anon_sym_LBRACK,
    ACTIONS(5103), 1,
      anon_sym_STAR,
    ACTIONS(5105), 1,
      anon_sym_async,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(5107), 2,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(5111), 2,
      anon_sym_get,
      anon_sym_set,
    STATE(3135), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(3814), 9,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_QMARK,
      anon_sym_PIPE_RBRACE,
    ACTIONS(3700), 20,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [74701] = 15,
    ACTIONS(237), 1,
      anon_sym_COMMA,
    ACTIONS(667), 1,
      anon_sym_RBRACE,
    ACTIONS(1550), 1,
      anon_sym_DQUOTE,
    ACTIONS(1552), 1,
      anon_sym_SQUOTE,
    ACTIONS(4622), 1,
      anon_sym_EQ,
    ACTIONS(4688), 1,
      anon_sym_LBRACK,
    ACTIONS(4990), 1,
      anon_sym_STAR,
    STATE(4792), 1,
      aux_sym_object_repeat1,
    STATE(4815), 1,
      aux_sym_object_pattern_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(2337), 2,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(2357), 2,
      anon_sym_get,
      anon_sym_set,
    STATE(3816), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(3814), 4,
      anon_sym_LPAREN,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_QMARK,
    ACTIONS(2351), 21,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [74775] = 16,
    ACTIONS(237), 1,
      anon_sym_COMMA,
    ACTIONS(1550), 1,
      anon_sym_DQUOTE,
    ACTIONS(1552), 1,
      anon_sym_SQUOTE,
    ACTIONS(2353), 1,
      anon_sym_async,
    ACTIONS(4622), 1,
      anon_sym_EQ,
    ACTIONS(4688), 1,
      anon_sym_LBRACK,
    ACTIONS(4990), 1,
      anon_sym_STAR,
    ACTIONS(4992), 1,
      anon_sym_RBRACE,
    STATE(4792), 1,
      aux_sym_object_repeat1,
    STATE(4815), 1,
      aux_sym_object_pattern_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(2337), 2,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(2357), 2,
      anon_sym_get,
      anon_sym_set,
    STATE(3816), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(3814), 4,
      anon_sym_LPAREN,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_QMARK,
    ACTIONS(2351), 20,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [74851] = 33,
    ACTIONS(1977), 1,
      anon_sym_COMMA,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_as,
    ACTIONS(4640), 1,
      anon_sym_BANG,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4649), 1,
      anon_sym_satisfies,
    ACTIONS(4875), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4877), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4879), 1,
      anon_sym_GT_GT,
    ACTIONS(4883), 1,
      anon_sym_AMP,
    ACTIONS(4885), 1,
      anon_sym_CARET,
    ACTIONS(4887), 1,
      anon_sym_PIPE,
    ACTIONS(4891), 1,
      anon_sym_PERCENT,
    ACTIONS(4893), 1,
      anon_sym_STAR_STAR,
    ACTIONS(4895), 1,
      anon_sym_LT,
    ACTIONS(4903), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(4905), 1,
      sym__ternary_qmark,
    ACTIONS(5368), 1,
      anon_sym_RPAREN,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4554), 1,
      aux_sym_array_repeat1,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4867), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(4873), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(4881), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(4889), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4899), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4901), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(4897), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [74961] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4506), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4508), 28,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [75011] = 4,
    ACTIONS(5360), 1,
      sym_regex_flags,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4911), 17,
      anon_sym_STAR,
      anon_sym_as,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_of,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_instanceof,
      anon_sym_satisfies,
    ACTIONS(4913), 23,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
  [75063] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3492), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(3496), 28,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [75113] = 16,
    ACTIONS(237), 1,
      anon_sym_COMMA,
    ACTIONS(667), 1,
      anon_sym_RBRACE,
    ACTIONS(1550), 1,
      anon_sym_DQUOTE,
    ACTIONS(1552), 1,
      anon_sym_SQUOTE,
    ACTIONS(2353), 1,
      anon_sym_async,
    ACTIONS(4622), 1,
      anon_sym_EQ,
    ACTIONS(4688), 1,
      anon_sym_LBRACK,
    ACTIONS(4990), 1,
      anon_sym_STAR,
    STATE(4792), 1,
      aux_sym_object_repeat1,
    STATE(4815), 1,
      aux_sym_object_pattern_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(2337), 2,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(2357), 2,
      anon_sym_get,
      anon_sym_set,
    STATE(3816), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(3814), 4,
      anon_sym_LPAREN,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_QMARK,
    ACTIONS(2351), 20,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [75189] = 31,
    ACTIONS(4588), 1,
      anon_sym_LPAREN,
    ACTIONS(4590), 1,
      anon_sym_LBRACK,
    ACTIONS(4592), 1,
      anon_sym_DOT,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4798), 1,
      anon_sym_as,
    ACTIONS(4800), 1,
      anon_sym_BANG,
    ACTIONS(4804), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4806), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4808), 1,
      anon_sym_GT_GT,
    ACTIONS(4812), 1,
      anon_sym_AMP,
    ACTIONS(4814), 1,
      anon_sym_CARET,
    ACTIONS(4816), 1,
      anon_sym_PIPE,
    ACTIONS(4820), 1,
      anon_sym_PERCENT,
    ACTIONS(4822), 1,
      anon_sym_STAR_STAR,
    ACTIONS(4824), 1,
      anon_sym_LT,
    ACTIONS(4832), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(4836), 1,
      anon_sym_satisfies,
    ACTIONS(4838), 1,
      sym__ternary_qmark,
    STATE(2019), 1,
      sym_type_arguments,
    STATE(2130), 1,
      sym_arguments,
    STATE(4524), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4796), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(4802), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(4810), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(4818), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4828), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4830), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(4834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4826), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
    ACTIONS(4852), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [75295] = 33,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_as,
    ACTIONS(4640), 1,
      anon_sym_BANG,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4649), 1,
      anon_sym_satisfies,
    ACTIONS(4708), 1,
      anon_sym_LT,
    ACTIONS(4714), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4716), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4718), 1,
      anon_sym_GT_GT,
    ACTIONS(4722), 1,
      anon_sym_AMP,
    ACTIONS(4724), 1,
      anon_sym_CARET,
    ACTIONS(4726), 1,
      anon_sym_PIPE,
    ACTIONS(4730), 1,
      anon_sym_PERCENT,
    ACTIONS(4732), 1,
      anon_sym_STAR_STAR,
    ACTIONS(4740), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(4742), 1,
      sym__ternary_qmark,
    ACTIONS(5217), 1,
      anon_sym_COMMA,
    ACTIONS(5370), 1,
      anon_sym_RBRACK,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(3792), 1,
      aux_sym_sequence_expression_repeat1,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4710), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(4712), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(4720), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(4728), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4736), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4738), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(4734), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [75405] = 6,
    ACTIONS(4608), 1,
      anon_sym_LBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4408), 2,
      anon_sym_COMMA,
      anon_sym_extends,
    ACTIONS(4611), 3,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_GT,
    ACTIONS(3492), 10,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(3496), 25,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_of,
      anon_sym_COLON,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [75461] = 33,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_as,
    ACTIONS(4640), 1,
      anon_sym_BANG,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4649), 1,
      anon_sym_satisfies,
    ACTIONS(4708), 1,
      anon_sym_LT,
    ACTIONS(4714), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4716), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4718), 1,
      anon_sym_GT_GT,
    ACTIONS(4722), 1,
      anon_sym_AMP,
    ACTIONS(4724), 1,
      anon_sym_CARET,
    ACTIONS(4726), 1,
      anon_sym_PIPE,
    ACTIONS(4730), 1,
      anon_sym_PERCENT,
    ACTIONS(4732), 1,
      anon_sym_STAR_STAR,
    ACTIONS(4740), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(4742), 1,
      sym__ternary_qmark,
    ACTIONS(5217), 1,
      anon_sym_COMMA,
    ACTIONS(5372), 1,
      anon_sym_SEMI,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(3792), 1,
      aux_sym_sequence_expression_repeat1,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4710), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(4712), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(4720), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(4728), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4736), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4738), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(4734), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [75571] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4288), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4290), 28,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [75621] = 7,
    ACTIONS(3516), 1,
      anon_sym_DOT,
    ACTIONS(3520), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3522), 2,
      anon_sym_AMP,
      anon_sym_PIPE,
    ACTIONS(3512), 4,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_LBRACK,
      anon_sym_extends,
    ACTIONS(3492), 11,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(3496), 22,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_COLON,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [75679] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4482), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4484), 28,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [75729] = 33,
    ACTIONS(1977), 1,
      anon_sym_COMMA,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_as,
    ACTIONS(4640), 1,
      anon_sym_BANG,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4649), 1,
      anon_sym_satisfies,
    ACTIONS(4875), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4877), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4879), 1,
      anon_sym_GT_GT,
    ACTIONS(4883), 1,
      anon_sym_AMP,
    ACTIONS(4885), 1,
      anon_sym_CARET,
    ACTIONS(4887), 1,
      anon_sym_PIPE,
    ACTIONS(4891), 1,
      anon_sym_PERCENT,
    ACTIONS(4893), 1,
      anon_sym_STAR_STAR,
    ACTIONS(4895), 1,
      anon_sym_LT,
    ACTIONS(4903), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(4905), 1,
      sym__ternary_qmark,
    ACTIONS(5374), 1,
      anon_sym_RPAREN,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4602), 1,
      aux_sym_array_repeat1,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4867), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(4873), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(4881), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(4889), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4899), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4901), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(4897), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [75839] = 5,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4184), 2,
      anon_sym_AMP,
      anon_sym_PIPE,
    ACTIONS(4182), 4,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_LBRACK,
      anon_sym_extends,
    ACTIONS(3492), 11,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(3496), 24,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [75893] = 7,
    ACTIONS(4376), 1,
      anon_sym_QMARK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4378), 2,
      anon_sym_RPAREN,
      anon_sym_extends,
    ACTIONS(4617), 2,
      anon_sym_AMP,
      anon_sym_PIPE,
    ACTIONS(4614), 3,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
    ACTIONS(4458), 11,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4460), 22,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [75951] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4486), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4488), 28,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [76001] = 10,
    ACTIONS(1550), 1,
      anon_sym_DQUOTE,
    ACTIONS(1552), 1,
      anon_sym_SQUOTE,
    ACTIONS(4688), 1,
      anon_sym_LBRACK,
    ACTIONS(5000), 1,
      anon_sym_STAR,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(5376), 2,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(5378), 2,
      anon_sym_get,
      anon_sym_set,
    STATE(3781), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(3814), 9,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_QMARK,
      anon_sym_PIPE_RBRACE,
    ACTIONS(2351), 21,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [76065] = 8,
    ACTIONS(3494), 1,
      anon_sym_EQ,
    ACTIONS(3586), 1,
      anon_sym_COLON,
    ACTIONS(4608), 1,
      anon_sym_LBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4611), 2,
      anon_sym_AMP,
      anon_sym_PIPE,
    ACTIONS(4408), 3,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_extends,
    ACTIONS(3492), 11,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(3496), 22,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [76125] = 33,
    ACTIONS(1977), 1,
      anon_sym_COMMA,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_as,
    ACTIONS(4640), 1,
      anon_sym_BANG,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4649), 1,
      anon_sym_satisfies,
    ACTIONS(4875), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4877), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4879), 1,
      anon_sym_GT_GT,
    ACTIONS(4883), 1,
      anon_sym_AMP,
    ACTIONS(4885), 1,
      anon_sym_CARET,
    ACTIONS(4887), 1,
      anon_sym_PIPE,
    ACTIONS(4891), 1,
      anon_sym_PERCENT,
    ACTIONS(4893), 1,
      anon_sym_STAR_STAR,
    ACTIONS(4895), 1,
      anon_sym_LT,
    ACTIONS(4903), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(4905), 1,
      sym__ternary_qmark,
    ACTIONS(5380), 1,
      anon_sym_RPAREN,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4644), 1,
      aux_sym_array_repeat1,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4867), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(4873), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(4881), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(4889), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4899), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4901), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(4897), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [76235] = 33,
    ACTIONS(1977), 1,
      anon_sym_COMMA,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_as,
    ACTIONS(4640), 1,
      anon_sym_BANG,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4649), 1,
      anon_sym_satisfies,
    ACTIONS(4875), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4877), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4879), 1,
      anon_sym_GT_GT,
    ACTIONS(4883), 1,
      anon_sym_AMP,
    ACTIONS(4885), 1,
      anon_sym_CARET,
    ACTIONS(4887), 1,
      anon_sym_PIPE,
    ACTIONS(4891), 1,
      anon_sym_PERCENT,
    ACTIONS(4893), 1,
      anon_sym_STAR_STAR,
    ACTIONS(4895), 1,
      anon_sym_LT,
    ACTIONS(4903), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(4905), 1,
      sym__ternary_qmark,
    ACTIONS(5382), 1,
      anon_sym_RPAREN,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4656), 1,
      aux_sym_array_repeat1,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4867), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(4873), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(4881), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(4889), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4899), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4901), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(4897), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [76345] = 12,
    ACTIONS(4588), 1,
      anon_sym_LPAREN,
    ACTIONS(4590), 1,
      anon_sym_LBRACK,
    ACTIONS(4592), 1,
      anon_sym_DOT,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(5384), 1,
      anon_sym_LT,
    STATE(2019), 1,
      sym_type_arguments,
    STATE(2130), 1,
      sym_arguments,
    STATE(4524), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4778), 12,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4780), 19,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_SEMI,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [76413] = 15,
    ACTIONS(4588), 1,
      anon_sym_LPAREN,
    ACTIONS(4590), 1,
      anon_sym_LBRACK,
    ACTIONS(4592), 1,
      anon_sym_DOT,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4798), 1,
      anon_sym_as,
    ACTIONS(4800), 1,
      anon_sym_BANG,
    ACTIONS(4836), 1,
      anon_sym_satisfies,
    ACTIONS(5387), 1,
      anon_sym_LT,
    STATE(2019), 1,
      sym_type_arguments,
    STATE(2130), 1,
      sym_arguments,
    STATE(4524), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4634), 11,
      anon_sym_STAR,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4638), 17,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_SEMI,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_BQUOTE,
  [76487] = 31,
    ACTIONS(4588), 1,
      anon_sym_LPAREN,
    ACTIONS(4590), 1,
      anon_sym_LBRACK,
    ACTIONS(4592), 1,
      anon_sym_DOT,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4798), 1,
      anon_sym_as,
    ACTIONS(4800), 1,
      anon_sym_BANG,
    ACTIONS(4836), 1,
      anon_sym_satisfies,
    ACTIONS(5233), 1,
      anon_sym_LT,
    ACTIONS(5239), 1,
      anon_sym_AMP_AMP,
    ACTIONS(5241), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(5243), 1,
      anon_sym_GT_GT,
    ACTIONS(5247), 1,
      anon_sym_AMP,
    ACTIONS(5249), 1,
      anon_sym_CARET,
    ACTIONS(5251), 1,
      anon_sym_PIPE,
    ACTIONS(5255), 1,
      anon_sym_PERCENT,
    ACTIONS(5257), 1,
      anon_sym_STAR_STAR,
    ACTIONS(5265), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(5267), 1,
      sym__ternary_qmark,
    STATE(2019), 1,
      sym_type_arguments,
    STATE(2130), 1,
      sym_arguments,
    STATE(4524), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(5235), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(5237), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(5245), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(5253), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(5261), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(5263), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(4792), 3,
      sym__automatic_semicolon,
      anon_sym_SEMI,
      anon_sym_BQUOTE,
    ACTIONS(5259), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [76593] = 11,
    ACTIONS(4588), 1,
      anon_sym_LPAREN,
    ACTIONS(4590), 1,
      anon_sym_LBRACK,
    ACTIONS(4592), 1,
      anon_sym_DOT,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(5390), 1,
      anon_sym_LT,
    STATE(2019), 1,
      sym_type_arguments,
    STATE(2130), 1,
      sym_arguments,
    STATE(4524), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4785), 12,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4787), 21,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_SEMI,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [76659] = 5,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(5119), 2,
      anon_sym_EQ,
      anon_sym_QMARK,
    ACTIONS(5121), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_COLON,
    ACTIONS(3492), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(3496), 23,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [76713] = 11,
    ACTIONS(1626), 1,
      anon_sym_DQUOTE,
    ACTIONS(1628), 1,
      anon_sym_SQUOTE,
    ACTIONS(4698), 1,
      anon_sym_LBRACK,
    ACTIONS(5000), 1,
      anon_sym_STAR,
    ACTIONS(5002), 1,
      anon_sym_async,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(5004), 2,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(5008), 2,
      anon_sym_get,
      anon_sym_set,
    STATE(3147), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(3814), 9,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_QMARK,
      anon_sym_PIPE_RBRACE,
    ACTIONS(3700), 20,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [76779] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4474), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4476), 28,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [76829] = 5,
    ACTIONS(1828), 1,
      sym__automatic_semicolon,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(1820), 2,
      anon_sym_else,
      anon_sym_while,
    ACTIONS(1824), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(1826), 25,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [76883] = 5,
    ACTIONS(1838), 1,
      sym__automatic_semicolon,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(1830), 2,
      anon_sym_else,
      anon_sym_while,
    ACTIONS(1834), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(1836), 25,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [76937] = 11,
    ACTIONS(1626), 1,
      anon_sym_DQUOTE,
    ACTIONS(1628), 1,
      anon_sym_SQUOTE,
    ACTIONS(4624), 1,
      anon_sym_LBRACK,
    ACTIONS(5393), 1,
      anon_sym_STAR,
    ACTIONS(5395), 1,
      anon_sym_async,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(5397), 2,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(5399), 2,
      anon_sym_get,
      anon_sym_set,
    STATE(3143), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(3814), 9,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_QMARK,
      anon_sym_PIPE_RBRACE,
    ACTIONS(3700), 20,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [77003] = 32,
    ACTIONS(4588), 1,
      anon_sym_LPAREN,
    ACTIONS(4590), 1,
      anon_sym_LBRACK,
    ACTIONS(4592), 1,
      anon_sym_DOT,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4744), 1,
      anon_sym_COMMA,
    ACTIONS(4798), 1,
      anon_sym_as,
    ACTIONS(4800), 1,
      anon_sym_BANG,
    ACTIONS(4804), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4806), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4808), 1,
      anon_sym_GT_GT,
    ACTIONS(4812), 1,
      anon_sym_AMP,
    ACTIONS(4814), 1,
      anon_sym_CARET,
    ACTIONS(4816), 1,
      anon_sym_PIPE,
    ACTIONS(4820), 1,
      anon_sym_PERCENT,
    ACTIONS(4822), 1,
      anon_sym_STAR_STAR,
    ACTIONS(4824), 1,
      anon_sym_LT,
    ACTIONS(4832), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(4836), 1,
      anon_sym_satisfies,
    ACTIONS(4838), 1,
      sym__ternary_qmark,
    STATE(2019), 1,
      sym_type_arguments,
    STATE(2130), 1,
      sym_arguments,
    STATE(4524), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4796), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(4802), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(4810), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(4818), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4828), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4830), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(4834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(5041), 2,
      sym__automatic_semicolon,
      anon_sym_SEMI,
    ACTIONS(4826), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [77111] = 33,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_as,
    ACTIONS(4640), 1,
      anon_sym_BANG,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4649), 1,
      anon_sym_satisfies,
    ACTIONS(4708), 1,
      anon_sym_LT,
    ACTIONS(4714), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4716), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4718), 1,
      anon_sym_GT_GT,
    ACTIONS(4722), 1,
      anon_sym_AMP,
    ACTIONS(4724), 1,
      anon_sym_CARET,
    ACTIONS(4726), 1,
      anon_sym_PIPE,
    ACTIONS(4730), 1,
      anon_sym_PERCENT,
    ACTIONS(4732), 1,
      anon_sym_STAR_STAR,
    ACTIONS(4740), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(4742), 1,
      sym__ternary_qmark,
    ACTIONS(5217), 1,
      anon_sym_COMMA,
    ACTIONS(5401), 1,
      anon_sym_RBRACK,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(3792), 1,
      aux_sym_sequence_expression_repeat1,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4710), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(4712), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(4720), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(4728), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4736), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4738), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(4734), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [77221] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4572), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4574), 28,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [77271] = 10,
    ACTIONS(1550), 1,
      anon_sym_DQUOTE,
    ACTIONS(1552), 1,
      anon_sym_SQUOTE,
    ACTIONS(4688), 1,
      anon_sym_LBRACK,
    ACTIONS(5403), 1,
      anon_sym_STAR,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(5405), 2,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(5407), 2,
      anon_sym_get,
      anon_sym_set,
    STATE(3888), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(3814), 9,
      sym__automatic_semicolon,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_BANG,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_QMARK,
    ACTIONS(2351), 21,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [77335] = 11,
    ACTIONS(1626), 1,
      anon_sym_DQUOTE,
    ACTIONS(1628), 1,
      anon_sym_SQUOTE,
    ACTIONS(4624), 1,
      anon_sym_LBRACK,
    ACTIONS(5271), 1,
      anon_sym_STAR,
    ACTIONS(5273), 1,
      anon_sym_async,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(5277), 2,
      anon_sym_get,
      anon_sym_set,
    ACTIONS(5409), 2,
      sym_number,
      sym_private_property_identifier,
    STATE(3060), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(3814), 9,
      sym__automatic_semicolon,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_BANG,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_QMARK,
    ACTIONS(3700), 20,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [77401] = 5,
    ACTIONS(1850), 1,
      sym__automatic_semicolon,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(1842), 2,
      anon_sym_else,
      anon_sym_while,
    ACTIONS(1846), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(1848), 25,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [77455] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4516), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4518), 28,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [77505] = 7,
    ACTIONS(3582), 1,
      anon_sym_EQ,
    ACTIONS(4608), 1,
      anon_sym_LBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4408), 2,
      anon_sym_COMMA,
      anon_sym_extends,
    ACTIONS(4611), 3,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_GT,
    ACTIONS(3492), 10,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(3496), 24,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [77563] = 10,
    ACTIONS(1550), 1,
      anon_sym_DQUOTE,
    ACTIONS(1552), 1,
      anon_sym_SQUOTE,
    ACTIONS(4688), 1,
      anon_sym_LBRACK,
    ACTIONS(5310), 1,
      anon_sym_STAR,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(5411), 2,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(5413), 2,
      anon_sym_get,
      anon_sym_set,
    STATE(3874), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(3814), 9,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_QMARK,
      anon_sym_PIPE_RBRACE,
    ACTIONS(2351), 21,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [77627] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4576), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4578), 28,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [77677] = 5,
    ACTIONS(1864), 1,
      sym__automatic_semicolon,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(1856), 2,
      anon_sym_else,
      anon_sym_while,
    ACTIONS(1860), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(1862), 25,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [77731] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4580), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4582), 28,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [77781] = 5,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(5415), 2,
      anon_sym_EQ,
      anon_sym_QMARK,
    ACTIONS(5417), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_COLON,
    ACTIONS(3492), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(3496), 23,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [77835] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4520), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4522), 28,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [77885] = 10,
    ACTIONS(1550), 1,
      anon_sym_DQUOTE,
    ACTIONS(1552), 1,
      anon_sym_SQUOTE,
    ACTIONS(4688), 1,
      anon_sym_LBRACK,
    ACTIONS(5151), 1,
      anon_sym_STAR,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(5419), 2,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(5421), 2,
      anon_sym_get,
      anon_sym_set,
    STATE(3882), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(3814), 9,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_QMARK,
      anon_sym_PIPE_RBRACE,
    ACTIONS(2351), 21,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [77949] = 9,
    ACTIONS(3510), 1,
      anon_sym_EQ,
    ACTIONS(3586), 1,
      anon_sym_COLON,
    ACTIONS(4408), 1,
      anon_sym_extends,
    ACTIONS(4608), 1,
      anon_sym_LBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4611), 2,
      anon_sym_AMP,
      anon_sym_PIPE,
    ACTIONS(5423), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK,
    ACTIONS(3492), 11,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(3496), 22,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [78011] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(1860), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(1862), 28,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [78061] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4454), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4456), 28,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [78111] = 4,
    ACTIONS(3562), 1,
      anon_sym_EQ,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3492), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(3496), 27,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [78163] = 10,
    ACTIONS(1550), 1,
      anon_sym_DQUOTE,
    ACTIONS(1552), 1,
      anon_sym_SQUOTE,
    ACTIONS(4656), 1,
      anon_sym_STAR,
    ACTIONS(4688), 1,
      anon_sym_LBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(5427), 2,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(5429), 2,
      anon_sym_get,
      anon_sym_set,
    STATE(3804), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(3814), 9,
      sym__automatic_semicolon,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_BANG,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_QMARK,
    ACTIONS(2351), 21,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [78227] = 33,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_as,
    ACTIONS(4640), 1,
      anon_sym_BANG,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4649), 1,
      anon_sym_satisfies,
    ACTIONS(4869), 1,
      anon_sym_COMMA,
    ACTIONS(4875), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4877), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4879), 1,
      anon_sym_GT_GT,
    ACTIONS(4883), 1,
      anon_sym_AMP,
    ACTIONS(4885), 1,
      anon_sym_CARET,
    ACTIONS(4887), 1,
      anon_sym_PIPE,
    ACTIONS(4891), 1,
      anon_sym_PERCENT,
    ACTIONS(4893), 1,
      anon_sym_STAR_STAR,
    ACTIONS(4895), 1,
      anon_sym_LT,
    ACTIONS(4903), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(4905), 1,
      sym__ternary_qmark,
    ACTIONS(5431), 1,
      anon_sym_RPAREN,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    STATE(5026), 1,
      aux_sym_sequence_expression_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4867), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(4873), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(4881), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(4889), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4899), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4901), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(4897), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [78337] = 10,
    ACTIONS(1550), 1,
      anon_sym_DQUOTE,
    ACTIONS(1552), 1,
      anon_sym_SQUOTE,
    ACTIONS(4688), 1,
      anon_sym_LBRACK,
    ACTIONS(5393), 1,
      anon_sym_STAR,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(5433), 2,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(5435), 2,
      anon_sym_get,
      anon_sym_set,
    STATE(3836), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(3814), 9,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_QMARK,
      anon_sym_PIPE_RBRACE,
    ACTIONS(2351), 21,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [78401] = 6,
    ACTIONS(4614), 1,
      anon_sym_LBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4378), 2,
      anon_sym_COMMA,
      anon_sym_extends,
    ACTIONS(4617), 3,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_GT,
    ACTIONS(4458), 10,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4460), 25,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_of,
      anon_sym_COLON,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [78457] = 33,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_as,
    ACTIONS(4640), 1,
      anon_sym_BANG,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4649), 1,
      anon_sym_satisfies,
    ACTIONS(4869), 1,
      anon_sym_COMMA,
    ACTIONS(4875), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4877), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4879), 1,
      anon_sym_GT_GT,
    ACTIONS(4883), 1,
      anon_sym_AMP,
    ACTIONS(4885), 1,
      anon_sym_CARET,
    ACTIONS(4887), 1,
      anon_sym_PIPE,
    ACTIONS(4891), 1,
      anon_sym_PERCENT,
    ACTIONS(4893), 1,
      anon_sym_STAR_STAR,
    ACTIONS(4895), 1,
      anon_sym_LT,
    ACTIONS(4903), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(4905), 1,
      sym__ternary_qmark,
    ACTIONS(5437), 1,
      anon_sym_RPAREN,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    STATE(5026), 1,
      aux_sym_sequence_expression_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4867), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(4873), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(4881), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(4889), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4899), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4901), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(4897), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [78567] = 33,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_as,
    ACTIONS(4640), 1,
      anon_sym_BANG,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4649), 1,
      anon_sym_satisfies,
    ACTIONS(4869), 1,
      anon_sym_COMMA,
    ACTIONS(4875), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4877), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4879), 1,
      anon_sym_GT_GT,
    ACTIONS(4883), 1,
      anon_sym_AMP,
    ACTIONS(4885), 1,
      anon_sym_CARET,
    ACTIONS(4887), 1,
      anon_sym_PIPE,
    ACTIONS(4891), 1,
      anon_sym_PERCENT,
    ACTIONS(4893), 1,
      anon_sym_STAR_STAR,
    ACTIONS(4895), 1,
      anon_sym_LT,
    ACTIONS(4903), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(4905), 1,
      sym__ternary_qmark,
    ACTIONS(5439), 1,
      anon_sym_RPAREN,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    STATE(5026), 1,
      aux_sym_sequence_expression_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4867), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(4873), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(4881), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(4889), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4899), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4901), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(4897), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [78677] = 10,
    ACTIONS(1550), 1,
      anon_sym_DQUOTE,
    ACTIONS(1552), 1,
      anon_sym_SQUOTE,
    ACTIONS(4688), 1,
      anon_sym_LBRACK,
    ACTIONS(5350), 1,
      anon_sym_STAR,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(5441), 2,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(5443), 2,
      anon_sym_get,
      anon_sym_set,
    STATE(3753), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(3814), 9,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_QMARK,
      anon_sym_PIPE_RBRACE,
    ACTIONS(2351), 21,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [78741] = 33,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_as,
    ACTIONS(4640), 1,
      anon_sym_BANG,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4649), 1,
      anon_sym_satisfies,
    ACTIONS(4869), 1,
      anon_sym_COMMA,
    ACTIONS(4875), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4877), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4879), 1,
      anon_sym_GT_GT,
    ACTIONS(4883), 1,
      anon_sym_AMP,
    ACTIONS(4885), 1,
      anon_sym_CARET,
    ACTIONS(4887), 1,
      anon_sym_PIPE,
    ACTIONS(4891), 1,
      anon_sym_PERCENT,
    ACTIONS(4893), 1,
      anon_sym_STAR_STAR,
    ACTIONS(4895), 1,
      anon_sym_LT,
    ACTIONS(4903), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(4905), 1,
      sym__ternary_qmark,
    ACTIONS(5445), 1,
      anon_sym_RPAREN,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    STATE(5026), 1,
      aux_sym_sequence_expression_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4867), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(4873), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(4881), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(4889), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4899), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4901), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(4897), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [78851] = 10,
    ACTIONS(1550), 1,
      anon_sym_DQUOTE,
    ACTIONS(1552), 1,
      anon_sym_SQUOTE,
    ACTIONS(4688), 1,
      anon_sym_LBRACK,
    ACTIONS(5447), 1,
      anon_sym_STAR,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(5449), 2,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(5451), 2,
      anon_sym_get,
      anon_sym_set,
    STATE(3828), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(3814), 9,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_QMARK,
      anon_sym_PIPE_RBRACE,
    ACTIONS(2351), 21,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [78915] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4524), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4526), 28,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [78965] = 7,
    ACTIONS(3601), 1,
      anon_sym_EQ,
    ACTIONS(4408), 1,
      anon_sym_extends,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4608), 2,
      anon_sym_COMMA,
      anon_sym_LBRACK,
    ACTIONS(4611), 3,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_GT,
    ACTIONS(3492), 10,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(3496), 24,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [79023] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(1870), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(1872), 28,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [79073] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4466), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4468), 28,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [79123] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(1794), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(1796), 28,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [79173] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(1804), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(1806), 28,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [79223] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(1814), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(1816), 28,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [79273] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(1710), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(1712), 28,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [79323] = 33,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_as,
    ACTIONS(4640), 1,
      anon_sym_BANG,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4649), 1,
      anon_sym_satisfies,
    ACTIONS(4869), 1,
      anon_sym_COMMA,
    ACTIONS(4875), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4877), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4879), 1,
      anon_sym_GT_GT,
    ACTIONS(4883), 1,
      anon_sym_AMP,
    ACTIONS(4885), 1,
      anon_sym_CARET,
    ACTIONS(4887), 1,
      anon_sym_PIPE,
    ACTIONS(4891), 1,
      anon_sym_PERCENT,
    ACTIONS(4893), 1,
      anon_sym_STAR_STAR,
    ACTIONS(4895), 1,
      anon_sym_LT,
    ACTIONS(4903), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(4905), 1,
      sym__ternary_qmark,
    ACTIONS(5453), 1,
      anon_sym_RPAREN,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    STATE(5026), 1,
      aux_sym_sequence_expression_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4867), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(4873), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(4881), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(4889), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4899), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4901), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(4897), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [79433] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4528), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4530), 28,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [79483] = 33,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_as,
    ACTIONS(4640), 1,
      anon_sym_BANG,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4649), 1,
      anon_sym_satisfies,
    ACTIONS(4708), 1,
      anon_sym_LT,
    ACTIONS(4714), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4716), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4718), 1,
      anon_sym_GT_GT,
    ACTIONS(4722), 1,
      anon_sym_AMP,
    ACTIONS(4724), 1,
      anon_sym_CARET,
    ACTIONS(4726), 1,
      anon_sym_PIPE,
    ACTIONS(4730), 1,
      anon_sym_PERCENT,
    ACTIONS(4732), 1,
      anon_sym_STAR_STAR,
    ACTIONS(4740), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(4742), 1,
      sym__ternary_qmark,
    ACTIONS(5217), 1,
      anon_sym_COMMA,
    ACTIONS(5455), 1,
      anon_sym_COLON,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(3792), 1,
      aux_sym_sequence_expression_repeat1,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4710), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(4712), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(4720), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(4728), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4736), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4738), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(4734), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [79593] = 33,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_as,
    ACTIONS(4640), 1,
      anon_sym_BANG,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4649), 1,
      anon_sym_satisfies,
    ACTIONS(4869), 1,
      anon_sym_COMMA,
    ACTIONS(4875), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4877), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4879), 1,
      anon_sym_GT_GT,
    ACTIONS(4883), 1,
      anon_sym_AMP,
    ACTIONS(4885), 1,
      anon_sym_CARET,
    ACTIONS(4887), 1,
      anon_sym_PIPE,
    ACTIONS(4891), 1,
      anon_sym_PERCENT,
    ACTIONS(4893), 1,
      anon_sym_STAR_STAR,
    ACTIONS(4895), 1,
      anon_sym_LT,
    ACTIONS(4903), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(4905), 1,
      sym__ternary_qmark,
    ACTIONS(5457), 1,
      anon_sym_RPAREN,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    STATE(5026), 1,
      aux_sym_sequence_expression_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4867), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(4873), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(4881), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(4889), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4899), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4901), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(4897), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [79703] = 33,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_as,
    ACTIONS(4640), 1,
      anon_sym_BANG,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4649), 1,
      anon_sym_satisfies,
    ACTIONS(4869), 1,
      anon_sym_COMMA,
    ACTIONS(4875), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4877), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4879), 1,
      anon_sym_GT_GT,
    ACTIONS(4883), 1,
      anon_sym_AMP,
    ACTIONS(4885), 1,
      anon_sym_CARET,
    ACTIONS(4887), 1,
      anon_sym_PIPE,
    ACTIONS(4891), 1,
      anon_sym_PERCENT,
    ACTIONS(4893), 1,
      anon_sym_STAR_STAR,
    ACTIONS(4895), 1,
      anon_sym_LT,
    ACTIONS(4903), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(4905), 1,
      sym__ternary_qmark,
    ACTIONS(5459), 1,
      anon_sym_RPAREN,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    STATE(5026), 1,
      aux_sym_sequence_expression_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4867), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(4873), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(4881), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(4889), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4899), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4901), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(4897), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [79813] = 33,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_as,
    ACTIONS(4640), 1,
      anon_sym_BANG,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4649), 1,
      anon_sym_satisfies,
    ACTIONS(4869), 1,
      anon_sym_COMMA,
    ACTIONS(4875), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4877), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4879), 1,
      anon_sym_GT_GT,
    ACTIONS(4883), 1,
      anon_sym_AMP,
    ACTIONS(4885), 1,
      anon_sym_CARET,
    ACTIONS(4887), 1,
      anon_sym_PIPE,
    ACTIONS(4891), 1,
      anon_sym_PERCENT,
    ACTIONS(4893), 1,
      anon_sym_STAR_STAR,
    ACTIONS(4895), 1,
      anon_sym_LT,
    ACTIONS(4903), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(4905), 1,
      sym__ternary_qmark,
    ACTIONS(5461), 1,
      anon_sym_RPAREN,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    STATE(5026), 1,
      aux_sym_sequence_expression_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4867), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(4873), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(4881), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(4889), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4899), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4901), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(4897), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [79923] = 33,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_as,
    ACTIONS(4640), 1,
      anon_sym_BANG,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4649), 1,
      anon_sym_satisfies,
    ACTIONS(4869), 1,
      anon_sym_COMMA,
    ACTIONS(4875), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4877), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4879), 1,
      anon_sym_GT_GT,
    ACTIONS(4883), 1,
      anon_sym_AMP,
    ACTIONS(4885), 1,
      anon_sym_CARET,
    ACTIONS(4887), 1,
      anon_sym_PIPE,
    ACTIONS(4891), 1,
      anon_sym_PERCENT,
    ACTIONS(4893), 1,
      anon_sym_STAR_STAR,
    ACTIONS(4895), 1,
      anon_sym_LT,
    ACTIONS(4903), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(4905), 1,
      sym__ternary_qmark,
    ACTIONS(5463), 1,
      anon_sym_RPAREN,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    STATE(5026), 1,
      aux_sym_sequence_expression_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4867), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(4873), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(4881), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(4889), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4899), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4901), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(4897), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [80033] = 33,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_as,
    ACTIONS(4640), 1,
      anon_sym_BANG,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4649), 1,
      anon_sym_satisfies,
    ACTIONS(4708), 1,
      anon_sym_LT,
    ACTIONS(4714), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4716), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4718), 1,
      anon_sym_GT_GT,
    ACTIONS(4722), 1,
      anon_sym_AMP,
    ACTIONS(4724), 1,
      anon_sym_CARET,
    ACTIONS(4726), 1,
      anon_sym_PIPE,
    ACTIONS(4730), 1,
      anon_sym_PERCENT,
    ACTIONS(4732), 1,
      anon_sym_STAR_STAR,
    ACTIONS(4740), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(4742), 1,
      sym__ternary_qmark,
    ACTIONS(5217), 1,
      anon_sym_COMMA,
    ACTIONS(5465), 1,
      anon_sym_SEMI,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(3792), 1,
      aux_sym_sequence_expression_repeat1,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4710), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(4712), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(4720), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(4728), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4736), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4738), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(4734), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [80143] = 5,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(5467), 2,
      anon_sym_EQ,
      anon_sym_QMARK,
    ACTIONS(5469), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_COLON,
    ACTIONS(3492), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(3496), 23,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [80197] = 5,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(5471), 2,
      anon_sym_EQ,
      anon_sym_QMARK,
    ACTIONS(5473), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_COLON,
    ACTIONS(3492), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(3496), 23,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [80251] = 5,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(5471), 2,
      anon_sym_EQ,
      anon_sym_QMARK,
    ACTIONS(5473), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_COLON,
    ACTIONS(3492), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(3496), 23,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [80305] = 5,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(5471), 2,
      anon_sym_EQ,
      anon_sym_QMARK,
    ACTIONS(5473), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_COLON,
    ACTIONS(3492), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(3496), 23,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [80359] = 10,
    ACTIONS(1550), 1,
      anon_sym_DQUOTE,
    ACTIONS(1552), 1,
      anon_sym_SQUOTE,
    ACTIONS(4688), 1,
      anon_sym_LBRACK,
    ACTIONS(5475), 1,
      anon_sym_STAR,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(5477), 2,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(5479), 2,
      anon_sym_get,
      anon_sym_set,
    STATE(3898), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(3814), 9,
      sym__automatic_semicolon,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_BANG,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_QMARK,
    ACTIONS(2351), 21,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [80423] = 11,
    ACTIONS(1626), 1,
      anon_sym_DQUOTE,
    ACTIONS(1628), 1,
      anon_sym_SQUOTE,
    ACTIONS(4624), 1,
      anon_sym_LBRACK,
    ACTIONS(5475), 1,
      anon_sym_STAR,
    ACTIONS(5481), 1,
      anon_sym_async,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(5483), 2,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(5485), 2,
      anon_sym_get,
      anon_sym_set,
    STATE(3074), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(3814), 9,
      sym__automatic_semicolon,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_BANG,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_QMARK,
    ACTIONS(3700), 20,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [80489] = 7,
    ACTIONS(3592), 1,
      anon_sym_EQ,
    ACTIONS(4408), 1,
      anon_sym_extends,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4608), 2,
      anon_sym_COMMA,
      anon_sym_LBRACK,
    ACTIONS(4611), 3,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_GT,
    ACTIONS(3492), 10,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(3496), 24,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_implements,
  [80547] = 11,
    ACTIONS(1626), 1,
      anon_sym_DQUOTE,
    ACTIONS(1628), 1,
      anon_sym_SQUOTE,
    ACTIONS(4624), 1,
      anon_sym_LBRACK,
    ACTIONS(5137), 1,
      anon_sym_STAR,
    ACTIONS(5139), 1,
      anon_sym_async,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(5145), 2,
      anon_sym_get,
      anon_sym_set,
    ACTIONS(5487), 2,
      sym_number,
      sym_private_property_identifier,
    STATE(3079), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(3814), 9,
      sym__automatic_semicolon,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_BANG,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_QMARK,
    ACTIONS(3700), 20,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [80613] = 33,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_as,
    ACTIONS(4640), 1,
      anon_sym_BANG,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4649), 1,
      anon_sym_satisfies,
    ACTIONS(4708), 1,
      anon_sym_LT,
    ACTIONS(4714), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4716), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4718), 1,
      anon_sym_GT_GT,
    ACTIONS(4722), 1,
      anon_sym_AMP,
    ACTIONS(4724), 1,
      anon_sym_CARET,
    ACTIONS(4726), 1,
      anon_sym_PIPE,
    ACTIONS(4730), 1,
      anon_sym_PERCENT,
    ACTIONS(4732), 1,
      anon_sym_STAR_STAR,
    ACTIONS(4740), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(4742), 1,
      sym__ternary_qmark,
    ACTIONS(5225), 1,
      anon_sym_COMMA,
    ACTIONS(5489), 1,
      anon_sym_RBRACK,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    STATE(4987), 1,
      aux_sym_array_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4710), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(4712), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(4720), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(4728), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4736), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4738), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(4734), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [80723] = 7,
    ACTIONS(5491), 1,
      anon_sym_LPAREN,
    ACTIONS(5494), 1,
      anon_sym_COLON,
    ACTIONS(5496), 1,
      anon_sym_LT,
    ACTIONS(5499), 1,
      anon_sym_QMARK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4478), 12,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4480), 25,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [80781] = 11,
    ACTIONS(1626), 1,
      anon_sym_DQUOTE,
    ACTIONS(1628), 1,
      anon_sym_SQUOTE,
    ACTIONS(4624), 1,
      anon_sym_LBRACK,
    ACTIONS(5137), 1,
      anon_sym_STAR,
    ACTIONS(5139), 1,
      anon_sym_async,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(5145), 2,
      anon_sym_get,
      anon_sym_set,
    ACTIONS(5501), 2,
      sym_number,
      sym_private_property_identifier,
    STATE(3072), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(3814), 9,
      sym__automatic_semicolon,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_BANG,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_QMARK,
    ACTIONS(3700), 20,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [80847] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4584), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4586), 28,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [80897] = 33,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_as,
    ACTIONS(4640), 1,
      anon_sym_BANG,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4649), 1,
      anon_sym_satisfies,
    ACTIONS(4708), 1,
      anon_sym_LT,
    ACTIONS(4714), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4716), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4718), 1,
      anon_sym_GT_GT,
    ACTIONS(4722), 1,
      anon_sym_AMP,
    ACTIONS(4724), 1,
      anon_sym_CARET,
    ACTIONS(4726), 1,
      anon_sym_PIPE,
    ACTIONS(4730), 1,
      anon_sym_PERCENT,
    ACTIONS(4732), 1,
      anon_sym_STAR_STAR,
    ACTIONS(4740), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(4742), 1,
      sym__ternary_qmark,
    ACTIONS(5225), 1,
      anon_sym_COMMA,
    ACTIONS(5503), 1,
      anon_sym_RBRACK,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    STATE(4987), 1,
      aux_sym_array_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4710), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(4712), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(4720), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(4728), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4736), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4738), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(4734), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [81007] = 10,
    ACTIONS(1550), 1,
      anon_sym_DQUOTE,
    ACTIONS(1552), 1,
      anon_sym_SQUOTE,
    ACTIONS(4688), 1,
      anon_sym_LBRACK,
    ACTIONS(5505), 1,
      anon_sym_STAR,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(5507), 2,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(5509), 2,
      anon_sym_get,
      anon_sym_set,
    STATE(3802), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(3814), 9,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_QMARK,
      anon_sym_PIPE_RBRACE,
    ACTIONS(2351), 21,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [81071] = 11,
    ACTIONS(1626), 1,
      anon_sym_DQUOTE,
    ACTIONS(1628), 1,
      anon_sym_SQUOTE,
    ACTIONS(4624), 1,
      anon_sym_LBRACK,
    ACTIONS(5505), 1,
      anon_sym_STAR,
    ACTIONS(5511), 1,
      anon_sym_async,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(5513), 2,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(5515), 2,
      anon_sym_get,
      anon_sym_set,
    STATE(3098), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(3814), 9,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_QMARK,
      anon_sym_PIPE_RBRACE,
    ACTIONS(3700), 20,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [81137] = 33,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_as,
    ACTIONS(4640), 1,
      anon_sym_BANG,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4649), 1,
      anon_sym_satisfies,
    ACTIONS(4869), 1,
      anon_sym_COMMA,
    ACTIONS(4875), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4877), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4879), 1,
      anon_sym_GT_GT,
    ACTIONS(4883), 1,
      anon_sym_AMP,
    ACTIONS(4885), 1,
      anon_sym_CARET,
    ACTIONS(4887), 1,
      anon_sym_PIPE,
    ACTIONS(4891), 1,
      anon_sym_PERCENT,
    ACTIONS(4893), 1,
      anon_sym_STAR_STAR,
    ACTIONS(4895), 1,
      anon_sym_LT,
    ACTIONS(4903), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(4905), 1,
      sym__ternary_qmark,
    ACTIONS(5517), 1,
      anon_sym_RPAREN,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    STATE(5026), 1,
      aux_sym_sequence_expression_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4867), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(4873), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(4881), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(4889), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4899), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4901), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(4897), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [81247] = 5,
    ACTIONS(1874), 1,
      sym__automatic_semicolon,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(1866), 2,
      anon_sym_else,
      anon_sym_while,
    ACTIONS(1870), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(1872), 25,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [81301] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4532), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4534), 28,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [81351] = 33,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_as,
    ACTIONS(4640), 1,
      anon_sym_BANG,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4649), 1,
      anon_sym_satisfies,
    ACTIONS(4708), 1,
      anon_sym_LT,
    ACTIONS(4714), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4716), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4718), 1,
      anon_sym_GT_GT,
    ACTIONS(4722), 1,
      anon_sym_AMP,
    ACTIONS(4724), 1,
      anon_sym_CARET,
    ACTIONS(4726), 1,
      anon_sym_PIPE,
    ACTIONS(4730), 1,
      anon_sym_PERCENT,
    ACTIONS(4732), 1,
      anon_sym_STAR_STAR,
    ACTIONS(4740), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(4742), 1,
      sym__ternary_qmark,
    ACTIONS(5217), 1,
      anon_sym_COMMA,
    ACTIONS(5519), 1,
      anon_sym_SEMI,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(3792), 1,
      aux_sym_sequence_expression_repeat1,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4710), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(4712), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(4720), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(4728), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4736), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4738), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(4734), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [81461] = 31,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_as,
    ACTIONS(4640), 1,
      anon_sym_BANG,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4649), 1,
      anon_sym_satisfies,
    ACTIONS(4708), 1,
      anon_sym_LT,
    ACTIONS(4714), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4716), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4718), 1,
      anon_sym_GT_GT,
    ACTIONS(4722), 1,
      anon_sym_AMP,
    ACTIONS(4724), 1,
      anon_sym_CARET,
    ACTIONS(4726), 1,
      anon_sym_PIPE,
    ACTIONS(4730), 1,
      anon_sym_PERCENT,
    ACTIONS(4732), 1,
      anon_sym_STAR_STAR,
    ACTIONS(4740), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(4742), 1,
      sym__ternary_qmark,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4710), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(4712), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(4720), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(4728), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4736), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4738), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(4734), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
    ACTIONS(5521), 3,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_RBRACK,
  [81567] = 11,
    ACTIONS(1626), 1,
      anon_sym_DQUOTE,
    ACTIONS(1628), 1,
      anon_sym_SQUOTE,
    ACTIONS(4624), 1,
      anon_sym_LBRACK,
    ACTIONS(5151), 1,
      anon_sym_STAR,
    ACTIONS(5153), 1,
      anon_sym_async,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(5155), 2,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(5159), 2,
      anon_sym_get,
      anon_sym_set,
    STATE(3097), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(3814), 9,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_QMARK,
      anon_sym_PIPE_RBRACE,
    ACTIONS(3700), 20,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [81633] = 5,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(5092), 2,
      anon_sym_EQ,
      anon_sym_QMARK,
    ACTIONS(5094), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_COLON,
    ACTIONS(3492), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(3496), 23,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [81687] = 12,
    ACTIONS(162), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1550), 1,
      anon_sym_DQUOTE,
    ACTIONS(1552), 1,
      anon_sym_SQUOTE,
    ACTIONS(3275), 1,
      anon_sym_LBRACE,
    ACTIONS(3942), 1,
      anon_sym_LBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(5064), 2,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(5525), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
    STATE(5225), 3,
      sym_object_assignment_pattern,
      sym_rest_pattern,
      sym_pair_pattern,
    STATE(5509), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    STATE(5536), 3,
      sym_object_pattern,
      sym_array_pattern,
      sym__destructuring_pattern,
    ACTIONS(5523), 23,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [81755] = 6,
    ACTIONS(3611), 1,
      anon_sym_EQ,
    ACTIONS(3617), 1,
      anon_sym_QMARK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3614), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_COLON,
    ACTIONS(3492), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(3496), 23,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [81811] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4470), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4472), 28,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [81861] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4490), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4492), 28,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [81911] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4598), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4600), 28,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [81961] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(1846), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(1848), 28,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [82011] = 15,
    ACTIONS(237), 1,
      anon_sym_COMMA,
    ACTIONS(692), 1,
      anon_sym_RBRACE,
    ACTIONS(1550), 1,
      anon_sym_DQUOTE,
    ACTIONS(1552), 1,
      anon_sym_SQUOTE,
    ACTIONS(4622), 1,
      anon_sym_EQ,
    ACTIONS(4688), 1,
      anon_sym_LBRACK,
    ACTIONS(4990), 1,
      anon_sym_STAR,
    STATE(4810), 1,
      aux_sym_object_repeat1,
    STATE(4815), 1,
      aux_sym_object_pattern_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(2337), 2,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(2357), 2,
      anon_sym_get,
      anon_sym_set,
    STATE(3816), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(3814), 4,
      anon_sym_LPAREN,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_QMARK,
    ACTIONS(2351), 21,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [82085] = 16,
    ACTIONS(237), 1,
      anon_sym_COMMA,
    ACTIONS(692), 1,
      anon_sym_RBRACE,
    ACTIONS(1550), 1,
      anon_sym_DQUOTE,
    ACTIONS(1552), 1,
      anon_sym_SQUOTE,
    ACTIONS(2353), 1,
      anon_sym_async,
    ACTIONS(4622), 1,
      anon_sym_EQ,
    ACTIONS(4688), 1,
      anon_sym_LBRACK,
    ACTIONS(4990), 1,
      anon_sym_STAR,
    STATE(4810), 1,
      aux_sym_object_repeat1,
    STATE(4815), 1,
      aux_sym_object_pattern_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(2337), 2,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(2357), 2,
      anon_sym_get,
      anon_sym_set,
    STATE(3816), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(3814), 4,
      anon_sym_LPAREN,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_QMARK,
    ACTIONS(2351), 20,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [82161] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(1762), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(1764), 28,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [82211] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(1774), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(1776), 28,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [82261] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(1784), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(1786), 28,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [82311] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(1824), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(1826), 28,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [82361] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(1834), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(1836), 28,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [82411] = 33,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_as,
    ACTIONS(4640), 1,
      anon_sym_BANG,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4649), 1,
      anon_sym_satisfies,
    ACTIONS(4869), 1,
      anon_sym_COMMA,
    ACTIONS(4875), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4877), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4879), 1,
      anon_sym_GT_GT,
    ACTIONS(4883), 1,
      anon_sym_AMP,
    ACTIONS(4885), 1,
      anon_sym_CARET,
    ACTIONS(4887), 1,
      anon_sym_PIPE,
    ACTIONS(4891), 1,
      anon_sym_PERCENT,
    ACTIONS(4893), 1,
      anon_sym_STAR_STAR,
    ACTIONS(4895), 1,
      anon_sym_LT,
    ACTIONS(4903), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(4905), 1,
      sym__ternary_qmark,
    ACTIONS(5527), 1,
      anon_sym_RPAREN,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    STATE(5026), 1,
      aux_sym_sequence_expression_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4867), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(4873), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(4881), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(4889), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4899), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4901), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(4897), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [82521] = 33,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_as,
    ACTIONS(4640), 1,
      anon_sym_BANG,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4649), 1,
      anon_sym_satisfies,
    ACTIONS(4869), 1,
      anon_sym_COMMA,
    ACTIONS(4875), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4877), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4879), 1,
      anon_sym_GT_GT,
    ACTIONS(4883), 1,
      anon_sym_AMP,
    ACTIONS(4885), 1,
      anon_sym_CARET,
    ACTIONS(4887), 1,
      anon_sym_PIPE,
    ACTIONS(4891), 1,
      anon_sym_PERCENT,
    ACTIONS(4893), 1,
      anon_sym_STAR_STAR,
    ACTIONS(4895), 1,
      anon_sym_LT,
    ACTIONS(4903), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(4905), 1,
      sym__ternary_qmark,
    ACTIONS(5529), 1,
      anon_sym_RPAREN,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    STATE(5026), 1,
      aux_sym_sequence_expression_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4867), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(4873), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(4881), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(4889), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4899), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4901), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(4897), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [82631] = 33,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_as,
    ACTIONS(4640), 1,
      anon_sym_BANG,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4649), 1,
      anon_sym_satisfies,
    ACTIONS(4869), 1,
      anon_sym_COMMA,
    ACTIONS(4875), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4877), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4879), 1,
      anon_sym_GT_GT,
    ACTIONS(4883), 1,
      anon_sym_AMP,
    ACTIONS(4885), 1,
      anon_sym_CARET,
    ACTIONS(4887), 1,
      anon_sym_PIPE,
    ACTIONS(4891), 1,
      anon_sym_PERCENT,
    ACTIONS(4893), 1,
      anon_sym_STAR_STAR,
    ACTIONS(4895), 1,
      anon_sym_LT,
    ACTIONS(4903), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(4905), 1,
      sym__ternary_qmark,
    ACTIONS(5531), 1,
      anon_sym_RPAREN,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    STATE(5026), 1,
      aux_sym_sequence_expression_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4867), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(4873), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(4881), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(4889), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4899), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4901), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(4897), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [82741] = 5,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(5533), 2,
      anon_sym_EQ,
      anon_sym_QMARK,
    ACTIONS(5535), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_COLON,
    ACTIONS(3492), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(3496), 23,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [82795] = 15,
    ACTIONS(237), 1,
      anon_sym_COMMA,
    ACTIONS(1550), 1,
      anon_sym_DQUOTE,
    ACTIONS(1552), 1,
      anon_sym_SQUOTE,
    ACTIONS(4622), 1,
      anon_sym_EQ,
    ACTIONS(4688), 1,
      anon_sym_LBRACK,
    ACTIONS(4990), 1,
      anon_sym_STAR,
    ACTIONS(5051), 1,
      anon_sym_RBRACE,
    STATE(4792), 1,
      aux_sym_object_repeat1,
    STATE(4815), 1,
      aux_sym_object_pattern_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(2337), 2,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(2357), 2,
      anon_sym_get,
      anon_sym_set,
    STATE(3816), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(3814), 4,
      anon_sym_LPAREN,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_QMARK,
    ACTIONS(2351), 21,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [82869] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4494), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4496), 28,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [82919] = 16,
    ACTIONS(237), 1,
      anon_sym_COMMA,
    ACTIONS(1550), 1,
      anon_sym_DQUOTE,
    ACTIONS(1552), 1,
      anon_sym_SQUOTE,
    ACTIONS(2353), 1,
      anon_sym_async,
    ACTIONS(4622), 1,
      anon_sym_EQ,
    ACTIONS(4688), 1,
      anon_sym_LBRACK,
    ACTIONS(4990), 1,
      anon_sym_STAR,
    ACTIONS(5051), 1,
      anon_sym_RBRACE,
    STATE(4792), 1,
      aux_sym_object_repeat1,
    STATE(4815), 1,
      aux_sym_object_pattern_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(2337), 2,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(2357), 2,
      anon_sym_get,
      anon_sym_set,
    STATE(3816), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(3814), 4,
      anon_sym_LPAREN,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_QMARK,
    ACTIONS(2351), 20,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [82995] = 10,
    ACTIONS(1550), 1,
      anon_sym_DQUOTE,
    ACTIONS(1552), 1,
      anon_sym_SQUOTE,
    ACTIONS(4688), 1,
      anon_sym_LBRACK,
    ACTIONS(5537), 1,
      anon_sym_STAR,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(5539), 2,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(5541), 2,
      anon_sym_get,
      anon_sym_set,
    STATE(3890), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(3814), 9,
      sym__automatic_semicolon,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_BANG,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_QMARK,
    ACTIONS(2351), 21,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [83059] = 33,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_as,
    ACTIONS(4640), 1,
      anon_sym_BANG,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4649), 1,
      anon_sym_satisfies,
    ACTIONS(4708), 1,
      anon_sym_LT,
    ACTIONS(4714), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4716), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4718), 1,
      anon_sym_GT_GT,
    ACTIONS(4722), 1,
      anon_sym_AMP,
    ACTIONS(4724), 1,
      anon_sym_CARET,
    ACTIONS(4726), 1,
      anon_sym_PIPE,
    ACTIONS(4730), 1,
      anon_sym_PERCENT,
    ACTIONS(4732), 1,
      anon_sym_STAR_STAR,
    ACTIONS(4740), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(4742), 1,
      sym__ternary_qmark,
    ACTIONS(5217), 1,
      anon_sym_COMMA,
    ACTIONS(5543), 1,
      anon_sym_SEMI,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(3792), 1,
      aux_sym_sequence_expression_repeat1,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4710), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(4712), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(4720), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(4728), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4736), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4738), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(4734), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [83169] = 33,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_as,
    ACTIONS(4640), 1,
      anon_sym_BANG,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4649), 1,
      anon_sym_satisfies,
    ACTIONS(4708), 1,
      anon_sym_LT,
    ACTIONS(4714), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4716), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4718), 1,
      anon_sym_GT_GT,
    ACTIONS(4722), 1,
      anon_sym_AMP,
    ACTIONS(4724), 1,
      anon_sym_CARET,
    ACTIONS(4726), 1,
      anon_sym_PIPE,
    ACTIONS(4730), 1,
      anon_sym_PERCENT,
    ACTIONS(4732), 1,
      anon_sym_STAR_STAR,
    ACTIONS(4740), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(4742), 1,
      sym__ternary_qmark,
    ACTIONS(5217), 1,
      anon_sym_COMMA,
    ACTIONS(5545), 1,
      anon_sym_SEMI,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(3792), 1,
      aux_sym_sequence_expression_repeat1,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4710), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(4712), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(4720), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(4728), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4736), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4738), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(4734), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [83279] = 6,
    ACTIONS(4408), 1,
      anon_sym_extends,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4611), 2,
      anon_sym_AMP,
      anon_sym_PIPE,
    ACTIONS(4608), 3,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_LBRACK,
    ACTIONS(3492), 11,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(3496), 24,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [83335] = 6,
    ACTIONS(4378), 1,
      anon_sym_extends,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4617), 2,
      anon_sym_AMP,
      anon_sym_PIPE,
    ACTIONS(4614), 3,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_LBRACK,
    ACTIONS(4458), 11,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4460), 24,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [83391] = 10,
    ACTIONS(1550), 1,
      anon_sym_DQUOTE,
    ACTIONS(1552), 1,
      anon_sym_SQUOTE,
    ACTIONS(4688), 1,
      anon_sym_LBRACK,
    ACTIONS(5271), 1,
      anon_sym_STAR,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(5547), 2,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(5549), 2,
      anon_sym_get,
      anon_sym_set,
    STATE(3851), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(3814), 9,
      sym__automatic_semicolon,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_BANG,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_QMARK,
    ACTIONS(2351), 21,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [83455] = 33,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_as,
    ACTIONS(4640), 1,
      anon_sym_BANG,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4649), 1,
      anon_sym_satisfies,
    ACTIONS(4869), 1,
      anon_sym_COMMA,
    ACTIONS(4875), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4877), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4879), 1,
      anon_sym_GT_GT,
    ACTIONS(4883), 1,
      anon_sym_AMP,
    ACTIONS(4885), 1,
      anon_sym_CARET,
    ACTIONS(4887), 1,
      anon_sym_PIPE,
    ACTIONS(4891), 1,
      anon_sym_PERCENT,
    ACTIONS(4893), 1,
      anon_sym_STAR_STAR,
    ACTIONS(4895), 1,
      anon_sym_LT,
    ACTIONS(4903), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(4905), 1,
      sym__ternary_qmark,
    ACTIONS(5551), 1,
      anon_sym_RPAREN,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    STATE(5026), 1,
      aux_sym_sequence_expression_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4867), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(4873), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(4881), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(4889), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4899), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4901), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(4897), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [83565] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4458), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4460), 28,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [83615] = 21,
    ACTIONS(231), 1,
      anon_sym_STAR,
    ACTIONS(1550), 1,
      anon_sym_DQUOTE,
    ACTIONS(1552), 1,
      anon_sym_SQUOTE,
    ACTIONS(2019), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(4688), 1,
      anon_sym_LBRACK,
    ACTIONS(5555), 1,
      anon_sym_COMMA,
    ACTIONS(5557), 1,
      anon_sym_RBRACE,
    ACTIONS(5559), 1,
      anon_sym_async,
    ACTIONS(5563), 1,
      anon_sym_static,
    ACTIONS(5565), 1,
      anon_sym_readonly,
    ACTIONS(5571), 1,
      anon_sym_override,
    STATE(2786), 1,
      sym_accessibility_modifier,
    STATE(2808), 1,
      sym_override_modifier,
    STATE(4925), 1,
      aux_sym_object_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(5561), 2,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(5567), 2,
      anon_sym_get,
      anon_sym_set,
    ACTIONS(5569), 3,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
    STATE(3688), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    STATE(4910), 3,
      sym_spread_element,
      sym_method_definition,
      sym_pair,
    ACTIONS(5553), 14,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_new,
      sym_identifier,
      anon_sym_declare,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [83701] = 15,
    ACTIONS(237), 1,
      anon_sym_COMMA,
    ACTIONS(1550), 1,
      anon_sym_DQUOTE,
    ACTIONS(1552), 1,
      anon_sym_SQUOTE,
    ACTIONS(4622), 1,
      anon_sym_EQ,
    ACTIONS(4688), 1,
      anon_sym_LBRACK,
    ACTIONS(4990), 1,
      anon_sym_STAR,
    ACTIONS(5053), 1,
      anon_sym_RBRACE,
    STATE(4792), 1,
      aux_sym_object_repeat1,
    STATE(4815), 1,
      aux_sym_object_pattern_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(2337), 2,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(2357), 2,
      anon_sym_get,
      anon_sym_set,
    STATE(3816), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(3814), 4,
      anon_sym_LPAREN,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_QMARK,
    ACTIONS(2351), 21,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [83775] = 5,
    ACTIONS(1714), 1,
      sym__automatic_semicolon,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(1706), 2,
      anon_sym_else,
      anon_sym_while,
    ACTIONS(1710), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(1712), 25,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [83829] = 16,
    ACTIONS(237), 1,
      anon_sym_COMMA,
    ACTIONS(1550), 1,
      anon_sym_DQUOTE,
    ACTIONS(1552), 1,
      anon_sym_SQUOTE,
    ACTIONS(2353), 1,
      anon_sym_async,
    ACTIONS(4622), 1,
      anon_sym_EQ,
    ACTIONS(4688), 1,
      anon_sym_LBRACK,
    ACTIONS(4990), 1,
      anon_sym_STAR,
    ACTIONS(5053), 1,
      anon_sym_RBRACE,
    STATE(4792), 1,
      aux_sym_object_repeat1,
    STATE(4815), 1,
      aux_sym_object_pattern_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(2337), 2,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(2357), 2,
      anon_sym_get,
      anon_sym_set,
    STATE(3816), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(3814), 4,
      anon_sym_LPAREN,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_QMARK,
    ACTIONS(2351), 20,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [83905] = 9,
    ACTIONS(3808), 1,
      anon_sym_COMMA,
    ACTIONS(3909), 1,
      anon_sym_RBRACE,
    ACTIONS(4622), 1,
      anon_sym_EQ,
    STATE(4792), 1,
      aux_sym_object_repeat1,
    STATE(4815), 1,
      aux_sym_object_pattern_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(1971), 6,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(3814), 7,
      sym__automatic_semicolon,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_QMARK,
      anon_sym_PIPE_RBRACE,
    ACTIONS(1969), 23,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [83967] = 9,
    ACTIONS(3808), 1,
      anon_sym_COMMA,
    ACTIONS(3909), 1,
      anon_sym_RBRACE,
    ACTIONS(4622), 1,
      anon_sym_EQ,
    STATE(4792), 1,
      aux_sym_object_repeat1,
    STATE(4815), 1,
      aux_sym_object_pattern_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(1975), 6,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(3814), 7,
      sym__automatic_semicolon,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_QMARK,
      anon_sym_PIPE_RBRACE,
    ACTIONS(1973), 23,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [84029] = 5,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(5092), 2,
      anon_sym_EQ,
      anon_sym_QMARK,
    ACTIONS(5130), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_COLON,
    ACTIONS(3492), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(3496), 23,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [84083] = 4,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4120), 3,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_extends,
    ACTIONS(4288), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4290), 25,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_of,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [84135] = 4,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4322), 3,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_extends,
    ACTIONS(4288), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4290), 25,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_of,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [84187] = 11,
    ACTIONS(1626), 1,
      anon_sym_DQUOTE,
    ACTIONS(1628), 1,
      anon_sym_SQUOTE,
    ACTIONS(4624), 1,
      anon_sym_LBRACK,
    ACTIONS(5537), 1,
      anon_sym_STAR,
    ACTIONS(5573), 1,
      anon_sym_async,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(5575), 2,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(5577), 2,
      anon_sym_get,
      anon_sym_set,
    STATE(3073), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(3814), 9,
      sym__automatic_semicolon,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_BANG,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_QMARK,
    ACTIONS(3700), 20,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [84253] = 31,
    ACTIONS(4588), 1,
      anon_sym_LPAREN,
    ACTIONS(4590), 1,
      anon_sym_LBRACK,
    ACTIONS(4592), 1,
      anon_sym_DOT,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4798), 1,
      anon_sym_as,
    ACTIONS(4800), 1,
      anon_sym_BANG,
    ACTIONS(4804), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4806), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4808), 1,
      anon_sym_GT_GT,
    ACTIONS(4812), 1,
      anon_sym_AMP,
    ACTIONS(4814), 1,
      anon_sym_CARET,
    ACTIONS(4816), 1,
      anon_sym_PIPE,
    ACTIONS(4820), 1,
      anon_sym_PERCENT,
    ACTIONS(4822), 1,
      anon_sym_STAR_STAR,
    ACTIONS(4824), 1,
      anon_sym_LT,
    ACTIONS(4832), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(4836), 1,
      anon_sym_satisfies,
    ACTIONS(4838), 1,
      sym__ternary_qmark,
    STATE(2019), 1,
      sym_type_arguments,
    STATE(2130), 1,
      sym_arguments,
    STATE(4524), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4796), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(4802), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(4810), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(4818), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4828), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4830), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(4834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4826), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
    ACTIONS(5014), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [84359] = 9,
    ACTIONS(3808), 1,
      anon_sym_COMMA,
    ACTIONS(3906), 1,
      anon_sym_RBRACE,
    ACTIONS(4622), 1,
      anon_sym_EQ,
    STATE(4810), 1,
      aux_sym_object_repeat1,
    STATE(4815), 1,
      aux_sym_object_pattern_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(1971), 6,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(3814), 7,
      sym__automatic_semicolon,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_QMARK,
      anon_sym_PIPE_RBRACE,
    ACTIONS(1969), 23,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [84421] = 9,
    ACTIONS(3808), 1,
      anon_sym_COMMA,
    ACTIONS(3906), 1,
      anon_sym_RBRACE,
    ACTIONS(4622), 1,
      anon_sym_EQ,
    STATE(4810), 1,
      aux_sym_object_repeat1,
    STATE(4815), 1,
      aux_sym_object_pattern_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(1975), 6,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(3814), 7,
      sym__automatic_semicolon,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_QMARK,
      anon_sym_PIPE_RBRACE,
    ACTIONS(1973), 23,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [84483] = 4,
    ACTIONS(3578), 1,
      anon_sym_EQ,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3492), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(3496), 27,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [84535] = 11,
    ACTIONS(1626), 1,
      anon_sym_DQUOTE,
    ACTIONS(1628), 1,
      anon_sym_SQUOTE,
    ACTIONS(4624), 1,
      anon_sym_LBRACK,
    ACTIONS(5271), 1,
      anon_sym_STAR,
    ACTIONS(5273), 1,
      anon_sym_async,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(5277), 2,
      anon_sym_get,
      anon_sym_set,
    ACTIONS(5579), 2,
      sym_number,
      sym_private_property_identifier,
    STATE(3081), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(3814), 9,
      sym__automatic_semicolon,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_BANG,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_QMARK,
    ACTIONS(3700), 20,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [84601] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(1734), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(1736), 28,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_of,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [84651] = 31,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_as,
    ACTIONS(4640), 1,
      anon_sym_BANG,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4649), 1,
      anon_sym_satisfies,
    ACTIONS(4875), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4877), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4879), 1,
      anon_sym_GT_GT,
    ACTIONS(4883), 1,
      anon_sym_AMP,
    ACTIONS(4885), 1,
      anon_sym_CARET,
    ACTIONS(4887), 1,
      anon_sym_PIPE,
    ACTIONS(4891), 1,
      anon_sym_PERCENT,
    ACTIONS(4893), 1,
      anon_sym_STAR_STAR,
    ACTIONS(4895), 1,
      anon_sym_LT,
    ACTIONS(4903), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(4905), 1,
      sym__ternary_qmark,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4867), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(4873), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(4881), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(4889), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4899), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4901), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(5521), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    ACTIONS(4897), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [84756] = 16,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_as,
    ACTIONS(4640), 1,
      anon_sym_BANG,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4649), 1,
      anon_sym_satisfies,
    ACTIONS(5581), 1,
      anon_sym_STAR_STAR,
    ACTIONS(5583), 1,
      anon_sym_LT,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4762), 11,
      anon_sym_STAR,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4760), 15,
      sym__ternary_qmark,
      anon_sym_COLON,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_BQUOTE,
  [84831] = 20,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(5581), 1,
      anon_sym_STAR_STAR,
    ACTIONS(5590), 1,
      anon_sym_GT_GT,
    ACTIONS(5596), 1,
      anon_sym_PERCENT,
    ACTIONS(5598), 1,
      anon_sym_LT,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(5586), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(5588), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(5592), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(5594), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(5600), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
    ACTIONS(4762), 5,
      anon_sym_BANG,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4760), 11,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COLON,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_CARET,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [84914] = 27,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4762), 1,
      anon_sym_BANG,
    ACTIONS(5581), 1,
      anon_sym_STAR_STAR,
    ACTIONS(5590), 1,
      anon_sym_GT_GT,
    ACTIONS(5596), 1,
      anon_sym_PERCENT,
    ACTIONS(5598), 1,
      anon_sym_LT,
    ACTIONS(5602), 1,
      anon_sym_AMP_AMP,
    ACTIONS(5604), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(5606), 1,
      anon_sym_AMP,
    ACTIONS(5608), 1,
      anon_sym_CARET,
    ACTIONS(5610), 1,
      anon_sym_PIPE,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(5586), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(5588), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(5592), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(5594), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(5612), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(5614), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(5600), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
    ACTIONS(4760), 6,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COLON,
      anon_sym_QMARK_QMARK,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [85011] = 31,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_as,
    ACTIONS(4640), 1,
      anon_sym_BANG,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4649), 1,
      anon_sym_satisfies,
    ACTIONS(5581), 1,
      anon_sym_STAR_STAR,
    ACTIONS(5590), 1,
      anon_sym_GT_GT,
    ACTIONS(5596), 1,
      anon_sym_PERCENT,
    ACTIONS(5598), 1,
      anon_sym_LT,
    ACTIONS(5602), 1,
      anon_sym_AMP_AMP,
    ACTIONS(5604), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(5606), 1,
      anon_sym_AMP,
    ACTIONS(5608), 1,
      anon_sym_CARET,
    ACTIONS(5610), 1,
      anon_sym_PIPE,
    ACTIONS(5616), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(5618), 1,
      sym__ternary_qmark,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4522), 2,
      anon_sym_COLON,
      anon_sym_BQUOTE,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(5586), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(5588), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(5592), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(5594), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(5612), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(5614), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(5600), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [85116] = 31,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_as,
    ACTIONS(4640), 1,
      anon_sym_BANG,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4649), 1,
      anon_sym_satisfies,
    ACTIONS(5581), 1,
      anon_sym_STAR_STAR,
    ACTIONS(5590), 1,
      anon_sym_GT_GT,
    ACTIONS(5596), 1,
      anon_sym_PERCENT,
    ACTIONS(5598), 1,
      anon_sym_LT,
    ACTIONS(5602), 1,
      anon_sym_AMP_AMP,
    ACTIONS(5604), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(5606), 1,
      anon_sym_AMP,
    ACTIONS(5608), 1,
      anon_sym_CARET,
    ACTIONS(5610), 1,
      anon_sym_PIPE,
    ACTIONS(5616), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(5618), 1,
      sym__ternary_qmark,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4767), 2,
      anon_sym_COLON,
      anon_sym_BQUOTE,
    ACTIONS(5586), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(5588), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(5592), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(5594), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(5612), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(5614), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(5600), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [85221] = 31,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_as,
    ACTIONS(4640), 1,
      anon_sym_BANG,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4649), 1,
      anon_sym_satisfies,
    ACTIONS(5581), 1,
      anon_sym_STAR_STAR,
    ACTIONS(5590), 1,
      anon_sym_GT_GT,
    ACTIONS(5596), 1,
      anon_sym_PERCENT,
    ACTIONS(5598), 1,
      anon_sym_LT,
    ACTIONS(5602), 1,
      anon_sym_AMP_AMP,
    ACTIONS(5604), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(5606), 1,
      anon_sym_AMP,
    ACTIONS(5608), 1,
      anon_sym_CARET,
    ACTIONS(5610), 1,
      anon_sym_PIPE,
    ACTIONS(5616), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(5618), 1,
      sym__ternary_qmark,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4546), 2,
      anon_sym_COLON,
      anon_sym_BQUOTE,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(5586), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(5588), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(5592), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(5594), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(5612), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(5614), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(5600), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [85326] = 31,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_as,
    ACTIONS(4640), 1,
      anon_sym_BANG,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4649), 1,
      anon_sym_satisfies,
    ACTIONS(5581), 1,
      anon_sym_STAR_STAR,
    ACTIONS(5590), 1,
      anon_sym_GT_GT,
    ACTIONS(5596), 1,
      anon_sym_PERCENT,
    ACTIONS(5598), 1,
      anon_sym_LT,
    ACTIONS(5602), 1,
      anon_sym_AMP_AMP,
    ACTIONS(5604), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(5606), 1,
      anon_sym_AMP,
    ACTIONS(5608), 1,
      anon_sym_CARET,
    ACTIONS(5610), 1,
      anon_sym_PIPE,
    ACTIONS(5616), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(5618), 1,
      sym__ternary_qmark,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4554), 2,
      anon_sym_COLON,
      anon_sym_BQUOTE,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(5586), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(5588), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(5592), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(5594), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(5612), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(5614), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(5600), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [85431] = 31,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_as,
    ACTIONS(4640), 1,
      anon_sym_BANG,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4649), 1,
      anon_sym_satisfies,
    ACTIONS(5581), 1,
      anon_sym_STAR_STAR,
    ACTIONS(5590), 1,
      anon_sym_GT_GT,
    ACTIONS(5596), 1,
      anon_sym_PERCENT,
    ACTIONS(5598), 1,
      anon_sym_LT,
    ACTIONS(5602), 1,
      anon_sym_AMP_AMP,
    ACTIONS(5604), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(5606), 1,
      anon_sym_AMP,
    ACTIONS(5608), 1,
      anon_sym_CARET,
    ACTIONS(5610), 1,
      anon_sym_PIPE,
    ACTIONS(5616), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(5618), 1,
      sym__ternary_qmark,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4558), 2,
      anon_sym_COLON,
      anon_sym_BQUOTE,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(5586), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(5588), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(5592), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(5594), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(5612), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(5614), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(5600), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [85536] = 31,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_as,
    ACTIONS(4640), 1,
      anon_sym_BANG,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4649), 1,
      anon_sym_satisfies,
    ACTIONS(5581), 1,
      anon_sym_STAR_STAR,
    ACTIONS(5590), 1,
      anon_sym_GT_GT,
    ACTIONS(5596), 1,
      anon_sym_PERCENT,
    ACTIONS(5598), 1,
      anon_sym_LT,
    ACTIONS(5602), 1,
      anon_sym_AMP_AMP,
    ACTIONS(5604), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(5606), 1,
      anon_sym_AMP,
    ACTIONS(5608), 1,
      anon_sym_CARET,
    ACTIONS(5610), 1,
      anon_sym_PIPE,
    ACTIONS(5616), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(5618), 1,
      sym__ternary_qmark,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4769), 2,
      anon_sym_COLON,
      anon_sym_BQUOTE,
    ACTIONS(5586), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(5588), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(5592), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(5594), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(5612), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(5614), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(5600), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [85641] = 31,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_as,
    ACTIONS(4640), 1,
      anon_sym_BANG,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4649), 1,
      anon_sym_satisfies,
    ACTIONS(5581), 1,
      anon_sym_STAR_STAR,
    ACTIONS(5590), 1,
      anon_sym_GT_GT,
    ACTIONS(5596), 1,
      anon_sym_PERCENT,
    ACTIONS(5598), 1,
      anon_sym_LT,
    ACTIONS(5602), 1,
      anon_sym_AMP_AMP,
    ACTIONS(5604), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(5606), 1,
      anon_sym_AMP,
    ACTIONS(5608), 1,
      anon_sym_CARET,
    ACTIONS(5610), 1,
      anon_sym_PIPE,
    ACTIONS(5616), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(5618), 1,
      sym__ternary_qmark,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4771), 2,
      anon_sym_COLON,
      anon_sym_BQUOTE,
    ACTIONS(5586), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(5588), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(5592), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(5594), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(5612), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(5614), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(5600), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [85746] = 31,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_as,
    ACTIONS(4640), 1,
      anon_sym_BANG,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4649), 1,
      anon_sym_satisfies,
    ACTIONS(4708), 1,
      anon_sym_LT,
    ACTIONS(4714), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4716), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4718), 1,
      anon_sym_GT_GT,
    ACTIONS(4722), 1,
      anon_sym_AMP,
    ACTIONS(4724), 1,
      anon_sym_CARET,
    ACTIONS(4726), 1,
      anon_sym_PIPE,
    ACTIONS(4730), 1,
      anon_sym_PERCENT,
    ACTIONS(4732), 1,
      anon_sym_STAR_STAR,
    ACTIONS(4740), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(4742), 1,
      sym__ternary_qmark,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4710), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(4712), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(4720), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(4728), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4736), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4738), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(5039), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
    ACTIONS(4734), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [85851] = 31,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_as,
    ACTIONS(4640), 1,
      anon_sym_BANG,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4649), 1,
      anon_sym_satisfies,
    ACTIONS(4708), 1,
      anon_sym_LT,
    ACTIONS(4714), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4716), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4718), 1,
      anon_sym_GT_GT,
    ACTIONS(4722), 1,
      anon_sym_AMP,
    ACTIONS(4724), 1,
      anon_sym_CARET,
    ACTIONS(4726), 1,
      anon_sym_PIPE,
    ACTIONS(4730), 1,
      anon_sym_PERCENT,
    ACTIONS(4732), 1,
      anon_sym_STAR_STAR,
    ACTIONS(4740), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(4742), 1,
      sym__ternary_qmark,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4710), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(4712), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(4720), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(4728), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4736), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4738), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(5049), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
    ACTIONS(4734), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [85956] = 4,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4120), 2,
      anon_sym_COMMA,
      anon_sym_extends,
    ACTIONS(4288), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4290), 25,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [86007] = 31,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_as,
    ACTIONS(4640), 1,
      anon_sym_BANG,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4649), 1,
      anon_sym_satisfies,
    ACTIONS(5581), 1,
      anon_sym_STAR_STAR,
    ACTIONS(5590), 1,
      anon_sym_GT_GT,
    ACTIONS(5596), 1,
      anon_sym_PERCENT,
    ACTIONS(5598), 1,
      anon_sym_LT,
    ACTIONS(5602), 1,
      anon_sym_AMP_AMP,
    ACTIONS(5604), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(5606), 1,
      anon_sym_AMP,
    ACTIONS(5608), 1,
      anon_sym_CARET,
    ACTIONS(5610), 1,
      anon_sym_PIPE,
    ACTIONS(5616), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(5618), 1,
      sym__ternary_qmark,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4773), 2,
      anon_sym_COLON,
      anon_sym_BQUOTE,
    ACTIONS(5586), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(5588), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(5592), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(5594), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(5612), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(5614), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(5600), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [86112] = 13,
    ACTIONS(237), 1,
      anon_sym_COMMA,
    ACTIONS(667), 1,
      anon_sym_RBRACE,
    ACTIONS(1550), 1,
      anon_sym_DQUOTE,
    ACTIONS(1552), 1,
      anon_sym_SQUOTE,
    ACTIONS(4622), 1,
      anon_sym_EQ,
    ACTIONS(4688), 1,
      anon_sym_LBRACK,
    STATE(4792), 1,
      aux_sym_object_repeat1,
    STATE(4815), 1,
      aux_sym_object_pattern_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(2337), 2,
      sym_number,
      sym_private_property_identifier,
    STATE(3816), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(3814), 4,
      anon_sym_LPAREN,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_QMARK,
    ACTIONS(2351), 23,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [86181] = 8,
    ACTIONS(1550), 1,
      anon_sym_DQUOTE,
    ACTIONS(1552), 1,
      anon_sym_SQUOTE,
    ACTIONS(4688), 1,
      anon_sym_LBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(5620), 2,
      sym_number,
      sym_private_property_identifier,
    STATE(3787), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(3814), 9,
      sym__automatic_semicolon,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_BANG,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_QMARK,
    ACTIONS(2351), 23,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [86240] = 4,
    ACTIONS(4120), 1,
      anon_sym_extends,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4288), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4290), 26,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [86291] = 31,
    ACTIONS(4588), 1,
      anon_sym_LPAREN,
    ACTIONS(4590), 1,
      anon_sym_LBRACK,
    ACTIONS(4592), 1,
      anon_sym_DOT,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4798), 1,
      anon_sym_as,
    ACTIONS(4800), 1,
      anon_sym_BANG,
    ACTIONS(4836), 1,
      anon_sym_satisfies,
    ACTIONS(5233), 1,
      anon_sym_LT,
    ACTIONS(5239), 1,
      anon_sym_AMP_AMP,
    ACTIONS(5241), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(5243), 1,
      anon_sym_GT_GT,
    ACTIONS(5247), 1,
      anon_sym_AMP,
    ACTIONS(5249), 1,
      anon_sym_CARET,
    ACTIONS(5251), 1,
      anon_sym_PIPE,
    ACTIONS(5255), 1,
      anon_sym_PERCENT,
    ACTIONS(5257), 1,
      anon_sym_STAR_STAR,
    ACTIONS(5265), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(5267), 1,
      sym__ternary_qmark,
    STATE(2019), 1,
      sym_type_arguments,
    STATE(2130), 1,
      sym_arguments,
    STATE(4524), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(5235), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(5237), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(5245), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(5253), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(5261), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(5263), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(5622), 2,
      sym__automatic_semicolon,
      anon_sym_SEMI,
    ACTIONS(5259), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [86396] = 13,
    ACTIONS(237), 1,
      anon_sym_COMMA,
    ACTIONS(694), 1,
      anon_sym_RBRACE,
    ACTIONS(1550), 1,
      anon_sym_DQUOTE,
    ACTIONS(1552), 1,
      anon_sym_SQUOTE,
    ACTIONS(4622), 1,
      anon_sym_EQ,
    ACTIONS(4688), 1,
      anon_sym_LBRACK,
    STATE(4792), 1,
      aux_sym_object_repeat1,
    STATE(4815), 1,
      aux_sym_object_pattern_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(2337), 2,
      sym_number,
      sym_private_property_identifier,
    STATE(3816), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(3814), 4,
      anon_sym_LPAREN,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_QMARK,
    ACTIONS(2351), 23,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [86465] = 8,
    ACTIONS(1550), 1,
      anon_sym_DQUOTE,
    ACTIONS(1552), 1,
      anon_sym_SQUOTE,
    ACTIONS(4688), 1,
      anon_sym_LBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(5292), 2,
      sym_number,
      sym_private_property_identifier,
    STATE(3853), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(3814), 9,
      sym__automatic_semicolon,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_BANG,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_QMARK,
    ACTIONS(2351), 23,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [86524] = 8,
    ACTIONS(1550), 1,
      anon_sym_DQUOTE,
    ACTIONS(1552), 1,
      anon_sym_SQUOTE,
    ACTIONS(4688), 1,
      anon_sym_LBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(5507), 2,
      sym_number,
      sym_private_property_identifier,
    STATE(3802), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(3814), 9,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_QMARK,
      anon_sym_PIPE_RBRACE,
    ACTIONS(2351), 23,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [86583] = 4,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4322), 2,
      anon_sym_COMMA,
      anon_sym_extends,
    ACTIONS(4288), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4290), 25,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [86634] = 4,
    ACTIONS(4322), 1,
      anon_sym_extends,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4288), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4290), 26,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [86685] = 8,
    ACTIONS(1550), 1,
      anon_sym_DQUOTE,
    ACTIONS(1552), 1,
      anon_sym_SQUOTE,
    ACTIONS(4688), 1,
      anon_sym_LBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(5279), 2,
      sym_number,
      sym_private_property_identifier,
    STATE(3863), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(3814), 9,
      sym__automatic_semicolon,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_BANG,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_QMARK,
    ACTIONS(2351), 23,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [86744] = 17,
    ACTIONS(1550), 1,
      anon_sym_DQUOTE,
    ACTIONS(1552), 1,
      anon_sym_SQUOTE,
    ACTIONS(2353), 1,
      anon_sym_async,
    ACTIONS(2355), 1,
      anon_sym_readonly,
    ACTIONS(2359), 1,
      anon_sym_override,
    ACTIONS(4688), 1,
      anon_sym_LBRACK,
    ACTIONS(4990), 1,
      anon_sym_STAR,
    ACTIONS(5555), 1,
      anon_sym_COMMA,
    ACTIONS(5624), 1,
      anon_sym_RBRACE,
    STATE(2813), 1,
      sym_override_modifier,
    STATE(4960), 1,
      aux_sym_object_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(2337), 2,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(2357), 2,
      anon_sym_get,
      anon_sym_set,
    STATE(3816), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(3814), 4,
      anon_sym_LPAREN,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_QMARK,
    ACTIONS(2351), 18,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [86821] = 4,
    ACTIONS(4915), 1,
      sym_regex_flags,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4911), 17,
      anon_sym_STAR,
      anon_sym_as,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_instanceof,
      anon_sym_satisfies,
      anon_sym_implements,
    ACTIONS(4913), 22,
      sym__ternary_qmark,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
  [86872] = 31,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_as,
    ACTIONS(4640), 1,
      anon_sym_BANG,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4649), 1,
      anon_sym_satisfies,
    ACTIONS(4875), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4877), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4879), 1,
      anon_sym_GT_GT,
    ACTIONS(4883), 1,
      anon_sym_AMP,
    ACTIONS(4885), 1,
      anon_sym_CARET,
    ACTIONS(4887), 1,
      anon_sym_PIPE,
    ACTIONS(4891), 1,
      anon_sym_PERCENT,
    ACTIONS(4893), 1,
      anon_sym_STAR_STAR,
    ACTIONS(4895), 1,
      anon_sym_LT,
    ACTIONS(4903), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(4905), 1,
      sym__ternary_qmark,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4867), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(4873), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(4881), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(4889), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4899), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4901), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(5014), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    ACTIONS(4897), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [86977] = 8,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(5626), 1,
      anon_sym_LT,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4704), 12,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4706), 23,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [87036] = 31,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_as,
    ACTIONS(4640), 1,
      anon_sym_BANG,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4649), 1,
      anon_sym_satisfies,
    ACTIONS(5626), 1,
      anon_sym_LT,
    ACTIONS(5632), 1,
      anon_sym_AMP_AMP,
    ACTIONS(5634), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(5636), 1,
      anon_sym_GT_GT,
    ACTIONS(5640), 1,
      anon_sym_AMP,
    ACTIONS(5642), 1,
      anon_sym_CARET,
    ACTIONS(5644), 1,
      anon_sym_PIPE,
    ACTIONS(5648), 1,
      anon_sym_PERCENT,
    ACTIONS(5650), 1,
      anon_sym_STAR_STAR,
    ACTIONS(5658), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(5660), 1,
      sym__ternary_qmark,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4468), 2,
      anon_sym_RBRACK,
      anon_sym_BQUOTE,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(5628), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(5630), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(5638), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(5646), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(5654), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(5656), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(5652), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [87141] = 31,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_as,
    ACTIONS(4640), 1,
      anon_sym_BANG,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4649), 1,
      anon_sym_satisfies,
    ACTIONS(5626), 1,
      anon_sym_LT,
    ACTIONS(5632), 1,
      anon_sym_AMP_AMP,
    ACTIONS(5634), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(5636), 1,
      anon_sym_GT_GT,
    ACTIONS(5640), 1,
      anon_sym_AMP,
    ACTIONS(5642), 1,
      anon_sym_CARET,
    ACTIONS(5644), 1,
      anon_sym_PIPE,
    ACTIONS(5648), 1,
      anon_sym_PERCENT,
    ACTIONS(5650), 1,
      anon_sym_STAR_STAR,
    ACTIONS(5658), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(5660), 1,
      sym__ternary_qmark,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4744), 2,
      anon_sym_RBRACK,
      anon_sym_BQUOTE,
    ACTIONS(5628), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(5630), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(5638), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(5646), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(5654), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(5656), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(5652), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [87246] = 31,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_as,
    ACTIONS(4640), 1,
      anon_sym_BANG,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4649), 1,
      anon_sym_satisfies,
    ACTIONS(5626), 1,
      anon_sym_LT,
    ACTIONS(5632), 1,
      anon_sym_AMP_AMP,
    ACTIONS(5634), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(5636), 1,
      anon_sym_GT_GT,
    ACTIONS(5640), 1,
      anon_sym_AMP,
    ACTIONS(5642), 1,
      anon_sym_CARET,
    ACTIONS(5644), 1,
      anon_sym_PIPE,
    ACTIONS(5648), 1,
      anon_sym_PERCENT,
    ACTIONS(5650), 1,
      anon_sym_STAR_STAR,
    ACTIONS(5658), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(5660), 1,
      sym__ternary_qmark,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4756), 2,
      anon_sym_RBRACK,
      anon_sym_BQUOTE,
    ACTIONS(5628), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(5630), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(5638), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(5646), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(5654), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(5656), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(5652), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [87351] = 31,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_as,
    ACTIONS(4640), 1,
      anon_sym_BANG,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4649), 1,
      anon_sym_satisfies,
    ACTIONS(5626), 1,
      anon_sym_LT,
    ACTIONS(5632), 1,
      anon_sym_AMP_AMP,
    ACTIONS(5634), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(5636), 1,
      anon_sym_GT_GT,
    ACTIONS(5640), 1,
      anon_sym_AMP,
    ACTIONS(5642), 1,
      anon_sym_CARET,
    ACTIONS(5644), 1,
      anon_sym_PIPE,
    ACTIONS(5648), 1,
      anon_sym_PERCENT,
    ACTIONS(5650), 1,
      anon_sym_STAR_STAR,
    ACTIONS(5658), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(5660), 1,
      sym__ternary_qmark,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4758), 2,
      anon_sym_RBRACK,
      anon_sym_BQUOTE,
    ACTIONS(5628), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(5630), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(5638), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(5646), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(5654), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(5656), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(5652), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [87456] = 31,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_as,
    ACTIONS(4640), 1,
      anon_sym_BANG,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4649), 1,
      anon_sym_satisfies,
    ACTIONS(5626), 1,
      anon_sym_LT,
    ACTIONS(5632), 1,
      anon_sym_AMP_AMP,
    ACTIONS(5634), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(5636), 1,
      anon_sym_GT_GT,
    ACTIONS(5640), 1,
      anon_sym_AMP,
    ACTIONS(5642), 1,
      anon_sym_CARET,
    ACTIONS(5644), 1,
      anon_sym_PIPE,
    ACTIONS(5648), 1,
      anon_sym_PERCENT,
    ACTIONS(5650), 1,
      anon_sym_STAR_STAR,
    ACTIONS(5658), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(5660), 1,
      sym__ternary_qmark,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4504), 2,
      anon_sym_RBRACK,
      anon_sym_BQUOTE,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(5628), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(5630), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(5638), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(5646), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(5654), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(5656), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(5652), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [87561] = 18,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(5626), 1,
      anon_sym_LT,
    ACTIONS(5636), 1,
      anon_sym_GT_GT,
    ACTIONS(5648), 1,
      anon_sym_PERCENT,
    ACTIONS(5650), 1,
      anon_sym_STAR_STAR,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(5628), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(5638), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(5646), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4762), 7,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4760), 14,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_RBRACK,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [87640] = 13,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(5650), 1,
      anon_sym_STAR_STAR,
    ACTIONS(5662), 1,
      anon_sym_LT,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4762), 12,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4760), 17,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_RBRACK,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [87709] = 25,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4762), 1,
      anon_sym_BANG,
    ACTIONS(5626), 1,
      anon_sym_LT,
    ACTIONS(5636), 1,
      anon_sym_GT_GT,
    ACTIONS(5640), 1,
      anon_sym_AMP,
    ACTIONS(5642), 1,
      anon_sym_CARET,
    ACTIONS(5644), 1,
      anon_sym_PIPE,
    ACTIONS(5648), 1,
      anon_sym_PERCENT,
    ACTIONS(5650), 1,
      anon_sym_STAR_STAR,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(5628), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(5630), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(5638), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(5646), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(5654), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(5656), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(5652), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
    ACTIONS(4760), 8,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_RBRACK,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [87802] = 26,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4762), 1,
      anon_sym_BANG,
    ACTIONS(5626), 1,
      anon_sym_LT,
    ACTIONS(5632), 1,
      anon_sym_AMP_AMP,
    ACTIONS(5636), 1,
      anon_sym_GT_GT,
    ACTIONS(5640), 1,
      anon_sym_AMP,
    ACTIONS(5642), 1,
      anon_sym_CARET,
    ACTIONS(5644), 1,
      anon_sym_PIPE,
    ACTIONS(5648), 1,
      anon_sym_PERCENT,
    ACTIONS(5650), 1,
      anon_sym_STAR_STAR,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(5628), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(5630), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(5638), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(5646), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(5654), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(5656), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(5652), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
    ACTIONS(4760), 7,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_RBRACK,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [87897] = 16,
    ACTIONS(1550), 1,
      anon_sym_DQUOTE,
    ACTIONS(1552), 1,
      anon_sym_SQUOTE,
    ACTIONS(2353), 1,
      anon_sym_async,
    ACTIONS(2355), 1,
      anon_sym_readonly,
    ACTIONS(2359), 1,
      anon_sym_override,
    ACTIONS(4622), 1,
      anon_sym_EQ,
    ACTIONS(4688), 1,
      anon_sym_LBRACK,
    ACTIONS(4990), 1,
      anon_sym_STAR,
    STATE(2813), 1,
      sym_override_modifier,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(2337), 2,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(2357), 2,
      anon_sym_get,
      anon_sym_set,
    ACTIONS(5665), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
    STATE(3816), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(3814), 4,
      anon_sym_LPAREN,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_QMARK,
    ACTIONS(2351), 18,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [87972] = 8,
    ACTIONS(1626), 1,
      anon_sym_DQUOTE,
    ACTIONS(1628), 1,
      anon_sym_SQUOTE,
    ACTIONS(4624), 1,
      anon_sym_LBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(5668), 2,
      sym_number,
      sym_private_property_identifier,
    STATE(3399), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(3814), 9,
      sym__automatic_semicolon,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_BANG,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_QMARK,
    ACTIONS(3700), 23,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [88031] = 16,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(5648), 1,
      anon_sym_PERCENT,
    ACTIONS(5650), 1,
      anon_sym_STAR_STAR,
    ACTIONS(5662), 1,
      anon_sym_LT,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(5628), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(5646), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4762), 8,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4760), 16,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_RBRACK,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [88106] = 22,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(5626), 1,
      anon_sym_LT,
    ACTIONS(5636), 1,
      anon_sym_GT_GT,
    ACTIONS(5648), 1,
      anon_sym_PERCENT,
    ACTIONS(5650), 1,
      anon_sym_STAR_STAR,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(5628), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(5630), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(5638), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(5646), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(5654), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(5656), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(4762), 3,
      anon_sym_BANG,
      anon_sym_AMP,
      anon_sym_PIPE,
    ACTIONS(5652), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
    ACTIONS(4760), 9,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_RBRACK,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_CARET,
      anon_sym_QMARK_QMARK,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [88193] = 8,
    ACTIONS(1550), 1,
      anon_sym_DQUOTE,
    ACTIONS(1552), 1,
      anon_sym_SQUOTE,
    ACTIONS(4688), 1,
      anon_sym_LBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(5427), 2,
      sym_number,
      sym_private_property_identifier,
    STATE(3804), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(3814), 9,
      sym__automatic_semicolon,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_BANG,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_QMARK,
    ACTIONS(2351), 23,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [88252] = 23,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(5626), 1,
      anon_sym_LT,
    ACTIONS(5636), 1,
      anon_sym_GT_GT,
    ACTIONS(5640), 1,
      anon_sym_AMP,
    ACTIONS(5648), 1,
      anon_sym_PERCENT,
    ACTIONS(5650), 1,
      anon_sym_STAR_STAR,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4762), 2,
      anon_sym_BANG,
      anon_sym_PIPE,
    ACTIONS(5628), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(5630), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(5638), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(5646), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(5654), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(5656), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(5652), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
    ACTIONS(4760), 9,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_RBRACK,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_CARET,
      anon_sym_QMARK_QMARK,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [88341] = 24,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(5626), 1,
      anon_sym_LT,
    ACTIONS(5636), 1,
      anon_sym_GT_GT,
    ACTIONS(5640), 1,
      anon_sym_AMP,
    ACTIONS(5642), 1,
      anon_sym_CARET,
    ACTIONS(5648), 1,
      anon_sym_PERCENT,
    ACTIONS(5650), 1,
      anon_sym_STAR_STAR,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4762), 2,
      anon_sym_BANG,
      anon_sym_PIPE,
    ACTIONS(5628), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(5630), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(5638), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(5646), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(5654), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(5656), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(5652), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
    ACTIONS(4760), 8,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_RBRACK,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [88432] = 12,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(5670), 1,
      anon_sym_LT,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4778), 12,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4780), 18,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COLON,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [88499] = 15,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_as,
    ACTIONS(4640), 1,
      anon_sym_BANG,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4649), 1,
      anon_sym_satisfies,
    ACTIONS(5673), 1,
      anon_sym_LT,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4634), 11,
      anon_sym_STAR,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4638), 16,
      sym__ternary_qmark,
      anon_sym_COLON,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_BQUOTE,
  [88572] = 31,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_as,
    ACTIONS(4640), 1,
      anon_sym_BANG,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4649), 1,
      anon_sym_satisfies,
    ACTIONS(5581), 1,
      anon_sym_STAR_STAR,
    ACTIONS(5590), 1,
      anon_sym_GT_GT,
    ACTIONS(5596), 1,
      anon_sym_PERCENT,
    ACTIONS(5598), 1,
      anon_sym_LT,
    ACTIONS(5602), 1,
      anon_sym_AMP_AMP,
    ACTIONS(5604), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(5606), 1,
      anon_sym_AMP,
    ACTIONS(5608), 1,
      anon_sym_CARET,
    ACTIONS(5610), 1,
      anon_sym_PIPE,
    ACTIONS(5616), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(5618), 1,
      sym__ternary_qmark,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4792), 2,
      anon_sym_COLON,
      anon_sym_BQUOTE,
    ACTIONS(5586), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(5588), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(5592), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(5594), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(5612), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(5614), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(5600), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [88677] = 11,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(5676), 1,
      anon_sym_LT,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4785), 12,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4787), 20,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COLON,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [88742] = 15,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(5648), 1,
      anon_sym_PERCENT,
    ACTIONS(5650), 1,
      anon_sym_STAR_STAR,
    ACTIONS(5662), 1,
      anon_sym_LT,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(5628), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(4762), 10,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4760), 16,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_RBRACK,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [88815] = 16,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_as,
    ACTIONS(4640), 1,
      anon_sym_BANG,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4649), 1,
      anon_sym_satisfies,
    ACTIONS(5650), 1,
      anon_sym_STAR_STAR,
    ACTIONS(5662), 1,
      anon_sym_LT,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4762), 11,
      anon_sym_STAR,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4760), 15,
      sym__ternary_qmark,
      anon_sym_RBRACK,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_BQUOTE,
  [88890] = 20,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(5626), 1,
      anon_sym_LT,
    ACTIONS(5636), 1,
      anon_sym_GT_GT,
    ACTIONS(5648), 1,
      anon_sym_PERCENT,
    ACTIONS(5650), 1,
      anon_sym_STAR_STAR,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(5628), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(5630), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(5638), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(5646), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(5652), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
    ACTIONS(4762), 5,
      anon_sym_BANG,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4760), 11,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_RBRACK,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_CARET,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [88973] = 31,
    ACTIONS(4588), 1,
      anon_sym_LPAREN,
    ACTIONS(4590), 1,
      anon_sym_LBRACK,
    ACTIONS(4592), 1,
      anon_sym_DOT,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4798), 1,
      anon_sym_as,
    ACTIONS(4800), 1,
      anon_sym_BANG,
    ACTIONS(4836), 1,
      anon_sym_satisfies,
    ACTIONS(5233), 1,
      anon_sym_LT,
    ACTIONS(5239), 1,
      anon_sym_AMP_AMP,
    ACTIONS(5241), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(5243), 1,
      anon_sym_GT_GT,
    ACTIONS(5247), 1,
      anon_sym_AMP,
    ACTIONS(5249), 1,
      anon_sym_CARET,
    ACTIONS(5251), 1,
      anon_sym_PIPE,
    ACTIONS(5255), 1,
      anon_sym_PERCENT,
    ACTIONS(5257), 1,
      anon_sym_STAR_STAR,
    ACTIONS(5265), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(5267), 1,
      sym__ternary_qmark,
    STATE(2019), 1,
      sym_type_arguments,
    STATE(2130), 1,
      sym_arguments,
    STATE(4524), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(5101), 2,
      sym__automatic_semicolon,
      anon_sym_SEMI,
    ACTIONS(5235), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(5237), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(5245), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(5253), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(5261), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(5263), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(5259), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [89078] = 27,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4762), 1,
      anon_sym_BANG,
    ACTIONS(5626), 1,
      anon_sym_LT,
    ACTIONS(5632), 1,
      anon_sym_AMP_AMP,
    ACTIONS(5634), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(5636), 1,
      anon_sym_GT_GT,
    ACTIONS(5640), 1,
      anon_sym_AMP,
    ACTIONS(5642), 1,
      anon_sym_CARET,
    ACTIONS(5644), 1,
      anon_sym_PIPE,
    ACTIONS(5648), 1,
      anon_sym_PERCENT,
    ACTIONS(5650), 1,
      anon_sym_STAR_STAR,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(5628), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(5630), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(5638), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(5646), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(5654), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(5656), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(5652), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
    ACTIONS(4760), 6,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_RBRACK,
      anon_sym_QMARK_QMARK,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [89175] = 31,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_as,
    ACTIONS(4640), 1,
      anon_sym_BANG,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4649), 1,
      anon_sym_satisfies,
    ACTIONS(5626), 1,
      anon_sym_LT,
    ACTIONS(5632), 1,
      anon_sym_AMP_AMP,
    ACTIONS(5634), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(5636), 1,
      anon_sym_GT_GT,
    ACTIONS(5640), 1,
      anon_sym_AMP,
    ACTIONS(5642), 1,
      anon_sym_CARET,
    ACTIONS(5644), 1,
      anon_sym_PIPE,
    ACTIONS(5648), 1,
      anon_sym_PERCENT,
    ACTIONS(5650), 1,
      anon_sym_STAR_STAR,
    ACTIONS(5658), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(5660), 1,
      sym__ternary_qmark,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4522), 2,
      anon_sym_RBRACK,
      anon_sym_BQUOTE,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(5628), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(5630), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(5638), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(5646), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(5654), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(5656), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(5652), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [89280] = 12,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(5679), 1,
      anon_sym_LT,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4778), 12,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4780), 18,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_RBRACK,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [89347] = 15,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_as,
    ACTIONS(4640), 1,
      anon_sym_BANG,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4649), 1,
      anon_sym_satisfies,
    ACTIONS(5682), 1,
      anon_sym_LT,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4634), 11,
      anon_sym_STAR,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4638), 16,
      sym__ternary_qmark,
      anon_sym_RBRACK,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_BQUOTE,
  [89420] = 31,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_as,
    ACTIONS(4640), 1,
      anon_sym_BANG,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4649), 1,
      anon_sym_satisfies,
    ACTIONS(5626), 1,
      anon_sym_LT,
    ACTIONS(5632), 1,
      anon_sym_AMP_AMP,
    ACTIONS(5634), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(5636), 1,
      anon_sym_GT_GT,
    ACTIONS(5640), 1,
      anon_sym_AMP,
    ACTIONS(5642), 1,
      anon_sym_CARET,
    ACTIONS(5644), 1,
      anon_sym_PIPE,
    ACTIONS(5648), 1,
      anon_sym_PERCENT,
    ACTIONS(5650), 1,
      anon_sym_STAR_STAR,
    ACTIONS(5658), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(5660), 1,
      sym__ternary_qmark,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4792), 2,
      anon_sym_RBRACK,
      anon_sym_BQUOTE,
    ACTIONS(5628), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(5630), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(5638), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(5646), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(5654), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(5656), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(5652), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [89525] = 11,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(5685), 1,
      anon_sym_LT,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4785), 12,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4787), 20,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_RBRACK,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [89590] = 31,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_as,
    ACTIONS(4640), 1,
      anon_sym_BANG,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4649), 1,
      anon_sym_satisfies,
    ACTIONS(5626), 1,
      anon_sym_LT,
    ACTIONS(5632), 1,
      anon_sym_AMP_AMP,
    ACTIONS(5634), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(5636), 1,
      anon_sym_GT_GT,
    ACTIONS(5640), 1,
      anon_sym_AMP,
    ACTIONS(5642), 1,
      anon_sym_CARET,
    ACTIONS(5644), 1,
      anon_sym_PIPE,
    ACTIONS(5648), 1,
      anon_sym_PERCENT,
    ACTIONS(5650), 1,
      anon_sym_STAR_STAR,
    ACTIONS(5658), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(5660), 1,
      sym__ternary_qmark,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4767), 2,
      anon_sym_RBRACK,
      anon_sym_BQUOTE,
    ACTIONS(5628), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(5630), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(5638), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(5646), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(5654), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(5656), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(5652), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [89695] = 31,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_as,
    ACTIONS(4640), 1,
      anon_sym_BANG,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4649), 1,
      anon_sym_satisfies,
    ACTIONS(5626), 1,
      anon_sym_LT,
    ACTIONS(5632), 1,
      anon_sym_AMP_AMP,
    ACTIONS(5634), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(5636), 1,
      anon_sym_GT_GT,
    ACTIONS(5640), 1,
      anon_sym_AMP,
    ACTIONS(5642), 1,
      anon_sym_CARET,
    ACTIONS(5644), 1,
      anon_sym_PIPE,
    ACTIONS(5648), 1,
      anon_sym_PERCENT,
    ACTIONS(5650), 1,
      anon_sym_STAR_STAR,
    ACTIONS(5658), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(5660), 1,
      sym__ternary_qmark,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4546), 2,
      anon_sym_RBRACK,
      anon_sym_BQUOTE,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(5628), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(5630), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(5638), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(5646), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(5654), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(5656), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(5652), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [89800] = 31,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_as,
    ACTIONS(4640), 1,
      anon_sym_BANG,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4649), 1,
      anon_sym_satisfies,
    ACTIONS(5626), 1,
      anon_sym_LT,
    ACTIONS(5632), 1,
      anon_sym_AMP_AMP,
    ACTIONS(5634), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(5636), 1,
      anon_sym_GT_GT,
    ACTIONS(5640), 1,
      anon_sym_AMP,
    ACTIONS(5642), 1,
      anon_sym_CARET,
    ACTIONS(5644), 1,
      anon_sym_PIPE,
    ACTIONS(5648), 1,
      anon_sym_PERCENT,
    ACTIONS(5650), 1,
      anon_sym_STAR_STAR,
    ACTIONS(5658), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(5660), 1,
      sym__ternary_qmark,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4554), 2,
      anon_sym_RBRACK,
      anon_sym_BQUOTE,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(5628), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(5630), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(5638), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(5646), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(5654), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(5656), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(5652), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [89905] = 31,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_as,
    ACTIONS(4640), 1,
      anon_sym_BANG,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4649), 1,
      anon_sym_satisfies,
    ACTIONS(5626), 1,
      anon_sym_LT,
    ACTIONS(5632), 1,
      anon_sym_AMP_AMP,
    ACTIONS(5634), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(5636), 1,
      anon_sym_GT_GT,
    ACTIONS(5640), 1,
      anon_sym_AMP,
    ACTIONS(5642), 1,
      anon_sym_CARET,
    ACTIONS(5644), 1,
      anon_sym_PIPE,
    ACTIONS(5648), 1,
      anon_sym_PERCENT,
    ACTIONS(5650), 1,
      anon_sym_STAR_STAR,
    ACTIONS(5658), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(5660), 1,
      sym__ternary_qmark,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4558), 2,
      anon_sym_RBRACK,
      anon_sym_BQUOTE,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(5628), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(5630), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(5638), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(5646), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(5654), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(5656), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(5652), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [90010] = 5,
    ACTIONS(3510), 1,
      anon_sym_EQ,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3686), 3,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_RBRACK,
    ACTIONS(3492), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(3496), 23,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [90063] = 31,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_as,
    ACTIONS(4640), 1,
      anon_sym_BANG,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4649), 1,
      anon_sym_satisfies,
    ACTIONS(5626), 1,
      anon_sym_LT,
    ACTIONS(5632), 1,
      anon_sym_AMP_AMP,
    ACTIONS(5634), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(5636), 1,
      anon_sym_GT_GT,
    ACTIONS(5640), 1,
      anon_sym_AMP,
    ACTIONS(5642), 1,
      anon_sym_CARET,
    ACTIONS(5644), 1,
      anon_sym_PIPE,
    ACTIONS(5648), 1,
      anon_sym_PERCENT,
    ACTIONS(5650), 1,
      anon_sym_STAR_STAR,
    ACTIONS(5658), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(5660), 1,
      sym__ternary_qmark,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4769), 2,
      anon_sym_RBRACK,
      anon_sym_BQUOTE,
    ACTIONS(5628), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(5630), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(5638), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(5646), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(5654), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(5656), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(5652), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [90168] = 31,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_as,
    ACTIONS(4640), 1,
      anon_sym_BANG,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4649), 1,
      anon_sym_satisfies,
    ACTIONS(5626), 1,
      anon_sym_LT,
    ACTIONS(5632), 1,
      anon_sym_AMP_AMP,
    ACTIONS(5634), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(5636), 1,
      anon_sym_GT_GT,
    ACTIONS(5640), 1,
      anon_sym_AMP,
    ACTIONS(5642), 1,
      anon_sym_CARET,
    ACTIONS(5644), 1,
      anon_sym_PIPE,
    ACTIONS(5648), 1,
      anon_sym_PERCENT,
    ACTIONS(5650), 1,
      anon_sym_STAR_STAR,
    ACTIONS(5658), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(5660), 1,
      sym__ternary_qmark,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4771), 2,
      anon_sym_RBRACK,
      anon_sym_BQUOTE,
    ACTIONS(5628), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(5630), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(5638), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(5646), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(5654), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(5656), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(5652), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [90273] = 31,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_as,
    ACTIONS(4640), 1,
      anon_sym_BANG,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4649), 1,
      anon_sym_satisfies,
    ACTIONS(4708), 1,
      anon_sym_LT,
    ACTIONS(4714), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4716), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4718), 1,
      anon_sym_GT_GT,
    ACTIONS(4722), 1,
      anon_sym_AMP,
    ACTIONS(4724), 1,
      anon_sym_CARET,
    ACTIONS(4726), 1,
      anon_sym_PIPE,
    ACTIONS(4730), 1,
      anon_sym_PERCENT,
    ACTIONS(4732), 1,
      anon_sym_STAR_STAR,
    ACTIONS(4740), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(4742), 1,
      sym__ternary_qmark,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4710), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(4712), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(4720), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(4728), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4736), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4738), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(5688), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
    ACTIONS(4734), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [90378] = 31,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_as,
    ACTIONS(4640), 1,
      anon_sym_BANG,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4649), 1,
      anon_sym_satisfies,
    ACTIONS(5626), 1,
      anon_sym_LT,
    ACTIONS(5632), 1,
      anon_sym_AMP_AMP,
    ACTIONS(5634), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(5636), 1,
      anon_sym_GT_GT,
    ACTIONS(5640), 1,
      anon_sym_AMP,
    ACTIONS(5642), 1,
      anon_sym_CARET,
    ACTIONS(5644), 1,
      anon_sym_PIPE,
    ACTIONS(5648), 1,
      anon_sym_PERCENT,
    ACTIONS(5650), 1,
      anon_sym_STAR_STAR,
    ACTIONS(5658), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(5660), 1,
      sym__ternary_qmark,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4773), 2,
      anon_sym_RBRACK,
      anon_sym_BQUOTE,
    ACTIONS(5628), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(5630), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(5638), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(5646), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(5654), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(5656), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(5652), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [90483] = 31,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_as,
    ACTIONS(4640), 1,
      anon_sym_BANG,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4649), 1,
      anon_sym_satisfies,
    ACTIONS(4708), 1,
      anon_sym_LT,
    ACTIONS(4714), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4716), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4718), 1,
      anon_sym_GT_GT,
    ACTIONS(4722), 1,
      anon_sym_AMP,
    ACTIONS(4724), 1,
      anon_sym_CARET,
    ACTIONS(4726), 1,
      anon_sym_PIPE,
    ACTIONS(4730), 1,
      anon_sym_PERCENT,
    ACTIONS(4732), 1,
      anon_sym_STAR_STAR,
    ACTIONS(4740), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(4742), 1,
      sym__ternary_qmark,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4710), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(4712), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(4720), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(4728), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4736), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4738), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(5014), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
    ACTIONS(4734), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [90588] = 8,
    ACTIONS(1550), 1,
      anon_sym_DQUOTE,
    ACTIONS(1552), 1,
      anon_sym_SQUOTE,
    ACTIONS(4688), 1,
      anon_sym_LBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(5419), 2,
      sym_number,
      sym_private_property_identifier,
    STATE(3882), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(3814), 9,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_QMARK,
      anon_sym_PIPE_RBRACE,
    ACTIONS(2351), 23,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [90647] = 19,
    ACTIONS(231), 1,
      anon_sym_STAR,
    ACTIONS(1550), 1,
      anon_sym_DQUOTE,
    ACTIONS(1552), 1,
      anon_sym_SQUOTE,
    ACTIONS(2019), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(4688), 1,
      anon_sym_LBRACK,
    ACTIONS(5694), 1,
      anon_sym_async,
    ACTIONS(5696), 1,
      anon_sym_static,
    ACTIONS(5698), 1,
      anon_sym_readonly,
    ACTIONS(5704), 1,
      anon_sym_override,
    STATE(2786), 1,
      sym_accessibility_modifier,
    STATE(2808), 1,
      sym_override_modifier,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(5561), 2,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(5692), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
    ACTIONS(5700), 2,
      anon_sym_get,
      anon_sym_set,
    ACTIONS(5702), 3,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
    STATE(3688), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    STATE(5230), 3,
      sym_spread_element,
      sym_method_definition,
      sym_pair,
    ACTIONS(5690), 14,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_new,
      sym_identifier,
      anon_sym_declare,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [90728] = 7,
    ACTIONS(1696), 1,
      anon_sym_EQ,
    ACTIONS(2373), 1,
      anon_sym_extends,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4126), 2,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
    ACTIONS(4129), 2,
      anon_sym_AMP,
      anon_sym_PIPE,
    ACTIONS(1694), 11,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(1698), 23,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [90785] = 8,
    ACTIONS(1626), 1,
      anon_sym_DQUOTE,
    ACTIONS(1628), 1,
      anon_sym_SQUOTE,
    ACTIONS(4624), 1,
      anon_sym_LBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4840), 2,
      sym_number,
      sym_private_property_identifier,
    STATE(3368), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(3814), 9,
      sym__automatic_semicolon,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_BANG,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_QMARK,
    ACTIONS(3700), 23,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [90844] = 6,
    ACTIONS(4146), 1,
      anon_sym_EQ,
    ACTIONS(4850), 1,
      anon_sym_of,
    ACTIONS(5706), 1,
      anon_sym_in,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4144), 12,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4148), 25,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [90899] = 6,
    ACTIONS(3510), 1,
      anon_sym_EQ,
    ACTIONS(3681), 1,
      anon_sym_in,
    ACTIONS(3684), 1,
      anon_sym_of,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3492), 12,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(3496), 25,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [90954] = 8,
    ACTIONS(1550), 1,
      anon_sym_DQUOTE,
    ACTIONS(1552), 1,
      anon_sym_SQUOTE,
    ACTIONS(4688), 1,
      anon_sym_LBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(5364), 2,
      sym_number,
      sym_private_property_identifier,
    STATE(3798), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(3814), 9,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_QMARK,
      anon_sym_PIPE_RBRACE,
    ACTIONS(2351), 23,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [91013] = 32,
    ACTIONS(4588), 1,
      anon_sym_LPAREN,
    ACTIONS(4590), 1,
      anon_sym_LBRACK,
    ACTIONS(4592), 1,
      anon_sym_DOT,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4798), 1,
      anon_sym_as,
    ACTIONS(4800), 1,
      anon_sym_BANG,
    ACTIONS(4836), 1,
      anon_sym_satisfies,
    ACTIONS(5233), 1,
      anon_sym_LT,
    ACTIONS(5239), 1,
      anon_sym_AMP_AMP,
    ACTIONS(5241), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(5243), 1,
      anon_sym_GT_GT,
    ACTIONS(5247), 1,
      anon_sym_AMP,
    ACTIONS(5249), 1,
      anon_sym_CARET,
    ACTIONS(5251), 1,
      anon_sym_PIPE,
    ACTIONS(5255), 1,
      anon_sym_PERCENT,
    ACTIONS(5257), 1,
      anon_sym_STAR_STAR,
    ACTIONS(5265), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(5267), 1,
      sym__ternary_qmark,
    ACTIONS(5709), 1,
      anon_sym_SEMI,
    ACTIONS(5711), 1,
      sym__automatic_semicolon,
    STATE(2019), 1,
      sym_type_arguments,
    STATE(2130), 1,
      sym_arguments,
    STATE(4524), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(5235), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(5237), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(5245), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(5253), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(5261), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(5263), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(5259), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [91120] = 6,
    ACTIONS(4604), 1,
      anon_sym_EQ,
    ACTIONS(4854), 1,
      anon_sym_of,
    ACTIONS(5713), 1,
      anon_sym_in,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4602), 12,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4606), 25,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [91175] = 8,
    ACTIONS(1550), 1,
      anon_sym_DQUOTE,
    ACTIONS(1552), 1,
      anon_sym_SQUOTE,
    ACTIONS(4688), 1,
      anon_sym_LBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(5716), 2,
      sym_number,
      sym_private_property_identifier,
    STATE(3843), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(3814), 9,
      sym__automatic_semicolon,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_BANG,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_QMARK,
    ACTIONS(2351), 23,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [91234] = 13,
    ACTIONS(237), 1,
      anon_sym_COMMA,
    ACTIONS(692), 1,
      anon_sym_RBRACE,
    ACTIONS(1550), 1,
      anon_sym_DQUOTE,
    ACTIONS(1552), 1,
      anon_sym_SQUOTE,
    ACTIONS(4622), 1,
      anon_sym_EQ,
    ACTIONS(4688), 1,
      anon_sym_LBRACK,
    STATE(4810), 1,
      aux_sym_object_repeat1,
    STATE(4815), 1,
      aux_sym_object_pattern_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(2337), 2,
      sym_number,
      sym_private_property_identifier,
    STATE(3816), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(3814), 4,
      anon_sym_LPAREN,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_QMARK,
    ACTIONS(2351), 23,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [91303] = 31,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_as,
    ACTIONS(4640), 1,
      anon_sym_BANG,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4649), 1,
      anon_sym_satisfies,
    ACTIONS(4708), 1,
      anon_sym_LT,
    ACTIONS(4714), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4716), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4718), 1,
      anon_sym_GT_GT,
    ACTIONS(4722), 1,
      anon_sym_AMP,
    ACTIONS(4724), 1,
      anon_sym_CARET,
    ACTIONS(4726), 1,
      anon_sym_PIPE,
    ACTIONS(4730), 1,
      anon_sym_PERCENT,
    ACTIONS(4732), 1,
      anon_sym_STAR_STAR,
    ACTIONS(4740), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(4742), 1,
      sym__ternary_qmark,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4710), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(4712), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(4720), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(4728), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4736), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4738), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(5718), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK,
    ACTIONS(4734), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [91408] = 8,
    ACTIONS(1550), 1,
      anon_sym_DQUOTE,
    ACTIONS(1552), 1,
      anon_sym_SQUOTE,
    ACTIONS(4688), 1,
      anon_sym_LBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(5433), 2,
      sym_number,
      sym_private_property_identifier,
    STATE(3836), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(3814), 9,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_QMARK,
      anon_sym_PIPE_RBRACE,
    ACTIONS(2351), 23,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [91467] = 31,
    ACTIONS(4588), 1,
      anon_sym_LPAREN,
    ACTIONS(4590), 1,
      anon_sym_LBRACK,
    ACTIONS(4592), 1,
      anon_sym_DOT,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4798), 1,
      anon_sym_as,
    ACTIONS(4800), 1,
      anon_sym_BANG,
    ACTIONS(4836), 1,
      anon_sym_satisfies,
    ACTIONS(5233), 1,
      anon_sym_LT,
    ACTIONS(5239), 1,
      anon_sym_AMP_AMP,
    ACTIONS(5241), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(5243), 1,
      anon_sym_GT_GT,
    ACTIONS(5247), 1,
      anon_sym_AMP,
    ACTIONS(5249), 1,
      anon_sym_CARET,
    ACTIONS(5251), 1,
      anon_sym_PIPE,
    ACTIONS(5255), 1,
      anon_sym_PERCENT,
    ACTIONS(5257), 1,
      anon_sym_STAR_STAR,
    ACTIONS(5265), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(5267), 1,
      sym__ternary_qmark,
    STATE(2019), 1,
      sym_type_arguments,
    STATE(2130), 1,
      sym_arguments,
    STATE(4524), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(5235), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(5237), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(5245), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(5253), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(5261), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(5263), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(5720), 2,
      sym__automatic_semicolon,
      anon_sym_SEMI,
    ACTIONS(5259), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [91572] = 7,
    ACTIONS(4146), 1,
      anon_sym_EQ,
    ACTIONS(4156), 1,
      anon_sym_extends,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4150), 2,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
    ACTIONS(4153), 2,
      anon_sym_AMP,
      anon_sym_PIPE,
    ACTIONS(4144), 11,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4148), 23,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [91629] = 8,
    ACTIONS(1550), 1,
      anon_sym_DQUOTE,
    ACTIONS(1552), 1,
      anon_sym_SQUOTE,
    ACTIONS(4688), 1,
      anon_sym_LBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(5441), 2,
      sym_number,
      sym_private_property_identifier,
    STATE(3753), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(3814), 9,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_QMARK,
      anon_sym_PIPE_RBRACE,
    ACTIONS(2351), 23,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [91688] = 8,
    ACTIONS(1550), 1,
      anon_sym_DQUOTE,
    ACTIONS(1552), 1,
      anon_sym_SQUOTE,
    ACTIONS(4688), 1,
      anon_sym_LBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(5449), 2,
      sym_number,
      sym_private_property_identifier,
    STATE(3828), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(3814), 9,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_QMARK,
      anon_sym_PIPE_RBRACE,
    ACTIONS(2351), 23,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [91747] = 13,
    ACTIONS(237), 1,
      anon_sym_COMMA,
    ACTIONS(1550), 1,
      anon_sym_DQUOTE,
    ACTIONS(1552), 1,
      anon_sym_SQUOTE,
    ACTIONS(4622), 1,
      anon_sym_EQ,
    ACTIONS(4688), 1,
      anon_sym_LBRACK,
    ACTIONS(4992), 1,
      anon_sym_RBRACE,
    STATE(4792), 1,
      aux_sym_object_repeat1,
    STATE(4815), 1,
      aux_sym_object_pattern_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(2337), 2,
      sym_number,
      sym_private_property_identifier,
    STATE(3816), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(3814), 4,
      anon_sym_LPAREN,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_QMARK,
    ACTIONS(2351), 23,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [91816] = 24,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(5581), 1,
      anon_sym_STAR_STAR,
    ACTIONS(5590), 1,
      anon_sym_GT_GT,
    ACTIONS(5596), 1,
      anon_sym_PERCENT,
    ACTIONS(5598), 1,
      anon_sym_LT,
    ACTIONS(5606), 1,
      anon_sym_AMP,
    ACTIONS(5608), 1,
      anon_sym_CARET,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4762), 2,
      anon_sym_BANG,
      anon_sym_PIPE,
    ACTIONS(5586), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(5588), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(5592), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(5594), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(5612), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(5614), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(5600), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
    ACTIONS(4760), 8,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COLON,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [91907] = 15,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(5581), 1,
      anon_sym_STAR_STAR,
    ACTIONS(5583), 1,
      anon_sym_LT,
    ACTIONS(5596), 1,
      anon_sym_PERCENT,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(5586), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(4762), 10,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4760), 16,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COLON,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [91980] = 6,
    ACTIONS(1696), 1,
      anon_sym_EQ,
    ACTIONS(4859), 1,
      anon_sym_of,
    ACTIONS(5722), 1,
      anon_sym_in,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(1694), 12,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(1698), 25,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [92035] = 5,
    ACTIONS(3550), 1,
      anon_sym_EQ,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3614), 3,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_RBRACK,
    ACTIONS(3492), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(3496), 23,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [92088] = 31,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_as,
    ACTIONS(4640), 1,
      anon_sym_BANG,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4649), 1,
      anon_sym_satisfies,
    ACTIONS(4875), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4877), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4879), 1,
      anon_sym_GT_GT,
    ACTIONS(4883), 1,
      anon_sym_AMP,
    ACTIONS(4885), 1,
      anon_sym_CARET,
    ACTIONS(4887), 1,
      anon_sym_PIPE,
    ACTIONS(4891), 1,
      anon_sym_PERCENT,
    ACTIONS(4893), 1,
      anon_sym_STAR_STAR,
    ACTIONS(4895), 1,
      anon_sym_LT,
    ACTIONS(4903), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(4905), 1,
      sym__ternary_qmark,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4867), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(4873), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(4881), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(4889), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4899), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4901), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(5718), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    ACTIONS(4897), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [92193] = 4,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(1975), 6,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(3814), 11,
      sym__automatic_semicolon,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_BANG,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_QMARK,
      anon_sym_PIPE_RBRACE,
    ACTIONS(1973), 23,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [92244] = 8,
    ACTIONS(1550), 1,
      anon_sym_DQUOTE,
    ACTIONS(1552), 1,
      anon_sym_SQUOTE,
    ACTIONS(4688), 1,
      anon_sym_LBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(5477), 2,
      sym_number,
      sym_private_property_identifier,
    STATE(3898), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(3814), 9,
      sym__automatic_semicolon,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_BANG,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_QMARK,
    ACTIONS(2351), 23,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [92303] = 4,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(1730), 5,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACE,
    ACTIONS(1734), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(1736), 22,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_satisfies,
  [92354] = 32,
    ACTIONS(4588), 1,
      anon_sym_LPAREN,
    ACTIONS(4590), 1,
      anon_sym_LBRACK,
    ACTIONS(4592), 1,
      anon_sym_DOT,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4798), 1,
      anon_sym_as,
    ACTIONS(4800), 1,
      anon_sym_BANG,
    ACTIONS(4836), 1,
      anon_sym_satisfies,
    ACTIONS(5233), 1,
      anon_sym_LT,
    ACTIONS(5239), 1,
      anon_sym_AMP_AMP,
    ACTIONS(5241), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(5243), 1,
      anon_sym_GT_GT,
    ACTIONS(5247), 1,
      anon_sym_AMP,
    ACTIONS(5249), 1,
      anon_sym_CARET,
    ACTIONS(5251), 1,
      anon_sym_PIPE,
    ACTIONS(5255), 1,
      anon_sym_PERCENT,
    ACTIONS(5257), 1,
      anon_sym_STAR_STAR,
    ACTIONS(5265), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(5267), 1,
      sym__ternary_qmark,
    ACTIONS(5725), 1,
      anon_sym_SEMI,
    ACTIONS(5727), 1,
      sym__automatic_semicolon,
    STATE(2019), 1,
      sym_type_arguments,
    STATE(2130), 1,
      sym_arguments,
    STATE(4524), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(5235), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(5237), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(5245), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(5253), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(5261), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(5263), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(5259), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [92461] = 8,
    ACTIONS(1550), 1,
      anon_sym_DQUOTE,
    ACTIONS(1552), 1,
      anon_sym_SQUOTE,
    ACTIONS(4688), 1,
      anon_sym_LBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(5405), 2,
      sym_number,
      sym_private_property_identifier,
    STATE(3888), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(3814), 9,
      sym__automatic_semicolon,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_BANG,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_QMARK,
    ACTIONS(2351), 23,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [92520] = 7,
    ACTIONS(3642), 1,
      anon_sym_EQ,
    ACTIONS(4608), 1,
      anon_sym_LBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4408), 2,
      anon_sym_COMMA,
      anon_sym_extends,
    ACTIONS(4611), 3,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_GT,
    ACTIONS(3492), 10,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(3496), 23,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [92577] = 13,
    ACTIONS(237), 1,
      anon_sym_COMMA,
    ACTIONS(1550), 1,
      anon_sym_DQUOTE,
    ACTIONS(1552), 1,
      anon_sym_SQUOTE,
    ACTIONS(4622), 1,
      anon_sym_EQ,
    ACTIONS(4688), 1,
      anon_sym_LBRACK,
    ACTIONS(5051), 1,
      anon_sym_RBRACE,
    STATE(4792), 1,
      aux_sym_object_repeat1,
    STATE(4815), 1,
      aux_sym_object_pattern_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(2337), 2,
      sym_number,
      sym_private_property_identifier,
    STATE(3816), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(3814), 4,
      anon_sym_LPAREN,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_QMARK,
    ACTIONS(2351), 23,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [92646] = 8,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(5598), 1,
      anon_sym_LT,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4704), 12,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4706), 23,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [92705] = 8,
    ACTIONS(1550), 1,
      anon_sym_DQUOTE,
    ACTIONS(1552), 1,
      anon_sym_SQUOTE,
    ACTIONS(4688), 1,
      anon_sym_LBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(5300), 2,
      sym_number,
      sym_private_property_identifier,
    STATE(3780), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(3814), 9,
      sym__automatic_semicolon,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_BANG,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_QMARK,
    ACTIONS(2351), 23,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [92764] = 7,
    ACTIONS(3510), 1,
      anon_sym_EQ,
    ACTIONS(4408), 1,
      anon_sym_extends,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4608), 2,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
    ACTIONS(4611), 2,
      anon_sym_AMP,
      anon_sym_PIPE,
    ACTIONS(3492), 11,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(3496), 23,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [92821] = 8,
    ACTIONS(1550), 1,
      anon_sym_DQUOTE,
    ACTIONS(1552), 1,
      anon_sym_SQUOTE,
    ACTIONS(4688), 1,
      anon_sym_LBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(5547), 2,
      sym_number,
      sym_private_property_identifier,
    STATE(3851), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(3814), 9,
      sym__automatic_semicolon,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_BANG,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_QMARK,
    ACTIONS(2351), 23,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [92880] = 7,
    ACTIONS(3516), 1,
      anon_sym_DOT,
    ACTIONS(3520), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3522), 3,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_QMARK,
    ACTIONS(3512), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_extends,
    ACTIONS(3492), 11,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(3496), 20,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [92937] = 8,
    ACTIONS(1550), 1,
      anon_sym_DQUOTE,
    ACTIONS(1552), 1,
      anon_sym_SQUOTE,
    ACTIONS(4688), 1,
      anon_sym_LBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(5346), 2,
      sym_number,
      sym_private_property_identifier,
    STATE(3845), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(3814), 9,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_QMARK,
      anon_sym_PIPE_RBRACE,
    ACTIONS(2351), 23,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [92996] = 5,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4184), 3,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_QMARK,
    ACTIONS(4182), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_extends,
    ACTIONS(3492), 11,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(3496), 22,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [93049] = 31,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_as,
    ACTIONS(4640), 1,
      anon_sym_BANG,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4649), 1,
      anon_sym_satisfies,
    ACTIONS(5581), 1,
      anon_sym_STAR_STAR,
    ACTIONS(5590), 1,
      anon_sym_GT_GT,
    ACTIONS(5596), 1,
      anon_sym_PERCENT,
    ACTIONS(5598), 1,
      anon_sym_LT,
    ACTIONS(5602), 1,
      anon_sym_AMP_AMP,
    ACTIONS(5604), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(5606), 1,
      anon_sym_AMP,
    ACTIONS(5608), 1,
      anon_sym_CARET,
    ACTIONS(5610), 1,
      anon_sym_PIPE,
    ACTIONS(5616), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(5618), 1,
      sym__ternary_qmark,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4468), 2,
      anon_sym_COLON,
      anon_sym_BQUOTE,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(5586), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(5588), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(5592), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(5594), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(5612), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(5614), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(5600), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [93154] = 8,
    ACTIONS(1550), 1,
      anon_sym_DQUOTE,
    ACTIONS(1552), 1,
      anon_sym_SQUOTE,
    ACTIONS(4688), 1,
      anon_sym_LBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(5376), 2,
      sym_number,
      sym_private_property_identifier,
    STATE(3781), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(3814), 9,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_QMARK,
      anon_sym_PIPE_RBRACE,
    ACTIONS(2351), 23,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [93213] = 31,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_as,
    ACTIONS(4640), 1,
      anon_sym_BANG,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4649), 1,
      anon_sym_satisfies,
    ACTIONS(4875), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4877), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4879), 1,
      anon_sym_GT_GT,
    ACTIONS(4883), 1,
      anon_sym_AMP,
    ACTIONS(4885), 1,
      anon_sym_CARET,
    ACTIONS(4887), 1,
      anon_sym_PIPE,
    ACTIONS(4891), 1,
      anon_sym_PERCENT,
    ACTIONS(4893), 1,
      anon_sym_STAR_STAR,
    ACTIONS(4895), 1,
      anon_sym_LT,
    ACTIONS(4903), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(4905), 1,
      sym__ternary_qmark,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4852), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    ACTIONS(4867), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(4873), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(4881), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(4889), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4899), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4901), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(4897), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [93318] = 31,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_as,
    ACTIONS(4640), 1,
      anon_sym_BANG,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4649), 1,
      anon_sym_satisfies,
    ACTIONS(5581), 1,
      anon_sym_STAR_STAR,
    ACTIONS(5590), 1,
      anon_sym_GT_GT,
    ACTIONS(5596), 1,
      anon_sym_PERCENT,
    ACTIONS(5598), 1,
      anon_sym_LT,
    ACTIONS(5602), 1,
      anon_sym_AMP_AMP,
    ACTIONS(5604), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(5606), 1,
      anon_sym_AMP,
    ACTIONS(5608), 1,
      anon_sym_CARET,
    ACTIONS(5610), 1,
      anon_sym_PIPE,
    ACTIONS(5616), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(5618), 1,
      sym__ternary_qmark,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4744), 2,
      anon_sym_COLON,
      anon_sym_BQUOTE,
    ACTIONS(5586), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(5588), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(5592), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(5594), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(5612), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(5614), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(5600), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [93423] = 31,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_as,
    ACTIONS(4640), 1,
      anon_sym_BANG,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4649), 1,
      anon_sym_satisfies,
    ACTIONS(5581), 1,
      anon_sym_STAR_STAR,
    ACTIONS(5590), 1,
      anon_sym_GT_GT,
    ACTIONS(5596), 1,
      anon_sym_PERCENT,
    ACTIONS(5598), 1,
      anon_sym_LT,
    ACTIONS(5602), 1,
      anon_sym_AMP_AMP,
    ACTIONS(5604), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(5606), 1,
      anon_sym_AMP,
    ACTIONS(5608), 1,
      anon_sym_CARET,
    ACTIONS(5610), 1,
      anon_sym_PIPE,
    ACTIONS(5616), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(5618), 1,
      sym__ternary_qmark,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4756), 2,
      anon_sym_COLON,
      anon_sym_BQUOTE,
    ACTIONS(5586), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(5588), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(5592), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(5594), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(5612), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(5614), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(5600), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [93528] = 7,
    ACTIONS(4104), 1,
      anon_sym_QMARK,
    ACTIONS(4106), 1,
      anon_sym_extends,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4513), 2,
      anon_sym_AMP,
      anon_sym_PIPE,
    ACTIONS(4510), 3,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
    ACTIONS(3492), 11,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(3496), 22,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [93585] = 31,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_as,
    ACTIONS(4640), 1,
      anon_sym_BANG,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4649), 1,
      anon_sym_satisfies,
    ACTIONS(5581), 1,
      anon_sym_STAR_STAR,
    ACTIONS(5590), 1,
      anon_sym_GT_GT,
    ACTIONS(5596), 1,
      anon_sym_PERCENT,
    ACTIONS(5598), 1,
      anon_sym_LT,
    ACTIONS(5602), 1,
      anon_sym_AMP_AMP,
    ACTIONS(5604), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(5606), 1,
      anon_sym_AMP,
    ACTIONS(5608), 1,
      anon_sym_CARET,
    ACTIONS(5610), 1,
      anon_sym_PIPE,
    ACTIONS(5616), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(5618), 1,
      sym__ternary_qmark,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4758), 2,
      anon_sym_COLON,
      anon_sym_BQUOTE,
    ACTIONS(5586), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(5588), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(5592), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(5594), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(5612), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(5614), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(5600), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [93690] = 4,
    ACTIONS(3601), 1,
      anon_sym_EQ,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3492), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(3496), 26,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [93741] = 13,
    ACTIONS(237), 1,
      anon_sym_COMMA,
    ACTIONS(1550), 1,
      anon_sym_DQUOTE,
    ACTIONS(1552), 1,
      anon_sym_SQUOTE,
    ACTIONS(4622), 1,
      anon_sym_EQ,
    ACTIONS(4688), 1,
      anon_sym_LBRACK,
    ACTIONS(5053), 1,
      anon_sym_RBRACE,
    STATE(4792), 1,
      aux_sym_object_repeat1,
    STATE(4815), 1,
      aux_sym_object_pattern_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(2337), 2,
      sym_number,
      sym_private_property_identifier,
    STATE(3816), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(3814), 4,
      anon_sym_LPAREN,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_QMARK,
    ACTIONS(2351), 23,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [93810] = 31,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_as,
    ACTIONS(4640), 1,
      anon_sym_BANG,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4649), 1,
      anon_sym_satisfies,
    ACTIONS(5581), 1,
      anon_sym_STAR_STAR,
    ACTIONS(5590), 1,
      anon_sym_GT_GT,
    ACTIONS(5596), 1,
      anon_sym_PERCENT,
    ACTIONS(5598), 1,
      anon_sym_LT,
    ACTIONS(5602), 1,
      anon_sym_AMP_AMP,
    ACTIONS(5604), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(5606), 1,
      anon_sym_AMP,
    ACTIONS(5608), 1,
      anon_sym_CARET,
    ACTIONS(5610), 1,
      anon_sym_PIPE,
    ACTIONS(5616), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(5618), 1,
      sym__ternary_qmark,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4504), 2,
      anon_sym_COLON,
      anon_sym_BQUOTE,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(5586), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(5588), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(5592), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(5594), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(5612), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(5614), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(5600), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [93915] = 8,
    ACTIONS(1550), 1,
      anon_sym_DQUOTE,
    ACTIONS(1552), 1,
      anon_sym_SQUOTE,
    ACTIONS(4688), 1,
      anon_sym_LBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(5539), 2,
      sym_number,
      sym_private_property_identifier,
    STATE(3890), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(3814), 9,
      sym__automatic_semicolon,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_BANG,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_QMARK,
    ACTIONS(2351), 23,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [93974] = 6,
    ACTIONS(4608), 1,
      anon_sym_LBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4408), 2,
      anon_sym_COMMA,
      anon_sym_extends,
    ACTIONS(4611), 3,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_GT,
    ACTIONS(3492), 10,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(3496), 24,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [94029] = 6,
    ACTIONS(4510), 1,
      anon_sym_LBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4106), 2,
      anon_sym_COMMA,
      anon_sym_extends,
    ACTIONS(4513), 3,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_GT,
    ACTIONS(3492), 10,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(3496), 24,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [94084] = 23,
    ACTIONS(1626), 1,
      anon_sym_DQUOTE,
    ACTIONS(1628), 1,
      anon_sym_SQUOTE,
    ACTIONS(3722), 1,
      anon_sym_override,
    ACTIONS(3828), 1,
      anon_sym_AT,
    ACTIONS(4624), 1,
      anon_sym_LBRACK,
    ACTIONS(5729), 1,
      anon_sym_STAR,
    ACTIONS(5731), 1,
      anon_sym_async,
    ACTIONS(5735), 1,
      anon_sym_static,
    ACTIONS(5737), 1,
      anon_sym_readonly,
    ACTIONS(5741), 1,
      anon_sym_declare,
    ACTIONS(5743), 1,
      anon_sym_abstract,
    ACTIONS(5745), 1,
      anon_sym_accessor,
    STATE(2699), 1,
      sym_method_definition,
    STATE(2732), 1,
      sym_accessibility_modifier,
    STATE(2761), 1,
      aux_sym_export_statement_repeat1,
    STATE(2802), 1,
      sym_decorator,
    STATE(2811), 1,
      sym_override_modifier,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(5733), 2,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(5739), 2,
      anon_sym_get,
      anon_sym_set,
    ACTIONS(3720), 3,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
    STATE(3045), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(3700), 13,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_new,
      sym_identifier,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [94173] = 18,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(5581), 1,
      anon_sym_STAR_STAR,
    ACTIONS(5590), 1,
      anon_sym_GT_GT,
    ACTIONS(5596), 1,
      anon_sym_PERCENT,
    ACTIONS(5598), 1,
      anon_sym_LT,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(5586), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(5592), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(5594), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4762), 7,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4760), 14,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COLON,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [94252] = 6,
    ACTIONS(4614), 1,
      anon_sym_LBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4378), 2,
      anon_sym_COMMA,
      anon_sym_extends,
    ACTIONS(4617), 3,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_GT,
    ACTIONS(4458), 10,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4460), 24,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [94307] = 13,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(5581), 1,
      anon_sym_STAR_STAR,
    ACTIONS(5583), 1,
      anon_sym_LT,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4762), 12,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4760), 17,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COLON,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [94376] = 25,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4762), 1,
      anon_sym_BANG,
    ACTIONS(5581), 1,
      anon_sym_STAR_STAR,
    ACTIONS(5590), 1,
      anon_sym_GT_GT,
    ACTIONS(5596), 1,
      anon_sym_PERCENT,
    ACTIONS(5598), 1,
      anon_sym_LT,
    ACTIONS(5606), 1,
      anon_sym_AMP,
    ACTIONS(5608), 1,
      anon_sym_CARET,
    ACTIONS(5610), 1,
      anon_sym_PIPE,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(5586), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(5588), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(5592), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(5594), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(5612), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(5614), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(5600), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
    ACTIONS(4760), 8,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COLON,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [94469] = 26,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4762), 1,
      anon_sym_BANG,
    ACTIONS(5581), 1,
      anon_sym_STAR_STAR,
    ACTIONS(5590), 1,
      anon_sym_GT_GT,
    ACTIONS(5596), 1,
      anon_sym_PERCENT,
    ACTIONS(5598), 1,
      anon_sym_LT,
    ACTIONS(5602), 1,
      anon_sym_AMP_AMP,
    ACTIONS(5606), 1,
      anon_sym_AMP,
    ACTIONS(5608), 1,
      anon_sym_CARET,
    ACTIONS(5610), 1,
      anon_sym_PIPE,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(5586), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(5588), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(5592), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(5594), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(5612), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(5614), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(5600), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
    ACTIONS(4760), 7,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COLON,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [94564] = 8,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(5747), 1,
      anon_sym_LT,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4704), 12,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4706), 23,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_of,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [94623] = 31,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_as,
    ACTIONS(4640), 1,
      anon_sym_BANG,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4649), 1,
      anon_sym_satisfies,
    ACTIONS(5747), 1,
      anon_sym_LT,
    ACTIONS(5753), 1,
      anon_sym_AMP_AMP,
    ACTIONS(5755), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(5757), 1,
      anon_sym_GT_GT,
    ACTIONS(5761), 1,
      anon_sym_AMP,
    ACTIONS(5763), 1,
      anon_sym_CARET,
    ACTIONS(5765), 1,
      anon_sym_PIPE,
    ACTIONS(5769), 1,
      anon_sym_PERCENT,
    ACTIONS(5771), 1,
      anon_sym_STAR_STAR,
    ACTIONS(5779), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(5781), 1,
      sym__ternary_qmark,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4468), 2,
      anon_sym_of,
      anon_sym_BQUOTE,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(5749), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(5751), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(5759), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(5767), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(5775), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(5777), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(5773), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [94728] = 31,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_as,
    ACTIONS(4640), 1,
      anon_sym_BANG,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4649), 1,
      anon_sym_satisfies,
    ACTIONS(5747), 1,
      anon_sym_LT,
    ACTIONS(5753), 1,
      anon_sym_AMP_AMP,
    ACTIONS(5755), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(5757), 1,
      anon_sym_GT_GT,
    ACTIONS(5761), 1,
      anon_sym_AMP,
    ACTIONS(5763), 1,
      anon_sym_CARET,
    ACTIONS(5765), 1,
      anon_sym_PIPE,
    ACTIONS(5769), 1,
      anon_sym_PERCENT,
    ACTIONS(5771), 1,
      anon_sym_STAR_STAR,
    ACTIONS(5779), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(5781), 1,
      sym__ternary_qmark,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4744), 2,
      anon_sym_of,
      anon_sym_BQUOTE,
    ACTIONS(5749), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(5751), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(5759), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(5767), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(5775), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(5777), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(5773), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [94833] = 31,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_as,
    ACTIONS(4640), 1,
      anon_sym_BANG,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4649), 1,
      anon_sym_satisfies,
    ACTIONS(5747), 1,
      anon_sym_LT,
    ACTIONS(5753), 1,
      anon_sym_AMP_AMP,
    ACTIONS(5755), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(5757), 1,
      anon_sym_GT_GT,
    ACTIONS(5761), 1,
      anon_sym_AMP,
    ACTIONS(5763), 1,
      anon_sym_CARET,
    ACTIONS(5765), 1,
      anon_sym_PIPE,
    ACTIONS(5769), 1,
      anon_sym_PERCENT,
    ACTIONS(5771), 1,
      anon_sym_STAR_STAR,
    ACTIONS(5779), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(5781), 1,
      sym__ternary_qmark,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4756), 2,
      anon_sym_of,
      anon_sym_BQUOTE,
    ACTIONS(5749), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(5751), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(5759), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(5767), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(5775), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(5777), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(5773), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [94938] = 31,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_as,
    ACTIONS(4640), 1,
      anon_sym_BANG,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4649), 1,
      anon_sym_satisfies,
    ACTIONS(5747), 1,
      anon_sym_LT,
    ACTIONS(5753), 1,
      anon_sym_AMP_AMP,
    ACTIONS(5755), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(5757), 1,
      anon_sym_GT_GT,
    ACTIONS(5761), 1,
      anon_sym_AMP,
    ACTIONS(5763), 1,
      anon_sym_CARET,
    ACTIONS(5765), 1,
      anon_sym_PIPE,
    ACTIONS(5769), 1,
      anon_sym_PERCENT,
    ACTIONS(5771), 1,
      anon_sym_STAR_STAR,
    ACTIONS(5779), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(5781), 1,
      sym__ternary_qmark,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4758), 2,
      anon_sym_of,
      anon_sym_BQUOTE,
    ACTIONS(5749), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(5751), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(5759), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(5767), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(5775), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(5777), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(5773), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [95043] = 31,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_as,
    ACTIONS(4640), 1,
      anon_sym_BANG,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4649), 1,
      anon_sym_satisfies,
    ACTIONS(5747), 1,
      anon_sym_LT,
    ACTIONS(5753), 1,
      anon_sym_AMP_AMP,
    ACTIONS(5755), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(5757), 1,
      anon_sym_GT_GT,
    ACTIONS(5761), 1,
      anon_sym_AMP,
    ACTIONS(5763), 1,
      anon_sym_CARET,
    ACTIONS(5765), 1,
      anon_sym_PIPE,
    ACTIONS(5769), 1,
      anon_sym_PERCENT,
    ACTIONS(5771), 1,
      anon_sym_STAR_STAR,
    ACTIONS(5779), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(5781), 1,
      sym__ternary_qmark,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4504), 2,
      anon_sym_of,
      anon_sym_BQUOTE,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(5749), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(5751), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(5759), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(5767), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(5775), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(5777), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(5773), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [95148] = 18,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(5747), 1,
      anon_sym_LT,
    ACTIONS(5757), 1,
      anon_sym_GT_GT,
    ACTIONS(5769), 1,
      anon_sym_PERCENT,
    ACTIONS(5771), 1,
      anon_sym_STAR_STAR,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(5749), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(5759), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(5767), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4762), 7,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4760), 14,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_of,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [95227] = 13,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(5771), 1,
      anon_sym_STAR_STAR,
    ACTIONS(5783), 1,
      anon_sym_LT,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4762), 12,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4760), 17,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_of,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [95296] = 25,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4762), 1,
      anon_sym_BANG,
    ACTIONS(5747), 1,
      anon_sym_LT,
    ACTIONS(5757), 1,
      anon_sym_GT_GT,
    ACTIONS(5761), 1,
      anon_sym_AMP,
    ACTIONS(5763), 1,
      anon_sym_CARET,
    ACTIONS(5765), 1,
      anon_sym_PIPE,
    ACTIONS(5769), 1,
      anon_sym_PERCENT,
    ACTIONS(5771), 1,
      anon_sym_STAR_STAR,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(5749), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(5751), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(5759), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(5767), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(5775), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(5777), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(5773), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
    ACTIONS(4760), 8,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_of,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [95389] = 26,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4762), 1,
      anon_sym_BANG,
    ACTIONS(5747), 1,
      anon_sym_LT,
    ACTIONS(5753), 1,
      anon_sym_AMP_AMP,
    ACTIONS(5757), 1,
      anon_sym_GT_GT,
    ACTIONS(5761), 1,
      anon_sym_AMP,
    ACTIONS(5763), 1,
      anon_sym_CARET,
    ACTIONS(5765), 1,
      anon_sym_PIPE,
    ACTIONS(5769), 1,
      anon_sym_PERCENT,
    ACTIONS(5771), 1,
      anon_sym_STAR_STAR,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(5749), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(5751), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(5759), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(5767), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(5775), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(5777), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(5773), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
    ACTIONS(4760), 7,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_of,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [95484] = 16,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(5769), 1,
      anon_sym_PERCENT,
    ACTIONS(5771), 1,
      anon_sym_STAR_STAR,
    ACTIONS(5783), 1,
      anon_sym_LT,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(5749), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(5767), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4762), 8,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4760), 16,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_of,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [95559] = 22,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(5747), 1,
      anon_sym_LT,
    ACTIONS(5757), 1,
      anon_sym_GT_GT,
    ACTIONS(5769), 1,
      anon_sym_PERCENT,
    ACTIONS(5771), 1,
      anon_sym_STAR_STAR,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(5749), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(5751), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(5759), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(5767), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(5775), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(5777), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(4762), 3,
      anon_sym_BANG,
      anon_sym_AMP,
      anon_sym_PIPE,
    ACTIONS(5773), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
    ACTIONS(4760), 9,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_of,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_CARET,
      anon_sym_QMARK_QMARK,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [95646] = 23,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(5747), 1,
      anon_sym_LT,
    ACTIONS(5757), 1,
      anon_sym_GT_GT,
    ACTIONS(5761), 1,
      anon_sym_AMP,
    ACTIONS(5769), 1,
      anon_sym_PERCENT,
    ACTIONS(5771), 1,
      anon_sym_STAR_STAR,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4762), 2,
      anon_sym_BANG,
      anon_sym_PIPE,
    ACTIONS(5749), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(5751), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(5759), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(5767), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(5775), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(5777), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(5773), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
    ACTIONS(4760), 9,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_of,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_CARET,
      anon_sym_QMARK_QMARK,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [95735] = 24,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(5747), 1,
      anon_sym_LT,
    ACTIONS(5757), 1,
      anon_sym_GT_GT,
    ACTIONS(5761), 1,
      anon_sym_AMP,
    ACTIONS(5763), 1,
      anon_sym_CARET,
    ACTIONS(5769), 1,
      anon_sym_PERCENT,
    ACTIONS(5771), 1,
      anon_sym_STAR_STAR,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4762), 2,
      anon_sym_BANG,
      anon_sym_PIPE,
    ACTIONS(5749), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(5751), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(5759), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(5767), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(5775), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(5777), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(5773), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
    ACTIONS(4760), 8,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_of,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [95826] = 15,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(5769), 1,
      anon_sym_PERCENT,
    ACTIONS(5771), 1,
      anon_sym_STAR_STAR,
    ACTIONS(5783), 1,
      anon_sym_LT,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(5749), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(4762), 10,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4760), 16,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_of,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [95899] = 16,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_as,
    ACTIONS(4640), 1,
      anon_sym_BANG,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4649), 1,
      anon_sym_satisfies,
    ACTIONS(5771), 1,
      anon_sym_STAR_STAR,
    ACTIONS(5783), 1,
      anon_sym_LT,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4762), 11,
      anon_sym_STAR,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4760), 15,
      sym__ternary_qmark,
      anon_sym_of,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_BQUOTE,
  [95974] = 20,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(5747), 1,
      anon_sym_LT,
    ACTIONS(5757), 1,
      anon_sym_GT_GT,
    ACTIONS(5769), 1,
      anon_sym_PERCENT,
    ACTIONS(5771), 1,
      anon_sym_STAR_STAR,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(5749), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(5751), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(5759), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(5767), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(5773), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
    ACTIONS(4762), 5,
      anon_sym_BANG,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4760), 11,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_of,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_CARET,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [96057] = 27,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4762), 1,
      anon_sym_BANG,
    ACTIONS(5747), 1,
      anon_sym_LT,
    ACTIONS(5753), 1,
      anon_sym_AMP_AMP,
    ACTIONS(5755), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(5757), 1,
      anon_sym_GT_GT,
    ACTIONS(5761), 1,
      anon_sym_AMP,
    ACTIONS(5763), 1,
      anon_sym_CARET,
    ACTIONS(5765), 1,
      anon_sym_PIPE,
    ACTIONS(5769), 1,
      anon_sym_PERCENT,
    ACTIONS(5771), 1,
      anon_sym_STAR_STAR,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(5749), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(5751), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(5759), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(5767), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(5775), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(5777), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(5773), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
    ACTIONS(4760), 6,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_of,
      anon_sym_QMARK_QMARK,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [96154] = 31,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_as,
    ACTIONS(4640), 1,
      anon_sym_BANG,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4649), 1,
      anon_sym_satisfies,
    ACTIONS(5747), 1,
      anon_sym_LT,
    ACTIONS(5753), 1,
      anon_sym_AMP_AMP,
    ACTIONS(5755), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(5757), 1,
      anon_sym_GT_GT,
    ACTIONS(5761), 1,
      anon_sym_AMP,
    ACTIONS(5763), 1,
      anon_sym_CARET,
    ACTIONS(5765), 1,
      anon_sym_PIPE,
    ACTIONS(5769), 1,
      anon_sym_PERCENT,
    ACTIONS(5771), 1,
      anon_sym_STAR_STAR,
    ACTIONS(5779), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(5781), 1,
      sym__ternary_qmark,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4522), 2,
      anon_sym_of,
      anon_sym_BQUOTE,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(5749), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(5751), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(5759), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(5767), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(5775), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(5777), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(5773), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [96259] = 31,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_as,
    ACTIONS(4640), 1,
      anon_sym_BANG,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4649), 1,
      anon_sym_satisfies,
    ACTIONS(5747), 1,
      anon_sym_LT,
    ACTIONS(5753), 1,
      anon_sym_AMP_AMP,
    ACTIONS(5755), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(5757), 1,
      anon_sym_GT_GT,
    ACTIONS(5761), 1,
      anon_sym_AMP,
    ACTIONS(5763), 1,
      anon_sym_CARET,
    ACTIONS(5765), 1,
      anon_sym_PIPE,
    ACTIONS(5769), 1,
      anon_sym_PERCENT,
    ACTIONS(5771), 1,
      anon_sym_STAR_STAR,
    ACTIONS(5779), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(5781), 1,
      sym__ternary_qmark,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4767), 2,
      anon_sym_of,
      anon_sym_BQUOTE,
    ACTIONS(5749), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(5751), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(5759), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(5767), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(5775), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(5777), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(5773), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [96364] = 31,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_as,
    ACTIONS(4640), 1,
      anon_sym_BANG,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4649), 1,
      anon_sym_satisfies,
    ACTIONS(5747), 1,
      anon_sym_LT,
    ACTIONS(5753), 1,
      anon_sym_AMP_AMP,
    ACTIONS(5755), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(5757), 1,
      anon_sym_GT_GT,
    ACTIONS(5761), 1,
      anon_sym_AMP,
    ACTIONS(5763), 1,
      anon_sym_CARET,
    ACTIONS(5765), 1,
      anon_sym_PIPE,
    ACTIONS(5769), 1,
      anon_sym_PERCENT,
    ACTIONS(5771), 1,
      anon_sym_STAR_STAR,
    ACTIONS(5779), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(5781), 1,
      sym__ternary_qmark,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4546), 2,
      anon_sym_of,
      anon_sym_BQUOTE,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(5749), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(5751), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(5759), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(5767), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(5775), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(5777), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(5773), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [96469] = 31,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_as,
    ACTIONS(4640), 1,
      anon_sym_BANG,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4649), 1,
      anon_sym_satisfies,
    ACTIONS(5747), 1,
      anon_sym_LT,
    ACTIONS(5753), 1,
      anon_sym_AMP_AMP,
    ACTIONS(5755), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(5757), 1,
      anon_sym_GT_GT,
    ACTIONS(5761), 1,
      anon_sym_AMP,
    ACTIONS(5763), 1,
      anon_sym_CARET,
    ACTIONS(5765), 1,
      anon_sym_PIPE,
    ACTIONS(5769), 1,
      anon_sym_PERCENT,
    ACTIONS(5771), 1,
      anon_sym_STAR_STAR,
    ACTIONS(5779), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(5781), 1,
      sym__ternary_qmark,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4554), 2,
      anon_sym_of,
      anon_sym_BQUOTE,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(5749), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(5751), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(5759), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(5767), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(5775), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(5777), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(5773), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [96574] = 31,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_as,
    ACTIONS(4640), 1,
      anon_sym_BANG,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4649), 1,
      anon_sym_satisfies,
    ACTIONS(5747), 1,
      anon_sym_LT,
    ACTIONS(5753), 1,
      anon_sym_AMP_AMP,
    ACTIONS(5755), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(5757), 1,
      anon_sym_GT_GT,
    ACTIONS(5761), 1,
      anon_sym_AMP,
    ACTIONS(5763), 1,
      anon_sym_CARET,
    ACTIONS(5765), 1,
      anon_sym_PIPE,
    ACTIONS(5769), 1,
      anon_sym_PERCENT,
    ACTIONS(5771), 1,
      anon_sym_STAR_STAR,
    ACTIONS(5779), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(5781), 1,
      sym__ternary_qmark,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4558), 2,
      anon_sym_of,
      anon_sym_BQUOTE,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(5749), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(5751), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(5759), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(5767), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(5775), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(5777), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(5773), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [96679] = 31,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_as,
    ACTIONS(4640), 1,
      anon_sym_BANG,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4649), 1,
      anon_sym_satisfies,
    ACTIONS(5747), 1,
      anon_sym_LT,
    ACTIONS(5753), 1,
      anon_sym_AMP_AMP,
    ACTIONS(5755), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(5757), 1,
      anon_sym_GT_GT,
    ACTIONS(5761), 1,
      anon_sym_AMP,
    ACTIONS(5763), 1,
      anon_sym_CARET,
    ACTIONS(5765), 1,
      anon_sym_PIPE,
    ACTIONS(5769), 1,
      anon_sym_PERCENT,
    ACTIONS(5771), 1,
      anon_sym_STAR_STAR,
    ACTIONS(5779), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(5781), 1,
      sym__ternary_qmark,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4769), 2,
      anon_sym_of,
      anon_sym_BQUOTE,
    ACTIONS(5749), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(5751), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(5759), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(5767), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(5775), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(5777), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(5773), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [96784] = 31,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_as,
    ACTIONS(4640), 1,
      anon_sym_BANG,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4649), 1,
      anon_sym_satisfies,
    ACTIONS(5747), 1,
      anon_sym_LT,
    ACTIONS(5753), 1,
      anon_sym_AMP_AMP,
    ACTIONS(5755), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(5757), 1,
      anon_sym_GT_GT,
    ACTIONS(5761), 1,
      anon_sym_AMP,
    ACTIONS(5763), 1,
      anon_sym_CARET,
    ACTIONS(5765), 1,
      anon_sym_PIPE,
    ACTIONS(5769), 1,
      anon_sym_PERCENT,
    ACTIONS(5771), 1,
      anon_sym_STAR_STAR,
    ACTIONS(5779), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(5781), 1,
      sym__ternary_qmark,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4771), 2,
      anon_sym_of,
      anon_sym_BQUOTE,
    ACTIONS(5749), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(5751), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(5759), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(5767), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(5775), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(5777), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(5773), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [96889] = 31,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_as,
    ACTIONS(4640), 1,
      anon_sym_BANG,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4649), 1,
      anon_sym_satisfies,
    ACTIONS(5747), 1,
      anon_sym_LT,
    ACTIONS(5753), 1,
      anon_sym_AMP_AMP,
    ACTIONS(5755), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(5757), 1,
      anon_sym_GT_GT,
    ACTIONS(5761), 1,
      anon_sym_AMP,
    ACTIONS(5763), 1,
      anon_sym_CARET,
    ACTIONS(5765), 1,
      anon_sym_PIPE,
    ACTIONS(5769), 1,
      anon_sym_PERCENT,
    ACTIONS(5771), 1,
      anon_sym_STAR_STAR,
    ACTIONS(5779), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(5781), 1,
      sym__ternary_qmark,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4773), 2,
      anon_sym_of,
      anon_sym_BQUOTE,
    ACTIONS(5749), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(5751), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(5759), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(5767), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(5775), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(5777), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(5773), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [96994] = 8,
    ACTIONS(1550), 1,
      anon_sym_DQUOTE,
    ACTIONS(1552), 1,
      anon_sym_SQUOTE,
    ACTIONS(4688), 1,
      anon_sym_LBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(5411), 2,
      sym_number,
      sym_private_property_identifier,
    STATE(3874), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(3814), 9,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_QMARK,
      anon_sym_PIPE_RBRACE,
    ACTIONS(2351), 23,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [97053] = 6,
    ACTIONS(4604), 1,
      anon_sym_EQ,
    ACTIONS(4854), 1,
      anon_sym_COLON,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4671), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK,
    ACTIONS(4602), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4606), 23,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [97108] = 16,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(5581), 1,
      anon_sym_STAR_STAR,
    ACTIONS(5583), 1,
      anon_sym_LT,
    ACTIONS(5596), 1,
      anon_sym_PERCENT,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(5586), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(5594), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4762), 8,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4760), 16,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COLON,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [97183] = 4,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(1730), 2,
      anon_sym_else,
      anon_sym_while,
    ACTIONS(1734), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(1736), 25,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_satisfies,
  [97234] = 12,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(5786), 1,
      anon_sym_LT,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4778), 12,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4780), 18,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_of,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [97301] = 15,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_as,
    ACTIONS(4640), 1,
      anon_sym_BANG,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4649), 1,
      anon_sym_satisfies,
    ACTIONS(5789), 1,
      anon_sym_LT,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4634), 11,
      anon_sym_STAR,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4638), 16,
      sym__ternary_qmark,
      anon_sym_of,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_BQUOTE,
  [97374] = 31,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_as,
    ACTIONS(4640), 1,
      anon_sym_BANG,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4649), 1,
      anon_sym_satisfies,
    ACTIONS(5747), 1,
      anon_sym_LT,
    ACTIONS(5753), 1,
      anon_sym_AMP_AMP,
    ACTIONS(5755), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(5757), 1,
      anon_sym_GT_GT,
    ACTIONS(5761), 1,
      anon_sym_AMP,
    ACTIONS(5763), 1,
      anon_sym_CARET,
    ACTIONS(5765), 1,
      anon_sym_PIPE,
    ACTIONS(5769), 1,
      anon_sym_PERCENT,
    ACTIONS(5771), 1,
      anon_sym_STAR_STAR,
    ACTIONS(5779), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(5781), 1,
      sym__ternary_qmark,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4792), 2,
      anon_sym_of,
      anon_sym_BQUOTE,
    ACTIONS(5749), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(5751), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(5759), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(5767), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(5775), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(5777), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(5773), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [97479] = 11,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(5792), 1,
      anon_sym_LT,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4785), 12,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4787), 20,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_of,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [97544] = 22,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(5581), 1,
      anon_sym_STAR_STAR,
    ACTIONS(5590), 1,
      anon_sym_GT_GT,
    ACTIONS(5596), 1,
      anon_sym_PERCENT,
    ACTIONS(5598), 1,
      anon_sym_LT,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(5586), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(5588), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(5592), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(5594), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(5612), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(5614), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(4762), 3,
      anon_sym_BANG,
      anon_sym_AMP,
      anon_sym_PIPE,
    ACTIONS(5600), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
    ACTIONS(4760), 9,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COLON,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_CARET,
      anon_sym_QMARK_QMARK,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [97631] = 23,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(5581), 1,
      anon_sym_STAR_STAR,
    ACTIONS(5590), 1,
      anon_sym_GT_GT,
    ACTIONS(5596), 1,
      anon_sym_PERCENT,
    ACTIONS(5598), 1,
      anon_sym_LT,
    ACTIONS(5606), 1,
      anon_sym_AMP,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4762), 2,
      anon_sym_BANG,
      anon_sym_PIPE,
    ACTIONS(5586), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(5588), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(5592), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(5594), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(5612), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(5614), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(5600), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
    ACTIONS(4760), 9,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COLON,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_CARET,
      anon_sym_QMARK_QMARK,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [97720] = 8,
    ACTIONS(1550), 1,
      anon_sym_DQUOTE,
    ACTIONS(1552), 1,
      anon_sym_SQUOTE,
    ACTIONS(4688), 1,
      anon_sym_LBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(5211), 2,
      sym_number,
      sym_private_property_identifier,
    STATE(3878), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(3814), 9,
      sym__automatic_semicolon,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_BANG,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_QMARK,
    ACTIONS(2351), 23,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [97779] = 7,
    ACTIONS(3658), 1,
      anon_sym_EQ,
    ACTIONS(4608), 1,
      anon_sym_LBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4408), 2,
      anon_sym_COMMA,
      anon_sym_extends,
    ACTIONS(4611), 3,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_GT,
    ACTIONS(3492), 10,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(3496), 23,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [97836] = 4,
    ACTIONS(3592), 1,
      anon_sym_EQ,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3492), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(3496), 26,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
      anon_sym_implements,
  [97887] = 7,
    ACTIONS(3646), 1,
      anon_sym_EQ,
    ACTIONS(4608), 1,
      anon_sym_LBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4408), 2,
      anon_sym_COMMA,
      anon_sym_extends,
    ACTIONS(4611), 3,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_GT,
    ACTIONS(3492), 10,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(3496), 23,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_of,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [97944] = 8,
    ACTIONS(1550), 1,
      anon_sym_DQUOTE,
    ACTIONS(1552), 1,
      anon_sym_SQUOTE,
    ACTIONS(4688), 1,
      anon_sym_LBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(5330), 2,
      sym_number,
      sym_private_property_identifier,
    STATE(3822), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(3814), 9,
      sym__automatic_semicolon,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_BANG,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_QMARK,
    ACTIONS(2351), 23,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [98003] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3235), 12,
      anon_sym_STAR,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_number,
      sym_private_property_identifier,
      anon_sym_AT,
      anon_sym_QMARK,
    ACTIONS(3233), 27,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_DOT,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
      anon_sym_abstract,
      anon_sym_accessor,
      anon_sym_extends,
  [98051] = 9,
    ACTIONS(1626), 1,
      anon_sym_DQUOTE,
    ACTIONS(1628), 1,
      anon_sym_SQUOTE,
    ACTIONS(4624), 1,
      anon_sym_LBRACK,
    ACTIONS(5797), 1,
      anon_sym_abstract,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(5795), 2,
      sym_number,
      sym_private_property_identifier,
    STATE(3320), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(3814), 7,
      sym__automatic_semicolon,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_BANG,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_QMARK,
    ACTIONS(3700), 23,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [98111] = 8,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(5799), 1,
      anon_sym_LT,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4704), 12,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4706), 22,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [98169] = 31,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4468), 1,
      anon_sym_BQUOTE,
    ACTIONS(4636), 1,
      anon_sym_as,
    ACTIONS(4640), 1,
      anon_sym_BANG,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4649), 1,
      anon_sym_satisfies,
    ACTIONS(5799), 1,
      anon_sym_LT,
    ACTIONS(5805), 1,
      anon_sym_AMP_AMP,
    ACTIONS(5807), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(5809), 1,
      anon_sym_GT_GT,
    ACTIONS(5813), 1,
      anon_sym_AMP,
    ACTIONS(5815), 1,
      anon_sym_CARET,
    ACTIONS(5817), 1,
      anon_sym_PIPE,
    ACTIONS(5821), 1,
      anon_sym_PERCENT,
    ACTIONS(5823), 1,
      anon_sym_STAR_STAR,
    ACTIONS(5831), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(5833), 1,
      sym__ternary_qmark,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(5801), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(5803), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(5811), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(5819), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(5827), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(5829), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(5825), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [98273] = 31,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_as,
    ACTIONS(4640), 1,
      anon_sym_BANG,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4649), 1,
      anon_sym_satisfies,
    ACTIONS(4756), 1,
      anon_sym_BQUOTE,
    ACTIONS(5799), 1,
      anon_sym_LT,
    ACTIONS(5805), 1,
      anon_sym_AMP_AMP,
    ACTIONS(5807), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(5809), 1,
      anon_sym_GT_GT,
    ACTIONS(5813), 1,
      anon_sym_AMP,
    ACTIONS(5815), 1,
      anon_sym_CARET,
    ACTIONS(5817), 1,
      anon_sym_PIPE,
    ACTIONS(5821), 1,
      anon_sym_PERCENT,
    ACTIONS(5823), 1,
      anon_sym_STAR_STAR,
    ACTIONS(5831), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(5833), 1,
      sym__ternary_qmark,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(5801), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(5803), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(5811), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(5819), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(5827), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(5829), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(5825), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [98377] = 31,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_as,
    ACTIONS(4640), 1,
      anon_sym_BANG,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4649), 1,
      anon_sym_satisfies,
    ACTIONS(4758), 1,
      anon_sym_BQUOTE,
    ACTIONS(5799), 1,
      anon_sym_LT,
    ACTIONS(5805), 1,
      anon_sym_AMP_AMP,
    ACTIONS(5807), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(5809), 1,
      anon_sym_GT_GT,
    ACTIONS(5813), 1,
      anon_sym_AMP,
    ACTIONS(5815), 1,
      anon_sym_CARET,
    ACTIONS(5817), 1,
      anon_sym_PIPE,
    ACTIONS(5821), 1,
      anon_sym_PERCENT,
    ACTIONS(5823), 1,
      anon_sym_STAR_STAR,
    ACTIONS(5831), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(5833), 1,
      sym__ternary_qmark,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(5801), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(5803), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(5811), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(5819), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(5827), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(5829), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(5825), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [98481] = 31,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4504), 1,
      anon_sym_BQUOTE,
    ACTIONS(4636), 1,
      anon_sym_as,
    ACTIONS(4640), 1,
      anon_sym_BANG,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4649), 1,
      anon_sym_satisfies,
    ACTIONS(5799), 1,
      anon_sym_LT,
    ACTIONS(5805), 1,
      anon_sym_AMP_AMP,
    ACTIONS(5807), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(5809), 1,
      anon_sym_GT_GT,
    ACTIONS(5813), 1,
      anon_sym_AMP,
    ACTIONS(5815), 1,
      anon_sym_CARET,
    ACTIONS(5817), 1,
      anon_sym_PIPE,
    ACTIONS(5821), 1,
      anon_sym_PERCENT,
    ACTIONS(5823), 1,
      anon_sym_STAR_STAR,
    ACTIONS(5831), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(5833), 1,
      sym__ternary_qmark,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(5801), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(5803), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(5811), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(5819), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(5827), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(5829), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(5825), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [98585] = 18,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(5799), 1,
      anon_sym_LT,
    ACTIONS(5809), 1,
      anon_sym_GT_GT,
    ACTIONS(5821), 1,
      anon_sym_PERCENT,
    ACTIONS(5823), 1,
      anon_sym_STAR_STAR,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(5801), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(5811), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(5819), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4762), 7,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4760), 13,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [98663] = 13,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(5823), 1,
      anon_sym_STAR_STAR,
    ACTIONS(5835), 1,
      anon_sym_LT,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4762), 12,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4760), 16,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [98731] = 25,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4762), 1,
      anon_sym_BANG,
    ACTIONS(5799), 1,
      anon_sym_LT,
    ACTIONS(5809), 1,
      anon_sym_GT_GT,
    ACTIONS(5813), 1,
      anon_sym_AMP,
    ACTIONS(5815), 1,
      anon_sym_CARET,
    ACTIONS(5817), 1,
      anon_sym_PIPE,
    ACTIONS(5821), 1,
      anon_sym_PERCENT,
    ACTIONS(5823), 1,
      anon_sym_STAR_STAR,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(5801), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(5803), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(5811), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(5819), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(5827), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(5829), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(5825), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
    ACTIONS(4760), 7,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [98823] = 26,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4762), 1,
      anon_sym_BANG,
    ACTIONS(5799), 1,
      anon_sym_LT,
    ACTIONS(5805), 1,
      anon_sym_AMP_AMP,
    ACTIONS(5809), 1,
      anon_sym_GT_GT,
    ACTIONS(5813), 1,
      anon_sym_AMP,
    ACTIONS(5815), 1,
      anon_sym_CARET,
    ACTIONS(5817), 1,
      anon_sym_PIPE,
    ACTIONS(5821), 1,
      anon_sym_PERCENT,
    ACTIONS(5823), 1,
      anon_sym_STAR_STAR,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(5801), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(5803), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(5811), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(5819), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(5827), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(5829), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(5825), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
    ACTIONS(4760), 6,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [98917] = 16,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(5821), 1,
      anon_sym_PERCENT,
    ACTIONS(5823), 1,
      anon_sym_STAR_STAR,
    ACTIONS(5835), 1,
      anon_sym_LT,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(5801), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(5819), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4762), 8,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4760), 15,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [98991] = 22,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(5799), 1,
      anon_sym_LT,
    ACTIONS(5809), 1,
      anon_sym_GT_GT,
    ACTIONS(5821), 1,
      anon_sym_PERCENT,
    ACTIONS(5823), 1,
      anon_sym_STAR_STAR,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(5801), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(5803), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(5811), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(5819), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(5827), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(5829), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(4762), 3,
      anon_sym_BANG,
      anon_sym_AMP,
      anon_sym_PIPE,
    ACTIONS(5825), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
    ACTIONS(4760), 8,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_CARET,
      anon_sym_QMARK_QMARK,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [99077] = 23,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(5799), 1,
      anon_sym_LT,
    ACTIONS(5809), 1,
      anon_sym_GT_GT,
    ACTIONS(5813), 1,
      anon_sym_AMP,
    ACTIONS(5821), 1,
      anon_sym_PERCENT,
    ACTIONS(5823), 1,
      anon_sym_STAR_STAR,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4762), 2,
      anon_sym_BANG,
      anon_sym_PIPE,
    ACTIONS(5801), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(5803), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(5811), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(5819), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(5827), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(5829), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(5825), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
    ACTIONS(4760), 8,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_CARET,
      anon_sym_QMARK_QMARK,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [99165] = 24,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(5799), 1,
      anon_sym_LT,
    ACTIONS(5809), 1,
      anon_sym_GT_GT,
    ACTIONS(5813), 1,
      anon_sym_AMP,
    ACTIONS(5815), 1,
      anon_sym_CARET,
    ACTIONS(5821), 1,
      anon_sym_PERCENT,
    ACTIONS(5823), 1,
      anon_sym_STAR_STAR,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4762), 2,
      anon_sym_BANG,
      anon_sym_PIPE,
    ACTIONS(5801), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(5803), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(5811), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(5819), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(5827), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(5829), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(5825), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
    ACTIONS(4760), 7,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [99255] = 15,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(5821), 1,
      anon_sym_PERCENT,
    ACTIONS(5823), 1,
      anon_sym_STAR_STAR,
    ACTIONS(5835), 1,
      anon_sym_LT,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(5801), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(4762), 10,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4760), 15,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [99327] = 16,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_as,
    ACTIONS(4640), 1,
      anon_sym_BANG,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4649), 1,
      anon_sym_satisfies,
    ACTIONS(5823), 1,
      anon_sym_STAR_STAR,
    ACTIONS(5835), 1,
      anon_sym_LT,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4762), 11,
      anon_sym_STAR,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4760), 14,
      sym__ternary_qmark,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_BQUOTE,
  [99401] = 20,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(5799), 1,
      anon_sym_LT,
    ACTIONS(5809), 1,
      anon_sym_GT_GT,
    ACTIONS(5821), 1,
      anon_sym_PERCENT,
    ACTIONS(5823), 1,
      anon_sym_STAR_STAR,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(5801), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(5803), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(5811), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(5819), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(5825), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
    ACTIONS(4762), 5,
      anon_sym_BANG,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4760), 10,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_CARET,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [99483] = 27,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4762), 1,
      anon_sym_BANG,
    ACTIONS(5799), 1,
      anon_sym_LT,
    ACTIONS(5805), 1,
      anon_sym_AMP_AMP,
    ACTIONS(5807), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(5809), 1,
      anon_sym_GT_GT,
    ACTIONS(5813), 1,
      anon_sym_AMP,
    ACTIONS(5815), 1,
      anon_sym_CARET,
    ACTIONS(5817), 1,
      anon_sym_PIPE,
    ACTIONS(5821), 1,
      anon_sym_PERCENT,
    ACTIONS(5823), 1,
      anon_sym_STAR_STAR,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(5801), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(5803), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(5811), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(5819), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(5827), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(5829), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(5825), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
    ACTIONS(4760), 5,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_QMARK_QMARK,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [99579] = 31,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4522), 1,
      anon_sym_BQUOTE,
    ACTIONS(4636), 1,
      anon_sym_as,
    ACTIONS(4640), 1,
      anon_sym_BANG,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4649), 1,
      anon_sym_satisfies,
    ACTIONS(5799), 1,
      anon_sym_LT,
    ACTIONS(5805), 1,
      anon_sym_AMP_AMP,
    ACTIONS(5807), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(5809), 1,
      anon_sym_GT_GT,
    ACTIONS(5813), 1,
      anon_sym_AMP,
    ACTIONS(5815), 1,
      anon_sym_CARET,
    ACTIONS(5817), 1,
      anon_sym_PIPE,
    ACTIONS(5821), 1,
      anon_sym_PERCENT,
    ACTIONS(5823), 1,
      anon_sym_STAR_STAR,
    ACTIONS(5831), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(5833), 1,
      sym__ternary_qmark,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(5801), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(5803), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(5811), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(5819), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(5827), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(5829), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(5825), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [99683] = 31,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_as,
    ACTIONS(4640), 1,
      anon_sym_BANG,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4649), 1,
      anon_sym_satisfies,
    ACTIONS(4767), 1,
      anon_sym_BQUOTE,
    ACTIONS(5799), 1,
      anon_sym_LT,
    ACTIONS(5805), 1,
      anon_sym_AMP_AMP,
    ACTIONS(5807), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(5809), 1,
      anon_sym_GT_GT,
    ACTIONS(5813), 1,
      anon_sym_AMP,
    ACTIONS(5815), 1,
      anon_sym_CARET,
    ACTIONS(5817), 1,
      anon_sym_PIPE,
    ACTIONS(5821), 1,
      anon_sym_PERCENT,
    ACTIONS(5823), 1,
      anon_sym_STAR_STAR,
    ACTIONS(5831), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(5833), 1,
      sym__ternary_qmark,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(5801), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(5803), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(5811), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(5819), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(5827), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(5829), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(5825), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [99787] = 31,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4546), 1,
      anon_sym_BQUOTE,
    ACTIONS(4636), 1,
      anon_sym_as,
    ACTIONS(4640), 1,
      anon_sym_BANG,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4649), 1,
      anon_sym_satisfies,
    ACTIONS(5799), 1,
      anon_sym_LT,
    ACTIONS(5805), 1,
      anon_sym_AMP_AMP,
    ACTIONS(5807), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(5809), 1,
      anon_sym_GT_GT,
    ACTIONS(5813), 1,
      anon_sym_AMP,
    ACTIONS(5815), 1,
      anon_sym_CARET,
    ACTIONS(5817), 1,
      anon_sym_PIPE,
    ACTIONS(5821), 1,
      anon_sym_PERCENT,
    ACTIONS(5823), 1,
      anon_sym_STAR_STAR,
    ACTIONS(5831), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(5833), 1,
      sym__ternary_qmark,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(5801), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(5803), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(5811), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(5819), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(5827), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(5829), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(5825), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [99891] = 31,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4554), 1,
      anon_sym_BQUOTE,
    ACTIONS(4636), 1,
      anon_sym_as,
    ACTIONS(4640), 1,
      anon_sym_BANG,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4649), 1,
      anon_sym_satisfies,
    ACTIONS(5799), 1,
      anon_sym_LT,
    ACTIONS(5805), 1,
      anon_sym_AMP_AMP,
    ACTIONS(5807), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(5809), 1,
      anon_sym_GT_GT,
    ACTIONS(5813), 1,
      anon_sym_AMP,
    ACTIONS(5815), 1,
      anon_sym_CARET,
    ACTIONS(5817), 1,
      anon_sym_PIPE,
    ACTIONS(5821), 1,
      anon_sym_PERCENT,
    ACTIONS(5823), 1,
      anon_sym_STAR_STAR,
    ACTIONS(5831), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(5833), 1,
      sym__ternary_qmark,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(5801), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(5803), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(5811), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(5819), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(5827), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(5829), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(5825), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [99995] = 31,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4558), 1,
      anon_sym_BQUOTE,
    ACTIONS(4636), 1,
      anon_sym_as,
    ACTIONS(4640), 1,
      anon_sym_BANG,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4649), 1,
      anon_sym_satisfies,
    ACTIONS(5799), 1,
      anon_sym_LT,
    ACTIONS(5805), 1,
      anon_sym_AMP_AMP,
    ACTIONS(5807), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(5809), 1,
      anon_sym_GT_GT,
    ACTIONS(5813), 1,
      anon_sym_AMP,
    ACTIONS(5815), 1,
      anon_sym_CARET,
    ACTIONS(5817), 1,
      anon_sym_PIPE,
    ACTIONS(5821), 1,
      anon_sym_PERCENT,
    ACTIONS(5823), 1,
      anon_sym_STAR_STAR,
    ACTIONS(5831), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(5833), 1,
      sym__ternary_qmark,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(5801), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(5803), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(5811), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(5819), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(5827), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(5829), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(5825), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [100099] = 31,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_as,
    ACTIONS(4640), 1,
      anon_sym_BANG,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4649), 1,
      anon_sym_satisfies,
    ACTIONS(4769), 1,
      anon_sym_BQUOTE,
    ACTIONS(5799), 1,
      anon_sym_LT,
    ACTIONS(5805), 1,
      anon_sym_AMP_AMP,
    ACTIONS(5807), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(5809), 1,
      anon_sym_GT_GT,
    ACTIONS(5813), 1,
      anon_sym_AMP,
    ACTIONS(5815), 1,
      anon_sym_CARET,
    ACTIONS(5817), 1,
      anon_sym_PIPE,
    ACTIONS(5821), 1,
      anon_sym_PERCENT,
    ACTIONS(5823), 1,
      anon_sym_STAR_STAR,
    ACTIONS(5831), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(5833), 1,
      sym__ternary_qmark,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(5801), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(5803), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(5811), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(5819), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(5827), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(5829), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(5825), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [100203] = 31,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_as,
    ACTIONS(4640), 1,
      anon_sym_BANG,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4649), 1,
      anon_sym_satisfies,
    ACTIONS(4771), 1,
      anon_sym_BQUOTE,
    ACTIONS(5799), 1,
      anon_sym_LT,
    ACTIONS(5805), 1,
      anon_sym_AMP_AMP,
    ACTIONS(5807), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(5809), 1,
      anon_sym_GT_GT,
    ACTIONS(5813), 1,
      anon_sym_AMP,
    ACTIONS(5815), 1,
      anon_sym_CARET,
    ACTIONS(5817), 1,
      anon_sym_PIPE,
    ACTIONS(5821), 1,
      anon_sym_PERCENT,
    ACTIONS(5823), 1,
      anon_sym_STAR_STAR,
    ACTIONS(5831), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(5833), 1,
      sym__ternary_qmark,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(5801), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(5803), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(5811), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(5819), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(5827), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(5829), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(5825), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [100307] = 31,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_as,
    ACTIONS(4640), 1,
      anon_sym_BANG,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4649), 1,
      anon_sym_satisfies,
    ACTIONS(4773), 1,
      anon_sym_BQUOTE,
    ACTIONS(5799), 1,
      anon_sym_LT,
    ACTIONS(5805), 1,
      anon_sym_AMP_AMP,
    ACTIONS(5807), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(5809), 1,
      anon_sym_GT_GT,
    ACTIONS(5813), 1,
      anon_sym_AMP,
    ACTIONS(5815), 1,
      anon_sym_CARET,
    ACTIONS(5817), 1,
      anon_sym_PIPE,
    ACTIONS(5821), 1,
      anon_sym_PERCENT,
    ACTIONS(5823), 1,
      anon_sym_STAR_STAR,
    ACTIONS(5831), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(5833), 1,
      sym__ternary_qmark,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(5801), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(5803), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(5811), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(5819), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(5827), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(5829), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(5825), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [100411] = 32,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_as,
    ACTIONS(4640), 1,
      anon_sym_BANG,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4649), 1,
      anon_sym_satisfies,
    ACTIONS(5014), 1,
      anon_sym_of,
    ACTIONS(5747), 1,
      anon_sym_LT,
    ACTIONS(5751), 1,
      anon_sym_GT,
    ACTIONS(5753), 1,
      anon_sym_AMP_AMP,
    ACTIONS(5755), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(5757), 1,
      anon_sym_GT_GT,
    ACTIONS(5761), 1,
      anon_sym_AMP,
    ACTIONS(5763), 1,
      anon_sym_CARET,
    ACTIONS(5765), 1,
      anon_sym_PIPE,
    ACTIONS(5769), 1,
      anon_sym_PERCENT,
    ACTIONS(5771), 1,
      anon_sym_STAR_STAR,
    ACTIONS(5779), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(5781), 1,
      sym__ternary_qmark,
    ACTIONS(5838), 1,
      anon_sym_in,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(5749), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(5759), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(5767), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(5775), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(5777), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(5773), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [100517] = 31,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_as,
    ACTIONS(4640), 1,
      anon_sym_BANG,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4649), 1,
      anon_sym_satisfies,
    ACTIONS(5626), 1,
      anon_sym_LT,
    ACTIONS(5632), 1,
      anon_sym_AMP_AMP,
    ACTIONS(5634), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(5636), 1,
      anon_sym_GT_GT,
    ACTIONS(5640), 1,
      anon_sym_AMP,
    ACTIONS(5642), 1,
      anon_sym_CARET,
    ACTIONS(5644), 1,
      anon_sym_PIPE,
    ACTIONS(5648), 1,
      anon_sym_PERCENT,
    ACTIONS(5650), 1,
      anon_sym_STAR_STAR,
    ACTIONS(5658), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(5660), 1,
      sym__ternary_qmark,
    ACTIONS(5841), 1,
      anon_sym_RBRACK,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(5628), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(5630), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(5638), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(5646), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(5654), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(5656), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(5652), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [100621] = 6,
    ACTIONS(4622), 1,
      anon_sym_EQ,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4074), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
    ACTIONS(1971), 6,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(3814), 7,
      sym__automatic_semicolon,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_QMARK,
      anon_sym_PIPE_RBRACE,
    ACTIONS(1969), 23,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [100675] = 6,
    ACTIONS(4622), 1,
      anon_sym_EQ,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4074), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
    ACTIONS(1975), 6,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(3814), 7,
      sym__automatic_semicolon,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_QMARK,
      anon_sym_PIPE_RBRACE,
    ACTIONS(1973), 23,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [100729] = 15,
    ACTIONS(1550), 1,
      anon_sym_DQUOTE,
    ACTIONS(1552), 1,
      anon_sym_SQUOTE,
    ACTIONS(2353), 1,
      anon_sym_async,
    ACTIONS(2355), 1,
      anon_sym_readonly,
    ACTIONS(2359), 1,
      anon_sym_override,
    ACTIONS(4688), 1,
      anon_sym_LBRACK,
    ACTIONS(4990), 1,
      anon_sym_STAR,
    STATE(2813), 1,
      sym_override_modifier,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(2337), 2,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(2357), 2,
      anon_sym_get,
      anon_sym_set,
    ACTIONS(5843), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
    STATE(3816), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(3814), 4,
      anon_sym_LPAREN,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_QMARK,
    ACTIONS(2351), 18,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [100801] = 6,
    ACTIONS(4510), 1,
      anon_sym_LBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4513), 2,
      anon_sym_AMP,
      anon_sym_PIPE,
    ACTIONS(4106), 3,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_extends,
    ACTIONS(3492), 11,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(3496), 22,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [100855] = 6,
    ACTIONS(4146), 1,
      anon_sym_EQ,
    ACTIONS(4651), 1,
      anon_sym_RBRACK,
    ACTIONS(4850), 1,
      anon_sym_COMMA,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4144), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4148), 23,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [100909] = 6,
    ACTIONS(4604), 1,
      anon_sym_EQ,
    ACTIONS(4671), 1,
      anon_sym_RBRACK,
    ACTIONS(4854), 1,
      anon_sym_COMMA,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4602), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4606), 23,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [100963] = 6,
    ACTIONS(1696), 1,
      anon_sym_EQ,
    ACTIONS(4775), 1,
      anon_sym_RBRACK,
    ACTIONS(4859), 1,
      anon_sym_COMMA,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(1694), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(1698), 23,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [101017] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3227), 12,
      anon_sym_STAR,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_number,
      sym_private_property_identifier,
      anon_sym_AT,
      anon_sym_QMARK,
    ACTIONS(3225), 27,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_DOT,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
      anon_sym_abstract,
      anon_sym_accessor,
      anon_sym_extends,
  [101065] = 6,
    ACTIONS(3614), 1,
      anon_sym_RBRACK,
    ACTIONS(3622), 1,
      anon_sym_COMMA,
    ACTIONS(3693), 1,
      anon_sym_EQ,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3492), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(3496), 23,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [101119] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3239), 12,
      anon_sym_STAR,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_number,
      sym_private_property_identifier,
      anon_sym_AT,
      anon_sym_QMARK,
    ACTIONS(3237), 27,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_DOT,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
      anon_sym_abstract,
      anon_sym_accessor,
      anon_sym_extends,
  [101167] = 6,
    ACTIONS(4106), 1,
      anon_sym_extends,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4510), 2,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
    ACTIONS(4513), 2,
      anon_sym_AMP,
      anon_sym_PIPE,
    ACTIONS(3492), 11,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(3496), 23,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [101221] = 4,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4120), 2,
      anon_sym_COMMA,
      anon_sym_extends,
    ACTIONS(4288), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4290), 24,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [101271] = 4,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4322), 2,
      anon_sym_COMMA,
      anon_sym_extends,
    ACTIONS(4288), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4290), 24,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [101321] = 6,
    ACTIONS(4608), 1,
      anon_sym_LBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4611), 2,
      anon_sym_AMP,
      anon_sym_PIPE,
    ACTIONS(4408), 3,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_extends,
    ACTIONS(3492), 11,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(3496), 22,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [101375] = 6,
    ACTIONS(4614), 1,
      anon_sym_LBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4617), 2,
      anon_sym_AMP,
      anon_sym_PIPE,
    ACTIONS(4378), 3,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_extends,
    ACTIONS(4458), 11,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4460), 22,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [101429] = 13,
    ACTIONS(1550), 1,
      anon_sym_DQUOTE,
    ACTIONS(1552), 1,
      anon_sym_SQUOTE,
    ACTIONS(4688), 1,
      anon_sym_LBRACK,
    ACTIONS(4990), 1,
      anon_sym_STAR,
    ACTIONS(5555), 1,
      anon_sym_COMMA,
    ACTIONS(5624), 1,
      anon_sym_RBRACE,
    STATE(4960), 1,
      aux_sym_object_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(2337), 2,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(2357), 2,
      anon_sym_get,
      anon_sym_set,
    STATE(3816), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(3814), 4,
      anon_sym_LPAREN,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_QMARK,
    ACTIONS(2351), 21,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [101497] = 14,
    ACTIONS(1550), 1,
      anon_sym_DQUOTE,
    ACTIONS(1552), 1,
      anon_sym_SQUOTE,
    ACTIONS(2353), 1,
      anon_sym_async,
    ACTIONS(4688), 1,
      anon_sym_LBRACK,
    ACTIONS(4990), 1,
      anon_sym_STAR,
    ACTIONS(5555), 1,
      anon_sym_COMMA,
    ACTIONS(5624), 1,
      anon_sym_RBRACE,
    STATE(4960), 1,
      aux_sym_object_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(2337), 2,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(2357), 2,
      anon_sym_get,
      anon_sym_set,
    STATE(3816), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(3814), 4,
      anon_sym_LPAREN,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_QMARK,
    ACTIONS(2351), 20,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [101567] = 7,
    ACTIONS(3494), 1,
      anon_sym_EQ,
    ACTIONS(4608), 1,
      anon_sym_LBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4408), 2,
      anon_sym_COMMA,
      anon_sym_extends,
    ACTIONS(4611), 3,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_GT,
    ACTIONS(3492), 10,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(3496), 22,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [101623] = 31,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_as,
    ACTIONS(4640), 1,
      anon_sym_BANG,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4649), 1,
      anon_sym_satisfies,
    ACTIONS(5581), 1,
      anon_sym_STAR_STAR,
    ACTIONS(5590), 1,
      anon_sym_GT_GT,
    ACTIONS(5596), 1,
      anon_sym_PERCENT,
    ACTIONS(5598), 1,
      anon_sym_LT,
    ACTIONS(5602), 1,
      anon_sym_AMP_AMP,
    ACTIONS(5604), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(5606), 1,
      anon_sym_AMP,
    ACTIONS(5608), 1,
      anon_sym_CARET,
    ACTIONS(5610), 1,
      anon_sym_PIPE,
    ACTIONS(5616), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(5618), 1,
      sym__ternary_qmark,
    ACTIONS(5845), 1,
      anon_sym_COLON,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(5586), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(5588), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(5592), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(5594), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(5612), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(5614), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(5600), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [101727] = 4,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4526), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_COLON,
    ACTIONS(5847), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(5850), 23,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [101777] = 4,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(1712), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_COLON,
    ACTIONS(5853), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(5856), 23,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [101827] = 4,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4578), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_COLON,
    ACTIONS(5859), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(5862), 23,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [101877] = 4,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4582), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_COLON,
    ACTIONS(5865), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(5868), 23,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [101927] = 12,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(5871), 1,
      anon_sym_LT,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4778), 12,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4780), 17,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [101993] = 15,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_as,
    ACTIONS(4640), 1,
      anon_sym_BANG,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4649), 1,
      anon_sym_satisfies,
    ACTIONS(5874), 1,
      anon_sym_LT,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4634), 11,
      anon_sym_STAR,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4638), 15,
      sym__ternary_qmark,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_BQUOTE,
  [102065] = 31,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_as,
    ACTIONS(4640), 1,
      anon_sym_BANG,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4649), 1,
      anon_sym_satisfies,
    ACTIONS(4792), 1,
      anon_sym_BQUOTE,
    ACTIONS(5799), 1,
      anon_sym_LT,
    ACTIONS(5805), 1,
      anon_sym_AMP_AMP,
    ACTIONS(5807), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(5809), 1,
      anon_sym_GT_GT,
    ACTIONS(5813), 1,
      anon_sym_AMP,
    ACTIONS(5815), 1,
      anon_sym_CARET,
    ACTIONS(5817), 1,
      anon_sym_PIPE,
    ACTIONS(5821), 1,
      anon_sym_PERCENT,
    ACTIONS(5823), 1,
      anon_sym_STAR_STAR,
    ACTIONS(5831), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(5833), 1,
      sym__ternary_qmark,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(5801), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(5803), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(5811), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(5819), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(5827), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(5829), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(5825), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [102169] = 11,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(5877), 1,
      anon_sym_LT,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4785), 12,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4787), 19,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [102233] = 12,
    ACTIONS(1550), 1,
      anon_sym_DQUOTE,
    ACTIONS(1552), 1,
      anon_sym_SQUOTE,
    ACTIONS(4622), 1,
      anon_sym_EQ,
    ACTIONS(4688), 1,
      anon_sym_LBRACK,
    ACTIONS(4990), 1,
      anon_sym_STAR,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(2337), 2,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(2357), 2,
      anon_sym_get,
      anon_sym_set,
    ACTIONS(5665), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
    STATE(3816), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(3814), 4,
      anon_sym_LPAREN,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_QMARK,
    ACTIONS(2351), 21,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [102299] = 13,
    ACTIONS(1550), 1,
      anon_sym_DQUOTE,
    ACTIONS(1552), 1,
      anon_sym_SQUOTE,
    ACTIONS(2353), 1,
      anon_sym_async,
    ACTIONS(4622), 1,
      anon_sym_EQ,
    ACTIONS(4688), 1,
      anon_sym_LBRACK,
    ACTIONS(4990), 1,
      anon_sym_STAR,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(2337), 2,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(2357), 2,
      anon_sym_get,
      anon_sym_set,
    ACTIONS(5665), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
    STATE(3816), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(3814), 4,
      anon_sym_LPAREN,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_QMARK,
    ACTIONS(2351), 20,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [102367] = 11,
    ACTIONS(1626), 1,
      anon_sym_DQUOTE,
    ACTIONS(1628), 1,
      anon_sym_SQUOTE,
    ACTIONS(3722), 1,
      anon_sym_override,
    ACTIONS(4624), 1,
      anon_sym_LBRACK,
    ACTIONS(5880), 1,
      anon_sym_readonly,
    STATE(2847), 1,
      sym_override_modifier,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(5668), 2,
      sym_number,
      sym_private_property_identifier,
    STATE(3399), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(3814), 7,
      sym__automatic_semicolon,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_BANG,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_QMARK,
    ACTIONS(3700), 21,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [102431] = 9,
    ACTIONS(1626), 1,
      anon_sym_DQUOTE,
    ACTIONS(1628), 1,
      anon_sym_SQUOTE,
    ACTIONS(4624), 1,
      anon_sym_LBRACK,
    ACTIONS(5882), 1,
      anon_sym_abstract,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(5668), 2,
      sym_number,
      sym_private_property_identifier,
    STATE(3399), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(3814), 7,
      sym__automatic_semicolon,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_BANG,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_QMARK,
    ACTIONS(3700), 23,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [102491] = 11,
    ACTIONS(1626), 1,
      anon_sym_DQUOTE,
    ACTIONS(1628), 1,
      anon_sym_SQUOTE,
    ACTIONS(3722), 1,
      anon_sym_override,
    ACTIONS(4624), 1,
      anon_sym_LBRACK,
    ACTIONS(5886), 1,
      anon_sym_readonly,
    STATE(2865), 1,
      sym_override_modifier,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(5884), 2,
      sym_number,
      sym_private_property_identifier,
    STATE(3446), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(3814), 7,
      sym__automatic_semicolon,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_BANG,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_QMARK,
    ACTIONS(3700), 21,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [102555] = 9,
    ACTIONS(1626), 1,
      anon_sym_DQUOTE,
    ACTIONS(1628), 1,
      anon_sym_SQUOTE,
    ACTIONS(4624), 1,
      anon_sym_LBRACK,
    ACTIONS(5890), 1,
      anon_sym_abstract,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(5888), 2,
      sym_number,
      sym_private_property_identifier,
    STATE(3449), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(3814), 7,
      sym__automatic_semicolon,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_BANG,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_QMARK,
    ACTIONS(3700), 23,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [102615] = 31,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_as,
    ACTIONS(4640), 1,
      anon_sym_BANG,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4649), 1,
      anon_sym_satisfies,
    ACTIONS(5581), 1,
      anon_sym_STAR_STAR,
    ACTIONS(5590), 1,
      anon_sym_GT_GT,
    ACTIONS(5596), 1,
      anon_sym_PERCENT,
    ACTIONS(5598), 1,
      anon_sym_LT,
    ACTIONS(5602), 1,
      anon_sym_AMP_AMP,
    ACTIONS(5604), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(5606), 1,
      anon_sym_AMP,
    ACTIONS(5608), 1,
      anon_sym_CARET,
    ACTIONS(5610), 1,
      anon_sym_PIPE,
    ACTIONS(5616), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(5618), 1,
      sym__ternary_qmark,
    ACTIONS(5892), 1,
      anon_sym_COLON,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(5586), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(5588), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(5592), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(5594), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(5612), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(5614), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(5600), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [102719] = 31,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_as,
    ACTIONS(4640), 1,
      anon_sym_BANG,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4649), 1,
      anon_sym_satisfies,
    ACTIONS(5581), 1,
      anon_sym_STAR_STAR,
    ACTIONS(5590), 1,
      anon_sym_GT_GT,
    ACTIONS(5596), 1,
      anon_sym_PERCENT,
    ACTIONS(5598), 1,
      anon_sym_LT,
    ACTIONS(5602), 1,
      anon_sym_AMP_AMP,
    ACTIONS(5604), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(5606), 1,
      anon_sym_AMP,
    ACTIONS(5608), 1,
      anon_sym_CARET,
    ACTIONS(5610), 1,
      anon_sym_PIPE,
    ACTIONS(5616), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(5618), 1,
      sym__ternary_qmark,
    ACTIONS(5894), 1,
      anon_sym_COLON,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(5586), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(5588), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(5592), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(5594), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(5612), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(5614), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(5600), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [102823] = 31,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_as,
    ACTIONS(4640), 1,
      anon_sym_BANG,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4649), 1,
      anon_sym_satisfies,
    ACTIONS(5581), 1,
      anon_sym_STAR_STAR,
    ACTIONS(5590), 1,
      anon_sym_GT_GT,
    ACTIONS(5596), 1,
      anon_sym_PERCENT,
    ACTIONS(5598), 1,
      anon_sym_LT,
    ACTIONS(5602), 1,
      anon_sym_AMP_AMP,
    ACTIONS(5604), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(5606), 1,
      anon_sym_AMP,
    ACTIONS(5608), 1,
      anon_sym_CARET,
    ACTIONS(5610), 1,
      anon_sym_PIPE,
    ACTIONS(5616), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(5618), 1,
      sym__ternary_qmark,
    ACTIONS(5896), 1,
      anon_sym_COLON,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(5586), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(5588), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(5592), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(5594), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(5612), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(5614), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(5600), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [102927] = 31,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_as,
    ACTIONS(4640), 1,
      anon_sym_BANG,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4649), 1,
      anon_sym_satisfies,
    ACTIONS(5581), 1,
      anon_sym_STAR_STAR,
    ACTIONS(5590), 1,
      anon_sym_GT_GT,
    ACTIONS(5596), 1,
      anon_sym_PERCENT,
    ACTIONS(5598), 1,
      anon_sym_LT,
    ACTIONS(5602), 1,
      anon_sym_AMP_AMP,
    ACTIONS(5604), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(5606), 1,
      anon_sym_AMP,
    ACTIONS(5608), 1,
      anon_sym_CARET,
    ACTIONS(5610), 1,
      anon_sym_PIPE,
    ACTIONS(5616), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(5618), 1,
      sym__ternary_qmark,
    ACTIONS(5898), 1,
      anon_sym_COLON,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(5586), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(5588), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(5592), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(5594), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(5612), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(5614), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(5600), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [103031] = 31,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_as,
    ACTIONS(4640), 1,
      anon_sym_BANG,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4649), 1,
      anon_sym_satisfies,
    ACTIONS(5626), 1,
      anon_sym_LT,
    ACTIONS(5632), 1,
      anon_sym_AMP_AMP,
    ACTIONS(5634), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(5636), 1,
      anon_sym_GT_GT,
    ACTIONS(5640), 1,
      anon_sym_AMP,
    ACTIONS(5642), 1,
      anon_sym_CARET,
    ACTIONS(5644), 1,
      anon_sym_PIPE,
    ACTIONS(5648), 1,
      anon_sym_PERCENT,
    ACTIONS(5650), 1,
      anon_sym_STAR_STAR,
    ACTIONS(5658), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(5660), 1,
      sym__ternary_qmark,
    ACTIONS(5900), 1,
      anon_sym_RBRACK,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(5628), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(5630), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(5638), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(5646), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(5654), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(5656), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(5652), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [103135] = 31,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_as,
    ACTIONS(4640), 1,
      anon_sym_BANG,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4649), 1,
      anon_sym_satisfies,
    ACTIONS(5581), 1,
      anon_sym_STAR_STAR,
    ACTIONS(5590), 1,
      anon_sym_GT_GT,
    ACTIONS(5596), 1,
      anon_sym_PERCENT,
    ACTIONS(5598), 1,
      anon_sym_LT,
    ACTIONS(5602), 1,
      anon_sym_AMP_AMP,
    ACTIONS(5604), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(5606), 1,
      anon_sym_AMP,
    ACTIONS(5608), 1,
      anon_sym_CARET,
    ACTIONS(5610), 1,
      anon_sym_PIPE,
    ACTIONS(5616), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(5618), 1,
      sym__ternary_qmark,
    ACTIONS(5902), 1,
      anon_sym_COLON,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(5586), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(5588), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(5592), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(5594), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(5612), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(5614), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(5600), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [103239] = 11,
    ACTIONS(1626), 1,
      anon_sym_DQUOTE,
    ACTIONS(1628), 1,
      anon_sym_SQUOTE,
    ACTIONS(3722), 1,
      anon_sym_override,
    ACTIONS(4624), 1,
      anon_sym_LBRACK,
    ACTIONS(5904), 1,
      anon_sym_readonly,
    STATE(2814), 1,
      sym_override_modifier,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4840), 2,
      sym_number,
      sym_private_property_identifier,
    STATE(3368), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(3814), 7,
      sym__automatic_semicolon,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_BANG,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_QMARK,
    ACTIONS(3700), 21,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [103303] = 9,
    ACTIONS(1626), 1,
      anon_sym_DQUOTE,
    ACTIONS(1628), 1,
      anon_sym_SQUOTE,
    ACTIONS(4624), 1,
      anon_sym_LBRACK,
    ACTIONS(4848), 1,
      anon_sym_abstract,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4840), 2,
      sym_number,
      sym_private_property_identifier,
    STATE(3368), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(3814), 7,
      sym__automatic_semicolon,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_BANG,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_QMARK,
    ACTIONS(3700), 23,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [103363] = 31,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_as,
    ACTIONS(4640), 1,
      anon_sym_BANG,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4649), 1,
      anon_sym_satisfies,
    ACTIONS(5581), 1,
      anon_sym_STAR_STAR,
    ACTIONS(5590), 1,
      anon_sym_GT_GT,
    ACTIONS(5596), 1,
      anon_sym_PERCENT,
    ACTIONS(5598), 1,
      anon_sym_LT,
    ACTIONS(5602), 1,
      anon_sym_AMP_AMP,
    ACTIONS(5604), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(5606), 1,
      anon_sym_AMP,
    ACTIONS(5608), 1,
      anon_sym_CARET,
    ACTIONS(5610), 1,
      anon_sym_PIPE,
    ACTIONS(5616), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(5618), 1,
      sym__ternary_qmark,
    ACTIONS(5906), 1,
      anon_sym_COLON,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(5586), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(5588), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(5592), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(5594), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(5612), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(5614), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(5600), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [103467] = 4,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(1826), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_COLON,
    ACTIONS(5908), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(5911), 23,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [103517] = 4,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(1836), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_COLON,
    ACTIONS(5914), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(5917), 23,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [103567] = 4,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4600), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_COLON,
    ACTIONS(5920), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(5923), 23,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [103617] = 4,
    ACTIONS(3582), 1,
      anon_sym_EQ,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3492), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(3496), 25,
      sym__automatic_semicolon,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [103667] = 11,
    ACTIONS(1626), 1,
      anon_sym_DQUOTE,
    ACTIONS(1628), 1,
      anon_sym_SQUOTE,
    ACTIONS(3722), 1,
      anon_sym_override,
    ACTIONS(4624), 1,
      anon_sym_LBRACK,
    ACTIONS(5928), 1,
      anon_sym_readonly,
    STATE(2868), 1,
      sym_override_modifier,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(5926), 2,
      sym_number,
      sym_private_property_identifier,
    STATE(3369), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(3814), 7,
      sym__automatic_semicolon,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_BANG,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_QMARK,
    ACTIONS(3700), 21,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [103731] = 31,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_as,
    ACTIONS(4640), 1,
      anon_sym_BANG,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4649), 1,
      anon_sym_satisfies,
    ACTIONS(5581), 1,
      anon_sym_STAR_STAR,
    ACTIONS(5590), 1,
      anon_sym_GT_GT,
    ACTIONS(5596), 1,
      anon_sym_PERCENT,
    ACTIONS(5598), 1,
      anon_sym_LT,
    ACTIONS(5602), 1,
      anon_sym_AMP_AMP,
    ACTIONS(5604), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(5606), 1,
      anon_sym_AMP,
    ACTIONS(5608), 1,
      anon_sym_CARET,
    ACTIONS(5610), 1,
      anon_sym_PIPE,
    ACTIONS(5616), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(5618), 1,
      sym__ternary_qmark,
    ACTIONS(5930), 1,
      anon_sym_COLON,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(5586), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(5588), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(5592), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(5594), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(5612), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(5614), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(5600), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [103835] = 9,
    ACTIONS(1626), 1,
      anon_sym_DQUOTE,
    ACTIONS(1628), 1,
      anon_sym_SQUOTE,
    ACTIONS(4624), 1,
      anon_sym_LBRACK,
    ACTIONS(5934), 1,
      anon_sym_abstract,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(5932), 2,
      sym_number,
      sym_private_property_identifier,
    STATE(3376), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(3814), 7,
      sym__automatic_semicolon,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_BANG,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_QMARK,
    ACTIONS(3700), 23,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [103895] = 4,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(1872), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_COLON,
    ACTIONS(5936), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(5939), 23,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [103945] = 31,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_as,
    ACTIONS(4640), 1,
      anon_sym_BANG,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4649), 1,
      anon_sym_satisfies,
    ACTIONS(5581), 1,
      anon_sym_STAR_STAR,
    ACTIONS(5590), 1,
      anon_sym_GT_GT,
    ACTIONS(5596), 1,
      anon_sym_PERCENT,
    ACTIONS(5598), 1,
      anon_sym_LT,
    ACTIONS(5602), 1,
      anon_sym_AMP_AMP,
    ACTIONS(5604), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(5606), 1,
      anon_sym_AMP,
    ACTIONS(5608), 1,
      anon_sym_CARET,
    ACTIONS(5610), 1,
      anon_sym_PIPE,
    ACTIONS(5616), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(5618), 1,
      sym__ternary_qmark,
    ACTIONS(5942), 1,
      anon_sym_COLON,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(5586), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(5588), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(5592), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(5594), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(5612), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(5614), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(5600), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [104049] = 6,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    STATE(1669), 1,
      sym_arguments,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(5944), 3,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_implements,
    ACTIONS(4410), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4412), 21,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_satisfies,
  [104103] = 31,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_as,
    ACTIONS(4640), 1,
      anon_sym_BANG,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4649), 1,
      anon_sym_satisfies,
    ACTIONS(5581), 1,
      anon_sym_STAR_STAR,
    ACTIONS(5590), 1,
      anon_sym_GT_GT,
    ACTIONS(5596), 1,
      anon_sym_PERCENT,
    ACTIONS(5598), 1,
      anon_sym_LT,
    ACTIONS(5602), 1,
      anon_sym_AMP_AMP,
    ACTIONS(5604), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(5606), 1,
      anon_sym_AMP,
    ACTIONS(5608), 1,
      anon_sym_CARET,
    ACTIONS(5610), 1,
      anon_sym_PIPE,
    ACTIONS(5616), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(5618), 1,
      sym__ternary_qmark,
    ACTIONS(5946), 1,
      anon_sym_COLON,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(5586), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(5588), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(5592), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(5594), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(5612), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(5614), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(5600), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [104207] = 11,
    ACTIONS(1626), 1,
      anon_sym_DQUOTE,
    ACTIONS(1628), 1,
      anon_sym_SQUOTE,
    ACTIONS(3722), 1,
      anon_sym_override,
    ACTIONS(4624), 1,
      anon_sym_LBRACK,
    ACTIONS(5950), 1,
      anon_sym_readonly,
    STATE(2862), 1,
      sym_override_modifier,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(5948), 2,
      sym_number,
      sym_private_property_identifier,
    STATE(3459), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(3814), 7,
      sym__automatic_semicolon,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_BANG,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_QMARK,
    ACTIONS(3700), 21,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [104271] = 31,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_as,
    ACTIONS(4640), 1,
      anon_sym_BANG,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4649), 1,
      anon_sym_satisfies,
    ACTIONS(4744), 1,
      anon_sym_BQUOTE,
    ACTIONS(5799), 1,
      anon_sym_LT,
    ACTIONS(5805), 1,
      anon_sym_AMP_AMP,
    ACTIONS(5807), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(5809), 1,
      anon_sym_GT_GT,
    ACTIONS(5813), 1,
      anon_sym_AMP,
    ACTIONS(5815), 1,
      anon_sym_CARET,
    ACTIONS(5817), 1,
      anon_sym_PIPE,
    ACTIONS(5821), 1,
      anon_sym_PERCENT,
    ACTIONS(5823), 1,
      anon_sym_STAR_STAR,
    ACTIONS(5831), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(5833), 1,
      sym__ternary_qmark,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(5801), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(5803), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(5811), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(5819), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(5827), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(5829), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(5825), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [104375] = 9,
    ACTIONS(237), 1,
      anon_sym_COMMA,
    ACTIONS(694), 1,
      anon_sym_RBRACE,
    ACTIONS(4622), 1,
      anon_sym_EQ,
    STATE(4792), 1,
      aux_sym_object_repeat1,
    STATE(4815), 1,
      aux_sym_object_pattern_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3814), 4,
      anon_sym_LPAREN,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_QMARK,
    ACTIONS(1975), 6,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(1973), 23,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [104434] = 11,
    ACTIONS(1550), 1,
      anon_sym_DQUOTE,
    ACTIONS(1552), 1,
      anon_sym_SQUOTE,
    ACTIONS(4688), 1,
      anon_sym_LBRACK,
    ACTIONS(4990), 1,
      anon_sym_STAR,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(2337), 2,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(2357), 2,
      anon_sym_get,
      anon_sym_set,
    ACTIONS(5843), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
    STATE(3816), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(3814), 4,
      anon_sym_LPAREN,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_QMARK,
    ACTIONS(2351), 21,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [104497] = 30,
    ACTIONS(4588), 1,
      anon_sym_LPAREN,
    ACTIONS(4590), 1,
      anon_sym_LBRACK,
    ACTIONS(4592), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_as,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4649), 1,
      anon_sym_satisfies,
    ACTIONS(4800), 1,
      anon_sym_BANG,
    ACTIONS(5799), 1,
      anon_sym_LT,
    ACTIONS(5805), 1,
      anon_sym_AMP_AMP,
    ACTIONS(5807), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(5809), 1,
      anon_sym_GT_GT,
    ACTIONS(5813), 1,
      anon_sym_AMP,
    ACTIONS(5815), 1,
      anon_sym_CARET,
    ACTIONS(5817), 1,
      anon_sym_PIPE,
    ACTIONS(5821), 1,
      anon_sym_PERCENT,
    ACTIONS(5823), 1,
      anon_sym_STAR_STAR,
    ACTIONS(5831), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(5833), 1,
      sym__ternary_qmark,
    STATE(2130), 1,
      sym_arguments,
    STATE(2719), 1,
      sym_type_arguments,
    STATE(4524), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(5801), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(5803), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(5811), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(5819), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(5827), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(5829), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(5825), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [104598] = 8,
    ACTIONS(1626), 1,
      anon_sym_DQUOTE,
    ACTIONS(1628), 1,
      anon_sym_SQUOTE,
    ACTIONS(4624), 1,
      anon_sym_LBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(5952), 2,
      sym_number,
      sym_private_property_identifier,
    STATE(3419), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(3814), 7,
      sym__automatic_semicolon,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_BANG,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_QMARK,
    ACTIONS(3700), 23,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [104655] = 9,
    ACTIONS(237), 1,
      anon_sym_COMMA,
    ACTIONS(667), 1,
      anon_sym_RBRACE,
    ACTIONS(4622), 1,
      anon_sym_EQ,
    STATE(4792), 1,
      aux_sym_object_repeat1,
    STATE(4815), 1,
      aux_sym_object_pattern_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3814), 4,
      anon_sym_LPAREN,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_QMARK,
    ACTIONS(1971), 6,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(1969), 23,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [104714] = 9,
    ACTIONS(237), 1,
      anon_sym_COMMA,
    ACTIONS(667), 1,
      anon_sym_RBRACE,
    ACTIONS(4622), 1,
      anon_sym_EQ,
    STATE(4792), 1,
      aux_sym_object_repeat1,
    STATE(4815), 1,
      aux_sym_object_pattern_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3814), 4,
      anon_sym_LPAREN,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_QMARK,
    ACTIONS(1975), 6,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(1973), 23,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [104773] = 9,
    ACTIONS(237), 1,
      anon_sym_COMMA,
    ACTIONS(692), 1,
      anon_sym_RBRACE,
    ACTIONS(4622), 1,
      anon_sym_EQ,
    STATE(4810), 1,
      aux_sym_object_repeat1,
    STATE(4815), 1,
      aux_sym_object_pattern_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3814), 4,
      anon_sym_LPAREN,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_QMARK,
    ACTIONS(1971), 6,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(1969), 23,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [104832] = 9,
    ACTIONS(237), 1,
      anon_sym_COMMA,
    ACTIONS(692), 1,
      anon_sym_RBRACE,
    ACTIONS(4622), 1,
      anon_sym_EQ,
    STATE(4810), 1,
      aux_sym_object_repeat1,
    STATE(4815), 1,
      aux_sym_object_pattern_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3814), 4,
      anon_sym_LPAREN,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_QMARK,
    ACTIONS(1975), 6,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(1973), 23,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [104891] = 9,
    ACTIONS(237), 1,
      anon_sym_COMMA,
    ACTIONS(4622), 1,
      anon_sym_EQ,
    ACTIONS(5053), 1,
      anon_sym_RBRACE,
    STATE(4792), 1,
      aux_sym_object_repeat1,
    STATE(4815), 1,
      aux_sym_object_pattern_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3814), 4,
      anon_sym_LPAREN,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_QMARK,
    ACTIONS(1971), 6,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(1969), 23,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [104950] = 9,
    ACTIONS(237), 1,
      anon_sym_COMMA,
    ACTIONS(4622), 1,
      anon_sym_EQ,
    ACTIONS(5053), 1,
      anon_sym_RBRACE,
    STATE(4792), 1,
      aux_sym_object_repeat1,
    STATE(4815), 1,
      aux_sym_object_pattern_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3814), 4,
      anon_sym_LPAREN,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_QMARK,
    ACTIONS(1975), 6,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(1973), 23,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [105009] = 8,
    ACTIONS(1626), 1,
      anon_sym_DQUOTE,
    ACTIONS(1628), 1,
      anon_sym_SQUOTE,
    ACTIONS(4624), 1,
      anon_sym_LBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(5954), 2,
      sym_number,
      sym_private_property_identifier,
    STATE(3414), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(3814), 7,
      sym__automatic_semicolon,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_BANG,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_QMARK,
    ACTIONS(3700), 23,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [105066] = 9,
    ACTIONS(237), 1,
      anon_sym_COMMA,
    ACTIONS(694), 1,
      anon_sym_RBRACE,
    ACTIONS(4622), 1,
      anon_sym_EQ,
    STATE(4792), 1,
      aux_sym_object_repeat1,
    STATE(4815), 1,
      aux_sym_object_pattern_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3814), 4,
      anon_sym_LPAREN,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_QMARK,
    ACTIONS(1971), 6,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(1969), 23,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [105125] = 12,
    ACTIONS(1550), 1,
      anon_sym_DQUOTE,
    ACTIONS(1552), 1,
      anon_sym_SQUOTE,
    ACTIONS(2353), 1,
      anon_sym_async,
    ACTIONS(4688), 1,
      anon_sym_LBRACK,
    ACTIONS(4990), 1,
      anon_sym_STAR,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(2337), 2,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(2357), 2,
      anon_sym_get,
      anon_sym_set,
    ACTIONS(5843), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
    STATE(3816), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(3814), 4,
      anon_sym_LPAREN,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_QMARK,
    ACTIONS(2351), 20,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [105190] = 6,
    ACTIONS(3494), 1,
      anon_sym_EQ,
    ACTIONS(3681), 1,
      anon_sym_in,
    ACTIONS(3684), 1,
      anon_sym_of,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3492), 12,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(3496), 23,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [105243] = 10,
    ACTIONS(1550), 1,
      anon_sym_DQUOTE,
    ACTIONS(1552), 1,
      anon_sym_SQUOTE,
    ACTIONS(4622), 1,
      anon_sym_EQ,
    ACTIONS(4688), 1,
      anon_sym_LBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(2337), 2,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(5665), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
    STATE(3816), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(3814), 4,
      anon_sym_LPAREN,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_QMARK,
    ACTIONS(2351), 23,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [105304] = 8,
    ACTIONS(1626), 1,
      anon_sym_DQUOTE,
    ACTIONS(1628), 1,
      anon_sym_SQUOTE,
    ACTIONS(4624), 1,
      anon_sym_LBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(5956), 2,
      sym_number,
      sym_private_property_identifier,
    STATE(3326), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(3814), 7,
      sym__automatic_semicolon,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_BANG,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_QMARK,
    ACTIONS(3700), 23,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [105361] = 8,
    ACTIONS(1626), 1,
      anon_sym_DQUOTE,
    ACTIONS(1628), 1,
      anon_sym_SQUOTE,
    ACTIONS(4624), 1,
      anon_sym_LBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(5958), 2,
      sym_number,
      sym_private_property_identifier,
    STATE(3403), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(3814), 7,
      sym__automatic_semicolon,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_BANG,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_QMARK,
    ACTIONS(3700), 23,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [105418] = 9,
    ACTIONS(237), 1,
      anon_sym_COMMA,
    ACTIONS(4622), 1,
      anon_sym_EQ,
    ACTIONS(5051), 1,
      anon_sym_RBRACE,
    STATE(4792), 1,
      aux_sym_object_repeat1,
    STATE(4815), 1,
      aux_sym_object_pattern_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3814), 4,
      anon_sym_LPAREN,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_QMARK,
    ACTIONS(1971), 6,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(1969), 23,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [105477] = 9,
    ACTIONS(237), 1,
      anon_sym_COMMA,
    ACTIONS(4622), 1,
      anon_sym_EQ,
    ACTIONS(4992), 1,
      anon_sym_RBRACE,
    STATE(4792), 1,
      aux_sym_object_repeat1,
    STATE(4815), 1,
      aux_sym_object_pattern_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3814), 4,
      anon_sym_LPAREN,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_QMARK,
    ACTIONS(1971), 6,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(1969), 23,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [105536] = 9,
    ACTIONS(237), 1,
      anon_sym_COMMA,
    ACTIONS(4622), 1,
      anon_sym_EQ,
    ACTIONS(4992), 1,
      anon_sym_RBRACE,
    STATE(4792), 1,
      aux_sym_object_repeat1,
    STATE(4815), 1,
      aux_sym_object_pattern_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3814), 4,
      anon_sym_LPAREN,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_QMARK,
    ACTIONS(1975), 6,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(1973), 23,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [105595] = 9,
    ACTIONS(237), 1,
      anon_sym_COMMA,
    ACTIONS(4622), 1,
      anon_sym_EQ,
    ACTIONS(5051), 1,
      anon_sym_RBRACE,
    STATE(4792), 1,
      aux_sym_object_repeat1,
    STATE(4815), 1,
      aux_sym_object_pattern_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3814), 4,
      anon_sym_LPAREN,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_QMARK,
    ACTIONS(1975), 6,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(1973), 23,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [105654] = 11,
    ACTIONS(1550), 1,
      anon_sym_DQUOTE,
    ACTIONS(1552), 1,
      anon_sym_SQUOTE,
    ACTIONS(4688), 1,
      anon_sym_LBRACK,
    ACTIONS(5555), 1,
      anon_sym_COMMA,
    ACTIONS(5624), 1,
      anon_sym_RBRACE,
    STATE(4960), 1,
      aux_sym_object_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(2337), 2,
      sym_number,
      sym_private_property_identifier,
    STATE(3816), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(3814), 4,
      anon_sym_LPAREN,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_QMARK,
    ACTIONS(2351), 23,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [105717] = 8,
    ACTIONS(1626), 1,
      anon_sym_DQUOTE,
    ACTIONS(1628), 1,
      anon_sym_SQUOTE,
    ACTIONS(4624), 1,
      anon_sym_LBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(5960), 2,
      sym_number,
      sym_private_property_identifier,
    STATE(3334), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(3814), 7,
      sym__automatic_semicolon,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_BANG,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_QMARK,
    ACTIONS(3700), 23,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [105774] = 8,
    ACTIONS(1626), 1,
      anon_sym_DQUOTE,
    ACTIONS(1628), 1,
      anon_sym_SQUOTE,
    ACTIONS(4624), 1,
      anon_sym_LBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(5962), 2,
      sym_number,
      sym_private_property_identifier,
    STATE(3462), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(3814), 7,
      sym__automatic_semicolon,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_BANG,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_QMARK,
    ACTIONS(3700), 23,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [105831] = 8,
    ACTIONS(1626), 1,
      anon_sym_DQUOTE,
    ACTIONS(1628), 1,
      anon_sym_SQUOTE,
    ACTIONS(4624), 1,
      anon_sym_LBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(5964), 2,
      sym_number,
      sym_private_property_identifier,
    STATE(3367), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(3814), 7,
      sym__automatic_semicolon,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_BANG,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_QMARK,
    ACTIONS(3700), 23,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [105888] = 8,
    ACTIONS(1626), 1,
      anon_sym_DQUOTE,
    ACTIONS(1628), 1,
      anon_sym_SQUOTE,
    ACTIONS(4624), 1,
      anon_sym_LBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(5966), 2,
      sym_number,
      sym_private_property_identifier,
    STATE(3379), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(3814), 7,
      sym__automatic_semicolon,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_BANG,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_QMARK,
    ACTIONS(3700), 23,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [105945] = 8,
    ACTIONS(1626), 1,
      anon_sym_DQUOTE,
    ACTIONS(1628), 1,
      anon_sym_SQUOTE,
    ACTIONS(4624), 1,
      anon_sym_LBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(5968), 2,
      sym_number,
      sym_private_property_identifier,
    STATE(3397), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(3814), 7,
      sym__automatic_semicolon,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_BANG,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_QMARK,
    ACTIONS(3700), 23,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [106002] = 8,
    ACTIONS(1626), 1,
      anon_sym_DQUOTE,
    ACTIONS(1628), 1,
      anon_sym_SQUOTE,
    ACTIONS(4624), 1,
      anon_sym_LBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(5970), 2,
      sym_number,
      sym_private_property_identifier,
    STATE(3428), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(3814), 7,
      sym__automatic_semicolon,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_BANG,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_QMARK,
    ACTIONS(3700), 23,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [106059] = 8,
    ACTIONS(1626), 1,
      anon_sym_DQUOTE,
    ACTIONS(1628), 1,
      anon_sym_SQUOTE,
    ACTIONS(4624), 1,
      anon_sym_LBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(5972), 2,
      sym_number,
      sym_private_property_identifier,
    STATE(3429), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(3814), 7,
      sym__automatic_semicolon,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_BANG,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_QMARK,
    ACTIONS(3700), 23,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [106116] = 4,
    ACTIONS(4915), 1,
      sym_regex_flags,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4911), 17,
      anon_sym_STAR,
      anon_sym_as,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_of,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_instanceof,
      anon_sym_satisfies,
    ACTIONS(4913), 20,
      sym__ternary_qmark,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
  [106165] = 8,
    ACTIONS(1626), 1,
      anon_sym_DQUOTE,
    ACTIONS(1628), 1,
      anon_sym_SQUOTE,
    ACTIONS(4624), 1,
      anon_sym_LBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(5974), 2,
      sym_number,
      sym_private_property_identifier,
    STATE(3348), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(3814), 7,
      sym__automatic_semicolon,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_BANG,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_QMARK,
    ACTIONS(3700), 23,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [106222] = 8,
    ACTIONS(1626), 1,
      anon_sym_DQUOTE,
    ACTIONS(1628), 1,
      anon_sym_SQUOTE,
    ACTIONS(4624), 1,
      anon_sym_LBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(5976), 2,
      sym_number,
      sym_private_property_identifier,
    STATE(3343), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(3814), 7,
      sym__automatic_semicolon,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_BANG,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_QMARK,
    ACTIONS(3700), 23,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [106279] = 8,
    ACTIONS(1626), 1,
      anon_sym_DQUOTE,
    ACTIONS(1628), 1,
      anon_sym_SQUOTE,
    ACTIONS(4624), 1,
      anon_sym_LBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(5978), 2,
      sym_number,
      sym_private_property_identifier,
    STATE(3415), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(3814), 7,
      sym__automatic_semicolon,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_BANG,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_QMARK,
    ACTIONS(3700), 23,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [106336] = 4,
    ACTIONS(3642), 1,
      anon_sym_EQ,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3492), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(3496), 24,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [106385] = 4,
    ACTIONS(3658), 1,
      anon_sym_EQ,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3492), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(3496), 24,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [106434] = 30,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4012), 1,
      anon_sym_LBRACK,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_as,
    ACTIONS(4640), 1,
      anon_sym_BANG,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(4649), 1,
      anon_sym_satisfies,
    ACTIONS(5799), 1,
      anon_sym_LT,
    ACTIONS(5805), 1,
      anon_sym_AMP_AMP,
    ACTIONS(5807), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(5809), 1,
      anon_sym_GT_GT,
    ACTIONS(5813), 1,
      anon_sym_AMP,
    ACTIONS(5815), 1,
      anon_sym_CARET,
    ACTIONS(5817), 1,
      anon_sym_PIPE,
    ACTIONS(5821), 1,
      anon_sym_PERCENT,
    ACTIONS(5823), 1,
      anon_sym_STAR_STAR,
    ACTIONS(5831), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(5833), 1,
      sym__ternary_qmark,
    STATE(1633), 1,
      sym_type_arguments,
    STATE(1655), 1,
      sym_arguments,
    STATE(4733), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4647), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(5801), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(5803), 2,
      anon_sym_in,
      anon_sym_GT,
    ACTIONS(5811), 2,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(5819), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(5827), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(5829), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(5825), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [106535] = 8,
    ACTIONS(1626), 1,
      anon_sym_DQUOTE,
    ACTIONS(1628), 1,
      anon_sym_SQUOTE,
    ACTIONS(4624), 1,
      anon_sym_LBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(5980), 2,
      sym_number,
      sym_private_property_identifier,
    STATE(3400), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(3814), 7,
      sym__automatic_semicolon,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_BANG,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_QMARK,
    ACTIONS(3700), 23,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [106592] = 4,
    ACTIONS(3646), 1,
      anon_sym_EQ,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3492), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(3496), 24,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_of,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [106641] = 8,
    ACTIONS(1626), 1,
      anon_sym_DQUOTE,
    ACTIONS(1628), 1,
      anon_sym_SQUOTE,
    ACTIONS(4624), 1,
      anon_sym_LBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(5982), 2,
      sym_number,
      sym_private_property_identifier,
    STATE(3358), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(3814), 7,
      sym__automatic_semicolon,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_BANG,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_QMARK,
    ACTIONS(3700), 23,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [106698] = 4,
    ACTIONS(5984), 1,
      sym__automatic_semicolon,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(1878), 11,
      anon_sym_STAR,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_number,
      sym_private_property_identifier,
      anon_sym_AT,
    ACTIONS(1880), 25,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
      anon_sym_abstract,
      anon_sym_accessor,
  [106746] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(5988), 12,
      sym__automatic_semicolon,
      anon_sym_STAR,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_number,
      sym_private_property_identifier,
      anon_sym_AT,
    ACTIONS(5986), 25,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
      anon_sym_abstract,
      anon_sym_accessor,
  [106792] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(5992), 12,
      sym__automatic_semicolon,
      anon_sym_STAR,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_number,
      sym_private_property_identifier,
      anon_sym_AT,
    ACTIONS(5990), 25,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
      anon_sym_abstract,
      anon_sym_accessor,
  [106838] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(5996), 12,
      sym__automatic_semicolon,
      anon_sym_STAR,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_number,
      sym_private_property_identifier,
      anon_sym_AT,
    ACTIONS(5994), 25,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
      anon_sym_abstract,
      anon_sym_accessor,
  [106884] = 4,
    ACTIONS(3754), 1,
      anon_sym_EQ,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3492), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(3496), 23,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [106932] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(5992), 12,
      sym__automatic_semicolon,
      anon_sym_STAR,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_number,
      sym_private_property_identifier,
      anon_sym_AT,
    ACTIONS(5990), 25,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
      anon_sym_abstract,
      anon_sym_accessor,
  [106978] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6000), 12,
      sym__automatic_semicolon,
      anon_sym_STAR,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_number,
      sym_private_property_identifier,
      anon_sym_AT,
    ACTIONS(5998), 25,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
      anon_sym_abstract,
      anon_sym_accessor,
  [107024] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6004), 12,
      sym__automatic_semicolon,
      anon_sym_STAR,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_number,
      sym_private_property_identifier,
      anon_sym_AT,
    ACTIONS(6002), 25,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
      anon_sym_abstract,
      anon_sym_accessor,
  [107070] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(5996), 12,
      sym__automatic_semicolon,
      anon_sym_STAR,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_number,
      sym_private_property_identifier,
      anon_sym_AT,
    ACTIONS(5994), 25,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
      anon_sym_abstract,
      anon_sym_accessor,
  [107116] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6008), 12,
      sym__automatic_semicolon,
      anon_sym_STAR,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_number,
      sym_private_property_identifier,
      anon_sym_AT,
    ACTIONS(6006), 25,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
      anon_sym_abstract,
      anon_sym_accessor,
  [107162] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6000), 12,
      sym__automatic_semicolon,
      anon_sym_STAR,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_number,
      sym_private_property_identifier,
      anon_sym_AT,
    ACTIONS(5998), 25,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
      anon_sym_abstract,
      anon_sym_accessor,
  [107208] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6012), 12,
      sym__automatic_semicolon,
      anon_sym_STAR,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_number,
      sym_private_property_identifier,
      anon_sym_AT,
    ACTIONS(6010), 25,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
      anon_sym_abstract,
      anon_sym_accessor,
  [107254] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6016), 12,
      sym__automatic_semicolon,
      anon_sym_STAR,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_number,
      sym_private_property_identifier,
      anon_sym_AT,
    ACTIONS(6014), 25,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
      anon_sym_abstract,
      anon_sym_accessor,
  [107300] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(5996), 12,
      sym__automatic_semicolon,
      anon_sym_STAR,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_number,
      sym_private_property_identifier,
      anon_sym_AT,
    ACTIONS(5994), 25,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
      anon_sym_abstract,
      anon_sym_accessor,
  [107346] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6020), 12,
      sym__automatic_semicolon,
      anon_sym_STAR,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_number,
      sym_private_property_identifier,
      anon_sym_AT,
    ACTIONS(6018), 25,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
      anon_sym_abstract,
      anon_sym_accessor,
  [107392] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6024), 12,
      sym__automatic_semicolon,
      anon_sym_STAR,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_number,
      sym_private_property_identifier,
      anon_sym_AT,
    ACTIONS(6022), 25,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
      anon_sym_abstract,
      anon_sym_accessor,
  [107438] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6000), 12,
      sym__automatic_semicolon,
      anon_sym_STAR,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_number,
      sym_private_property_identifier,
      anon_sym_AT,
    ACTIONS(5998), 25,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
      anon_sym_abstract,
      anon_sym_accessor,
  [107484] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6028), 12,
      sym__automatic_semicolon,
      anon_sym_STAR,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_number,
      sym_private_property_identifier,
      anon_sym_AT,
    ACTIONS(6026), 25,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
      anon_sym_abstract,
      anon_sym_accessor,
  [107530] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(5988), 12,
      sym__automatic_semicolon,
      anon_sym_STAR,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_number,
      sym_private_property_identifier,
      anon_sym_AT,
    ACTIONS(5986), 25,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
      anon_sym_abstract,
      anon_sym_accessor,
  [107576] = 4,
    ACTIONS(3770), 1,
      anon_sym_EQ,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3492), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(3496), 23,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [107624] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6028), 12,
      sym__automatic_semicolon,
      anon_sym_STAR,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_number,
      sym_private_property_identifier,
      anon_sym_AT,
    ACTIONS(6026), 25,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
      anon_sym_abstract,
      anon_sym_accessor,
  [107670] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6024), 12,
      sym__automatic_semicolon,
      anon_sym_STAR,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_number,
      sym_private_property_identifier,
      anon_sym_AT,
    ACTIONS(6022), 25,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
      anon_sym_abstract,
      anon_sym_accessor,
  [107716] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(5996), 12,
      sym__automatic_semicolon,
      anon_sym_STAR,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_number,
      sym_private_property_identifier,
      anon_sym_AT,
    ACTIONS(5994), 25,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
      anon_sym_abstract,
      anon_sym_accessor,
  [107762] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(5996), 12,
      sym__automatic_semicolon,
      anon_sym_STAR,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_number,
      sym_private_property_identifier,
      anon_sym_AT,
    ACTIONS(5994), 25,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
      anon_sym_abstract,
      anon_sym_accessor,
  [107808] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6004), 12,
      sym__automatic_semicolon,
      anon_sym_STAR,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_number,
      sym_private_property_identifier,
      anon_sym_AT,
    ACTIONS(6002), 25,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
      anon_sym_abstract,
      anon_sym_accessor,
  [107854] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6032), 12,
      sym__automatic_semicolon,
      anon_sym_STAR,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_number,
      sym_private_property_identifier,
      anon_sym_AT,
    ACTIONS(6030), 25,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
      anon_sym_abstract,
      anon_sym_accessor,
  [107900] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6032), 12,
      sym__automatic_semicolon,
      anon_sym_STAR,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_number,
      sym_private_property_identifier,
      anon_sym_AT,
    ACTIONS(6030), 25,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
      anon_sym_abstract,
      anon_sym_accessor,
  [107946] = 4,
    ACTIONS(3782), 1,
      anon_sym_EQ,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3492), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(3496), 23,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [107994] = 4,
    ACTIONS(3792), 1,
      anon_sym_EQ,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3492), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(3496), 23,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [108042] = 4,
    ACTIONS(3746), 1,
      anon_sym_EQ,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3492), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(3496), 23,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [108090] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(1878), 12,
      sym__automatic_semicolon,
      anon_sym_STAR,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_number,
      sym_private_property_identifier,
      anon_sym_AT,
    ACTIONS(1880), 25,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
      anon_sym_abstract,
      anon_sym_accessor,
  [108136] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6024), 12,
      sym__automatic_semicolon,
      anon_sym_STAR,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_number,
      sym_private_property_identifier,
      anon_sym_AT,
    ACTIONS(6022), 25,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
      anon_sym_abstract,
      anon_sym_accessor,
  [108182] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6032), 12,
      sym__automatic_semicolon,
      anon_sym_STAR,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_number,
      sym_private_property_identifier,
      anon_sym_AT,
    ACTIONS(6030), 25,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
      anon_sym_abstract,
      anon_sym_accessor,
  [108228] = 4,
    ACTIONS(6034), 1,
      sym__automatic_semicolon,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(1690), 11,
      anon_sym_STAR,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_number,
      sym_private_property_identifier,
      anon_sym_AT,
    ACTIONS(1692), 25,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
      anon_sym_abstract,
      anon_sym_accessor,
  [108276] = 4,
    ACTIONS(3756), 1,
      anon_sym_EQ,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3492), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(3496), 23,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [108324] = 9,
    ACTIONS(1550), 1,
      anon_sym_DQUOTE,
    ACTIONS(1552), 1,
      anon_sym_SQUOTE,
    ACTIONS(4688), 1,
      anon_sym_LBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(2337), 2,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(5843), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
    STATE(3816), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(3814), 4,
      anon_sym_LPAREN,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_QMARK,
    ACTIONS(2351), 23,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [108382] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(1716), 12,
      sym__automatic_semicolon,
      anon_sym_STAR,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_number,
      sym_private_property_identifier,
      anon_sym_AT,
    ACTIONS(1718), 25,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
      anon_sym_abstract,
      anon_sym_accessor,
  [108428] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6024), 12,
      sym__automatic_semicolon,
      anon_sym_STAR,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_number,
      sym_private_property_identifier,
      anon_sym_AT,
    ACTIONS(6022), 25,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
      anon_sym_abstract,
      anon_sym_accessor,
  [108474] = 4,
    ACTIONS(3762), 1,
      anon_sym_EQ,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3492), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(3496), 23,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [108522] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(5996), 12,
      sym__automatic_semicolon,
      anon_sym_STAR,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_number,
      sym_private_property_identifier,
      anon_sym_AT,
    ACTIONS(5994), 25,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
      anon_sym_abstract,
      anon_sym_accessor,
  [108568] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6000), 12,
      sym__automatic_semicolon,
      anon_sym_STAR,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_number,
      sym_private_property_identifier,
      anon_sym_AT,
    ACTIONS(5998), 25,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
      anon_sym_abstract,
      anon_sym_accessor,
  [108614] = 4,
    ACTIONS(3778), 1,
      anon_sym_EQ,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3492), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(3496), 23,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [108662] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(5988), 12,
      sym__automatic_semicolon,
      anon_sym_STAR,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_number,
      sym_private_property_identifier,
      anon_sym_AT,
    ACTIONS(5986), 25,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
      anon_sym_abstract,
      anon_sym_accessor,
  [108708] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6028), 12,
      sym__automatic_semicolon,
      anon_sym_STAR,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_number,
      sym_private_property_identifier,
      anon_sym_AT,
    ACTIONS(6026), 25,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
      anon_sym_abstract,
      anon_sym_accessor,
  [108754] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6024), 12,
      sym__automatic_semicolon,
      anon_sym_STAR,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_number,
      sym_private_property_identifier,
      anon_sym_AT,
    ACTIONS(6022), 25,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
      anon_sym_abstract,
      anon_sym_accessor,
  [108800] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6038), 12,
      sym__automatic_semicolon,
      anon_sym_STAR,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_number,
      sym_private_property_identifier,
      anon_sym_AT,
    ACTIONS(6036), 25,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
      anon_sym_abstract,
      anon_sym_accessor,
  [108846] = 5,
    ACTIONS(87), 1,
      anon_sym_BQUOTE,
    STATE(2228), 1,
      sym_template_string,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(1734), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(1736), 22,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_satisfies,
  [108896] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(5988), 12,
      sym__automatic_semicolon,
      anon_sym_STAR,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_number,
      sym_private_property_identifier,
      anon_sym_AT,
    ACTIONS(5986), 25,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
      anon_sym_abstract,
      anon_sym_accessor,
  [108942] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6042), 12,
      sym__automatic_semicolon,
      anon_sym_STAR,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_number,
      sym_private_property_identifier,
      anon_sym_AT,
    ACTIONS(6040), 25,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
      anon_sym_abstract,
      anon_sym_accessor,
  [108988] = 4,
    ACTIONS(6044), 1,
      sym__automatic_semicolon,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(1690), 11,
      anon_sym_STAR,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_number,
      sym_private_property_identifier,
      anon_sym_AT,
    ACTIONS(1692), 25,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
      anon_sym_abstract,
      anon_sym_accessor,
  [109036] = 4,
    ACTIONS(6046), 1,
      sym__automatic_semicolon,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(1878), 11,
      anon_sym_STAR,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_number,
      sym_private_property_identifier,
      anon_sym_AT,
    ACTIONS(1880), 25,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
      anon_sym_abstract,
      anon_sym_accessor,
  [109084] = 5,
    ACTIONS(6052), 1,
      anon_sym_SEMI,
    ACTIONS(6055), 1,
      sym__automatic_semicolon,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6050), 10,
      anon_sym_STAR,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_number,
      sym_private_property_identifier,
      anon_sym_AT,
    ACTIONS(6048), 25,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
      anon_sym_abstract,
      anon_sym_accessor,
  [109134] = 5,
    ACTIONS(6061), 1,
      anon_sym_SEMI,
    ACTIONS(6064), 1,
      sym__automatic_semicolon,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6059), 10,
      anon_sym_STAR,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_number,
      sym_private_property_identifier,
      anon_sym_AT,
    ACTIONS(6057), 25,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
      anon_sym_abstract,
      anon_sym_accessor,
  [109184] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6024), 12,
      sym__automatic_semicolon,
      anon_sym_STAR,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_number,
      sym_private_property_identifier,
      anon_sym_AT,
    ACTIONS(6022), 25,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
      anon_sym_abstract,
      anon_sym_accessor,
  [109230] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6024), 12,
      sym__automatic_semicolon,
      anon_sym_STAR,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_number,
      sym_private_property_identifier,
      anon_sym_AT,
    ACTIONS(6022), 25,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
      anon_sym_abstract,
      anon_sym_accessor,
  [109276] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6028), 12,
      sym__automatic_semicolon,
      anon_sym_STAR,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_number,
      sym_private_property_identifier,
      anon_sym_AT,
    ACTIONS(6026), 25,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
      anon_sym_abstract,
      anon_sym_accessor,
  [109322] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6028), 12,
      sym__automatic_semicolon,
      anon_sym_STAR,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_number,
      sym_private_property_identifier,
      anon_sym_AT,
    ACTIONS(6026), 25,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
      anon_sym_abstract,
      anon_sym_accessor,
  [109368] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(5988), 12,
      sym__automatic_semicolon,
      anon_sym_STAR,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_number,
      sym_private_property_identifier,
      anon_sym_AT,
    ACTIONS(5986), 25,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
      anon_sym_abstract,
      anon_sym_accessor,
  [109414] = 4,
    ACTIONS(3784), 1,
      anon_sym_EQ,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3492), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(3496), 23,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [109462] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6032), 12,
      sym__automatic_semicolon,
      anon_sym_STAR,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_number,
      sym_private_property_identifier,
      anon_sym_AT,
    ACTIONS(6030), 25,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
      anon_sym_abstract,
      anon_sym_accessor,
  [109508] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(5996), 12,
      sym__automatic_semicolon,
      anon_sym_STAR,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_number,
      sym_private_property_identifier,
      anon_sym_AT,
    ACTIONS(5994), 25,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
      anon_sym_abstract,
      anon_sym_accessor,
  [109554] = 4,
    ACTIONS(3744), 1,
      anon_sym_EQ,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3492), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(3496), 23,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BQUOTE,
      anon_sym_satisfies,
  [109602] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6000), 12,
      sym__automatic_semicolon,
      anon_sym_STAR,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_number,
      sym_private_property_identifier,
      anon_sym_AT,
    ACTIONS(5998), 25,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
      anon_sym_abstract,
      anon_sym_accessor,
  [109648] = 8,
    ACTIONS(3576), 1,
      anon_sym_LT,
    ACTIONS(6066), 1,
      anon_sym_LPAREN,
    ACTIONS(6068), 1,
      anon_sym_DOT,
    STATE(2810), 1,
      sym_arguments,
    STATE(5442), 1,
      sym_type_arguments,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3572), 7,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_number,
      sym_private_property_identifier,
      anon_sym_AT,
    ACTIONS(3570), 25,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
      anon_sym_abstract,
      anon_sym_accessor,
  [109704] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6032), 12,
      sym__automatic_semicolon,
      anon_sym_STAR,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_number,
      sym_private_property_identifier,
      anon_sym_AT,
    ACTIONS(6030), 25,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
      anon_sym_abstract,
      anon_sym_accessor,
  [109750] = 6,
    ACTIONS(4622), 1,
      anon_sym_EQ,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(5665), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
    ACTIONS(3814), 4,
      anon_sym_LPAREN,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_QMARK,
    ACTIONS(1971), 6,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(1969), 23,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [109801] = 6,
    ACTIONS(4622), 1,
      anon_sym_EQ,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(5665), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
    ACTIONS(3814), 4,
      anon_sym_LPAREN,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_QMARK,
    ACTIONS(1975), 6,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(1973), 23,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [109852] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(1878), 11,
      anon_sym_STAR,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_number,
      sym_private_property_identifier,
      anon_sym_AT,
    ACTIONS(1880), 25,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
      anon_sym_abstract,
      anon_sym_accessor,
  [109897] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6072), 11,
      anon_sym_STAR,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_number,
      sym_private_property_identifier,
      anon_sym_AT,
    ACTIONS(6070), 25,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
      anon_sym_abstract,
      anon_sym_accessor,
  [109942] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6076), 11,
      anon_sym_STAR,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_number,
      sym_private_property_identifier,
      anon_sym_AT,
    ACTIONS(6074), 25,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
      anon_sym_abstract,
      anon_sym_accessor,
  [109987] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6080), 11,
      anon_sym_STAR,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_number,
      sym_private_property_identifier,
      anon_sym_AT,
    ACTIONS(6078), 25,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
      anon_sym_abstract,
      anon_sym_accessor,
  [110032] = 5,
    ACTIONS(4588), 1,
      anon_sym_LPAREN,
    STATE(2220), 1,
      sym_arguments,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4410), 13,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
    ACTIONS(4412), 21,
      sym__ternary_qmark,
      anon_sym_as,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_GT_GT_GT,
      anon_sym_LT_LT,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_instanceof,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_satisfies,
  [110081] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6080), 11,
      anon_sym_STAR,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_number,
      sym_private_property_identifier,
      anon_sym_AT,
    ACTIONS(6078), 25,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
      anon_sym_abstract,
      anon_sym_accessor,
  [110126] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6084), 11,
      anon_sym_STAR,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_number,
      sym_private_property_identifier,
      anon_sym_AT,
    ACTIONS(6082), 25,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
      anon_sym_abstract,
      anon_sym_accessor,
  [110171] = 14,
    ACTIONS(1550), 1,
      anon_sym_DQUOTE,
    ACTIONS(1552), 1,
      anon_sym_SQUOTE,
    ACTIONS(2359), 1,
      anon_sym_override,
    ACTIONS(4688), 1,
      anon_sym_LBRACK,
    ACTIONS(6086), 1,
      anon_sym_STAR,
    ACTIONS(6088), 1,
      anon_sym_async,
    ACTIONS(6092), 1,
      anon_sym_readonly,
    STATE(2807), 1,
      sym_override_modifier,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6090), 2,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(6094), 2,
      anon_sym_get,
      anon_sym_set,
    ACTIONS(3814), 3,
      anon_sym_LPAREN,
      anon_sym_LT,
      anon_sym_QMARK,
    STATE(3752), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(2351), 18,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [110238] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(1716), 11,
      anon_sym_STAR,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_number,
      sym_private_property_identifier,
      anon_sym_AT,
    ACTIONS(1718), 25,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
      anon_sym_abstract,
      anon_sym_accessor,
  [110283] = 7,
    ACTIONS(5555), 1,
      anon_sym_COMMA,
    ACTIONS(5624), 1,
      anon_sym_RBRACE,
    STATE(4960), 1,
      aux_sym_object_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3814), 4,
      anon_sym_LPAREN,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_QMARK,
    ACTIONS(1971), 6,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(1969), 23,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [110336] = 7,
    ACTIONS(5555), 1,
      anon_sym_COMMA,
    ACTIONS(5624), 1,
      anon_sym_RBRACE,
    STATE(4960), 1,
      aux_sym_object_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3814), 4,
      anon_sym_LPAREN,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_QMARK,
    ACTIONS(1975), 6,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(1973), 23,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [110389] = 5,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(5843), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
    ACTIONS(3814), 4,
      anon_sym_LPAREN,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_QMARK,
    ACTIONS(1971), 6,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(1969), 23,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [110437] = 11,
    ACTIONS(1550), 1,
      anon_sym_DQUOTE,
    ACTIONS(1552), 1,
      anon_sym_SQUOTE,
    ACTIONS(4688), 1,
      anon_sym_LBRACK,
    ACTIONS(6096), 1,
      anon_sym_STAR,
    ACTIONS(6098), 1,
      anon_sym_async,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6100), 2,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(6102), 2,
      anon_sym_get,
      anon_sym_set,
    ACTIONS(3814), 3,
      anon_sym_LPAREN,
      anon_sym_LT,
      anon_sym_QMARK,
    STATE(3872), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(2351), 20,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [110497] = 9,
    ACTIONS(1550), 1,
      anon_sym_DQUOTE,
    ACTIONS(1552), 1,
      anon_sym_SQUOTE,
    ACTIONS(4688), 1,
      anon_sym_LBRACK,
    ACTIONS(6104), 1,
      anon_sym_EQ_GT,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6090), 2,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(3814), 3,
      anon_sym_LPAREN,
      anon_sym_LT,
      anon_sym_QMARK,
    STATE(3752), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(2351), 23,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [110553] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3633), 9,
      anon_sym_STAR,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_LT,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_number,
      sym_private_property_identifier,
      anon_sym_AT,
    ACTIONS(3631), 26,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_DOT,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
      anon_sym_abstract,
      anon_sym_accessor,
  [110597] = 10,
    ACTIONS(1550), 1,
      anon_sym_DQUOTE,
    ACTIONS(1552), 1,
      anon_sym_SQUOTE,
    ACTIONS(4688), 1,
      anon_sym_LBRACK,
    ACTIONS(6086), 1,
      anon_sym_STAR,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6090), 2,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(6094), 2,
      anon_sym_get,
      anon_sym_set,
    ACTIONS(3814), 3,
      anon_sym_LPAREN,
      anon_sym_LT,
      anon_sym_QMARK,
    STATE(3752), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(2351), 21,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [110655] = 11,
    ACTIONS(1550), 1,
      anon_sym_DQUOTE,
    ACTIONS(1552), 1,
      anon_sym_SQUOTE,
    ACTIONS(4688), 1,
      anon_sym_LBRACK,
    ACTIONS(6086), 1,
      anon_sym_STAR,
    ACTIONS(6088), 1,
      anon_sym_async,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6090), 2,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(6094), 2,
      anon_sym_get,
      anon_sym_set,
    ACTIONS(3814), 3,
      anon_sym_LPAREN,
      anon_sym_LT,
      anon_sym_QMARK,
    STATE(3752), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(2351), 20,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [110715] = 17,
    ACTIONS(1626), 1,
      anon_sym_DQUOTE,
    ACTIONS(1628), 1,
      anon_sym_SQUOTE,
    ACTIONS(3722), 1,
      anon_sym_override,
    ACTIONS(4624), 1,
      anon_sym_LBRACK,
    ACTIONS(5076), 1,
      anon_sym_STAR,
    ACTIONS(5078), 1,
      anon_sym_async,
    ACTIONS(6108), 1,
      anon_sym_static,
    ACTIONS(6110), 1,
      anon_sym_readonly,
    ACTIONS(6112), 1,
      anon_sym_declare,
    ACTIONS(6114), 1,
      anon_sym_abstract,
    ACTIONS(6116), 1,
      anon_sym_accessor,
    STATE(2798), 1,
      sym_override_modifier,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(5084), 2,
      anon_sym_get,
      anon_sym_set,
    ACTIONS(6106), 2,
      sym_number,
      sym_private_property_identifier,
    STATE(3069), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(3700), 16,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_new,
      sym_identifier,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [110787] = 10,
    ACTIONS(1550), 1,
      anon_sym_DQUOTE,
    ACTIONS(1552), 1,
      anon_sym_SQUOTE,
    ACTIONS(4688), 1,
      anon_sym_LBRACK,
    ACTIONS(6096), 1,
      anon_sym_STAR,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6100), 2,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(6102), 2,
      anon_sym_get,
      anon_sym_set,
    ACTIONS(3814), 3,
      anon_sym_LPAREN,
      anon_sym_LT,
      anon_sym_QMARK,
    STATE(3872), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(2351), 21,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [110845] = 10,
    ACTIONS(1550), 1,
      anon_sym_DQUOTE,
    ACTIONS(1552), 1,
      anon_sym_SQUOTE,
    ACTIONS(4688), 1,
      anon_sym_LBRACK,
    ACTIONS(6118), 1,
      anon_sym_STAR,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6120), 2,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(6122), 2,
      anon_sym_get,
      anon_sym_set,
    ACTIONS(3814), 3,
      anon_sym_LPAREN,
      anon_sym_LT,
      anon_sym_QMARK,
    STATE(3837), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(2351), 21,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [110903] = 11,
    ACTIONS(1550), 1,
      anon_sym_DQUOTE,
    ACTIONS(1552), 1,
      anon_sym_SQUOTE,
    ACTIONS(4688), 1,
      anon_sym_LBRACK,
    ACTIONS(6118), 1,
      anon_sym_STAR,
    ACTIONS(6124), 1,
      anon_sym_async,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6120), 2,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(6122), 2,
      anon_sym_get,
      anon_sym_set,
    ACTIONS(3814), 3,
      anon_sym_LPAREN,
      anon_sym_LT,
      anon_sym_QMARK,
    STATE(3837), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(2351), 20,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [110963] = 17,
    ACTIONS(1626), 1,
      anon_sym_DQUOTE,
    ACTIONS(1628), 1,
      anon_sym_SQUOTE,
    ACTIONS(3722), 1,
      anon_sym_override,
    ACTIONS(4624), 1,
      anon_sym_LBRACK,
    ACTIONS(4656), 1,
      anon_sym_STAR,
    ACTIONS(4660), 1,
      anon_sym_async,
    ACTIONS(4682), 1,
      anon_sym_accessor,
    ACTIONS(6126), 1,
      anon_sym_static,
    ACTIONS(6128), 1,
      anon_sym_readonly,
    ACTIONS(6130), 1,
      anon_sym_declare,
    ACTIONS(6132), 1,
      anon_sym_abstract,
    STATE(2793), 1,
      sym_override_modifier,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4662), 2,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(4666), 2,
      anon_sym_get,
      anon_sym_set,
    STATE(3082), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(3700), 16,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_new,
      sym_identifier,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [111035] = 10,
    ACTIONS(1550), 1,
      anon_sym_DQUOTE,
    ACTIONS(1552), 1,
      anon_sym_SQUOTE,
    ACTIONS(4688), 1,
      anon_sym_LBRACK,
    ACTIONS(6134), 1,
      anon_sym_STAR,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6136), 2,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(6138), 2,
      anon_sym_get,
      anon_sym_set,
    ACTIONS(3814), 3,
      anon_sym_LPAREN,
      anon_sym_LT,
      anon_sym_QMARK,
    STATE(3840), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(2351), 21,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [111093] = 5,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(5843), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
    ACTIONS(3814), 4,
      anon_sym_LPAREN,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_QMARK,
    ACTIONS(1975), 6,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(1973), 23,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [111141] = 8,
    ACTIONS(1550), 1,
      anon_sym_DQUOTE,
    ACTIONS(1552), 1,
      anon_sym_SQUOTE,
    ACTIONS(4688), 1,
      anon_sym_LBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(5507), 2,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(3814), 3,
      anon_sym_LPAREN,
      anon_sym_LT,
      anon_sym_QMARK,
    STATE(3802), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(2351), 23,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [111194] = 8,
    ACTIONS(1550), 1,
      anon_sym_DQUOTE,
    ACTIONS(1552), 1,
      anon_sym_SQUOTE,
    ACTIONS(4688), 1,
      anon_sym_LBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(5547), 2,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(3814), 3,
      anon_sym_LPAREN,
      anon_sym_LT,
      anon_sym_QMARK,
    STATE(3851), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(2351), 23,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [111247] = 8,
    ACTIONS(1550), 1,
      anon_sym_DQUOTE,
    ACTIONS(1552), 1,
      anon_sym_SQUOTE,
    ACTIONS(4688), 1,
      anon_sym_LBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6090), 2,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(3814), 3,
      anon_sym_LPAREN,
      anon_sym_LT,
      anon_sym_QMARK,
    STATE(3752), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(2351), 23,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [111300] = 8,
    ACTIONS(1550), 1,
      anon_sym_DQUOTE,
    ACTIONS(1552), 1,
      anon_sym_SQUOTE,
    ACTIONS(4688), 1,
      anon_sym_LBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(5539), 2,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(3814), 3,
      anon_sym_LPAREN,
      anon_sym_LT,
      anon_sym_QMARK,
    STATE(3890), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(2351), 23,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [111353] = 8,
    ACTIONS(1550), 1,
      anon_sym_DQUOTE,
    ACTIONS(1552), 1,
      anon_sym_SQUOTE,
    ACTIONS(4688), 1,
      anon_sym_LBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(5441), 2,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(3814), 3,
      anon_sym_LPAREN,
      anon_sym_LT,
      anon_sym_QMARK,
    STATE(3753), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(2351), 23,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [111406] = 8,
    ACTIONS(1550), 1,
      anon_sym_DQUOTE,
    ACTIONS(1552), 1,
      anon_sym_SQUOTE,
    ACTIONS(4688), 1,
      anon_sym_LBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(5346), 2,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(3814), 3,
      anon_sym_LPAREN,
      anon_sym_LT,
      anon_sym_QMARK,
    STATE(3845), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(2351), 23,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [111459] = 8,
    ACTIONS(1550), 1,
      anon_sym_DQUOTE,
    ACTIONS(1552), 1,
      anon_sym_SQUOTE,
    ACTIONS(4688), 1,
      anon_sym_LBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(5620), 2,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(3814), 3,
      anon_sym_LPAREN,
      anon_sym_LT,
      anon_sym_QMARK,
    STATE(3787), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(2351), 23,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [111512] = 8,
    ACTIONS(1550), 1,
      anon_sym_DQUOTE,
    ACTIONS(1552), 1,
      anon_sym_SQUOTE,
    ACTIONS(4688), 1,
      anon_sym_LBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(5449), 2,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(3814), 3,
      anon_sym_LPAREN,
      anon_sym_LT,
      anon_sym_QMARK,
    STATE(3828), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(2351), 23,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [111565] = 8,
    ACTIONS(1550), 1,
      anon_sym_DQUOTE,
    ACTIONS(1552), 1,
      anon_sym_SQUOTE,
    ACTIONS(4688), 1,
      anon_sym_LBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(5279), 2,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(3814), 3,
      anon_sym_LPAREN,
      anon_sym_LT,
      anon_sym_QMARK,
    STATE(3863), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(2351), 23,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [111618] = 8,
    ACTIONS(1550), 1,
      anon_sym_DQUOTE,
    ACTIONS(1552), 1,
      anon_sym_SQUOTE,
    ACTIONS(4688), 1,
      anon_sym_LBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6100), 2,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(3814), 3,
      anon_sym_LPAREN,
      anon_sym_LT,
      anon_sym_QMARK,
    STATE(3872), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(2351), 23,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [111671] = 8,
    ACTIONS(1550), 1,
      anon_sym_DQUOTE,
    ACTIONS(1552), 1,
      anon_sym_SQUOTE,
    ACTIONS(4688), 1,
      anon_sym_LBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(5364), 2,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(3814), 3,
      anon_sym_LPAREN,
      anon_sym_LT,
      anon_sym_QMARK,
    STATE(3798), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(2351), 23,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [111724] = 8,
    ACTIONS(1550), 1,
      anon_sym_DQUOTE,
    ACTIONS(1552), 1,
      anon_sym_SQUOTE,
    ACTIONS(4688), 1,
      anon_sym_LBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6140), 2,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(3814), 3,
      anon_sym_LPAREN,
      anon_sym_LT,
      anon_sym_QMARK,
    STATE(3860), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(2351), 23,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [111777] = 8,
    ACTIONS(1550), 1,
      anon_sym_DQUOTE,
    ACTIONS(1552), 1,
      anon_sym_SQUOTE,
    ACTIONS(4688), 1,
      anon_sym_LBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(5300), 2,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(3814), 3,
      anon_sym_LPAREN,
      anon_sym_LT,
      anon_sym_QMARK,
    STATE(3780), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(2351), 23,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [111830] = 8,
    ACTIONS(1550), 1,
      anon_sym_DQUOTE,
    ACTIONS(1552), 1,
      anon_sym_SQUOTE,
    ACTIONS(4688), 1,
      anon_sym_LBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6142), 2,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(3814), 3,
      anon_sym_LPAREN,
      anon_sym_LT,
      anon_sym_QMARK,
    STATE(3846), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(2351), 23,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [111883] = 8,
    ACTIONS(1550), 1,
      anon_sym_DQUOTE,
    ACTIONS(1552), 1,
      anon_sym_SQUOTE,
    ACTIONS(4688), 1,
      anon_sym_LBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(5330), 2,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(3814), 3,
      anon_sym_LPAREN,
      anon_sym_LT,
      anon_sym_QMARK,
    STATE(3822), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(2351), 23,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [111936] = 8,
    ACTIONS(1550), 1,
      anon_sym_DQUOTE,
    ACTIONS(1552), 1,
      anon_sym_SQUOTE,
    ACTIONS(4688), 1,
      anon_sym_LBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6120), 2,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(3814), 3,
      anon_sym_LPAREN,
      anon_sym_LT,
      anon_sym_QMARK,
    STATE(3837), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(2351), 23,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [111989] = 8,
    ACTIONS(1550), 1,
      anon_sym_DQUOTE,
    ACTIONS(1552), 1,
      anon_sym_SQUOTE,
    ACTIONS(4688), 1,
      anon_sym_LBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(5211), 2,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(3814), 3,
      anon_sym_LPAREN,
      anon_sym_LT,
      anon_sym_QMARK,
    STATE(3878), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(2351), 23,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [112042] = 8,
    ACTIONS(1550), 1,
      anon_sym_DQUOTE,
    ACTIONS(1552), 1,
      anon_sym_SQUOTE,
    ACTIONS(4688), 1,
      anon_sym_LBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(5405), 2,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(3814), 3,
      anon_sym_LPAREN,
      anon_sym_LT,
      anon_sym_QMARK,
    STATE(3888), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(2351), 23,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [112095] = 8,
    ACTIONS(1550), 1,
      anon_sym_DQUOTE,
    ACTIONS(1552), 1,
      anon_sym_SQUOTE,
    ACTIONS(4688), 1,
      anon_sym_LBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6144), 2,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(3814), 3,
      anon_sym_LPAREN,
      anon_sym_LT,
      anon_sym_QMARK,
    STATE(3880), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(2351), 23,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [112148] = 8,
    ACTIONS(1550), 1,
      anon_sym_DQUOTE,
    ACTIONS(1552), 1,
      anon_sym_SQUOTE,
    ACTIONS(4688), 1,
      anon_sym_LBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6146), 2,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(3814), 3,
      anon_sym_LPAREN,
      anon_sym_LT,
      anon_sym_QMARK,
    STATE(3841), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(2351), 23,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [112201] = 8,
    ACTIONS(1550), 1,
      anon_sym_DQUOTE,
    ACTIONS(1552), 1,
      anon_sym_SQUOTE,
    ACTIONS(4688), 1,
      anon_sym_LBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6136), 2,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(3814), 3,
      anon_sym_LPAREN,
      anon_sym_LT,
      anon_sym_QMARK,
    STATE(3840), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(2351), 23,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [112254] = 8,
    ACTIONS(1550), 1,
      anon_sym_DQUOTE,
    ACTIONS(1552), 1,
      anon_sym_SQUOTE,
    ACTIONS(4688), 1,
      anon_sym_LBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6148), 2,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(3814), 3,
      anon_sym_LPAREN,
      anon_sym_LT,
      anon_sym_QMARK,
    STATE(3897), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(2351), 23,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [112307] = 6,
    ACTIONS(6150), 1,
      anon_sym_AT,
    STATE(2761), 1,
      aux_sym_export_statement_repeat1,
    STATE(2802), 1,
      sym_decorator,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3626), 6,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(3624), 25,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
      anon_sym_abstract,
      anon_sym_accessor,
  [112356] = 8,
    ACTIONS(1550), 1,
      anon_sym_DQUOTE,
    ACTIONS(1552), 1,
      anon_sym_SQUOTE,
    ACTIONS(4688), 1,
      anon_sym_LBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(5411), 2,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(3814), 3,
      anon_sym_LPAREN,
      anon_sym_LT,
      anon_sym_QMARK,
    STATE(3874), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(2351), 23,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [112409] = 8,
    ACTIONS(1550), 1,
      anon_sym_DQUOTE,
    ACTIONS(1552), 1,
      anon_sym_SQUOTE,
    ACTIONS(4688), 1,
      anon_sym_LBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6153), 2,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(3814), 3,
      anon_sym_LPAREN,
      anon_sym_LT,
      anon_sym_QMARK,
    STATE(3833), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(2351), 23,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [112462] = 8,
    ACTIONS(1550), 1,
      anon_sym_DQUOTE,
    ACTIONS(1552), 1,
      anon_sym_SQUOTE,
    ACTIONS(4688), 1,
      anon_sym_LBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(5433), 2,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(3814), 3,
      anon_sym_LPAREN,
      anon_sym_LT,
      anon_sym_QMARK,
    STATE(3836), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(2351), 23,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [112515] = 8,
    ACTIONS(1550), 1,
      anon_sym_DQUOTE,
    ACTIONS(1552), 1,
      anon_sym_SQUOTE,
    ACTIONS(4688), 1,
      anon_sym_LBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(5477), 2,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(3814), 3,
      anon_sym_LPAREN,
      anon_sym_LT,
      anon_sym_QMARK,
    STATE(3898), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(2351), 23,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [112568] = 13,
    ACTIONS(1626), 1,
      anon_sym_DQUOTE,
    ACTIONS(1628), 1,
      anon_sym_SQUOTE,
    ACTIONS(3722), 1,
      anon_sym_override,
    ACTIONS(4624), 1,
      anon_sym_LBRACK,
    ACTIONS(6157), 1,
      anon_sym_static,
    ACTIONS(6159), 1,
      anon_sym_readonly,
    ACTIONS(6161), 1,
      anon_sym_abstract,
    ACTIONS(6163), 1,
      anon_sym_accessor,
    STATE(2872), 1,
      sym_override_modifier,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6155), 2,
      sym_number,
      sym_private_property_identifier,
    STATE(3458), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(3700), 20,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [112631] = 13,
    ACTIONS(1626), 1,
      anon_sym_DQUOTE,
    ACTIONS(1628), 1,
      anon_sym_SQUOTE,
    ACTIONS(3722), 1,
      anon_sym_override,
    ACTIONS(4624), 1,
      anon_sym_LBRACK,
    ACTIONS(4842), 1,
      anon_sym_static,
    ACTIONS(4844), 1,
      anon_sym_readonly,
    ACTIONS(4846), 1,
      anon_sym_abstract,
    ACTIONS(4848), 1,
      anon_sym_accessor,
    STATE(2814), 1,
      sym_override_modifier,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4840), 2,
      sym_number,
      sym_private_property_identifier,
    STATE(3368), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(3700), 20,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [112694] = 8,
    ACTIONS(1550), 1,
      anon_sym_DQUOTE,
    ACTIONS(1552), 1,
      anon_sym_SQUOTE,
    ACTIONS(4688), 1,
      anon_sym_LBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(5419), 2,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(3814), 3,
      anon_sym_LPAREN,
      anon_sym_LT,
      anon_sym_QMARK,
    STATE(3882), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(2351), 23,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [112747] = 9,
    ACTIONS(1550), 1,
      anon_sym_DQUOTE,
    ACTIONS(1552), 1,
      anon_sym_SQUOTE,
    ACTIONS(4688), 1,
      anon_sym_LBRACK,
    ACTIONS(6165), 1,
      anon_sym_RBRACE,
    STATE(4692), 1,
      sym_enum_assignment,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6167), 2,
      sym_number,
      sym_private_property_identifier,
    STATE(4151), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(2351), 23,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [112801] = 22,
    ACTIONS(97), 1,
      anon_sym_AT,
    ACTIONS(2381), 1,
      anon_sym_type,
    ACTIONS(2383), 1,
      anon_sym_namespace,
    ACTIONS(2385), 1,
      anon_sym_import,
    ACTIONS(2387), 1,
      anon_sym_var,
    ACTIONS(2389), 1,
      anon_sym_let,
    ACTIONS(2391), 1,
      anon_sym_const,
    ACTIONS(2393), 1,
      anon_sym_class,
    ACTIONS(2395), 1,
      anon_sym_async,
    ACTIONS(2397), 1,
      anon_sym_function,
    ACTIONS(2399), 1,
      anon_sym_declare,
    ACTIONS(2403), 1,
      anon_sym_abstract,
    ACTIONS(2407), 1,
      anon_sym_interface,
    ACTIONS(2409), 1,
      anon_sym_enum,
    ACTIONS(3816), 1,
      anon_sym_module,
    ACTIONS(6169), 1,
      anon_sym_default,
    STATE(1344), 1,
      sym_decorator,
    STATE(3925), 1,
      sym_declaration,
    STATE(4287), 1,
      sym_internal_module,
    STATE(4304), 1,
      aux_sym_export_statement_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    STATE(4275), 13,
      sym_variable_declaration,
      sym_lexical_declaration,
      sym_class_declaration,
      sym_function_declaration,
      sym_generator_function_declaration,
      sym_function_signature,
      sym_ambient_declaration,
      sym_abstract_class_declaration,
      sym_module,
      sym_import_alias,
      sym_interface_declaration,
      sym_enum_declaration,
      sym_type_alias_declaration,
  [112881] = 14,
    ACTIONS(1626), 1,
      anon_sym_DQUOTE,
    ACTIONS(1628), 1,
      anon_sym_SQUOTE,
    ACTIONS(3722), 1,
      anon_sym_override,
    ACTIONS(4620), 1,
      anon_sym_STAR,
    ACTIONS(4624), 1,
      anon_sym_LBRACK,
    ACTIONS(4626), 1,
      anon_sym_async,
    ACTIONS(4630), 1,
      anon_sym_readonly,
    ACTIONS(6171), 1,
      anon_sym_static,
    STATE(2805), 1,
      sym_override_modifier,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4628), 2,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(4632), 2,
      anon_sym_get,
      anon_sym_set,
    STATE(3144), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(3700), 17,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_new,
      sym_identifier,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [112945] = 9,
    ACTIONS(1550), 1,
      anon_sym_DQUOTE,
    ACTIONS(1552), 1,
      anon_sym_SQUOTE,
    ACTIONS(4688), 1,
      anon_sym_LBRACK,
    ACTIONS(6173), 1,
      anon_sym_RBRACE,
    STATE(4646), 1,
      sym_enum_assignment,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6175), 2,
      sym_number,
      sym_private_property_identifier,
    STATE(3976), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(2351), 23,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [112999] = 14,
    ACTIONS(1626), 1,
      anon_sym_DQUOTE,
    ACTIONS(1628), 1,
      anon_sym_SQUOTE,
    ACTIONS(3722), 1,
      anon_sym_override,
    ACTIONS(4624), 1,
      anon_sym_LBRACK,
    ACTIONS(5000), 1,
      anon_sym_STAR,
    ACTIONS(5002), 1,
      anon_sym_async,
    ACTIONS(5006), 1,
      anon_sym_readonly,
    ACTIONS(6177), 1,
      anon_sym_static,
    STATE(2789), 1,
      sym_override_modifier,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(5004), 2,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(5008), 2,
      anon_sym_get,
      anon_sym_set,
    STATE(3147), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(3700), 17,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_new,
      sym_identifier,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [113063] = 12,
    ACTIONS(1626), 1,
      anon_sym_DQUOTE,
    ACTIONS(1628), 1,
      anon_sym_SQUOTE,
    ACTIONS(3722), 1,
      anon_sym_override,
    ACTIONS(4624), 1,
      anon_sym_LBRACK,
    ACTIONS(6179), 1,
      anon_sym_STAR,
    ACTIONS(6183), 1,
      anon_sym_readonly,
    STATE(2796), 1,
      sym_override_modifier,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6181), 2,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(6185), 2,
      anon_sym_get,
      anon_sym_set,
    STATE(3044), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(3700), 19,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [113123] = 9,
    ACTIONS(1550), 1,
      anon_sym_DQUOTE,
    ACTIONS(1552), 1,
      anon_sym_SQUOTE,
    ACTIONS(4688), 1,
      anon_sym_LBRACK,
    ACTIONS(6187), 1,
      anon_sym_RBRACE,
    STATE(5285), 1,
      sym_enum_assignment,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6189), 2,
      sym_number,
      sym_private_property_identifier,
    STATE(4446), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(2351), 23,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [113177] = 9,
    ACTIONS(1550), 1,
      anon_sym_DQUOTE,
    ACTIONS(1552), 1,
      anon_sym_SQUOTE,
    ACTIONS(4688), 1,
      anon_sym_LBRACK,
    ACTIONS(6191), 1,
      anon_sym_RBRACE,
    STATE(5285), 1,
      sym_enum_assignment,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6189), 2,
      sym_number,
      sym_private_property_identifier,
    STATE(4446), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(2351), 23,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [113231] = 9,
    ACTIONS(1550), 1,
      anon_sym_DQUOTE,
    ACTIONS(1552), 1,
      anon_sym_SQUOTE,
    ACTIONS(4688), 1,
      anon_sym_LBRACK,
    ACTIONS(6193), 1,
      anon_sym_RBRACE,
    STATE(5285), 1,
      sym_enum_assignment,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6189), 2,
      sym_number,
      sym_private_property_identifier,
    STATE(4446), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(2351), 23,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [113285] = 9,
    ACTIONS(1550), 1,
      anon_sym_DQUOTE,
    ACTIONS(1552), 1,
      anon_sym_SQUOTE,
    ACTIONS(4688), 1,
      anon_sym_LBRACK,
    ACTIONS(6195), 1,
      anon_sym_RBRACE,
    STATE(5285), 1,
      sym_enum_assignment,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6189), 2,
      sym_number,
      sym_private_property_identifier,
    STATE(4446), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(2351), 23,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [113339] = 9,
    ACTIONS(1550), 1,
      anon_sym_DQUOTE,
    ACTIONS(1552), 1,
      anon_sym_SQUOTE,
    ACTIONS(4688), 1,
      anon_sym_LBRACK,
    ACTIONS(6197), 1,
      anon_sym_RBRACE,
    STATE(5285), 1,
      sym_enum_assignment,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6189), 2,
      sym_number,
      sym_private_property_identifier,
    STATE(4446), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(2351), 23,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [113393] = 9,
    ACTIONS(1550), 1,
      anon_sym_DQUOTE,
    ACTIONS(1552), 1,
      anon_sym_SQUOTE,
    ACTIONS(4688), 1,
      anon_sym_LBRACK,
    ACTIONS(6199), 1,
      anon_sym_RBRACE,
    STATE(5285), 1,
      sym_enum_assignment,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6189), 2,
      sym_number,
      sym_private_property_identifier,
    STATE(4446), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(2351), 23,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [113447] = 12,
    ACTIONS(1626), 1,
      anon_sym_DQUOTE,
    ACTIONS(1628), 1,
      anon_sym_SQUOTE,
    ACTIONS(3722), 1,
      anon_sym_override,
    ACTIONS(4624), 1,
      anon_sym_LBRACK,
    ACTIONS(5904), 1,
      anon_sym_readonly,
    ACTIONS(6201), 1,
      anon_sym_STAR,
    STATE(2799), 1,
      sym_override_modifier,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6203), 2,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(6205), 2,
      anon_sym_get,
      anon_sym_set,
    STATE(3065), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(3700), 19,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [113507] = 9,
    ACTIONS(1550), 1,
      anon_sym_DQUOTE,
    ACTIONS(1552), 1,
      anon_sym_SQUOTE,
    ACTIONS(4688), 1,
      anon_sym_LBRACK,
    ACTIONS(6207), 1,
      anon_sym_RBRACE,
    STATE(5285), 1,
      sym_enum_assignment,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6189), 2,
      sym_number,
      sym_private_property_identifier,
    STATE(4446), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(2351), 23,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [113561] = 9,
    ACTIONS(1550), 1,
      anon_sym_DQUOTE,
    ACTIONS(1552), 1,
      anon_sym_SQUOTE,
    ACTIONS(4688), 1,
      anon_sym_LBRACK,
    ACTIONS(6209), 1,
      anon_sym_RBRACE,
    STATE(5285), 1,
      sym_enum_assignment,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6189), 2,
      sym_number,
      sym_private_property_identifier,
    STATE(4446), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(2351), 23,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [113615] = 22,
    ACTIONS(97), 1,
      anon_sym_AT,
    ACTIONS(2137), 1,
      anon_sym_namespace,
    ACTIONS(2141), 1,
      anon_sym_import,
    ACTIONS(2143), 1,
      anon_sym_var,
    ACTIONS(2145), 1,
      anon_sym_let,
    ACTIONS(2147), 1,
      anon_sym_const,
    ACTIONS(2152), 1,
      anon_sym_class,
    ACTIONS(2154), 1,
      anon_sym_async,
    ACTIONS(2156), 1,
      anon_sym_function,
    ACTIONS(2161), 1,
      anon_sym_declare,
    ACTIONS(2165), 1,
      anon_sym_abstract,
    ACTIONS(2167), 1,
      anon_sym_interface,
    ACTIONS(2169), 1,
      anon_sym_enum,
    ACTIONS(2341), 1,
      anon_sym_type,
    ACTIONS(2343), 1,
      anon_sym_module,
    ACTIONS(2345), 1,
      anon_sym_global,
    STATE(824), 1,
      sym_internal_module,
    STATE(867), 1,
      sym_declaration,
    STATE(1344), 1,
      sym_decorator,
    STATE(4301), 1,
      aux_sym_export_statement_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    STATE(831), 13,
      sym_variable_declaration,
      sym_lexical_declaration,
      sym_class_declaration,
      sym_function_declaration,
      sym_generator_function_declaration,
      sym_function_signature,
      sym_ambient_declaration,
      sym_abstract_class_declaration,
      sym_module,
      sym_import_alias,
      sym_interface_declaration,
      sym_enum_declaration,
      sym_type_alias_declaration,
  [113695] = 22,
    ACTIONS(97), 1,
      anon_sym_AT,
    ACTIONS(2381), 1,
      anon_sym_type,
    ACTIONS(2383), 1,
      anon_sym_namespace,
    ACTIONS(2385), 1,
      anon_sym_import,
    ACTIONS(2387), 1,
      anon_sym_var,
    ACTIONS(2389), 1,
      anon_sym_let,
    ACTIONS(2391), 1,
      anon_sym_const,
    ACTIONS(2393), 1,
      anon_sym_class,
    ACTIONS(2395), 1,
      anon_sym_async,
    ACTIONS(2397), 1,
      anon_sym_function,
    ACTIONS(2399), 1,
      anon_sym_declare,
    ACTIONS(2401), 1,
      anon_sym_module,
    ACTIONS(2403), 1,
      anon_sym_abstract,
    ACTIONS(2405), 1,
      anon_sym_global,
    ACTIONS(2407), 1,
      anon_sym_interface,
    ACTIONS(2409), 1,
      anon_sym_enum,
    STATE(1344), 1,
      sym_decorator,
    STATE(4287), 1,
      sym_internal_module,
    STATE(4304), 1,
      aux_sym_export_statement_repeat1,
    STATE(4310), 1,
      sym_declaration,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    STATE(4275), 13,
      sym_variable_declaration,
      sym_lexical_declaration,
      sym_class_declaration,
      sym_function_declaration,
      sym_generator_function_declaration,
      sym_function_signature,
      sym_ambient_declaration,
      sym_abstract_class_declaration,
      sym_module,
      sym_import_alias,
      sym_interface_declaration,
      sym_enum_declaration,
      sym_type_alias_declaration,
  [113775] = 14,
    ACTIONS(1550), 1,
      anon_sym_DQUOTE,
    ACTIONS(1552), 1,
      anon_sym_SQUOTE,
    ACTIONS(2353), 1,
      anon_sym_async,
    ACTIONS(2355), 1,
      anon_sym_readonly,
    ACTIONS(2359), 1,
      anon_sym_override,
    ACTIONS(4688), 1,
      anon_sym_LBRACK,
    ACTIONS(4990), 1,
      anon_sym_STAR,
    ACTIONS(6211), 1,
      anon_sym_static,
    STATE(2813), 1,
      sym_override_modifier,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(2337), 2,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(2357), 2,
      anon_sym_get,
      anon_sym_set,
    STATE(3816), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(2351), 17,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_new,
      sym_identifier,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [113839] = 22,
    ACTIONS(97), 1,
      anon_sym_AT,
    ACTIONS(2137), 1,
      anon_sym_namespace,
    ACTIONS(2141), 1,
      anon_sym_import,
    ACTIONS(2143), 1,
      anon_sym_var,
    ACTIONS(2145), 1,
      anon_sym_let,
    ACTIONS(2147), 1,
      anon_sym_const,
    ACTIONS(2152), 1,
      anon_sym_class,
    ACTIONS(2154), 1,
      anon_sym_async,
    ACTIONS(2156), 1,
      anon_sym_function,
    ACTIONS(2161), 1,
      anon_sym_declare,
    ACTIONS(2163), 1,
      anon_sym_module,
    ACTIONS(2165), 1,
      anon_sym_abstract,
    ACTIONS(2167), 1,
      anon_sym_interface,
    ACTIONS(2169), 1,
      anon_sym_enum,
    ACTIONS(2341), 1,
      anon_sym_type,
    ACTIONS(6213), 1,
      anon_sym_default,
    STATE(824), 1,
      sym_internal_module,
    STATE(921), 1,
      sym_declaration,
    STATE(1344), 1,
      sym_decorator,
    STATE(4301), 1,
      aux_sym_export_statement_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    STATE(831), 13,
      sym_variable_declaration,
      sym_lexical_declaration,
      sym_class_declaration,
      sym_function_declaration,
      sym_generator_function_declaration,
      sym_function_signature,
      sym_ambient_declaration,
      sym_abstract_class_declaration,
      sym_module,
      sym_import_alias,
      sym_interface_declaration,
      sym_enum_declaration,
      sym_type_alias_declaration,
  [113919] = 22,
    ACTIONS(97), 1,
      anon_sym_AT,
    ACTIONS(2137), 1,
      anon_sym_namespace,
    ACTIONS(2141), 1,
      anon_sym_import,
    ACTIONS(2143), 1,
      anon_sym_var,
    ACTIONS(2145), 1,
      anon_sym_let,
    ACTIONS(2147), 1,
      anon_sym_const,
    ACTIONS(2152), 1,
      anon_sym_class,
    ACTIONS(2154), 1,
      anon_sym_async,
    ACTIONS(2156), 1,
      anon_sym_function,
    ACTIONS(2161), 1,
      anon_sym_declare,
    ACTIONS(2163), 1,
      anon_sym_module,
    ACTIONS(2165), 1,
      anon_sym_abstract,
    ACTIONS(2167), 1,
      anon_sym_interface,
    ACTIONS(2169), 1,
      anon_sym_enum,
    ACTIONS(2341), 1,
      anon_sym_type,
    ACTIONS(6215), 1,
      anon_sym_default,
    STATE(824), 1,
      sym_internal_module,
    STATE(921), 1,
      sym_declaration,
    STATE(1344), 1,
      sym_decorator,
    STATE(4301), 1,
      aux_sym_export_statement_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    STATE(831), 13,
      sym_variable_declaration,
      sym_lexical_declaration,
      sym_class_declaration,
      sym_function_declaration,
      sym_generator_function_declaration,
      sym_function_signature,
      sym_ambient_declaration,
      sym_abstract_class_declaration,
      sym_module,
      sym_import_alias,
      sym_interface_declaration,
      sym_enum_declaration,
      sym_type_alias_declaration,
  [113999] = 11,
    ACTIONS(1626), 1,
      anon_sym_DQUOTE,
    ACTIONS(1628), 1,
      anon_sym_SQUOTE,
    ACTIONS(4624), 1,
      anon_sym_LBRACK,
    ACTIONS(5103), 1,
      anon_sym_STAR,
    ACTIONS(5105), 1,
      anon_sym_async,
    ACTIONS(5109), 1,
      anon_sym_readonly,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(5107), 2,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(5111), 2,
      anon_sym_get,
      anon_sym_set,
    STATE(3135), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(3700), 19,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [114056] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3652), 7,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_number,
      sym_private_property_identifier,
      anon_sym_AT,
    ACTIONS(3650), 25,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
      anon_sym_abstract,
      anon_sym_accessor,
  [114097] = 11,
    ACTIONS(1626), 1,
      anon_sym_DQUOTE,
    ACTIONS(1628), 1,
      anon_sym_SQUOTE,
    ACTIONS(4624), 1,
      anon_sym_LBRACK,
    ACTIONS(5475), 1,
      anon_sym_STAR,
    ACTIONS(5481), 1,
      anon_sym_async,
    ACTIONS(6217), 1,
      anon_sym_readonly,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(5483), 2,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(5485), 2,
      anon_sym_get,
      anon_sym_set,
    STATE(3074), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(3700), 19,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [114154] = 11,
    ACTIONS(1626), 1,
      anon_sym_DQUOTE,
    ACTIONS(1628), 1,
      anon_sym_SQUOTE,
    ACTIONS(4620), 1,
      anon_sym_STAR,
    ACTIONS(4624), 1,
      anon_sym_LBRACK,
    ACTIONS(4626), 1,
      anon_sym_async,
    ACTIONS(4630), 1,
      anon_sym_readonly,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4628), 2,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(4632), 2,
      anon_sym_get,
      anon_sym_set,
    STATE(3144), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(3700), 19,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [114211] = 11,
    ACTIONS(1626), 1,
      anon_sym_DQUOTE,
    ACTIONS(1628), 1,
      anon_sym_SQUOTE,
    ACTIONS(4624), 1,
      anon_sym_LBRACK,
    ACTIONS(5066), 1,
      anon_sym_STAR,
    ACTIONS(5068), 1,
      anon_sym_async,
    ACTIONS(5072), 1,
      anon_sym_readonly,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(5070), 2,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(5074), 2,
      anon_sym_get,
      anon_sym_set,
    STATE(3064), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(3700), 19,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [114268] = 8,
    ACTIONS(1550), 1,
      anon_sym_DQUOTE,
    ACTIONS(1552), 1,
      anon_sym_SQUOTE,
    ACTIONS(4688), 1,
      anon_sym_LBRACK,
    STATE(5285), 1,
      sym_enum_assignment,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6189), 2,
      sym_number,
      sym_private_property_identifier,
    STATE(4446), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(2351), 23,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [114319] = 11,
    ACTIONS(1626), 1,
      anon_sym_DQUOTE,
    ACTIONS(1628), 1,
      anon_sym_SQUOTE,
    ACTIONS(4624), 1,
      anon_sym_LBRACK,
    ACTIONS(4656), 1,
      anon_sym_STAR,
    ACTIONS(4660), 1,
      anon_sym_async,
    ACTIONS(4664), 1,
      anon_sym_readonly,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4662), 2,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(4666), 2,
      anon_sym_get,
      anon_sym_set,
    STATE(3082), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(3700), 19,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [114376] = 9,
    ACTIONS(1550), 1,
      anon_sym_DQUOTE,
    ACTIONS(1552), 1,
      anon_sym_SQUOTE,
    ACTIONS(4688), 1,
      anon_sym_LBRACK,
    ACTIONS(6201), 1,
      anon_sym_STAR,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(5716), 2,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(6219), 2,
      anon_sym_get,
      anon_sym_set,
    STATE(3843), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(2351), 21,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [114429] = 11,
    ACTIONS(1626), 1,
      anon_sym_DQUOTE,
    ACTIONS(1628), 1,
      anon_sym_SQUOTE,
    ACTIONS(4624), 1,
      anon_sym_LBRACK,
    ACTIONS(5271), 1,
      anon_sym_STAR,
    ACTIONS(5273), 1,
      anon_sym_async,
    ACTIONS(6223), 1,
      anon_sym_readonly,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(5277), 2,
      anon_sym_get,
      anon_sym_set,
    ACTIONS(6221), 2,
      sym_number,
      sym_private_property_identifier,
    STATE(3058), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(3700), 19,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [114486] = 11,
    ACTIONS(1626), 1,
      anon_sym_DQUOTE,
    ACTIONS(1628), 1,
      anon_sym_SQUOTE,
    ACTIONS(4624), 1,
      anon_sym_LBRACK,
    ACTIONS(5137), 1,
      anon_sym_STAR,
    ACTIONS(5139), 1,
      anon_sym_async,
    ACTIONS(6227), 1,
      anon_sym_readonly,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(5145), 2,
      anon_sym_get,
      anon_sym_set,
    ACTIONS(6225), 2,
      sym_number,
      sym_private_property_identifier,
    STATE(3043), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(3700), 19,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [114543] = 9,
    ACTIONS(1550), 1,
      anon_sym_DQUOTE,
    ACTIONS(1552), 1,
      anon_sym_SQUOTE,
    ACTIONS(4688), 1,
      anon_sym_LBRACK,
    ACTIONS(6229), 1,
      anon_sym_STAR,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(5620), 2,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(6231), 2,
      anon_sym_get,
      anon_sym_set,
    STATE(3787), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(2351), 21,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [114596] = 11,
    ACTIONS(1626), 1,
      anon_sym_DQUOTE,
    ACTIONS(1628), 1,
      anon_sym_SQUOTE,
    ACTIONS(4624), 1,
      anon_sym_LBRACK,
    ACTIONS(5000), 1,
      anon_sym_STAR,
    ACTIONS(5002), 1,
      anon_sym_async,
    ACTIONS(5006), 1,
      anon_sym_readonly,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(5004), 2,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(5008), 2,
      anon_sym_get,
      anon_sym_set,
    STATE(3147), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(3700), 19,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [114653] = 11,
    ACTIONS(1626), 1,
      anon_sym_DQUOTE,
    ACTIONS(1628), 1,
      anon_sym_SQUOTE,
    ACTIONS(4624), 1,
      anon_sym_LBRACK,
    ACTIONS(5137), 1,
      anon_sym_STAR,
    ACTIONS(5139), 1,
      anon_sym_async,
    ACTIONS(6235), 1,
      anon_sym_readonly,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(5145), 2,
      anon_sym_get,
      anon_sym_set,
    ACTIONS(6233), 2,
      sym_number,
      sym_private_property_identifier,
    STATE(3080), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(3700), 19,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [114710] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3675), 7,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_number,
      sym_private_property_identifier,
      anon_sym_AT,
    ACTIONS(3673), 25,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
      anon_sym_abstract,
      anon_sym_accessor,
  [114751] = 11,
    ACTIONS(1626), 1,
      anon_sym_DQUOTE,
    ACTIONS(1628), 1,
      anon_sym_SQUOTE,
    ACTIONS(4624), 1,
      anon_sym_LBRACK,
    ACTIONS(5505), 1,
      anon_sym_STAR,
    ACTIONS(5511), 1,
      anon_sym_async,
    ACTIONS(6237), 1,
      anon_sym_readonly,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(5513), 2,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(5515), 2,
      anon_sym_get,
      anon_sym_set,
    STATE(3098), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(3700), 19,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [114808] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3667), 7,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_number,
      sym_private_property_identifier,
      anon_sym_AT,
    ACTIONS(3665), 25,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
      anon_sym_abstract,
      anon_sym_accessor,
  [114849] = 11,
    ACTIONS(1626), 1,
      anon_sym_DQUOTE,
    ACTIONS(1628), 1,
      anon_sym_SQUOTE,
    ACTIONS(4624), 1,
      anon_sym_LBRACK,
    ACTIONS(5151), 1,
      anon_sym_STAR,
    ACTIONS(5153), 1,
      anon_sym_async,
    ACTIONS(5157), 1,
      anon_sym_readonly,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(5155), 2,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(5159), 2,
      anon_sym_get,
      anon_sym_set,
    STATE(3097), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(3700), 19,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [114906] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3572), 7,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_number,
      sym_private_property_identifier,
      anon_sym_AT,
    ACTIONS(3570), 25,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
      anon_sym_abstract,
      anon_sym_accessor,
  [114947] = 11,
    ACTIONS(1550), 1,
      anon_sym_DQUOTE,
    ACTIONS(1552), 1,
      anon_sym_SQUOTE,
    ACTIONS(4688), 1,
      anon_sym_LBRACK,
    ACTIONS(6096), 1,
      anon_sym_STAR,
    ACTIONS(6098), 1,
      anon_sym_async,
    ACTIONS(6239), 1,
      anon_sym_readonly,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6100), 2,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(6102), 2,
      anon_sym_get,
      anon_sym_set,
    STATE(3872), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(2351), 19,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [115004] = 11,
    ACTIONS(1550), 1,
      anon_sym_DQUOTE,
    ACTIONS(1552), 1,
      anon_sym_SQUOTE,
    ACTIONS(2353), 1,
      anon_sym_async,
    ACTIONS(2355), 1,
      anon_sym_readonly,
    ACTIONS(4688), 1,
      anon_sym_LBRACK,
    ACTIONS(4990), 1,
      anon_sym_STAR,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(2337), 2,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(2357), 2,
      anon_sym_get,
      anon_sym_set,
    STATE(3816), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(2351), 19,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [115061] = 11,
    ACTIONS(1626), 1,
      anon_sym_DQUOTE,
    ACTIONS(1628), 1,
      anon_sym_SQUOTE,
    ACTIONS(4624), 1,
      anon_sym_LBRACK,
    ACTIONS(5393), 1,
      anon_sym_STAR,
    ACTIONS(5395), 1,
      anon_sym_async,
    ACTIONS(6241), 1,
      anon_sym_readonly,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(5397), 2,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(5399), 2,
      anon_sym_get,
      anon_sym_set,
    STATE(3143), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(3700), 19,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [115118] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3656), 7,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_number,
      sym_private_property_identifier,
      anon_sym_AT,
    ACTIONS(3654), 25,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
      anon_sym_abstract,
      anon_sym_accessor,
  [115159] = 11,
    ACTIONS(1626), 1,
      anon_sym_DQUOTE,
    ACTIONS(1628), 1,
      anon_sym_SQUOTE,
    ACTIONS(4624), 1,
      anon_sym_LBRACK,
    ACTIONS(5076), 1,
      anon_sym_STAR,
    ACTIONS(5078), 1,
      anon_sym_async,
    ACTIONS(6245), 1,
      anon_sym_readonly,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(5084), 2,
      anon_sym_get,
      anon_sym_set,
    ACTIONS(6243), 2,
      sym_number,
      sym_private_property_identifier,
    STATE(3070), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(3700), 19,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [115216] = 4,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3814), 3,
      anon_sym_LPAREN,
      anon_sym_LT,
      anon_sym_QMARK,
    ACTIONS(1975), 6,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(1973), 23,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [115259] = 11,
    ACTIONS(1550), 1,
      anon_sym_DQUOTE,
    ACTIONS(1552), 1,
      anon_sym_SQUOTE,
    ACTIONS(4688), 1,
      anon_sym_LBRACK,
    ACTIONS(6086), 1,
      anon_sym_STAR,
    ACTIONS(6088), 1,
      anon_sym_async,
    ACTIONS(6092), 1,
      anon_sym_readonly,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6090), 2,
      sym_number,
      sym_private_property_identifier,
    ACTIONS(6094), 2,
      anon_sym_get,
      anon_sym_set,
    STATE(3752), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(2351), 19,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [115316] = 8,
    ACTIONS(1626), 1,
      anon_sym_DQUOTE,
    ACTIONS(1628), 1,
      anon_sym_SQUOTE,
    ACTIONS(4624), 1,
      anon_sym_LBRACK,
    ACTIONS(5880), 1,
      anon_sym_readonly,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(5668), 2,
      sym_number,
      sym_private_property_identifier,
    STATE(3399), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(3700), 22,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [115366] = 8,
    ACTIONS(1626), 1,
      anon_sym_DQUOTE,
    ACTIONS(1628), 1,
      anon_sym_SQUOTE,
    ACTIONS(4624), 1,
      anon_sym_LBRACK,
    ACTIONS(6249), 1,
      anon_sym_readonly,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6247), 2,
      sym_number,
      sym_private_property_identifier,
    STATE(3460), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(3700), 22,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [115416] = 7,
    ACTIONS(1626), 1,
      anon_sym_DQUOTE,
    ACTIONS(1628), 1,
      anon_sym_SQUOTE,
    ACTIONS(4624), 1,
      anon_sym_LBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6251), 2,
      sym_number,
      sym_private_property_identifier,
    STATE(3321), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(3700), 23,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [115464] = 7,
    ACTIONS(1550), 1,
      anon_sym_DQUOTE,
    ACTIONS(1552), 1,
      anon_sym_SQUOTE,
    ACTIONS(4688), 1,
      anon_sym_LBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6090), 2,
      sym_number,
      sym_private_property_identifier,
    STATE(3752), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(2351), 23,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [115512] = 7,
    ACTIONS(1550), 1,
      anon_sym_DQUOTE,
    ACTIONS(1552), 1,
      anon_sym_SQUOTE,
    ACTIONS(4688), 1,
      anon_sym_LBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(5507), 2,
      sym_number,
      sym_private_property_identifier,
    STATE(3802), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(2351), 23,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [115560] = 7,
    ACTIONS(1550), 1,
      anon_sym_DQUOTE,
    ACTIONS(1552), 1,
      anon_sym_SQUOTE,
    ACTIONS(4688), 1,
      anon_sym_LBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(5346), 2,
      sym_number,
      sym_private_property_identifier,
    STATE(3845), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(2351), 23,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [115608] = 7,
    ACTIONS(1550), 1,
      anon_sym_DQUOTE,
    ACTIONS(1552), 1,
      anon_sym_SQUOTE,
    ACTIONS(4688), 1,
      anon_sym_LBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(5364), 2,
      sym_number,
      sym_private_property_identifier,
    STATE(3798), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(2351), 23,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [115656] = 7,
    ACTIONS(1626), 1,
      anon_sym_DQUOTE,
    ACTIONS(1628), 1,
      anon_sym_SQUOTE,
    ACTIONS(4624), 1,
      anon_sym_LBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(5668), 2,
      sym_number,
      sym_private_property_identifier,
    STATE(3399), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(3700), 23,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [115704] = 7,
    ACTIONS(1550), 1,
      anon_sym_DQUOTE,
    ACTIONS(1552), 1,
      anon_sym_SQUOTE,
    ACTIONS(4688), 1,
      anon_sym_LBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(5419), 2,
      sym_number,
      sym_private_property_identifier,
    STATE(3882), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(2351), 23,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [115752] = 7,
    ACTIONS(1550), 1,
      anon_sym_DQUOTE,
    ACTIONS(1552), 1,
      anon_sym_SQUOTE,
    ACTIONS(4688), 1,
      anon_sym_LBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(5620), 2,
      sym_number,
      sym_private_property_identifier,
    STATE(3787), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(2351), 23,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [115800] = 7,
    ACTIONS(1626), 1,
      anon_sym_DQUOTE,
    ACTIONS(1628), 1,
      anon_sym_SQUOTE,
    ACTIONS(4624), 1,
      anon_sym_LBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4674), 2,
      sym_number,
      sym_private_property_identifier,
    STATE(3360), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(3700), 23,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [115848] = 7,
    ACTIONS(1550), 1,
      anon_sym_DQUOTE,
    ACTIONS(1552), 1,
      anon_sym_SQUOTE,
    ACTIONS(4688), 1,
      anon_sym_LBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(5477), 2,
      sym_number,
      sym_private_property_identifier,
    STATE(3898), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(2351), 23,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [115896] = 7,
    ACTIONS(1626), 1,
      anon_sym_DQUOTE,
    ACTIONS(1628), 1,
      anon_sym_SQUOTE,
    ACTIONS(4624), 1,
      anon_sym_LBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4840), 2,
      sym_number,
      sym_private_property_identifier,
    STATE(3368), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(3700), 23,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [115944] = 7,
    ACTIONS(1550), 1,
      anon_sym_DQUOTE,
    ACTIONS(1552), 1,
      anon_sym_SQUOTE,
    ACTIONS(4688), 1,
      anon_sym_LBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6136), 2,
      sym_number,
      sym_private_property_identifier,
    STATE(3840), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(2351), 23,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [115992] = 7,
    ACTIONS(1550), 1,
      anon_sym_DQUOTE,
    ACTIONS(1552), 1,
      anon_sym_SQUOTE,
    ACTIONS(4688), 1,
      anon_sym_LBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(5433), 2,
      sym_number,
      sym_private_property_identifier,
    STATE(3836), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(2351), 23,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [116040] = 8,
    ACTIONS(1626), 1,
      anon_sym_DQUOTE,
    ACTIONS(1628), 1,
      anon_sym_SQUOTE,
    ACTIONS(4624), 1,
      anon_sym_LBRACK,
    ACTIONS(5904), 1,
      anon_sym_readonly,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4840), 2,
      sym_number,
      sym_private_property_identifier,
    STATE(3368), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(3700), 22,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [116090] = 7,
    ACTIONS(1550), 1,
      anon_sym_DQUOTE,
    ACTIONS(1552), 1,
      anon_sym_SQUOTE,
    ACTIONS(4688), 1,
      anon_sym_LBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(5716), 2,
      sym_number,
      sym_private_property_identifier,
    STATE(3843), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(2351), 23,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [116138] = 7,
    ACTIONS(1550), 1,
      anon_sym_DQUOTE,
    ACTIONS(1552), 1,
      anon_sym_SQUOTE,
    ACTIONS(4688), 1,
      anon_sym_LBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(5441), 2,
      sym_number,
      sym_private_property_identifier,
    STATE(3753), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(2351), 23,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [116186] = 7,
    ACTIONS(1550), 1,
      anon_sym_DQUOTE,
    ACTIONS(1552), 1,
      anon_sym_SQUOTE,
    ACTIONS(4688), 1,
      anon_sym_LBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(5292), 2,
      sym_number,
      sym_private_property_identifier,
    STATE(3853), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(2351), 23,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [116234] = 7,
    ACTIONS(1626), 1,
      anon_sym_DQUOTE,
    ACTIONS(1628), 1,
      anon_sym_SQUOTE,
    ACTIONS(4624), 1,
      anon_sym_LBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6253), 2,
      sym_number,
      sym_private_property_identifier,
    STATE(3442), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(3700), 23,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [116282] = 7,
    ACTIONS(1550), 1,
      anon_sym_DQUOTE,
    ACTIONS(1552), 1,
      anon_sym_SQUOTE,
    ACTIONS(4688), 1,
      anon_sym_LBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4690), 2,
      sym_number,
      sym_private_property_identifier,
    STATE(3866), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(2351), 23,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [116330] = 7,
    ACTIONS(1550), 1,
      anon_sym_DQUOTE,
    ACTIONS(1552), 1,
      anon_sym_SQUOTE,
    ACTIONS(4688), 1,
      anon_sym_LBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(5449), 2,
      sym_number,
      sym_private_property_identifier,
    STATE(3828), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(2351), 23,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [116378] = 7,
    ACTIONS(1550), 1,
      anon_sym_DQUOTE,
    ACTIONS(1552), 1,
      anon_sym_SQUOTE,
    ACTIONS(4688), 1,
      anon_sym_LBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(5539), 2,
      sym_number,
      sym_private_property_identifier,
    STATE(3890), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(2351), 23,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [116426] = 7,
    ACTIONS(1550), 1,
      anon_sym_DQUOTE,
    ACTIONS(1552), 1,
      anon_sym_SQUOTE,
    ACTIONS(4688), 1,
      anon_sym_LBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(5330), 2,
      sym_number,
      sym_private_property_identifier,
    STATE(3822), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(2351), 23,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [116474] = 7,
    ACTIONS(1550), 1,
      anon_sym_DQUOTE,
    ACTIONS(1552), 1,
      anon_sym_SQUOTE,
    ACTIONS(4688), 1,
      anon_sym_LBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6140), 2,
      sym_number,
      sym_private_property_identifier,
    STATE(3860), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(2351), 23,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [116522] = 7,
    ACTIONS(1550), 1,
      anon_sym_DQUOTE,
    ACTIONS(1552), 1,
      anon_sym_SQUOTE,
    ACTIONS(4688), 1,
      anon_sym_LBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(5547), 2,
      sym_number,
      sym_private_property_identifier,
    STATE(3851), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(2351), 23,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [116570] = 7,
    ACTIONS(1550), 1,
      anon_sym_DQUOTE,
    ACTIONS(1552), 1,
      anon_sym_SQUOTE,
    ACTIONS(4688), 1,
      anon_sym_LBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6100), 2,
      sym_number,
      sym_private_property_identifier,
    STATE(3872), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(2351), 23,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [116618] = 7,
    ACTIONS(1550), 1,
      anon_sym_DQUOTE,
    ACTIONS(1552), 1,
      anon_sym_SQUOTE,
    ACTIONS(4688), 1,
      anon_sym_LBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(5211), 2,
      sym_number,
      sym_private_property_identifier,
    STATE(3878), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(2351), 23,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [116666] = 7,
    ACTIONS(1550), 1,
      anon_sym_DQUOTE,
    ACTIONS(1552), 1,
      anon_sym_SQUOTE,
    ACTIONS(4688), 1,
      anon_sym_LBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6153), 2,
      sym_number,
      sym_private_property_identifier,
    STATE(3833), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(2351), 23,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [116714] = 8,
    ACTIONS(1626), 1,
      anon_sym_DQUOTE,
    ACTIONS(1628), 1,
      anon_sym_SQUOTE,
    ACTIONS(4624), 1,
      anon_sym_LBRACK,
    ACTIONS(6257), 1,
      anon_sym_readonly,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6255), 2,
      sym_number,
      sym_private_property_identifier,
    STATE(3451), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(3700), 22,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [116764] = 7,
    ACTIONS(1550), 1,
      anon_sym_DQUOTE,
    ACTIONS(1552), 1,
      anon_sym_SQUOTE,
    ACTIONS(4688), 1,
      anon_sym_LBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(5405), 2,
      sym_number,
      sym_private_property_identifier,
    STATE(3888), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(2351), 23,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [116812] = 7,
    ACTIONS(1550), 1,
      anon_sym_DQUOTE,
    ACTIONS(1552), 1,
      anon_sym_SQUOTE,
    ACTIONS(4688), 1,
      anon_sym_LBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6148), 2,
      sym_number,
      sym_private_property_identifier,
    STATE(3897), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(2351), 23,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [116860] = 7,
    ACTIONS(1550), 1,
      anon_sym_DQUOTE,
    ACTIONS(1552), 1,
      anon_sym_SQUOTE,
    ACTIONS(4688), 1,
      anon_sym_LBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6120), 2,
      sym_number,
      sym_private_property_identifier,
    STATE(3837), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(2351), 23,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [116908] = 8,
    ACTIONS(1626), 1,
      anon_sym_DQUOTE,
    ACTIONS(1628), 1,
      anon_sym_SQUOTE,
    ACTIONS(4624), 1,
      anon_sym_LBRACK,
    ACTIONS(6259), 1,
      anon_sym_readonly,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(5982), 2,
      sym_number,
      sym_private_property_identifier,
    STATE(3358), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(3700), 22,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [116958] = 7,
    ACTIONS(1626), 1,
      anon_sym_DQUOTE,
    ACTIONS(1628), 1,
      anon_sym_SQUOTE,
    ACTIONS(4624), 1,
      anon_sym_LBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(5982), 2,
      sym_number,
      sym_private_property_identifier,
    STATE(3358), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(3700), 23,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [117006] = 7,
    ACTIONS(1626), 1,
      anon_sym_DQUOTE,
    ACTIONS(1628), 1,
      anon_sym_SQUOTE,
    ACTIONS(4624), 1,
      anon_sym_LBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6261), 2,
      sym_number,
      sym_private_property_identifier,
    STATE(3452), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(3700), 23,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [117054] = 8,
    ACTIONS(1626), 1,
      anon_sym_DQUOTE,
    ACTIONS(1628), 1,
      anon_sym_SQUOTE,
    ACTIONS(4624), 1,
      anon_sym_LBRACK,
    ACTIONS(6265), 1,
      anon_sym_readonly,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6263), 2,
      sym_number,
      sym_private_property_identifier,
    STATE(3402), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(3700), 22,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [117104] = 8,
    ACTIONS(1626), 1,
      anon_sym_DQUOTE,
    ACTIONS(1628), 1,
      anon_sym_SQUOTE,
    ACTIONS(4624), 1,
      anon_sym_LBRACK,
    ACTIONS(6269), 1,
      anon_sym_readonly,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6267), 2,
      sym_number,
      sym_private_property_identifier,
    STATE(3422), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(3700), 22,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [117154] = 7,
    ACTIONS(1626), 1,
      anon_sym_DQUOTE,
    ACTIONS(1628), 1,
      anon_sym_SQUOTE,
    ACTIONS(4624), 1,
      anon_sym_LBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6271), 2,
      sym_number,
      sym_private_property_identifier,
    STATE(3425), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(3700), 23,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [117202] = 8,
    ACTIONS(1626), 1,
      anon_sym_DQUOTE,
    ACTIONS(1628), 1,
      anon_sym_SQUOTE,
    ACTIONS(4624), 1,
      anon_sym_LBRACK,
    ACTIONS(6275), 1,
      anon_sym_readonly,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6273), 2,
      sym_number,
      sym_private_property_identifier,
    STATE(3461), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(3700), 22,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [117252] = 7,
    ACTIONS(1626), 1,
      anon_sym_DQUOTE,
    ACTIONS(1628), 1,
      anon_sym_SQUOTE,
    ACTIONS(4624), 1,
      anon_sym_LBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6277), 2,
      sym_number,
      sym_private_property_identifier,
    STATE(3350), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(3700), 23,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [117300] = 7,
    ACTIONS(1550), 1,
      anon_sym_DQUOTE,
    ACTIONS(1552), 1,
      anon_sym_SQUOTE,
    ACTIONS(4688), 1,
      anon_sym_LBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6144), 2,
      sym_number,
      sym_private_property_identifier,
    STATE(3880), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(2351), 23,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [117348] = 7,
    ACTIONS(1550), 1,
      anon_sym_DQUOTE,
    ACTIONS(1552), 1,
      anon_sym_SQUOTE,
    ACTIONS(4688), 1,
      anon_sym_LBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(5411), 2,
      sym_number,
      sym_private_property_identifier,
    STATE(3874), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(2351), 23,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [117396] = 8,
    ACTIONS(1626), 1,
      anon_sym_DQUOTE,
    ACTIONS(1628), 1,
      anon_sym_SQUOTE,
    ACTIONS(4624), 1,
      anon_sym_LBRACK,
    ACTIONS(6281), 1,
      anon_sym_readonly,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6279), 2,
      sym_number,
      sym_private_property_identifier,
    STATE(3392), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(3700), 22,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [117446] = 7,
    ACTIONS(1550), 1,
      anon_sym_DQUOTE,
    ACTIONS(1552), 1,
      anon_sym_SQUOTE,
    ACTIONS(4688), 1,
      anon_sym_LBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(5376), 2,
      sym_number,
      sym_private_property_identifier,
    STATE(3781), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(2351), 23,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [117494] = 7,
    ACTIONS(1626), 1,
      anon_sym_DQUOTE,
    ACTIONS(1628), 1,
      anon_sym_SQUOTE,
    ACTIONS(4624), 1,
      anon_sym_LBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6283), 2,
      sym_number,
      sym_private_property_identifier,
    STATE(3394), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(3700), 23,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [117542] = 7,
    ACTIONS(1550), 1,
      anon_sym_DQUOTE,
    ACTIONS(1552), 1,
      anon_sym_SQUOTE,
    ACTIONS(4688), 1,
      anon_sym_LBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(5300), 2,
      sym_number,
      sym_private_property_identifier,
    STATE(3780), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(2351), 23,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [117590] = 7,
    ACTIONS(1550), 1,
      anon_sym_DQUOTE,
    ACTIONS(1552), 1,
      anon_sym_SQUOTE,
    ACTIONS(4688), 1,
      anon_sym_LBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(2337), 2,
      sym_number,
      sym_private_property_identifier,
    STATE(3816), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(2351), 23,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [117638] = 8,
    ACTIONS(1626), 1,
      anon_sym_DQUOTE,
    ACTIONS(1628), 1,
      anon_sym_SQUOTE,
    ACTIONS(4624), 1,
      anon_sym_LBRACK,
    ACTIONS(6287), 1,
      anon_sym_readonly,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6285), 2,
      sym_number,
      sym_private_property_identifier,
    STATE(3423), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(3700), 22,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [117688] = 7,
    ACTIONS(1626), 1,
      anon_sym_DQUOTE,
    ACTIONS(1628), 1,
      anon_sym_SQUOTE,
    ACTIONS(4624), 1,
      anon_sym_LBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6289), 2,
      sym_number,
      sym_private_property_identifier,
    STATE(3426), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(3700), 23,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [117736] = 7,
    ACTIONS(1550), 1,
      anon_sym_DQUOTE,
    ACTIONS(1552), 1,
      anon_sym_SQUOTE,
    ACTIONS(4688), 1,
      anon_sym_LBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6146), 2,
      sym_number,
      sym_private_property_identifier,
    STATE(3841), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(2351), 23,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [117784] = 8,
    ACTIONS(1626), 1,
      anon_sym_DQUOTE,
    ACTIONS(1628), 1,
      anon_sym_SQUOTE,
    ACTIONS(4624), 1,
      anon_sym_LBRACK,
    ACTIONS(6293), 1,
      anon_sym_readonly,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6291), 2,
      sym_number,
      sym_private_property_identifier,
    STATE(3391), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(3700), 22,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [117834] = 7,
    ACTIONS(1626), 1,
      anon_sym_DQUOTE,
    ACTIONS(1628), 1,
      anon_sym_SQUOTE,
    ACTIONS(4624), 1,
      anon_sym_LBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6295), 2,
      sym_number,
      sym_private_property_identifier,
    STATE(3393), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(3700), 23,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [117882] = 7,
    ACTIONS(1550), 1,
      anon_sym_DQUOTE,
    ACTIONS(1552), 1,
      anon_sym_SQUOTE,
    ACTIONS(4688), 1,
      anon_sym_LBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(5427), 2,
      sym_number,
      sym_private_property_identifier,
    STATE(3804), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(2351), 23,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [117930] = 8,
    ACTIONS(1626), 1,
      anon_sym_DQUOTE,
    ACTIONS(1628), 1,
      anon_sym_SQUOTE,
    ACTIONS(4624), 1,
      anon_sym_LBRACK,
    ACTIONS(6299), 1,
      anon_sym_readonly,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6297), 2,
      sym_number,
      sym_private_property_identifier,
    STATE(3405), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(3700), 22,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [117980] = 7,
    ACTIONS(1550), 1,
      anon_sym_DQUOTE,
    ACTIONS(1552), 1,
      anon_sym_SQUOTE,
    ACTIONS(4688), 1,
      anon_sym_LBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(5279), 2,
      sym_number,
      sym_private_property_identifier,
    STATE(3863), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(2351), 23,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [118028] = 8,
    ACTIONS(1626), 1,
      anon_sym_DQUOTE,
    ACTIONS(1628), 1,
      anon_sym_SQUOTE,
    ACTIONS(4624), 1,
      anon_sym_LBRACK,
    ACTIONS(6303), 1,
      anon_sym_readonly,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6301), 2,
      sym_number,
      sym_private_property_identifier,
    STATE(3323), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(3700), 22,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [118078] = 7,
    ACTIONS(1626), 1,
      anon_sym_DQUOTE,
    ACTIONS(1628), 1,
      anon_sym_SQUOTE,
    ACTIONS(4624), 1,
      anon_sym_LBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6305), 2,
      sym_number,
      sym_private_property_identifier,
    STATE(3324), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(3700), 23,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [118126] = 8,
    ACTIONS(1626), 1,
      anon_sym_DQUOTE,
    ACTIONS(1628), 1,
      anon_sym_SQUOTE,
    ACTIONS(4624), 1,
      anon_sym_LBRACK,
    ACTIONS(6309), 1,
      anon_sym_readonly,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6307), 2,
      sym_number,
      sym_private_property_identifier,
    STATE(3333), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(3700), 22,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [118176] = 7,
    ACTIONS(1626), 1,
      anon_sym_DQUOTE,
    ACTIONS(1628), 1,
      anon_sym_SQUOTE,
    ACTIONS(4624), 1,
      anon_sym_LBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6311), 2,
      sym_number,
      sym_private_property_identifier,
    STATE(3408), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(3700), 23,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [118224] = 7,
    ACTIONS(1550), 1,
      anon_sym_DQUOTE,
    ACTIONS(1552), 1,
      anon_sym_SQUOTE,
    ACTIONS(4688), 1,
      anon_sym_LBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6142), 2,
      sym_number,
      sym_private_property_identifier,
    STATE(3846), 3,
      sym_string,
      sym__property_name,
      sym_computed_property_name,
    ACTIONS(2351), 23,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      sym_identifier,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [118272] = 4,
    ACTIONS(6313), 1,
      sym_identifier,
    STATE(5613), 1,
      sym_mapped_type_clause,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6315), 22,
      anon_sym_export,
      anon_sym_type,
      anon_sym_namespace,
      anon_sym_let,
      anon_sym_async,
      anon_sym_new,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_get,
      anon_sym_set,
      anon_sym_declare,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_override,
      anon_sym_module,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
  [118307] = 9,
    ACTIONS(3514), 1,
      anon_sym_LPAREN,
    ACTIONS(3576), 1,
      anon_sym_LT,
    ACTIONS(6317), 1,
      anon_sym_DOT,
    ACTIONS(6319), 1,
      anon_sym_QMARK_DOT,
    STATE(2918), 1,
      sym_arguments,
    STATE(2975), 1,
      sym_type_arguments,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4068), 2,
      anon_sym_EQ,
      anon_sym_QMARK,
    ACTIONS(4070), 12,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_EQ_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_extends,
  [118348] = 9,
    ACTIONS(3514), 1,
      anon_sym_LPAREN,
    ACTIONS(3576), 1,
      anon_sym_LT,
    ACTIONS(6321), 1,
      anon_sym_DOT,
    ACTIONS(6323), 1,
      anon_sym_QMARK_DOT,
    STATE(2920), 1,
      sym_arguments,
    STATE(2973), 1,
      sym_type_arguments,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4060), 2,
      anon_sym_EQ,
      anon_sym_QMARK,
    ACTIONS(4062), 12,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_EQ_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_extends,
  [118389] = 9,
    ACTIONS(3514), 1,
      anon_sym_LPAREN,
    ACTIONS(3516), 1,
      anon_sym_DOT,
    ACTIONS(3520), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(3576), 1,
      anon_sym_LT,
    STATE(2917), 1,
      sym_arguments,
    STATE(3015), 1,
      sym_type_arguments,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3522), 2,
      anon_sym_EQ,
      anon_sym_QMARK,
    ACTIONS(3512), 12,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_EQ_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_extends,
  [118430] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4380), 2,
      anon_sym_EQ,
      anon_sym_QMARK,
    ACTIONS(4382), 17,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_EQ_GT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_extends,
  [118458] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4284), 2,
      anon_sym_EQ,
      anon_sym_QMARK,
    ACTIONS(4286), 17,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_EQ_GT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_extends,
  [118486] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4284), 2,
      anon_sym_EQ,
      anon_sym_QMARK,
    ACTIONS(4286), 17,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_EQ_GT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_extends,
  [118514] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4308), 2,
      anon_sym_EQ,
      anon_sym_QMARK,
    ACTIONS(4310), 17,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_EQ_GT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_extends,
  [118542] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4246), 2,
      anon_sym_EQ,
      anon_sym_QMARK,
    ACTIONS(4248), 17,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_EQ_GT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_extends,
  [118570] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4242), 2,
      anon_sym_EQ,
      anon_sym_QMARK,
    ACTIONS(4244), 17,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_EQ_GT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_extends,
  [118598] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4246), 2,
      anon_sym_EQ,
      anon_sym_QMARK,
    ACTIONS(4248), 17,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_EQ_GT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_extends,
  [118626] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4246), 2,
      anon_sym_EQ,
      anon_sym_QMARK,
    ACTIONS(4248), 17,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_EQ_GT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_extends,
  [118654] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4242), 2,
      anon_sym_EQ,
      anon_sym_QMARK,
    ACTIONS(4244), 17,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_EQ_GT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_extends,
  [118682] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4276), 2,
      anon_sym_EQ,
      anon_sym_QMARK,
    ACTIONS(4278), 17,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_EQ_GT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_extends,
  [118710] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4158), 2,
      anon_sym_EQ,
      anon_sym_QMARK,
    ACTIONS(4160), 17,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_EQ_GT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_extends,
  [118738] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4312), 2,
      anon_sym_EQ,
      anon_sym_QMARK,
    ACTIONS(4314), 17,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_EQ_GT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_extends,
  [118766] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4280), 2,
      anon_sym_EQ,
      anon_sym_QMARK,
    ACTIONS(4282), 17,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_EQ_GT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_extends,
  [118794] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4122), 2,
      anon_sym_EQ,
      anon_sym_QMARK,
    ACTIONS(4124), 17,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_EQ_GT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_extends,
  [118822] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4280), 2,
      anon_sym_EQ,
      anon_sym_QMARK,
    ACTIONS(4282), 17,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_EQ_GT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_extends,
  [118850] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4308), 2,
      anon_sym_EQ,
      anon_sym_QMARK,
    ACTIONS(4310), 17,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_EQ_GT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_extends,
  [118878] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4122), 2,
      anon_sym_EQ,
      anon_sym_QMARK,
    ACTIONS(4124), 17,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_EQ_GT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_extends,
  [118906] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4132), 2,
      anon_sym_EQ,
      anon_sym_QMARK,
    ACTIONS(4134), 17,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_EQ_GT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_extends,
  [118934] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4136), 2,
      anon_sym_EQ,
      anon_sym_QMARK,
    ACTIONS(4138), 17,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_EQ_GT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_extends,
  [118962] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4284), 2,
      anon_sym_EQ,
      anon_sym_QMARK,
    ACTIONS(4286), 17,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_EQ_GT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_extends,
  [118990] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4132), 2,
      anon_sym_EQ,
      anon_sym_QMARK,
    ACTIONS(4134), 17,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_EQ_GT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_extends,
  [119018] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4136), 2,
      anon_sym_EQ,
      anon_sym_QMARK,
    ACTIONS(4138), 17,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_EQ_GT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_extends,
  [119046] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4162), 2,
      anon_sym_EQ,
      anon_sym_QMARK,
    ACTIONS(4164), 17,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_EQ_GT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_extends,
  [119074] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4234), 2,
      anon_sym_EQ,
      anon_sym_QMARK,
    ACTIONS(4236), 17,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_EQ_GT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_extends,
  [119102] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4238), 2,
      anon_sym_EQ,
      anon_sym_QMARK,
    ACTIONS(4240), 17,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_EQ_GT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_extends,
  [119130] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4238), 2,
      anon_sym_EQ,
      anon_sym_QMARK,
    ACTIONS(4240), 17,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_EQ_GT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_extends,
  [119158] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4166), 2,
      anon_sym_EQ,
      anon_sym_QMARK,
    ACTIONS(4168), 17,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_EQ_GT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_extends,
  [119186] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4238), 2,
      anon_sym_EQ,
      anon_sym_QMARK,
    ACTIONS(4240), 17,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_EQ_GT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_extends,
  [119214] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4162), 2,
      anon_sym_EQ,
      anon_sym_QMARK,
    ACTIONS(4164), 17,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_EQ_GT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_extends,
  [119242] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4166), 2,
      anon_sym_EQ,
      anon_sym_QMARK,
    ACTIONS(4168), 17,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_EQ_GT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_extends,
  [119270] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4242), 2,
      anon_sym_EQ,
      anon_sym_QMARK,
    ACTIONS(4244), 17,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_EQ_GT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_extends,
  [119298] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4308), 2,
      anon_sym_EQ,
      anon_sym_QMARK,
    ACTIONS(4310), 17,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_EQ_GT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_extends,
  [119326] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4280), 2,
      anon_sym_EQ,
      anon_sym_QMARK,
    ACTIONS(4282), 17,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_EQ_GT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_extends,
  [119354] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4380), 2,
      anon_sym_EQ,
      anon_sym_QMARK,
    ACTIONS(4382), 17,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_EQ_GT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_extends,
  [119382] = 3,
    ACTIONS(1728), 1,
      anon_sym_PIPE,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(1726), 17,
      sym__automatic_semicolon,
      anon_sym_EQ,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_with,
      anon_sym_assert,
      anon_sym_BANG,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_QMARK,
      anon_sym_extends,
      anon_sym_PIPE_RBRACE,
  [119409] = 3,
    ACTIONS(1756), 1,
      anon_sym_PIPE,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(1754), 17,
      sym__automatic_semicolon,
      anon_sym_EQ,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_with,
      anon_sym_assert,
      anon_sym_BANG,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_QMARK,
      anon_sym_extends,
      anon_sym_PIPE_RBRACE,
  [119436] = 3,
    ACTIONS(4418), 1,
      anon_sym_EQ,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4420), 16,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_EQ_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_extends,
  [119462] = 5,
    ACTIONS(3516), 1,
      anon_sym_DOT,
    ACTIONS(3520), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3522), 2,
      anon_sym_EQ,
      anon_sym_QMARK,
    ACTIONS(3512), 13,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_EQ_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_extends,
  [119492] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4320), 2,
      anon_sym_EQ,
      anon_sym_QMARK,
    ACTIONS(4322), 15,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_EQ_GT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_extends,
  [119518] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4328), 2,
      anon_sym_EQ,
      anon_sym_QMARK,
    ACTIONS(4330), 15,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_EQ_GT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_extends,
  [119544] = 3,
    ACTIONS(4426), 1,
      anon_sym_EQ,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4428), 16,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_EQ_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_extends,
  [119570] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4346), 2,
      anon_sym_EQ,
      anon_sym_QMARK,
    ACTIONS(4348), 15,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_EQ_GT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_extends,
  [119596] = 15,
    ACTIONS(1626), 1,
      anon_sym_DQUOTE,
    ACTIONS(1628), 1,
      anon_sym_SQUOTE,
    ACTIONS(6325), 1,
      sym_identifier,
    ACTIONS(6327), 1,
      anon_sym_STAR,
    ACTIONS(6329), 1,
      anon_sym_type,
    ACTIONS(6331), 1,
      anon_sym_LBRACE,
    ACTIONS(6333), 1,
      anon_sym_typeof,
    ACTIONS(6337), 1,
      anon_sym_DOT,
    STATE(4113), 1,
      sym_string,
    STATE(4131), 1,
      sym_import_require_clause,
    STATE(5136), 1,
      sym__import_identifier,
    STATE(5258), 1,
      sym_import_clause,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    STATE(5844), 2,
      sym_namespace_import,
      sym_named_imports,
    ACTIONS(6335), 3,
      anon_sym_LPAREN,
      anon_sym_QMARK_DOT,
      anon_sym_LT,
  [119646] = 5,
    ACTIONS(6339), 1,
      anon_sym_DOT,
    ACTIONS(6341), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4224), 2,
      anon_sym_EQ,
      anon_sym_QMARK,
    ACTIONS(4226), 13,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_EQ_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_extends,
  [119676] = 6,
    ACTIONS(3576), 1,
      anon_sym_LT,
    ACTIONS(4054), 1,
      anon_sym_EQ,
    ACTIONS(6343), 1,
      anon_sym_DOT,
    STATE(2964), 1,
      sym_type_arguments,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3548), 13,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_EQ_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_extends,
  [119708] = 4,
    ACTIONS(1888), 1,
      anon_sym_DOT,
    ACTIONS(4384), 1,
      anon_sym_EQ,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4386), 15,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_EQ_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_extends,
  [119736] = 9,
    ACTIONS(3522), 1,
      anon_sym_PIPE,
    ACTIONS(3528), 1,
      anon_sym_LPAREN,
    ACTIONS(3530), 1,
      anon_sym_DOT,
    ACTIONS(3532), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(6345), 1,
      anon_sym_LT,
    STATE(3086), 1,
      sym_arguments,
    STATE(3215), 1,
      sym_type_arguments,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3512), 10,
      sym__automatic_semicolon,
      anon_sym_EQ,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_AMP,
      anon_sym_extends,
      anon_sym_PIPE_RBRACE,
  [119774] = 3,
    ACTIONS(3691), 1,
      anon_sym_EQ,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3474), 16,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_EQ_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_extends,
  [119800] = 3,
    ACTIONS(3679), 1,
      anon_sym_EQ,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3478), 16,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_EQ_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_extends,
  [119826] = 3,
    ACTIONS(4414), 1,
      anon_sym_EQ,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4416), 16,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_EQ_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_extends,
  [119852] = 4,
    ACTIONS(1892), 1,
      anon_sym_DOT,
    ACTIONS(4384), 1,
      anon_sym_EQ,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4386), 15,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_EQ_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_extends,
  [119880] = 3,
    ACTIONS(4422), 1,
      anon_sym_EQ,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4424), 16,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_EQ_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_extends,
  [119906] = 9,
    ACTIONS(3528), 1,
      anon_sym_LPAREN,
    ACTIONS(4068), 1,
      anon_sym_PIPE,
    ACTIONS(6345), 1,
      anon_sym_LT,
    ACTIONS(6347), 1,
      anon_sym_DOT,
    ACTIONS(6349), 1,
      anon_sym_QMARK_DOT,
    STATE(3089), 1,
      sym_arguments,
    STATE(3255), 1,
      sym_type_arguments,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4070), 10,
      sym__automatic_semicolon,
      anon_sym_EQ,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_AMP,
      anon_sym_extends,
      anon_sym_PIPE_RBRACE,
  [119944] = 7,
    ACTIONS(3576), 1,
      anon_sym_LT,
    ACTIONS(4054), 1,
      anon_sym_EQ,
    ACTIONS(6343), 1,
      anon_sym_DOT,
    ACTIONS(6351), 1,
      anon_sym_is,
    STATE(2964), 1,
      sym_type_arguments,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3548), 12,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_EQ_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_extends,
  [119978] = 9,
    ACTIONS(3528), 1,
      anon_sym_LPAREN,
    ACTIONS(4060), 1,
      anon_sym_PIPE,
    ACTIONS(6345), 1,
      anon_sym_LT,
    ACTIONS(6353), 1,
      anon_sym_DOT,
    ACTIONS(6355), 1,
      anon_sym_QMARK_DOT,
    STATE(3090), 1,
      sym_arguments,
    STATE(3257), 1,
      sym_type_arguments,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4062), 10,
      sym__automatic_semicolon,
      anon_sym_EQ,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_AMP,
      anon_sym_extends,
      anon_sym_PIPE_RBRACE,
  [120016] = 3,
    ACTIONS(4178), 1,
      anon_sym_EQ,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4180), 15,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_EQ_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_extends,
  [120041] = 3,
    ACTIONS(1900), 1,
      anon_sym_EQ,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(1898), 15,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_EQ_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_extends,
      anon_sym_is,
  [120066] = 3,
    ACTIONS(4118), 1,
      anon_sym_EQ,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4120), 15,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_EQ_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_extends,
  [120091] = 6,
    ACTIONS(3514), 1,
      anon_sym_LPAREN,
    ACTIONS(4078), 1,
      anon_sym_EQ,
    ACTIONS(6357), 1,
      anon_sym_DOT,
    STATE(2934), 1,
      sym_arguments,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4080), 12,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_EQ_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_extends,
  [120122] = 4,
    ACTIONS(4250), 1,
      anon_sym_EQ,
    ACTIONS(6359), 1,
      anon_sym_DOT,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4252), 14,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_EQ_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_extends,
  [120149] = 5,
    ACTIONS(3576), 1,
      anon_sym_LT,
    ACTIONS(4108), 1,
      anon_sym_EQ,
    STATE(3030), 1,
      sym_type_arguments,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4110), 13,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_EQ_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_extends,
  [120178] = 3,
    ACTIONS(4084), 1,
      anon_sym_EQ,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4086), 15,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_EQ_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_extends,
      anon_sym_is,
  [120203] = 3,
    ACTIONS(4284), 1,
      anon_sym_PIPE,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4286), 14,
      sym__automatic_semicolon,
      anon_sym_EQ,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_extends,
      anon_sym_PIPE_RBRACE,
  [120227] = 8,
    ACTIONS(1550), 1,
      anon_sym_DQUOTE,
    ACTIONS(1552), 1,
      anon_sym_SQUOTE,
    ACTIONS(6363), 1,
      sym_number,
    ACTIONS(6365), 1,
      anon_sym_unique,
    STATE(5699), 1,
      sym_string,
    STATE(5715), 1,
      sym_predefined_type,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6361), 9,
      anon_sym_void,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
      anon_sym_unknown,
      anon_sym_never,
  [120261] = 3,
    ACTIONS(4238), 1,
      anon_sym_PIPE,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4240), 14,
      sym__automatic_semicolon,
      anon_sym_EQ,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_extends,
      anon_sym_PIPE_RBRACE,
  [120285] = 8,
    ACTIONS(1550), 1,
      anon_sym_DQUOTE,
    ACTIONS(1552), 1,
      anon_sym_SQUOTE,
    ACTIONS(6365), 1,
      anon_sym_unique,
    ACTIONS(6367), 1,
      sym_number,
    STATE(5717), 1,
      sym_string,
    STATE(5719), 1,
      sym_predefined_type,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6361), 9,
      anon_sym_void,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
      anon_sym_unknown,
      anon_sym_never,
  [120319] = 8,
    ACTIONS(1550), 1,
      anon_sym_DQUOTE,
    ACTIONS(1552), 1,
      anon_sym_SQUOTE,
    ACTIONS(6365), 1,
      anon_sym_unique,
    ACTIONS(6369), 1,
      sym_number,
    STATE(5721), 1,
      sym_string,
    STATE(5728), 1,
      sym_predefined_type,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6361), 9,
      anon_sym_void,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
      anon_sym_unknown,
      anon_sym_never,
  [120353] = 3,
    ACTIONS(4242), 1,
      anon_sym_PIPE,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4244), 14,
      sym__automatic_semicolon,
      anon_sym_EQ,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_extends,
      anon_sym_PIPE_RBRACE,
  [120377] = 3,
    ACTIONS(4196), 1,
      anon_sym_EQ,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4198), 14,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_EQ_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_extends,
  [120401] = 7,
    ACTIONS(1550), 1,
      anon_sym_DQUOTE,
    ACTIONS(1552), 1,
      anon_sym_SQUOTE,
    ACTIONS(6365), 1,
      anon_sym_unique,
    ACTIONS(6371), 1,
      sym_number,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    STATE(5510), 2,
      sym_string,
      sym_predefined_type,
    ACTIONS(6361), 9,
      anon_sym_void,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
      anon_sym_unknown,
      anon_sym_never,
  [120433] = 5,
    ACTIONS(4450), 1,
      anon_sym_EQ,
    ACTIONS(6373), 1,
      anon_sym_LBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4172), 3,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_extends,
    ACTIONS(4452), 10,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_RBRACK,
      anon_sym_EQ_GT,
      anon_sym_GT,
      anon_sym_QMARK,
  [120461] = 3,
    ACTIONS(4380), 1,
      anon_sym_PIPE,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4382), 14,
      sym__automatic_semicolon,
      anon_sym_EQ,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_extends,
      anon_sym_PIPE_RBRACE,
  [120485] = 8,
    ACTIONS(6375), 1,
      anon_sym_LPAREN,
    ACTIONS(6377), 1,
      anon_sym_DOT,
    ACTIONS(6379), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(6381), 1,
      anon_sym_LT,
    STATE(3226), 1,
      sym_arguments,
    STATE(3457), 1,
      sym_type_arguments,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4062), 9,
      sym__automatic_semicolon,
      sym__function_signature_automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_extends,
  [120519] = 3,
    ACTIONS(4122), 1,
      anon_sym_PIPE,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4124), 14,
      sym__automatic_semicolon,
      anon_sym_EQ,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_extends,
      anon_sym_PIPE_RBRACE,
  [120543] = 3,
    ACTIONS(4132), 1,
      anon_sym_PIPE,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4134), 14,
      sym__automatic_semicolon,
      anon_sym_EQ,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_extends,
      anon_sym_PIPE_RBRACE,
  [120567] = 3,
    ACTIONS(4136), 1,
      anon_sym_PIPE,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4138), 14,
      sym__automatic_semicolon,
      anon_sym_EQ,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_extends,
      anon_sym_PIPE_RBRACE,
  [120591] = 3,
    ACTIONS(4260), 1,
      anon_sym_EQ,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4262), 14,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_EQ_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_extends,
  [120615] = 3,
    ACTIONS(4276), 1,
      anon_sym_PIPE,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4278), 14,
      sym__automatic_semicolon,
      anon_sym_EQ,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_extends,
      anon_sym_PIPE_RBRACE,
  [120639] = 3,
    ACTIONS(4186), 1,
      anon_sym_EQ,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4188), 14,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_EQ_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_extends,
  [120663] = 3,
    ACTIONS(4280), 1,
      anon_sym_PIPE,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4282), 14,
      sym__automatic_semicolon,
      anon_sym_EQ,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_extends,
      anon_sym_PIPE_RBRACE,
  [120687] = 3,
    ACTIONS(4280), 1,
      anon_sym_PIPE,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4282), 14,
      sym__automatic_semicolon,
      anon_sym_EQ,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_extends,
      anon_sym_PIPE_RBRACE,
  [120711] = 3,
    ACTIONS(4312), 1,
      anon_sym_PIPE,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4314), 14,
      sym__automatic_semicolon,
      anon_sym_EQ,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_extends,
      anon_sym_PIPE_RBRACE,
  [120735] = 3,
    ACTIONS(4280), 1,
      anon_sym_PIPE,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4282), 14,
      sym__automatic_semicolon,
      anon_sym_EQ,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_extends,
      anon_sym_PIPE_RBRACE,
  [120759] = 3,
    ACTIONS(4316), 1,
      anon_sym_EQ,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4318), 14,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_EQ_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_extends,
  [120783] = 3,
    ACTIONS(4284), 1,
      anon_sym_PIPE,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4286), 14,
      sym__automatic_semicolon,
      anon_sym_EQ,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_extends,
      anon_sym_PIPE_RBRACE,
  [120807] = 3,
    ACTIONS(4391), 1,
      anon_sym_EQ,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4393), 14,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_EQ_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_extends,
  [120831] = 3,
    ACTIONS(4284), 1,
      anon_sym_PIPE,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4286), 14,
      sym__automatic_semicolon,
      anon_sym_EQ,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_extends,
      anon_sym_PIPE_RBRACE,
  [120855] = 3,
    ACTIONS(4308), 1,
      anon_sym_PIPE,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4310), 14,
      sym__automatic_semicolon,
      anon_sym_EQ,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_extends,
      anon_sym_PIPE_RBRACE,
  [120879] = 3,
    ACTIONS(4308), 1,
      anon_sym_PIPE,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4310), 14,
      sym__automatic_semicolon,
      anon_sym_EQ,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_extends,
      anon_sym_PIPE_RBRACE,
  [120903] = 8,
    ACTIONS(1550), 1,
      anon_sym_DQUOTE,
    ACTIONS(1552), 1,
      anon_sym_SQUOTE,
    ACTIONS(6365), 1,
      anon_sym_unique,
    ACTIONS(6383), 1,
      sym_number,
    STATE(5540), 1,
      sym_string,
    STATE(5756), 1,
      sym_predefined_type,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6361), 9,
      anon_sym_void,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
      anon_sym_unknown,
      anon_sym_never,
  [120937] = 3,
    ACTIONS(4308), 1,
      anon_sym_PIPE,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4310), 14,
      sym__automatic_semicolon,
      anon_sym_EQ,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_extends,
      anon_sym_PIPE_RBRACE,
  [120961] = 3,
    ACTIONS(4368), 1,
      anon_sym_EQ,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4370), 14,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_EQ_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_extends,
  [120985] = 4,
    ACTIONS(4212), 1,
      anon_sym_EQ,
    ACTIONS(6373), 1,
      anon_sym_LBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4214), 13,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_RBRACK,
      anon_sym_EQ_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_extends,
  [121011] = 3,
    ACTIONS(4264), 1,
      anon_sym_EQ,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4266), 14,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_EQ_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_extends,
  [121035] = 3,
    ACTIONS(4350), 1,
      anon_sym_EQ,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4352), 14,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_EQ_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_extends,
  [121059] = 7,
    ACTIONS(1550), 1,
      anon_sym_DQUOTE,
    ACTIONS(1552), 1,
      anon_sym_SQUOTE,
    ACTIONS(6365), 1,
      anon_sym_unique,
    ACTIONS(6385), 1,
      sym_number,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    STATE(5669), 2,
      sym_string,
      sym_predefined_type,
    ACTIONS(6361), 9,
      anon_sym_void,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
      anon_sym_unknown,
      anon_sym_never,
  [121091] = 3,
    ACTIONS(4342), 1,
      anon_sym_EQ,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4344), 14,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_EQ_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_extends,
  [121115] = 3,
    ACTIONS(4446), 1,
      anon_sym_EQ,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4448), 14,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_EQ_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_extends,
  [121139] = 8,
    ACTIONS(1550), 1,
      anon_sym_DQUOTE,
    ACTIONS(1552), 1,
      anon_sym_SQUOTE,
    ACTIONS(6365), 1,
      anon_sym_unique,
    ACTIONS(6387), 1,
      sym_number,
    STATE(5684), 1,
      sym_string,
    STATE(5691), 1,
      sym_predefined_type,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6361), 9,
      anon_sym_void,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
      anon_sym_unknown,
      anon_sym_never,
  [121173] = 3,
    ACTIONS(4114), 1,
      anon_sym_EQ,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4116), 14,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_EQ_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_extends,
  [121197] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6389), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
  [121219] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6391), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
  [121241] = 4,
    ACTIONS(4170), 1,
      anon_sym_EQ,
    ACTIONS(6373), 1,
      anon_sym_LBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4172), 13,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_RBRACK,
      anon_sym_EQ_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_extends,
  [121267] = 8,
    ACTIONS(1550), 1,
      anon_sym_DQUOTE,
    ACTIONS(1552), 1,
      anon_sym_SQUOTE,
    ACTIONS(6365), 1,
      anon_sym_unique,
    ACTIONS(6393), 1,
      sym_number,
    STATE(5583), 1,
      sym_string,
    STATE(5624), 1,
      sym_predefined_type,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6361), 9,
      anon_sym_void,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
      anon_sym_unknown,
      anon_sym_never,
  [121301] = 3,
    ACTIONS(4242), 1,
      anon_sym_PIPE,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4244), 14,
      sym__automatic_semicolon,
      anon_sym_EQ,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_extends,
      anon_sym_PIPE_RBRACE,
  [121325] = 8,
    ACTIONS(1550), 1,
      anon_sym_DQUOTE,
    ACTIONS(1552), 1,
      anon_sym_SQUOTE,
    ACTIONS(6365), 1,
      anon_sym_unique,
    ACTIONS(6395), 1,
      sym_number,
    STATE(5697), 1,
      sym_string,
    STATE(5701), 1,
      sym_predefined_type,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6361), 9,
      anon_sym_void,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
      anon_sym_unknown,
      anon_sym_never,
  [121359] = 8,
    ACTIONS(1550), 1,
      anon_sym_DQUOTE,
    ACTIONS(1552), 1,
      anon_sym_SQUOTE,
    ACTIONS(6365), 1,
      anon_sym_unique,
    ACTIONS(6397), 1,
      sym_number,
    STATE(5703), 1,
      sym_string,
    STATE(5706), 1,
      sym_predefined_type,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6361), 9,
      anon_sym_void,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
      anon_sym_unknown,
      anon_sym_never,
  [121393] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6399), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
  [121415] = 3,
    ACTIONS(4158), 1,
      anon_sym_PIPE,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4160), 14,
      sym__automatic_semicolon,
      anon_sym_EQ,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_extends,
      anon_sym_PIPE_RBRACE,
  [121439] = 3,
    ACTIONS(4184), 1,
      anon_sym_EQ,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4182), 14,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_EQ_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_extends,
  [121463] = 3,
    ACTIONS(4242), 1,
      anon_sym_PIPE,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4244), 14,
      sym__automatic_semicolon,
      anon_sym_EQ,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_extends,
      anon_sym_PIPE_RBRACE,
  [121487] = 3,
    ACTIONS(4246), 1,
      anon_sym_PIPE,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4248), 14,
      sym__automatic_semicolon,
      anon_sym_EQ,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_extends,
      anon_sym_PIPE_RBRACE,
  [121511] = 3,
    ACTIONS(4270), 1,
      anon_sym_EQ,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4156), 14,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_EQ_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_extends,
  [121535] = 3,
    ACTIONS(4256), 1,
      anon_sym_EQ,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4258), 14,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_EQ_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_extends,
  [121559] = 3,
    ACTIONS(4238), 1,
      anon_sym_PIPE,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4240), 14,
      sym__automatic_semicolon,
      anon_sym_EQ,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_extends,
      anon_sym_PIPE_RBRACE,
  [121583] = 3,
    ACTIONS(4406), 1,
      anon_sym_EQ,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4408), 14,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_EQ_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_extends,
  [121607] = 3,
    ACTIONS(4234), 1,
      anon_sym_PIPE,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4236), 14,
      sym__automatic_semicolon,
      anon_sym_EQ,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_extends,
      anon_sym_PIPE_RBRACE,
  [121631] = 7,
    ACTIONS(1550), 1,
      anon_sym_DQUOTE,
    ACTIONS(1552), 1,
      anon_sym_SQUOTE,
    ACTIONS(6365), 1,
      anon_sym_unique,
    ACTIONS(6401), 1,
      sym_number,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    STATE(5846), 2,
      sym_string,
      sym_predefined_type,
    ACTIONS(6361), 9,
      anon_sym_void,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
      anon_sym_unknown,
      anon_sym_never,
  [121663] = 3,
    ACTIONS(4246), 1,
      anon_sym_PIPE,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4248), 14,
      sym__automatic_semicolon,
      anon_sym_EQ,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_extends,
      anon_sym_PIPE_RBRACE,
  [121687] = 3,
    ACTIONS(4216), 1,
      anon_sym_EQ,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4218), 14,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_EQ_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_extends,
  [121711] = 3,
    ACTIONS(4354), 1,
      anon_sym_EQ,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4356), 14,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_EQ_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_extends,
  [121735] = 8,
    ACTIONS(1550), 1,
      anon_sym_DQUOTE,
    ACTIONS(1552), 1,
      anon_sym_SQUOTE,
    ACTIONS(6365), 1,
      anon_sym_unique,
    ACTIONS(6403), 1,
      sym_number,
    STATE(5862), 1,
      sym_string,
    STATE(5864), 1,
      sym_predefined_type,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6361), 9,
      anon_sym_void,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
      anon_sym_unknown,
      anon_sym_never,
  [121769] = 3,
    ACTIONS(4358), 1,
      anon_sym_EQ,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4360), 14,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_EQ_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_extends,
  [121793] = 8,
    ACTIONS(1550), 1,
      anon_sym_DQUOTE,
    ACTIONS(1552), 1,
      anon_sym_SQUOTE,
    ACTIONS(6365), 1,
      anon_sym_unique,
    ACTIONS(6405), 1,
      sym_number,
    STATE(5497), 1,
      sym_predefined_type,
    STATE(5718), 1,
      sym_string,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6361), 9,
      anon_sym_void,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
      anon_sym_unknown,
      anon_sym_never,
  [121827] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6407), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
  [121849] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6409), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
  [121871] = 3,
    ACTIONS(4380), 1,
      anon_sym_PIPE,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4382), 14,
      sym__automatic_semicolon,
      anon_sym_EQ,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_extends,
      anon_sym_PIPE_RBRACE,
  [121895] = 8,
    ACTIONS(1550), 1,
      anon_sym_DQUOTE,
    ACTIONS(1552), 1,
      anon_sym_SQUOTE,
    ACTIONS(6365), 1,
      anon_sym_unique,
    ACTIONS(6411), 1,
      sym_number,
    STATE(5514), 1,
      sym_string,
    STATE(5546), 1,
      sym_predefined_type,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6361), 9,
      anon_sym_void,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
      anon_sym_unknown,
      anon_sym_never,
  [121929] = 3,
    ACTIONS(4170), 1,
      anon_sym_EQ,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4172), 14,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_EQ_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_extends,
  [121953] = 8,
    ACTIONS(1550), 1,
      anon_sym_DQUOTE,
    ACTIONS(1552), 1,
      anon_sym_SQUOTE,
    ACTIONS(6365), 1,
      anon_sym_unique,
    ACTIONS(6413), 1,
      sym_number,
    STATE(5512), 1,
      sym_string,
    STATE(5749), 1,
      sym_predefined_type,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6361), 9,
      anon_sym_void,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
      anon_sym_unknown,
      anon_sym_never,
  [121987] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6415), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
  [122009] = 3,
    ACTIONS(4230), 1,
      anon_sym_EQ,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4232), 14,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_EQ_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_extends,
  [122033] = 3,
    ACTIONS(4372), 1,
      anon_sym_EQ,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4374), 14,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_EQ_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_extends,
  [122057] = 3,
    ACTIONS(4122), 1,
      anon_sym_PIPE,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4124), 14,
      sym__automatic_semicolon,
      anon_sym_EQ,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_extends,
      anon_sym_PIPE_RBRACE,
  [122081] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6417), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
  [122103] = 3,
    ACTIONS(4132), 1,
      anon_sym_PIPE,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4134), 14,
      sym__automatic_semicolon,
      anon_sym_EQ,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_extends,
      anon_sym_PIPE_RBRACE,
  [122127] = 3,
    ACTIONS(4324), 1,
      anon_sym_EQ,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4326), 14,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_EQ_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_extends,
  [122151] = 7,
    ACTIONS(4054), 1,
      anon_sym_PIPE,
    ACTIONS(6345), 1,
      anon_sym_LT,
    ACTIONS(6419), 1,
      anon_sym_DOT,
    ACTIONS(6421), 1,
      anon_sym_is,
    STATE(3250), 1,
      sym_type_arguments,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3548), 10,
      sym__automatic_semicolon,
      anon_sym_EQ,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_AMP,
      anon_sym_extends,
      anon_sym_PIPE_RBRACE,
  [122183] = 3,
    ACTIONS(4136), 1,
      anon_sym_PIPE,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4138), 14,
      sym__automatic_semicolon,
      anon_sym_EQ,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_extends,
      anon_sym_PIPE_RBRACE,
  [122207] = 3,
    ACTIONS(4220), 1,
      anon_sym_EQ,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4222), 14,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_EQ_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_extends,
  [122231] = 3,
    ACTIONS(4300), 1,
      anon_sym_EQ,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4302), 14,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_EQ_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_extends,
  [122255] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6423), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
  [122277] = 3,
    ACTIONS(4430), 1,
      anon_sym_EQ,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4432), 14,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_EQ_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_extends,
  [122301] = 3,
    ACTIONS(4246), 1,
      anon_sym_PIPE,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4248), 14,
      sym__automatic_semicolon,
      anon_sym_EQ,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_extends,
      anon_sym_PIPE_RBRACE,
  [122325] = 3,
    ACTIONS(4402), 1,
      anon_sym_EQ,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4404), 14,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_EQ_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_extends,
  [122349] = 3,
    ACTIONS(4104), 1,
      anon_sym_EQ,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4106), 14,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_EQ_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_extends,
  [122373] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6425), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
  [122395] = 8,
    ACTIONS(6375), 1,
      anon_sym_LPAREN,
    ACTIONS(6381), 1,
      anon_sym_LT,
    ACTIONS(6427), 1,
      anon_sym_DOT,
    ACTIONS(6429), 1,
      anon_sym_QMARK_DOT,
    STATE(3224), 1,
      sym_arguments,
    STATE(3401), 1,
      sym_type_arguments,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3512), 9,
      sym__automatic_semicolon,
      sym__function_signature_automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_extends,
  [122429] = 3,
    ACTIONS(4162), 1,
      anon_sym_PIPE,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4164), 14,
      sym__automatic_semicolon,
      anon_sym_EQ,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_extends,
      anon_sym_PIPE_RBRACE,
  [122453] = 3,
    ACTIONS(4166), 1,
      anon_sym_PIPE,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4168), 14,
      sym__automatic_semicolon,
      anon_sym_EQ,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_extends,
      anon_sym_PIPE_RBRACE,
  [122477] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6431), 15,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_QMARK_QMARK_EQ,
  [122499] = 3,
    ACTIONS(4174), 1,
      anon_sym_EQ,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4176), 14,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_EQ_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_extends,
  [122523] = 3,
    ACTIONS(4162), 1,
      anon_sym_PIPE,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4164), 14,
      sym__automatic_semicolon,
      anon_sym_EQ,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_extends,
      anon_sym_PIPE_RBRACE,
  [122547] = 7,
    ACTIONS(1550), 1,
      anon_sym_DQUOTE,
    ACTIONS(1552), 1,
      anon_sym_SQUOTE,
    ACTIONS(6365), 1,
      anon_sym_unique,
    ACTIONS(6433), 1,
      sym_number,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    STATE(5694), 2,
      sym_string,
      sym_predefined_type,
    ACTIONS(6361), 9,
      anon_sym_void,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
      anon_sym_unknown,
      anon_sym_never,
  [122579] = 3,
    ACTIONS(4166), 1,
      anon_sym_PIPE,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4168), 14,
      sym__automatic_semicolon,
      anon_sym_EQ,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_extends,
      anon_sym_PIPE_RBRACE,
  [122603] = 7,
    ACTIONS(1550), 1,
      anon_sym_DQUOTE,
    ACTIONS(1552), 1,
      anon_sym_SQUOTE,
    ACTIONS(6365), 1,
      anon_sym_unique,
    ACTIONS(6435), 1,
      sym_number,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    STATE(5784), 2,
      sym_string,
      sym_predefined_type,
    ACTIONS(6361), 9,
      anon_sym_void,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
      anon_sym_unknown,
      anon_sym_never,
  [122635] = 8,
    ACTIONS(1550), 1,
      anon_sym_DQUOTE,
    ACTIONS(1552), 1,
      anon_sym_SQUOTE,
    ACTIONS(6365), 1,
      anon_sym_unique,
    ACTIONS(6437), 1,
      sym_number,
    STATE(5791), 1,
      sym_string,
    STATE(5794), 1,
      sym_predefined_type,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6361), 9,
      anon_sym_void,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
      anon_sym_unknown,
      anon_sym_never,
  [122669] = 8,
    ACTIONS(1550), 1,
      anon_sym_DQUOTE,
    ACTIONS(1552), 1,
      anon_sym_SQUOTE,
    ACTIONS(6365), 1,
      anon_sym_unique,
    ACTIONS(6439), 1,
      sym_number,
    STATE(5799), 1,
      sym_string,
    STATE(5806), 1,
      sym_predefined_type,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6361), 9,
      anon_sym_void,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
      anon_sym_unknown,
      anon_sym_never,
  [122703] = 8,
    ACTIONS(6375), 1,
      anon_sym_LPAREN,
    ACTIONS(6381), 1,
      anon_sym_LT,
    ACTIONS(6441), 1,
      anon_sym_DOT,
    ACTIONS(6443), 1,
      anon_sym_QMARK_DOT,
    STATE(3225), 1,
      sym_arguments,
    STATE(3420), 1,
      sym_type_arguments,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4070), 9,
      sym__automatic_semicolon,
      sym__function_signature_automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_extends,
  [122737] = 3,
    ACTIONS(4238), 1,
      anon_sym_PIPE,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4240), 14,
      sym__automatic_semicolon,
      anon_sym_EQ,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_extends,
      anon_sym_PIPE_RBRACE,
  [122761] = 3,
    ACTIONS(4108), 1,
      anon_sym_EQ,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4110), 14,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_EQ_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_extends,
  [122785] = 8,
    ACTIONS(1550), 1,
      anon_sym_DQUOTE,
    ACTIONS(1552), 1,
      anon_sym_SQUOTE,
    ACTIONS(6365), 1,
      anon_sym_unique,
    ACTIONS(6445), 1,
      sym_number,
    STATE(5809), 1,
      sym_string,
    STATE(5811), 1,
      sym_predefined_type,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6361), 9,
      anon_sym_void,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
      anon_sym_unknown,
      anon_sym_never,
  [122819] = 3,
    ACTIONS(4140), 1,
      anon_sym_EQ,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4142), 14,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_EQ_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_extends,
  [122843] = 3,
    ACTIONS(4376), 1,
      anon_sym_EQ,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4378), 14,
      anon_sym_as,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_EQ_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_extends,
  [122867] = 13,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    ACTIONS(6451), 1,
      anon_sym_BANG,
    ACTIONS(6453), 1,
      anon_sym_LPAREN,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    ACTIONS(6457), 1,
      anon_sym_QMARK,
    STATE(3806), 1,
      sym_formal_parameters,
    STATE(4162), 1,
      sym_type_annotation,
    STATE(4706), 1,
      sym__initializer,
    STATE(5256), 1,
      sym__call_signature,
    STATE(5328), 1,
      sym_type_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6449), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [122910] = 13,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(3281), 1,
      anon_sym_LPAREN,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    ACTIONS(6461), 1,
      anon_sym_BANG,
    ACTIONS(6463), 1,
      anon_sym_QMARK,
    STATE(3315), 1,
      sym_formal_parameters,
    STATE(4234), 1,
      sym_type_annotation,
    STATE(4859), 1,
      sym__call_signature,
    STATE(4860), 1,
      sym__initializer,
    STATE(5233), 1,
      sym_type_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6459), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [122953] = 13,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    ACTIONS(6453), 1,
      anon_sym_LPAREN,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    ACTIONS(6467), 1,
      anon_sym_BANG,
    ACTIONS(6469), 1,
      anon_sym_QMARK,
    STATE(3806), 1,
      sym_formal_parameters,
    STATE(4246), 1,
      sym_type_annotation,
    STATE(4880), 1,
      sym__initializer,
    STATE(5155), 1,
      sym__call_signature,
    STATE(5328), 1,
      sym_type_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6465), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [122996] = 14,
    ACTIONS(1626), 1,
      anon_sym_DQUOTE,
    ACTIONS(1628), 1,
      anon_sym_SQUOTE,
    ACTIONS(6327), 1,
      anon_sym_STAR,
    ACTIONS(6331), 1,
      anon_sym_LBRACE,
    ACTIONS(6471), 1,
      sym_identifier,
    ACTIONS(6473), 1,
      anon_sym_type,
    ACTIONS(6475), 1,
      anon_sym_COMMA,
    ACTIONS(6477), 1,
      anon_sym_from,
    STATE(4299), 1,
      sym_string,
    STATE(4300), 1,
      sym_import_require_clause,
    STATE(5136), 1,
      sym__import_identifier,
    STATE(5337), 1,
      sym_import_clause,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    STATE(5844), 2,
      sym_namespace_import,
      sym_named_imports,
  [123041] = 6,
    ACTIONS(214), 1,
      anon_sym_unique,
    STATE(3286), 1,
      sym_type_predicate,
    STATE(5724), 1,
      sym_predefined_type,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6479), 2,
      sym_identifier,
      sym_this,
    ACTIONS(216), 9,
      anon_sym_void,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
      anon_sym_unknown,
      anon_sym_never,
  [123070] = 11,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(3281), 1,
      anon_sym_LPAREN,
    ACTIONS(3808), 1,
      anon_sym_COMMA,
    ACTIONS(3925), 1,
      anon_sym_RBRACE,
    ACTIONS(4622), 1,
      anon_sym_EQ,
    STATE(3615), 1,
      sym_formal_parameters,
    STATE(4792), 1,
      aux_sym_object_repeat1,
    STATE(4815), 1,
      aux_sym_object_pattern_repeat1,
    STATE(5411), 1,
      sym_type_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3814), 5,
      sym__automatic_semicolon,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_PIPE_RBRACE,
  [123109] = 6,
    ACTIONS(214), 1,
      anon_sym_unique,
    STATE(1939), 1,
      sym_type_predicate,
    STATE(5747), 1,
      sym_predefined_type,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6481), 2,
      sym_identifier,
      sym_this,
    ACTIONS(216), 9,
      anon_sym_void,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
      anon_sym_unknown,
      anon_sym_never,
  [123138] = 11,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(3281), 1,
      anon_sym_LPAREN,
    ACTIONS(3808), 1,
      anon_sym_COMMA,
    ACTIONS(3811), 1,
      anon_sym_RBRACE,
    ACTIONS(4622), 1,
      anon_sym_EQ,
    STATE(3615), 1,
      sym_formal_parameters,
    STATE(4792), 1,
      aux_sym_object_repeat1,
    STATE(4815), 1,
      aux_sym_object_pattern_repeat1,
    STATE(5411), 1,
      sym_type_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3814), 5,
      sym__automatic_semicolon,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_PIPE_RBRACE,
  [123177] = 11,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(3281), 1,
      anon_sym_LPAREN,
    ACTIONS(3808), 1,
      anon_sym_COMMA,
    ACTIONS(3906), 1,
      anon_sym_RBRACE,
    ACTIONS(4622), 1,
      anon_sym_EQ,
    STATE(3615), 1,
      sym_formal_parameters,
    STATE(4810), 1,
      aux_sym_object_repeat1,
    STATE(4815), 1,
      aux_sym_object_pattern_repeat1,
    STATE(5411), 1,
      sym_type_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3814), 5,
      sym__automatic_semicolon,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_PIPE_RBRACE,
  [123216] = 11,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(3281), 1,
      anon_sym_LPAREN,
    ACTIONS(3808), 1,
      anon_sym_COMMA,
    ACTIONS(3909), 1,
      anon_sym_RBRACE,
    ACTIONS(4622), 1,
      anon_sym_EQ,
    STATE(3615), 1,
      sym_formal_parameters,
    STATE(4792), 1,
      aux_sym_object_repeat1,
    STATE(4815), 1,
      aux_sym_object_pattern_repeat1,
    STATE(5411), 1,
      sym_type_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3814), 5,
      sym__automatic_semicolon,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_PIPE_RBRACE,
  [123255] = 6,
    ACTIONS(214), 1,
      anon_sym_unique,
    STATE(1637), 1,
      sym_type_predicate,
    STATE(5570), 1,
      sym_predefined_type,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6483), 2,
      sym_identifier,
      sym_this,
    ACTIONS(216), 9,
      anon_sym_void,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
      anon_sym_unknown,
      anon_sym_never,
  [123284] = 4,
    ACTIONS(4104), 1,
      anon_sym_EQ,
    ACTIONS(6351), 1,
      anon_sym_is,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4106), 12,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_EQ_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_extends,
  [123309] = 6,
    ACTIONS(214), 1,
      anon_sym_unique,
    STATE(2978), 1,
      sym_type_predicate,
    STATE(5861), 1,
      sym_predefined_type,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6485), 2,
      sym_identifier,
      sym_this,
    ACTIONS(216), 9,
      anon_sym_void,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
      anon_sym_unknown,
      anon_sym_never,
  [123338] = 4,
    ACTIONS(4108), 1,
      anon_sym_EQ,
    ACTIONS(6487), 1,
      anon_sym_is,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4110), 12,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_EQ_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_extends,
  [123363] = 13,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    ACTIONS(6453), 1,
      anon_sym_LPAREN,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    ACTIONS(6491), 1,
      anon_sym_BANG,
    ACTIONS(6493), 1,
      anon_sym_QMARK,
    STATE(3806), 1,
      sym_formal_parameters,
    STATE(3949), 1,
      sym_type_annotation,
    STATE(5042), 1,
      sym__initializer,
    STATE(5328), 1,
      sym_type_parameters,
    STATE(5373), 1,
      sym__call_signature,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6489), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [123406] = 13,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    ACTIONS(6453), 1,
      anon_sym_LPAREN,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    ACTIONS(6495), 1,
      anon_sym_BANG,
    ACTIONS(6497), 1,
      anon_sym_QMARK,
    STATE(3806), 1,
      sym_formal_parameters,
    STATE(3956), 1,
      sym_type_annotation,
    STATE(4528), 1,
      sym__initializer,
    STATE(5257), 1,
      sym__call_signature,
    STATE(5328), 1,
      sym_type_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6489), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [123449] = 4,
    ACTIONS(4114), 1,
      anon_sym_EQ,
    ACTIONS(6351), 1,
      anon_sym_is,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4116), 12,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_EQ_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_extends,
  [123474] = 13,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    ACTIONS(6453), 1,
      anon_sym_LPAREN,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    ACTIONS(6499), 1,
      anon_sym_BANG,
    ACTIONS(6501), 1,
      anon_sym_QMARK,
    STATE(3806), 1,
      sym_formal_parameters,
    STATE(4014), 1,
      sym_type_annotation,
    STATE(4805), 1,
      sym__initializer,
    STATE(5139), 1,
      sym__call_signature,
    STATE(5328), 1,
      sym_type_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6489), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [123517] = 6,
    ACTIONS(214), 1,
      anon_sym_unique,
    STATE(2978), 1,
      sym_type_predicate,
    STATE(5673), 1,
      sym_predefined_type,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6503), 2,
      sym_identifier,
      sym_this,
    ACTIONS(216), 9,
      anon_sym_void,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
      anon_sym_unknown,
      anon_sym_never,
  [123546] = 13,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    ACTIONS(6507), 1,
      anon_sym_BANG,
    ACTIONS(6509), 1,
      anon_sym_LPAREN,
    ACTIONS(6511), 1,
      anon_sym_QMARK,
    STATE(3330), 1,
      sym_formal_parameters,
    STATE(3900), 1,
      sym__call_signature,
    STATE(4003), 1,
      sym_type_annotation,
    STATE(4741), 1,
      sym__initializer,
    STATE(5249), 1,
      sym_type_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6505), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [123589] = 13,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    ACTIONS(6453), 1,
      anon_sym_LPAREN,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    ACTIONS(6515), 1,
      anon_sym_BANG,
    ACTIONS(6517), 1,
      anon_sym_QMARK,
    STATE(3806), 1,
      sym_formal_parameters,
    STATE(4126), 1,
      sym_type_annotation,
    STATE(4632), 1,
      sym__initializer,
    STATE(5131), 1,
      sym__call_signature,
    STATE(5328), 1,
      sym_type_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6513), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [123632] = 13,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    ACTIONS(6509), 1,
      anon_sym_LPAREN,
    ACTIONS(6521), 1,
      anon_sym_BANG,
    ACTIONS(6523), 1,
      anon_sym_QMARK,
    STATE(3330), 1,
      sym_formal_parameters,
    STATE(3754), 1,
      sym__call_signature,
    STATE(4313), 1,
      sym_type_annotation,
    STATE(5010), 1,
      sym__initializer,
    STATE(5249), 1,
      sym_type_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6519), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [123675] = 13,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(3281), 1,
      anon_sym_LPAREN,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    ACTIONS(6521), 1,
      anon_sym_BANG,
    ACTIONS(6525), 1,
      anon_sym_QMARK,
    STATE(3315), 1,
      sym_formal_parameters,
    STATE(4313), 1,
      sym_type_annotation,
    STATE(5077), 1,
      sym__call_signature,
    STATE(5084), 1,
      sym__initializer,
    STATE(5233), 1,
      sym_type_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6519), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [123718] = 13,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    ACTIONS(6453), 1,
      anon_sym_LPAREN,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    ACTIONS(6529), 1,
      anon_sym_BANG,
    ACTIONS(6531), 1,
      anon_sym_QMARK,
    STATE(3806), 1,
      sym_formal_parameters,
    STATE(4357), 1,
      sym_type_annotation,
    STATE(5089), 1,
      sym__initializer,
    STATE(5328), 1,
      sym_type_parameters,
    STATE(5431), 1,
      sym__call_signature,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6527), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [123761] = 13,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    ACTIONS(6453), 1,
      anon_sym_LPAREN,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    ACTIONS(6533), 1,
      anon_sym_BANG,
    ACTIONS(6535), 1,
      anon_sym_QMARK,
    STATE(3806), 1,
      sym_formal_parameters,
    STATE(4361), 1,
      sym_type_annotation,
    STATE(5093), 1,
      sym__initializer,
    STATE(5328), 1,
      sym_type_parameters,
    STATE(5436), 1,
      sym__call_signature,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6527), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [123804] = 11,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(3281), 1,
      anon_sym_LPAREN,
    ACTIONS(3808), 1,
      anon_sym_COMMA,
    ACTIONS(3912), 1,
      anon_sym_RBRACE,
    ACTIONS(4622), 1,
      anon_sym_EQ,
    STATE(3615), 1,
      sym_formal_parameters,
    STATE(4792), 1,
      aux_sym_object_repeat1,
    STATE(4815), 1,
      aux_sym_object_pattern_repeat1,
    STATE(5411), 1,
      sym_type_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3814), 5,
      sym__automatic_semicolon,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_PIPE_RBRACE,
  [123843] = 13,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    ACTIONS(6453), 1,
      anon_sym_LPAREN,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    ACTIONS(6537), 1,
      anon_sym_BANG,
    ACTIONS(6539), 1,
      anon_sym_QMARK,
    STATE(3806), 1,
      sym_formal_parameters,
    STATE(4060), 1,
      sym_type_annotation,
    STATE(4563), 1,
      sym__initializer,
    STATE(5265), 1,
      sym__call_signature,
    STATE(5328), 1,
      sym_type_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6527), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [123886] = 13,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    ACTIONS(6453), 1,
      anon_sym_LPAREN,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    ACTIONS(6541), 1,
      anon_sym_BANG,
    ACTIONS(6543), 1,
      anon_sym_QMARK,
    STATE(3806), 1,
      sym_formal_parameters,
    STATE(4059), 1,
      sym_type_annotation,
    STATE(4884), 1,
      sym__initializer,
    STATE(5226), 1,
      sym__call_signature,
    STATE(5328), 1,
      sym_type_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6527), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [123929] = 13,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    ACTIONS(6453), 1,
      anon_sym_LPAREN,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    ACTIONS(6545), 1,
      anon_sym_BANG,
    ACTIONS(6547), 1,
      anon_sym_QMARK,
    STATE(3806), 1,
      sym_formal_parameters,
    STATE(4028), 1,
      sym_type_annotation,
    STATE(4864), 1,
      sym__initializer,
    STATE(5185), 1,
      sym__call_signature,
    STATE(5328), 1,
      sym_type_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6449), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [123972] = 13,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    ACTIONS(6453), 1,
      anon_sym_LPAREN,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    ACTIONS(6549), 1,
      anon_sym_BANG,
    ACTIONS(6551), 1,
      anon_sym_QMARK,
    STATE(3806), 1,
      sym_formal_parameters,
    STATE(4183), 1,
      sym_type_annotation,
    STATE(4516), 1,
      sym__initializer,
    STATE(5328), 1,
      sym_type_parameters,
    STATE(5367), 1,
      sym__call_signature,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6449), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [124015] = 13,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    ACTIONS(6509), 1,
      anon_sym_LPAREN,
    ACTIONS(6555), 1,
      anon_sym_BANG,
    ACTIONS(6557), 1,
      anon_sym_QMARK,
    STATE(3330), 1,
      sym_formal_parameters,
    STATE(3819), 1,
      sym__call_signature,
    STATE(4333), 1,
      sym_type_annotation,
    STATE(5058), 1,
      sym__initializer,
    STATE(5249), 1,
      sym_type_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6553), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [124058] = 13,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    ACTIONS(6509), 1,
      anon_sym_LPAREN,
    ACTIONS(6561), 1,
      anon_sym_BANG,
    ACTIONS(6563), 1,
      anon_sym_QMARK,
    STATE(3330), 1,
      sym_formal_parameters,
    STATE(3751), 1,
      sym__call_signature,
    STATE(4235), 1,
      sym_type_annotation,
    STATE(4848), 1,
      sym__initializer,
    STATE(5249), 1,
      sym_type_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6559), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [124101] = 6,
    ACTIONS(214), 1,
      anon_sym_unique,
    STATE(2978), 1,
      sym_type_predicate,
    STATE(5675), 1,
      sym_predefined_type,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6565), 2,
      sym_identifier,
      sym_this,
    ACTIONS(216), 9,
      anon_sym_void,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
      anon_sym_unknown,
      anon_sym_never,
  [124130] = 6,
    ACTIONS(3528), 1,
      anon_sym_LPAREN,
    ACTIONS(4078), 1,
      anon_sym_PIPE,
    ACTIONS(6567), 1,
      anon_sym_DOT,
    STATE(3168), 1,
      sym_arguments,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4080), 10,
      sym__automatic_semicolon,
      anon_sym_EQ,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_AMP,
      anon_sym_extends,
      anon_sym_PIPE_RBRACE,
  [124159] = 6,
    ACTIONS(4054), 1,
      anon_sym_PIPE,
    ACTIONS(6345), 1,
      anon_sym_LT,
    ACTIONS(6419), 1,
      anon_sym_DOT,
    STATE(3250), 1,
      sym_type_arguments,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3548), 10,
      sym__automatic_semicolon,
      anon_sym_EQ,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_AMP,
      anon_sym_extends,
      anon_sym_PIPE_RBRACE,
  [124188] = 6,
    ACTIONS(214), 1,
      anon_sym_unique,
    STATE(3336), 1,
      sym_type_predicate,
    STATE(5501), 1,
      sym_predefined_type,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6569), 2,
      sym_identifier,
      sym_this,
    ACTIONS(216), 9,
      anon_sym_void,
      anon_sym_any,
      anon_sym_number,
      anon_sym_boolean,
      anon_sym_string,
      anon_sym_symbol,
      anon_sym_object,
      anon_sym_unknown,
      anon_sym_never,
  [124217] = 13,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    ACTIONS(6453), 1,
      anon_sym_LPAREN,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    ACTIONS(6571), 1,
      anon_sym_BANG,
    ACTIONS(6573), 1,
      anon_sym_QMARK,
    STATE(3806), 1,
      sym_formal_parameters,
    STATE(4295), 1,
      sym_type_annotation,
    STATE(4985), 1,
      sym__initializer,
    STATE(5322), 1,
      sym__call_signature,
    STATE(5328), 1,
      sym_type_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6449), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [124260] = 13,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    ACTIONS(6453), 1,
      anon_sym_LPAREN,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    ACTIONS(6575), 1,
      anon_sym_BANG,
    ACTIONS(6577), 1,
      anon_sym_QMARK,
    STATE(3806), 1,
      sym_formal_parameters,
    STATE(4325), 1,
      sym_type_annotation,
    STATE(5028), 1,
      sym__initializer,
    STATE(5328), 1,
      sym_type_parameters,
    STATE(5381), 1,
      sym__call_signature,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6449), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [124303] = 13,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    ACTIONS(6453), 1,
      anon_sym_LPAREN,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    ACTIONS(6579), 1,
      anon_sym_BANG,
    ACTIONS(6581), 1,
      anon_sym_QMARK,
    STATE(3806), 1,
      sym_formal_parameters,
    STATE(4344), 1,
      sym_type_annotation,
    STATE(5070), 1,
      sym__initializer,
    STATE(5328), 1,
      sym_type_parameters,
    STATE(5412), 1,
      sym__call_signature,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6489), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [124346] = 13,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    ACTIONS(6461), 1,
      anon_sym_BANG,
    ACTIONS(6509), 1,
      anon_sym_LPAREN,
    ACTIONS(6583), 1,
      anon_sym_QMARK,
    STATE(3330), 1,
      sym_formal_parameters,
    STATE(3848), 1,
      sym__call_signature,
    STATE(4234), 1,
      sym_type_annotation,
    STATE(4849), 1,
      sym__initializer,
    STATE(5249), 1,
      sym_type_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6459), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [124389] = 13,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    ACTIONS(6453), 1,
      anon_sym_LPAREN,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    ACTIONS(6585), 1,
      anon_sym_BANG,
    ACTIONS(6587), 1,
      anon_sym_QMARK,
    STATE(3806), 1,
      sym_formal_parameters,
    STATE(4049), 1,
      sym_type_annotation,
    STATE(4944), 1,
      sym__initializer,
    STATE(5267), 1,
      sym__call_signature,
    STATE(5328), 1,
      sym_type_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6449), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [124432] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4138), 13,
      sym__automatic_semicolon,
      sym__function_signature_automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_extends,
  [124452] = 10,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(3281), 1,
      anon_sym_LPAREN,
    ACTIONS(6591), 1,
      anon_sym_COLON,
    ACTIONS(6593), 1,
      anon_sym_QMARK,
    STATE(3315), 1,
      sym_formal_parameters,
    STATE(3714), 1,
      sym__call_signature,
    STATE(4084), 1,
      sym_type_annotation,
    STATE(5233), 1,
      sym_type_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6589), 5,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACE,
  [124488] = 3,
    ACTIONS(4320), 1,
      anon_sym_PIPE,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4322), 12,
      sym__automatic_semicolon,
      anon_sym_EQ,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP,
      anon_sym_extends,
      anon_sym_PIPE_RBRACE,
  [124510] = 11,
    ACTIONS(3576), 1,
      anon_sym_LT,
    ACTIONS(6343), 1,
      anon_sym_DOT,
    ACTIONS(6595), 1,
      anon_sym_EQ,
    ACTIONS(6600), 1,
      anon_sym_COLON,
    ACTIONS(6602), 1,
      anon_sym_extends,
    STATE(2964), 1,
      sym_type_arguments,
    STATE(4499), 1,
      sym_constraint,
    STATE(5417), 1,
      sym_default_type,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6597), 2,
      anon_sym_COMMA,
      anon_sym_GT,
    ACTIONS(3548), 3,
      anon_sym_LBRACK,
      anon_sym_AMP,
      anon_sym_PIPE,
  [124548] = 3,
    ACTIONS(3225), 1,
      anon_sym_PIPE,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3227), 12,
      sym__automatic_semicolon,
      anon_sym_EQ,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP,
      anon_sym_extends,
      anon_sym_PIPE_RBRACE,
  [124570] = 3,
    ACTIONS(4328), 1,
      anon_sym_PIPE,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4330), 12,
      sym__automatic_semicolon,
      anon_sym_EQ,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP,
      anon_sym_extends,
      anon_sym_PIPE_RBRACE,
  [124592] = 3,
    ACTIONS(4346), 1,
      anon_sym_PIPE,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4348), 12,
      sym__automatic_semicolon,
      anon_sym_EQ,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP,
      anon_sym_extends,
      anon_sym_PIPE_RBRACE,
  [124614] = 4,
    ACTIONS(1888), 1,
      anon_sym_DOT,
    ACTIONS(4384), 1,
      anon_sym_PIPE,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4386), 11,
      sym__automatic_semicolon,
      anon_sym_EQ,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_extends,
      anon_sym_PIPE_RBRACE,
  [124638] = 3,
    ACTIONS(3691), 1,
      anon_sym_PIPE,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3474), 12,
      sym__automatic_semicolon,
      anon_sym_EQ,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_AMP,
      anon_sym_extends,
      anon_sym_PIPE_RBRACE,
  [124660] = 3,
    ACTIONS(3679), 1,
      anon_sym_PIPE,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3478), 12,
      sym__automatic_semicolon,
      anon_sym_EQ,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_AMP,
      anon_sym_extends,
      anon_sym_PIPE_RBRACE,
  [124682] = 3,
    ACTIONS(3233), 1,
      anon_sym_PIPE,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3235), 12,
      sym__automatic_semicolon,
      anon_sym_EQ,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP,
      anon_sym_extends,
      anon_sym_PIPE_RBRACE,
  [124704] = 6,
    ACTIONS(4402), 1,
      anon_sym_EQ,
    ACTIONS(6605), 1,
      anon_sym_AMP,
    ACTIONS(6607), 1,
      anon_sym_PIPE,
    ACTIONS(6609), 1,
      anon_sym_extends,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4404), 9,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_EQ_GT,
      anon_sym_GT,
  [124732] = 4,
    ACTIONS(4438), 1,
      anon_sym_EQ,
    ACTIONS(6605), 1,
      anon_sym_AMP,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4440), 11,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_EQ_GT,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_extends,
  [124756] = 10,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(3281), 1,
      anon_sym_LPAREN,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    ACTIONS(6613), 1,
      anon_sym_QMARK,
    STATE(3315), 1,
      sym_formal_parameters,
    STATE(3524), 1,
      sym__call_signature,
    STATE(4050), 1,
      sym_type_annotation,
    STATE(5233), 1,
      sym_type_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6611), 5,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACE,
  [124792] = 10,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(3281), 1,
      anon_sym_LPAREN,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    ACTIONS(6617), 1,
      anon_sym_QMARK,
    STATE(3315), 1,
      sym_formal_parameters,
    STATE(4282), 1,
      sym__call_signature,
    STATE(4283), 1,
      sym_type_annotation,
    STATE(5233), 1,
      sym_type_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6615), 5,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACE,
  [124828] = 3,
    ACTIONS(3237), 1,
      anon_sym_PIPE,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3239), 12,
      sym__automatic_semicolon,
      anon_sym_EQ,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP,
      anon_sym_extends,
      anon_sym_PIPE_RBRACE,
  [124850] = 4,
    ACTIONS(1892), 1,
      anon_sym_DOT,
    ACTIONS(4384), 1,
      anon_sym_PIPE,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4386), 11,
      sym__automatic_semicolon,
      anon_sym_EQ,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_extends,
      anon_sym_PIPE_RBRACE,
  [124874] = 3,
    ACTIONS(4414), 1,
      anon_sym_PIPE,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4416), 12,
      sym__automatic_semicolon,
      anon_sym_EQ,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_AMP,
      anon_sym_extends,
      anon_sym_PIPE_RBRACE,
  [124896] = 3,
    ACTIONS(4418), 1,
      anon_sym_PIPE,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4420), 12,
      sym__automatic_semicolon,
      anon_sym_EQ,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_AMP,
      anon_sym_extends,
      anon_sym_PIPE_RBRACE,
  [124918] = 3,
    ACTIONS(4422), 1,
      anon_sym_PIPE,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4424), 12,
      sym__automatic_semicolon,
      anon_sym_EQ,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_AMP,
      anon_sym_extends,
      anon_sym_PIPE_RBRACE,
  [124940] = 3,
    ACTIONS(4426), 1,
      anon_sym_PIPE,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4428), 12,
      sym__automatic_semicolon,
      anon_sym_EQ,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_AMP,
      anon_sym_extends,
      anon_sym_PIPE_RBRACE,
  [124962] = 10,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(3281), 1,
      anon_sym_LPAREN,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    ACTIONS(6621), 1,
      anon_sym_QMARK,
    STATE(3315), 1,
      sym_formal_parameters,
    STATE(4029), 1,
      sym__call_signature,
    STATE(4030), 1,
      sym_type_annotation,
    STATE(5233), 1,
      sym_type_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6619), 5,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACE,
  [124998] = 4,
    ACTIONS(4190), 1,
      anon_sym_EQ,
    ACTIONS(6623), 1,
      anon_sym_extends,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4192), 11,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_EQ_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_GT,
  [125022] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4160), 13,
      sym__automatic_semicolon,
      sym__function_signature_automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_extends,
  [125042] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4314), 13,
      sym__automatic_semicolon,
      sym__function_signature_automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_extends,
  [125062] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4382), 13,
      sym__automatic_semicolon,
      sym__function_signature_automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_extends,
  [125082] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4124), 13,
      sym__automatic_semicolon,
      sym__function_signature_automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_extends,
  [125102] = 10,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(3281), 1,
      anon_sym_LPAREN,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    ACTIONS(6625), 1,
      anon_sym_QMARK,
    STATE(3315), 1,
      sym_formal_parameters,
    STATE(4083), 1,
      sym__call_signature,
    STATE(4084), 1,
      sym_type_annotation,
    STATE(5233), 1,
      sym_type_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6589), 5,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACE,
  [125138] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4382), 13,
      sym__automatic_semicolon,
      sym__function_signature_automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_extends,
  [125158] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4124), 13,
      sym__automatic_semicolon,
      sym__function_signature_automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_extends,
  [125178] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4134), 13,
      sym__automatic_semicolon,
      sym__function_signature_automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_extends,
  [125198] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4138), 13,
      sym__automatic_semicolon,
      sym__function_signature_automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_extends,
  [125218] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4134), 13,
      sym__automatic_semicolon,
      sym__function_signature_automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_extends,
  [125238] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4164), 13,
      sym__automatic_semicolon,
      sym__function_signature_automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_extends,
  [125258] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4168), 13,
      sym__automatic_semicolon,
      sym__function_signature_automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_extends,
  [125278] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4164), 13,
      sym__automatic_semicolon,
      sym__function_signature_automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_extends,
  [125298] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4168), 13,
      sym__automatic_semicolon,
      sym__function_signature_automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_extends,
  [125318] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4236), 13,
      sym__automatic_semicolon,
      sym__function_signature_automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_extends,
  [125338] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4240), 13,
      sym__automatic_semicolon,
      sym__function_signature_automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_extends,
  [125358] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4240), 13,
      sym__automatic_semicolon,
      sym__function_signature_automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_extends,
  [125378] = 5,
    ACTIONS(4224), 1,
      anon_sym_PIPE,
    ACTIONS(6627), 1,
      anon_sym_DOT,
    ACTIONS(6629), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4226), 10,
      sym__automatic_semicolon,
      anon_sym_EQ,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_AMP,
      anon_sym_extends,
      anon_sym_PIPE_RBRACE,
  [125404] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4244), 13,
      sym__automatic_semicolon,
      sym__function_signature_automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_extends,
  [125424] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4244), 13,
      sym__automatic_semicolon,
      sym__function_signature_automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_extends,
  [125444] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4244), 13,
      sym__automatic_semicolon,
      sym__function_signature_automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_extends,
  [125464] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4248), 13,
      sym__automatic_semicolon,
      sym__function_signature_automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_extends,
  [125484] = 6,
    ACTIONS(6381), 1,
      anon_sym_LT,
    ACTIONS(6631), 1,
      anon_sym_DOT,
    ACTIONS(6633), 1,
      anon_sym_is,
    STATE(3319), 1,
      sym_type_arguments,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3548), 9,
      sym__automatic_semicolon,
      sym__function_signature_automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_extends,
  [125512] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4248), 13,
      sym__automatic_semicolon,
      sym__function_signature_automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_extends,
  [125532] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4248), 13,
      sym__automatic_semicolon,
      sym__function_signature_automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_extends,
  [125552] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4278), 13,
      sym__automatic_semicolon,
      sym__function_signature_automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_extends,
  [125572] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4282), 13,
      sym__automatic_semicolon,
      sym__function_signature_automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_extends,
  [125592] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4282), 13,
      sym__automatic_semicolon,
      sym__function_signature_automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_extends,
  [125612] = 10,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(3281), 1,
      anon_sym_LPAREN,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    ACTIONS(6635), 1,
      anon_sym_QMARK,
    STATE(3315), 1,
      sym_formal_parameters,
    STATE(4037), 1,
      sym__call_signature,
    STATE(4050), 1,
      sym_type_annotation,
    STATE(5233), 1,
      sym_type_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6611), 5,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACE,
  [125648] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4282), 13,
      sym__automatic_semicolon,
      sym__function_signature_automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_extends,
  [125668] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4286), 13,
      sym__automatic_semicolon,
      sym__function_signature_automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_extends,
  [125688] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4286), 13,
      sym__automatic_semicolon,
      sym__function_signature_automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_extends,
  [125708] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4286), 13,
      sym__automatic_semicolon,
      sym__function_signature_automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_extends,
  [125728] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4310), 13,
      sym__automatic_semicolon,
      sym__function_signature_automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_extends,
  [125748] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4310), 13,
      sym__automatic_semicolon,
      sym__function_signature_automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_extends,
  [125768] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4310), 13,
      sym__automatic_semicolon,
      sym__function_signature_automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_extends,
  [125788] = 10,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(3281), 1,
      anon_sym_LPAREN,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    ACTIONS(6637), 1,
      anon_sym_QMARK,
    STATE(3315), 1,
      sym_formal_parameters,
    STATE(3606), 1,
      sym__call_signature,
    STATE(4283), 1,
      sym_type_annotation,
    STATE(5233), 1,
      sym_type_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6615), 5,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACE,
  [125824] = 10,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(3281), 1,
      anon_sym_LPAREN,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    ACTIONS(6641), 1,
      anon_sym_QMARK,
    STATE(3315), 1,
      sym_formal_parameters,
    STATE(3597), 1,
      sym__call_signature,
    STATE(4262), 1,
      sym_type_annotation,
    STATE(5233), 1,
      sym_type_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6639), 5,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACE,
  [125860] = 6,
    ACTIONS(4202), 1,
      anon_sym_EQ,
    ACTIONS(6605), 1,
      anon_sym_AMP,
    ACTIONS(6607), 1,
      anon_sym_PIPE,
    ACTIONS(6609), 1,
      anon_sym_extends,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4204), 9,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_EQ_GT,
      anon_sym_GT,
  [125888] = 6,
    ACTIONS(4220), 1,
      anon_sym_EQ,
    ACTIONS(6605), 1,
      anon_sym_AMP,
    ACTIONS(6607), 1,
      anon_sym_PIPE,
    ACTIONS(6609), 1,
      anon_sym_extends,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4222), 9,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_EQ_GT,
      anon_sym_GT,
  [125916] = 10,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(3281), 1,
      anon_sym_LPAREN,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    ACTIONS(6643), 1,
      anon_sym_QMARK,
    STATE(3315), 1,
      sym_formal_parameters,
    STATE(4261), 1,
      sym__call_signature,
    STATE(4262), 1,
      sym_type_annotation,
    STATE(5233), 1,
      sym_type_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6639), 5,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACE,
  [125952] = 6,
    ACTIONS(4434), 1,
      anon_sym_EQ,
    ACTIONS(6605), 1,
      anon_sym_AMP,
    ACTIONS(6607), 1,
      anon_sym_PIPE,
    ACTIONS(6609), 1,
      anon_sym_extends,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4436), 9,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_EQ_GT,
      anon_sym_GT,
  [125980] = 6,
    ACTIONS(4442), 1,
      anon_sym_EQ,
    ACTIONS(6605), 1,
      anon_sym_AMP,
    ACTIONS(6607), 1,
      anon_sym_PIPE,
    ACTIONS(6609), 1,
      anon_sym_extends,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4444), 9,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_EQ_GT,
      anon_sym_GT,
  [126008] = 4,
    ACTIONS(4304), 1,
      anon_sym_EQ,
    ACTIONS(6605), 1,
      anon_sym_AMP,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4306), 11,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_EQ_GT,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_extends,
  [126032] = 5,
    ACTIONS(4108), 1,
      anon_sym_PIPE,
    ACTIONS(6345), 1,
      anon_sym_LT,
    STATE(3217), 1,
      sym_type_arguments,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4110), 10,
      sym__automatic_semicolon,
      anon_sym_EQ,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_AMP,
      anon_sym_extends,
      anon_sym_PIPE_RBRACE,
  [126058] = 10,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(3281), 1,
      anon_sym_LPAREN,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    ACTIONS(6645), 1,
      anon_sym_QMARK,
    STATE(3315), 1,
      sym_formal_parameters,
    STATE(3627), 1,
      sym__call_signature,
    STATE(4030), 1,
      sym_type_annotation,
    STATE(5233), 1,
      sym_type_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6619), 5,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACE,
  [126094] = 6,
    ACTIONS(4292), 1,
      anon_sym_EQ,
    ACTIONS(6605), 1,
      anon_sym_AMP,
    ACTIONS(6607), 1,
      anon_sym_PIPE,
    ACTIONS(6609), 1,
      anon_sym_extends,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4294), 9,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_EQ_GT,
      anon_sym_GT,
  [126122] = 6,
    ACTIONS(4332), 1,
      anon_sym_EQ,
    ACTIONS(6605), 1,
      anon_sym_AMP,
    ACTIONS(6607), 1,
      anon_sym_PIPE,
    ACTIONS(6609), 1,
      anon_sym_extends,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4334), 9,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_EQ_GT,
      anon_sym_GT,
  [126150] = 5,
    ACTIONS(3522), 1,
      anon_sym_PIPE,
    ACTIONS(3530), 1,
      anon_sym_DOT,
    ACTIONS(3532), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3512), 10,
      sym__automatic_semicolon,
      anon_sym_EQ,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_AMP,
      anon_sym_extends,
      anon_sym_PIPE_RBRACE,
  [126176] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4240), 13,
      sym__automatic_semicolon,
      sym__function_signature_automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_extends,
  [126196] = 11,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    ACTIONS(6509), 1,
      anon_sym_LPAREN,
    STATE(3330), 1,
      sym_formal_parameters,
    STATE(3870), 1,
      sym__call_signature,
    STATE(4241), 1,
      sym_type_annotation,
    STATE(4866), 1,
      sym__initializer,
    STATE(5249), 1,
      sym_type_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6647), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [126233] = 5,
    ACTIONS(6381), 1,
      anon_sym_LT,
    ACTIONS(6631), 1,
      anon_sym_DOT,
    STATE(3319), 1,
      sym_type_arguments,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3548), 9,
      sym__automatic_semicolon,
      sym__function_signature_automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_extends,
  [126258] = 9,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(3281), 1,
      anon_sym_LPAREN,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    STATE(3315), 1,
      sym_formal_parameters,
    STATE(4055), 1,
      sym__call_signature,
    STATE(4058), 1,
      sym_type_annotation,
    STATE(5233), 1,
      sym_type_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6649), 5,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACE,
  [126291] = 11,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    ACTIONS(6453), 1,
      anon_sym_LPAREN,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    STATE(3806), 1,
      sym_formal_parameters,
    STATE(3952), 1,
      sym_type_annotation,
    STATE(5114), 1,
      sym__initializer,
    STATE(5328), 1,
      sym_type_parameters,
    STATE(5443), 1,
      sym__call_signature,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6651), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [126328] = 11,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    ACTIONS(6509), 1,
      anon_sym_LPAREN,
    STATE(3330), 1,
      sym_formal_parameters,
    STATE(3757), 1,
      sym__call_signature,
    STATE(4314), 1,
      sym_type_annotation,
    STATE(5015), 1,
      sym__initializer,
    STATE(5249), 1,
      sym_type_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6653), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [126365] = 11,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    ACTIONS(6453), 1,
      anon_sym_LPAREN,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    STATE(3806), 1,
      sym_formal_parameters,
    STATE(3902), 1,
      sym_type_annotation,
    STATE(5124), 1,
      sym__initializer,
    STATE(5137), 1,
      sym__call_signature,
    STATE(5328), 1,
      sym_type_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6655), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [126402] = 11,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(3281), 1,
      anon_sym_LPAREN,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    STATE(3315), 1,
      sym_formal_parameters,
    STATE(4314), 1,
      sym_type_annotation,
    STATE(5045), 1,
      sym__call_signature,
    STATE(5046), 1,
      sym__initializer,
    STATE(5233), 1,
      sym_type_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6653), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [126439] = 11,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    ACTIONS(6453), 1,
      anon_sym_LPAREN,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    STATE(3806), 1,
      sym_formal_parameters,
    STATE(3960), 1,
      sym_type_annotation,
    STATE(4538), 1,
      sym__initializer,
    STATE(5148), 1,
      sym__call_signature,
    STATE(5328), 1,
      sym_type_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6651), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [126476] = 3,
    ACTIONS(3423), 1,
      anon_sym_PIPE,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3425), 11,
      sym__automatic_semicolon,
      anon_sym_EQ,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_AMP,
      anon_sym_extends,
      anon_sym_PIPE_RBRACE,
  [126497] = 4,
    ACTIONS(4114), 1,
      anon_sym_PIPE,
    ACTIONS(6421), 1,
      anon_sym_is,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4116), 10,
      sym__automatic_semicolon,
      anon_sym_EQ,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_AMP,
      anon_sym_extends,
      anon_sym_PIPE_RBRACE,
  [126520] = 7,
    ACTIONS(3808), 1,
      anon_sym_COMMA,
    ACTIONS(3909), 1,
      anon_sym_RBRACE,
    ACTIONS(4622), 1,
      anon_sym_EQ,
    STATE(4792), 1,
      aux_sym_object_repeat1,
    STATE(4815), 1,
      aux_sym_object_pattern_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3814), 7,
      sym__automatic_semicolon,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_QMARK,
      anon_sym_PIPE_RBRACE,
  [126549] = 3,
    ACTIONS(4178), 1,
      anon_sym_PIPE,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4180), 11,
      sym__automatic_semicolon,
      anon_sym_EQ,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_AMP,
      anon_sym_extends,
      anon_sym_PIPE_RBRACE,
  [126570] = 11,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    ACTIONS(6453), 1,
      anon_sym_LPAREN,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    STATE(3806), 1,
      sym_formal_parameters,
    STATE(4128), 1,
      sym_type_annotation,
    STATE(4635), 1,
      sym__initializer,
    STATE(5141), 1,
      sym__call_signature,
    STATE(5328), 1,
      sym_type_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6657), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [126607] = 11,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    ACTIONS(6509), 1,
      anon_sym_LPAREN,
    STATE(3330), 1,
      sym_formal_parameters,
    STATE(3783), 1,
      sym__call_signature,
    STATE(4328), 1,
      sym_type_annotation,
    STATE(5047), 1,
      sym__initializer,
    STATE(5249), 1,
      sym_type_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6659), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [126644] = 8,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(3281), 1,
      anon_sym_LPAREN,
    ACTIONS(4622), 1,
      anon_sym_EQ,
    STATE(3615), 1,
      sym_formal_parameters,
    STATE(5411), 1,
      sym_type_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4074), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
    ACTIONS(3814), 5,
      sym__automatic_semicolon,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_PIPE_RBRACE,
  [126675] = 11,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    ACTIONS(6453), 1,
      anon_sym_LPAREN,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    STATE(3806), 1,
      sym_formal_parameters,
    STATE(4019), 1,
      sym_type_annotation,
    STATE(4816), 1,
      sym__initializer,
    STATE(5151), 1,
      sym__call_signature,
    STATE(5328), 1,
      sym_type_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6651), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [126712] = 9,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(3281), 1,
      anon_sym_LPAREN,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    STATE(3315), 1,
      sym_formal_parameters,
    STATE(3608), 1,
      sym__call_signature,
    STATE(4267), 1,
      sym_type_annotation,
    STATE(5233), 1,
      sym_type_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6661), 5,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACE,
  [126745] = 4,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    STATE(1669), 1,
      sym_arguments,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4326), 10,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_extends,
  [126768] = 7,
    ACTIONS(3808), 1,
      anon_sym_COMMA,
    ACTIONS(3906), 1,
      anon_sym_RBRACE,
    ACTIONS(4622), 1,
      anon_sym_EQ,
    STATE(4810), 1,
      aux_sym_object_repeat1,
    STATE(4815), 1,
      aux_sym_object_pattern_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3814), 7,
      sym__automatic_semicolon,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_QMARK,
      anon_sym_PIPE_RBRACE,
  [126797] = 11,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    ACTIONS(6453), 1,
      anon_sym_LPAREN,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    STATE(3806), 1,
      sym_formal_parameters,
    STATE(4022), 1,
      sym_type_annotation,
    STATE(4833), 1,
      sym__initializer,
    STATE(5164), 1,
      sym__call_signature,
    STATE(5328), 1,
      sym_type_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6651), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [126834] = 12,
    ACTIONS(1626), 1,
      anon_sym_DQUOTE,
    ACTIONS(1628), 1,
      anon_sym_SQUOTE,
    ACTIONS(6327), 1,
      anon_sym_STAR,
    ACTIONS(6331), 1,
      anon_sym_LBRACE,
    ACTIONS(6471), 1,
      sym_identifier,
    ACTIONS(6473), 1,
      anon_sym_type,
    STATE(4299), 1,
      sym_string,
    STATE(4300), 1,
      sym_import_require_clause,
    STATE(5136), 1,
      sym__import_identifier,
    STATE(5337), 1,
      sym_import_clause,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    STATE(5844), 2,
      sym_namespace_import,
      sym_named_imports,
  [126873] = 11,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    ACTIONS(6453), 1,
      anon_sym_LPAREN,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    STATE(3806), 1,
      sym_formal_parameters,
    STATE(4204), 1,
      sym_type_annotation,
    STATE(4773), 1,
      sym__initializer,
    STATE(5328), 1,
      sym_type_parameters,
    STATE(5402), 1,
      sym__call_signature,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6663), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [126910] = 3,
    ACTIONS(3417), 1,
      anon_sym_PIPE,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3419), 11,
      sym__automatic_semicolon,
      anon_sym_EQ,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_AMP,
      anon_sym_extends,
      anon_sym_PIPE_RBRACE,
  [126931] = 11,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    ACTIONS(6509), 1,
      anon_sym_LPAREN,
    STATE(3330), 1,
      sym_formal_parameters,
    STATE(3855), 1,
      sym__call_signature,
    STATE(4054), 1,
      sym_type_annotation,
    STATE(5007), 1,
      sym__initializer,
    STATE(5249), 1,
      sym_type_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6665), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [126968] = 5,
    ACTIONS(6375), 1,
      anon_sym_LPAREN,
    ACTIONS(6667), 1,
      anon_sym_DOT,
    STATE(3289), 1,
      sym_arguments,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4080), 9,
      sym__automatic_semicolon,
      sym__function_signature_automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_extends,
  [126993] = 11,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    ACTIONS(6453), 1,
      anon_sym_LPAREN,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    STATE(3806), 1,
      sym_formal_parameters,
    STATE(4141), 1,
      sym_type_annotation,
    STATE(4660), 1,
      sym__initializer,
    STATE(5177), 1,
      sym__call_signature,
    STATE(5328), 1,
      sym_type_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6663), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [127030] = 11,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    ACTIONS(6453), 1,
      anon_sym_LPAREN,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    STATE(3806), 1,
      sym_formal_parameters,
    STATE(4065), 1,
      sym_type_annotation,
    STATE(5040), 1,
      sym__initializer,
    STATE(5328), 1,
      sym_type_parameters,
    STATE(5393), 1,
      sym__call_signature,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6657), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [127067] = 7,
    ACTIONS(3808), 1,
      anon_sym_COMMA,
    ACTIONS(3912), 1,
      anon_sym_RBRACE,
    ACTIONS(4622), 1,
      anon_sym_EQ,
    STATE(4792), 1,
      aux_sym_object_repeat1,
    STATE(4815), 1,
      aux_sym_object_pattern_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3814), 7,
      sym__automatic_semicolon,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_QMARK,
      anon_sym_PIPE_RBRACE,
  [127096] = 11,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    ACTIONS(6453), 1,
      anon_sym_LPAREN,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    STATE(3806), 1,
      sym_formal_parameters,
    STATE(4346), 1,
      sym_type_annotation,
    STATE(5072), 1,
      sym__initializer,
    STATE(5328), 1,
      sym_type_parameters,
    STATE(5415), 1,
      sym__call_signature,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6651), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [127133] = 7,
    ACTIONS(3808), 1,
      anon_sym_COMMA,
    ACTIONS(3811), 1,
      anon_sym_RBRACE,
    ACTIONS(4622), 1,
      anon_sym_EQ,
    STATE(4792), 1,
      aux_sym_object_repeat1,
    STATE(4815), 1,
      aux_sym_object_pattern_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3814), 7,
      sym__automatic_semicolon,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_QMARK,
      anon_sym_PIPE_RBRACE,
  [127162] = 11,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    ACTIONS(6509), 1,
      anon_sym_LPAREN,
    STATE(3330), 1,
      sym_formal_parameters,
    STATE(3847), 1,
      sym__call_signature,
    STATE(4100), 1,
      sym_type_annotation,
    STATE(4574), 1,
      sym__initializer,
    STATE(5249), 1,
      sym_type_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6669), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [127199] = 9,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(3281), 1,
      anon_sym_LPAREN,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    STATE(3315), 1,
      sym_formal_parameters,
    STATE(4181), 1,
      sym__call_signature,
    STATE(4182), 1,
      sym_type_annotation,
    STATE(5233), 1,
      sym_type_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6671), 5,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACE,
  [127232] = 8,
    ACTIONS(3557), 1,
      anon_sym_COLON,
    ACTIONS(3576), 1,
      anon_sym_LT,
    ACTIONS(6343), 1,
      anon_sym_DOT,
    ACTIONS(6673), 1,
      anon_sym_QMARK,
    STATE(2964), 1,
      sym_type_arguments,
    STATE(5159), 1,
      sym_type_annotation,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3548), 6,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_extends,
  [127263] = 9,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(3281), 1,
      anon_sym_LPAREN,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    STATE(3315), 1,
      sym_formal_parameters,
    STATE(3626), 1,
      sym__call_signature,
    STATE(4027), 1,
      sym_type_annotation,
    STATE(5233), 1,
      sym_type_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6676), 5,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACE,
  [127296] = 11,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    ACTIONS(6453), 1,
      anon_sym_LPAREN,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    STATE(3806), 1,
      sym_formal_parameters,
    STATE(4170), 1,
      sym_type_annotation,
    STATE(4729), 1,
      sym__initializer,
    STATE(5328), 1,
      sym_type_parameters,
    STATE(5336), 1,
      sym__call_signature,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6657), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [127333] = 11,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    ACTIONS(6453), 1,
      anon_sym_LPAREN,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    STATE(3806), 1,
      sym_formal_parameters,
    STATE(4337), 1,
      sym_type_annotation,
    STATE(5063), 1,
      sym__initializer,
    STATE(5328), 1,
      sym_type_parameters,
    STATE(5406), 1,
      sym__call_signature,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6651), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [127370] = 3,
    ACTIONS(1900), 1,
      anon_sym_PIPE,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(1898), 11,
      sym__automatic_semicolon,
      anon_sym_EQ,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_AMP,
      anon_sym_extends,
      anon_sym_is,
      anon_sym_PIPE_RBRACE,
  [127391] = 9,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(3281), 1,
      anon_sym_LPAREN,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    STATE(3315), 1,
      sym_formal_parameters,
    STATE(3527), 1,
      sym__call_signature,
    STATE(4058), 1,
      sym_type_annotation,
    STATE(5233), 1,
      sym_type_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6649), 5,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACE,
  [127424] = 9,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(3281), 1,
      anon_sym_LPAREN,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    STATE(3315), 1,
      sym_formal_parameters,
    STATE(3604), 1,
      sym__call_signature,
    STATE(4278), 1,
      sym_type_annotation,
    STATE(5233), 1,
      sym_type_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6678), 5,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACE,
  [127457] = 8,
    ACTIONS(3516), 1,
      anon_sym_DOT,
    ACTIONS(3520), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(6680), 1,
      anon_sym_LPAREN,
    ACTIONS(6682), 1,
      anon_sym_LT,
    STATE(2917), 1,
      sym_arguments,
    STATE(3015), 1,
      sym_type_arguments,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3512), 6,
      anon_sym_as,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_extends,
  [127488] = 8,
    ACTIONS(6317), 1,
      anon_sym_DOT,
    ACTIONS(6319), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(6680), 1,
      anon_sym_LPAREN,
    ACTIONS(6682), 1,
      anon_sym_LT,
    STATE(2918), 1,
      sym_arguments,
    STATE(2975), 1,
      sym_type_arguments,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4070), 6,
      anon_sym_as,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_extends,
  [127519] = 8,
    ACTIONS(6321), 1,
      anon_sym_DOT,
    ACTIONS(6323), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(6680), 1,
      anon_sym_LPAREN,
    ACTIONS(6682), 1,
      anon_sym_LT,
    STATE(2920), 1,
      sym_arguments,
    STATE(2973), 1,
      sym_type_arguments,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4062), 6,
      anon_sym_as,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_extends,
  [127550] = 11,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(3281), 1,
      anon_sym_LPAREN,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    STATE(3315), 1,
      sym_formal_parameters,
    STATE(4100), 1,
      sym_type_annotation,
    STATE(4978), 1,
      sym__call_signature,
    STATE(4979), 1,
      sym__initializer,
    STATE(5233), 1,
      sym_type_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6669), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [127587] = 4,
    ACTIONS(4250), 1,
      anon_sym_PIPE,
    ACTIONS(6684), 1,
      anon_sym_DOT,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4252), 10,
      sym__automatic_semicolon,
      anon_sym_EQ,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_AMP,
      anon_sym_extends,
      anon_sym_PIPE_RBRACE,
  [127610] = 3,
    ACTIONS(3427), 1,
      anon_sym_PIPE,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3429), 11,
      sym__automatic_semicolon,
      anon_sym_EQ,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_AMP,
      anon_sym_extends,
      anon_sym_PIPE_RBRACE,
  [127631] = 9,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(3281), 1,
      anon_sym_LPAREN,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    STATE(3315), 1,
      sym_formal_parameters,
    STATE(4026), 1,
      sym__call_signature,
    STATE(4027), 1,
      sym_type_annotation,
    STATE(5233), 1,
      sym_type_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6676), 5,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACE,
  [127664] = 9,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(3281), 1,
      anon_sym_LPAREN,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    STATE(3315), 1,
      sym_formal_parameters,
    STATE(4266), 1,
      sym__call_signature,
    STATE(4267), 1,
      sym_type_annotation,
    STATE(5233), 1,
      sym_type_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6661), 5,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACE,
  [127697] = 3,
    ACTIONS(4084), 1,
      anon_sym_PIPE,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4086), 11,
      sym__automatic_semicolon,
      anon_sym_EQ,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_AMP,
      anon_sym_extends,
      anon_sym_is,
      anon_sym_PIPE_RBRACE,
  [127718] = 11,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    ACTIONS(6453), 1,
      anon_sym_LPAREN,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    STATE(3806), 1,
      sym_formal_parameters,
    STATE(4302), 1,
      sym_type_annotation,
    STATE(4995), 1,
      sym__initializer,
    STATE(5328), 1,
      sym_type_parameters,
    STATE(5335), 1,
      sym__call_signature,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6663), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [127755] = 3,
    ACTIONS(4118), 1,
      anon_sym_PIPE,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4120), 11,
      sym__automatic_semicolon,
      anon_sym_EQ,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_AMP,
      anon_sym_extends,
      anon_sym_PIPE_RBRACE,
  [127776] = 4,
    ACTIONS(4104), 1,
      anon_sym_PIPE,
    ACTIONS(6421), 1,
      anon_sym_is,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4106), 10,
      sym__automatic_semicolon,
      anon_sym_EQ,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_AMP,
      anon_sym_extends,
      anon_sym_PIPE_RBRACE,
  [127799] = 11,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    ACTIONS(6453), 1,
      anon_sym_LPAREN,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    STATE(3806), 1,
      sym_formal_parameters,
    STATE(4334), 1,
      sym_type_annotation,
    STATE(5055), 1,
      sym__initializer,
    STATE(5328), 1,
      sym_type_parameters,
    STATE(5401), 1,
      sym__call_signature,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6663), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [127836] = 11,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    ACTIONS(6453), 1,
      anon_sym_LPAREN,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    STATE(3806), 1,
      sym_formal_parameters,
    STATE(4123), 1,
      sym_type_annotation,
    STATE(4619), 1,
      sym__initializer,
    STATE(5328), 1,
      sym_type_parameters,
    STATE(5439), 1,
      sym__call_signature,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6657), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [127873] = 9,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(3281), 1,
      anon_sym_LPAREN,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    STATE(3315), 1,
      sym_formal_parameters,
    STATE(4274), 1,
      sym__call_signature,
    STATE(4278), 1,
      sym_type_annotation,
    STATE(5233), 1,
      sym_type_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6678), 5,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACE,
  [127906] = 11,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    ACTIONS(6453), 1,
      anon_sym_LPAREN,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    STATE(3806), 1,
      sym_formal_parameters,
    STATE(4231), 1,
      sym_type_annotation,
    STATE(4834), 1,
      sym__initializer,
    STATE(5170), 1,
      sym__call_signature,
    STATE(5328), 1,
      sym_type_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6686), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [127943] = 4,
    ACTIONS(4108), 1,
      anon_sym_PIPE,
    ACTIONS(6688), 1,
      anon_sym_is,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4110), 10,
      sym__automatic_semicolon,
      anon_sym_EQ,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_AMP,
      anon_sym_extends,
      anon_sym_PIPE_RBRACE,
  [127966] = 9,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(3281), 1,
      anon_sym_LPAREN,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    STATE(3315), 1,
      sym_formal_parameters,
    STATE(3633), 1,
      sym__call_signature,
    STATE(4182), 1,
      sym_type_annotation,
    STATE(5233), 1,
      sym_type_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6671), 5,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACE,
  [127999] = 7,
    ACTIONS(3808), 1,
      anon_sym_COMMA,
    ACTIONS(3925), 1,
      anon_sym_RBRACE,
    ACTIONS(4622), 1,
      anon_sym_EQ,
    STATE(4792), 1,
      aux_sym_object_repeat1,
    STATE(4815), 1,
      aux_sym_object_pattern_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3814), 7,
      sym__automatic_semicolon,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_QMARK,
      anon_sym_PIPE_RBRACE,
  [128028] = 3,
    ACTIONS(4324), 1,
      anon_sym_PIPE,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4326), 10,
      sym__automatic_semicolon,
      anon_sym_EQ,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_AMP,
      anon_sym_extends,
      anon_sym_PIPE_RBRACE,
  [128048] = 5,
    ACTIONS(4170), 1,
      anon_sym_PIPE,
    ACTIONS(6690), 1,
      anon_sym_LBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4172), 2,
      anon_sym_AMP,
      anon_sym_extends,
    ACTIONS(4452), 7,
      sym__automatic_semicolon,
      anon_sym_EQ,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACE,
  [128072] = 3,
    ACTIONS(4174), 1,
      anon_sym_PIPE,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4176), 10,
      sym__automatic_semicolon,
      anon_sym_EQ,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_AMP,
      anon_sym_extends,
      anon_sym_PIPE_RBRACE,
  [128092] = 3,
    ACTIONS(2371), 1,
      anon_sym_PIPE,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(2369), 10,
      sym__automatic_semicolon,
      anon_sym_EQ,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_AMP,
      anon_sym_extends,
      anon_sym_PIPE_RBRACE,
  [128112] = 4,
    ACTIONS(4190), 1,
      anon_sym_PIPE,
    ACTIONS(6692), 1,
      anon_sym_extends,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4192), 9,
      sym__automatic_semicolon,
      anon_sym_EQ,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_AMP,
      anon_sym_PIPE_RBRACE,
  [128134] = 4,
    ACTIONS(6427), 1,
      anon_sym_DOT,
    ACTIONS(6429), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3512), 9,
      sym__automatic_semicolon,
      sym__function_signature_automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_extends,
  [128156] = 4,
    ACTIONS(6694), 1,
      anon_sym_DOT,
    ACTIONS(6696), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4226), 9,
      sym__automatic_semicolon,
      sym__function_signature_automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_extends,
  [128178] = 5,
    ACTIONS(6698), 1,
      anon_sym_AMP,
    ACTIONS(6700), 1,
      anon_sym_PIPE,
    ACTIONS(6702), 1,
      anon_sym_extends,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4294), 8,
      sym__automatic_semicolon,
      anon_sym_EQ,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_PIPE_RBRACE,
  [128202] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3227), 11,
      sym__automatic_semicolon,
      sym__function_signature_automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_extends,
  [128220] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4322), 11,
      sym__automatic_semicolon,
      sym__function_signature_automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_extends,
  [128238] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4330), 11,
      sym__automatic_semicolon,
      sym__function_signature_automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_extends,
  [128256] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4348), 11,
      sym__automatic_semicolon,
      sym__function_signature_automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_extends,
  [128274] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3814), 11,
      sym__automatic_semicolon,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_BANG,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_QMARK,
      anon_sym_PIPE_RBRACE,
  [128292] = 3,
    ACTIONS(1888), 1,
      anon_sym_DOT,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4386), 10,
      sym__automatic_semicolon,
      sym__function_signature_automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_extends,
  [128312] = 3,
    ACTIONS(4402), 1,
      anon_sym_PIPE,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4404), 10,
      sym__automatic_semicolon,
      anon_sym_EQ,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_AMP,
      anon_sym_extends,
      anon_sym_PIPE_RBRACE,
  [128332] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3474), 11,
      sym__automatic_semicolon,
      sym__function_signature_automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_extends,
  [128350] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3478), 11,
      sym__automatic_semicolon,
      sym__function_signature_automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_extends,
  [128368] = 3,
    ACTIONS(4256), 1,
      anon_sym_PIPE,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4258), 10,
      sym__automatic_semicolon,
      anon_sym_EQ,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_AMP,
      anon_sym_extends,
      anon_sym_PIPE_RBRACE,
  [128388] = 3,
    ACTIONS(1892), 1,
      anon_sym_DOT,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4386), 10,
      sym__automatic_semicolon,
      sym__function_signature_automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_extends,
  [128408] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4416), 11,
      sym__automatic_semicolon,
      sym__function_signature_automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_extends,
  [128426] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4420), 11,
      sym__automatic_semicolon,
      sym__function_signature_automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_extends,
  [128444] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4424), 11,
      sym__automatic_semicolon,
      sym__function_signature_automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_extends,
  [128462] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4428), 11,
      sym__automatic_semicolon,
      sym__function_signature_automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_extends,
  [128480] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3235), 11,
      sym__automatic_semicolon,
      sym__function_signature_automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_extends,
  [128498] = 3,
    ACTIONS(4260), 1,
      anon_sym_PIPE,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4262), 10,
      sym__automatic_semicolon,
      anon_sym_EQ,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_AMP,
      anon_sym_extends,
      anon_sym_PIPE_RBRACE,
  [128518] = 3,
    ACTIONS(4264), 1,
      anon_sym_PIPE,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4266), 10,
      sym__automatic_semicolon,
      anon_sym_EQ,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_AMP,
      anon_sym_extends,
      anon_sym_PIPE_RBRACE,
  [128538] = 3,
    ACTIONS(2363), 1,
      anon_sym_PIPE,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(2361), 10,
      sym__automatic_semicolon,
      anon_sym_EQ,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_AMP,
      anon_sym_extends,
      anon_sym_PIPE_RBRACE,
  [128558] = 5,
    ACTIONS(6698), 1,
      anon_sym_AMP,
    ACTIONS(6700), 1,
      anon_sym_PIPE,
    ACTIONS(6702), 1,
      anon_sym_extends,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4404), 8,
      sym__automatic_semicolon,
      anon_sym_EQ,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_PIPE_RBRACE,
  [128582] = 3,
    ACTIONS(4316), 1,
      anon_sym_PIPE,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4318), 10,
      sym__automatic_semicolon,
      anon_sym_EQ,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_AMP,
      anon_sym_extends,
      anon_sym_PIPE_RBRACE,
  [128602] = 5,
    ACTIONS(6698), 1,
      anon_sym_AMP,
    ACTIONS(6700), 1,
      anon_sym_PIPE,
    ACTIONS(6702), 1,
      anon_sym_extends,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4334), 8,
      sym__automatic_semicolon,
      anon_sym_EQ,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_PIPE_RBRACE,
  [128626] = 3,
    ACTIONS(2379), 1,
      anon_sym_PIPE,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(2377), 10,
      sym__automatic_semicolon,
      anon_sym_EQ,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_AMP,
      anon_sym_extends,
      anon_sym_PIPE_RBRACE,
  [128646] = 3,
    ACTIONS(4430), 1,
      anon_sym_PIPE,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4432), 10,
      sym__automatic_semicolon,
      anon_sym_EQ,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_AMP,
      anon_sym_extends,
      anon_sym_PIPE_RBRACE,
  [128666] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3239), 11,
      sym__automatic_semicolon,
      sym__function_signature_automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_extends,
  [128684] = 4,
    ACTIONS(4438), 1,
      anon_sym_PIPE,
    ACTIONS(6698), 1,
      anon_sym_AMP,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4440), 9,
      sym__automatic_semicolon,
      anon_sym_EQ,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_extends,
      anon_sym_PIPE_RBRACE,
  [128706] = 3,
    ACTIONS(4446), 1,
      anon_sym_PIPE,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4448), 10,
      sym__automatic_semicolon,
      anon_sym_EQ,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_AMP,
      anon_sym_extends,
      anon_sym_PIPE_RBRACE,
  [128726] = 3,
    ACTIONS(4391), 1,
      anon_sym_PIPE,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4393), 10,
      sym__automatic_semicolon,
      anon_sym_EQ,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_AMP,
      anon_sym_extends,
      anon_sym_PIPE_RBRACE,
  [128746] = 5,
    ACTIONS(6698), 1,
      anon_sym_AMP,
    ACTIONS(6700), 1,
      anon_sym_PIPE,
    ACTIONS(6702), 1,
      anon_sym_extends,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4444), 8,
      sym__automatic_semicolon,
      anon_sym_EQ,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_PIPE_RBRACE,
  [128770] = 3,
    ACTIONS(2367), 1,
      anon_sym_PIPE,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(2365), 10,
      sym__automatic_semicolon,
      anon_sym_EQ,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_AMP,
      anon_sym_extends,
      anon_sym_PIPE_RBRACE,
  [128790] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(5494), 11,
      sym__automatic_semicolon,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_BANG,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_QMARK,
      anon_sym_PIPE_RBRACE,
  [128808] = 4,
    ACTIONS(4212), 1,
      anon_sym_PIPE,
    ACTIONS(6690), 1,
      anon_sym_LBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4214), 9,
      sym__automatic_semicolon,
      anon_sym_EQ,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_AMP,
      anon_sym_extends,
      anon_sym_PIPE_RBRACE,
  [128830] = 3,
    ACTIONS(4342), 1,
      anon_sym_PIPE,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4344), 10,
      sym__automatic_semicolon,
      anon_sym_EQ,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_AMP,
      anon_sym_extends,
      anon_sym_PIPE_RBRACE,
  [128850] = 11,
    ACTIONS(3109), 1,
      anon_sym_DQUOTE,
    ACTIONS(3111), 1,
      anon_sym_SQUOTE,
    ACTIONS(6704), 1,
      sym_identifier,
    ACTIONS(6706), 1,
      anon_sym_type,
    ACTIONS(6708), 1,
      anon_sym_COMMA,
    ACTIONS(6710), 1,
      anon_sym_RBRACE,
    ACTIONS(6712), 1,
      anon_sym_typeof,
    STATE(5029), 1,
      sym_import_specifier,
    STATE(5384), 1,
      sym__import_identifier,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    STATE(5604), 2,
      sym__module_export_name,
      sym_string,
  [128886] = 3,
    ACTIONS(4350), 1,
      anon_sym_PIPE,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4352), 10,
      sym__automatic_semicolon,
      anon_sym_EQ,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_AMP,
      anon_sym_extends,
      anon_sym_PIPE_RBRACE,
  [128906] = 3,
    ACTIONS(4354), 1,
      anon_sym_PIPE,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4356), 10,
      sym__automatic_semicolon,
      anon_sym_EQ,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_AMP,
      anon_sym_extends,
      anon_sym_PIPE_RBRACE,
  [128926] = 3,
    ACTIONS(4186), 1,
      anon_sym_PIPE,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4188), 10,
      sym__automatic_semicolon,
      anon_sym_EQ,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_AMP,
      anon_sym_extends,
      anon_sym_PIPE_RBRACE,
  [128946] = 3,
    ACTIONS(4358), 1,
      anon_sym_PIPE,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4360), 10,
      sym__automatic_semicolon,
      anon_sym_EQ,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_AMP,
      anon_sym_extends,
      anon_sym_PIPE_RBRACE,
  [128966] = 3,
    ACTIONS(4196), 1,
      anon_sym_PIPE,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4198), 10,
      sym__automatic_semicolon,
      anon_sym_EQ,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_AMP,
      anon_sym_extends,
      anon_sym_PIPE_RBRACE,
  [128986] = 6,
    ACTIONS(3576), 1,
      anon_sym_LT,
    ACTIONS(6343), 1,
      anon_sym_DOT,
    ACTIONS(6714), 1,
      anon_sym_is,
    STATE(2964), 1,
      sym_type_arguments,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3548), 7,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_QMARK,
      anon_sym_extends,
  [129012] = 3,
    ACTIONS(4372), 1,
      anon_sym_PIPE,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4374), 10,
      sym__automatic_semicolon,
      anon_sym_EQ,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_AMP,
      anon_sym_extends,
      anon_sym_PIPE_RBRACE,
  [129032] = 3,
    ACTIONS(4368), 1,
      anon_sym_PIPE,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4370), 10,
      sym__automatic_semicolon,
      anon_sym_EQ,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_AMP,
      anon_sym_extends,
      anon_sym_PIPE_RBRACE,
  [129052] = 3,
    ACTIONS(4406), 1,
      anon_sym_PIPE,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4408), 10,
      sym__automatic_semicolon,
      anon_sym_EQ,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_AMP,
      anon_sym_extends,
      anon_sym_PIPE_RBRACE,
  [129072] = 3,
    ACTIONS(4104), 1,
      anon_sym_PIPE,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4106), 10,
      sym__automatic_semicolon,
      anon_sym_EQ,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_AMP,
      anon_sym_extends,
      anon_sym_PIPE_RBRACE,
  [129092] = 5,
    ACTIONS(6698), 1,
      anon_sym_AMP,
    ACTIONS(6700), 1,
      anon_sym_PIPE,
    ACTIONS(6702), 1,
      anon_sym_extends,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4204), 8,
      sym__automatic_semicolon,
      anon_sym_EQ,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_PIPE_RBRACE,
  [129116] = 5,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4324), 1,
      anon_sym_PIPE,
    STATE(1669), 1,
      sym_arguments,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4326), 8,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_AMP,
      anon_sym_extends,
      anon_sym_PIPE_RBRACE,
  [129140] = 3,
    ACTIONS(4216), 1,
      anon_sym_PIPE,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4218), 10,
      sym__automatic_semicolon,
      anon_sym_EQ,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_AMP,
      anon_sym_extends,
      anon_sym_PIPE_RBRACE,
  [129160] = 3,
    ACTIONS(4220), 1,
      anon_sym_PIPE,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4222), 10,
      sym__automatic_semicolon,
      anon_sym_EQ,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_AMP,
      anon_sym_extends,
      anon_sym_PIPE_RBRACE,
  [129180] = 3,
    ACTIONS(4170), 1,
      anon_sym_PIPE,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4172), 10,
      sym__automatic_semicolon,
      anon_sym_EQ,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_AMP,
      anon_sym_extends,
      anon_sym_PIPE_RBRACE,
  [129200] = 4,
    ACTIONS(4170), 1,
      anon_sym_PIPE,
    ACTIONS(6690), 1,
      anon_sym_LBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4172), 9,
      sym__automatic_semicolon,
      anon_sym_EQ,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_AMP,
      anon_sym_extends,
      anon_sym_PIPE_RBRACE,
  [129222] = 3,
    ACTIONS(4108), 1,
      anon_sym_PIPE,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4110), 10,
      sym__automatic_semicolon,
      anon_sym_EQ,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_AMP,
      anon_sym_extends,
      anon_sym_PIPE_RBRACE,
  [129242] = 3,
    ACTIONS(4140), 1,
      anon_sym_PIPE,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4142), 10,
      sym__automatic_semicolon,
      anon_sym_EQ,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_AMP,
      anon_sym_extends,
      anon_sym_PIPE_RBRACE,
  [129262] = 5,
    ACTIONS(6698), 1,
      anon_sym_AMP,
    ACTIONS(6700), 1,
      anon_sym_PIPE,
    ACTIONS(6702), 1,
      anon_sym_extends,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4222), 8,
      sym__automatic_semicolon,
      anon_sym_EQ,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_PIPE_RBRACE,
  [129286] = 5,
    ACTIONS(6698), 1,
      anon_sym_AMP,
    ACTIONS(6700), 1,
      anon_sym_PIPE,
    ACTIONS(6702), 1,
      anon_sym_extends,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4436), 8,
      sym__automatic_semicolon,
      anon_sym_EQ,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_PIPE_RBRACE,
  [129310] = 3,
    ACTIONS(2375), 1,
      anon_sym_PIPE,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(2373), 10,
      sym__automatic_semicolon,
      anon_sym_EQ,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_AMP,
      anon_sym_extends,
      anon_sym_PIPE_RBRACE,
  [129330] = 4,
    ACTIONS(6381), 1,
      anon_sym_LT,
    STATE(3363), 1,
      sym_type_arguments,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4110), 9,
      sym__automatic_semicolon,
      sym__function_signature_automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_extends,
  [129352] = 6,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(3281), 1,
      anon_sym_LPAREN,
    STATE(3615), 1,
      sym_formal_parameters,
    STATE(5411), 1,
      sym_type_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3814), 7,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_PIPE_RBRACE,
  [129378] = 3,
    ACTIONS(4230), 1,
      anon_sym_PIPE,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4232), 10,
      sym__automatic_semicolon,
      anon_sym_EQ,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_AMP,
      anon_sym_extends,
      anon_sym_PIPE_RBRACE,
  [129398] = 3,
    ACTIONS(4270), 1,
      anon_sym_PIPE,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4156), 10,
      sym__automatic_semicolon,
      anon_sym_EQ,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_AMP,
      anon_sym_extends,
      anon_sym_PIPE_RBRACE,
  [129418] = 3,
    ACTIONS(4300), 1,
      anon_sym_PIPE,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4302), 10,
      sym__automatic_semicolon,
      anon_sym_EQ,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_AMP,
      anon_sym_extends,
      anon_sym_PIPE_RBRACE,
  [129438] = 4,
    ACTIONS(4304), 1,
      anon_sym_PIPE,
    ACTIONS(6698), 1,
      anon_sym_AMP,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4306), 9,
      sym__automatic_semicolon,
      anon_sym_EQ,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_extends,
      anon_sym_PIPE_RBRACE,
  [129460] = 3,
    ACTIONS(4184), 1,
      anon_sym_PIPE,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4182), 10,
      sym__automatic_semicolon,
      anon_sym_EQ,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_AMP,
      anon_sym_extends,
      anon_sym_PIPE_RBRACE,
  [129480] = 3,
    ACTIONS(4376), 1,
      anon_sym_PIPE,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4378), 10,
      sym__automatic_semicolon,
      anon_sym_EQ,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_AMP,
      anon_sym_extends,
      anon_sym_PIPE_RBRACE,
  [129500] = 3,
    ACTIONS(4114), 1,
      anon_sym_PIPE,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4116), 10,
      sym__automatic_semicolon,
      anon_sym_EQ,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_AMP,
      anon_sym_extends,
      anon_sym_PIPE_RBRACE,
  [129520] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(1898), 10,
      sym__automatic_semicolon,
      sym__function_signature_automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_extends,
      anon_sym_is,
  [129537] = 3,
    ACTIONS(6633), 1,
      anon_sym_is,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4116), 9,
      sym__automatic_semicolon,
      sym__function_signature_automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_extends,
  [129556] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4180), 10,
      sym__automatic_semicolon,
      sym__function_signature_automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_extends,
  [129573] = 11,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(6716), 1,
      sym_identifier,
    ACTIONS(6718), 1,
      anon_sym_LBRACE,
    ACTIONS(6720), 1,
      anon_sym_extends,
    ACTIONS(6722), 1,
      anon_sym_implements,
    STATE(2266), 1,
      sym_class_body,
    STATE(3685), 1,
      sym_type_parameters,
    STATE(5080), 1,
      sym_extends_clause,
    STATE(5418), 1,
      sym_class_heritage,
    STATE(5792), 1,
      sym_implements_clause,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [129608] = 11,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(6718), 1,
      anon_sym_LBRACE,
    ACTIONS(6720), 1,
      anon_sym_extends,
    ACTIONS(6722), 1,
      anon_sym_implements,
    ACTIONS(6724), 1,
      sym_identifier,
    STATE(2277), 1,
      sym_class_body,
    STATE(3578), 1,
      sym_type_parameters,
    STATE(5080), 1,
      sym_extends_clause,
    STATE(5201), 1,
      sym_class_heritage,
    STATE(5792), 1,
      sym_implements_clause,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [129643] = 10,
    ACTIONS(3109), 1,
      anon_sym_DQUOTE,
    ACTIONS(3111), 1,
      anon_sym_SQUOTE,
    ACTIONS(6704), 1,
      sym_identifier,
    ACTIONS(6706), 1,
      anon_sym_type,
    ACTIONS(6712), 1,
      anon_sym_typeof,
    ACTIONS(6726), 1,
      anon_sym_RBRACE,
    STATE(5314), 1,
      sym_import_specifier,
    STATE(5384), 1,
      sym__import_identifier,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    STATE(5604), 2,
      sym__module_export_name,
      sym_string,
  [129676] = 11,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(6718), 1,
      anon_sym_LBRACE,
    ACTIONS(6720), 1,
      anon_sym_extends,
    ACTIONS(6722), 1,
      anon_sym_implements,
    ACTIONS(6728), 1,
      sym_identifier,
    STATE(2277), 1,
      sym_class_body,
    STATE(3578), 1,
      sym_type_parameters,
    STATE(5080), 1,
      sym_extends_clause,
    STATE(5201), 1,
      sym_class_heritage,
    STATE(5792), 1,
      sym_implements_clause,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [129711] = 11,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(6720), 1,
      anon_sym_extends,
    ACTIONS(6722), 1,
      anon_sym_implements,
    ACTIONS(6730), 1,
      sym_identifier,
    ACTIONS(6732), 1,
      anon_sym_LBRACE,
    STATE(1673), 1,
      sym_class_body,
    STATE(3716), 1,
      sym_type_parameters,
    STATE(5080), 1,
      sym_extends_clause,
    STATE(5149), 1,
      sym_class_heritage,
    STATE(5792), 1,
      sym_implements_clause,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [129746] = 10,
    ACTIONS(3109), 1,
      anon_sym_DQUOTE,
    ACTIONS(3111), 1,
      anon_sym_SQUOTE,
    ACTIONS(6704), 1,
      sym_identifier,
    ACTIONS(6706), 1,
      anon_sym_type,
    ACTIONS(6712), 1,
      anon_sym_typeof,
    ACTIONS(6734), 1,
      anon_sym_RBRACE,
    STATE(5314), 1,
      sym_import_specifier,
    STATE(5384), 1,
      sym__import_identifier,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    STATE(5604), 2,
      sym__module_export_name,
      sym_string,
  [129779] = 9,
    ACTIONS(3109), 1,
      anon_sym_DQUOTE,
    ACTIONS(3111), 1,
      anon_sym_SQUOTE,
    ACTIONS(6736), 1,
      sym_identifier,
    ACTIONS(6740), 1,
      anon_sym_COMMA,
    ACTIONS(6742), 1,
      anon_sym_RBRACE,
    STATE(4730), 1,
      sym_export_specifier,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6738), 2,
      anon_sym_type,
      anon_sym_typeof,
    STATE(4735), 2,
      sym__module_export_name,
      sym_string,
  [129810] = 11,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(6718), 1,
      anon_sym_LBRACE,
    ACTIONS(6720), 1,
      anon_sym_extends,
    ACTIONS(6722), 1,
      anon_sym_implements,
    ACTIONS(6744), 1,
      sym_identifier,
    STATE(2266), 1,
      sym_class_body,
    STATE(3685), 1,
      sym_type_parameters,
    STATE(5080), 1,
      sym_extends_clause,
    STATE(5418), 1,
      sym_class_heritage,
    STATE(5792), 1,
      sym_implements_clause,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [129845] = 11,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(6718), 1,
      anon_sym_LBRACE,
    ACTIONS(6720), 1,
      anon_sym_extends,
    ACTIONS(6722), 1,
      anon_sym_implements,
    ACTIONS(6746), 1,
      sym_identifier,
    STATE(2266), 1,
      sym_class_body,
    STATE(3685), 1,
      sym_type_parameters,
    STATE(5080), 1,
      sym_extends_clause,
    STATE(5418), 1,
      sym_class_heritage,
    STATE(5792), 1,
      sym_implements_clause,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [129880] = 4,
    ACTIONS(4622), 1,
      anon_sym_EQ,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4074), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
    ACTIONS(3814), 7,
      sym__automatic_semicolon,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_QMARK,
      anon_sym_PIPE_RBRACE,
  [129901] = 11,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(6718), 1,
      anon_sym_LBRACE,
    ACTIONS(6720), 1,
      anon_sym_extends,
    ACTIONS(6722), 1,
      anon_sym_implements,
    ACTIONS(6748), 1,
      sym_identifier,
    STATE(2266), 1,
      sym_class_body,
    STATE(3685), 1,
      sym_type_parameters,
    STATE(5080), 1,
      sym_extends_clause,
    STATE(5418), 1,
      sym_class_heritage,
    STATE(5792), 1,
      sym_implements_clause,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [129936] = 3,
    ACTIONS(6633), 1,
      anon_sym_is,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4106), 9,
      sym__automatic_semicolon,
      sym__function_signature_automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_extends,
  [129955] = 5,
    ACTIONS(6698), 1,
      anon_sym_AMP,
    ACTIONS(6700), 1,
      anon_sym_PIPE,
    ACTIONS(6702), 1,
      anon_sym_extends,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6750), 7,
      sym__automatic_semicolon,
      anon_sym_EQ,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACE,
  [129978] = 5,
    ACTIONS(6066), 1,
      anon_sym_LPAREN,
    ACTIONS(6357), 1,
      anon_sym_DOT,
    STATE(2934), 1,
      sym_arguments,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4080), 7,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_QMARK,
      anon_sym_extends,
  [130001] = 4,
    ACTIONS(6754), 1,
      anon_sym_COLON,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    STATE(3886), 3,
      sym_type_annotation,
      sym_asserts_annotation,
      sym_type_predicate_annotation,
    ACTIONS(6752), 6,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACE,
  [130022] = 3,
    ACTIONS(6756), 1,
      anon_sym_is,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4110), 9,
      sym__automatic_semicolon,
      sym__function_signature_automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_extends,
  [130041] = 6,
    ACTIONS(6343), 1,
      anon_sym_DOT,
    ACTIONS(6682), 1,
      anon_sym_LT,
    ACTIONS(6758), 1,
      anon_sym_is,
    STATE(2964), 1,
      sym_type_arguments,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3548), 6,
      anon_sym_as,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_extends,
  [130066] = 11,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(6720), 1,
      anon_sym_extends,
    ACTIONS(6722), 1,
      anon_sym_implements,
    ACTIONS(6732), 1,
      anon_sym_LBRACE,
    ACTIONS(6760), 1,
      sym_identifier,
    STATE(2573), 1,
      sym_class_body,
    STATE(3670), 1,
      sym_type_parameters,
    STATE(5080), 1,
      sym_extends_clause,
    STATE(5171), 1,
      sym_class_heritage,
    STATE(5792), 1,
      sym_implements_clause,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [130101] = 11,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(6718), 1,
      anon_sym_LBRACE,
    ACTIONS(6720), 1,
      anon_sym_extends,
    ACTIONS(6722), 1,
      anon_sym_implements,
    ACTIONS(6762), 1,
      sym_identifier,
    STATE(2277), 1,
      sym_class_body,
    STATE(3578), 1,
      sym_type_parameters,
    STATE(5080), 1,
      sym_extends_clause,
    STATE(5201), 1,
      sym_class_heritage,
    STATE(5792), 1,
      sym_implements_clause,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [130136] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4086), 10,
      sym__automatic_semicolon,
      sym__function_signature_automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_extends,
      anon_sym_is,
  [130153] = 11,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(6718), 1,
      anon_sym_LBRACE,
    ACTIONS(6720), 1,
      anon_sym_extends,
    ACTIONS(6722), 1,
      anon_sym_implements,
    ACTIONS(6764), 1,
      sym_identifier,
    STATE(2277), 1,
      sym_class_body,
    STATE(3578), 1,
      sym_type_parameters,
    STATE(5080), 1,
      sym_extends_clause,
    STATE(5201), 1,
      sym_class_heritage,
    STATE(5792), 1,
      sym_implements_clause,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [130188] = 3,
    ACTIONS(6766), 1,
      anon_sym_DOT,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4252), 9,
      sym__automatic_semicolon,
      sym__function_signature_automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_extends,
  [130207] = 9,
    ACTIONS(3109), 1,
      anon_sym_DQUOTE,
    ACTIONS(3111), 1,
      anon_sym_SQUOTE,
    ACTIONS(6704), 1,
      sym_identifier,
    ACTIONS(6768), 1,
      anon_sym_type,
    ACTIONS(6770), 1,
      anon_sym_as,
    STATE(5355), 1,
      sym__import_identifier,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6475), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
    STATE(5579), 2,
      sym__module_export_name,
      sym_string,
  [130238] = 8,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    ACTIONS(6772), 1,
      anon_sym_EQ,
    ACTIONS(6776), 1,
      anon_sym_BANG,
    STATE(4215), 1,
      sym__initializer,
    STATE(4338), 1,
      sym_type_annotation,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6778), 2,
      anon_sym_in,
      anon_sym_of,
    ACTIONS(6774), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [130267] = 9,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    ACTIONS(6776), 1,
      anon_sym_BANG,
    ACTIONS(6780), 1,
      sym__automatic_semicolon,
    STATE(4338), 1,
      sym_type_annotation,
    STATE(5056), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6774), 2,
      anon_sym_COMMA,
      anon_sym_SEMI,
    ACTIONS(6778), 2,
      anon_sym_in,
      anon_sym_of,
  [130298] = 4,
    ACTIONS(6754), 1,
      anon_sym_COLON,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    STATE(3825), 3,
      sym_type_annotation,
      sym_asserts_annotation,
      sym_type_predicate_annotation,
    ACTIONS(6783), 6,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACE,
  [130319] = 11,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(6720), 1,
      anon_sym_extends,
    ACTIONS(6722), 1,
      anon_sym_implements,
    ACTIONS(6732), 1,
      anon_sym_LBRACE,
    ACTIONS(6785), 1,
      sym_identifier,
    STATE(1653), 1,
      sym_class_body,
    STATE(3666), 1,
      sym_type_parameters,
    STATE(5080), 1,
      sym_extends_clause,
    STATE(5449), 1,
      sym_class_heritage,
    STATE(5792), 1,
      sym_implements_clause,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [130354] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4120), 10,
      sym__automatic_semicolon,
      sym__function_signature_automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_extends,
  [130371] = 8,
    ACTIONS(3109), 1,
      anon_sym_DQUOTE,
    ACTIONS(3111), 1,
      anon_sym_SQUOTE,
    ACTIONS(6736), 1,
      sym_identifier,
    ACTIONS(6787), 1,
      anon_sym_RBRACE,
    STATE(5379), 1,
      sym_export_specifier,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6738), 2,
      anon_sym_type,
      anon_sym_typeof,
    STATE(4735), 2,
      sym__module_export_name,
      sym_string,
  [130399] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4393), 9,
      sym__automatic_semicolon,
      sym__function_signature_automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_extends,
  [130415] = 8,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    ACTIONS(6789), 1,
      anon_sym_BANG,
    ACTIONS(6791), 1,
      anon_sym_QMARK,
    STATE(3908), 1,
      sym_type_annotation,
    STATE(4610), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6489), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [130443] = 8,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    ACTIONS(6793), 1,
      anon_sym_BANG,
    ACTIONS(6795), 1,
      anon_sym_QMARK,
    STATE(4124), 1,
      sym_type_annotation,
    STATE(4627), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6449), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [130471] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4356), 9,
      sym__automatic_semicolon,
      sym__function_signature_automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_extends,
  [130487] = 8,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    ACTIONS(6797), 1,
      anon_sym_BANG,
    ACTIONS(6799), 1,
      anon_sym_QMARK,
    STATE(3911), 1,
      sym_type_annotation,
    STATE(4680), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6489), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [130515] = 8,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    ACTIONS(6801), 1,
      anon_sym_BANG,
    ACTIONS(6803), 1,
      anon_sym_QMARK,
    STATE(3913), 1,
      sym_type_annotation,
    STATE(4825), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6489), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [130543] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4360), 9,
      sym__automatic_semicolon,
      sym__function_signature_automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_extends,
  [130559] = 8,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    ACTIONS(6805), 1,
      anon_sym_BANG,
    ACTIONS(6807), 1,
      anon_sym_QMARK,
    STATE(4379), 1,
      sym_type_annotation,
    STATE(4707), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6513), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [130587] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4258), 9,
      sym__automatic_semicolon,
      sym__function_signature_automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_extends,
  [130603] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4262), 9,
      sym__automatic_semicolon,
      sym__function_signature_automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_extends,
  [130619] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4266), 9,
      sym__automatic_semicolon,
      sym__function_signature_automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_extends,
  [130635] = 4,
    ACTIONS(6809), 1,
      anon_sym_COLON,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    STATE(4324), 3,
      sym_type_annotation,
      sym_asserts_annotation,
      sym_type_predicate_annotation,
    ACTIONS(6783), 5,
      sym__automatic_semicolon,
      sym__function_signature_automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [130655] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(2361), 9,
      sym__automatic_semicolon,
      sym__function_signature_automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_extends,
  [130671] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4374), 9,
      sym__automatic_semicolon,
      sym__function_signature_automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_extends,
  [130687] = 8,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    ACTIONS(6811), 1,
      anon_sym_BANG,
    ACTIONS(6813), 1,
      anon_sym_QMARK,
    STATE(3936), 1,
      sym_type_annotation,
    STATE(4665), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6489), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [130715] = 8,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    ACTIONS(6815), 1,
      anon_sym_BANG,
    ACTIONS(6817), 1,
      anon_sym_QMARK,
    STATE(3937), 1,
      sym_type_annotation,
    STATE(4774), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6489), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [130743] = 5,
    ACTIONS(6819), 1,
      anon_sym_AMP,
    ACTIONS(6821), 1,
      anon_sym_PIPE,
    ACTIONS(6823), 1,
      anon_sym_extends,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4294), 6,
      sym__automatic_semicolon,
      sym__function_signature_automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LBRACK,
  [130765] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4116), 9,
      sym__automatic_semicolon,
      sym__function_signature_automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_extends,
  [130781] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(2373), 9,
      sym__automatic_semicolon,
      sym__function_signature_automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_extends,
  [130797] = 4,
    ACTIONS(6825), 1,
      anon_sym_LBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4172), 3,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_extends,
    ACTIONS(4452), 5,
      sym__automatic_semicolon,
      sym__function_signature_automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [130817] = 3,
    ACTIONS(6827), 1,
      anon_sym_extends,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4192), 8,
      sym__automatic_semicolon,
      sym__function_signature_automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_AMP,
      anon_sym_PIPE,
  [130835] = 6,
    ACTIONS(6605), 1,
      anon_sym_AMP,
    ACTIONS(6607), 1,
      anon_sym_PIPE,
    ACTIONS(6609), 1,
      anon_sym_extends,
    ACTIONS(6829), 1,
      anon_sym_EQ,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6750), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      anon_sym_EQ_GT,
  [130859] = 10,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(6718), 1,
      anon_sym_LBRACE,
    ACTIONS(6831), 1,
      anon_sym_extends,
    ACTIONS(6833), 1,
      anon_sym_implements,
    STATE(2173), 1,
      sym_class_body,
    STATE(3555), 1,
      sym_type_parameters,
    STATE(5080), 1,
      sym_extends_clause,
    STATE(5300), 1,
      sym_class_heritage,
    STATE(5792), 1,
      sym_implements_clause,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [130891] = 8,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    ACTIONS(6835), 1,
      anon_sym_BANG,
    ACTIONS(6837), 1,
      anon_sym_QMARK,
    STATE(4098), 1,
      sym_type_annotation,
    STATE(4560), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6449), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [130919] = 8,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    ACTIONS(6839), 1,
      anon_sym_BANG,
    ACTIONS(6841), 1,
      anon_sym_QMARK,
    STATE(4138), 1,
      sym_type_annotation,
    STATE(4662), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6513), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [130947] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4318), 9,
      sym__automatic_semicolon,
      sym__function_signature_automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_extends,
  [130963] = 5,
    ACTIONS(6819), 1,
      anon_sym_AMP,
    ACTIONS(6821), 1,
      anon_sym_PIPE,
    ACTIONS(6823), 1,
      anon_sym_extends,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4334), 6,
      sym__automatic_semicolon,
      sym__function_signature_automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LBRACK,
  [130985] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(1726), 9,
      sym__automatic_semicolon,
      sym__function_signature_automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_extends,
  [131001] = 3,
    ACTIONS(6825), 1,
      anon_sym_LBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4214), 8,
      sym__automatic_semicolon,
      sym__function_signature_automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_extends,
  [131019] = 8,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    ACTIONS(6843), 1,
      anon_sym_BANG,
    ACTIONS(6845), 1,
      anon_sym_QMARK,
    STATE(4353), 1,
      sym_type_annotation,
    STATE(5085), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6489), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [131047] = 10,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(6831), 1,
      anon_sym_extends,
    ACTIONS(6833), 1,
      anon_sym_implements,
    ACTIONS(6847), 1,
      anon_sym_LBRACE,
    STATE(209), 1,
      sym_class_body,
    STATE(3675), 1,
      sym_type_parameters,
    STATE(5080), 1,
      sym_extends_clause,
    STATE(5299), 1,
      sym_class_heritage,
    STATE(5792), 1,
      sym_implements_clause,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [131079] = 8,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    ACTIONS(6849), 1,
      anon_sym_BANG,
    ACTIONS(6851), 1,
      anon_sym_QMARK,
    STATE(3958), 1,
      sym_type_annotation,
    STATE(4534), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6489), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [131107] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3425), 9,
      sym__automatic_semicolon,
      sym__function_signature_automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_extends,
  [131123] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(1754), 9,
      sym__automatic_semicolon,
      sym__function_signature_automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_extends,
  [131139] = 7,
    ACTIONS(237), 1,
      anon_sym_COMMA,
    ACTIONS(667), 1,
      anon_sym_RBRACE,
    ACTIONS(4622), 1,
      anon_sym_EQ,
    STATE(4792), 1,
      aux_sym_object_repeat1,
    STATE(4815), 1,
      aux_sym_object_pattern_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3814), 4,
      anon_sym_LPAREN,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_QMARK,
  [131165] = 5,
    ACTIONS(6819), 1,
      anon_sym_AMP,
    ACTIONS(6821), 1,
      anon_sym_PIPE,
    ACTIONS(6823), 1,
      anon_sym_extends,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4444), 6,
      sym__automatic_semicolon,
      sym__function_signature_automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LBRACK,
  [131187] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4404), 9,
      sym__automatic_semicolon,
      sym__function_signature_automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_extends,
  [131203] = 5,
    ACTIONS(6819), 1,
      anon_sym_AMP,
    ACTIONS(6821), 1,
      anon_sym_PIPE,
    ACTIONS(6823), 1,
      anon_sym_extends,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4404), 6,
      sym__automatic_semicolon,
      sym__function_signature_automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LBRACK,
  [131225] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3419), 9,
      sym__automatic_semicolon,
      sym__function_signature_automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_extends,
  [131241] = 7,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    STATE(4333), 1,
      sym_type_annotation,
    STATE(5053), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6555), 2,
      anon_sym_BANG,
      anon_sym_QMARK,
    ACTIONS(6553), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [131267] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3429), 9,
      sym__automatic_semicolon,
      sym__function_signature_automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_extends,
  [131283] = 7,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    STATE(4234), 1,
      sym_type_annotation,
    STATE(4855), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6461), 2,
      anon_sym_BANG,
      anon_sym_QMARK,
    ACTIONS(6459), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [131309] = 4,
    ACTIONS(6809), 1,
      anon_sym_COLON,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    STATE(3921), 3,
      sym_type_annotation,
      sym_asserts_annotation,
      sym_type_predicate_annotation,
    ACTIONS(6752), 5,
      sym__automatic_semicolon,
      sym__function_signature_automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [131329] = 10,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(6718), 1,
      anon_sym_LBRACE,
    ACTIONS(6831), 1,
      anon_sym_extends,
    ACTIONS(6833), 1,
      anon_sym_implements,
    STATE(2284), 1,
      sym_class_body,
    STATE(3610), 1,
      sym_type_parameters,
    STATE(5080), 1,
      sym_extends_clause,
    STATE(5452), 1,
      sym_class_heritage,
    STATE(5792), 1,
      sym_implements_clause,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [131361] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4176), 9,
      sym__automatic_semicolon,
      sym__function_signature_automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_extends,
  [131377] = 7,
    ACTIONS(237), 1,
      anon_sym_COMMA,
    ACTIONS(4622), 1,
      anon_sym_EQ,
    ACTIONS(5051), 1,
      anon_sym_RBRACE,
    STATE(4792), 1,
      aux_sym_object_repeat1,
    STATE(4815), 1,
      aux_sym_object_pattern_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3814), 4,
      anon_sym_LPAREN,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_QMARK,
  [131403] = 10,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(6831), 1,
      anon_sym_extends,
    ACTIONS(6833), 1,
      anon_sym_implements,
    ACTIONS(6853), 1,
      anon_sym_LBRACE,
    STATE(788), 1,
      sym_class_body,
    STATE(3744), 1,
      sym_type_parameters,
    STATE(5080), 1,
      sym_extends_clause,
    STATE(5408), 1,
      sym_class_heritage,
    STATE(5792), 1,
      sym_implements_clause,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [131435] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6855), 9,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_in,
      anon_sym_of,
      anon_sym_COLON,
      anon_sym_RBRACK,
      anon_sym_QMARK,
  [131451] = 7,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    STATE(4056), 1,
      sym_type_annotation,
    STATE(4991), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6859), 2,
      anon_sym_BANG,
      anon_sym_QMARK,
    ACTIONS(6857), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [131477] = 7,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    STATE(4313), 1,
      sym_type_annotation,
    STATE(5036), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6521), 2,
      anon_sym_BANG,
      anon_sym_QMARK,
    ACTIONS(6519), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [131503] = 8,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    ACTIONS(6861), 1,
      anon_sym_BANG,
    ACTIONS(6863), 1,
      anon_sym_QMARK,
    STATE(3963), 1,
      sym_type_annotation,
    STATE(4570), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6489), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [131531] = 7,
    ACTIONS(237), 1,
      anon_sym_COMMA,
    ACTIONS(4622), 1,
      anon_sym_EQ,
    ACTIONS(5053), 1,
      anon_sym_RBRACE,
    STATE(4792), 1,
      aux_sym_object_repeat1,
    STATE(4815), 1,
      aux_sym_object_pattern_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3814), 4,
      anon_sym_LPAREN,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_QMARK,
  [131557] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6865), 9,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_in,
      anon_sym_of,
      anon_sym_COLON,
      anon_sym_RBRACK,
      anon_sym_QMARK,
  [131573] = 3,
    ACTIONS(3417), 1,
      anon_sym_LBRACE,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3419), 8,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_extends,
      anon_sym_LBRACE_PIPE,
  [131591] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4432), 9,
      sym__automatic_semicolon,
      sym__function_signature_automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_extends,
  [131607] = 7,
    ACTIONS(237), 1,
      anon_sym_COMMA,
    ACTIONS(692), 1,
      anon_sym_RBRACE,
    ACTIONS(4622), 1,
      anon_sym_EQ,
    STATE(4810), 1,
      aux_sym_object_repeat1,
    STATE(4815), 1,
      aux_sym_object_pattern_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3814), 4,
      anon_sym_LPAREN,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_QMARK,
  [131633] = 3,
    ACTIONS(6819), 1,
      anon_sym_AMP,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4440), 8,
      sym__automatic_semicolon,
      sym__function_signature_automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_PIPE,
      anon_sym_extends,
  [131651] = 8,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    ACTIONS(6867), 1,
      anon_sym_BANG,
    ACTIONS(6869), 1,
      anon_sym_QMARK,
    STATE(3966), 1,
      sym_type_annotation,
    STATE(4581), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6489), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [131679] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6871), 9,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_in,
      anon_sym_of,
      anon_sym_COLON,
      anon_sym_RBRACK,
      anon_sym_QMARK,
  [131695] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4448), 9,
      sym__automatic_semicolon,
      sym__function_signature_automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_extends,
  [131711] = 8,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    ACTIONS(6873), 1,
      anon_sym_BANG,
    ACTIONS(6875), 1,
      anon_sym_QMARK,
    STATE(4077), 1,
      sym_type_annotation,
    STATE(5123), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6513), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [131739] = 9,
    ACTIONS(3109), 1,
      anon_sym_DQUOTE,
    ACTIONS(3111), 1,
      anon_sym_SQUOTE,
    ACTIONS(6704), 1,
      sym_identifier,
    ACTIONS(6706), 1,
      anon_sym_type,
    ACTIONS(6712), 1,
      anon_sym_typeof,
    STATE(5314), 1,
      sym_import_specifier,
    STATE(5384), 1,
      sym__import_identifier,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    STATE(5604), 2,
      sym__module_export_name,
      sym_string,
  [131769] = 10,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(6718), 1,
      anon_sym_LBRACE,
    ACTIONS(6831), 1,
      anon_sym_extends,
    ACTIONS(6833), 1,
      anon_sym_implements,
    STATE(2320), 1,
      sym_class_body,
    STATE(3709), 1,
      sym_type_parameters,
    STATE(5080), 1,
      sym_extends_clause,
    STATE(5268), 1,
      sym_class_heritage,
    STATE(5792), 1,
      sym_implements_clause,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [131801] = 3,
    ACTIONS(3423), 1,
      anon_sym_LBRACE,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3425), 8,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_extends,
      anon_sym_LBRACE_PIPE,
  [131819] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4232), 9,
      sym__automatic_semicolon,
      sym__function_signature_automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_extends,
  [131835] = 5,
    ACTIONS(6819), 1,
      anon_sym_AMP,
    ACTIONS(6821), 1,
      anon_sym_PIPE,
    ACTIONS(6823), 1,
      anon_sym_extends,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4436), 6,
      sym__automatic_semicolon,
      sym__function_signature_automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LBRACK,
  [131857] = 7,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    ACTIONS(6772), 1,
      anon_sym_EQ,
    STATE(4216), 1,
      sym__initializer,
    STATE(4338), 1,
      sym_type_annotation,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6778), 2,
      anon_sym_in,
      anon_sym_of,
    ACTIONS(6774), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [131883] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(2365), 9,
      sym__automatic_semicolon,
      sym__function_signature_automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_extends,
  [131899] = 8,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    ACTIONS(6780), 1,
      sym__automatic_semicolon,
    STATE(4338), 1,
      sym_type_annotation,
    STATE(4561), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6774), 2,
      anon_sym_COMMA,
      anon_sym_SEMI,
    ACTIONS(6778), 2,
      anon_sym_in,
      anon_sym_of,
  [131927] = 5,
    ACTIONS(6357), 1,
      anon_sym_DOT,
    ACTIONS(6680), 1,
      anon_sym_LPAREN,
    STATE(2934), 1,
      sym_arguments,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4080), 6,
      anon_sym_as,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_extends,
  [131949] = 10,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(6718), 1,
      anon_sym_LBRACE,
    ACTIONS(6831), 1,
      anon_sym_extends,
    ACTIONS(6833), 1,
      anon_sym_implements,
    STATE(2184), 1,
      sym_class_body,
    STATE(3616), 1,
      sym_type_parameters,
    STATE(5080), 1,
      sym_extends_clause,
    STATE(5409), 1,
      sym_class_heritage,
    STATE(5792), 1,
      sym_implements_clause,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [131981] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(2377), 9,
      sym__automatic_semicolon,
      sym__function_signature_automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_extends,
  [131997] = 8,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    ACTIONS(6877), 1,
      anon_sym_BANG,
    ACTIONS(6879), 1,
      anon_sym_QMARK,
    STATE(4360), 1,
      sym_type_annotation,
    STATE(5092), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6489), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [132025] = 8,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    ACTIONS(6881), 1,
      anon_sym_BANG,
    ACTIONS(6883), 1,
      anon_sym_QMARK,
    STATE(3969), 1,
      sym_type_annotation,
    STATE(4603), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6489), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [132053] = 8,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    ACTIONS(6885), 1,
      anon_sym_BANG,
    ACTIONS(6887), 1,
      anon_sym_QMARK,
    STATE(4362), 1,
      sym_type_annotation,
    STATE(5095), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6489), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [132081] = 8,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    ACTIONS(6889), 1,
      anon_sym_BANG,
    ACTIONS(6891), 1,
      anon_sym_QMARK,
    STATE(3973), 1,
      sym_type_annotation,
    STATE(4618), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6489), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [132109] = 10,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(6718), 1,
      anon_sym_LBRACE,
    ACTIONS(6831), 1,
      anon_sym_extends,
    ACTIONS(6833), 1,
      anon_sym_implements,
    STATE(2254), 1,
      sym_class_body,
    STATE(3689), 1,
      sym_type_parameters,
    STATE(5080), 1,
      sym_extends_clause,
    STATE(5227), 1,
      sym_class_heritage,
    STATE(5792), 1,
      sym_implements_clause,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [132141] = 10,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(6732), 1,
      anon_sym_LBRACE,
    ACTIONS(6831), 1,
      anon_sym_extends,
    ACTIONS(6833), 1,
      anon_sym_implements,
    STATE(2574), 1,
      sym_class_body,
    STATE(3513), 1,
      sym_type_parameters,
    STATE(5080), 1,
      sym_extends_clause,
    STATE(5153), 1,
      sym_class_heritage,
    STATE(5792), 1,
      sym_implements_clause,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [132173] = 8,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    ACTIONS(6893), 1,
      anon_sym_BANG,
    ACTIONS(6895), 1,
      anon_sym_QMARK,
    STATE(4095), 1,
      sym_type_annotation,
    STATE(4551), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6513), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [132201] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4378), 9,
      sym__automatic_semicolon,
      sym__function_signature_automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_extends,
  [132217] = 7,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    STATE(4235), 1,
      sym_type_annotation,
    STATE(4951), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6561), 2,
      anon_sym_BANG,
      anon_sym_QMARK,
    ACTIONS(6559), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [132243] = 8,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    ACTIONS(6899), 1,
      anon_sym_BANG,
    ACTIONS(6901), 1,
      anon_sym_QMARK,
    STATE(4205), 1,
      sym_type_annotation,
    STATE(4775), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6897), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [132271] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4326), 9,
      sym__automatic_semicolon,
      sym__function_signature_automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_extends,
  [132287] = 8,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    ACTIONS(6903), 1,
      anon_sym_BANG,
    ACTIONS(6905), 1,
      anon_sym_QMARK,
    STATE(3978), 1,
      sym_type_annotation,
    STATE(4657), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6489), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [132315] = 8,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    ACTIONS(6907), 1,
      anon_sym_BANG,
    ACTIONS(6909), 1,
      anon_sym_QMARK,
    STATE(3990), 1,
      sym_type_annotation,
    STATE(4701), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6489), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [132343] = 10,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(6831), 1,
      anon_sym_extends,
    ACTIONS(6833), 1,
      anon_sym_implements,
    ACTIONS(6853), 1,
      anon_sym_LBRACE,
    STATE(3717), 1,
      sym_type_parameters,
    STATE(3931), 1,
      sym_class_body,
    STATE(5080), 1,
      sym_extends_clause,
    STATE(5231), 1,
      sym_class_heritage,
    STATE(5792), 1,
      sym_implements_clause,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [132375] = 8,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    ACTIONS(6911), 1,
      anon_sym_BANG,
    ACTIONS(6913), 1,
      anon_sym_QMARK,
    STATE(4142), 1,
      sym_type_annotation,
    STATE(4673), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6513), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [132403] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4302), 9,
      sym__automatic_semicolon,
      sym__function_signature_automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_extends,
  [132419] = 10,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(6732), 1,
      anon_sym_LBRACE,
    ACTIONS(6831), 1,
      anon_sym_extends,
    ACTIONS(6833), 1,
      anon_sym_implements,
    STATE(1676), 1,
      sym_class_body,
    STATE(3720), 1,
      sym_type_parameters,
    STATE(5080), 1,
      sym_extends_clause,
    STATE(5145), 1,
      sym_class_heritage,
    STATE(5792), 1,
      sym_implements_clause,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [132451] = 8,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    ACTIONS(6915), 1,
      anon_sym_BANG,
    ACTIONS(6917), 1,
      anon_sym_QMARK,
    STATE(4144), 1,
      sym_type_annotation,
    STATE(4675), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6513), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [132479] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6919), 9,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_in,
      anon_sym_of,
      anon_sym_COLON,
      anon_sym_RBRACK,
      anon_sym_QMARK,
  [132495] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6921), 9,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_in,
      anon_sym_of,
      anon_sym_COLON,
      anon_sym_RBRACK,
      anon_sym_QMARK,
  [132511] = 10,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(6831), 1,
      anon_sym_extends,
    ACTIONS(6833), 1,
      anon_sym_implements,
    ACTIONS(6847), 1,
      anon_sym_LBRACE,
    STATE(230), 1,
      sym_class_body,
    STATE(3581), 1,
      sym_type_parameters,
    STATE(5080), 1,
      sym_extends_clause,
    STATE(5397), 1,
      sym_class_heritage,
    STATE(5792), 1,
      sym_implements_clause,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [132543] = 5,
    ACTIONS(6343), 1,
      anon_sym_DOT,
    ACTIONS(6682), 1,
      anon_sym_LT,
    STATE(2964), 1,
      sym_type_arguments,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3548), 6,
      anon_sym_as,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_extends,
  [132565] = 10,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(6831), 1,
      anon_sym_extends,
    ACTIONS(6833), 1,
      anon_sym_implements,
    ACTIONS(6923), 1,
      anon_sym_LBRACE,
    STATE(812), 1,
      sym_class_body,
    STATE(3619), 1,
      sym_type_parameters,
    STATE(5080), 1,
      sym_extends_clause,
    STATE(5255), 1,
      sym_class_heritage,
    STATE(5792), 1,
      sym_implements_clause,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [132597] = 8,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    ACTIONS(6925), 1,
      anon_sym_BANG,
    ACTIONS(6927), 1,
      anon_sym_QMARK,
    STATE(4152), 1,
      sym_type_annotation,
    STATE(4689), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6513), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [132625] = 8,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    ACTIONS(6929), 1,
      anon_sym_BANG,
    ACTIONS(6931), 1,
      anon_sym_QMARK,
    STATE(4367), 1,
      sym_type_annotation,
    STATE(5103), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6489), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [132653] = 10,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(6831), 1,
      anon_sym_extends,
    ACTIONS(6833), 1,
      anon_sym_implements,
    ACTIONS(6923), 1,
      anon_sym_LBRACE,
    STATE(912), 1,
      sym_class_body,
    STATE(3621), 1,
      sym_type_parameters,
    STATE(5080), 1,
      sym_extends_clause,
    STATE(5304), 1,
      sym_class_heritage,
    STATE(5792), 1,
      sym_implements_clause,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [132685] = 7,
    ACTIONS(237), 1,
      anon_sym_COMMA,
    ACTIONS(4622), 1,
      anon_sym_EQ,
    ACTIONS(4992), 1,
      anon_sym_RBRACE,
    STATE(4792), 1,
      aux_sym_object_repeat1,
    STATE(4815), 1,
      aux_sym_object_pattern_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3814), 4,
      anon_sym_LPAREN,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_QMARK,
  [132711] = 8,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    ACTIONS(6933), 1,
      anon_sym_BANG,
    ACTIONS(6935), 1,
      anon_sym_QMARK,
    STATE(4366), 1,
      sym_type_annotation,
    STATE(5104), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6527), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [132739] = 8,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    ACTIONS(6937), 1,
      anon_sym_BANG,
    ACTIONS(6939), 1,
      anon_sym_QMARK,
    STATE(4236), 1,
      sym_type_annotation,
    STATE(4851), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6897), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [132767] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4344), 9,
      sym__automatic_semicolon,
      sym__function_signature_automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_extends,
  [132783] = 10,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(6831), 1,
      anon_sym_extends,
    ACTIONS(6833), 1,
      anon_sym_implements,
    ACTIONS(6853), 1,
      anon_sym_LBRACE,
    STATE(3594), 1,
      sym_type_parameters,
    STATE(4043), 1,
      sym_class_body,
    STATE(5080), 1,
      sym_extends_clause,
    STATE(5341), 1,
      sym_class_heritage,
    STATE(5792), 1,
      sym_implements_clause,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [132815] = 8,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    ACTIONS(6941), 1,
      anon_sym_BANG,
    ACTIONS(6943), 1,
      anon_sym_QMARK,
    STATE(4372), 1,
      sym_type_annotation,
    STATE(5113), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6527), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [132843] = 8,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    ACTIONS(6945), 1,
      anon_sym_BANG,
    ACTIONS(6947), 1,
      anon_sym_QMARK,
    STATE(4099), 1,
      sym_type_annotation,
    STATE(4562), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6513), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [132871] = 10,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(6831), 1,
      anon_sym_extends,
    ACTIONS(6833), 1,
      anon_sym_implements,
    ACTIONS(6853), 1,
      anon_sym_LBRACE,
    STATE(3645), 1,
      sym_type_parameters,
    STATE(3979), 1,
      sym_class_body,
    STATE(5080), 1,
      sym_extends_clause,
    STATE(5144), 1,
      sym_class_heritage,
    STATE(5792), 1,
      sym_implements_clause,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [132903] = 8,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    ACTIONS(6949), 1,
      anon_sym_BANG,
    ACTIONS(6951), 1,
      anon_sym_QMARK,
    STATE(4377), 1,
      sym_type_annotation,
    STATE(5120), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6527), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [132931] = 8,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    ACTIONS(6953), 1,
      anon_sym_BANG,
    ACTIONS(6955), 1,
      anon_sym_QMARK,
    STATE(4101), 1,
      sym_type_annotation,
    STATE(4567), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6513), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [132959] = 7,
    ACTIONS(237), 1,
      anon_sym_COMMA,
    ACTIONS(694), 1,
      anon_sym_RBRACE,
    ACTIONS(4622), 1,
      anon_sym_EQ,
    STATE(4792), 1,
      aux_sym_object_repeat1,
    STATE(4815), 1,
      aux_sym_object_pattern_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3814), 4,
      anon_sym_LPAREN,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_QMARK,
  [132985] = 8,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    ACTIONS(6957), 1,
      anon_sym_BANG,
    ACTIONS(6959), 1,
      anon_sym_QMARK,
    STATE(4105), 1,
      sym_type_annotation,
    STATE(4575), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6513), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [133013] = 8,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    ACTIONS(6961), 1,
      anon_sym_BANG,
    ACTIONS(6963), 1,
      anon_sym_QMARK,
    STATE(4117), 1,
      sym_type_annotation,
    STATE(4598), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6513), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [133041] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4188), 9,
      sym__automatic_semicolon,
      sym__function_signature_automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_extends,
  [133057] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4370), 9,
      sym__automatic_semicolon,
      sym__function_signature_automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_extends,
  [133073] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4198), 9,
      sym__automatic_semicolon,
      sym__function_signature_automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_extends,
  [133089] = 5,
    ACTIONS(6819), 1,
      anon_sym_AMP,
    ACTIONS(6821), 1,
      anon_sym_PIPE,
    ACTIONS(6823), 1,
      anon_sym_extends,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4204), 6,
      sym__automatic_semicolon,
      sym__function_signature_automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LBRACK,
  [133111] = 10,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(6718), 1,
      anon_sym_LBRACE,
    ACTIONS(6831), 1,
      anon_sym_extends,
    ACTIONS(6833), 1,
      anon_sym_implements,
    STATE(2345), 1,
      sym_class_body,
    STATE(3545), 1,
      sym_type_parameters,
    STATE(5080), 1,
      sym_extends_clause,
    STATE(5175), 1,
      sym_class_heritage,
    STATE(5792), 1,
      sym_implements_clause,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [133143] = 10,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(6831), 1,
      anon_sym_extends,
    ACTIONS(6833), 1,
      anon_sym_implements,
    ACTIONS(6853), 1,
      anon_sym_LBRACE,
    STATE(3558), 1,
      sym_type_parameters,
    STATE(4002), 1,
      sym_class_body,
    STATE(5080), 1,
      sym_extends_clause,
    STATE(5204), 1,
      sym_class_heritage,
    STATE(5792), 1,
      sym_implements_clause,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [133175] = 3,
    ACTIONS(6819), 1,
      anon_sym_AMP,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4306), 8,
      sym__automatic_semicolon,
      sym__function_signature_automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_PIPE,
      anon_sym_extends,
  [133193] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4408), 9,
      sym__automatic_semicolon,
      sym__function_signature_automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_extends,
  [133209] = 10,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(6732), 1,
      anon_sym_LBRACE,
    ACTIONS(6831), 1,
      anon_sym_extends,
    ACTIONS(6833), 1,
      anon_sym_implements,
    STATE(1694), 1,
      sym_class_body,
    STATE(3605), 1,
      sym_type_parameters,
    STATE(5080), 1,
      sym_extends_clause,
    STATE(5223), 1,
      sym_class_heritage,
    STATE(5792), 1,
      sym_implements_clause,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [133241] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4106), 9,
      sym__automatic_semicolon,
      sym__function_signature_automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_extends,
  [133257] = 8,
    ACTIONS(3109), 1,
      anon_sym_DQUOTE,
    ACTIONS(3111), 1,
      anon_sym_SQUOTE,
    ACTIONS(6736), 1,
      sym_identifier,
    ACTIONS(6965), 1,
      anon_sym_RBRACE,
    STATE(5379), 1,
      sym_export_specifier,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6738), 2,
      anon_sym_type,
      anon_sym_typeof,
    STATE(4735), 2,
      sym__module_export_name,
      sym_string,
  [133285] = 10,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(6831), 1,
      anon_sym_extends,
    ACTIONS(6833), 1,
      anon_sym_implements,
    ACTIONS(6853), 1,
      anon_sym_LBRACE,
    STATE(794), 1,
      sym_class_body,
    STATE(3590), 1,
      sym_type_parameters,
    STATE(5080), 1,
      sym_extends_clause,
    STATE(5219), 1,
      sym_class_heritage,
    STATE(5792), 1,
      sym_implements_clause,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [133317] = 8,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    ACTIONS(6967), 1,
      anon_sym_BANG,
    ACTIONS(6969), 1,
      anon_sym_QMARK,
    STATE(4331), 1,
      sym_type_annotation,
    STATE(5048), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6449), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [133345] = 3,
    ACTIONS(3427), 1,
      anon_sym_LBRACE,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3429), 8,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_extends,
      anon_sym_LBRACE_PIPE,
  [133363] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4218), 9,
      sym__automatic_semicolon,
      sym__function_signature_automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_extends,
  [133379] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4222), 9,
      sym__automatic_semicolon,
      sym__function_signature_automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_extends,
  [133395] = 8,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    ACTIONS(6971), 1,
      anon_sym_BANG,
    ACTIONS(6973), 1,
      anon_sym_QMARK,
    STATE(4352), 1,
      sym_type_annotation,
    STATE(5082), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6449), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [133423] = 5,
    ACTIONS(6819), 1,
      anon_sym_AMP,
    ACTIONS(6821), 1,
      anon_sym_PIPE,
    ACTIONS(6823), 1,
      anon_sym_extends,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4222), 6,
      sym__automatic_semicolon,
      sym__function_signature_automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LBRACK,
  [133445] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4172), 9,
      sym__automatic_semicolon,
      sym__function_signature_automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_extends,
  [133461] = 8,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    ACTIONS(6975), 1,
      anon_sym_BANG,
    ACTIONS(6977), 1,
      anon_sym_QMARK,
    STATE(4365), 1,
      sym_type_annotation,
    STATE(5094), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6449), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [133489] = 3,
    ACTIONS(6825), 1,
      anon_sym_LBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4172), 8,
      sym__automatic_semicolon,
      sym__function_signature_automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_extends,
  [133507] = 8,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    ACTIONS(6979), 1,
      anon_sym_BANG,
    ACTIONS(6981), 1,
      anon_sym_QMARK,
    STATE(3905), 1,
      sym_type_annotation,
    STATE(4674), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6449), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [133535] = 8,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    ACTIONS(6983), 1,
      anon_sym_BANG,
    ACTIONS(6985), 1,
      anon_sym_QMARK,
    STATE(3907), 1,
      sym_type_annotation,
    STATE(4604), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6449), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [133563] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4110), 9,
      sym__automatic_semicolon,
      sym__function_signature_automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_extends,
  [133579] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4142), 9,
      sym__automatic_semicolon,
      sym__function_signature_automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_extends,
  [133595] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4182), 9,
      sym__automatic_semicolon,
      sym__function_signature_automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_extends,
  [133611] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(2369), 9,
      sym__automatic_semicolon,
      sym__function_signature_automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_extends,
  [133627] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4352), 9,
      sym__automatic_semicolon,
      sym__function_signature_automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_extends,
  [133643] = 8,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    ACTIONS(6987), 1,
      anon_sym_BANG,
    ACTIONS(6989), 1,
      anon_sym_QMARK,
    STATE(3957), 1,
      sym_type_annotation,
    STATE(4525), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6449), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [133671] = 8,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    ACTIONS(6991), 1,
      anon_sym_BANG,
    ACTIONS(6993), 1,
      anon_sym_QMARK,
    STATE(3904), 1,
      sym_type_annotation,
    STATE(4728), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6489), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [133699] = 8,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    ACTIONS(6995), 1,
      anon_sym_BANG,
    ACTIONS(6997), 1,
      anon_sym_QMARK,
    STATE(4114), 1,
      sym_type_annotation,
    STATE(4593), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6449), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [133727] = 8,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    ACTIONS(6999), 1,
      anon_sym_BANG,
    ACTIONS(7001), 1,
      anon_sym_QMARK,
    STATE(3965), 1,
      sym_type_annotation,
    STATE(4573), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6449), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [133755] = 8,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    ACTIONS(7003), 1,
      anon_sym_BANG,
    ACTIONS(7005), 1,
      anon_sym_QMARK,
    STATE(3967), 1,
      sym_type_annotation,
    STATE(4579), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6449), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [133783] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4156), 9,
      sym__automatic_semicolon,
      sym__function_signature_automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_extends,
  [133799] = 5,
    ACTIONS(6698), 1,
      anon_sym_AMP,
    ACTIONS(6700), 1,
      anon_sym_PIPE,
    ACTIONS(6702), 1,
      anon_sym_extends,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7007), 5,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACE,
  [133820] = 6,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    ACTIONS(7009), 1,
      anon_sym_DASH_QMARK_COLON,
    ACTIONS(7011), 1,
      anon_sym_PLUS_QMARK_COLON,
    ACTIONS(7013), 1,
      anon_sym_QMARK_COLON,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    STATE(4316), 4,
      sym_omitting_type_annotation,
      sym_adding_type_annotation,
      sym_opting_type_annotation,
      sym_type_annotation,
  [133843] = 5,
    ACTIONS(6698), 1,
      anon_sym_AMP,
    ACTIONS(6700), 1,
      anon_sym_PIPE,
    ACTIONS(6702), 1,
      anon_sym_extends,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7015), 5,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACE,
  [133864] = 5,
    ACTIONS(6698), 1,
      anon_sym_AMP,
    ACTIONS(6700), 1,
      anon_sym_PIPE,
    ACTIONS(6702), 1,
      anon_sym_extends,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7017), 5,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACE,
  [133885] = 6,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    ACTIONS(7009), 1,
      anon_sym_DASH_QMARK_COLON,
    ACTIONS(7011), 1,
      anon_sym_PLUS_QMARK_COLON,
    ACTIONS(7013), 1,
      anon_sym_QMARK_COLON,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    STATE(4318), 4,
      sym_omitting_type_annotation,
      sym_adding_type_annotation,
      sym_opting_type_annotation,
      sym_type_annotation,
  [133908] = 7,
    ACTIONS(3405), 1,
      sym_identifier,
    ACTIONS(3407), 1,
      anon_sym_LBRACE,
    ACTIONS(3409), 1,
      anon_sym_LBRACK,
    ACTIONS(7019), 1,
      anon_sym_enum,
    STATE(4416), 1,
      sym_variable_declarator,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    STATE(3718), 3,
      sym_object_pattern,
      sym_array_pattern,
      sym__destructuring_pattern,
  [133933] = 6,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    ACTIONS(7009), 1,
      anon_sym_DASH_QMARK_COLON,
    ACTIONS(7011), 1,
      anon_sym_PLUS_QMARK_COLON,
    ACTIONS(7013), 1,
      anon_sym_QMARK_COLON,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    STATE(4307), 4,
      sym_omitting_type_annotation,
      sym_adding_type_annotation,
      sym_opting_type_annotation,
      sym_type_annotation,
  [133956] = 4,
    ACTIONS(4588), 1,
      anon_sym_LPAREN,
    STATE(2220), 1,
      sym_arguments,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4326), 6,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_extends,
  [133975] = 9,
    ACTIONS(1538), 1,
      anon_sym_import,
    ACTIONS(7021), 1,
      sym_identifier,
    ACTIONS(7023), 1,
      sym_this,
    STATE(2951), 1,
      sym__type_query_subscript_expression,
    STATE(3037), 1,
      sym__type_query_member_expression,
    STATE(3221), 1,
      sym__type_query_call_expression,
    STATE(3383), 1,
      sym__type_query_instantiation_expression,
    STATE(4468), 1,
      sym_import,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [134004] = 7,
    ACTIONS(7025), 1,
      sym_escape_sequence,
    ACTIONS(7027), 1,
      anon_sym_BQUOTE,
    ACTIONS(7029), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(7031), 1,
      sym__template_chars,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    STATE(3785), 2,
      sym_template_substitution,
      aux_sym_template_string_repeat1,
    STATE(4108), 2,
      sym_template_type,
      aux_sym_template_literal_type_repeat1,
  [134029] = 9,
    ACTIONS(1538), 1,
      anon_sym_import,
    ACTIONS(7033), 1,
      sym_identifier,
    ACTIONS(7035), 1,
      sym_this,
    STATE(2931), 1,
      sym__type_query_member_expression,
    STATE(2933), 1,
      sym__type_query_subscript_expression,
    STATE(3124), 1,
      sym__type_query_call_expression,
    STATE(3280), 1,
      sym__type_query_instantiation_expression,
    STATE(4502), 1,
      sym_import,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [134058] = 7,
    ACTIONS(7025), 1,
      sym_escape_sequence,
    ACTIONS(7029), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(7031), 1,
      sym__template_chars,
    ACTIONS(7037), 1,
      anon_sym_BQUOTE,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    STATE(3785), 2,
      sym_template_substitution,
      aux_sym_template_string_repeat1,
    STATE(4108), 2,
      sym_template_type,
      aux_sym_template_literal_type_repeat1,
  [134083] = 7,
    ACTIONS(7025), 1,
      sym_escape_sequence,
    ACTIONS(7029), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(7031), 1,
      sym__template_chars,
    ACTIONS(7039), 1,
      anon_sym_BQUOTE,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    STATE(3785), 2,
      sym_template_substitution,
      aux_sym_template_string_repeat1,
    STATE(4108), 2,
      sym_template_type,
      aux_sym_template_literal_type_repeat1,
  [134108] = 7,
    ACTIONS(7025), 1,
      sym_escape_sequence,
    ACTIONS(7029), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(7031), 1,
      sym__template_chars,
    ACTIONS(7041), 1,
      anon_sym_BQUOTE,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    STATE(3785), 2,
      sym_template_substitution,
      aux_sym_template_string_repeat1,
    STATE(4108), 2,
      sym_template_type,
      aux_sym_template_literal_type_repeat1,
  [134133] = 7,
    ACTIONS(7029), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(7031), 1,
      sym__template_chars,
    ACTIONS(7043), 1,
      sym_escape_sequence,
    ACTIONS(7045), 1,
      anon_sym_BQUOTE,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    STATE(3764), 2,
      sym_template_substitution,
      aux_sym_template_string_repeat1,
    STATE(4108), 2,
      sym_template_type,
      aux_sym_template_literal_type_repeat1,
  [134158] = 7,
    ACTIONS(7025), 1,
      sym_escape_sequence,
    ACTIONS(7029), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(7031), 1,
      sym__template_chars,
    ACTIONS(7047), 1,
      anon_sym_BQUOTE,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    STATE(3785), 2,
      sym_template_substitution,
      aux_sym_template_string_repeat1,
    STATE(4057), 2,
      sym_template_type,
      aux_sym_template_literal_type_repeat1,
  [134183] = 7,
    ACTIONS(3405), 1,
      sym_identifier,
    ACTIONS(3407), 1,
      anon_sym_LBRACE,
    ACTIONS(3409), 1,
      anon_sym_LBRACK,
    ACTIONS(7049), 1,
      anon_sym_enum,
    STATE(4451), 1,
      sym_variable_declarator,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    STATE(3718), 3,
      sym_object_pattern,
      sym_array_pattern,
      sym__destructuring_pattern,
  [134208] = 9,
    ACTIONS(1538), 1,
      anon_sym_import,
    ACTIONS(7051), 1,
      sym_identifier,
    ACTIONS(7053), 1,
      sym_this,
    STATE(2876), 1,
      sym__type_query_member_expression,
    STATE(2877), 1,
      sym__type_query_subscript_expression,
    STATE(2922), 1,
      sym__type_query_call_expression,
    STATE(3010), 1,
      sym__type_query_instantiation_expression,
    STATE(4382), 1,
      sym_import,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [134237] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(1726), 8,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_extends,
  [134252] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(1754), 8,
      anon_sym_as,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_extends,
  [134267] = 7,
    ACTIONS(7025), 1,
      sym_escape_sequence,
    ACTIONS(7029), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(7031), 1,
      sym__template_chars,
    ACTIONS(7055), 1,
      anon_sym_BQUOTE,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    STATE(3785), 2,
      sym_template_substitution,
      aux_sym_template_string_repeat1,
    STATE(4108), 2,
      sym_template_type,
      aux_sym_template_literal_type_repeat1,
  [134292] = 6,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    ACTIONS(7009), 1,
      anon_sym_DASH_QMARK_COLON,
    ACTIONS(7011), 1,
      anon_sym_PLUS_QMARK_COLON,
    ACTIONS(7013), 1,
      anon_sym_QMARK_COLON,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    STATE(4051), 4,
      sym_omitting_type_annotation,
      sym_adding_type_annotation,
      sym_opting_type_annotation,
      sym_type_annotation,
  [134315] = 9,
    ACTIONS(1538), 1,
      anon_sym_import,
    ACTIONS(7053), 1,
      sym_this,
    ACTIONS(7057), 1,
      sym_identifier,
    STATE(2922), 1,
      sym__type_query_call_expression,
    STATE(3010), 1,
      sym__type_query_instantiation_expression,
    STATE(3197), 1,
      sym__type_query_member_expression,
    STATE(3198), 1,
      sym__type_query_subscript_expression,
    STATE(4384), 1,
      sym_import,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [134344] = 4,
    ACTIONS(6682), 1,
      anon_sym_LT,
    STATE(3030), 1,
      sym_type_arguments,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4110), 6,
      anon_sym_as,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_extends,
  [134363] = 6,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    ACTIONS(7009), 1,
      anon_sym_DASH_QMARK_COLON,
    ACTIONS(7011), 1,
      anon_sym_PLUS_QMARK_COLON,
    ACTIONS(7013), 1,
      anon_sym_QMARK_COLON,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    STATE(4052), 4,
      sym_omitting_type_annotation,
      sym_adding_type_annotation,
      sym_opting_type_annotation,
      sym_type_annotation,
  [134386] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3235), 8,
      anon_sym_as,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_extends,
  [134401] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3239), 8,
      anon_sym_as,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_extends,
  [134416] = 7,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    ACTIONS(6776), 1,
      anon_sym_BANG,
    STATE(4338), 1,
      sym_type_annotation,
    STATE(5056), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6774), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [134441] = 7,
    ACTIONS(3109), 1,
      anon_sym_DQUOTE,
    ACTIONS(3111), 1,
      anon_sym_SQUOTE,
    ACTIONS(6736), 1,
      sym_identifier,
    STATE(5379), 1,
      sym_export_specifier,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6738), 2,
      anon_sym_type,
      anon_sym_typeof,
    STATE(4735), 2,
      sym__module_export_name,
      sym_string,
  [134466] = 3,
    ACTIONS(6714), 1,
      anon_sym_is,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4106), 7,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_QMARK,
      anon_sym_extends,
  [134483] = 3,
    ACTIONS(7059), 1,
      anon_sym_is,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4110), 7,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_QMARK,
      anon_sym_extends,
  [134500] = 6,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    ACTIONS(7009), 1,
      anon_sym_DASH_QMARK_COLON,
    ACTIONS(7011), 1,
      anon_sym_PLUS_QMARK_COLON,
    ACTIONS(7013), 1,
      anon_sym_QMARK_COLON,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    STATE(4281), 4,
      sym_omitting_type_annotation,
      sym_adding_type_annotation,
      sym_opting_type_annotation,
      sym_type_annotation,
  [134523] = 9,
    ACTIONS(1538), 1,
      anon_sym_import,
    ACTIONS(7061), 1,
      sym_identifier,
    ACTIONS(7063), 1,
      sym_this,
    STATE(1735), 1,
      sym__type_query_member_expression,
    STATE(1737), 1,
      sym__type_query_subscript_expression,
    STATE(1977), 1,
      sym__type_query_call_expression,
    STATE(1978), 1,
      sym__type_query_instantiation_expression,
    STATE(4500), 1,
      sym_import,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [134552] = 6,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    ACTIONS(7009), 1,
      anon_sym_DASH_QMARK_COLON,
    ACTIONS(7011), 1,
      anon_sym_PLUS_QMARK_COLON,
    ACTIONS(7013), 1,
      anon_sym_QMARK_COLON,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    STATE(4186), 4,
      sym_omitting_type_annotation,
      sym_adding_type_annotation,
      sym_opting_type_annotation,
      sym_type_annotation,
  [134575] = 6,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    ACTIONS(7009), 1,
      anon_sym_DASH_QMARK_COLON,
    ACTIONS(7011), 1,
      anon_sym_PLUS_QMARK_COLON,
    ACTIONS(7013), 1,
      anon_sym_QMARK_COLON,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    STATE(4187), 4,
      sym_omitting_type_annotation,
      sym_adding_type_annotation,
      sym_opting_type_annotation,
      sym_type_annotation,
  [134598] = 5,
    ACTIONS(7065), 1,
      anon_sym_LBRACE,
    ACTIONS(7067), 1,
      anon_sym_DOT,
    STATE(4280), 1,
      sym_statement_block,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(1674), 5,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACE,
  [134619] = 5,
    ACTIONS(7065), 1,
      anon_sym_LBRACE,
    ACTIONS(7069), 1,
      anon_sym_DOT,
    STATE(4280), 1,
      sym_statement_block,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(1674), 5,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACE,
  [134640] = 7,
    ACTIONS(7029), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(7031), 1,
      sym__template_chars,
    ACTIONS(7043), 1,
      sym_escape_sequence,
    ACTIONS(7071), 1,
      anon_sym_BQUOTE,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    STATE(3764), 2,
      sym_template_substitution,
      aux_sym_template_string_repeat1,
    STATE(4108), 2,
      sym_template_type,
      aux_sym_template_literal_type_repeat1,
  [134665] = 5,
    ACTIONS(6819), 1,
      anon_sym_AMP,
    ACTIONS(6821), 1,
      anon_sym_PIPE,
    ACTIONS(6823), 1,
      anon_sym_extends,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6750), 5,
      sym__automatic_semicolon,
      sym__function_signature_automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [134686] = 3,
    ACTIONS(6714), 1,
      anon_sym_is,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4116), 7,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_QMARK,
      anon_sym_extends,
  [134703] = 9,
    ACTIONS(1538), 1,
      anon_sym_import,
    ACTIONS(7073), 1,
      sym_identifier,
    ACTIONS(7075), 1,
      sym_this,
    STATE(1506), 1,
      sym__type_query_subscript_expression,
    STATE(1509), 1,
      sym__type_query_member_expression,
    STATE(1562), 1,
      sym__type_query_call_expression,
    STATE(1563), 1,
      sym__type_query_instantiation_expression,
    STATE(4388), 1,
      sym_import,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [134732] = 6,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    ACTIONS(7009), 1,
      anon_sym_DASH_QMARK_COLON,
    ACTIONS(7011), 1,
      anon_sym_PLUS_QMARK_COLON,
    ACTIONS(7013), 1,
      anon_sym_QMARK_COLON,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    STATE(4315), 4,
      sym_omitting_type_annotation,
      sym_adding_type_annotation,
      sym_opting_type_annotation,
      sym_type_annotation,
  [134755] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3227), 8,
      anon_sym_as,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_extends,
  [134770] = 8,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(6453), 1,
      anon_sym_LPAREN,
    ACTIONS(7077), 1,
      sym_identifier,
    ACTIONS(7079), 1,
      anon_sym_STAR,
    STATE(3806), 1,
      sym_formal_parameters,
    STATE(5328), 1,
      sym_type_parameters,
    STATE(5421), 1,
      sym__call_signature,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [134796] = 8,
    ACTIONS(3576), 1,
      anon_sym_LT,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(7081), 1,
      anon_sym_DOT,
    STATE(2350), 1,
      sym_arguments,
    STATE(5286), 1,
      sym_optional_chain,
    STATE(5293), 1,
      sym_type_arguments,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [134822] = 6,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    STATE(4140), 1,
      sym_type_annotation,
    STATE(4666), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6657), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [134844] = 6,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    STATE(4237), 1,
      sym_type_annotation,
    STATE(4852), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6686), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [134866] = 6,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    STATE(4238), 1,
      sym_type_annotation,
    STATE(4853), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6686), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [134888] = 6,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    STATE(4239), 1,
      sym_type_annotation,
    STATE(4856), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6686), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [134910] = 8,
    ACTIONS(6732), 1,
      anon_sym_LBRACE,
    ACTIONS(6831), 1,
      anon_sym_extends,
    ACTIONS(6833), 1,
      anon_sym_implements,
    STATE(2597), 1,
      sym_class_body,
    STATE(5080), 1,
      sym_extends_clause,
    STATE(5343), 1,
      sym_class_heritage,
    STATE(5792), 1,
      sym_implements_clause,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [134936] = 6,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    STATE(4166), 1,
      sym_type_annotation,
    STATE(4715), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6657), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [134958] = 6,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    STATE(4240), 1,
      sym_type_annotation,
    STATE(4857), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6686), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [134980] = 6,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    STATE(4242), 1,
      sym_type_annotation,
    STATE(4868), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6686), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [135002] = 6,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    STATE(4243), 1,
      sym_type_annotation,
    STATE(4870), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6686), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [135024] = 6,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    STATE(4244), 1,
      sym_type_annotation,
    STATE(4876), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6686), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [135046] = 6,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    STATE(4245), 1,
      sym_type_annotation,
    STATE(4883), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6686), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [135068] = 6,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    STATE(4209), 1,
      sym_type_annotation,
    STATE(4779), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6686), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [135090] = 4,
    ACTIONS(2483), 1,
      anon_sym_LBRACE,
    STATE(5465), 1,
      sym_statement_block,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7083), 5,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACE,
  [135108] = 4,
    ACTIONS(2483), 1,
      anon_sym_LBRACE,
    STATE(5316), 1,
      sym_statement_block,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7085), 5,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACE,
  [135126] = 6,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    STATE(4369), 1,
      sym_type_annotation,
    STATE(5107), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6651), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [135148] = 4,
    ACTIONS(2483), 1,
      anon_sym_LBRACE,
    STATE(5463), 1,
      sym_statement_block,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7085), 5,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACE,
  [135166] = 4,
    ACTIONS(4622), 1,
      anon_sym_EQ,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(5665), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
    ACTIONS(3814), 4,
      anon_sym_LPAREN,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_QMARK,
  [135184] = 6,
    ACTIONS(6595), 1,
      anon_sym_EQ,
    STATE(4499), 1,
      sym_constraint,
    STATE(5417), 1,
      sym_default_type,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6600), 2,
      anon_sym_COLON,
      anon_sym_extends,
    ACTIONS(7087), 2,
      anon_sym_COMMA,
      anon_sym_GT,
  [135206] = 4,
    ACTIONS(2483), 1,
      anon_sym_LBRACE,
    STATE(5464), 1,
      sym_statement_block,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7083), 5,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACE,
  [135224] = 6,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    STATE(4370), 1,
      sym_type_annotation,
    STATE(5110), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6651), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [135246] = 6,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    STATE(4376), 1,
      sym_type_annotation,
    STATE(5111), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6651), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [135268] = 6,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    STATE(4167), 1,
      sym_type_annotation,
    STATE(4718), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6657), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [135290] = 6,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    STATE(4314), 1,
      sym_type_annotation,
    STATE(5012), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6653), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [135312] = 6,
    ACTIONS(3576), 1,
      anon_sym_LT,
    ACTIONS(4588), 1,
      anon_sym_LPAREN,
    STATE(2255), 1,
      sym_arguments,
    STATE(5181), 1,
      sym_type_arguments,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7089), 3,
      anon_sym_LBRACK,
      sym_identifier,
      sym_private_property_identifier,
  [135334] = 6,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    STATE(4159), 1,
      sym_type_annotation,
    STATE(4699), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6657), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [135356] = 6,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    STATE(4263), 1,
      sym_type_annotation,
    STATE(4904), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7091), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [135378] = 6,
    ACTIONS(6595), 1,
      anon_sym_EQ,
    STATE(4414), 1,
      sym_constraint,
    STATE(5419), 1,
      sym_default_type,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6600), 2,
      anon_sym_COLON,
      anon_sym_extends,
    ACTIONS(7093), 2,
      anon_sym_COMMA,
      anon_sym_GT,
  [135400] = 6,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    STATE(4168), 1,
      sym_type_annotation,
    STATE(4720), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6657), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [135422] = 6,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    STATE(4264), 1,
      sym_type_annotation,
    STATE(4906), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7091), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [135444] = 6,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    STATE(4347), 1,
      sym_type_annotation,
    STATE(5074), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6651), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [135466] = 6,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    STATE(4268), 1,
      sym_type_annotation,
    STATE(4924), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7091), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [135488] = 8,
    ACTIONS(3576), 1,
      anon_sym_LT,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    STATE(1647), 1,
      sym_arguments,
    STATE(3174), 1,
      sym_type_arguments,
    STATE(5286), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [135514] = 6,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    STATE(4269), 1,
      sym_type_annotation,
    STATE(4926), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7091), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [135536] = 5,
    ACTIONS(7095), 1,
      anon_sym_AMP,
    ACTIONS(7097), 1,
      anon_sym_PIPE,
    ACTIONS(7099), 1,
      anon_sym_extends,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4334), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK,
  [135556] = 8,
    ACTIONS(3576), 1,
      anon_sym_LT,
    ACTIONS(4588), 1,
      anon_sym_LPAREN,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(7101), 1,
      anon_sym_DOT,
    STATE(2372), 1,
      sym_arguments,
    STATE(5280), 1,
      sym_optional_chain,
    STATE(5376), 1,
      sym_type_arguments,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [135582] = 6,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    STATE(4169), 1,
      sym_type_annotation,
    STATE(4727), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6657), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [135604] = 8,
    ACTIONS(6718), 1,
      anon_sym_LBRACE,
    ACTIONS(6831), 1,
      anon_sym_extends,
    ACTIONS(6833), 1,
      anon_sym_implements,
    STATE(2247), 1,
      sym_class_body,
    STATE(5080), 1,
      sym_extends_clause,
    STATE(5340), 1,
      sym_class_heritage,
    STATE(5792), 1,
      sym_implements_clause,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [135630] = 8,
    ACTIONS(3576), 1,
      anon_sym_LT,
    ACTIONS(4588), 1,
      anon_sym_LPAREN,
    ACTIONS(4592), 1,
      anon_sym_DOT,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    STATE(2381), 1,
      sym_arguments,
    STATE(3471), 1,
      sym_type_arguments,
    STATE(5280), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [135656] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7103), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_PIPE_RBRACE,
  [135670] = 6,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    STATE(4349), 1,
      sym_type_annotation,
    STATE(5078), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6651), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [135692] = 3,
    ACTIONS(6758), 1,
      anon_sym_is,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4116), 6,
      anon_sym_as,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_extends,
  [135708] = 6,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    STATE(4146), 1,
      sym_type_annotation,
    STATE(4676), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6657), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [135730] = 6,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    STATE(3915), 1,
      sym_type_annotation,
    STATE(4907), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6651), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [135752] = 6,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    STATE(4149), 1,
      sym_type_annotation,
    STATE(4679), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6657), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [135774] = 6,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    STATE(4241), 1,
      sym_type_annotation,
    STATE(4863), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6647), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [135796] = 6,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    STATE(3916), 1,
      sym_type_annotation,
    STATE(5100), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6651), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [135818] = 8,
    ACTIONS(6718), 1,
      anon_sym_LBRACE,
    ACTIONS(6831), 1,
      anon_sym_extends,
    ACTIONS(6833), 1,
      anon_sym_implements,
    STATE(2181), 1,
      sym_class_body,
    STATE(5080), 1,
      sym_extends_clause,
    STATE(5374), 1,
      sym_class_heritage,
    STATE(5792), 1,
      sym_implements_clause,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [135844] = 6,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    STATE(3938), 1,
      sym_type_annotation,
    STATE(4822), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6651), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [135866] = 6,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    STATE(4378), 1,
      sym_type_annotation,
    STATE(5122), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6655), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [135888] = 8,
    ACTIONS(6831), 1,
      anon_sym_extends,
    ACTIONS(6833), 1,
      anon_sym_implements,
    ACTIONS(6853), 1,
      anon_sym_LBRACE,
    STATE(4047), 1,
      sym_class_body,
    STATE(5080), 1,
      sym_extends_clause,
    STATE(5362), 1,
      sym_class_heritage,
    STATE(5792), 1,
      sym_implements_clause,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [135914] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7105), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_PIPE_RBRACE,
  [135928] = 6,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    STATE(3940), 1,
      sym_type_annotation,
    STATE(4830), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6651), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [135950] = 6,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    STATE(3942), 1,
      sym_type_annotation,
    STATE(4877), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6651), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [135972] = 6,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    STATE(3947), 1,
      sym_type_annotation,
    STATE(4917), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6651), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [135994] = 8,
    ACTIONS(3576), 1,
      anon_sym_LT,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(7107), 1,
      anon_sym_DOT,
    STATE(2376), 1,
      sym_arguments,
    STATE(5286), 1,
      sym_optional_chain,
    STATE(5293), 1,
      sym_type_arguments,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [136020] = 6,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    STATE(4130), 1,
      sym_type_annotation,
    STATE(4642), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6657), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [136042] = 6,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    STATE(4134), 1,
      sym_type_annotation,
    STATE(4645), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6657), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [136064] = 6,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    STATE(3950), 1,
      sym_type_annotation,
    STATE(5059), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6651), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [136086] = 6,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    STATE(4155), 1,
      sym_type_annotation,
    STATE(4690), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6657), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [136108] = 6,
    ACTIONS(3407), 1,
      anon_sym_LBRACE,
    ACTIONS(3409), 1,
      anon_sym_LBRACK,
    ACTIONS(7109), 1,
      sym_identifier,
    STATE(4601), 1,
      sym_variable_declarator,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    STATE(3718), 3,
      sym_object_pattern,
      sym_array_pattern,
      sym__destructuring_pattern,
  [136130] = 6,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    STATE(4211), 1,
      sym_type_annotation,
    STATE(4788), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6686), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [136152] = 8,
    ACTIONS(3576), 1,
      anon_sym_LT,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(7111), 1,
      anon_sym_DOT,
    STATE(2565), 1,
      sym_arguments,
    STATE(5286), 1,
      sym_optional_chain,
    STATE(5293), 1,
      sym_type_arguments,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [136178] = 4,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    STATE(3920), 1,
      sym_type_annotation,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7113), 5,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACE,
  [136196] = 8,
    ACTIONS(3576), 1,
      anon_sym_LT,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    STATE(2566), 1,
      sym_arguments,
    STATE(3174), 1,
      sym_type_arguments,
    STATE(5286), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [136222] = 6,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    STATE(4212), 1,
      sym_type_annotation,
    STATE(4791), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6686), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [136244] = 8,
    ACTIONS(3576), 1,
      anon_sym_LT,
    ACTIONS(4588), 1,
      anon_sym_LPAREN,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(7115), 1,
      anon_sym_DOT,
    STATE(1951), 1,
      sym_arguments,
    STATE(5286), 1,
      sym_optional_chain,
    STATE(5293), 1,
      sym_type_arguments,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [136270] = 8,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4588), 1,
      anon_sym_LPAREN,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(6345), 1,
      anon_sym_LT,
    STATE(1952), 1,
      sym_arguments,
    STATE(3268), 1,
      sym_type_arguments,
    STATE(5286), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [136296] = 4,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    STATE(4076), 1,
      sym_type_annotation,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7117), 5,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACE,
  [136314] = 8,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(6453), 1,
      anon_sym_LPAREN,
    ACTIONS(7119), 1,
      sym_identifier,
    ACTIONS(7121), 1,
      anon_sym_STAR,
    STATE(3806), 1,
      sym_formal_parameters,
    STATE(5247), 1,
      sym__call_signature,
    STATE(5328), 1,
      sym_type_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [136340] = 8,
    ACTIONS(6718), 1,
      anon_sym_LBRACE,
    ACTIONS(6831), 1,
      anon_sym_extends,
    ACTIONS(6833), 1,
      anon_sym_implements,
    STATE(2260), 1,
      sym_class_body,
    STATE(5080), 1,
      sym_extends_clause,
    STATE(5332), 1,
      sym_class_heritage,
    STATE(5792), 1,
      sym_implements_clause,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [136366] = 6,
    ACTIONS(3407), 1,
      anon_sym_LBRACE,
    ACTIONS(3409), 1,
      anon_sym_LBRACK,
    ACTIONS(7109), 1,
      sym_identifier,
    STATE(4385), 1,
      sym_variable_declarator,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    STATE(3718), 3,
      sym_object_pattern,
      sym_array_pattern,
      sym__destructuring_pattern,
  [136388] = 6,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    STATE(4213), 1,
      sym_type_annotation,
    STATE(4796), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6686), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [136410] = 8,
    ACTIONS(6831), 1,
      anon_sym_extends,
    ACTIONS(6833), 1,
      anon_sym_implements,
    ACTIONS(6847), 1,
      anon_sym_LBRACE,
    STATE(225), 1,
      sym_class_body,
    STATE(5080), 1,
      sym_extends_clause,
    STATE(5237), 1,
      sym_class_heritage,
    STATE(5792), 1,
      sym_implements_clause,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [136436] = 6,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    STATE(4356), 1,
      sym_type_annotation,
    STATE(5087), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6651), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [136458] = 6,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    STATE(4156), 1,
      sym_type_annotation,
    STATE(4691), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6657), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [136480] = 6,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    STATE(4158), 1,
      sym_type_annotation,
    STATE(4696), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6657), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [136502] = 6,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    STATE(3959), 1,
      sym_type_annotation,
    STATE(4536), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6651), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [136524] = 6,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    STATE(4358), 1,
      sym_type_annotation,
    STATE(5090), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6651), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [136546] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6855), 7,
      sym__automatic_semicolon,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_of,
      anon_sym_COLON,
  [136560] = 6,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    STATE(4192), 1,
      sym_type_annotation,
    STATE(4747), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6663), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [136582] = 4,
    ACTIONS(2483), 1,
      anon_sym_LBRACE,
    STATE(5433), 1,
      sym_statement_block,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7123), 5,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACE,
  [136600] = 8,
    ACTIONS(6831), 1,
      anon_sym_extends,
    ACTIONS(6833), 1,
      anon_sym_implements,
    ACTIONS(6853), 1,
      anon_sym_LBRACE,
    STATE(811), 1,
      sym_class_body,
    STATE(5080), 1,
      sym_extends_clause,
    STATE(5394), 1,
      sym_class_heritage,
    STATE(5792), 1,
      sym_implements_clause,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [136626] = 6,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    STATE(4328), 1,
      sym_type_annotation,
    STATE(5037), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6659), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [136648] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4854), 7,
      sym__automatic_semicolon,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_of,
      anon_sym_COLON,
  [136662] = 8,
    ACTIONS(3576), 1,
      anon_sym_LT,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(7107), 1,
      anon_sym_DOT,
    STATE(1588), 1,
      sym_arguments,
    STATE(5286), 1,
      sym_optional_chain,
    STATE(5293), 1,
      sym_type_arguments,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [136688] = 8,
    ACTIONS(6831), 1,
      anon_sym_extends,
    ACTIONS(6833), 1,
      anon_sym_implements,
    ACTIONS(6853), 1,
      anon_sym_LBRACE,
    STATE(4073), 1,
      sym_class_body,
    STATE(5080), 1,
      sym_extends_clause,
    STATE(5422), 1,
      sym_class_heritage,
    STATE(5792), 1,
      sym_implements_clause,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [136714] = 6,
    ACTIONS(3407), 1,
      anon_sym_LBRACE,
    ACTIONS(3409), 1,
      anon_sym_LBRACK,
    ACTIONS(7109), 1,
      sym_identifier,
    STATE(4451), 1,
      sym_variable_declarator,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    STATE(3718), 3,
      sym_object_pattern,
      sym_array_pattern,
      sym__destructuring_pattern,
  [136736] = 6,
    ACTIONS(3407), 1,
      anon_sym_LBRACE,
    ACTIONS(3409), 1,
      anon_sym_LBRACK,
    ACTIONS(7109), 1,
      sym_identifier,
    STATE(4416), 1,
      sym_variable_declarator,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    STATE(3718), 3,
      sym_object_pattern,
      sym_array_pattern,
      sym__destructuring_pattern,
  [136758] = 4,
    ACTIONS(2483), 1,
      anon_sym_LBRACE,
    STATE(5368), 1,
      sym_statement_block,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7123), 5,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACE,
  [136776] = 4,
    ACTIONS(2483), 1,
      anon_sym_LBRACE,
    STATE(5416), 1,
      sym_statement_block,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7125), 5,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACE,
  [136794] = 8,
    ACTIONS(3576), 1,
      anon_sym_LT,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    STATE(2382), 1,
      sym_arguments,
    STATE(3174), 1,
      sym_type_arguments,
    STATE(5286), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [136820] = 8,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(6453), 1,
      anon_sym_LPAREN,
    ACTIONS(7127), 1,
      sym_identifier,
    ACTIONS(7129), 1,
      anon_sym_STAR,
    STATE(3806), 1,
      sym_formal_parameters,
    STATE(5328), 1,
      sym_type_parameters,
    STATE(5453), 1,
      sym__call_signature,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [136846] = 4,
    ACTIONS(2483), 1,
      anon_sym_LBRACE,
    STATE(5434), 1,
      sym_statement_block,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7131), 5,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACE,
  [136864] = 6,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    STATE(4135), 1,
      sym_type_annotation,
    STATE(4637), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6663), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [136886] = 6,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    STATE(4214), 1,
      sym_type_annotation,
    STATE(4799), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6686), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [136908] = 4,
    ACTIONS(2483), 1,
      anon_sym_LBRACE,
    STATE(5259), 1,
      sym_statement_block,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7125), 5,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACE,
  [136926] = 8,
    ACTIONS(6732), 1,
      anon_sym_LBRACE,
    ACTIONS(6831), 1,
      anon_sym_extends,
    ACTIONS(6833), 1,
      anon_sym_implements,
    STATE(1702), 1,
      sym_class_body,
    STATE(5080), 1,
      sym_extends_clause,
    STATE(5369), 1,
      sym_class_heritage,
    STATE(5792), 1,
      sym_implements_clause,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [136952] = 4,
    ACTIONS(2483), 1,
      anon_sym_LBRACE,
    STATE(5297), 1,
      sym_statement_block,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7131), 5,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACE,
  [136970] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4859), 7,
      sym__automatic_semicolon,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_of,
      anon_sym_COLON,
  [136984] = 4,
    ACTIONS(2483), 1,
      anon_sym_LBRACE,
    STATE(5441), 1,
      sym_statement_block,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7133), 5,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACE,
  [137002] = 8,
    ACTIONS(3576), 1,
      anon_sym_LT,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    STATE(2351), 1,
      sym_arguments,
    STATE(3174), 1,
      sym_type_arguments,
    STATE(5286), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [137028] = 8,
    ACTIONS(6718), 1,
      anon_sym_LBRACE,
    ACTIONS(6831), 1,
      anon_sym_extends,
    ACTIONS(6833), 1,
      anon_sym_implements,
    STATE(2327), 1,
      sym_class_body,
    STATE(5080), 1,
      sym_extends_clause,
    STATE(5326), 1,
      sym_class_heritage,
    STATE(5792), 1,
      sym_implements_clause,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [137054] = 6,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    STATE(4219), 1,
      sym_type_annotation,
    STATE(4811), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6686), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [137076] = 6,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    STATE(4139), 1,
      sym_type_annotation,
    STATE(4664), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6657), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [137098] = 6,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    STATE(4054), 1,
      sym_type_annotation,
    STATE(4983), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6665), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [137120] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6865), 7,
      sym__automatic_semicolon,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_of,
      anon_sym_COLON,
  [137134] = 4,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    STATE(4259), 1,
      sym_type_annotation,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7135), 5,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACE,
  [137152] = 8,
    ACTIONS(6718), 1,
      anon_sym_LBRACE,
    ACTIONS(6831), 1,
      anon_sym_extends,
    ACTIONS(6833), 1,
      anon_sym_implements,
    STATE(2191), 1,
      sym_class_body,
    STATE(5080), 1,
      sym_extends_clause,
    STATE(5430), 1,
      sym_class_heritage,
    STATE(5792), 1,
      sym_implements_clause,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [137178] = 6,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    STATE(4221), 1,
      sym_type_annotation,
    STATE(4817), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6686), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [137200] = 5,
    ACTIONS(5555), 1,
      anon_sym_COMMA,
    ACTIONS(5624), 1,
      anon_sym_RBRACE,
    STATE(4960), 1,
      aux_sym_object_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3814), 4,
      anon_sym_LPAREN,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_QMARK,
  [137220] = 8,
    ACTIONS(6831), 1,
      anon_sym_extends,
    ACTIONS(6833), 1,
      anon_sym_implements,
    ACTIONS(6923), 1,
      anon_sym_LBRACE,
    STATE(936), 1,
      sym_class_body,
    STATE(5080), 1,
      sym_extends_clause,
    STATE(5287), 1,
      sym_class_heritage,
    STATE(5792), 1,
      sym_implements_clause,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [137246] = 8,
    ACTIONS(6682), 1,
      anon_sym_LT,
    ACTIONS(7137), 1,
      anon_sym_LBRACE,
    ACTIONS(7139), 1,
      anon_sym_COMMA,
    ACTIONS(7141), 1,
      anon_sym_DOT,
    ACTIONS(7143), 1,
      anon_sym_LBRACE_PIPE,
    STATE(4399), 1,
      aux_sym_extends_type_clause_repeat1,
    STATE(5075), 1,
      sym_type_arguments,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [137272] = 8,
    ACTIONS(6831), 1,
      anon_sym_extends,
    ACTIONS(6833), 1,
      anon_sym_implements,
    ACTIONS(6923), 1,
      anon_sym_LBRACE,
    STATE(825), 1,
      sym_class_body,
    STATE(5080), 1,
      sym_extends_clause,
    STATE(5395), 1,
      sym_class_heritage,
    STATE(5792), 1,
      sym_implements_clause,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [137298] = 6,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    STATE(4363), 1,
      sym_type_annotation,
    STATE(5097), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6651), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [137320] = 6,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    STATE(4064), 1,
      sym_type_annotation,
    STATE(5035), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6657), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [137342] = 7,
    ACTIONS(3557), 1,
      anon_sym_COLON,
    ACTIONS(7145), 1,
      anon_sym_EQ,
    ACTIONS(7149), 1,
      anon_sym_QMARK,
    STATE(4383), 1,
      sym_type_annotation,
    STATE(5272), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7147), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
  [137366] = 4,
    ACTIONS(2483), 1,
      anon_sym_LBRACE,
    STATE(5348), 1,
      sym_statement_block,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7151), 5,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACE,
  [137384] = 4,
    ACTIONS(2483), 1,
      anon_sym_LBRACE,
    STATE(5420), 1,
      sym_statement_block,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7153), 5,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACE,
  [137402] = 4,
    ACTIONS(2483), 1,
      anon_sym_LBRACE,
    STATE(5134), 1,
      sym_statement_block,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7151), 5,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACE,
  [137420] = 6,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    STATE(4336), 1,
      sym_type_annotation,
    STATE(5061), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6651), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [137442] = 6,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    STATE(4345), 1,
      sym_type_annotation,
    STATE(5071), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6651), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [137464] = 6,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    STATE(4066), 1,
      sym_type_annotation,
    STATE(5088), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6657), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [137486] = 4,
    ACTIONS(2483), 1,
      anon_sym_LBRACE,
    STATE(5214), 1,
      sym_statement_block,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7155), 5,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACE,
  [137504] = 4,
    ACTIONS(2483), 1,
      anon_sym_LBRACE,
    STATE(5221), 1,
      sym_statement_block,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7157), 5,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACE,
  [137522] = 4,
    ACTIONS(2483), 1,
      anon_sym_LBRACE,
    STATE(5147), 1,
      sym_statement_block,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7155), 5,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACE,
  [137540] = 8,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(6453), 1,
      anon_sym_LPAREN,
    ACTIONS(7159), 1,
      sym_identifier,
    ACTIONS(7161), 1,
      anon_sym_STAR,
    STATE(3806), 1,
      sym_formal_parameters,
    STATE(5328), 1,
      sym_type_parameters,
    STATE(5421), 1,
      sym__call_signature,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [137566] = 6,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    STATE(4075), 1,
      sym_type_annotation,
    STATE(5112), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6657), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [137588] = 8,
    ACTIONS(3576), 1,
      anon_sym_LT,
    ACTIONS(4588), 1,
      anon_sym_LPAREN,
    ACTIONS(4592), 1,
      anon_sym_DOT,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    STATE(2130), 1,
      sym_arguments,
    STATE(5280), 1,
      sym_optional_chain,
    STATE(5376), 1,
      sym_type_arguments,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [137614] = 4,
    ACTIONS(2483), 1,
      anon_sym_LBRACE,
    STATE(5389), 1,
      sym_statement_block,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7163), 5,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACE,
  [137632] = 8,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(6453), 1,
      anon_sym_LPAREN,
    ACTIONS(7165), 1,
      sym_identifier,
    ACTIONS(7167), 1,
      anon_sym_STAR,
    STATE(3806), 1,
      sym_formal_parameters,
    STATE(5235), 1,
      sym__call_signature,
    STATE(5328), 1,
      sym_type_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [137658] = 8,
    ACTIONS(3576), 1,
      anon_sym_LT,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4014), 1,
      anon_sym_DOT,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    STATE(1655), 1,
      sym_arguments,
    STATE(5286), 1,
      sym_optional_chain,
    STATE(5293), 1,
      sym_type_arguments,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [137684] = 4,
    ACTIONS(2483), 1,
      anon_sym_LBRACE,
    STATE(5392), 1,
      sym_statement_block,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7169), 5,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACE,
  [137702] = 6,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    STATE(4079), 1,
      sym_type_annotation,
    STATE(4518), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6657), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [137724] = 8,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(6453), 1,
      anon_sym_LPAREN,
    ACTIONS(7171), 1,
      sym_identifier,
    ACTIONS(7173), 1,
      anon_sym_STAR,
    STATE(3806), 1,
      sym_formal_parameters,
    STATE(5247), 1,
      sym__call_signature,
    STATE(5328), 1,
      sym_type_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [137750] = 8,
    ACTIONS(1550), 1,
      anon_sym_DQUOTE,
    ACTIONS(1552), 1,
      anon_sym_SQUOTE,
    ACTIONS(7175), 1,
      sym_identifier,
    ACTIONS(7177), 1,
      anon_sym_DOT,
    STATE(783), 1,
      sym_nested_identifier,
    STATE(798), 1,
      sym_string,
    STATE(878), 1,
      sym__module,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [137776] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6871), 7,
      sym__automatic_semicolon,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_of,
      anon_sym_COLON,
  [137790] = 8,
    ACTIONS(6831), 1,
      anon_sym_extends,
    ACTIONS(6833), 1,
      anon_sym_implements,
    ACTIONS(6853), 1,
      anon_sym_LBRACE,
    STATE(4033), 1,
      sym_class_body,
    STATE(5080), 1,
      sym_extends_clause,
    STATE(5296), 1,
      sym_class_heritage,
    STATE(5792), 1,
      sym_implements_clause,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [137816] = 6,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    STATE(3974), 1,
      sym_type_annotation,
    STATE(4628), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6651), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [137838] = 7,
    ACTIONS(3109), 1,
      anon_sym_DQUOTE,
    ACTIONS(3111), 1,
      anon_sym_SQUOTE,
    ACTIONS(6704), 1,
      sym_identifier,
    ACTIONS(6768), 1,
      anon_sym_type,
    STATE(5355), 1,
      sym__import_identifier,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    STATE(5579), 2,
      sym__module_export_name,
      sym_string,
  [137862] = 8,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(6453), 1,
      anon_sym_LPAREN,
    ACTIONS(7179), 1,
      anon_sym_COLON,
    ACTIONS(7181), 1,
      anon_sym_QMARK,
    STATE(3806), 1,
      sym_formal_parameters,
    STATE(5301), 1,
      sym__call_signature,
    STATE(5328), 1,
      sym_type_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [137888] = 4,
    ACTIONS(2483), 1,
      anon_sym_LBRACE,
    STATE(5238), 1,
      sym_statement_block,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7183), 5,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACE,
  [137906] = 8,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(6453), 1,
      anon_sym_LPAREN,
    ACTIONS(7185), 1,
      sym_identifier,
    ACTIONS(7187), 1,
      anon_sym_STAR,
    STATE(3806), 1,
      sym_formal_parameters,
    STATE(5328), 1,
      sym_type_parameters,
    STATE(5421), 1,
      sym__call_signature,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [137932] = 6,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    STATE(3975), 1,
      sym_type_annotation,
    STATE(4630), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6651), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [137954] = 8,
    ACTIONS(218), 1,
      anon_sym_LBRACE_PIPE,
    ACTIONS(1534), 1,
      anon_sym_LBRACE,
    ACTIONS(7189), 1,
      anon_sym_LT,
    ACTIONS(7191), 1,
      anon_sym_extends,
    STATE(897), 1,
      sym_object_type,
    STATE(4208), 1,
      sym_type_parameters,
    STATE(4780), 1,
      sym_extends_type_clause,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [137980] = 6,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    STATE(4100), 1,
      sym_type_annotation,
    STATE(4565), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6669), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [138002] = 3,
    ACTIONS(7193), 1,
      anon_sym_EQ,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3586), 6,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_RBRACK,
      anon_sym_QMARK,
  [138018] = 6,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    STATE(4080), 1,
      sym_type_annotation,
    STATE(4519), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6657), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [138040] = 6,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    STATE(4081), 1,
      sym_type_annotation,
    STATE(4521), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6657), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [138062] = 6,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    STATE(4082), 1,
      sym_type_annotation,
    STATE(4526), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6657), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [138084] = 6,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    STATE(4086), 1,
      sym_type_annotation,
    STATE(4532), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6657), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [138106] = 4,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    STATE(4284), 1,
      sym_type_annotation,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7195), 5,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACE,
  [138124] = 3,
    ACTIONS(7095), 1,
      anon_sym_AMP,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4306), 6,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_PIPE,
      anon_sym_QMARK,
      anon_sym_extends,
  [138140] = 5,
    ACTIONS(7095), 1,
      anon_sym_AMP,
    ACTIONS(7097), 1,
      anon_sym_PIPE,
    ACTIONS(7099), 1,
      anon_sym_extends,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4294), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK,
  [138160] = 3,
    ACTIONS(7197), 1,
      anon_sym_extends,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4192), 6,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_QMARK,
  [138176] = 8,
    ACTIONS(3576), 1,
      anon_sym_LT,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(7199), 1,
      anon_sym_DOT,
    STATE(1588), 1,
      sym_arguments,
    STATE(5286), 1,
      sym_optional_chain,
    STATE(5293), 1,
      sym_type_arguments,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [138202] = 6,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    STATE(4364), 1,
      sym_type_annotation,
    STATE(5098), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6651), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [138224] = 6,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    STATE(4230), 1,
      sym_type_annotation,
    STATE(4832), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6686), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [138246] = 8,
    ACTIONS(6732), 1,
      anon_sym_LBRACE,
    ACTIONS(6831), 1,
      anon_sym_extends,
    ACTIONS(6833), 1,
      anon_sym_implements,
    STATE(1664), 1,
      sym_class_body,
    STATE(5080), 1,
      sym_extends_clause,
    STATE(5234), 1,
      sym_class_heritage,
    STATE(5792), 1,
      sym_implements_clause,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [138272] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6921), 7,
      sym__automatic_semicolon,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_of,
      anon_sym_COLON,
  [138286] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7201), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_PIPE_RBRACE,
  [138300] = 6,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    STATE(4093), 1,
      sym_type_annotation,
    STATE(4539), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6657), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [138322] = 8,
    ACTIONS(6732), 1,
      anon_sym_LBRACE,
    ACTIONS(6831), 1,
      anon_sym_extends,
    ACTIONS(6833), 1,
      anon_sym_implements,
    STATE(2576), 1,
      sym_class_body,
    STATE(5080), 1,
      sym_extends_clause,
    STATE(5157), 1,
      sym_class_heritage,
    STATE(5792), 1,
      sym_implements_clause,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [138348] = 6,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    STATE(4165), 1,
      sym_type_annotation,
    STATE(4709), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6657), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [138370] = 6,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    STATE(4368), 1,
      sym_type_annotation,
    STATE(5105), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6651), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [138392] = 6,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    STATE(3991), 1,
      sym_type_annotation,
    STATE(4704), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6651), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [138414] = 6,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    STATE(3993), 1,
      sym_type_annotation,
    STATE(4710), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6651), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [138436] = 8,
    ACTIONS(6831), 1,
      anon_sym_extends,
    ACTIONS(6833), 1,
      anon_sym_implements,
    ACTIONS(6847), 1,
      anon_sym_LBRACE,
    STATE(228), 1,
      sym_class_body,
    STATE(5080), 1,
      sym_extends_clause,
    STATE(5303), 1,
      sym_class_heritage,
    STATE(5792), 1,
      sym_implements_clause,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [138462] = 8,
    ACTIONS(1626), 1,
      anon_sym_DQUOTE,
    ACTIONS(1628), 1,
      anon_sym_SQUOTE,
    ACTIONS(7203), 1,
      sym_identifier,
    ACTIONS(7205), 1,
      anon_sym_DOT,
    STATE(3500), 1,
      sym_nested_identifier,
    STATE(3698), 1,
      sym_string,
    STATE(4311), 1,
      sym__module,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [138488] = 8,
    ACTIONS(1034), 1,
      anon_sym_LBRACE_PIPE,
    ACTIONS(1610), 1,
      anon_sym_LBRACE,
    ACTIONS(7189), 1,
      anon_sym_LT,
    ACTIONS(7191), 1,
      anon_sym_extends,
    STATE(3951), 1,
      sym_type_parameters,
    STATE(4374), 1,
      sym_object_type,
    STATE(5108), 1,
      sym_extends_type_clause,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [138514] = 6,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    STATE(4096), 1,
      sym_type_annotation,
    STATE(4556), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6657), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [138536] = 6,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    STATE(4097), 1,
      sym_type_annotation,
    STATE(4558), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6657), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [138558] = 6,
    ACTIONS(3576), 1,
      anon_sym_LT,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    STATE(1671), 1,
      sym_arguments,
    STATE(5298), 1,
      sym_type_arguments,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7089), 3,
      anon_sym_LBRACK,
      sym_identifier,
      sym_private_property_identifier,
  [138580] = 6,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    STATE(4232), 1,
      sym_type_annotation,
    STATE(4841), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6686), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [138602] = 6,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    STATE(4006), 1,
      sym_type_annotation,
    STATE(4759), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6651), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [138624] = 6,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    STATE(4008), 1,
      sym_type_annotation,
    STATE(4768), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6651), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [138646] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3622), 7,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_RBRACK,
      anon_sym_QMARK,
  [138660] = 8,
    ACTIONS(6718), 1,
      anon_sym_LBRACE,
    ACTIONS(6831), 1,
      anon_sym_extends,
    ACTIONS(6833), 1,
      anon_sym_implements,
    STATE(2234), 1,
      sym_class_body,
    STATE(5080), 1,
      sym_extends_clause,
    STATE(5414), 1,
      sym_class_heritage,
    STATE(5792), 1,
      sym_implements_clause,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [138686] = 6,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    STATE(4015), 1,
      sym_type_annotation,
    STATE(4807), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6651), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [138708] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4850), 7,
      sym__automatic_semicolon,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_of,
      anon_sym_COLON,
  [138722] = 8,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(6453), 1,
      anon_sym_LPAREN,
    ACTIONS(7181), 1,
      anon_sym_QMARK,
    ACTIONS(7207), 1,
      anon_sym_COLON,
    STATE(3806), 1,
      sym_formal_parameters,
    STATE(5301), 1,
      sym__call_signature,
    STATE(5328), 1,
      sym_type_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [138748] = 8,
    ACTIONS(6718), 1,
      anon_sym_LBRACE,
    ACTIONS(6831), 1,
      anon_sym_extends,
    ACTIONS(6833), 1,
      anon_sym_implements,
    STATE(2170), 1,
      sym_class_body,
    STATE(5080), 1,
      sym_extends_clause,
    STATE(5183), 1,
      sym_class_heritage,
    STATE(5792), 1,
      sym_implements_clause,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [138774] = 6,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    STATE(4021), 1,
      sym_type_annotation,
    STATE(4828), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6651), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [138796] = 6,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    STATE(4188), 1,
      sym_type_annotation,
    STATE(4749), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7209), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [138818] = 6,
    ACTIONS(3407), 1,
      anon_sym_LBRACE,
    ACTIONS(3409), 1,
      anon_sym_LBRACK,
    ACTIONS(7109), 1,
      sym_identifier,
    STATE(4450), 1,
      sym_variable_declarator,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    STATE(3718), 3,
      sym_object_pattern,
      sym_array_pattern,
      sym__destructuring_pattern,
  [138840] = 8,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(6453), 1,
      anon_sym_LPAREN,
    ACTIONS(7211), 1,
      sym_identifier,
    ACTIONS(7213), 1,
      anon_sym_STAR,
    STATE(3806), 1,
      sym_formal_parameters,
    STATE(5247), 1,
      sym__call_signature,
    STATE(5328), 1,
      sym_type_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [138866] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(5494), 7,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_QMARK,
  [138880] = 8,
    ACTIONS(3576), 1,
      anon_sym_LT,
    ACTIONS(4588), 1,
      anon_sym_LPAREN,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    ACTIONS(7215), 1,
      anon_sym_DOT,
    STATE(1983), 1,
      sym_arguments,
    STATE(5280), 1,
      sym_optional_chain,
    STATE(5376), 1,
      sym_type_arguments,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [138906] = 3,
    ACTIONS(6758), 1,
      anon_sym_is,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4106), 6,
      anon_sym_as,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_extends,
  [138922] = 3,
    ACTIONS(7217), 1,
      anon_sym_is,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4110), 6,
      anon_sym_as,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_extends,
  [138938] = 4,
    ACTIONS(7065), 1,
      anon_sym_LBRACE,
    STATE(4280), 1,
      sym_statement_block,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(1674), 5,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACE,
  [138956] = 6,
    ACTIONS(3407), 1,
      anon_sym_LBRACE,
    ACTIONS(3409), 1,
      anon_sym_LBRACK,
    ACTIONS(7219), 1,
      sym_identifier,
    STATE(4416), 1,
      sym_variable_declarator,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    STATE(3387), 3,
      sym_object_pattern,
      sym_array_pattern,
      sym__destructuring_pattern,
  [138978] = 6,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    STATE(4102), 1,
      sym_type_annotation,
    STATE(4569), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6657), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [139000] = 6,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    STATE(4103), 1,
      sym_type_annotation,
    STATE(4571), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6657), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [139022] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6919), 7,
      sym__automatic_semicolon,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_of,
      anon_sym_COLON,
  [139036] = 6,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    STATE(4106), 1,
      sym_type_annotation,
    STATE(4577), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6657), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [139058] = 6,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    STATE(4109), 1,
      sym_type_annotation,
    STATE(4580), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6657), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [139080] = 6,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    STATE(4110), 1,
      sym_type_annotation,
    STATE(4583), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6657), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [139102] = 6,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    STATE(4111), 1,
      sym_type_annotation,
    STATE(4584), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6657), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [139124] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7221), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_PIPE_RBRACE,
  [139138] = 6,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    STATE(4118), 1,
      sym_type_annotation,
    STATE(4605), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6657), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [139160] = 8,
    ACTIONS(6718), 1,
      anon_sym_LBRACE,
    ACTIONS(6831), 1,
      anon_sym_extends,
    ACTIONS(6833), 1,
      anon_sym_implements,
    STATE(2282), 1,
      sym_class_body,
    STATE(5080), 1,
      sym_extends_clause,
    STATE(5446), 1,
      sym_class_heritage,
    STATE(5792), 1,
      sym_implements_clause,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [139186] = 6,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    STATE(4119), 1,
      sym_type_annotation,
    STATE(4607), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6657), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [139208] = 5,
    ACTIONS(7095), 1,
      anon_sym_AMP,
    ACTIONS(7097), 1,
      anon_sym_PIPE,
    ACTIONS(7099), 1,
      anon_sym_extends,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4404), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK,
  [139228] = 6,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    STATE(4120), 1,
      sym_type_annotation,
    STATE(4609), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6657), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [139250] = 3,
    ACTIONS(7095), 1,
      anon_sym_AMP,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4440), 6,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_PIPE,
      anon_sym_QMARK,
      anon_sym_extends,
  [139266] = 4,
    ACTIONS(2483), 1,
      anon_sym_LBRACE,
    STATE(5262), 1,
      sym_statement_block,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7223), 5,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACE,
  [139284] = 6,
    ACTIONS(3407), 1,
      anon_sym_LBRACE,
    ACTIONS(3409), 1,
      anon_sym_LBRACK,
    ACTIONS(7225), 1,
      sym_identifier,
    STATE(4450), 1,
      sym_variable_declarator,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    STATE(3385), 3,
      sym_object_pattern,
      sym_array_pattern,
      sym__destructuring_pattern,
  [139306] = 8,
    ACTIONS(6732), 1,
      anon_sym_LBRACE,
    ACTIONS(6831), 1,
      anon_sym_extends,
    ACTIONS(6833), 1,
      anon_sym_implements,
    STATE(1690), 1,
      sym_class_body,
    STATE(5080), 1,
      sym_extends_clause,
    STATE(5188), 1,
      sym_class_heritage,
    STATE(5792), 1,
      sym_implements_clause,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [139332] = 8,
    ACTIONS(6831), 1,
      anon_sym_extends,
    ACTIONS(6833), 1,
      anon_sym_implements,
    ACTIONS(6853), 1,
      anon_sym_LBRACE,
    STATE(4000), 1,
      sym_class_body,
    STATE(5080), 1,
      sym_extends_clause,
    STATE(5192), 1,
      sym_class_heritage,
    STATE(5792), 1,
      sym_implements_clause,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [139358] = 6,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    STATE(4338), 1,
      sym_type_annotation,
    STATE(4561), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6774), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [139380] = 8,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(6453), 1,
      anon_sym_LPAREN,
    ACTIONS(7227), 1,
      sym_identifier,
    ACTIONS(7229), 1,
      anon_sym_STAR,
    STATE(3806), 1,
      sym_formal_parameters,
    STATE(5247), 1,
      sym__call_signature,
    STATE(5328), 1,
      sym_type_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [139406] = 8,
    ACTIONS(6732), 1,
      anon_sym_LBRACE,
    ACTIONS(6831), 1,
      anon_sym_extends,
    ACTIONS(6833), 1,
      anon_sym_implements,
    STATE(1692), 1,
      sym_class_body,
    STATE(5080), 1,
      sym_extends_clause,
    STATE(5215), 1,
      sym_class_heritage,
    STATE(5792), 1,
      sym_implements_clause,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [139432] = 6,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    STATE(4297), 1,
      sym_type_annotation,
    STATE(4986), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6663), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [139454] = 3,
    ACTIONS(7231), 1,
      anon_sym_EQ,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3622), 6,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_RBRACK,
      anon_sym_QMARK,
  [139470] = 8,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(6453), 1,
      anon_sym_LPAREN,
    ACTIONS(7234), 1,
      sym_identifier,
    ACTIONS(7236), 1,
      anon_sym_STAR,
    STATE(3806), 1,
      sym_formal_parameters,
    STATE(5328), 1,
      sym_type_parameters,
    STATE(5421), 1,
      sym__call_signature,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [139496] = 6,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    STATE(4121), 1,
      sym_type_annotation,
    STATE(4611), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6657), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [139518] = 6,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    STATE(4194), 1,
      sym_type_annotation,
    STATE(4756), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6686), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [139540] = 6,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    STATE(4332), 1,
      sym_type_annotation,
    STATE(5051), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6663), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [139562] = 6,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    STATE(4122), 1,
      sym_type_annotation,
    STATE(4617), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6657), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [139584] = 6,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    STATE(4195), 1,
      sym_type_annotation,
    STATE(4757), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6686), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [139606] = 6,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    STATE(4198), 1,
      sym_type_annotation,
    STATE(4766), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6686), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [139628] = 5,
    ACTIONS(7095), 1,
      anon_sym_AMP,
    ACTIONS(7097), 1,
      anon_sym_PIPE,
    ACTIONS(7099), 1,
      anon_sym_extends,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4204), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK,
  [139648] = 5,
    ACTIONS(7095), 1,
      anon_sym_AMP,
    ACTIONS(7097), 1,
      anon_sym_PIPE,
    ACTIONS(7099), 1,
      anon_sym_extends,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4222), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK,
  [139668] = 5,
    ACTIONS(7095), 1,
      anon_sym_AMP,
    ACTIONS(7097), 1,
      anon_sym_PIPE,
    ACTIONS(7099), 1,
      anon_sym_extends,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4436), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK,
  [139688] = 5,
    ACTIONS(7095), 1,
      anon_sym_AMP,
    ACTIONS(7097), 1,
      anon_sym_PIPE,
    ACTIONS(7099), 1,
      anon_sym_extends,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4444), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK,
  [139708] = 6,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    STATE(4233), 1,
      sym_type_annotation,
    STATE(4843), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6686), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [139730] = 6,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    STATE(3909), 1,
      sym_type_annotation,
    STATE(4631), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6663), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [139752] = 6,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    STATE(3912), 1,
      sym_type_annotation,
    STATE(4677), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6663), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [139774] = 6,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    STATE(4127), 1,
      sym_type_annotation,
    STATE(4634), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6657), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [139796] = 6,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    STATE(4199), 1,
      sym_type_annotation,
    STATE(4767), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6686), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [139818] = 8,
    ACTIONS(3576), 1,
      anon_sym_LT,
    ACTIONS(4588), 1,
      anon_sym_LPAREN,
    ACTIONS(4592), 1,
      anon_sym_DOT,
    ACTIONS(4642), 1,
      anon_sym_QMARK_DOT,
    STATE(2030), 1,
      sym_arguments,
    STATE(3471), 1,
      sym_type_arguments,
    STATE(5280), 1,
      sym_optional_chain,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [139844] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(1888), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_PIPE_RBRACE,
  [139858] = 6,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    STATE(4206), 1,
      sym_type_annotation,
    STATE(4777), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6686), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [139880] = 4,
    ACTIONS(4108), 1,
      anon_sym_extends,
    ACTIONS(7238), 1,
      sym_identifier,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4110), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_GT,
  [139898] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(1892), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_PIPE_RBRACE,
  [139912] = 8,
    ACTIONS(6831), 1,
      anon_sym_extends,
    ACTIONS(6833), 1,
      anon_sym_implements,
    ACTIONS(6853), 1,
      anon_sym_LBRACE,
    STATE(791), 1,
      sym_class_body,
    STATE(5080), 1,
      sym_extends_clause,
    STATE(5312), 1,
      sym_class_heritage,
    STATE(5792), 1,
      sym_implements_clause,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [139938] = 6,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    STATE(3968), 1,
      sym_type_annotation,
    STATE(4600), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6663), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [139960] = 6,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    STATE(3970), 1,
      sym_type_annotation,
    STATE(4606), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6663), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [139982] = 6,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    STATE(3977), 1,
      sym_type_annotation,
    STATE(4648), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6663), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [140004] = 6,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    STATE(3988), 1,
      sym_type_annotation,
    STATE(4658), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6663), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [140026] = 4,
    ACTIONS(2483), 1,
      anon_sym_LBRACE,
    STATE(5345), 1,
      sym_statement_block,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7153), 5,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACE,
  [140044] = 4,
    STATE(3834), 1,
      aux_sym_object_type_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3752), 2,
      anon_sym_RBRACE,
      anon_sym_PIPE_RBRACE,
    ACTIONS(7240), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [140061] = 4,
    ACTIONS(7242), 1,
      anon_sym_LBRACE,
    STATE(2710), 1,
      sym_statement_block,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7131), 4,
      sym__automatic_semicolon,
      sym__function_signature_automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [140078] = 7,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(6453), 1,
      anon_sym_LPAREN,
    ACTIONS(7244), 1,
      anon_sym_QMARK,
    STATE(3806), 1,
      sym_formal_parameters,
    STATE(5328), 1,
      sym_type_parameters,
    STATE(5438), 1,
      sym__call_signature,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [140101] = 7,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(3281), 1,
      anon_sym_LPAREN,
    ACTIONS(7246), 1,
      anon_sym_QMARK,
    STATE(3315), 1,
      sym_formal_parameters,
    STATE(3625), 1,
      sym__call_signature,
    STATE(5233), 1,
      sym_type_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [140124] = 4,
    ACTIONS(7242), 1,
      anon_sym_LBRACE,
    STATE(2702), 1,
      sym_statement_block,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7085), 4,
      sym__automatic_semicolon,
      sym__function_signature_automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [140141] = 7,
    ACTIONS(6605), 1,
      anon_sym_AMP,
    ACTIONS(6607), 1,
      anon_sym_PIPE,
    ACTIONS(6609), 1,
      anon_sym_extends,
    ACTIONS(7248), 1,
      anon_sym_COMMA,
    ACTIONS(7250), 1,
      anon_sym_GT,
    STATE(4588), 1,
      aux_sym_implements_clause_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [140164] = 4,
    ACTIONS(7242), 1,
      anon_sym_LBRACE,
    STATE(2712), 1,
      sym_statement_block,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7153), 4,
      sym__automatic_semicolon,
      sym__function_signature_automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [140181] = 4,
    ACTIONS(7242), 1,
      anon_sym_LBRACE,
    STATE(2704), 1,
      sym_statement_block,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7083), 4,
      sym__automatic_semicolon,
      sym__function_signature_automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [140198] = 5,
    ACTIONS(6605), 1,
      anon_sym_AMP,
    ACTIONS(6607), 1,
      anon_sym_PIPE,
    ACTIONS(6609), 1,
      anon_sym_extends,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7252), 3,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_GT,
  [140217] = 4,
    ACTIONS(7242), 1,
      anon_sym_LBRACE,
    STATE(2653), 1,
      sym_statement_block,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7151), 4,
      sym__automatic_semicolon,
      sym__function_signature_automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [140234] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(2365), 6,
      anon_sym_as,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_extends,
  [140247] = 7,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(6453), 1,
      anon_sym_LPAREN,
    ACTIONS(7254), 1,
      sym_identifier,
    STATE(3806), 1,
      sym_formal_parameters,
    STATE(5250), 1,
      sym__call_signature,
    STATE(5328), 1,
      sym_type_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [140270] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7201), 6,
      sym__automatic_semicolon,
      sym__function_signature_automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON,
  [140283] = 5,
    ACTIONS(7256), 1,
      anon_sym_AMP,
    ACTIONS(7258), 1,
      anon_sym_PIPE,
    ACTIONS(7260), 1,
      anon_sym_extends,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4436), 3,
      anon_sym_as,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
  [140302] = 5,
    ACTIONS(7264), 1,
      anon_sym_BQUOTE,
    ACTIONS(7266), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7262), 2,
      sym__template_chars,
      sym_escape_sequence,
    STATE(3832), 2,
      sym_template_substitution,
      aux_sym_template_string_repeat1,
  [140321] = 4,
    ACTIONS(7268), 1,
      anon_sym_COLON,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6752), 2,
      anon_sym_LBRACE,
      anon_sym_EQ_GT,
    STATE(5199), 3,
      sym_type_annotation,
      sym_asserts_annotation,
      sym_type_predicate_annotation,
  [140338] = 5,
    ACTIONS(7256), 1,
      anon_sym_AMP,
    ACTIONS(7258), 1,
      anon_sym_PIPE,
    ACTIONS(7260), 1,
      anon_sym_extends,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4444), 3,
      anon_sym_as,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
  [140357] = 3,
    ACTIONS(7256), 1,
      anon_sym_AMP,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4306), 5,
      anon_sym_as,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_PIPE,
      anon_sym_extends,
  [140372] = 7,
    ACTIONS(6605), 1,
      anon_sym_AMP,
    ACTIONS(6607), 1,
      anon_sym_PIPE,
    ACTIONS(6609), 1,
      anon_sym_extends,
    ACTIONS(7270), 1,
      anon_sym_COMMA,
    ACTIONS(7272), 1,
      anon_sym_GT,
    STATE(4636), 1,
      aux_sym_implements_clause_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [140395] = 5,
    ACTIONS(7256), 1,
      anon_sym_AMP,
    ACTIONS(7258), 1,
      anon_sym_PIPE,
    ACTIONS(7260), 1,
      anon_sym_extends,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4294), 3,
      anon_sym_as,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
  [140414] = 4,
    ACTIONS(7242), 1,
      anon_sym_LBRACE,
    STATE(2662), 1,
      sym_statement_block,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7183), 4,
      sym__automatic_semicolon,
      sym__function_signature_automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [140431] = 3,
    ACTIONS(7274), 1,
      anon_sym_extends,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4192), 5,
      anon_sym_as,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_AMP,
      anon_sym_PIPE,
  [140446] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(2369), 6,
      anon_sym_as,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_extends,
  [140459] = 6,
    ACTIONS(7095), 1,
      anon_sym_AMP,
    ACTIONS(7097), 1,
      anon_sym_PIPE,
    ACTIONS(7099), 1,
      anon_sym_extends,
    ACTIONS(7278), 1,
      anon_sym_QMARK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7276), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK,
  [140480] = 7,
    ACTIONS(97), 1,
      anon_sym_AT,
    ACTIONS(7280), 1,
      anon_sym_export,
    ACTIONS(7282), 1,
      anon_sym_class,
    ACTIONS(7284), 1,
      anon_sym_abstract,
    STATE(1269), 1,
      aux_sym_export_statement_repeat1,
    STATE(1344), 1,
      sym_decorator,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [140503] = 7,
    ACTIONS(6605), 1,
      anon_sym_AMP,
    ACTIONS(6607), 1,
      anon_sym_PIPE,
    ACTIONS(6609), 1,
      anon_sym_extends,
    ACTIONS(7286), 1,
      anon_sym_COMMA,
    ACTIONS(7288), 1,
      anon_sym_GT,
    STATE(4693), 1,
      aux_sym_implements_clause_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [140526] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(2361), 6,
      anon_sym_as,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_extends,
  [140539] = 4,
    STATE(3801), 1,
      aux_sym_object_type_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7292), 2,
      anon_sym_RBRACE,
      anon_sym_PIPE_RBRACE,
    ACTIONS(7290), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [140556] = 6,
    ACTIONS(3557), 1,
      anon_sym_COLON,
    ACTIONS(7145), 1,
      anon_sym_EQ,
    STATE(4491), 1,
      sym_type_annotation,
    STATE(5132), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7294), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
  [140577] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3814), 6,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_LT,
      anon_sym_QMARK,
  [140590] = 7,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(6509), 1,
      anon_sym_LPAREN,
    ACTIONS(7296), 1,
      anon_sym_QMARK,
    STATE(3330), 1,
      sym_formal_parameters,
    STATE(3800), 1,
      sym__call_signature,
    STATE(5249), 1,
      sym_type_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [140613] = 7,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(3281), 1,
      anon_sym_LPAREN,
    ACTIONS(7298), 1,
      anon_sym_QMARK,
    STATE(3315), 1,
      sym_formal_parameters,
    STATE(4257), 1,
      sym__call_signature,
    STATE(5233), 1,
      sym_type_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [140636] = 7,
    ACTIONS(1550), 1,
      anon_sym_DQUOTE,
    ACTIONS(1552), 1,
      anon_sym_SQUOTE,
    ACTIONS(7175), 1,
      sym_identifier,
    STATE(783), 1,
      sym_nested_identifier,
    STATE(798), 1,
      sym_string,
    STATE(887), 1,
      sym__module,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [140659] = 4,
    ACTIONS(7242), 1,
      anon_sym_LBRACE,
    STATE(2707), 1,
      sym_statement_block,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7153), 4,
      sym__automatic_semicolon,
      sym__function_signature_automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [140676] = 7,
    ACTIONS(6605), 1,
      anon_sym_AMP,
    ACTIONS(6607), 1,
      anon_sym_PIPE,
    ACTIONS(6609), 1,
      anon_sym_extends,
    ACTIONS(7300), 1,
      anon_sym_COMMA,
    ACTIONS(7302), 1,
      anon_sym_GT,
    STATE(5016), 1,
      aux_sym_implements_clause_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [140699] = 5,
    ACTIONS(7266), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(7304), 1,
      anon_sym_BQUOTE,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7262), 2,
      sym__template_chars,
      sym_escape_sequence,
    STATE(3832), 2,
      sym_template_substitution,
      aux_sym_template_string_repeat1,
  [140718] = 4,
    STATE(3794), 1,
      aux_sym_object_type_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3764), 2,
      anon_sym_RBRACE,
      anon_sym_PIPE_RBRACE,
    ACTIONS(7306), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [140735] = 7,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(3281), 1,
      anon_sym_LPAREN,
    ACTIONS(7308), 1,
      anon_sym_QMARK,
    STATE(3315), 1,
      sym_formal_parameters,
    STATE(4968), 1,
      sym__call_signature,
    STATE(5233), 1,
      sym_type_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [140758] = 7,
    ACTIONS(6605), 1,
      anon_sym_AMP,
    ACTIONS(6607), 1,
      anon_sym_PIPE,
    ACTIONS(6609), 1,
      anon_sym_extends,
    ACTIONS(7310), 1,
      anon_sym_COMMA,
    ACTIONS(7312), 1,
      anon_sym_GT,
    STATE(5006), 1,
      aux_sym_implements_clause_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [140781] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7221), 6,
      sym__automatic_semicolon,
      sym__function_signature_automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON,
  [140794] = 4,
    STATE(3808), 1,
      aux_sym_object_type_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3752), 2,
      anon_sym_RBRACE,
      anon_sym_PIPE_RBRACE,
    ACTIONS(7240), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [140811] = 5,
    ACTIONS(3275), 1,
      anon_sym_LBRACE,
    ACTIONS(7314), 1,
      sym_identifier,
    ACTIONS(7316), 1,
      anon_sym_LBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    STATE(4829), 3,
      sym_object_pattern,
      sym_array_pattern,
      sym__destructuring_pattern,
  [140830] = 4,
    ACTIONS(5217), 1,
      anon_sym_COMMA,
    STATE(3807), 1,
      aux_sym_sequence_expression_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7318), 4,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_RBRACK,
  [140847] = 4,
    STATE(3803), 1,
      aux_sym_object_type_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3772), 2,
      anon_sym_RBRACE,
      anon_sym_PIPE_RBRACE,
    ACTIONS(7320), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [140864] = 4,
    STATE(3834), 1,
      aux_sym_object_type_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3780), 2,
      anon_sym_RBRACE,
      anon_sym_PIPE_RBRACE,
    ACTIONS(7322), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [140881] = 3,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(5843), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
    ACTIONS(3814), 4,
      anon_sym_LPAREN,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_QMARK,
  [140896] = 4,
    ACTIONS(7242), 1,
      anon_sym_LBRACE,
    STATE(2655), 1,
      sym_statement_block,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7155), 4,
      sym__automatic_semicolon,
      sym__function_signature_automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [140913] = 4,
    STATE(3834), 1,
      aux_sym_object_type_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3774), 2,
      anon_sym_RBRACE,
      anon_sym_PIPE_RBRACE,
    ACTIONS(7324), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [140930] = 7,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(3281), 1,
      anon_sym_LPAREN,
    ACTIONS(7326), 1,
      anon_sym_QMARK,
    STATE(3315), 1,
      sym_formal_parameters,
    STATE(3917), 1,
      sym__call_signature,
    STATE(5233), 1,
      sym_type_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [140953] = 4,
    ACTIONS(7242), 1,
      anon_sym_LBRACE,
    STATE(2695), 1,
      sym_statement_block,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7123), 4,
      sym__automatic_semicolon,
      sym__function_signature_automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [140970] = 4,
    ACTIONS(7242), 1,
      anon_sym_LBRACE,
    STATE(2657), 1,
      sym_statement_block,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7157), 4,
      sym__automatic_semicolon,
      sym__function_signature_automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [140987] = 4,
    STATE(3834), 1,
      aux_sym_object_type_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3772), 2,
      anon_sym_RBRACE,
      anon_sym_PIPE_RBRACE,
    ACTIONS(7320), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [141004] = 7,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(3281), 1,
      anon_sym_LPAREN,
    ACTIONS(7328), 1,
      anon_sym_QMARK,
    STATE(3315), 1,
      sym_formal_parameters,
    STATE(4272), 1,
      sym__call_signature,
    STATE(5233), 1,
      sym_type_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [141027] = 4,
    STATE(3834), 1,
      aux_sym_object_type_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3748), 2,
      anon_sym_RBRACE,
      anon_sym_PIPE_RBRACE,
    ACTIONS(7330), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [141044] = 7,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(6509), 1,
      anon_sym_LPAREN,
    ACTIONS(7332), 1,
      anon_sym_QMARK,
    STATE(3330), 1,
      sym_formal_parameters,
    STATE(3799), 1,
      sym__call_signature,
    STATE(5249), 1,
      sym_type_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [141067] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7103), 6,
      sym__automatic_semicolon,
      sym__function_signature_automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON,
  [141080] = 4,
    ACTIONS(7268), 1,
      anon_sym_COLON,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6783), 2,
      anon_sym_LBRACE,
      anon_sym_EQ_GT,
    STATE(5306), 3,
      sym_type_annotation,
      sym_asserts_annotation,
      sym_type_predicate_annotation,
  [141097] = 4,
    ACTIONS(7334), 1,
      anon_sym_COMMA,
    STATE(3807), 1,
      aux_sym_sequence_expression_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4852), 4,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_RBRACK,
  [141114] = 4,
    STATE(3834), 1,
      aux_sym_object_type_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3790), 2,
      anon_sym_RBRACE,
      anon_sym_PIPE_RBRACE,
    ACTIONS(7337), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [141131] = 4,
    STATE(3879), 1,
      aux_sym_object_type_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7341), 2,
      anon_sym_RBRACE,
      anon_sym_PIPE_RBRACE,
    ACTIONS(7339), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [141148] = 4,
    STATE(3889), 1,
      aux_sym_object_type_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7345), 2,
      anon_sym_RBRACE,
      anon_sym_PIPE_RBRACE,
    ACTIONS(7343), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [141165] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7347), 6,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACE,
  [141178] = 7,
    ACTIONS(1550), 1,
      anon_sym_DQUOTE,
    ACTIONS(1552), 1,
      anon_sym_SQUOTE,
    ACTIONS(7175), 1,
      sym_identifier,
    STATE(783), 1,
      sym_nested_identifier,
    STATE(798), 1,
      sym_string,
    STATE(878), 1,
      sym__module,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [141201] = 4,
    ACTIONS(7242), 1,
      anon_sym_LBRACE,
    STATE(2660), 1,
      sym_statement_block,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7169), 4,
      sym__automatic_semicolon,
      sym__function_signature_automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [141218] = 4,
    STATE(3797), 1,
      aux_sym_object_type_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3786), 2,
      anon_sym_RBRACE,
      anon_sym_PIPE_RBRACE,
    ACTIONS(7349), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [141235] = 4,
    STATE(3864), 1,
      aux_sym_object_type_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7353), 2,
      anon_sym_RBRACE,
      anon_sym_PIPE_RBRACE,
    ACTIONS(7351), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [141252] = 7,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(6453), 1,
      anon_sym_LPAREN,
    ACTIONS(7355), 1,
      anon_sym_QMARK,
    STATE(3806), 1,
      sym_formal_parameters,
    STATE(5242), 1,
      sym__call_signature,
    STATE(5328), 1,
      sym_type_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [141275] = 5,
    ACTIONS(7357), 1,
      anon_sym_default,
    ACTIONS(7360), 1,
      anon_sym_RBRACE,
    ACTIONS(7362), 1,
      anon_sym_case,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    STATE(3817), 3,
      sym_switch_case,
      sym_switch_default,
      aux_sym_switch_body_repeat1,
  [141294] = 7,
    ACTIONS(6682), 1,
      anon_sym_LT,
    ACTIONS(7139), 1,
      anon_sym_COMMA,
    ACTIONS(7365), 1,
      anon_sym_LBRACE,
    ACTIONS(7367), 1,
      anon_sym_LBRACE_PIPE,
    STATE(4400), 1,
      aux_sym_extends_type_clause_repeat1,
    STATE(5076), 1,
      sym_type_arguments,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [141317] = 4,
    ACTIONS(7242), 1,
      anon_sym_LBRACE,
    STATE(2650), 1,
      sym_statement_block,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7151), 4,
      sym__automatic_semicolon,
      sym__function_signature_automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [141334] = 4,
    ACTIONS(7242), 1,
      anon_sym_LBRACE,
    STATE(2687), 1,
      sym_statement_block,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7125), 4,
      sym__automatic_semicolon,
      sym__function_signature_automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [141351] = 7,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(6453), 1,
      anon_sym_LPAREN,
    ACTIONS(7369), 1,
      sym_identifier,
    STATE(3806), 1,
      sym_formal_parameters,
    STATE(5250), 1,
      sym__call_signature,
    STATE(5328), 1,
      sym_type_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [141374] = 7,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(6453), 1,
      anon_sym_LPAREN,
    ACTIONS(7371), 1,
      anon_sym_QMARK,
    STATE(3806), 1,
      sym_formal_parameters,
    STATE(5213), 1,
      sym__call_signature,
    STATE(5328), 1,
      sym_type_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [141397] = 7,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(6453), 1,
      anon_sym_LPAREN,
    ACTIONS(7373), 1,
      sym_identifier,
    STATE(3806), 1,
      sym_formal_parameters,
    STATE(5187), 1,
      sym__call_signature,
    STATE(5328), 1,
      sym_type_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [141420] = 5,
    ACTIONS(7256), 1,
      anon_sym_AMP,
    ACTIONS(7258), 1,
      anon_sym_PIPE,
    ACTIONS(7260), 1,
      anon_sym_extends,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4204), 3,
      anon_sym_as,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
  [141439] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7375), 6,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACE,
  [141452] = 7,
    ACTIONS(3514), 1,
      anon_sym_LPAREN,
    ACTIONS(3576), 1,
      anon_sym_LT,
    ACTIONS(7377), 1,
      anon_sym_RPAREN,
    ACTIONS(7379), 1,
      anon_sym_DOT,
    STATE(1288), 1,
      sym_arguments,
    STATE(5440), 1,
      sym_type_arguments,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [141475] = 5,
    ACTIONS(7381), 1,
      anon_sym_default,
    ACTIONS(7383), 1,
      anon_sym_RBRACE,
    ACTIONS(7385), 1,
      anon_sym_case,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    STATE(3877), 3,
      sym_switch_case,
      sym_switch_default,
      aux_sym_switch_body_repeat1,
  [141494] = 7,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(3281), 1,
      anon_sym_LPAREN,
    ACTIONS(7387), 1,
      anon_sym_QMARK,
    STATE(3315), 1,
      sym_formal_parameters,
    STATE(3632), 1,
      sym__call_signature,
    STATE(5233), 1,
      sym_type_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [141517] = 5,
    ACTIONS(3407), 1,
      anon_sym_LBRACE,
    ACTIONS(3409), 1,
      anon_sym_LBRACK,
    ACTIONS(7389), 1,
      sym_identifier,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    STATE(4813), 3,
      sym_object_pattern,
      sym_array_pattern,
      sym__destructuring_pattern,
  [141536] = 7,
    ACTIONS(97), 1,
      anon_sym_AT,
    ACTIONS(7284), 1,
      anon_sym_abstract,
    ACTIONS(7391), 1,
      anon_sym_export,
    ACTIONS(7393), 1,
      anon_sym_class,
    STATE(1269), 1,
      aux_sym_export_statement_repeat1,
    STATE(1344), 1,
      sym_decorator,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [141559] = 7,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(6453), 1,
      anon_sym_LPAREN,
    ACTIONS(7395), 1,
      sym_identifier,
    STATE(3806), 1,
      sym_formal_parameters,
    STATE(5328), 1,
      sym_type_parameters,
    STATE(5429), 1,
      sym__call_signature,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [141582] = 5,
    ACTIONS(7400), 1,
      anon_sym_BQUOTE,
    ACTIONS(7402), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7397), 2,
      sym__template_chars,
      sym_escape_sequence,
    STATE(3832), 2,
      sym_template_substitution,
      aux_sym_template_string_repeat1,
  [141601] = 7,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(6509), 1,
      anon_sym_LPAREN,
    ACTIONS(7405), 1,
      anon_sym_QMARK,
    STATE(3330), 1,
      sym_formal_parameters,
    STATE(3813), 1,
      sym__call_signature,
    STATE(5249), 1,
      sym_type_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [141624] = 4,
    STATE(3834), 1,
      aux_sym_object_type_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7410), 2,
      anon_sym_RBRACE,
      anon_sym_PIPE_RBRACE,
    ACTIONS(7407), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [141641] = 5,
    ACTIONS(6605), 1,
      anon_sym_AMP,
    ACTIONS(6607), 1,
      anon_sym_PIPE,
    ACTIONS(6609), 1,
      anon_sym_extends,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7412), 3,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_GT,
  [141660] = 7,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(3281), 1,
      anon_sym_LPAREN,
    ACTIONS(7414), 1,
      anon_sym_QMARK,
    STATE(3315), 1,
      sym_formal_parameters,
    STATE(3601), 1,
      sym__call_signature,
    STATE(5233), 1,
      sym_type_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [141683] = 7,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(6453), 1,
      anon_sym_LPAREN,
    ACTIONS(7416), 1,
      anon_sym_QMARK,
    STATE(3806), 1,
      sym_formal_parameters,
    STATE(5328), 1,
      sym_type_parameters,
    STATE(5435), 1,
      sym__call_signature,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [141706] = 5,
    ACTIONS(7256), 1,
      anon_sym_AMP,
    ACTIONS(7258), 1,
      anon_sym_PIPE,
    ACTIONS(7260), 1,
      anon_sym_extends,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4334), 3,
      anon_sym_as,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
  [141725] = 4,
    ACTIONS(7242), 1,
      anon_sym_LBRACE,
    STATE(2688), 1,
      sym_statement_block,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7131), 4,
      sym__automatic_semicolon,
      sym__function_signature_automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [141742] = 7,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(6453), 1,
      anon_sym_LPAREN,
    ACTIONS(7418), 1,
      anon_sym_QMARK,
    STATE(3806), 1,
      sym_formal_parameters,
    STATE(5328), 1,
      sym_type_parameters,
    STATE(5350), 1,
      sym__call_signature,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [141765] = 7,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(3281), 1,
      anon_sym_LPAREN,
    ACTIONS(7420), 1,
      anon_sym_QMARK,
    STATE(3315), 1,
      sym_formal_parameters,
    STATE(5060), 1,
      sym__call_signature,
    STATE(5233), 1,
      sym_type_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [141788] = 7,
    ACTIONS(3514), 1,
      anon_sym_LPAREN,
    ACTIONS(3576), 1,
      anon_sym_LT,
    ACTIONS(7379), 1,
      anon_sym_DOT,
    ACTIONS(7422), 1,
      anon_sym_RPAREN,
    STATE(1288), 1,
      sym_arguments,
    STATE(5440), 1,
      sym_type_arguments,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [141811] = 7,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(3281), 1,
      anon_sym_LPAREN,
    ACTIONS(7424), 1,
      anon_sym_QMARK,
    STATE(3315), 1,
      sym_formal_parameters,
    STATE(5044), 1,
      sym__call_signature,
    STATE(5233), 1,
      sym_type_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [141834] = 4,
    STATE(3750), 1,
      aux_sym_object_type_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7428), 2,
      anon_sym_RBRACE,
      anon_sym_PIPE_RBRACE,
    ACTIONS(7426), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [141851] = 7,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(3281), 1,
      anon_sym_LPAREN,
    ACTIONS(7430), 1,
      anon_sym_QMARK,
    STATE(3315), 1,
      sym_formal_parameters,
    STATE(4179), 1,
      sym__call_signature,
    STATE(5233), 1,
      sym_type_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [141874] = 7,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(3281), 1,
      anon_sym_LPAREN,
    ACTIONS(7432), 1,
      anon_sym_QMARK,
    STATE(3315), 1,
      sym_formal_parameters,
    STATE(4255), 1,
      sym__call_signature,
    STATE(5233), 1,
      sym_type_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [141897] = 4,
    ACTIONS(7242), 1,
      anon_sym_LBRACE,
    STATE(2708), 1,
      sym_statement_block,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7125), 4,
      sym__automatic_semicolon,
      sym__function_signature_automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [141914] = 4,
    ACTIONS(7242), 1,
      anon_sym_LBRACE,
    STATE(2690), 1,
      sym_statement_block,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7123), 4,
      sym__automatic_semicolon,
      sym__function_signature_automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [141931] = 5,
    ACTIONS(7256), 1,
      anon_sym_AMP,
    ACTIONS(7258), 1,
      anon_sym_PIPE,
    ACTIONS(7260), 1,
      anon_sym_extends,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4222), 3,
      anon_sym_as,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
  [141950] = 3,
    ACTIONS(7256), 1,
      anon_sym_AMP,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4440), 5,
      anon_sym_as,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_PIPE,
      anon_sym_extends,
  [141965] = 7,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(6453), 1,
      anon_sym_LPAREN,
    ACTIONS(7434), 1,
      anon_sym_QMARK,
    STATE(3806), 1,
      sym_formal_parameters,
    STATE(5328), 1,
      sym_type_parameters,
    STATE(5365), 1,
      sym__call_signature,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [141988] = 5,
    ACTIONS(7266), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(7436), 1,
      anon_sym_BQUOTE,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7025), 2,
      sym__template_chars,
      sym_escape_sequence,
    STATE(3785), 2,
      sym_template_substitution,
      aux_sym_template_string_repeat1,
  [142007] = 7,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(6453), 1,
      anon_sym_LPAREN,
    ACTIONS(7438), 1,
      anon_sym_QMARK,
    STATE(3806), 1,
      sym_formal_parameters,
    STATE(5133), 1,
      sym__call_signature,
    STATE(5328), 1,
      sym_type_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [142030] = 7,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(6453), 1,
      anon_sym_LPAREN,
    ACTIONS(7440), 1,
      sym_identifier,
    STATE(3806), 1,
      sym_formal_parameters,
    STATE(5250), 1,
      sym__call_signature,
    STATE(5328), 1,
      sym_type_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [142053] = 4,
    ACTIONS(7242), 1,
      anon_sym_LBRACE,
    STATE(2672), 1,
      sym_statement_block,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7155), 4,
      sym__automatic_semicolon,
      sym__function_signature_automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [142070] = 7,
    ACTIONS(6605), 1,
      anon_sym_AMP,
    ACTIONS(6607), 1,
      anon_sym_PIPE,
    ACTIONS(6609), 1,
      anon_sym_extends,
    ACTIONS(7442), 1,
      anon_sym_LBRACE,
    ACTIONS(7444), 1,
      anon_sym_COMMA,
    STATE(4905), 1,
      aux_sym_implements_clause_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [142093] = 5,
    ACTIONS(7256), 1,
      anon_sym_AMP,
    ACTIONS(7258), 1,
      anon_sym_PIPE,
    ACTIONS(7260), 1,
      anon_sym_extends,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4404), 3,
      anon_sym_as,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
  [142112] = 7,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(6453), 1,
      anon_sym_LPAREN,
    ACTIONS(7446), 1,
      sym_identifier,
    STATE(3806), 1,
      sym_formal_parameters,
    STATE(5328), 1,
      sym_type_parameters,
    STATE(5429), 1,
      sym__call_signature,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [142135] = 7,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(6453), 1,
      anon_sym_LPAREN,
    ACTIONS(7448), 1,
      sym_identifier,
    STATE(3806), 1,
      sym_formal_parameters,
    STATE(5328), 1,
      sym_type_parameters,
    STATE(5429), 1,
      sym__call_signature,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [142158] = 7,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(3281), 1,
      anon_sym_LPAREN,
    ACTIONS(7450), 1,
      anon_sym_QMARK,
    STATE(3315), 1,
      sym_formal_parameters,
    STATE(3640), 1,
      sym__call_signature,
    STATE(5233), 1,
      sym_type_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [142181] = 5,
    ACTIONS(7266), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(7452), 1,
      anon_sym_BQUOTE,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7043), 2,
      sym__template_chars,
      sym_escape_sequence,
    STATE(3764), 2,
      sym_template_substitution,
      aux_sym_template_string_repeat1,
  [142200] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7454), 6,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACE,
  [142213] = 7,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(6509), 1,
      anon_sym_LPAREN,
    ACTIONS(7456), 1,
      anon_sym_QMARK,
    STATE(3330), 1,
      sym_formal_parameters,
    STATE(3895), 1,
      sym__call_signature,
    STATE(5249), 1,
      sym_type_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [142236] = 4,
    STATE(3834), 1,
      aux_sym_object_type_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3786), 2,
      anon_sym_RBRACE,
      anon_sym_PIPE_RBRACE,
    ACTIONS(7349), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [142253] = 7,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(6453), 1,
      anon_sym_LPAREN,
    ACTIONS(7458), 1,
      sym_identifier,
    STATE(3806), 1,
      sym_formal_parameters,
    STATE(5250), 1,
      sym__call_signature,
    STATE(5328), 1,
      sym_type_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [142276] = 7,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(3281), 1,
      anon_sym_LPAREN,
    ACTIONS(7460), 1,
      anon_sym_QMARK,
    STATE(3315), 1,
      sym_formal_parameters,
    STATE(3589), 1,
      sym__call_signature,
    STATE(5233), 1,
      sym_type_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [142299] = 7,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(6453), 1,
      anon_sym_LPAREN,
    ACTIONS(7462), 1,
      sym_identifier,
    STATE(3806), 1,
      sym_formal_parameters,
    STATE(5236), 1,
      sym__call_signature,
    STATE(5328), 1,
      sym_type_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [142322] = 4,
    STATE(3834), 1,
      aux_sym_object_type_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3766), 2,
      anon_sym_RBRACE,
      anon_sym_PIPE_RBRACE,
    ACTIONS(7464), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [142339] = 6,
    ACTIONS(6682), 1,
      anon_sym_LT,
    ACTIONS(7141), 1,
      anon_sym_DOT,
    ACTIONS(7466), 1,
      anon_sym_LBRACE,
    STATE(5075), 1,
      sym_type_arguments,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7468), 2,
      anon_sym_COMMA,
      anon_sym_LBRACE_PIPE,
  [142360] = 4,
    ACTIONS(7242), 1,
      anon_sym_LBRACE,
    STATE(2696), 1,
      sym_statement_block,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7133), 4,
      sym__automatic_semicolon,
      sym__function_signature_automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [142377] = 7,
    ACTIONS(1626), 1,
      anon_sym_DQUOTE,
    ACTIONS(1628), 1,
      anon_sym_SQUOTE,
    ACTIONS(7203), 1,
      sym_identifier,
    STATE(3500), 1,
      sym_nested_identifier,
    STATE(3698), 1,
      sym_string,
    STATE(4270), 1,
      sym__module,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [142400] = 7,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(6453), 1,
      anon_sym_LPAREN,
    ACTIONS(7470), 1,
      anon_sym_QMARK,
    STATE(3806), 1,
      sym_formal_parameters,
    STATE(5318), 1,
      sym__call_signature,
    STATE(5328), 1,
      sym_type_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [142423] = 7,
    ACTIONS(1626), 1,
      anon_sym_DQUOTE,
    ACTIONS(1628), 1,
      anon_sym_SQUOTE,
    ACTIONS(7203), 1,
      sym_identifier,
    STATE(3500), 1,
      sym_nested_identifier,
    STATE(3698), 1,
      sym_string,
    STATE(4311), 1,
      sym__module,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [142446] = 7,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(3281), 1,
      anon_sym_LPAREN,
    ACTIONS(7472), 1,
      anon_sym_QMARK,
    STATE(3315), 1,
      sym_formal_parameters,
    STATE(4025), 1,
      sym__call_signature,
    STATE(5233), 1,
      sym_type_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [142469] = 4,
    STATE(3868), 1,
      aux_sym_object_type_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3760), 2,
      anon_sym_RBRACE,
      anon_sym_PIPE_RBRACE,
    ACTIONS(7474), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [142486] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(2373), 6,
      anon_sym_as,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_extends,
  [142499] = 5,
    ACTIONS(7381), 1,
      anon_sym_default,
    ACTIONS(7385), 1,
      anon_sym_case,
    ACTIONS(7476), 1,
      anon_sym_RBRACE,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    STATE(3817), 3,
      sym_switch_case,
      sym_switch_default,
      aux_sym_switch_body_repeat1,
  [142518] = 7,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(6453), 1,
      anon_sym_LPAREN,
    ACTIONS(7478), 1,
      anon_sym_QMARK,
    STATE(3806), 1,
      sym_formal_parameters,
    STATE(5328), 1,
      sym_type_parameters,
    STATE(5426), 1,
      sym__call_signature,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [142541] = 4,
    STATE(3834), 1,
      aux_sym_object_type_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3760), 2,
      anon_sym_RBRACE,
      anon_sym_PIPE_RBRACE,
    ACTIONS(7474), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [142558] = 7,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(6453), 1,
      anon_sym_LPAREN,
    ACTIONS(7480), 1,
      anon_sym_QMARK,
    STATE(3806), 1,
      sym_formal_parameters,
    STATE(5240), 1,
      sym__call_signature,
    STATE(5328), 1,
      sym_type_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [142581] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7105), 6,
      sym__automatic_semicolon,
      sym__function_signature_automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_COLON,
  [142594] = 7,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(3281), 1,
      anon_sym_LPAREN,
    ACTIONS(7482), 1,
      anon_sym_QMARK,
    STATE(3315), 1,
      sym_formal_parameters,
    STATE(3522), 1,
      sym__call_signature,
    STATE(5233), 1,
      sym_type_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [142617] = 7,
    ACTIONS(6605), 1,
      anon_sym_AMP,
    ACTIONS(6607), 1,
      anon_sym_PIPE,
    ACTIONS(6609), 1,
      anon_sym_extends,
    ACTIONS(7484), 1,
      anon_sym_COMMA,
    ACTIONS(7486), 1,
      anon_sym_GT,
    STATE(4542), 1,
      aux_sym_implements_clause_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [142640] = 4,
    STATE(3896), 1,
      aux_sym_object_type_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3768), 2,
      anon_sym_RBRACE,
      anon_sym_PIPE_RBRACE,
    ACTIONS(7488), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [142657] = 4,
    ACTIONS(7242), 1,
      anon_sym_LBRACE,
    STATE(2668), 1,
      sym_statement_block,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7083), 4,
      sym__automatic_semicolon,
      sym__function_signature_automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [142674] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7490), 6,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACE,
  [142687] = 4,
    STATE(3891), 1,
      aux_sym_object_type_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7494), 2,
      anon_sym_RBRACE,
      anon_sym_PIPE_RBRACE,
    ACTIONS(7492), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [142704] = 7,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(6453), 1,
      anon_sym_LPAREN,
    ACTIONS(7496), 1,
      anon_sym_QMARK,
    STATE(3806), 1,
      sym_formal_parameters,
    STATE(5328), 1,
      sym_type_parameters,
    STATE(5451), 1,
      sym__call_signature,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [142727] = 4,
    STATE(3834), 1,
      aux_sym_object_type_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3768), 2,
      anon_sym_RBRACE,
      anon_sym_PIPE_RBRACE,
    ACTIONS(7488), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [142744] = 7,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(6509), 1,
      anon_sym_LPAREN,
    ACTIONS(7498), 1,
      anon_sym_QMARK,
    STATE(3330), 1,
      sym_formal_parameters,
    STATE(3759), 1,
      sym__call_signature,
    STATE(5249), 1,
      sym_type_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [142767] = 4,
    STATE(3834), 1,
      aux_sym_object_type_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3764), 2,
      anon_sym_RBRACE,
      anon_sym_PIPE_RBRACE,
    ACTIONS(7306), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [142784] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(2377), 6,
      anon_sym_as,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_extends,
  [142797] = 4,
    ACTIONS(7242), 1,
      anon_sym_LBRACE,
    STATE(2659), 1,
      sym_statement_block,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7163), 4,
      sym__automatic_semicolon,
      sym__function_signature_automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [142814] = 7,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(6453), 1,
      anon_sym_LPAREN,
    ACTIONS(7500), 1,
      sym_identifier,
    STATE(3806), 1,
      sym_formal_parameters,
    STATE(5328), 1,
      sym_type_parameters,
    STATE(5429), 1,
      sym__call_signature,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [142837] = 4,
    ACTIONS(7242), 1,
      anon_sym_LBRACE,
    STATE(2669), 1,
      sym_statement_block,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7085), 4,
      sym__automatic_semicolon,
      sym__function_signature_automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [142854] = 4,
    STATE(3834), 1,
      aux_sym_object_type_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3776), 2,
      anon_sym_RBRACE,
      anon_sym_PIPE_RBRACE,
    ACTIONS(7502), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [142871] = 7,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(6453), 1,
      anon_sym_LPAREN,
    ACTIONS(7504), 1,
      anon_sym_QMARK,
    STATE(3806), 1,
      sym_formal_parameters,
    STATE(5128), 1,
      sym__call_signature,
    STATE(5328), 1,
      sym_type_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [142894] = 7,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(6509), 1,
      anon_sym_LPAREN,
    ACTIONS(7506), 1,
      anon_sym_QMARK,
    STATE(3330), 1,
      sym_formal_parameters,
    STATE(3839), 1,
      sym__call_signature,
    STATE(5249), 1,
      sym_type_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [142917] = 5,
    ACTIONS(3275), 1,
      anon_sym_LBRACE,
    ACTIONS(7316), 1,
      anon_sym_LBRACK,
    ACTIONS(7508), 1,
      sym_identifier,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    STATE(4431), 3,
      sym_object_pattern,
      sym_array_pattern,
      sym__destructuring_pattern,
  [142936] = 4,
    ACTIONS(7242), 1,
      anon_sym_LBRACE,
    STATE(2693), 1,
      sym_statement_block,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7223), 4,
      sym__automatic_semicolon,
      sym__function_signature_automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [142953] = 5,
    ACTIONS(7510), 1,
      anon_sym_BQUOTE,
    ACTIONS(7512), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(7514), 1,
      sym__template_chars,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    STATE(4136), 2,
      sym_template_type,
      aux_sym_template_literal_type_repeat1,
  [142971] = 4,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    STATE(4798), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7516), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [142987] = 5,
    ACTIONS(7518), 1,
      sym_identifier,
    ACTIONS(7520), 1,
      anon_sym_LPAREN,
    STATE(2711), 1,
      sym_decorator_member_expression,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    STATE(2806), 2,
      sym_decorator_call_expression,
      sym_decorator_parenthesized_expression,
  [143005] = 4,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    STATE(4559), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7522), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [143021] = 4,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    STATE(5109), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7524), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [143037] = 6,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(3281), 1,
      anon_sym_LPAREN,
    STATE(3315), 1,
      sym_formal_parameters,
    STATE(4251), 1,
      sym__call_signature,
    STATE(5233), 1,
      sym_type_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [143057] = 4,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    STATE(4743), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7524), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [143073] = 4,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    STATE(4572), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7522), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [143089] = 4,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    STATE(4823), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7526), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [143105] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7528), 5,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACE,
  [143117] = 4,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    STATE(4582), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7522), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [143133] = 4,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    STATE(4954), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7526), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [143149] = 4,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    STATE(4585), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7522), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [143165] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(5223), 5,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_QMARK,
  [143177] = 4,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    STATE(4589), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7530), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [143193] = 4,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    STATE(4592), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7530), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [143209] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7085), 5,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACE,
  [143221] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7347), 5,
      sym__automatic_semicolon,
      sym__function_signature_automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [143233] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7454), 5,
      sym__automatic_semicolon,
      sym__function_signature_automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [143245] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7532), 5,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACE,
  [143257] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7490), 5,
      sym__automatic_semicolon,
      sym__function_signature_automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [143269] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(5231), 5,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_QMARK,
  [143281] = 5,
    ACTIONS(7512), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(7534), 1,
      anon_sym_BQUOTE,
    ACTIONS(7536), 1,
      sym__template_chars,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    STATE(3901), 2,
      sym_template_type,
      aux_sym_template_literal_type_repeat1,
  [143299] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(5231), 5,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_QMARK,
  [143311] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(2901), 5,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACE,
  [143323] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(2561), 5,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACE,
  [143335] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(2561), 5,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACE,
  [143347] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(2969), 5,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACE,
  [143359] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(2977), 5,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACE,
  [143371] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(5231), 5,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_QMARK,
  [143383] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(1842), 5,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACE,
  [143395] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(2561), 5,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACE,
  [143407] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(2561), 5,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACE,
  [143419] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(2561), 5,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACE,
  [143431] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(2561), 5,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACE,
  [143443] = 4,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    STATE(4608), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7522), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [143459] = 4,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    STATE(4612), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7522), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [143475] = 4,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    STATE(4613), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7530), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [143491] = 6,
    ACTIONS(3814), 1,
      anon_sym_COLON,
    ACTIONS(4622), 1,
      anon_sym_EQ,
    ACTIONS(5060), 1,
      anon_sym_COMMA,
    ACTIONS(7538), 1,
      anon_sym_RBRACE,
    STATE(4815), 1,
      aux_sym_object_pattern_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [143511] = 4,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    STATE(4614), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7530), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [143527] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4854), 5,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_in,
      anon_sym_of,
      anon_sym_COLON,
  [143539] = 4,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    STATE(4615), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7530), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [143555] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(2629), 5,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACE,
  [143567] = 6,
    ACTIONS(4336), 1,
      anon_sym_LBRACE,
    ACTIONS(7540), 1,
      anon_sym_SEMI,
    ACTIONS(7542), 1,
      sym__automatic_semicolon,
    ACTIONS(7544), 1,
      sym__function_signature_automatic_semicolon,
    STATE(2199), 1,
      sym_statement_block,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [143587] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(2641), 5,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACE,
  [143599] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(2657), 5,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACE,
  [143611] = 4,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    STATE(4616), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7530), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [143627] = 4,
    ACTIONS(7268), 1,
      anon_sym_COLON,
    ACTIONS(7546), 1,
      anon_sym_EQ_GT,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    STATE(5306), 3,
      sym_type_annotation,
      sym_asserts_annotation,
      sym_type_predicate_annotation,
  [143643] = 4,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    STATE(4623), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7522), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [143659] = 4,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    STATE(4624), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7530), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [143675] = 6,
    ACTIONS(1034), 1,
      anon_sym_LBRACE_PIPE,
    ACTIONS(1610), 1,
      anon_sym_LBRACE,
    ACTIONS(7191), 1,
      anon_sym_extends,
    STATE(3984), 1,
      sym_object_type,
    STATE(4643), 1,
      sym_extends_type_clause,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [143695] = 4,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    STATE(4626), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7530), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [143711] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(2839), 5,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACE,
  [143723] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(2839), 5,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACE,
  [143735] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(2839), 5,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACE,
  [143747] = 4,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    STATE(4640), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7522), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [143763] = 4,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    STATE(4535), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7524), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [143779] = 4,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    STATE(4652), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7522), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [143795] = 4,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    STATE(4655), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7530), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [143811] = 4,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    STATE(4659), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7530), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [143827] = 6,
    ACTIONS(7065), 1,
      anon_sym_LBRACE,
    ACTIONS(7549), 1,
      anon_sym_SEMI,
    ACTIONS(7551), 1,
      sym__automatic_semicolon,
    ACTIONS(7553), 1,
      sym__function_signature_automatic_semicolon,
    STATE(3981), 1,
      sym_statement_block,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [143847] = 5,
    ACTIONS(6698), 1,
      anon_sym_AMP,
    ACTIONS(6702), 1,
      anon_sym_extends,
    ACTIONS(7557), 1,
      anon_sym_PIPE,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7555), 2,
      sym__automatic_semicolon,
      anon_sym_SEMI,
  [143865] = 4,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    STATE(4667), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7522), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [143881] = 6,
    ACTIONS(4336), 1,
      anon_sym_LBRACE,
    ACTIONS(7559), 1,
      anon_sym_SEMI,
    ACTIONS(7561), 1,
      sym__automatic_semicolon,
    ACTIONS(7563), 1,
      sym__function_signature_automatic_semicolon,
    STATE(2165), 1,
      sym_statement_block,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [143901] = 4,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    STATE(4858), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7524), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [143917] = 4,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    STATE(4682), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7522), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [143933] = 4,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    STATE(4945), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7524), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [143949] = 4,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    STATE(4947), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7526), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [143965] = 4,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    STATE(4694), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7522), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [143981] = 4,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    STATE(4948), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7526), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [143997] = 4,
    ACTIONS(7268), 1,
      anon_sym_COLON,
    ACTIONS(7565), 1,
      anon_sym_EQ_GT,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    STATE(5306), 3,
      sym_type_annotation,
      sym_asserts_annotation,
      sym_type_predicate_annotation,
  [144013] = 4,
    ACTIONS(7268), 1,
      anon_sym_COLON,
    ACTIONS(7568), 1,
      anon_sym_EQ_GT,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    STATE(5199), 3,
      sym_type_annotation,
      sym_asserts_annotation,
      sym_type_predicate_annotation,
  [144029] = 4,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    STATE(4702), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7522), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [144045] = 4,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    STATE(4703), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7530), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [144061] = 4,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    STATE(4705), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7530), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [144077] = 6,
    ACTIONS(7571), 1,
      anon_sym_EQ,
    ACTIONS(7573), 1,
      anon_sym_COMMA,
    ACTIONS(7575), 1,
      anon_sym_RBRACE,
    STATE(4712), 1,
      aux_sym_enum_body_repeat1,
    STATE(5290), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [144097] = 4,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    STATE(4953), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7526), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [144113] = 4,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    STATE(4717), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7522), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [144129] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(2553), 5,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACE,
  [144141] = 6,
    ACTIONS(7065), 1,
      anon_sym_LBRACE,
    ACTIONS(7577), 1,
      anon_sym_SEMI,
    ACTIONS(7579), 1,
      sym__automatic_semicolon,
    ACTIONS(7581), 1,
      sym__function_signature_automatic_semicolon,
    STATE(3997), 1,
      sym_statement_block,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [144161] = 3,
    ACTIONS(5318), 1,
      sym__automatic_semicolon,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(1810), 4,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACE,
  [144175] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(2675), 5,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACE,
  [144187] = 5,
    ACTIONS(6698), 1,
      anon_sym_AMP,
    ACTIONS(6702), 1,
      anon_sym_extends,
    ACTIONS(7557), 1,
      anon_sym_PIPE,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7583), 2,
      sym__automatic_semicolon,
      anon_sym_SEMI,
  [144205] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(2737), 5,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACE,
  [144217] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(2741), 5,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACE,
  [144229] = 6,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(3281), 1,
      anon_sym_LPAREN,
    STATE(3315), 1,
      sym_formal_parameters,
    STATE(3521), 1,
      sym__call_signature,
    STATE(5233), 1,
      sym_type_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [144249] = 6,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(6509), 1,
      anon_sym_LPAREN,
    STATE(3330), 1,
      sym_formal_parameters,
    STATE(4355), 1,
      sym__call_signature,
    STATE(5249), 1,
      sym_type_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [144269] = 4,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    STATE(4970), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7526), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [144285] = 4,
    ACTIONS(7268), 1,
      anon_sym_COLON,
    ACTIONS(7585), 1,
      anon_sym_EQ_GT,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    STATE(5199), 3,
      sym_type_annotation,
      sym_asserts_annotation,
      sym_type_predicate_annotation,
  [144301] = 4,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    STATE(4722), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7522), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [144317] = 4,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    STATE(4723), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7530), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [144333] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(2749), 5,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACE,
  [144345] = 4,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    STATE(4724), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7530), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [144361] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(2809), 5,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACE,
  [144373] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(2809), 5,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACE,
  [144385] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(2829), 5,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACE,
  [144397] = 3,
    ACTIONS(5322), 1,
      sym__automatic_semicolon,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(1770), 4,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACE,
  [144411] = 3,
    ACTIONS(5324), 1,
      sym__automatic_semicolon,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(1780), 4,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACE,
  [144425] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(1790), 5,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACE,
  [144437] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(1800), 5,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACE,
  [144449] = 6,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(3281), 1,
      anon_sym_LPAREN,
    STATE(3315), 1,
      sym_formal_parameters,
    STATE(3598), 1,
      sym__call_signature,
    STATE(5233), 1,
      sym_type_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [144469] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(1706), 5,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACE,
  [144481] = 4,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    STATE(4867), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7588), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [144497] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(2857), 5,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACE,
  [144509] = 5,
    ACTIONS(6698), 1,
      anon_sym_AMP,
    ACTIONS(6702), 1,
      anon_sym_extends,
    ACTIONS(7557), 1,
      anon_sym_PIPE,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7590), 2,
      sym__automatic_semicolon,
      anon_sym_SEMI,
  [144527] = 4,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    STATE(4725), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7530), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [144543] = 3,
    ACTIONS(5328), 1,
      sym__automatic_semicolon,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(1856), 4,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACE,
  [144557] = 4,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    STATE(4726), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7530), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [144573] = 6,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(3281), 1,
      anon_sym_LPAREN,
    STATE(3315), 1,
      sym_formal_parameters,
    STATE(3749), 1,
      sym__call_signature,
    STATE(5233), 1,
      sym_type_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [144593] = 6,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(3281), 1,
      anon_sym_LPAREN,
    STATE(3315), 1,
      sym_formal_parameters,
    STATE(3631), 1,
      sym__call_signature,
    STATE(5233), 1,
      sym_type_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [144613] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(2909), 5,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACE,
  [144625] = 6,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(3281), 1,
      anon_sym_LPAREN,
    STATE(3315), 1,
      sym_formal_parameters,
    STATE(3637), 1,
      sym__call_signature,
    STATE(5233), 1,
      sym_type_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [144645] = 6,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(3281), 1,
      anon_sym_LPAREN,
    STATE(3315), 1,
      sym_formal_parameters,
    STATE(3649), 1,
      sym__call_signature,
    STATE(5233), 1,
      sym_type_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [144665] = 4,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    STATE(4731), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7522), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [144681] = 4,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    STATE(4732), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7530), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [144697] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(2699), 5,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACE,
  [144709] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(2699), 5,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACE,
  [144721] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(2699), 5,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACE,
  [144733] = 4,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    STATE(4737), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7530), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [144749] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(2861), 5,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACE,
  [144761] = 4,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    STATE(4738), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7530), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [144777] = 4,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    STATE(4739), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7530), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [144793] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7153), 5,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACE,
  [144805] = 6,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(3281), 1,
      anon_sym_LPAREN,
    STATE(3315), 1,
      sym_formal_parameters,
    STATE(4177), 1,
      sym__call_signature,
    STATE(5233), 1,
      sym_type_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [144825] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7151), 5,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACE,
  [144837] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7153), 5,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACE,
  [144849] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7592), 5,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACE,
  [144861] = 4,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    STATE(4522), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7524), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [144877] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7151), 5,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACE,
  [144889] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7594), 5,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACE,
  [144901] = 6,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(6453), 1,
      anon_sym_LPAREN,
    STATE(3806), 1,
      sym_formal_parameters,
    STATE(5328), 1,
      sym_type_parameters,
    STATE(5391), 1,
      sym__call_signature,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [144921] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(2943), 5,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACE,
  [144933] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(2949), 5,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACE,
  [144945] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(2957), 5,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACE,
  [144957] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(2965), 5,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACE,
  [144969] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(2865), 5,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACE,
  [144981] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7085), 5,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACE,
  [144993] = 6,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(6453), 1,
      anon_sym_LPAREN,
    STATE(3806), 1,
      sym_formal_parameters,
    STATE(5228), 1,
      sym__call_signature,
    STATE(5328), 1,
      sym_type_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [145013] = 6,
    ACTIONS(1678), 1,
      anon_sym_LBRACE,
    ACTIONS(7559), 1,
      anon_sym_SEMI,
    ACTIONS(7561), 1,
      sym__automatic_semicolon,
    ACTIONS(7563), 1,
      sym__function_signature_automatic_semicolon,
    STATE(222), 1,
      sym_statement_block,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [145033] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(2719), 5,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACE,
  [145045] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(2719), 5,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACE,
  [145057] = 6,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(6509), 1,
      anon_sym_LPAREN,
    STATE(3330), 1,
      sym_formal_parameters,
    STATE(3893), 1,
      sym__call_signature,
    STATE(5249), 1,
      sym_type_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [145077] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(2869), 5,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACE,
  [145089] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(1758), 5,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACE,
  [145101] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(1820), 5,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACE,
  [145113] = 5,
    ACTIONS(7512), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(7596), 1,
      anon_sym_BQUOTE,
    ACTIONS(7598), 1,
      sym__template_chars,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    STATE(4057), 2,
      sym_template_type,
      aux_sym_template_literal_type_repeat1,
  [145131] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(1830), 5,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACE,
  [145143] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(2917), 5,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACE,
  [145155] = 4,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    STATE(4557), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7524), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [145171] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7600), 5,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACE,
  [145183] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7602), 5,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACE,
  [145195] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7604), 5,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACE,
  [145207] = 6,
    ACTIONS(4336), 1,
      anon_sym_LBRACE,
    ACTIONS(7549), 1,
      anon_sym_SEMI,
    ACTIONS(7551), 1,
      sym__automatic_semicolon,
    ACTIONS(7553), 1,
      sym__function_signature_automatic_semicolon,
    STATE(2182), 1,
      sym_statement_block,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [145227] = 4,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    STATE(4748), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7606), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [145243] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7083), 5,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACE,
  [145255] = 4,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    STATE(4750), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7608), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [145271] = 5,
    ACTIONS(7512), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(7514), 1,
      sym__template_chars,
    ACTIONS(7610), 1,
      anon_sym_BQUOTE,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    STATE(4136), 2,
      sym_template_type,
      aux_sym_template_literal_type_repeat1,
  [145289] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7612), 5,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACE,
  [145301] = 4,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    STATE(4837), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7614), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [145317] = 4,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    STATE(4670), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7614), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [145333] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(2775), 5,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACE,
  [145345] = 6,
    ACTIONS(4336), 1,
      anon_sym_LBRACE,
    ACTIONS(7577), 1,
      anon_sym_SEMI,
    ACTIONS(7579), 1,
      sym__automatic_semicolon,
    ACTIONS(7581), 1,
      sym__function_signature_automatic_semicolon,
    STATE(2186), 1,
      sym_statement_block,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [145365] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(2783), 5,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACE,
  [145377] = 4,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    STATE(4751), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7616), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [145393] = 4,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    STATE(4752), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7616), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [145409] = 4,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    STATE(4753), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7616), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [145425] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(2797), 5,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACE,
  [145437] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(2801), 5,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACE,
  [145449] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(2813), 5,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACE,
  [145461] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(2835), 5,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACE,
  [145473] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(2921), 5,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACE,
  [145485] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(2723), 5,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACE,
  [145497] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(2585), 5,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACE,
  [145509] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(1866), 5,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACE,
  [145521] = 4,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    STATE(4755), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7616), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [145537] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7618), 5,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACE,
  [145549] = 4,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    STATE(4758), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7620), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [145565] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(2707), 5,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACE,
  [145577] = 4,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    STATE(4760), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7616), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [145593] = 4,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    STATE(4761), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7616), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [145609] = 4,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    STATE(4762), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7616), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [145625] = 4,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    STATE(4763), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7616), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [145641] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7223), 5,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACE,
  [145653] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7622), 5,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACE,
  [145665] = 5,
    ACTIONS(7512), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(7624), 1,
      anon_sym_BQUOTE,
    ACTIONS(7626), 1,
      sym__template_chars,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    STATE(4092), 2,
      sym_template_type,
      aux_sym_template_literal_type_repeat1,
  [145683] = 4,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    STATE(4764), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7616), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [145699] = 4,
    ACTIONS(7268), 1,
      anon_sym_COLON,
    ACTIONS(7628), 1,
      anon_sym_EQ_GT,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    STATE(5306), 3,
      sym_type_annotation,
      sym_asserts_annotation,
      sym_type_predicate_annotation,
  [145715] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(2771), 5,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACE,
  [145727] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(2787), 5,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACE,
  [145739] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(2791), 5,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACE,
  [145751] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(2825), 5,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACE,
  [145763] = 5,
    ACTIONS(7512), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(7514), 1,
      sym__template_chars,
    ACTIONS(7631), 1,
      anon_sym_BQUOTE,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    STATE(4136), 2,
      sym_template_type,
      aux_sym_template_literal_type_repeat1,
  [145781] = 4,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    STATE(4765), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7616), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [145797] = 6,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(6509), 1,
      anon_sym_LPAREN,
    STATE(3330), 1,
      sym_formal_parameters,
    STATE(3756), 1,
      sym__call_signature,
    STATE(5249), 1,
      sym_type_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [145817] = 4,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    STATE(4769), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7620), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [145833] = 4,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    STATE(4770), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7616), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [145849] = 4,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    STATE(4771), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7616), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [145865] = 4,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    STATE(4633), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7524), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [145881] = 4,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    STATE(4786), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7620), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [145897] = 4,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    STATE(5031), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7633), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [145913] = 4,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    STATE(4793), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7620), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [145929] = 4,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    STATE(4794), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7616), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [145945] = 4,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    STATE(4795), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7616), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [145961] = 5,
    ACTIONS(6698), 1,
      anon_sym_AMP,
    ACTIONS(6702), 1,
      anon_sym_extends,
    ACTIONS(7557), 1,
      anon_sym_PIPE,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7635), 2,
      sym__automatic_semicolon,
      anon_sym_SEMI,
  [145979] = 4,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    STATE(4800), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7620), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [145995] = 4,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    STATE(4801), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7616), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [146011] = 5,
    ACTIONS(7512), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(7637), 1,
      anon_sym_BQUOTE,
    ACTIONS(7639), 1,
      sym__template_chars,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    STATE(4112), 2,
      sym_template_type,
      aux_sym_template_literal_type_repeat1,
  [146029] = 5,
    ACTIONS(7512), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(7514), 1,
      sym__template_chars,
    ACTIONS(7641), 1,
      anon_sym_BQUOTE,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    STATE(4136), 2,
      sym_template_type,
      aux_sym_template_literal_type_repeat1,
  [146047] = 4,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    STATE(4803), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7616), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [146063] = 4,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    STATE(4804), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7616), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [146079] = 4,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    STATE(4809), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7616), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [146095] = 5,
    ACTIONS(7512), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(7514), 1,
      sym__template_chars,
    ACTIONS(7643), 1,
      anon_sym_BQUOTE,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    STATE(4136), 2,
      sym_template_type,
      aux_sym_template_literal_type_repeat1,
  [146113] = 4,
    STATE(5437), 1,
      sym_import_attribute,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7645), 2,
      anon_sym_with,
      anon_sym_assert,
    ACTIONS(7647), 2,
      sym__automatic_semicolon,
      anon_sym_SEMI,
  [146129] = 4,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    STATE(4719), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7524), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [146145] = 4,
    ACTIONS(3557), 1,
      anon_sym_COLON,
    STATE(5159), 1,
      sym_type_annotation,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3622), 3,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_RBRACK,
  [146161] = 4,
    ACTIONS(7268), 1,
      anon_sym_COLON,
    ACTIONS(7649), 1,
      anon_sym_EQ_GT,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    STATE(5306), 3,
      sym_type_annotation,
      sym_asserts_annotation,
      sym_type_predicate_annotation,
  [146177] = 4,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    STATE(4818), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7620), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [146193] = 4,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    STATE(4819), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7616), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [146209] = 4,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    STATE(4820), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7616), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [146225] = 4,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    STATE(4821), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7616), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [146241] = 4,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    STATE(4824), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7616), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [146257] = 4,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    STATE(4826), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7616), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [146273] = 4,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    STATE(4831), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7616), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [146289] = 4,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    STATE(4772), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7524), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [146305] = 4,
    ACTIONS(7268), 1,
      anon_sym_COLON,
    ACTIONS(7652), 1,
      anon_sym_EQ_GT,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    STATE(5199), 3,
      sym_type_annotation,
      sym_asserts_annotation,
      sym_type_predicate_annotation,
  [146321] = 4,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    STATE(4835), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7620), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [146337] = 4,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    STATE(4836), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7616), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [146353] = 4,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    STATE(4838), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7616), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [146369] = 5,
    ACTIONS(6605), 1,
      anon_sym_AMP,
    ACTIONS(6607), 1,
      anon_sym_PIPE,
    ACTIONS(6609), 1,
      anon_sym_extends,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7655), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK,
  [146387] = 4,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    STATE(4839), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7616), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [146403] = 4,
    STATE(5309), 1,
      sym_import_attribute,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7645), 2,
      anon_sym_with,
      anon_sym_assert,
    ACTIONS(7657), 2,
      sym__automatic_semicolon,
      anon_sym_SEMI,
  [146419] = 5,
    ACTIONS(1550), 1,
      anon_sym_DQUOTE,
    ACTIONS(1552), 1,
      anon_sym_SQUOTE,
    ACTIONS(7659), 1,
      sym_identifier,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    STATE(5863), 2,
      sym__module_export_name,
      sym_string,
  [146437] = 4,
    ACTIONS(6373), 1,
      anon_sym_LBRACK,
    ACTIONS(7661), 1,
      anon_sym_RBRACE,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4172), 3,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_extends,
  [146453] = 4,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    STATE(4840), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7616), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [146469] = 4,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    STATE(4776), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7526), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [146485] = 5,
    ACTIONS(7663), 1,
      anon_sym_BQUOTE,
    ACTIONS(7665), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(7668), 1,
      sym__template_chars,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    STATE(4136), 2,
      sym_template_type,
      aux_sym_template_literal_type_repeat1,
  [146503] = 5,
    ACTIONS(6605), 1,
      anon_sym_AMP,
    ACTIONS(6607), 1,
      anon_sym_PIPE,
    ACTIONS(6609), 1,
      anon_sym_extends,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7671), 2,
      anon_sym_COMMA,
      anon_sym_GT,
  [146521] = 4,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    STATE(4845), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7620), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [146537] = 4,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    STATE(4846), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7616), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [146553] = 4,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    STATE(4847), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7616), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [146569] = 4,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    STATE(4781), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7526), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [146585] = 4,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    STATE(4854), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7620), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [146601] = 5,
    ACTIONS(6682), 1,
      anon_sym_LT,
    ACTIONS(7673), 1,
      anon_sym_LBRACE,
    STATE(5076), 1,
      sym_type_arguments,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7675), 2,
      anon_sym_COMMA,
      anon_sym_LBRACE_PIPE,
  [146619] = 4,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    STATE(4861), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7620), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [146635] = 4,
    ACTIONS(6337), 1,
      anon_sym_DOT,
    ACTIONS(7677), 1,
      sym_identifier,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6335), 3,
      anon_sym_LPAREN,
      anon_sym_QMARK_DOT,
      anon_sym_LT,
  [146651] = 4,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    STATE(4862), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7616), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [146667] = 6,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(6509), 1,
      anon_sym_LPAREN,
    STATE(3330), 1,
      sym_formal_parameters,
    STATE(3944), 1,
      sym__call_signature,
    STATE(5249), 1,
      sym_type_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [146687] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7679), 5,
      anon_sym_EQ,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_extends,
      anon_sym_implements,
  [146699] = 4,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    STATE(4865), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7616), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [146715] = 6,
    ACTIONS(97), 1,
      anon_sym_AT,
    ACTIONS(7282), 1,
      anon_sym_class,
    ACTIONS(7284), 1,
      anon_sym_abstract,
    STATE(1269), 1,
      aux_sym_export_statement_repeat1,
    STATE(1344), 1,
      sym_decorator,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [146735] = 6,
    ACTIONS(7571), 1,
      anon_sym_EQ,
    ACTIONS(7681), 1,
      anon_sym_COMMA,
    ACTIONS(7683), 1,
      anon_sym_RBRACE,
    STATE(4962), 1,
      aux_sym_enum_body_repeat1,
    STATE(5290), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [146755] = 4,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    STATE(4871), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7620), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [146771] = 6,
    ACTIONS(97), 1,
      anon_sym_AT,
    ACTIONS(7284), 1,
      anon_sym_abstract,
    ACTIONS(7393), 1,
      anon_sym_class,
    STATE(1269), 1,
      aux_sym_export_statement_repeat1,
    STATE(1344), 1,
      sym_decorator,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [146791] = 6,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(6509), 1,
      anon_sym_LPAREN,
    STATE(3330), 1,
      sym_formal_parameters,
    STATE(3961), 1,
      sym__call_signature,
    STATE(5249), 1,
      sym_type_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [146811] = 4,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    STATE(4872), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7616), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [146827] = 4,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    STATE(4873), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7616), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [146843] = 6,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(6453), 1,
      anon_sym_LPAREN,
    STATE(3806), 1,
      sym_formal_parameters,
    STATE(5150), 1,
      sym__call_signature,
    STATE(5328), 1,
      sym_type_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [146863] = 4,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    STATE(4874), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7616), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [146879] = 4,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    STATE(4875), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7616), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [146895] = 6,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(6509), 1,
      anon_sym_LPAREN,
    STATE(3330), 1,
      sym_formal_parameters,
    STATE(3964), 1,
      sym__call_signature,
    STATE(5249), 1,
      sym_type_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [146915] = 6,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(6453), 1,
      anon_sym_LPAREN,
    STATE(3806), 1,
      sym_formal_parameters,
    STATE(5224), 1,
      sym__call_signature,
    STATE(5328), 1,
      sym_type_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [146935] = 4,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    STATE(4827), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7524), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [146951] = 5,
    ACTIONS(3109), 1,
      anon_sym_DQUOTE,
    ACTIONS(3111), 1,
      anon_sym_SQUOTE,
    ACTIONS(7685), 1,
      sym_identifier,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    STATE(4881), 2,
      sym__module_export_name,
      sym_string,
  [146969] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7687), 5,
      anon_sym_EQ,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_extends,
      anon_sym_implements,
  [146981] = 4,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    STATE(4886), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7616), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [146997] = 4,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    STATE(4888), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7616), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [147013] = 4,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    STATE(4889), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7616), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [147029] = 4,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    STATE(4892), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7616), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [147045] = 4,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    STATE(4893), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7616), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [147061] = 4,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    STATE(4895), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7616), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [147077] = 6,
    ACTIONS(3814), 1,
      anon_sym_COLON,
    ACTIONS(4622), 1,
      anon_sym_EQ,
    ACTIONS(5060), 1,
      anon_sym_COMMA,
    ACTIONS(7689), 1,
      anon_sym_RBRACE,
    STATE(4802), 1,
      aux_sym_object_pattern_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [147097] = 6,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(6509), 1,
      anon_sym_LPAREN,
    STATE(3330), 1,
      sym_formal_parameters,
    STATE(3980), 1,
      sym__call_signature,
    STATE(5249), 1,
      sym_type_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [147117] = 6,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(6453), 1,
      anon_sym_LPAREN,
    STATE(3806), 1,
      sym_formal_parameters,
    STATE(5212), 1,
      sym__call_signature,
    STATE(5328), 1,
      sym_type_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [147137] = 6,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(6453), 1,
      anon_sym_LPAREN,
    STATE(3806), 1,
      sym_formal_parameters,
    STATE(5216), 1,
      sym__call_signature,
    STATE(5328), 1,
      sym_type_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [147157] = 6,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(6453), 1,
      anon_sym_LPAREN,
    STATE(3806), 1,
      sym_formal_parameters,
    STATE(5220), 1,
      sym__call_signature,
    STATE(5328), 1,
      sym_type_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [147177] = 6,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(6453), 1,
      anon_sym_LPAREN,
    STATE(3806), 1,
      sym_formal_parameters,
    STATE(5241), 1,
      sym__call_signature,
    STATE(5328), 1,
      sym_type_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [147197] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7155), 5,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACE,
  [147209] = 6,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(3281), 1,
      anon_sym_LPAREN,
    STATE(3315), 1,
      sym_formal_parameters,
    STATE(4252), 1,
      sym__call_signature,
    STATE(5233), 1,
      sym_type_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [147229] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7157), 5,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACE,
  [147241] = 5,
    ACTIONS(1550), 1,
      anon_sym_DQUOTE,
    ACTIONS(1552), 1,
      anon_sym_SQUOTE,
    ACTIONS(7691), 1,
      sym_identifier,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    STATE(5307), 2,
      sym__module_export_name,
      sym_string,
  [147259] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7155), 5,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACE,
  [147271] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7693), 5,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACE,
  [147283] = 4,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    STATE(4842), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7524), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [147299] = 6,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(6453), 1,
      anon_sym_LPAREN,
    STATE(3806), 1,
      sym_formal_parameters,
    STATE(5328), 1,
      sym_type_parameters,
    STATE(5363), 1,
      sym__call_signature,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [147319] = 6,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(6453), 1,
      anon_sym_LPAREN,
    STATE(3806), 1,
      sym_formal_parameters,
    STATE(5328), 1,
      sym_type_parameters,
    STATE(5366), 1,
      sym__call_signature,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [147339] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7695), 5,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACE,
  [147351] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7697), 5,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACE,
  [147363] = 4,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    STATE(4898), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7699), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [147379] = 6,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(6509), 1,
      anon_sym_LPAREN,
    STATE(3330), 1,
      sym_formal_parameters,
    STATE(3770), 1,
      sym__call_signature,
    STATE(5249), 1,
      sym_type_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [147399] = 6,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(6453), 1,
      anon_sym_LPAREN,
    STATE(3806), 1,
      sym_formal_parameters,
    STATE(5310), 1,
      sym__call_signature,
    STATE(5328), 1,
      sym_type_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [147419] = 6,
    ACTIONS(7065), 1,
      anon_sym_LBRACE,
    ACTIONS(7559), 1,
      anon_sym_SEMI,
    ACTIONS(7561), 1,
      sym__automatic_semicolon,
    ACTIONS(7563), 1,
      sym__function_signature_automatic_semicolon,
    STATE(799), 1,
      sym_statement_block,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [147439] = 4,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    STATE(4844), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7526), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [147455] = 6,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(6453), 1,
      anon_sym_LPAREN,
    STATE(3806), 1,
      sym_formal_parameters,
    STATE(5328), 1,
      sym_type_parameters,
    STATE(5424), 1,
      sym__call_signature,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [147475] = 4,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    STATE(4900), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7701), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [147491] = 4,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    STATE(4901), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7701), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [147507] = 6,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(6453), 1,
      anon_sym_LPAREN,
    STATE(3806), 1,
      sym_formal_parameters,
    STATE(5328), 1,
      sym_type_parameters,
    STATE(5447), 1,
      sym__call_signature,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [147527] = 6,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(6453), 1,
      anon_sym_LPAREN,
    STATE(3806), 1,
      sym_formal_parameters,
    STATE(5127), 1,
      sym__call_signature,
    STATE(5328), 1,
      sym_type_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [147547] = 4,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    STATE(4902), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7701), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [147563] = 4,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    STATE(4903), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7701), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [147579] = 6,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(6453), 1,
      anon_sym_LPAREN,
    STATE(3806), 1,
      sym_formal_parameters,
    STATE(5135), 1,
      sym__call_signature,
    STATE(5328), 1,
      sym_type_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [147599] = 6,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(6509), 1,
      anon_sym_LPAREN,
    STATE(3330), 1,
      sym_formal_parameters,
    STATE(4250), 1,
      sym__call_signature,
    STATE(5249), 1,
      sym_type_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [147619] = 5,
    ACTIONS(6698), 1,
      anon_sym_AMP,
    ACTIONS(6702), 1,
      anon_sym_extends,
    ACTIONS(7557), 1,
      anon_sym_PIPE,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7703), 2,
      sym__automatic_semicolon,
      anon_sym_SEMI,
  [147637] = 6,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(6453), 1,
      anon_sym_LPAREN,
    STATE(3806), 1,
      sym_formal_parameters,
    STATE(5315), 1,
      sym__call_signature,
    STATE(5328), 1,
      sym_type_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [147657] = 4,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    STATE(4850), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7526), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [147673] = 4,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    STATE(4909), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7705), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [147689] = 4,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    STATE(4911), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7701), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [147705] = 6,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(6453), 1,
      anon_sym_LPAREN,
    STATE(3806), 1,
      sym_formal_parameters,
    STATE(5324), 1,
      sym__call_signature,
    STATE(5328), 1,
      sym_type_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [147725] = 6,
    ACTIONS(218), 1,
      anon_sym_LBRACE_PIPE,
    ACTIONS(1534), 1,
      anon_sym_LBRACE,
    ACTIONS(7191), 1,
      anon_sym_extends,
    STATE(869), 1,
      sym_object_type,
    STATE(4688), 1,
      sym_extends_type_clause,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [147745] = 4,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    STATE(4912), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7701), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [147761] = 3,
    ACTIONS(4826), 1,
      anon_sym_in,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(5337), 4,
      anon_sym_LPAREN,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_QMARK,
  [147775] = 4,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    STATE(4913), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7701), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [147791] = 4,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    STATE(4914), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7701), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [147807] = 4,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    STATE(4915), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7701), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [147823] = 4,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    STATE(4916), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7701), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [147839] = 4,
    ACTIONS(7709), 1,
      anon_sym_in,
    ACTIONS(7711), 1,
      anon_sym_of,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7707), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [147855] = 4,
    ACTIONS(7713), 1,
      anon_sym_in,
    ACTIONS(7715), 1,
      anon_sym_of,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7707), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [147871] = 6,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(6509), 1,
      anon_sym_LPAREN,
    STATE(3330), 1,
      sym_formal_parameters,
    STATE(4053), 1,
      sym__call_signature,
    STATE(5249), 1,
      sym_type_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [147891] = 5,
    ACTIONS(7512), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(7717), 1,
      anon_sym_BQUOTE,
    ACTIONS(7719), 1,
      sym__template_chars,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    STATE(4108), 2,
      sym_template_type,
      aux_sym_template_literal_type_repeat1,
  [147909] = 4,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    STATE(4918), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7701), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [147925] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(5469), 5,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_QMARK,
  [147937] = 4,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    STATE(4919), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7701), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [147953] = 6,
    ACTIONS(97), 1,
      anon_sym_AT,
    ACTIONS(7721), 1,
      anon_sym_class,
    ACTIONS(7723), 1,
      anon_sym_abstract,
    STATE(1269), 1,
      aux_sym_export_statement_repeat1,
    STATE(1344), 1,
      sym_decorator,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [147973] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(5473), 5,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_QMARK,
  [147985] = 6,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(6509), 1,
      anon_sym_LPAREN,
    STATE(3330), 1,
      sym_formal_parameters,
    STATE(4062), 1,
      sym__call_signature,
    STATE(5249), 1,
      sym_type_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [148005] = 6,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(6453), 1,
      anon_sym_LPAREN,
    STATE(3806), 1,
      sym_formal_parameters,
    STATE(5328), 1,
      sym_type_parameters,
    STATE(5377), 1,
      sym__call_signature,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [148025] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(5473), 5,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_QMARK,
  [148037] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(5473), 5,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_QMARK,
  [148049] = 6,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(6509), 1,
      anon_sym_LPAREN,
    STATE(3330), 1,
      sym_formal_parameters,
    STATE(3885), 1,
      sym__call_signature,
    STATE(5249), 1,
      sym_type_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [148069] = 6,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(6453), 1,
      anon_sym_LPAREN,
    STATE(3806), 1,
      sym_formal_parameters,
    STATE(5328), 1,
      sym_type_parameters,
    STATE(5410), 1,
      sym__call_signature,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [148089] = 4,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    STATE(4920), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7701), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [148105] = 4,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    STATE(4921), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7701), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [148121] = 4,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    STATE(4922), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7701), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [148137] = 4,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    STATE(4923), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7701), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [148153] = 4,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    STATE(5017), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7725), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [148169] = 4,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    STATE(5049), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7727), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [148185] = 4,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    STATE(4928), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7705), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [148201] = 4,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    STATE(4929), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7701), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [148217] = 4,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    STATE(4931), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7701), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [148233] = 4,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    STATE(4932), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7701), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [148249] = 4,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    STATE(4933), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7701), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [148265] = 4,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    STATE(5065), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7729), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [148281] = 4,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    STATE(4934), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7701), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [148297] = 4,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    STATE(4936), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7701), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [148313] = 4,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    STATE(4937), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7701), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [148329] = 4,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    STATE(4938), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7701), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [148345] = 4,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    STATE(4517), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7731), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [148361] = 5,
    ACTIONS(1550), 1,
      anon_sym_DQUOTE,
    ACTIONS(1552), 1,
      anon_sym_SQUOTE,
    ACTIONS(7733), 1,
      sym_identifier,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    STATE(5385), 2,
      sym__module_export_name,
      sym_string,
  [148379] = 6,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(6509), 1,
      anon_sym_LPAREN,
    STATE(3330), 1,
      sym_formal_parameters,
    STATE(4191), 1,
      sym__call_signature,
    STATE(5249), 1,
      sym_type_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [148399] = 6,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(6453), 1,
      anon_sym_LPAREN,
    STATE(3806), 1,
      sym_formal_parameters,
    STATE(5328), 1,
      sym_type_parameters,
    STATE(5399), 1,
      sym__call_signature,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [148419] = 6,
    ACTIONS(7065), 1,
      anon_sym_LBRACE,
    ACTIONS(7540), 1,
      anon_sym_SEMI,
    ACTIONS(7542), 1,
      sym__automatic_semicolon,
    ACTIONS(7544), 1,
      sym__function_signature_automatic_semicolon,
    STATE(786), 1,
      sym_statement_block,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [148439] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7125), 5,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACE,
  [148451] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7163), 5,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACE,
  [148463] = 6,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(3281), 1,
      anon_sym_LPAREN,
    STATE(3315), 1,
      sym_formal_parameters,
    STATE(4271), 1,
      sym__call_signature,
    STATE(5233), 1,
      sym_type_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [148483] = 5,
    ACTIONS(6698), 1,
      anon_sym_AMP,
    ACTIONS(6702), 1,
      anon_sym_extends,
    ACTIONS(7557), 1,
      anon_sym_PIPE,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7735), 2,
      sym__automatic_semicolon,
      anon_sym_SEMI,
  [148501] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7169), 5,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACE,
  [148513] = 6,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(3281), 1,
      anon_sym_LPAREN,
    STATE(3315), 1,
      sym_formal_parameters,
    STATE(4294), 1,
      sym__call_signature,
    STATE(5233), 1,
      sym_type_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [148533] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7123), 5,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACE,
  [148545] = 6,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(3281), 1,
      anon_sym_LPAREN,
    STATE(3315), 1,
      sym_formal_parameters,
    STATE(4023), 1,
      sym__call_signature,
    STATE(5233), 1,
      sym_type_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [148565] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7737), 5,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACE,
  [148577] = 6,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(6453), 1,
      anon_sym_LPAREN,
    STATE(3806), 1,
      sym_formal_parameters,
    STATE(5328), 1,
      sym_type_parameters,
    STATE(5432), 1,
      sym__call_signature,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [148597] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7123), 5,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACE,
  [148609] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7739), 5,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACE,
  [148621] = 4,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    STATE(4940), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7741), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [148637] = 4,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    STATE(4941), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7741), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [148653] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7410), 5,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACE,
  [148665] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7133), 5,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACE,
  [148677] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7743), 5,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACE,
  [148689] = 4,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    STATE(4942), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7741), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [148705] = 4,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    STATE(4943), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7741), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [148721] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(1852), 5,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACE,
  [148733] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7183), 5,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACE,
  [148745] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7131), 5,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACE,
  [148757] = 6,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(6453), 1,
      anon_sym_LPAREN,
    STATE(3806), 1,
      sym_formal_parameters,
    STATE(5328), 1,
      sym_type_parameters,
    STATE(5448), 1,
      sym__call_signature,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [148777] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7125), 5,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACE,
  [148789] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(1730), 5,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACE,
  [148801] = 3,
    ACTIONS(7745), 1,
      anon_sym_EQ,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3586), 4,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_COLON,
      anon_sym_RBRACK,
  [148815] = 4,
    ACTIONS(7268), 1,
      anon_sym_COLON,
    ACTIONS(7747), 1,
      anon_sym_EQ_GT,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    STATE(5199), 3,
      sym_type_annotation,
      sym_asserts_annotation,
      sym_type_predicate_annotation,
  [148831] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7750), 5,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACE,
  [148843] = 6,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(6453), 1,
      anon_sym_LPAREN,
    STATE(3806), 1,
      sym_formal_parameters,
    STATE(5328), 1,
      sym_type_parameters,
    STATE(5450), 1,
      sym__call_signature,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [148863] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(1750), 5,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACE,
  [148875] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7752), 5,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACE,
  [148887] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7131), 5,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACE,
  [148899] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7754), 5,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACE,
  [148911] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7756), 5,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACE,
  [148923] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(5417), 5,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_QMARK,
  [148935] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(2893), 5,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACE,
  [148947] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(1730), 5,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACE,
  [148959] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7758), 5,
      anon_sym_EQ,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_extends,
      anon_sym_implements,
  [148971] = 5,
    ACTIONS(7760), 1,
      anon_sym_SEMI,
    ACTIONS(7762), 1,
      sym__automatic_semicolon,
    STATE(5398), 1,
      sym_import_attribute,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7645), 2,
      anon_sym_with,
      anon_sym_assert,
  [148989] = 5,
    ACTIONS(7764), 1,
      sym_identifier,
    ACTIONS(7766), 1,
      anon_sym_LPAREN,
    STATE(1246), 1,
      sym_decorator_member_expression,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    STATE(1317), 2,
      sym_decorator_call_expression,
      sym_decorator_parenthesized_expression,
  [149007] = 6,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(3281), 1,
      anon_sym_LPAREN,
    STATE(3315), 1,
      sym_formal_parameters,
    STATE(5054), 1,
      sym__call_signature,
    STATE(5233), 1,
      sym_type_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [149027] = 6,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(6453), 1,
      anon_sym_LPAREN,
    STATE(3806), 1,
      sym_formal_parameters,
    STATE(5261), 1,
      sym__call_signature,
    STATE(5328), 1,
      sym_type_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [149047] = 6,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(6453), 1,
      anon_sym_LPAREN,
    STATE(3806), 1,
      sym_formal_parameters,
    STATE(5328), 1,
      sym_type_parameters,
    STATE(5425), 1,
      sym__call_signature,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [149067] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7083), 5,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACE,
  [149079] = 4,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    STATE(5064), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7524), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [149095] = 5,
    ACTIONS(7768), 1,
      anon_sym_SEMI,
    ACTIONS(7770), 1,
      sym__automatic_semicolon,
    STATE(5460), 1,
      sym_import_attribute,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7645), 2,
      anon_sym_with,
      anon_sym_assert,
  [149113] = 4,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    STATE(5066), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7526), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [149129] = 6,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(6453), 1,
      anon_sym_LPAREN,
    STATE(3806), 1,
      sym_formal_parameters,
    STATE(5288), 1,
      sym__call_signature,
    STATE(5328), 1,
      sym_type_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [149149] = 4,
    STATE(5331), 1,
      sym_import_attribute,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7645), 2,
      anon_sym_with,
      anon_sym_assert,
    ACTIONS(7772), 2,
      sym__automatic_semicolon,
      anon_sym_SEMI,
  [149165] = 4,
    STATE(5334), 1,
      sym_import_attribute,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7645), 2,
      anon_sym_with,
      anon_sym_assert,
    ACTIONS(7774), 2,
      sym__automatic_semicolon,
      anon_sym_SEMI,
  [149181] = 6,
    ACTIONS(97), 1,
      anon_sym_AT,
    ACTIONS(7284), 1,
      anon_sym_abstract,
    ACTIONS(7776), 1,
      anon_sym_class,
    STATE(1269), 1,
      aux_sym_export_statement_repeat1,
    STATE(1344), 1,
      sym_decorator,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [149201] = 4,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    STATE(5067), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7526), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [149217] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(5535), 5,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_QMARK,
  [149229] = 6,
    ACTIONS(97), 1,
      anon_sym_AT,
    ACTIONS(7723), 1,
      anon_sym_abstract,
    ACTIONS(7778), 1,
      anon_sym_class,
    STATE(1269), 1,
      aux_sym_export_statement_repeat1,
    STATE(1344), 1,
      sym_decorator,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [149249] = 6,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(6453), 1,
      anon_sym_LPAREN,
    STATE(3806), 1,
      sym_formal_parameters,
    STATE(5217), 1,
      sym__call_signature,
    STATE(5328), 1,
      sym_type_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [149269] = 6,
    ACTIONS(7256), 1,
      anon_sym_AMP,
    ACTIONS(7258), 1,
      anon_sym_PIPE,
    ACTIONS(7260), 1,
      anon_sym_extends,
    ACTIONS(7780), 1,
      anon_sym_as,
    ACTIONS(7782), 1,
      anon_sym_RBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [149289] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7784), 5,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACE,
  [149301] = 6,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(6509), 1,
      anon_sym_LPAREN,
    STATE(3330), 1,
      sym_formal_parameters,
    STATE(3820), 1,
      sym__call_signature,
    STATE(5249), 1,
      sym_type_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [149321] = 3,
    ACTIONS(7786), 1,
      anon_sym_EQ,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3622), 4,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_QMARK,
  [149335] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(2731), 5,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACE,
  [149347] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(2763), 5,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACE,
  [149359] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(5121), 5,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_QMARK,
  [149371] = 4,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    STATE(4625), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7789), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [149387] = 4,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    STATE(4669), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7791), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [149403] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7793), 5,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACE,
  [149415] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7795), 5,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACE,
  [149427] = 4,
    ACTIONS(7268), 1,
      anon_sym_COLON,
    ACTIONS(7797), 1,
      anon_sym_EQ_GT,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    STATE(5306), 3,
      sym_type_annotation,
      sym_asserts_annotation,
      sym_type_predicate_annotation,
  [149443] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7800), 5,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACE,
  [149455] = 6,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(6453), 1,
      anon_sym_LPAREN,
    STATE(3806), 1,
      sym_formal_parameters,
    STATE(5328), 1,
      sym_type_parameters,
    STATE(5390), 1,
      sym__call_signature,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [149475] = 6,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(6509), 1,
      anon_sym_LPAREN,
    STATE(3330), 1,
      sym_formal_parameters,
    STATE(3796), 1,
      sym__call_signature,
    STATE(5249), 1,
      sym_type_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [149495] = 4,
    ACTIONS(7268), 1,
      anon_sym_COLON,
    ACTIONS(7802), 1,
      anon_sym_EQ_GT,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    STATE(5306), 3,
      sym_type_annotation,
      sym_asserts_annotation,
      sym_type_predicate_annotation,
  [149511] = 4,
    ACTIONS(7268), 1,
      anon_sym_COLON,
    ACTIONS(7805), 1,
      anon_sym_EQ_GT,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    STATE(5199), 3,
      sym_type_annotation,
      sym_asserts_annotation,
      sym_type_predicate_annotation,
  [149527] = 6,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(6453), 1,
      anon_sym_LPAREN,
    STATE(3806), 1,
      sym_formal_parameters,
    STATE(5328), 1,
      sym_type_parameters,
    STATE(5405), 1,
      sym__call_signature,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [149547] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7375), 5,
      sym__automatic_semicolon,
      sym__function_signature_automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [149559] = 4,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    STATE(5073), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7524), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [149575] = 4,
    ACTIONS(7268), 1,
      anon_sym_COLON,
    ACTIONS(7808), 1,
      anon_sym_EQ_GT,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    STATE(5199), 3,
      sym_type_annotation,
      sym_asserts_annotation,
      sym_type_predicate_annotation,
  [149591] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(2953), 5,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACE,
  [149603] = 4,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    STATE(4957), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7811), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [149619] = 6,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(3281), 1,
      anon_sym_LPAREN,
    STATE(3315), 1,
      sym_formal_parameters,
    STATE(4963), 1,
      sym__call_signature,
    STATE(5233), 1,
      sym_type_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [149639] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(2649), 5,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACE,
  [149651] = 4,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    STATE(5079), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7524), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [149667] = 4,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    STATE(5081), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7526), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [149683] = 4,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    STATE(4988), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7813), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [149699] = 4,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    STATE(5083), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7526), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [149715] = 6,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(3281), 1,
      anon_sym_LPAREN,
    STATE(3315), 1,
      sym_formal_parameters,
    STATE(5024), 1,
      sym__call_signature,
    STATE(5233), 1,
      sym_type_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [149735] = 4,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    STATE(5025), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7530), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [149751] = 4,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    STATE(5034), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7530), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [149767] = 4,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    STATE(5102), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7815), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [149783] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(5130), 5,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_QMARK,
  [149795] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4859), 5,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_in,
      anon_sym_of,
      anon_sym_COLON,
  [149807] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4850), 5,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_in,
      anon_sym_of,
      anon_sym_COLON,
  [149819] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(2671), 5,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACE,
  [149831] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(2695), 5,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACE,
  [149843] = 4,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    STATE(5043), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7522), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [149859] = 4,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    STATE(5050), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7530), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [149875] = 4,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    STATE(5068), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7530), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [149891] = 4,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    STATE(5069), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7530), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [149907] = 6,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(6509), 1,
      anon_sym_LPAREN,
    STATE(3330), 1,
      sym_formal_parameters,
    STATE(4039), 1,
      sym__call_signature,
    STATE(5249), 1,
      sym_type_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [149927] = 4,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    STATE(5086), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7530), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [149943] = 4,
    ACTIONS(1888), 1,
      anon_sym_DOT,
    ACTIONS(4384), 1,
      anon_sym_LBRACE,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4386), 3,
      anon_sym_COMMA,
      anon_sym_LT,
      anon_sym_LBRACE_PIPE,
  [149959] = 4,
    ACTIONS(1892), 1,
      anon_sym_DOT,
    ACTIONS(4384), 1,
      anon_sym_LBRACE,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4386), 3,
      anon_sym_COMMA,
      anon_sym_LT,
      anon_sym_LBRACE_PIPE,
  [149975] = 4,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    STATE(5091), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7524), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [149991] = 4,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    STATE(5117), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7522), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [150007] = 6,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(6453), 1,
      anon_sym_LPAREN,
    STATE(3806), 1,
      sym_formal_parameters,
    STATE(5276), 1,
      sym__call_signature,
    STATE(5328), 1,
      sym_type_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [150027] = 6,
    ACTIONS(1678), 1,
      anon_sym_LBRACE,
    ACTIONS(7540), 1,
      anon_sym_SEMI,
    ACTIONS(7542), 1,
      sym__automatic_semicolon,
    ACTIONS(7544), 1,
      sym__function_signature_automatic_semicolon,
    STATE(226), 1,
      sym_statement_block,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [150047] = 4,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    STATE(5118), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7530), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [150063] = 4,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    STATE(5002), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7614), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [150079] = 4,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    STATE(5119), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7530), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [150095] = 6,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(6453), 1,
      anon_sym_LPAREN,
    STATE(3806), 1,
      sym_formal_parameters,
    STATE(5328), 1,
      sym_type_parameters,
    STATE(5346), 1,
      sym__call_signature,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [150115] = 4,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    STATE(4520), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7522), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [150131] = 4,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    STATE(5057), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7614), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [150147] = 4,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    STATE(4527), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7522), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [150163] = 4,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    STATE(4529), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7530), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [150179] = 4,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    STATE(4530), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7530), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [150195] = 4,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    STATE(5099), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7524), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [150211] = 4,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    STATE(4754), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7614), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [150227] = 4,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    STATE(4546), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7522), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [150243] = 4,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    STATE(4547), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7530), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [150259] = 4,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    STATE(4548), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7530), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [150275] = 4,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    STATE(4549), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7530), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [150291] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(2759), 5,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACE,
  [150303] = 4,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    STATE(4641), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7614), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [150319] = 4,
    ACTIONS(6337), 1,
      anon_sym_DOT,
    ACTIONS(7817), 1,
      sym_identifier,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6335), 3,
      anon_sym_LPAREN,
      anon_sym_QMARK_DOT,
      anon_sym_LT,
  [150335] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(2821), 5,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACE,
  [150347] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(2849), 5,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACE,
  [150359] = 4,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    STATE(4550), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7530), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [150375] = 4,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    STATE(4778), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7614), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [150391] = 4,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    STATE(4782), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7516), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [150407] = 4,
    ACTIONS(6447), 1,
      anon_sym_EQ,
    STATE(4885), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7620), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [150423] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5), 1,
      sym_html_comment,
    ACTIONS(7819), 1,
      anon_sym_SQUOTE,
    STATE(4466), 1,
      aux_sym_string_repeat2,
    ACTIONS(7821), 2,
      sym_unescaped_single_string_fragment,
      sym_escape_sequence,
  [150440] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5), 1,
      sym_html_comment,
    ACTIONS(7823), 1,
      anon_sym_SQUOTE,
    STATE(4495), 1,
      aux_sym_string_repeat2,
    ACTIONS(7825), 2,
      sym_unescaped_single_string_fragment,
      sym_escape_sequence,
  [150457] = 5,
    ACTIONS(3514), 1,
      anon_sym_LPAREN,
    ACTIONS(3576), 1,
      anon_sym_LT,
    STATE(2917), 1,
      sym_arguments,
    STATE(3015), 1,
      sym_type_arguments,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [150474] = 4,
    ACTIONS(7145), 1,
      anon_sym_EQ,
    STATE(5319), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7827), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
  [150489] = 5,
    ACTIONS(6680), 1,
      anon_sym_LPAREN,
    ACTIONS(6682), 1,
      anon_sym_LT,
    STATE(2917), 1,
      sym_arguments,
    STATE(3015), 1,
      sym_type_arguments,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [150506] = 4,
    ACTIONS(7829), 1,
      anon_sym_COMMA,
    STATE(4458), 1,
      aux_sym_variable_declaration_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7831), 2,
      sym__automatic_semicolon,
      anon_sym_SEMI,
  [150521] = 5,
    ACTIONS(6605), 1,
      anon_sym_AMP,
    ACTIONS(6607), 1,
      anon_sym_PIPE,
    ACTIONS(6609), 1,
      anon_sym_extends,
    ACTIONS(7833), 1,
      anon_sym_RBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [150538] = 5,
    ACTIONS(6605), 1,
      anon_sym_AMP,
    ACTIONS(6607), 1,
      anon_sym_PIPE,
    ACTIONS(6609), 1,
      anon_sym_extends,
    ACTIONS(7835), 1,
      anon_sym_RPAREN,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [150555] = 5,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(7837), 1,
      anon_sym_LT,
    STATE(1602), 1,
      sym_arguments,
    STATE(1603), 1,
      sym_type_arguments,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [150572] = 3,
    ACTIONS(6337), 1,
      anon_sym_DOT,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6335), 3,
      anon_sym_LPAREN,
      anon_sym_QMARK_DOT,
      anon_sym_LT,
  [150585] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5), 1,
      sym_html_comment,
    ACTIONS(7839), 1,
      anon_sym_DQUOTE,
    STATE(4394), 1,
      aux_sym_string_repeat1,
    ACTIONS(7841), 2,
      sym_unescaped_double_string_fragment,
      sym_escape_sequence,
  [150602] = 5,
    ACTIONS(6605), 1,
      anon_sym_AMP,
    ACTIONS(6607), 1,
      anon_sym_PIPE,
    ACTIONS(6609), 1,
      anon_sym_extends,
    ACTIONS(7843), 1,
      anon_sym_COLON,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [150619] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5), 1,
      sym_html_comment,
    ACTIONS(7839), 1,
      anon_sym_SQUOTE,
    STATE(4395), 1,
      aux_sym_string_repeat2,
    ACTIONS(7845), 2,
      sym_unescaped_single_string_fragment,
      sym_escape_sequence,
  [150636] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5), 1,
      sym_html_comment,
    ACTIONS(7847), 1,
      anon_sym_DQUOTE,
    STATE(4476), 1,
      aux_sym_string_repeat1,
    ACTIONS(7849), 2,
      sym_unescaped_double_string_fragment,
      sym_escape_sequence,
  [150653] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5), 1,
      sym_html_comment,
    ACTIONS(7851), 1,
      anon_sym_DQUOTE,
    STATE(4494), 1,
      aux_sym_string_repeat1,
    ACTIONS(7853), 2,
      sym_unescaped_double_string_fragment,
      sym_escape_sequence,
  [150670] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5), 1,
      sym_html_comment,
    ACTIONS(7851), 1,
      anon_sym_SQUOTE,
    STATE(4495), 1,
      aux_sym_string_repeat2,
    ACTIONS(7825), 2,
      sym_unescaped_single_string_fragment,
      sym_escape_sequence,
  [150687] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5), 1,
      sym_html_comment,
    ACTIONS(7847), 1,
      anon_sym_SQUOTE,
    STATE(4478), 1,
      aux_sym_string_repeat2,
    ACTIONS(7855), 2,
      sym_unescaped_single_string_fragment,
      sym_escape_sequence,
  [150704] = 5,
    ACTIONS(6605), 1,
      anon_sym_AMP,
    ACTIONS(6607), 1,
      anon_sym_PIPE,
    ACTIONS(6609), 1,
      anon_sym_extends,
    ACTIONS(7857), 1,
      anon_sym_RPAREN,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [150721] = 5,
    ACTIONS(7859), 1,
      sym_identifier,
    STATE(4143), 1,
      sym_nested_type_identifier,
    STATE(4683), 1,
      sym_generic_type,
    STATE(5633), 1,
      sym_nested_identifier,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [150738] = 5,
    ACTIONS(7139), 1,
      anon_sym_COMMA,
    ACTIONS(7861), 1,
      anon_sym_LBRACE,
    ACTIONS(7863), 1,
      anon_sym_LBRACE_PIPE,
    STATE(4485), 1,
      aux_sym_extends_type_clause_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [150755] = 5,
    ACTIONS(7139), 1,
      anon_sym_COMMA,
    ACTIONS(7865), 1,
      anon_sym_LBRACE,
    ACTIONS(7867), 1,
      anon_sym_LBRACE_PIPE,
    STATE(4485), 1,
      aux_sym_extends_type_clause_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [150772] = 5,
    ACTIONS(7139), 1,
      anon_sym_COMMA,
    ACTIONS(7865), 1,
      anon_sym_LBRACE,
    ACTIONS(7867), 1,
      anon_sym_LBRACE_PIPE,
    STATE(4485), 1,
      aux_sym_extends_type_clause_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [150789] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5), 1,
      sym_html_comment,
    ACTIONS(7869), 1,
      anon_sym_DQUOTE,
    STATE(4494), 1,
      aux_sym_string_repeat1,
    ACTIONS(7853), 2,
      sym_unescaped_double_string_fragment,
      sym_escape_sequence,
  [150806] = 3,
    ACTIONS(7661), 1,
      anon_sym_RBRACE,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4172), 3,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_extends,
  [150819] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5), 1,
      sym_html_comment,
    ACTIONS(7871), 1,
      anon_sym_DQUOTE,
    STATE(4412), 1,
      aux_sym_string_repeat1,
    ACTIONS(7873), 2,
      sym_unescaped_double_string_fragment,
      sym_escape_sequence,
  [150836] = 5,
    ACTIONS(6605), 1,
      anon_sym_AMP,
    ACTIONS(6607), 1,
      anon_sym_PIPE,
    ACTIONS(6609), 1,
      anon_sym_extends,
    ACTIONS(7875), 1,
      anon_sym_RPAREN,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [150853] = 5,
    ACTIONS(1910), 1,
      anon_sym_COMMA,
    ACTIONS(7877), 1,
      anon_sym_EQ,
    ACTIONS(7879), 1,
      anon_sym_RBRACK,
    STATE(4990), 1,
      aux_sym_array_pattern_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [150870] = 5,
    ACTIONS(7881), 1,
      sym_identifier,
    ACTIONS(7883), 1,
      anon_sym_const,
    ACTIONS(7885), 1,
      anon_sym_GT,
    STATE(5244), 1,
      sym_type_parameter,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [150887] = 5,
    ACTIONS(97), 1,
      anon_sym_AT,
    ACTIONS(7887), 1,
      anon_sym_class,
    STATE(1269), 1,
      aux_sym_export_statement_repeat1,
    STATE(1344), 1,
      sym_decorator,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [150904] = 5,
    ACTIONS(6605), 1,
      anon_sym_AMP,
    ACTIONS(6607), 1,
      anon_sym_PIPE,
    ACTIONS(6609), 1,
      anon_sym_extends,
    ACTIONS(7889), 1,
      anon_sym_RBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [150921] = 5,
    ACTIONS(7891), 1,
      sym_identifier,
    STATE(3818), 1,
      sym_nested_type_identifier,
    STATE(4447), 1,
      sym_generic_type,
    STATE(5633), 1,
      sym_nested_identifier,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [150938] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5), 1,
      sym_html_comment,
    ACTIONS(7871), 1,
      anon_sym_SQUOTE,
    STATE(4456), 1,
      aux_sym_string_repeat2,
    ACTIONS(7893), 2,
      sym_unescaped_single_string_fragment,
      sym_escape_sequence,
  [150955] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5), 1,
      sym_html_comment,
    ACTIONS(7895), 1,
      anon_sym_DQUOTE,
    STATE(4494), 1,
      aux_sym_string_repeat1,
    ACTIONS(7853), 2,
      sym_unescaped_double_string_fragment,
      sym_escape_sequence,
  [150972] = 5,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(6453), 1,
      anon_sym_LPAREN,
    STATE(5174), 1,
      sym_type_parameters,
    STATE(5518), 1,
      sym_formal_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [150989] = 4,
    ACTIONS(6595), 1,
      anon_sym_EQ,
    STATE(5263), 1,
      sym_default_type,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7897), 2,
      anon_sym_COMMA,
      anon_sym_GT,
  [151004] = 5,
    ACTIONS(6605), 1,
      anon_sym_AMP,
    ACTIONS(6607), 1,
      anon_sym_PIPE,
    ACTIONS(6609), 1,
      anon_sym_extends,
    ACTIONS(7899), 1,
      anon_sym_COLON,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [151021] = 4,
    ACTIONS(7829), 1,
      anon_sym_COMMA,
    STATE(4506), 1,
      aux_sym_variable_declaration_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7901), 2,
      sym__automatic_semicolon,
      anon_sym_SEMI,
  [151036] = 4,
    ACTIONS(5010), 1,
      anon_sym_COMMA,
    STATE(4457), 1,
      aux_sym_sequence_expression_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7318), 2,
      sym__automatic_semicolon,
      anon_sym_SEMI,
  [151051] = 4,
    ACTIONS(7905), 1,
      anon_sym_COMMA,
    STATE(4480), 1,
      aux_sym_extends_clause_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7903), 2,
      anon_sym_LBRACE,
      anon_sym_implements,
  [151066] = 4,
    ACTIONS(6327), 1,
      anon_sym_STAR,
    ACTIONS(6331), 1,
      anon_sym_LBRACE,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    STATE(5748), 2,
      sym_namespace_import,
      sym_named_imports,
  [151081] = 5,
    ACTIONS(7095), 1,
      anon_sym_AMP,
    ACTIONS(7097), 1,
      anon_sym_PIPE,
    ACTIONS(7099), 1,
      anon_sym_extends,
    ACTIONS(7907), 1,
      anon_sym_QMARK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [151098] = 3,
    ACTIONS(7909), 1,
      anon_sym_DOT,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6335), 3,
      anon_sym_LPAREN,
      anon_sym_QMARK_DOT,
      anon_sym_LT,
  [151111] = 5,
    ACTIONS(6605), 1,
      anon_sym_AMP,
    ACTIONS(6607), 1,
      anon_sym_PIPE,
    ACTIONS(6609), 1,
      anon_sym_extends,
    ACTIONS(7911), 1,
      anon_sym_RBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [151128] = 4,
    ACTIONS(7913), 1,
      anon_sym_COMMA,
    STATE(4423), 1,
      aux_sym_implements_clause_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7252), 2,
      anon_sym_LBRACE,
      anon_sym_GT,
  [151143] = 5,
    ACTIONS(6605), 1,
      anon_sym_AMP,
    ACTIONS(6607), 1,
      anon_sym_PIPE,
    ACTIONS(6609), 1,
      anon_sym_extends,
    ACTIONS(7916), 1,
      anon_sym_RBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [151160] = 3,
    ACTIONS(7918), 1,
      anon_sym_EQ,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3622), 3,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_RBRACK,
  [151173] = 4,
    ACTIONS(7921), 1,
      anon_sym_from,
    STATE(5161), 1,
      sym__from_clause,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(5101), 2,
      sym__automatic_semicolon,
      anon_sym_SEMI,
  [151188] = 4,
    ACTIONS(7921), 1,
      anon_sym_from,
    STATE(5461), 1,
      sym__from_clause,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7923), 2,
      sym__automatic_semicolon,
      anon_sym_SEMI,
  [151203] = 5,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(6453), 1,
      anon_sym_LPAREN,
    STATE(5375), 1,
      sym_type_parameters,
    STATE(5478), 1,
      sym_formal_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [151220] = 5,
    ACTIONS(97), 1,
      anon_sym_AT,
    ACTIONS(7925), 1,
      anon_sym_class,
    STATE(1269), 1,
      aux_sym_export_statement_repeat1,
    STATE(1344), 1,
      sym_decorator,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [151237] = 5,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(6453), 1,
      anon_sym_LPAREN,
    STATE(5163), 1,
      sym_type_parameters,
    STATE(5577), 1,
      sym_formal_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [151254] = 4,
    ACTIONS(7927), 1,
      anon_sym_EQ,
    STATE(5342), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6778), 2,
      anon_sym_in,
      anon_sym_of,
  [151269] = 5,
    ACTIONS(6605), 1,
      anon_sym_AMP,
    ACTIONS(6607), 1,
      anon_sym_PIPE,
    ACTIONS(6609), 1,
      anon_sym_extends,
    ACTIONS(7929), 1,
      anon_sym_RBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [151286] = 5,
    ACTIONS(6605), 1,
      anon_sym_AMP,
    ACTIONS(6607), 1,
      anon_sym_PIPE,
    ACTIONS(6609), 1,
      anon_sym_extends,
    ACTIONS(7931), 1,
      anon_sym_COLON,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [151303] = 5,
    ACTIONS(6605), 1,
      anon_sym_AMP,
    ACTIONS(6607), 1,
      anon_sym_PIPE,
    ACTIONS(6609), 1,
      anon_sym_extends,
    ACTIONS(7933), 1,
      anon_sym_RPAREN,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [151320] = 5,
    ACTIONS(6605), 1,
      anon_sym_AMP,
    ACTIONS(6607), 1,
      anon_sym_PIPE,
    ACTIONS(6609), 1,
      anon_sym_extends,
    ACTIONS(7935), 1,
      anon_sym_RBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [151337] = 5,
    ACTIONS(6605), 1,
      anon_sym_AMP,
    ACTIONS(6607), 1,
      anon_sym_PIPE,
    ACTIONS(6609), 1,
      anon_sym_extends,
    ACTIONS(7937), 1,
      anon_sym_RBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [151354] = 5,
    ACTIONS(6605), 1,
      anon_sym_AMP,
    ACTIONS(6607), 1,
      anon_sym_PIPE,
    ACTIONS(6609), 1,
      anon_sym_extends,
    ACTIONS(7939), 1,
      anon_sym_COLON,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [151371] = 5,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(6453), 1,
      anon_sym_LPAREN,
    STATE(5292), 1,
      sym_type_parameters,
    STATE(5472), 1,
      sym_formal_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [151388] = 5,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(6453), 1,
      anon_sym_LPAREN,
    STATE(5387), 1,
      sym_type_parameters,
    STATE(5653), 1,
      sym_formal_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [151405] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6064), 4,
      sym__automatic_semicolon,
      sym__function_signature_automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [151416] = 5,
    ACTIONS(6605), 1,
      anon_sym_AMP,
    ACTIONS(6607), 1,
      anon_sym_PIPE,
    ACTIONS(6609), 1,
      anon_sym_extends,
    ACTIONS(7941), 1,
      anon_sym_RBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [151433] = 5,
    ACTIONS(6605), 1,
      anon_sym_AMP,
    ACTIONS(6607), 1,
      anon_sym_PIPE,
    ACTIONS(6609), 1,
      anon_sym_extends,
    ACTIONS(7943), 1,
      anon_sym_RBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [151450] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5), 1,
      sym_html_comment,
    ACTIONS(7869), 1,
      anon_sym_SQUOTE,
    STATE(4495), 1,
      aux_sym_string_repeat2,
    ACTIONS(7825), 2,
      sym_unescaped_single_string_fragment,
      sym_escape_sequence,
  [151467] = 5,
    ACTIONS(7881), 1,
      sym_identifier,
    ACTIONS(7883), 1,
      anon_sym_const,
    ACTIONS(7945), 1,
      anon_sym_GT,
    STATE(5244), 1,
      sym_type_parameter,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [151484] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7947), 4,
      sym__template_chars,
      sym_escape_sequence,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_LBRACE,
  [151495] = 4,
    ACTIONS(7571), 1,
      anon_sym_EQ,
    STATE(5290), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7949), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
  [151510] = 5,
    ACTIONS(7139), 1,
      anon_sym_COMMA,
    ACTIONS(7365), 1,
      anon_sym_LBRACE,
    ACTIONS(7367), 1,
      anon_sym_LBRACE_PIPE,
    STATE(4401), 1,
      aux_sym_extends_type_clause_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [151527] = 5,
    ACTIONS(7095), 1,
      anon_sym_AMP,
    ACTIONS(7097), 1,
      anon_sym_PIPE,
    ACTIONS(7099), 1,
      anon_sym_extends,
    ACTIONS(7951), 1,
      anon_sym_QMARK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [151544] = 5,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(6453), 1,
      anon_sym_LPAREN,
    STATE(5167), 1,
      sym_type_parameters,
    STATE(5711), 1,
      sym_formal_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [151561] = 4,
    ACTIONS(7829), 1,
      anon_sym_COMMA,
    STATE(4515), 1,
      aux_sym_variable_declaration_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7953), 2,
      sym__automatic_semicolon,
      anon_sym_SEMI,
  [151576] = 4,
    ACTIONS(7829), 1,
      anon_sym_COMMA,
    STATE(4459), 1,
      aux_sym_variable_declaration_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7955), 2,
      sym__automatic_semicolon,
      anon_sym_SEMI,
  [151591] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5), 1,
      sym_html_comment,
    ACTIONS(7957), 1,
      anon_sym_SQUOTE,
    STATE(4495), 1,
      aux_sym_string_repeat2,
    ACTIONS(7825), 2,
      sym_unescaped_single_string_fragment,
      sym_escape_sequence,
  [151608] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5), 1,
      sym_html_comment,
    ACTIONS(7819), 1,
      anon_sym_DQUOTE,
    STATE(4465), 1,
      aux_sym_string_repeat1,
    ACTIONS(7959), 2,
      sym_unescaped_double_string_fragment,
      sym_escape_sequence,
  [151625] = 5,
    ACTIONS(6605), 1,
      anon_sym_AMP,
    ACTIONS(6607), 1,
      anon_sym_PIPE,
    ACTIONS(6609), 1,
      anon_sym_extends,
    ACTIONS(7961), 1,
      anon_sym_COLON,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [151642] = 4,
    ACTIONS(7963), 1,
      anon_sym_COMMA,
    STATE(4455), 1,
      aux_sym_variable_declaration_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7966), 2,
      sym__automatic_semicolon,
      anon_sym_SEMI,
  [151657] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5), 1,
      sym_html_comment,
    ACTIONS(7895), 1,
      anon_sym_SQUOTE,
    STATE(4495), 1,
      aux_sym_string_repeat2,
    ACTIONS(7825), 2,
      sym_unescaped_single_string_fragment,
      sym_escape_sequence,
  [151674] = 4,
    ACTIONS(7968), 1,
      anon_sym_COMMA,
    STATE(4457), 1,
      aux_sym_sequence_expression_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4852), 2,
      sym__automatic_semicolon,
      anon_sym_SEMI,
  [151689] = 4,
    ACTIONS(7829), 1,
      anon_sym_COMMA,
    STATE(4455), 1,
      aux_sym_variable_declaration_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7971), 2,
      sym__automatic_semicolon,
      anon_sym_SEMI,
  [151704] = 4,
    ACTIONS(7829), 1,
      anon_sym_COMMA,
    STATE(4455), 1,
      aux_sym_variable_declaration_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7973), 2,
      sym__automatic_semicolon,
      anon_sym_SEMI,
  [151719] = 4,
    ACTIONS(7921), 1,
      anon_sym_from,
    STATE(5428), 1,
      sym__from_clause,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7975), 2,
      sym__automatic_semicolon,
      anon_sym_SEMI,
  [151734] = 5,
    ACTIONS(6605), 1,
      anon_sym_AMP,
    ACTIONS(6607), 1,
      anon_sym_PIPE,
    ACTIONS(6609), 1,
      anon_sym_extends,
    ACTIONS(7977), 1,
      anon_sym_RBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [151751] = 4,
    ACTIONS(7905), 1,
      anon_sym_COMMA,
    STATE(4418), 1,
      aux_sym_extends_clause_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7979), 2,
      anon_sym_LBRACE,
      anon_sym_implements,
  [151766] = 5,
    ACTIONS(7881), 1,
      sym_identifier,
    ACTIONS(7883), 1,
      anon_sym_const,
    ACTIONS(7981), 1,
      anon_sym_GT,
    STATE(5244), 1,
      sym_type_parameter,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [151783] = 4,
    ACTIONS(7921), 1,
      anon_sym_from,
    STATE(5203), 1,
      sym__from_clause,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(5041), 2,
      sym__automatic_semicolon,
      anon_sym_SEMI,
  [151798] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5), 1,
      sym_html_comment,
    ACTIONS(7983), 1,
      anon_sym_DQUOTE,
    STATE(4494), 1,
      aux_sym_string_repeat1,
    ACTIONS(7853), 2,
      sym_unescaped_double_string_fragment,
      sym_escape_sequence,
  [151815] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5), 1,
      sym_html_comment,
    ACTIONS(7983), 1,
      anon_sym_SQUOTE,
    STATE(4495), 1,
      aux_sym_string_repeat2,
    ACTIONS(7825), 2,
      sym_unescaped_single_string_fragment,
      sym_escape_sequence,
  [151832] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7985), 4,
      sym__automatic_semicolon,
      anon_sym_with,
      anon_sym_assert,
      anon_sym_SEMI,
  [151843] = 5,
    ACTIONS(6375), 1,
      anon_sym_LPAREN,
    ACTIONS(6381), 1,
      anon_sym_LT,
    STATE(3224), 1,
      sym_arguments,
    STATE(3401), 1,
      sym_type_arguments,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [151860] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7987), 4,
      sym__automatic_semicolon,
      anon_sym_with,
      anon_sym_assert,
      anon_sym_SEMI,
  [151871] = 5,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(6453), 1,
      anon_sym_LPAREN,
    STATE(5208), 1,
      sym_type_parameters,
    STATE(5491), 1,
      sym_formal_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [151888] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5), 1,
      sym_html_comment,
    ACTIONS(7989), 1,
      anon_sym_DQUOTE,
    STATE(4402), 1,
      aux_sym_string_repeat1,
    ACTIONS(7991), 2,
      sym_unescaped_double_string_fragment,
      sym_escape_sequence,
  [151905] = 5,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(6453), 1,
      anon_sym_LPAREN,
    STATE(5210), 1,
      sym_type_parameters,
    STATE(5560), 1,
      sym_formal_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [151922] = 5,
    ACTIONS(7095), 1,
      anon_sym_AMP,
    ACTIONS(7097), 1,
      anon_sym_PIPE,
    ACTIONS(7099), 1,
      anon_sym_extends,
    ACTIONS(7993), 1,
      anon_sym_QMARK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [151939] = 5,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(6453), 1,
      anon_sym_LPAREN,
    STATE(5378), 1,
      sym_type_parameters,
    STATE(5632), 1,
      sym_formal_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [151956] = 5,
    ACTIONS(7881), 1,
      sym_identifier,
    ACTIONS(7883), 1,
      anon_sym_const,
    ACTIONS(7995), 1,
      anon_sym_GT,
    STATE(5244), 1,
      sym_type_parameter,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [151973] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5), 1,
      sym_html_comment,
    ACTIONS(7997), 1,
      anon_sym_DQUOTE,
    STATE(4494), 1,
      aux_sym_string_repeat1,
    ACTIONS(7853), 2,
      sym_unescaped_double_string_fragment,
      sym_escape_sequence,
  [151990] = 5,
    ACTIONS(6605), 1,
      anon_sym_AMP,
    ACTIONS(6607), 1,
      anon_sym_PIPE,
    ACTIONS(6609), 1,
      anon_sym_extends,
    ACTIONS(7999), 1,
      anon_sym_RPAREN,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [152007] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5), 1,
      sym_html_comment,
    ACTIONS(7997), 1,
      anon_sym_SQUOTE,
    STATE(4495), 1,
      aux_sym_string_repeat2,
    ACTIONS(7825), 2,
      sym_unescaped_single_string_fragment,
      sym_escape_sequence,
  [152024] = 5,
    ACTIONS(1910), 1,
      anon_sym_COMMA,
    ACTIONS(7877), 1,
      anon_sym_EQ,
    ACTIONS(8001), 1,
      anon_sym_RBRACK,
    STATE(4890), 1,
      aux_sym_array_pattern_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [152041] = 4,
    ACTIONS(8005), 1,
      anon_sym_COMMA,
    STATE(4480), 1,
      aux_sym_extends_clause_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8003), 2,
      anon_sym_LBRACE,
      anon_sym_implements,
  [152056] = 5,
    ACTIONS(97), 1,
      anon_sym_AT,
    ACTIONS(8008), 1,
      anon_sym_export,
    STATE(1269), 1,
      aux_sym_export_statement_repeat1,
    STATE(1344), 1,
      sym_decorator,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [152073] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5), 1,
      sym_html_comment,
    ACTIONS(7989), 1,
      anon_sym_SQUOTE,
    STATE(4443), 1,
      aux_sym_string_repeat2,
    ACTIONS(8010), 2,
      sym_unescaped_single_string_fragment,
      sym_escape_sequence,
  [152090] = 3,
    ACTIONS(6104), 1,
      anon_sym_EQ_GT,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3814), 3,
      anon_sym_LPAREN,
      anon_sym_LT,
      anon_sym_QMARK,
  [152103] = 5,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(3281), 1,
      anon_sym_LPAREN,
    STATE(3576), 1,
      sym_formal_parameters,
    STATE(5246), 1,
      sym_type_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [152120] = 5,
    ACTIONS(8012), 1,
      anon_sym_LBRACE,
    ACTIONS(8014), 1,
      anon_sym_COMMA,
    ACTIONS(8017), 1,
      anon_sym_LBRACE_PIPE,
    STATE(4485), 1,
      aux_sym_extends_type_clause_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [152137] = 5,
    ACTIONS(6605), 1,
      anon_sym_AMP,
    ACTIONS(6607), 1,
      anon_sym_PIPE,
    ACTIONS(6609), 1,
      anon_sym_extends,
    ACTIONS(8019), 1,
      anon_sym_RBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [152154] = 3,
    ACTIONS(8021), 1,
      sym_escape_sequence,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8023), 3,
      sym__template_chars,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_LBRACE,
  [152167] = 3,
    ACTIONS(8026), 1,
      anon_sym_EQ_GT,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3814), 3,
      anon_sym_LPAREN,
      anon_sym_LT,
      anon_sym_QMARK,
  [152180] = 5,
    ACTIONS(7095), 1,
      anon_sym_AMP,
    ACTIONS(7097), 1,
      anon_sym_PIPE,
    ACTIONS(7099), 1,
      anon_sym_extends,
    ACTIONS(8028), 1,
      anon_sym_QMARK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [152197] = 5,
    ACTIONS(6605), 1,
      anon_sym_AMP,
    ACTIONS(6607), 1,
      anon_sym_PIPE,
    ACTIONS(6609), 1,
      anon_sym_extends,
    ACTIONS(8030), 1,
      anon_sym_COLON,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [152214] = 4,
    ACTIONS(7145), 1,
      anon_sym_EQ,
    STATE(5152), 1,
      sym__initializer,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8032), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
  [152229] = 5,
    ACTIONS(7095), 1,
      anon_sym_AMP,
    ACTIONS(7097), 1,
      anon_sym_PIPE,
    ACTIONS(7099), 1,
      anon_sym_extends,
    ACTIONS(8034), 1,
      anon_sym_QMARK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [152246] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5), 1,
      sym_html_comment,
    ACTIONS(8036), 1,
      anon_sym_DQUOTE,
    STATE(4512), 1,
      aux_sym_string_repeat1,
    ACTIONS(8038), 2,
      sym_unescaped_double_string_fragment,
      sym_escape_sequence,
  [152263] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5), 1,
      sym_html_comment,
    ACTIONS(8040), 1,
      anon_sym_DQUOTE,
    STATE(4494), 1,
      aux_sym_string_repeat1,
    ACTIONS(8042), 2,
      sym_unescaped_double_string_fragment,
      sym_escape_sequence,
  [152280] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5), 1,
      sym_html_comment,
    ACTIONS(8045), 1,
      anon_sym_SQUOTE,
    STATE(4495), 1,
      aux_sym_string_repeat2,
    ACTIONS(8047), 2,
      sym_unescaped_single_string_fragment,
      sym_escape_sequence,
  [152297] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5), 1,
      sym_html_comment,
    ACTIONS(8036), 1,
      anon_sym_SQUOTE,
    STATE(4381), 1,
      aux_sym_string_repeat2,
    ACTIONS(8050), 2,
      sym_unescaped_single_string_fragment,
      sym_escape_sequence,
  [152314] = 5,
    ACTIONS(7095), 1,
      anon_sym_AMP,
    ACTIONS(7097), 1,
      anon_sym_PIPE,
    ACTIONS(7099), 1,
      anon_sym_extends,
    ACTIONS(8052), 1,
      anon_sym_QMARK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [152331] = 5,
    ACTIONS(6605), 1,
      anon_sym_AMP,
    ACTIONS(6607), 1,
      anon_sym_PIPE,
    ACTIONS(6609), 1,
      anon_sym_extends,
    ACTIONS(8054), 1,
      anon_sym_COLON,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [152348] = 4,
    ACTIONS(6595), 1,
      anon_sym_EQ,
    STATE(5178), 1,
      sym_default_type,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8056), 2,
      anon_sym_COMMA,
      anon_sym_GT,
  [152363] = 5,
    ACTIONS(4588), 1,
      anon_sym_LPAREN,
    ACTIONS(8058), 1,
      anon_sym_LT,
    STATE(1964), 1,
      sym_arguments,
    STATE(1965), 1,
      sym_type_arguments,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [152380] = 5,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(6453), 1,
      anon_sym_LPAREN,
    STATE(5252), 1,
      sym_type_parameters,
    STATE(5769), 1,
      sym_formal_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [152397] = 5,
    ACTIONS(3528), 1,
      anon_sym_LPAREN,
    ACTIONS(6345), 1,
      anon_sym_LT,
    STATE(3086), 1,
      sym_arguments,
    STATE(3215), 1,
      sym_type_arguments,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [152414] = 5,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(6453), 1,
      anon_sym_LPAREN,
    STATE(5253), 1,
      sym_type_parameters,
    STATE(5552), 1,
      sym_formal_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [152431] = 5,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(6453), 1,
      anon_sym_LPAREN,
    STATE(5456), 1,
      sym_type_parameters,
    STATE(5647), 1,
      sym_formal_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [152448] = 4,
    ACTIONS(3814), 1,
      anon_sym_COLON,
    ACTIONS(4622), 1,
      anon_sym_EQ,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8060), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
  [152463] = 4,
    ACTIONS(7829), 1,
      anon_sym_COMMA,
    STATE(4455), 1,
      aux_sym_variable_declaration_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8062), 2,
      sym__automatic_semicolon,
      anon_sym_SEMI,
  [152478] = 5,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(6453), 1,
      anon_sym_LPAREN,
    STATE(5179), 1,
      sym_type_parameters,
    STATE(5547), 1,
      sym_formal_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [152495] = 5,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(6453), 1,
      anon_sym_LPAREN,
    STATE(5459), 1,
      sym_type_parameters,
    STATE(5671), 1,
      sym_formal_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [152512] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5), 1,
      sym_html_comment,
    ACTIONS(8064), 1,
      anon_sym_DQUOTE,
    STATE(4513), 1,
      aux_sym_string_repeat1,
    ACTIONS(8066), 2,
      sym_unescaped_double_string_fragment,
      sym_escape_sequence,
  [152529] = 5,
    ACTIONS(7095), 1,
      anon_sym_AMP,
    ACTIONS(7097), 1,
      anon_sym_PIPE,
    ACTIONS(7099), 1,
      anon_sym_extends,
    ACTIONS(8068), 1,
      anon_sym_QMARK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [152546] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5), 1,
      sym_html_comment,
    ACTIONS(8064), 1,
      anon_sym_SQUOTE,
    STATE(4452), 1,
      aux_sym_string_repeat2,
    ACTIONS(8070), 2,
      sym_unescaped_single_string_fragment,
      sym_escape_sequence,
  [152563] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5), 1,
      sym_html_comment,
    ACTIONS(7823), 1,
      anon_sym_DQUOTE,
    STATE(4494), 1,
      aux_sym_string_repeat1,
    ACTIONS(7853), 2,
      sym_unescaped_double_string_fragment,
      sym_escape_sequence,
  [152580] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5), 1,
      sym_html_comment,
    ACTIONS(7957), 1,
      anon_sym_DQUOTE,
    STATE(4494), 1,
      aux_sym_string_repeat1,
    ACTIONS(7853), 2,
      sym_unescaped_double_string_fragment,
      sym_escape_sequence,
  [152597] = 5,
    ACTIONS(6605), 1,
      anon_sym_AMP,
    ACTIONS(6607), 1,
      anon_sym_PIPE,
    ACTIONS(6609), 1,
      anon_sym_extends,
    ACTIONS(8072), 1,
      anon_sym_RBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [152614] = 4,
    ACTIONS(7829), 1,
      anon_sym_COMMA,
    STATE(4455), 1,
      aux_sym_variable_declaration_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8074), 2,
      sym__automatic_semicolon,
      anon_sym_SEMI,
  [152629] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8076), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [152639] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8078), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [152649] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8080), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [152659] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8080), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [152669] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8082), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [152679] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8080), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [152689] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8084), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [152699] = 3,
    ACTIONS(8086), 1,
      anon_sym_EQ,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8088), 2,
      anon_sym_COMMA,
      anon_sym_from,
  [152711] = 4,
    ACTIONS(8090), 1,
      sym_identifier,
    ACTIONS(8092), 1,
      anon_sym_LBRACK,
    ACTIONS(8094), 1,
      sym_private_property_identifier,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [152725] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8076), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [152735] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8080), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [152745] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8082), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [152755] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8096), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [152765] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8098), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [152775] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8098), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [152785] = 4,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    ACTIONS(8100), 1,
      anon_sym_DOT,
    STATE(1529), 1,
      sym_arguments,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [152799] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8080), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [152809] = 4,
    ACTIONS(8102), 1,
      sym_identifier,
    ACTIONS(8104), 1,
      anon_sym_LBRACK,
    ACTIONS(8106), 1,
      sym_private_property_identifier,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [152823] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8096), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [152833] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8084), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [152843] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8108), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [152853] = 4,
    ACTIONS(8110), 1,
      sym_identifier,
    ACTIONS(8112), 1,
      anon_sym_LBRACK,
    ACTIONS(8114), 1,
      sym_private_property_identifier,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [152867] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8108), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [152877] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8080), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [152887] = 4,
    ACTIONS(8116), 1,
      anon_sym_COMMA,
    ACTIONS(8118), 1,
      anon_sym_RBRACK,
    STATE(4552), 1,
      aux_sym_tuple_type_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [152901] = 4,
    ACTIONS(4210), 1,
      anon_sym_extends,
    ACTIONS(8120), 1,
      anon_sym_AMP,
    ACTIONS(8122), 1,
      anon_sym_PIPE,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [152915] = 4,
    ACTIONS(3215), 1,
      anon_sym_GT,
    ACTIONS(8124), 1,
      anon_sym_COMMA,
    STATE(4423), 1,
      aux_sym_implements_clause_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [152929] = 4,
    ACTIONS(8126), 1,
      sym_identifier,
    ACTIONS(8128), 1,
      anon_sym_LBRACK,
    ACTIONS(8130), 1,
      sym_private_property_identifier,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [152943] = 4,
    ACTIONS(1977), 1,
      anon_sym_COMMA,
    ACTIONS(5368), 1,
      anon_sym_RPAREN,
    STATE(4554), 1,
      aux_sym_array_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [152957] = 4,
    ACTIONS(1977), 1,
      anon_sym_COMMA,
    ACTIONS(5368), 1,
      anon_sym_RPAREN,
    STATE(4700), 1,
      aux_sym_array_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [152971] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8082), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [152981] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8098), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [152991] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8098), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [153001] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8098), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [153011] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8098), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [153021] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8132), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [153031] = 4,
    ACTIONS(2941), 1,
      anon_sym_RBRACK,
    ACTIONS(8134), 1,
      anon_sym_COMMA,
    STATE(4949), 1,
      aux_sym_tuple_type_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [153045] = 4,
    ACTIONS(8136), 1,
      sym_identifier,
    ACTIONS(8138), 1,
      anon_sym_LBRACK,
    ACTIONS(8140), 1,
      sym_private_property_identifier,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [153059] = 4,
    ACTIONS(1977), 1,
      anon_sym_COMMA,
    ACTIONS(8142), 1,
      anon_sym_RPAREN,
    STATE(4700), 1,
      aux_sym_array_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [153073] = 4,
    ACTIONS(5060), 1,
      anon_sym_COMMA,
    ACTIONS(8144), 1,
      anon_sym_RBRACE,
    STATE(4959), 1,
      aux_sym_object_pattern_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [153087] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8080), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [153097] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8084), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [153107] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8080), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [153117] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8082), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [153127] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8076), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [153137] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7707), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [153147] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8132), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [153157] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8146), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [153167] = 3,
    ACTIONS(7067), 1,
      anon_sym_DOT,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8148), 2,
      sym__automatic_semicolon,
      anon_sym_SEMI,
  [153179] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8150), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [153189] = 3,
    ACTIONS(7069), 1,
      anon_sym_DOT,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8148), 2,
      sym__automatic_semicolon,
      anon_sym_SEMI,
  [153201] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8132), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [153211] = 4,
    ACTIONS(8152), 1,
      anon_sym_COMMA,
    ACTIONS(8154), 1,
      anon_sym_RBRACK,
    STATE(4649), 1,
      aux_sym_tuple_type_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [153225] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8080), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [153235] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8096), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [153245] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8080), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [153255] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8082), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [153265] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8076), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [153275] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8150), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [153285] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8132), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [153295] = 4,
    ACTIONS(5555), 1,
      anon_sym_COMMA,
    ACTIONS(8156), 1,
      anon_sym_RBRACE,
    STATE(4965), 1,
      aux_sym_object_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [153309] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8080), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [153319] = 4,
    ACTIONS(6375), 1,
      anon_sym_LPAREN,
    ACTIONS(8158), 1,
      anon_sym_DOT,
    STATE(3317), 1,
      sym_arguments,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [153333] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8076), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [153343] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8080), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [153353] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8096), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [153363] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8082), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [153373] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8080), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [153383] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8080), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [153393] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8082), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [153403] = 4,
    ACTIONS(8160), 1,
      anon_sym_COMMA,
    ACTIONS(8162), 1,
      anon_sym_RBRACK,
    STATE(4599), 1,
      aux_sym_tuple_type_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [153417] = 4,
    ACTIONS(6819), 1,
      anon_sym_AMP,
    ACTIONS(6821), 1,
      anon_sym_PIPE,
    ACTIONS(6823), 1,
      anon_sym_extends,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [153431] = 4,
    ACTIONS(3201), 1,
      anon_sym_GT,
    ACTIONS(8164), 1,
      anon_sym_COMMA,
    STATE(4423), 1,
      aux_sym_implements_clause_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [153445] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8098), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [153455] = 4,
    ACTIONS(1977), 1,
      anon_sym_COMMA,
    ACTIONS(5374), 1,
      anon_sym_RPAREN,
    STATE(4602), 1,
      aux_sym_array_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [153469] = 4,
    ACTIONS(1977), 1,
      anon_sym_COMMA,
    ACTIONS(5374), 1,
      anon_sym_RPAREN,
    STATE(4700), 1,
      aux_sym_array_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [153483] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8098), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [153493] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8076), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [153503] = 4,
    ACTIONS(8166), 1,
      sym_identifier,
    ACTIONS(8168), 1,
      anon_sym_LBRACK,
    ACTIONS(8170), 1,
      sym_private_property_identifier,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [153517] = 4,
    ACTIONS(8172), 1,
      sym_identifier,
    ACTIONS(8174), 1,
      anon_sym_LBRACK,
    ACTIONS(8176), 1,
      sym_private_property_identifier,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [153531] = 4,
    ACTIONS(8178), 1,
      sym_identifier,
    ACTIONS(8180), 1,
      anon_sym_LBRACK,
    ACTIONS(8182), 1,
      sym_private_property_identifier,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [153545] = 4,
    ACTIONS(8184), 1,
      sym_identifier,
    ACTIONS(8186), 1,
      anon_sym_LBRACK,
    ACTIONS(8188), 1,
      sym_private_property_identifier,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [153559] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8132), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [153569] = 4,
    ACTIONS(2577), 1,
      anon_sym_RBRACK,
    ACTIONS(8190), 1,
      anon_sym_COMMA,
    STATE(4949), 1,
      aux_sym_tuple_type_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [153583] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8192), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [153593] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7966), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [153603] = 4,
    ACTIONS(1977), 1,
      anon_sym_COMMA,
    ACTIONS(8194), 1,
      anon_sym_RPAREN,
    STATE(4700), 1,
      aux_sym_array_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [153617] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8096), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [153627] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8076), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [153637] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8080), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [153647] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8192), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [153657] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8080), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [153667] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8082), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [153677] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8080), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [153687] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8096), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [153697] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8080), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [153707] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8082), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [153717] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8098), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [153727] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8098), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [153737] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8098), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [153747] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8098), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [153757] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8080), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [153767] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8096), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [153777] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8080), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [153787] = 4,
    ACTIONS(2735), 1,
      anon_sym_RBRACK,
    ACTIONS(8196), 1,
      anon_sym_COMMA,
    STATE(4949), 1,
      aux_sym_tuple_type_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [153801] = 4,
    ACTIONS(8198), 1,
      anon_sym_COMMA,
    ACTIONS(8200), 1,
      anon_sym_RPAREN,
    STATE(5014), 1,
      aux_sym_formal_parameters_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [153815] = 4,
    ACTIONS(6605), 1,
      anon_sym_AMP,
    ACTIONS(6607), 1,
      anon_sym_PIPE,
    ACTIONS(6609), 1,
      anon_sym_extends,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [153829] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8082), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [153839] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8098), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [153849] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8202), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [153859] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8098), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [153869] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8076), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [153879] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8108), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [153889] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7089), 3,
      anon_sym_LBRACK,
      sym_identifier,
      sym_private_property_identifier,
  [153899] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8108), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [153909] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8192), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [153919] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8132), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [153929] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8084), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [153939] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8080), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [153949] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8080), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [153959] = 4,
    ACTIONS(3231), 1,
      anon_sym_GT,
    ACTIONS(8204), 1,
      anon_sym_COMMA,
    STATE(4423), 1,
      aux_sym_implements_clause_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [153973] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8192), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [153983] = 4,
    ACTIONS(1977), 1,
      anon_sym_COMMA,
    ACTIONS(5380), 1,
      anon_sym_RPAREN,
    STATE(4644), 1,
      aux_sym_array_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [153997] = 4,
    ACTIONS(1977), 1,
      anon_sym_COMMA,
    ACTIONS(5380), 1,
      anon_sym_RPAREN,
    STATE(4700), 1,
      aux_sym_array_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [154011] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8082), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [154021] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8206), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [154031] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8080), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [154041] = 4,
    ACTIONS(1034), 1,
      anon_sym_LBRACE_PIPE,
    ACTIONS(1610), 1,
      anon_sym_LBRACE,
    STATE(4034), 1,
      sym_object_type,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [154055] = 4,
    ACTIONS(1977), 1,
      anon_sym_COMMA,
    ACTIONS(8208), 1,
      anon_sym_RPAREN,
    STATE(4700), 1,
      aux_sym_array_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [154069] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8080), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [154079] = 4,
    ACTIONS(8210), 1,
      anon_sym_COMMA,
    ACTIONS(8212), 1,
      anon_sym_RBRACE,
    STATE(4716), 1,
      aux_sym_enum_body_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [154093] = 4,
    ACTIONS(1977), 1,
      anon_sym_COMMA,
    ACTIONS(8214), 1,
      anon_sym_RPAREN,
    STATE(4700), 1,
      aux_sym_array_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [154107] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8192), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [154117] = 4,
    ACTIONS(2665), 1,
      anon_sym_RBRACK,
    ACTIONS(8216), 1,
      anon_sym_COMMA,
    STATE(4949), 1,
      aux_sym_tuple_type_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [154131] = 4,
    ACTIONS(4588), 1,
      anon_sym_LPAREN,
    ACTIONS(8218), 1,
      anon_sym_DOT,
    STATE(2048), 1,
      sym_arguments,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [154145] = 3,
    ACTIONS(8220), 1,
      anon_sym_LBRACE,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7679), 2,
      anon_sym_extends,
      anon_sym_LBRACE_PIPE,
  [154157] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8082), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [154167] = 4,
    ACTIONS(1977), 1,
      anon_sym_COMMA,
    ACTIONS(5382), 1,
      anon_sym_RPAREN,
    STATE(4656), 1,
      aux_sym_array_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [154181] = 4,
    ACTIONS(1977), 1,
      anon_sym_COMMA,
    ACTIONS(5382), 1,
      anon_sym_RPAREN,
    STATE(4700), 1,
      aux_sym_array_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [154195] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8098), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [154205] = 4,
    ACTIONS(1977), 1,
      anon_sym_COMMA,
    ACTIONS(8222), 1,
      anon_sym_RPAREN,
    STATE(4700), 1,
      aux_sym_array_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [154219] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8096), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [154229] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8192), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [154239] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8098), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [154249] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8192), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [154259] = 4,
    ACTIONS(1626), 1,
      anon_sym_DQUOTE,
    ACTIONS(1628), 1,
      anon_sym_SQUOTE,
    STATE(4469), 1,
      sym_string,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [154273] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8132), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [154283] = 4,
    ACTIONS(8224), 1,
      anon_sym_LPAREN,
    ACTIONS(8226), 1,
      anon_sym_await,
    STATE(36), 1,
      sym__for_header,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [154297] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8080), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [154307] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8096), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [154317] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8080), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [154327] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8082), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [154337] = 4,
    ACTIONS(8228), 1,
      anon_sym_COMMA,
    ACTIONS(8230), 1,
      anon_sym_GT,
    STATE(5038), 1,
      aux_sym_type_parameters_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [154351] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8232), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [154361] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8206), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [154371] = 4,
    ACTIONS(7921), 1,
      anon_sym_from,
    ACTIONS(8234), 1,
      anon_sym_as,
    STATE(5371), 1,
      sym__from_clause,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [154385] = 4,
    ACTIONS(2139), 1,
      anon_sym_LBRACE,
    ACTIONS(8236), 1,
      sym_identifier,
    STATE(4426), 1,
      sym_export_clause,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [154399] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8132), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [154409] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8076), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [154419] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8132), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [154429] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8080), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [154439] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8192), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [154449] = 4,
    ACTIONS(7881), 1,
      sym_identifier,
    ACTIONS(7883), 1,
      anon_sym_const,
    STATE(4668), 1,
      sym_type_parameter,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [154463] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8080), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [154473] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8096), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [154483] = 4,
    ACTIONS(6066), 1,
      anon_sym_LPAREN,
    ACTIONS(8238), 1,
      anon_sym_DOT,
    STATE(2936), 1,
      sym_arguments,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [154497] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8082), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [154507] = 3,
    ACTIONS(7673), 1,
      anon_sym_LBRACE,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7675), 2,
      anon_sym_COMMA,
      anon_sym_LBRACE_PIPE,
  [154519] = 4,
    ACTIONS(8240), 1,
      anon_sym_COMMA,
    ACTIONS(8243), 1,
      anon_sym_GT,
    STATE(4684), 1,
      aux_sym_type_parameters_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [154533] = 4,
    ACTIONS(8245), 1,
      sym_identifier,
    STATE(3826), 1,
      sym_decorator_member_expression,
    STATE(5817), 1,
      sym_decorator_call_expression,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [154547] = 4,
    ACTIONS(7921), 1,
      anon_sym_from,
    ACTIONS(8234), 1,
      anon_sym_as,
    STATE(5197), 1,
      sym__from_clause,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [154561] = 4,
    ACTIONS(8247), 1,
      anon_sym_LPAREN,
    ACTIONS(8249), 1,
      anon_sym_await,
    STATE(71), 1,
      sym__for_header,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [154575] = 4,
    ACTIONS(218), 1,
      anon_sym_LBRACE_PIPE,
    ACTIONS(1534), 1,
      anon_sym_LBRACE,
    STATE(939), 1,
      sym_object_type,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [154589] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8132), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [154599] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8080), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [154609] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8080), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [154619] = 4,
    ACTIONS(8251), 1,
      anon_sym_COMMA,
    ACTIONS(8253), 1,
      anon_sym_RBRACE,
    STATE(4966), 1,
      aux_sym_enum_body_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [154633] = 4,
    ACTIONS(3229), 1,
      anon_sym_GT,
    ACTIONS(8255), 1,
      anon_sym_COMMA,
    STATE(4423), 1,
      aux_sym_implements_clause_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [154647] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8082), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [154657] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6335), 3,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_LT,
  [154667] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8080), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [154677] = 4,
    ACTIONS(2511), 1,
      anon_sym_while,
    ACTIONS(8257), 1,
      anon_sym_else,
    STATE(854), 1,
      sym_else_clause,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [154691] = 4,
    ACTIONS(1977), 1,
      anon_sym_COMMA,
    ACTIONS(8259), 1,
      anon_sym_RPAREN,
    STATE(4700), 1,
      aux_sym_array_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [154705] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8080), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [154715] = 4,
    ACTIONS(5718), 1,
      anon_sym_RPAREN,
    ACTIONS(8261), 1,
      anon_sym_COMMA,
    STATE(4700), 1,
      aux_sym_array_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [154729] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8096), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [154739] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8082), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [154749] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8098), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [154759] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8108), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [154769] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8098), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [154779] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8076), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [154789] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8132), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [154799] = 4,
    ACTIONS(7256), 1,
      anon_sym_AMP,
    ACTIONS(7258), 1,
      anon_sym_PIPE,
    ACTIONS(7260), 1,
      anon_sym_extends,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [154813] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8080), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [154823] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8108), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [154833] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8264), 3,
      sym__automatic_semicolon,
      anon_sym_from,
      anon_sym_SEMI,
  [154843] = 4,
    ACTIONS(8266), 1,
      anon_sym_COMMA,
    ACTIONS(8268), 1,
      anon_sym_RBRACE,
    STATE(4973), 1,
      aux_sym_enum_body_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [154857] = 4,
    ACTIONS(7995), 1,
      anon_sym_GT,
    ACTIONS(8270), 1,
      anon_sym_COMMA,
    STATE(4684), 1,
      aux_sym_type_parameters_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [154871] = 4,
    ACTIONS(5060), 1,
      anon_sym_COMMA,
    ACTIONS(8272), 1,
      anon_sym_RBRACE,
    STATE(4806), 1,
      aux_sym_object_pattern_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [154885] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8080), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [154895] = 4,
    ACTIONS(8274), 1,
      anon_sym_COMMA,
    ACTIONS(8276), 1,
      anon_sym_RBRACE,
    STATE(4973), 1,
      aux_sym_enum_body_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [154909] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8082), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [154919] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8080), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [154929] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8084), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [154939] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8080), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [154949] = 4,
    ACTIONS(5555), 1,
      anon_sym_COMMA,
    ACTIONS(8278), 1,
      anon_sym_RBRACE,
    STATE(4812), 1,
      aux_sym_object_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [154963] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8082), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [154973] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8098), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [154983] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8098), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [154993] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8098), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [155003] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8098), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [155013] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8080), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [155023] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8096), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [155033] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8080), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [155043] = 4,
    ACTIONS(8280), 1,
      anon_sym_COMMA,
    ACTIONS(8282), 1,
      anon_sym_RBRACE,
    STATE(4887), 1,
      aux_sym_export_clause_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [155057] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8082), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [155067] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8098), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [155077] = 4,
    ACTIONS(8284), 1,
      sym_identifier,
    ACTIONS(8286), 1,
      anon_sym_LBRACK,
    ACTIONS(8288), 1,
      sym_private_property_identifier,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [155091] = 4,
    ACTIONS(5555), 1,
      anon_sym_COMMA,
    ACTIONS(8278), 1,
      anon_sym_RBRACE,
    STATE(4972), 1,
      aux_sym_object_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [155105] = 3,
    ACTIONS(8290), 1,
      anon_sym_as,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8292), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
  [155117] = 4,
    ACTIONS(5060), 1,
      anon_sym_COMMA,
    ACTIONS(8272), 1,
      anon_sym_RBRACE,
    STATE(4974), 1,
      aux_sym_object_pattern_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [155131] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8098), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [155141] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8098), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [155151] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8098), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [155161] = 4,
    ACTIONS(8294), 1,
      sym_identifier,
    STATE(3842), 1,
      sym_decorator_member_expression,
    STATE(5812), 1,
      sym_decorator_call_expression,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [155175] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8296), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [155185] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8298), 3,
      sym__automatic_semicolon,
      anon_sym_from,
      anon_sym_SEMI,
  [155195] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8084), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [155205] = 4,
    ACTIONS(5555), 1,
      anon_sym_COMMA,
    ACTIONS(8156), 1,
      anon_sym_RBRACE,
    STATE(4972), 1,
      aux_sym_object_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [155219] = 4,
    ACTIONS(5060), 1,
      anon_sym_COMMA,
    ACTIONS(8144), 1,
      anon_sym_RBRACE,
    STATE(4974), 1,
      aux_sym_object_pattern_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [155233] = 4,
    ACTIONS(8300), 1,
      anon_sym_COMMA,
    ACTIONS(8303), 1,
      anon_sym_RBRACE,
    STATE(4746), 1,
      aux_sym_export_clause_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [155247] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8192), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [155257] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8305), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [155267] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8307), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [155277] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8309), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [155287] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8311), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [155297] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8311), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [155307] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8311), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [155317] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8206), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [155327] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8311), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [155337] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8313), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [155347] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8313), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [155357] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8315), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [155367] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8108), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [155377] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8311), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [155387] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8311), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [155397] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8311), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [155407] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8311), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [155417] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8311), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [155427] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8311), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [155437] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8313), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [155447] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8313), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [155457] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8108), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [155467] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8315), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [155477] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8311), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [155487] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8311), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [155497] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8084), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [155507] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8192), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [155517] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8096), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [155527] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8317), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [155537] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8319), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [155547] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8313), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [155557] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8206), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [155567] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8313), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [155577] = 4,
    ACTIONS(218), 1,
      anon_sym_LBRACE_PIPE,
    ACTIONS(1534), 1,
      anon_sym_LBRACE,
    STATE(851), 1,
      sym_object_type,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [155591] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8319), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [155601] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8321), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [155611] = 4,
    ACTIONS(6473), 1,
      anon_sym_type,
    ACTIONS(8323), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__import_identifier,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [155625] = 4,
    ACTIONS(6473), 1,
      anon_sym_type,
    ACTIONS(8325), 1,
      sym_identifier,
    STATE(5330), 1,
      sym__import_identifier,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [155639] = 4,
    ACTIONS(8327), 1,
      anon_sym_COMMA,
    ACTIONS(8330), 1,
      anon_sym_RBRACE,
    STATE(4785), 1,
      aux_sym_named_imports_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [155653] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8315), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [155663] = 4,
    ACTIONS(1550), 1,
      anon_sym_DQUOTE,
    ACTIONS(1552), 1,
      anon_sym_SQUOTE,
    STATE(5545), 1,
      sym_string,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [155677] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8313), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [155687] = 4,
    ACTIONS(1977), 1,
      anon_sym_COMMA,
    ACTIONS(5358), 1,
      anon_sym_RPAREN,
    STATE(4698), 1,
      aux_sym_array_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [155701] = 4,
    ACTIONS(1977), 1,
      anon_sym_COMMA,
    ACTIONS(5358), 1,
      anon_sym_RPAREN,
    STATE(4700), 1,
      aux_sym_array_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [155715] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8313), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [155725] = 4,
    ACTIONS(5555), 1,
      anon_sym_COMMA,
    ACTIONS(8332), 1,
      anon_sym_RBRACE,
    STATE(4972), 1,
      aux_sym_object_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [155739] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8315), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [155749] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8311), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [155759] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8311), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [155769] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8313), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [155779] = 4,
    ACTIONS(2139), 1,
      anon_sym_LBRACE,
    ACTIONS(8334), 1,
      sym_identifier,
    STATE(4464), 1,
      sym_export_clause,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [155793] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8321), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [155803] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8313), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [155813] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8315), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [155823] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8311), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [155833] = 4,
    ACTIONS(5060), 1,
      anon_sym_COMMA,
    ACTIONS(8336), 1,
      anon_sym_RBRACE,
    STATE(4974), 1,
      aux_sym_object_pattern_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [155847] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8311), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [155857] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8311), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [155867] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8096), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [155877] = 4,
    ACTIONS(5060), 1,
      anon_sym_COMMA,
    ACTIONS(8338), 1,
      anon_sym_RBRACE,
    STATE(4974), 1,
      aux_sym_object_pattern_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [155891] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8108), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [155901] = 4,
    ACTIONS(6680), 1,
      anon_sym_LPAREN,
    ACTIONS(8238), 1,
      anon_sym_DOT,
    STATE(2936), 1,
      sym_arguments,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [155915] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8311), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [155925] = 4,
    ACTIONS(5555), 1,
      anon_sym_COMMA,
    ACTIONS(8340), 1,
      anon_sym_RBRACE,
    STATE(4972), 1,
      aux_sym_object_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [155939] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8313), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [155949] = 4,
    ACTIONS(5555), 1,
      anon_sym_COMMA,
    ACTIONS(8342), 1,
      anon_sym_RBRACE,
    STATE(4972), 1,
      aux_sym_object_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [155963] = 3,
    ACTIONS(8344), 1,
      sym__automatic_semicolon,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6778), 2,
      anon_sym_in,
      anon_sym_of,
  [155975] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7105), 3,
      anon_sym_LBRACE,
      anon_sym_COLON,
      anon_sym_EQ_GT,
  [155985] = 4,
    ACTIONS(5060), 1,
      anon_sym_COMMA,
    ACTIONS(8346), 1,
      anon_sym_RBRACE,
    STATE(4974), 1,
      aux_sym_object_pattern_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [155999] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8108), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [156009] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8313), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [156019] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8315), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [156029] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8311), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [156039] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8311), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [156049] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8311), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [156059] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8108), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [156069] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8319), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [156079] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8311), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [156089] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8096), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [156099] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8311), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [156109] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8084), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [156119] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8108), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [156129] = 4,
    ACTIONS(3557), 1,
      anon_sym_COLON,
    ACTIONS(8348), 1,
      anon_sym_RPAREN,
    STATE(5588), 1,
      sym_type_annotation,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [156143] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8108), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [156153] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8311), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [156163] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8313), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [156173] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8108), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [156183] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8313), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [156193] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8315), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [156203] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8311), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [156213] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8206), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [156223] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8311), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [156233] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8311), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [156243] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8311), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [156253] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8313), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [156263] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8084), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [156273] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8313), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [156283] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8319), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [156293] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8315), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [156303] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8311), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [156313] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8311), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [156323] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8350), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [156333] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8352), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [156343] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8319), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [156353] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8317), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [156363] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8313), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [156373] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8313), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [156383] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8315), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [156393] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8352), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [156403] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8313), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [156413] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8313), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [156423] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8084), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [156433] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8354), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [156443] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8352), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [156453] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8315), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [156463] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8311), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [156473] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8356), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [156483] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8076), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [156493] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8311), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [156503] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8356), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [156513] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8358), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [156523] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8313), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [156533] = 4,
    ACTIONS(1688), 1,
      anon_sym_RPAREN,
    ACTIONS(8360), 1,
      anon_sym_COMMA,
    STATE(4896), 1,
      aux_sym_formal_parameters_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [156547] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8313), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [156557] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8315), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [156567] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8311), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [156577] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8311), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [156587] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8311), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [156597] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8311), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [156607] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8313), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [156617] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8108), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [156627] = 4,
    ACTIONS(3514), 1,
      anon_sym_LPAREN,
    ACTIONS(8238), 1,
      anon_sym_DOT,
    STATE(2936), 1,
      sym_arguments,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [156641] = 4,
    ACTIONS(5225), 1,
      anon_sym_COMMA,
    ACTIONS(8362), 1,
      anon_sym_RBRACK,
    STATE(4997), 1,
      aux_sym_array_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [156655] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8364), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [156665] = 3,
    ACTIONS(8366), 1,
      anon_sym_as,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8368), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
  [156677] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8370), 3,
      sym__automatic_semicolon,
      anon_sym_from,
      anon_sym_SEMI,
  [156687] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8313), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [156697] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8146), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [156707] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8315), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [156717] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8311), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [156727] = 4,
    ACTIONS(6787), 1,
      anon_sym_RBRACE,
    ACTIONS(8372), 1,
      anon_sym_COMMA,
    STATE(4746), 1,
      aux_sym_export_clause_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [156741] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8311), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [156751] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8311), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [156761] = 4,
    ACTIONS(1910), 1,
      anon_sym_COMMA,
    ACTIONS(8374), 1,
      anon_sym_RBRACK,
    STATE(4998), 1,
      aux_sym_array_pattern_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [156775] = 3,
    ACTIONS(8376), 1,
      anon_sym_LBRACE,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7758), 2,
      anon_sym_extends,
      anon_sym_LBRACE_PIPE,
  [156787] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8311), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [156797] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8311), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [156807] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8378), 3,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_implements,
  [156817] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8311), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [156827] = 4,
    ACTIONS(8380), 1,
      anon_sym_COMMA,
    ACTIONS(8383), 1,
      anon_sym_RPAREN,
    STATE(4896), 1,
      aux_sym_formal_parameters_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [156841] = 4,
    ACTIONS(4852), 1,
      anon_sym_RPAREN,
    ACTIONS(8385), 1,
      anon_sym_COMMA,
    STATE(4897), 1,
      aux_sym_sequence_expression_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [156855] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8388), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [156865] = 4,
    ACTIONS(8390), 1,
      anon_sym_COMMA,
    ACTIONS(8392), 1,
      anon_sym_RPAREN,
    STATE(4869), 1,
      aux_sym_formal_parameters_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [156879] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8394), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [156889] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8394), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [156899] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8394), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [156909] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8394), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [156919] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8396), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [156929] = 4,
    ACTIONS(7444), 1,
      anon_sym_COMMA,
    ACTIONS(8398), 1,
      anon_sym_LBRACE,
    STATE(4423), 1,
      aux_sym_implements_clause_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [156943] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8396), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [156953] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8108), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [156963] = 4,
    ACTIONS(8400), 1,
      anon_sym_COMMA,
    ACTIONS(8402), 1,
      anon_sym_GT,
    STATE(4713), 1,
      aux_sym_type_parameters_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [156977] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8404), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [156987] = 4,
    ACTIONS(5555), 1,
      anon_sym_COMMA,
    ACTIONS(8406), 1,
      anon_sym_RBRACE,
    STATE(4961), 1,
      aux_sym_object_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [157001] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8394), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [157011] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8394), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [157021] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8394), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [157031] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8394), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [157041] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8394), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [157051] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8394), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [157061] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8108), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [157071] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8394), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [157081] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8394), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [157091] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8394), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [157101] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8394), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [157111] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8394), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [157121] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8394), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [157131] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8396), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [157141] = 4,
    ACTIONS(5555), 1,
      anon_sym_COMMA,
    ACTIONS(8406), 1,
      anon_sym_RBRACE,
    STATE(4972), 1,
      aux_sym_object_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [157155] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8396), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [157165] = 4,
    ACTIONS(1910), 1,
      anon_sym_COMMA,
    ACTIONS(8001), 1,
      anon_sym_RBRACK,
    STATE(4890), 1,
      aux_sym_array_pattern_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [157179] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8404), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [157189] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8394), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [157199] = 3,
    ACTIONS(7877), 1,
      anon_sym_EQ,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8408), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
  [157211] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8394), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [157221] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8394), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [157231] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8394), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [157241] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8394), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [157251] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7201), 3,
      anon_sym_LBRACE,
      anon_sym_COLON,
      anon_sym_EQ_GT,
  [157261] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8394), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [157271] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8394), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [157281] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8394), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [157291] = 4,
    ACTIONS(8410), 1,
      anon_sym_COMMA,
    ACTIONS(8412), 1,
      anon_sym_RPAREN,
    STATE(4964), 1,
      aux_sym_formal_parameters_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [157305] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8414), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [157315] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8414), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [157325] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8414), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [157335] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8414), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [157345] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8076), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [157355] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8084), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [157365] = 4,
    ACTIONS(5225), 1,
      anon_sym_COMMA,
    ACTIONS(5227), 1,
      anon_sym_RBRACK,
    STATE(4879), 1,
      aux_sym_array_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [157379] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8319), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [157389] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8319), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [157399] = 4,
    ACTIONS(8416), 1,
      anon_sym_COMMA,
    ACTIONS(8419), 1,
      anon_sym_RBRACK,
    STATE(4949), 1,
      aux_sym_tuple_type_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [157413] = 4,
    ACTIONS(3528), 1,
      anon_sym_LPAREN,
    ACTIONS(8421), 1,
      anon_sym_DOT,
    STATE(3206), 1,
      sym_arguments,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [157427] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8350), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [157437] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8423), 3,
      sym__template_chars,
      anon_sym_BQUOTE,
      anon_sym_DOLLAR_LBRACE,
  [157447] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8319), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [157457] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8319), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [157467] = 4,
    ACTIONS(5225), 1,
      anon_sym_COMMA,
    ACTIONS(5227), 1,
      anon_sym_RBRACK,
    STATE(4997), 1,
      aux_sym_array_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [157481] = 4,
    ACTIONS(8425), 1,
      anon_sym_COMMA,
    ACTIONS(8427), 1,
      anon_sym_RBRACK,
    STATE(4620), 1,
      aux_sym_tuple_type_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [157495] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8429), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [157505] = 4,
    ACTIONS(7881), 1,
      sym_identifier,
    ACTIONS(7883), 1,
      anon_sym_const,
    STATE(5244), 1,
      sym_type_parameter,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [157519] = 4,
    ACTIONS(5060), 1,
      anon_sym_COMMA,
    ACTIONS(8431), 1,
      anon_sym_RBRACE,
    STATE(4974), 1,
      aux_sym_object_pattern_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [157533] = 4,
    ACTIONS(5555), 1,
      anon_sym_COMMA,
    ACTIONS(8433), 1,
      anon_sym_RBRACE,
    STATE(4972), 1,
      aux_sym_object_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [157547] = 4,
    ACTIONS(5555), 1,
      anon_sym_COMMA,
    ACTIONS(8435), 1,
      anon_sym_RBRACE,
    STATE(4972), 1,
      aux_sym_object_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [157561] = 4,
    ACTIONS(8437), 1,
      anon_sym_COMMA,
    ACTIONS(8439), 1,
      anon_sym_RBRACE,
    STATE(4973), 1,
      aux_sym_enum_body_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [157575] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8441), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [157585] = 4,
    ACTIONS(1702), 1,
      anon_sym_RPAREN,
    ACTIONS(8443), 1,
      anon_sym_COMMA,
    STATE(4896), 1,
      aux_sym_formal_parameters_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [157599] = 4,
    ACTIONS(5555), 1,
      anon_sym_COMMA,
    ACTIONS(8445), 1,
      anon_sym_RBRACE,
    STATE(4972), 1,
      aux_sym_object_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [157613] = 4,
    ACTIONS(8447), 1,
      anon_sym_COMMA,
    ACTIONS(8449), 1,
      anon_sym_RBRACE,
    STATE(4973), 1,
      aux_sym_enum_body_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [157627] = 4,
    ACTIONS(2483), 1,
      anon_sym_LBRACE,
    ACTIONS(8451), 1,
      anon_sym_LPAREN,
    STATE(809), 1,
      sym_statement_block,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [157641] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8453), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [157651] = 4,
    ACTIONS(1910), 1,
      anon_sym_COMMA,
    ACTIONS(7879), 1,
      anon_sym_RBRACK,
    STATE(4990), 1,
      aux_sym_array_pattern_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [157665] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8319), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [157675] = 4,
    ACTIONS(5225), 1,
      anon_sym_COMMA,
    ACTIONS(5489), 1,
      anon_sym_RBRACK,
    STATE(4987), 1,
      aux_sym_array_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [157689] = 4,
    ACTIONS(8455), 1,
      anon_sym_COMMA,
    ACTIONS(8458), 1,
      anon_sym_RBRACE,
    STATE(4972), 1,
      aux_sym_object_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [157703] = 4,
    ACTIONS(8460), 1,
      anon_sym_COMMA,
    ACTIONS(8463), 1,
      anon_sym_RBRACE,
    STATE(4973), 1,
      aux_sym_enum_body_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [157717] = 4,
    ACTIONS(8465), 1,
      anon_sym_COMMA,
    ACTIONS(8468), 1,
      anon_sym_RBRACE,
    STATE(4974), 1,
      aux_sym_object_pattern_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [157731] = 4,
    ACTIONS(5225), 1,
      anon_sym_COMMA,
    ACTIONS(5489), 1,
      anon_sym_RBRACK,
    STATE(4997), 1,
      aux_sym_array_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [157745] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8470), 3,
      sym__automatic_semicolon,
      anon_sym_from,
      anon_sym_SEMI,
  [157755] = 4,
    ACTIONS(1910), 1,
      anon_sym_COMMA,
    ACTIONS(7879), 1,
      anon_sym_RBRACK,
    STATE(4998), 1,
      aux_sym_array_pattern_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [157769] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8441), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [157779] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8150), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [157789] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(5718), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
  [157799] = 4,
    ACTIONS(4998), 1,
      anon_sym_extends,
    ACTIONS(8472), 1,
      anon_sym_AMP,
    ACTIONS(8474), 1,
      anon_sym_PIPE,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [157813] = 3,
    ACTIONS(7877), 1,
      anon_sym_EQ,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8476), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK,
  [157825] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8478), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [157835] = 3,
    ACTIONS(8480), 1,
      sym_identifier,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8482), 2,
      sym__automatic_semicolon,
      anon_sym_SEMI,
  [157847] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8076), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [157857] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8192), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [157867] = 4,
    ACTIONS(5225), 1,
      anon_sym_COMMA,
    ACTIONS(8484), 1,
      anon_sym_RBRACK,
    STATE(4997), 1,
      aux_sym_array_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [157881] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8486), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [157891] = 3,
    ACTIONS(8488), 1,
      anon_sym_as,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6475), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
  [157903] = 4,
    ACTIONS(1910), 1,
      anon_sym_COMMA,
    ACTIONS(8490), 1,
      anon_sym_RBRACK,
    STATE(4998), 1,
      aux_sym_array_pattern_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [157917] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8492), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [157927] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6475), 3,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_from,
  [157937] = 3,
    ACTIONS(8494), 1,
      anon_sym_EQ,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8088), 2,
      anon_sym_COMMA,
      anon_sym_from,
  [157949] = 4,
    ACTIONS(6473), 1,
      anon_sym_type,
    ACTIONS(8496), 1,
      sym_identifier,
    STATE(5462), 1,
      sym__import_identifier,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [157963] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8192), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [157973] = 4,
    ACTIONS(7881), 1,
      sym_identifier,
    ACTIONS(7883), 1,
      anon_sym_const,
    STATE(4908), 1,
      sym_type_parameter,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [157987] = 4,
    ACTIONS(5718), 1,
      anon_sym_RBRACK,
    ACTIONS(8498), 1,
      anon_sym_COMMA,
    STATE(4997), 1,
      aux_sym_array_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [158001] = 4,
    ACTIONS(8476), 1,
      anon_sym_RBRACK,
    ACTIONS(8501), 1,
      anon_sym_COMMA,
    STATE(4998), 1,
      aux_sym_array_pattern_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [158015] = 4,
    ACTIONS(8504), 1,
      anon_sym_COMMA,
    ACTIONS(8506), 1,
      anon_sym_RBRACK,
    STATE(5052), 1,
      aux_sym_tuple_type_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [158029] = 4,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(8508), 1,
      anon_sym_EQ,
    STATE(5628), 1,
      sym_type_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [158043] = 4,
    ACTIONS(6698), 1,
      anon_sym_AMP,
    ACTIONS(6702), 1,
      anon_sym_extends,
    ACTIONS(7557), 1,
      anon_sym_PIPE,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [158057] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8206), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [158067] = 3,
    ACTIONS(7745), 1,
      anon_sym_EQ,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3684), 2,
      anon_sym_in,
      anon_sym_of,
  [158079] = 3,
    ACTIONS(8510), 1,
      anon_sym_as,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8088), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
  [158091] = 4,
    ACTIONS(2499), 1,
      anon_sym_LT,
    ACTIONS(8512), 1,
      anon_sym_EQ,
    STATE(5614), 1,
      sym_type_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [158105] = 4,
    ACTIONS(3241), 1,
      anon_sym_GT,
    ACTIONS(8514), 1,
      anon_sym_COMMA,
    STATE(4423), 1,
      aux_sym_implements_clause_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [158119] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8478), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [158129] = 4,
    ACTIONS(1977), 1,
      anon_sym_COMMA,
    ACTIONS(5362), 1,
      anon_sym_RPAREN,
    STATE(5062), 1,
      aux_sym_array_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [158143] = 3,
    ACTIONS(8516), 1,
      sym_identifier,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8518), 2,
      sym__automatic_semicolon,
      anon_sym_SEMI,
  [158155] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8520), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [158165] = 4,
    ACTIONS(1977), 1,
      anon_sym_COMMA,
    ACTIONS(5362), 1,
      anon_sym_RPAREN,
    STATE(4700), 1,
      aux_sym_array_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [158179] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8522), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [158189] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7221), 3,
      anon_sym_LBRACE,
      anon_sym_COLON,
      anon_sym_EQ_GT,
  [158199] = 4,
    ACTIONS(1686), 1,
      anon_sym_RPAREN,
    ACTIONS(8524), 1,
      anon_sym_COMMA,
    STATE(4896), 1,
      aux_sym_formal_parameters_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [158213] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8522), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [158223] = 4,
    ACTIONS(3247), 1,
      anon_sym_GT,
    ACTIONS(8526), 1,
      anon_sym_COMMA,
    STATE(4423), 1,
      aux_sym_implements_clause_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [158237] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8528), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [158247] = 4,
    ACTIONS(6473), 1,
      anon_sym_type,
    ACTIONS(8530), 1,
      sym_identifier,
    STATE(5313), 1,
      sym__import_identifier,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [158261] = 3,
    ACTIONS(7193), 1,
      anon_sym_EQ,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3684), 2,
      anon_sym_in,
      anon_sym_of,
  [158273] = 4,
    ACTIONS(6726), 1,
      anon_sym_RBRACE,
    ACTIONS(8532), 1,
      anon_sym_COMMA,
    STATE(4785), 1,
      aux_sym_named_imports_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [158287] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6064), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [158297] = 4,
    ACTIONS(7095), 1,
      anon_sym_AMP,
    ACTIONS(7097), 1,
      anon_sym_PIPE,
    ACTIONS(7099), 1,
      anon_sym_extends,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [158311] = 4,
    ACTIONS(1910), 1,
      anon_sym_COMMA,
    ACTIONS(8001), 1,
      anon_sym_RBRACK,
    STATE(4998), 1,
      aux_sym_array_pattern_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [158325] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8534), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [158335] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8098), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [158345] = 4,
    ACTIONS(4869), 1,
      anon_sym_COMMA,
    ACTIONS(7318), 1,
      anon_sym_RPAREN,
    STATE(4897), 1,
      aux_sym_sequence_expression_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [158359] = 4,
    ACTIONS(8536), 1,
      sym_identifier,
    ACTIONS(8538), 1,
      anon_sym_LBRACK,
    ACTIONS(8540), 1,
      sym_private_property_identifier,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [158373] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8076), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [158383] = 4,
    ACTIONS(8542), 1,
      anon_sym_COMMA,
    ACTIONS(8544), 1,
      anon_sym_RBRACE,
    STATE(5020), 1,
      aux_sym_named_imports_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [158397] = 4,
    ACTIONS(8546), 1,
      sym_identifier,
    ACTIONS(8548), 1,
      anon_sym_LBRACK,
    ACTIONS(8550), 1,
      sym_private_property_identifier,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [158411] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8552), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [158421] = 4,
    ACTIONS(8554), 1,
      sym_identifier,
    ACTIONS(8556), 1,
      anon_sym_LBRACK,
    ACTIONS(8558), 1,
      sym_private_property_identifier,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [158435] = 4,
    ACTIONS(8560), 1,
      sym_identifier,
    ACTIONS(8562), 1,
      anon_sym_LBRACK,
    ACTIONS(8564), 1,
      sym_private_property_identifier,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [158449] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8098), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [158459] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8080), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [158469] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8520), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [158479] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8566), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [158489] = 4,
    ACTIONS(7885), 1,
      anon_sym_GT,
    ACTIONS(8568), 1,
      anon_sym_COMMA,
    STATE(4684), 1,
      aux_sym_type_parameters_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [158503] = 3,
    ACTIONS(7067), 1,
      anon_sym_DOT,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8570), 2,
      sym__automatic_semicolon,
      anon_sym_SEMI,
  [158515] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8080), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [158525] = 3,
    ACTIONS(7069), 1,
      anon_sym_DOT,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8570), 2,
      sym__automatic_semicolon,
      anon_sym_SEMI,
  [158537] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8096), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [158547] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8082), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [158557] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8572), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [158567] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8574), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [158577] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8522), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [158587] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8566), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [158597] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8076), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [158607] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8576), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [158617] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8098), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [158627] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8192), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [158637] = 4,
    ACTIONS(2833), 1,
      anon_sym_RBRACK,
    ACTIONS(8578), 1,
      anon_sym_COMMA,
    STATE(4949), 1,
      aux_sym_tuple_type_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [158651] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8580), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [158661] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8582), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [158671] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8192), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [158681] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7707), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [158691] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8206), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [158701] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8580), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [158711] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8108), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [158721] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8584), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [158731] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8108), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [158741] = 4,
    ACTIONS(1977), 1,
      anon_sym_COMMA,
    ACTIONS(8586), 1,
      anon_sym_RPAREN,
    STATE(4700), 1,
      aux_sym_array_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [158755] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8108), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [158765] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8084), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [158775] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8588), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [158785] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8319), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [158795] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8319), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [158805] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8098), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [158815] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8098), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [158825] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8096), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [158835] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8108), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [158845] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8108), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [158855] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8084), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [158865] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8108), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [158875] = 3,
    ACTIONS(4391), 1,
      anon_sym_LBRACE,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4393), 2,
      anon_sym_COMMA,
      anon_sym_LBRACE_PIPE,
  [158887] = 3,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4176), 2,
      anon_sym_COMMA,
      anon_sym_LBRACE_PIPE,
  [158899] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8572), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [158909] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8108), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [158919] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8084), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [158929] = 4,
    ACTIONS(6833), 1,
      anon_sym_implements,
    ACTIONS(8590), 1,
      anon_sym_LBRACE,
    STATE(5735), 1,
      sym_implements_clause,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [158943] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8319), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [158953] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8076), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [158963] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8319), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [158973] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8520), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [158983] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8096), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [158993] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8098), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [159003] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8108), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [159013] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8080), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [159023] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8146), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [159033] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8108), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [159043] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8084), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [159053] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8096), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [159063] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8146), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [159073] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8076), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [159083] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8096), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [159093] = 3,
    ACTIONS(8592), 1,
      anon_sym_EQ,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(3622), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK,
  [159105] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8108), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [159115] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8108), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [159125] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8084), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [159135] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8108), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [159145] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8595), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [159155] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8597), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [159165] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8096), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [159175] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8146), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [159185] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8108), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [159195] = 3,
    ACTIONS(8599), 1,
      anon_sym_LBRACE,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7687), 2,
      anon_sym_extends,
      anon_sym_LBRACE_PIPE,
  [159207] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8108), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [159217] = 4,
    ACTIONS(1034), 1,
      anon_sym_LBRACE_PIPE,
    ACTIONS(1610), 1,
      anon_sym_LBRACE,
    STATE(3982), 1,
      sym_object_type,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [159231] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8084), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [159241] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8108), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [159251] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8108), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [159261] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8080), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [159271] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8146), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [159281] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8108), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [159291] = 4,
    ACTIONS(1977), 1,
      anon_sym_COMMA,
    ACTIONS(5283), 1,
      anon_sym_RPAREN,
    STATE(4647), 1,
      aux_sym_array_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [159305] = 4,
    ACTIONS(1977), 1,
      anon_sym_COMMA,
    ACTIONS(5283), 1,
      anon_sym_RPAREN,
    STATE(4700), 1,
      aux_sym_array_repeat1,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [159319] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8082), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [159329] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8098), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [159339] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8098), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [159349] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8146), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [159359] = 4,
    ACTIONS(8601), 1,
      sym_identifier,
    ACTIONS(8603), 1,
      anon_sym_require,
    STATE(5041), 1,
      sym_nested_identifier,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [159373] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8605), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [159383] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8132), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [159393] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8605), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [159403] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7103), 3,
      anon_sym_LBRACE,
      anon_sym_COLON,
      anon_sym_EQ_GT,
  [159413] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8476), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK,
  [159422] = 3,
    ACTIONS(7242), 1,
      anon_sym_LBRACE,
    STATE(2659), 1,
      sym_statement_block,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [159433] = 3,
    ACTIONS(7242), 1,
      anon_sym_LBRACE,
    STATE(2660), 1,
      sym_statement_block,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [159444] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(1698), 2,
      sym__automatic_semicolon,
      anon_sym_SEMI,
  [159453] = 3,
    ACTIONS(8607), 1,
      sym_identifier,
    ACTIONS(8609), 1,
      sym_private_property_identifier,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [159464] = 3,
    ACTIONS(7242), 1,
      anon_sym_LBRACE,
    STATE(2650), 1,
      sym_statement_block,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [159475] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8611), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
  [159484] = 3,
    ACTIONS(7242), 1,
      anon_sym_LBRACE,
    STATE(2695), 1,
      sym_statement_block,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [159495] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(5992), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
  [159504] = 3,
    ACTIONS(7242), 1,
      anon_sym_LBRACE,
    STATE(2662), 1,
      sym_statement_block,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [159515] = 3,
    ACTIONS(8613), 1,
      anon_sym_COMMA,
    ACTIONS(8615), 1,
      anon_sym_from,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [159526] = 3,
    ACTIONS(7242), 1,
      anon_sym_LBRACE,
    STATE(2696), 1,
      sym_statement_block,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [159537] = 3,
    ACTIONS(2483), 1,
      anon_sym_LBRACE,
    STATE(877), 1,
      sym_statement_block,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [159548] = 3,
    ACTIONS(7242), 1,
      anon_sym_LBRACE,
    STATE(2664), 1,
      sym_statement_block,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [159559] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8617), 2,
      anon_sym_in,
      anon_sym_of,
  [159568] = 3,
    ACTIONS(7242), 1,
      anon_sym_LBRACE,
    STATE(2674), 1,
      sym_statement_block,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [159579] = 3,
    ACTIONS(8619), 1,
      anon_sym_LBRACE,
    STATE(860), 1,
      sym_switch_body,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [159590] = 3,
    ACTIONS(8621), 1,
      sym_identifier,
    ACTIONS(8623), 1,
      sym_private_property_identifier,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [159601] = 3,
    ACTIONS(6853), 1,
      anon_sym_LBRACE,
    STATE(4032), 1,
      sym_class_body,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [159612] = 3,
    ACTIONS(6732), 1,
      anon_sym_LBRACE,
    STATE(1691), 1,
      sym_class_body,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [159623] = 3,
    ACTIONS(6453), 1,
      anon_sym_LPAREN,
    STATE(5618), 1,
      sym_formal_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [159634] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6004), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
  [159643] = 3,
    ACTIONS(7242), 1,
      anon_sym_LBRACE,
    STATE(2661), 1,
      sym_statement_block,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [159654] = 3,
    ACTIONS(6732), 1,
      anon_sym_LBRACE,
    STATE(1689), 1,
      sym_class_body,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [159665] = 3,
    ACTIONS(4362), 1,
      anon_sym_LBRACE,
    STATE(1693), 1,
      sym_statement_block,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [159676] = 3,
    ACTIONS(7242), 1,
      anon_sym_LBRACE,
    STATE(2670), 1,
      sym_statement_block,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [159687] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8625), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
  [159696] = 3,
    ACTIONS(6732), 1,
      anon_sym_LBRACE,
    STATE(2596), 1,
      sym_class_body,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [159707] = 3,
    ACTIONS(8627), 1,
      sym_identifier,
    ACTIONS(8629), 1,
      sym_private_property_identifier,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [159718] = 3,
    ACTIONS(7242), 1,
      anon_sym_LBRACE,
    STATE(2693), 1,
      sym_statement_block,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [159729] = 3,
    ACTIONS(3557), 1,
      anon_sym_COLON,
    STATE(5277), 1,
      sym_type_annotation,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [159740] = 3,
    ACTIONS(6732), 1,
      anon_sym_LBRACE,
    STATE(2598), 1,
      sym_class_body,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [159751] = 3,
    ACTIONS(6453), 1,
      anon_sym_LPAREN,
    STATE(4125), 1,
      sym_formal_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [159762] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8631), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK,
  [159771] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8633), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK,
  [159780] = 3,
    ACTIONS(8635), 1,
      anon_sym_SEMI,
    ACTIONS(8637), 1,
      sym__automatic_semicolon,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [159791] = 3,
    ACTIONS(8102), 1,
      sym_identifier,
    ACTIONS(8106), 1,
      sym_private_property_identifier,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [159802] = 3,
    ACTIONS(6453), 1,
      anon_sym_LPAREN,
    STATE(5709), 1,
      sym_formal_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [159813] = 3,
    ACTIONS(7242), 1,
      anon_sym_LBRACE,
    STATE(2671), 1,
      sym_statement_block,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [159824] = 3,
    ACTIONS(3557), 1,
      anon_sym_COLON,
    STATE(5159), 1,
      sym_type_annotation,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [159835] = 3,
    ACTIONS(8639), 1,
      sym_identifier,
    ACTIONS(8641), 1,
      sym_private_property_identifier,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [159846] = 3,
    ACTIONS(6453), 1,
      anon_sym_LPAREN,
    STATE(5775), 1,
      sym_formal_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [159857] = 3,
    ACTIONS(8643), 1,
      anon_sym_LPAREN,
    STATE(50), 1,
      sym__for_header,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [159868] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8383), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
  [159877] = 3,
    ACTIONS(7242), 1,
      anon_sym_LBRACE,
    STATE(2672), 1,
      sym_statement_block,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [159888] = 3,
    ACTIONS(6732), 1,
      anon_sym_LBRACE,
    STATE(2575), 1,
      sym_class_body,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [159899] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8645), 2,
      sym__automatic_semicolon,
      anon_sym_SEMI,
  [159908] = 3,
    ACTIONS(8647), 1,
      sym_identifier,
    ACTIONS(8649), 1,
      sym_private_property_identifier,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [159919] = 3,
    ACTIONS(6453), 1,
      anon_sym_LPAREN,
    STATE(5493), 1,
      sym_formal_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [159930] = 3,
    ACTIONS(6718), 1,
      anon_sym_LBRACE,
    STATE(2246), 1,
      sym_class_body,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [159941] = 3,
    ACTIONS(8651), 1,
      sym_identifier,
    ACTIONS(8653), 1,
      sym_private_property_identifier,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [159952] = 3,
    ACTIONS(7242), 1,
      anon_sym_LBRACE,
    STATE(2691), 1,
      sym_statement_block,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [159963] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8655), 2,
      anon_sym_COMMA,
      anon_sym_GT,
  [159972] = 3,
    ACTIONS(6453), 1,
      anon_sym_LPAREN,
    STATE(5841), 1,
      sym_formal_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [159983] = 3,
    ACTIONS(8657), 1,
      anon_sym_LPAREN,
    STATE(34), 1,
      sym_parenthesized_expression,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [159994] = 3,
    ACTIONS(4588), 1,
      anon_sym_LPAREN,
    STATE(2251), 1,
      sym_arguments,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [160005] = 3,
    ACTIONS(8659), 1,
      anon_sym_LBRACE,
    STATE(3946), 1,
      sym_enum_body,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [160016] = 3,
    ACTIONS(6718), 1,
      anon_sym_LBRACE,
    STATE(2163), 1,
      sym_class_body,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [160027] = 3,
    ACTIONS(8661), 1,
      sym_identifier,
    ACTIONS(8663), 1,
      sym_private_property_identifier,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [160038] = 3,
    ACTIONS(7242), 1,
      anon_sym_LBRACE,
    STATE(2679), 1,
      sym_statement_block,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [160049] = 3,
    ACTIONS(8657), 1,
      anon_sym_LPAREN,
    STATE(35), 1,
      sym_parenthesized_expression,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [160060] = 3,
    ACTIONS(4362), 1,
      anon_sym_LBRACE,
    STATE(1695), 1,
      sym_statement_block,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [160071] = 3,
    ACTIONS(6732), 1,
      anon_sym_LBRACE,
    STATE(1697), 1,
      sym_class_body,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [160082] = 3,
    ACTIONS(8657), 1,
      anon_sym_LPAREN,
    STATE(37), 1,
      sym_parenthesized_expression,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [160093] = 3,
    ACTIONS(8665), 1,
      sym_identifier,
    ACTIONS(8667), 1,
      sym_private_property_identifier,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [160104] = 3,
    ACTIONS(8669), 1,
      sym_identifier,
    ACTIONS(8671), 1,
      sym_private_property_identifier,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [160115] = 3,
    ACTIONS(6853), 1,
      anon_sym_LBRACE,
    STATE(4044), 1,
      sym_class_body,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [160126] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7347), 2,
      anon_sym_LBRACE,
      anon_sym_EQ_GT,
  [160135] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4530), 2,
      sym__automatic_semicolon,
      anon_sym_SEMI,
  [160144] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4534), 2,
      sym__automatic_semicolon,
      anon_sym_SEMI,
  [160153] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7454), 2,
      anon_sym_LBRACE,
      anon_sym_EQ_GT,
  [160162] = 3,
    ACTIONS(8673), 1,
      anon_sym_SEMI,
    ACTIONS(8675), 1,
      sym__automatic_semicolon,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [160173] = 3,
    ACTIONS(8677), 1,
      anon_sym_LBRACE,
    STATE(846), 1,
      sym_enum_body,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [160184] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7490), 2,
      anon_sym_LBRACE,
      anon_sym_EQ_GT,
  [160193] = 3,
    ACTIONS(8679), 1,
      sym_identifier,
    ACTIONS(8681), 1,
      sym_private_property_identifier,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [160204] = 3,
    ACTIONS(6718), 1,
      anon_sym_LBRACE,
    STATE(2258), 1,
      sym_class_body,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [160215] = 3,
    ACTIONS(7921), 1,
      anon_sym_from,
    STATE(5423), 1,
      sym__from_clause,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [160226] = 3,
    ACTIONS(8683), 1,
      anon_sym_SEMI,
    ACTIONS(8685), 1,
      sym__automatic_semicolon,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [160237] = 3,
    ACTIONS(6853), 1,
      anon_sym_LBRACE,
    STATE(4045), 1,
      sym_class_body,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [160248] = 3,
    ACTIONS(6453), 1,
      anon_sym_LPAREN,
    STATE(5505), 1,
      sym_formal_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [160259] = 3,
    ACTIONS(7921), 1,
      anon_sym_from,
    STATE(5457), 1,
      sym__from_clause,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [160270] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8687), 2,
      sym__automatic_semicolon,
      anon_sym_SEMI,
  [160279] = 3,
    ACTIONS(6453), 1,
      anon_sym_LPAREN,
    STATE(5556), 1,
      sym_formal_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [160290] = 3,
    ACTIONS(2483), 1,
      anon_sym_LBRACE,
    STATE(807), 1,
      sym_statement_block,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [160301] = 3,
    ACTIONS(6453), 1,
      anon_sym_LPAREN,
    STATE(5832), 1,
      sym_formal_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [160312] = 3,
    ACTIONS(8657), 1,
      anon_sym_LPAREN,
    STATE(57), 1,
      sym_parenthesized_expression,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [160323] = 3,
    ACTIONS(7242), 1,
      anon_sym_LBRACE,
    STATE(2668), 1,
      sym_statement_block,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [160334] = 3,
    ACTIONS(7242), 1,
      anon_sym_LBRACE,
    STATE(2669), 1,
      sym_statement_block,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [160345] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6004), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
  [160354] = 3,
    ACTIONS(6732), 1,
      anon_sym_LBRACE,
    STATE(1698), 1,
      sym_class_body,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [160365] = 3,
    ACTIONS(4362), 1,
      anon_sym_LBRACE,
    STATE(1699), 1,
      sym_statement_block,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [160376] = 3,
    ACTIONS(2483), 1,
      anon_sym_LBRACE,
    STATE(5389), 1,
      sym_statement_block,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [160387] = 3,
    ACTIONS(8689), 1,
      sym_identifier,
    STATE(5041), 1,
      sym_nested_identifier,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [160398] = 3,
    ACTIONS(6853), 1,
      anon_sym_LBRACE,
    STATE(804), 1,
      sym_class_body,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [160409] = 3,
    ACTIONS(4362), 1,
      anon_sym_LBRACE,
    STATE(1700), 1,
      sym_statement_block,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [160420] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6008), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
  [160429] = 3,
    ACTIONS(8643), 1,
      anon_sym_LPAREN,
    STATE(39), 1,
      sym__for_header,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [160440] = 3,
    ACTIONS(6732), 1,
      anon_sym_LBRACE,
    STATE(1701), 1,
      sym_class_body,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [160451] = 3,
    ACTIONS(4336), 1,
      anon_sym_LBRACE,
    STATE(2168), 1,
      sym_statement_block,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [160462] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8468), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
  [160471] = 3,
    ACTIONS(7242), 1,
      anon_sym_LBRACE,
    STATE(2666), 1,
      sym_statement_block,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [160482] = 3,
    ACTIONS(6718), 1,
      anon_sym_LBRACE,
    STATE(2164), 1,
      sym_class_body,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [160493] = 3,
    ACTIONS(1678), 1,
      anon_sym_LBRACE,
    STATE(232), 1,
      sym_statement_block,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [160504] = 3,
    ACTIONS(7065), 1,
      anon_sym_LBRACE,
    STATE(4371), 1,
      sym_statement_block,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [160515] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8458), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
  [160524] = 3,
    ACTIONS(6853), 1,
      anon_sym_LBRACE,
    STATE(3999), 1,
      sym_class_body,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [160535] = 3,
    ACTIONS(8657), 1,
      anon_sym_LPAREN,
    STATE(5142), 1,
      sym_parenthesized_expression,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [160546] = 3,
    ACTIONS(3281), 1,
      anon_sym_LPAREN,
    STATE(3304), 1,
      sym_formal_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [160557] = 3,
    ACTIONS(6732), 1,
      anon_sym_LBRACE,
    STATE(1679), 1,
      sym_class_body,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [160568] = 3,
    ACTIONS(4362), 1,
      anon_sym_LBRACE,
    STATE(1681), 1,
      sym_statement_block,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [160579] = 3,
    ACTIONS(4362), 1,
      anon_sym_LBRACE,
    STATE(1684), 1,
      sym_statement_block,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [160590] = 3,
    ACTIONS(6847), 1,
      anon_sym_LBRACE,
    STATE(220), 1,
      sym_class_body,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [160601] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6020), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
  [160610] = 3,
    ACTIONS(8659), 1,
      anon_sym_LBRACE,
    STATE(4375), 1,
      sym_enum_body,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [160621] = 3,
    ACTIONS(2483), 1,
      anon_sym_LBRACE,
    STATE(5392), 1,
      sym_statement_block,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [160632] = 3,
    ACTIONS(4336), 1,
      anon_sym_LBRACE,
    STATE(2259), 1,
      sym_statement_block,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [160643] = 3,
    ACTIONS(2483), 1,
      anon_sym_LBRACE,
    STATE(5433), 1,
      sym_statement_block,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [160654] = 3,
    ACTIONS(6453), 1,
      anon_sym_LPAREN,
    STATE(5646), 1,
      sym_formal_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [160665] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8243), 2,
      anon_sym_COMMA,
      anon_sym_GT,
  [160674] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(5024), 2,
      sym__automatic_semicolon,
      anon_sym_SEMI,
  [160683] = 3,
    ACTIONS(3281), 1,
      anon_sym_LPAREN,
    STATE(3659), 1,
      sym_formal_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [160694] = 3,
    ACTIONS(4336), 1,
      anon_sym_LBRACE,
    STATE(2318), 1,
      sym_statement_block,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [160705] = 3,
    ACTIONS(6453), 1,
      anon_sym_LPAREN,
    STATE(5469), 1,
      sym_formal_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [160716] = 3,
    ACTIONS(6509), 1,
      anon_sym_LPAREN,
    STATE(3361), 1,
      sym_formal_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [160727] = 3,
    ACTIONS(4336), 1,
      anon_sym_LBRACE,
    STATE(2304), 1,
      sym_statement_block,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [160738] = 3,
    ACTIONS(6453), 1,
      anon_sym_LPAREN,
    STATE(5483), 1,
      sym_formal_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [160749] = 3,
    ACTIONS(6453), 1,
      anon_sym_LPAREN,
    STATE(5549), 1,
      sym_formal_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [160760] = 3,
    ACTIONS(6453), 1,
      anon_sym_LPAREN,
    STATE(5665), 1,
      sym_formal_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [160771] = 3,
    ACTIONS(8691), 1,
      sym_identifier,
    ACTIONS(8693), 1,
      sym_private_property_identifier,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [160782] = 3,
    ACTIONS(6923), 1,
      anon_sym_LBRACE,
    STATE(934), 1,
      sym_class_body,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [160793] = 3,
    ACTIONS(7242), 1,
      anon_sym_LBRACE,
    STATE(2692), 1,
      sym_statement_block,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [160804] = 3,
    ACTIONS(7242), 1,
      anon_sym_LBRACE,
    STATE(2658), 1,
      sym_statement_block,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [160815] = 3,
    ACTIONS(7921), 1,
      anon_sym_from,
    STATE(4289), 1,
      sym__from_clause,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [160826] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(5996), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
  [160835] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8408), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
  [160844] = 3,
    ACTIONS(2483), 1,
      anon_sym_LBRACE,
    STATE(5441), 1,
      sym_statement_block,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [160855] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6038), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
  [160864] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8695), 2,
      anon_sym_COMMA,
      anon_sym_GT,
  [160873] = 3,
    ACTIONS(8697), 1,
      sym_identifier,
    ACTIONS(8699), 1,
      sym_private_property_identifier,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [160884] = 3,
    ACTIONS(7242), 1,
      anon_sym_LBRACE,
    STATE(2649), 1,
      sym_statement_block,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [160895] = 3,
    ACTIONS(8701), 1,
      sym_identifier,
    ACTIONS(8703), 1,
      sym_private_property_identifier,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [160906] = 3,
    ACTIONS(7242), 1,
      anon_sym_LBRACE,
    STATE(2685), 1,
      sym_statement_block,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [160917] = 3,
    ACTIONS(6718), 1,
      anon_sym_LBRACE,
    STATE(2281), 1,
      sym_class_body,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [160928] = 3,
    ACTIONS(8705), 1,
      sym_identifier,
    ACTIONS(8707), 1,
      sym_private_property_identifier,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [160939] = 3,
    ACTIONS(2483), 1,
      anon_sym_LBRACE,
    STATE(745), 1,
      sym_statement_block,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [160950] = 3,
    ACTIONS(8709), 1,
      sym_identifier,
    ACTIONS(8711), 1,
      sym_private_property_identifier,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [160961] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8713), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
  [160970] = 3,
    ACTIONS(8715), 1,
      sym_identifier,
    ACTIONS(8717), 1,
      sym_private_property_identifier,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [160981] = 3,
    ACTIONS(8719), 1,
      sym_identifier,
    ACTIONS(8721), 1,
      sym_private_property_identifier,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [160992] = 3,
    ACTIONS(8723), 1,
      sym_identifier,
    ACTIONS(8725), 1,
      sym_private_property_identifier,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [161003] = 3,
    ACTIONS(1678), 1,
      anon_sym_LBRACE,
    STATE(223), 1,
      sym_statement_block,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [161014] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8727), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK,
  [161023] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8419), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK,
  [161032] = 3,
    ACTIONS(8729), 1,
      sym_identifier,
    ACTIONS(8731), 1,
      sym_private_property_identifier,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [161043] = 3,
    ACTIONS(8090), 1,
      sym_identifier,
    ACTIONS(8094), 1,
      sym_private_property_identifier,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [161054] = 3,
    ACTIONS(8733), 1,
      sym_identifier,
    ACTIONS(8735), 1,
      sym_private_property_identifier,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [161065] = 3,
    ACTIONS(8737), 1,
      sym_identifier,
    ACTIONS(8739), 1,
      sym_private_property_identifier,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [161076] = 3,
    ACTIONS(8741), 1,
      sym_identifier,
    ACTIONS(8743), 1,
      sym_private_property_identifier,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [161087] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(5012), 2,
      sym__automatic_semicolon,
      anon_sym_SEMI,
  [161096] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8745), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
  [161105] = 3,
    ACTIONS(8284), 1,
      sym_identifier,
    ACTIONS(8288), 1,
      sym_private_property_identifier,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [161116] = 3,
    ACTIONS(6923), 1,
      anon_sym_LBRACE,
    STATE(890), 1,
      sym_class_body,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [161127] = 3,
    ACTIONS(4336), 1,
      anon_sym_LBRACE,
    STATE(2283), 1,
      sym_statement_block,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [161138] = 3,
    ACTIONS(8747), 1,
      anon_sym_LPAREN,
    STATE(785), 1,
      sym_parenthesized_expression,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [161149] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8749), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
  [161158] = 3,
    ACTIONS(6453), 1,
      anon_sym_LPAREN,
    STATE(3972), 1,
      sym_formal_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [161169] = 3,
    ACTIONS(6453), 1,
      anon_sym_LPAREN,
    STATE(5503), 1,
      sym_formal_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [161180] = 3,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    STATE(1669), 1,
      sym_arguments,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [161191] = 3,
    ACTIONS(8751), 1,
      sym_identifier,
    ACTIONS(8753), 1,
      sym_private_property_identifier,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [161202] = 3,
    ACTIONS(2483), 1,
      anon_sym_LBRACE,
    STATE(915), 1,
      sym_statement_block,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [161213] = 3,
    ACTIONS(6853), 1,
      anon_sym_LBRACE,
    STATE(4067), 1,
      sym_class_body,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [161224] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6000), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
  [161233] = 3,
    ACTIONS(4010), 1,
      anon_sym_LPAREN,
    STATE(1688), 1,
      sym_arguments,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [161244] = 3,
    ACTIONS(6847), 1,
      anon_sym_LBRACE,
    STATE(227), 1,
      sym_class_body,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [161255] = 3,
    ACTIONS(6718), 1,
      anon_sym_LBRACE,
    STATE(2180), 1,
      sym_class_body,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [161266] = 3,
    ACTIONS(2483), 1,
      anon_sym_LBRACE,
    STATE(5262), 1,
      sym_statement_block,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [161277] = 3,
    ACTIONS(8755), 1,
      sym_identifier,
    ACTIONS(8757), 1,
      anon_sym_STAR,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [161288] = 3,
    ACTIONS(6847), 1,
      anon_sym_LBRACE,
    STATE(233), 1,
      sym_class_body,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [161299] = 3,
    ACTIONS(6923), 1,
      anon_sym_LBRACE,
    STATE(863), 1,
      sym_class_body,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [161310] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(5022), 2,
      sym__automatic_semicolon,
      anon_sym_SEMI,
  [161319] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7375), 2,
      anon_sym_LBRACE,
      anon_sym_EQ_GT,
  [161328] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8759), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
  [161337] = 3,
    ACTIONS(8166), 1,
      sym_identifier,
    ACTIONS(8170), 1,
      sym_private_property_identifier,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [161348] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(7774), 2,
      sym__automatic_semicolon,
      anon_sym_SEMI,
  [161357] = 3,
    ACTIONS(7065), 1,
      anon_sym_LBRACE,
    STATE(801), 1,
      sym_statement_block,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [161368] = 3,
    ACTIONS(8761), 1,
      sym_identifier,
    ACTIONS(8763), 1,
      sym_private_property_identifier,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [161379] = 3,
    ACTIONS(6853), 1,
      anon_sym_LBRACE,
    STATE(806), 1,
      sym_class_body,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [161390] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8765), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
  [161399] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8330), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
  [161408] = 3,
    ACTIONS(2483), 1,
      anon_sym_LBRACE,
    STATE(5416), 1,
      sym_statement_block,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [161419] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6024), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
  [161428] = 3,
    ACTIONS(8767), 1,
      sym_identifier,
    ACTIONS(8769), 1,
      sym_private_property_identifier,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [161439] = 3,
    ACTIONS(2483), 1,
      anon_sym_LBRACE,
    STATE(5434), 1,
      sym_statement_block,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [161450] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8771), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
  [161459] = 3,
    ACTIONS(8773), 1,
      sym_identifier,
    ACTIONS(8775), 1,
      sym_private_property_identifier,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [161470] = 3,
    ACTIONS(8777), 1,
      sym_identifier,
    ACTIONS(8779), 1,
      sym_private_property_identifier,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [161481] = 3,
    ACTIONS(7242), 1,
      anon_sym_LBRACE,
    STATE(2702), 1,
      sym_statement_block,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [161492] = 3,
    ACTIONS(8781), 1,
      sym_identifier,
    ACTIONS(8783), 1,
      sym_private_property_identifier,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [161503] = 3,
    ACTIONS(4336), 1,
      anon_sym_LBRACE,
    STATE(2265), 1,
      sym_statement_block,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [161514] = 3,
    ACTIONS(8785), 1,
      sym_identifier,
    ACTIONS(8787), 1,
      sym_private_property_identifier,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [161525] = 3,
    ACTIONS(6718), 1,
      anon_sym_LBRACE,
    STATE(2279), 1,
      sym_class_body,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [161536] = 3,
    ACTIONS(8789), 1,
      sym_identifier,
    ACTIONS(8791), 1,
      sym_private_property_identifier,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [161547] = 3,
    ACTIONS(6453), 1,
      anon_sym_LPAREN,
    STATE(3765), 1,
      sym_formal_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [161558] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8793), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
  [161567] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8795), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
  [161576] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8797), 2,
      sym__automatic_semicolon,
      anon_sym_SEMI,
  [161585] = 3,
    ACTIONS(6718), 1,
      anon_sym_LBRACE,
    STATE(2319), 1,
      sym_class_body,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [161596] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4606), 2,
      sym__automatic_semicolon,
      anon_sym_SEMI,
  [161605] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8799), 2,
      sym__automatic_semicolon,
      anon_sym_SEMI,
  [161614] = 3,
    ACTIONS(7242), 1,
      anon_sym_LBRACE,
    STATE(2704), 1,
      sym_statement_block,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [161625] = 3,
    ACTIONS(7242), 1,
      anon_sym_LBRACE,
    STATE(2680), 1,
      sym_statement_block,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [161636] = 3,
    ACTIONS(7921), 1,
      anon_sym_from,
    STATE(4296), 1,
      sym__from_clause,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [161647] = 3,
    ACTIONS(8801), 1,
      sym_identifier,
    ACTIONS(8803), 1,
      sym_private_property_identifier,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [161658] = 3,
    ACTIONS(8805), 1,
      sym_identifier,
    ACTIONS(8807), 1,
      sym_private_property_identifier,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [161669] = 3,
    ACTIONS(6718), 1,
      anon_sym_LBRACE,
    STATE(2309), 1,
      sym_class_body,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [161680] = 3,
    ACTIONS(6853), 1,
      anon_sym_LBRACE,
    STATE(4072), 1,
      sym_class_body,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [161691] = 3,
    ACTIONS(7709), 1,
      anon_sym_in,
    ACTIONS(7711), 1,
      anon_sym_of,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [161702] = 3,
    ACTIONS(6732), 1,
      anon_sym_LBRACE,
    STATE(2603), 1,
      sym_class_body,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [161713] = 3,
    ACTIONS(6453), 1,
      anon_sym_LPAREN,
    STATE(4277), 1,
      sym_formal_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [161724] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6032), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
  [161733] = 3,
    ACTIONS(2483), 1,
      anon_sym_LBRACE,
    STATE(5214), 1,
      sym_statement_block,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [161744] = 3,
    ACTIONS(8809), 1,
      sym_identifier,
    ACTIONS(8811), 1,
      anon_sym_STAR,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [161755] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(5992), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
  [161764] = 3,
    ACTIONS(2483), 1,
      anon_sym_LBRACE,
    STATE(808), 1,
      sym_statement_block,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [161775] = 3,
    ACTIONS(2483), 1,
      anon_sym_LBRACE,
    STATE(5221), 1,
      sym_statement_block,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [161786] = 3,
    ACTIONS(8813), 1,
      sym_identifier,
    STATE(4566), 1,
      sym_nested_identifier,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [161797] = 3,
    ACTIONS(8815), 1,
      sym_identifier,
    ACTIONS(8817), 1,
      sym_private_property_identifier,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [161808] = 3,
    ACTIONS(8819), 1,
      anon_sym_LBRACE,
    STATE(5413), 1,
      sym_object,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [161819] = 3,
    ACTIONS(8821), 1,
      sym_identifier,
    ACTIONS(8823), 1,
      sym_private_property_identifier,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [161830] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8825), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
  [161839] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8827), 2,
      sym__automatic_semicolon,
      anon_sym_SEMI,
  [161848] = 3,
    ACTIONS(8829), 1,
      sym_identifier,
    ACTIONS(8831), 1,
      sym_private_property_identifier,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [161859] = 3,
    ACTIONS(8833), 1,
      anon_sym_in,
    ACTIONS(8835), 1,
      anon_sym_COLON,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [161870] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8837), 2,
      sym__automatic_semicolon,
      anon_sym_SEMI,
  [161879] = 3,
    ACTIONS(4658), 1,
      anon_sym_LBRACE,
    STATE(2717), 1,
      sym_statement_block,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [161890] = 3,
    ACTIONS(6453), 1,
      anon_sym_LPAREN,
    STATE(5499), 1,
      sym_formal_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [161901] = 3,
    ACTIONS(6853), 1,
      anon_sym_LBRACE,
    STATE(4074), 1,
      sym_class_body,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [161912] = 3,
    ACTIONS(7242), 1,
      anon_sym_LBRACE,
    STATE(2687), 1,
      sym_statement_block,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [161923] = 3,
    ACTIONS(8839), 1,
      sym_identifier,
    ACTIONS(8841), 1,
      anon_sym_STAR,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [161934] = 3,
    ACTIONS(7242), 1,
      anon_sym_LBRACE,
    STATE(2688), 1,
      sym_statement_block,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [161945] = 3,
    ACTIONS(4362), 1,
      anon_sym_LBRACE,
    STATE(1703), 1,
      sym_statement_block,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [161956] = 3,
    ACTIONS(7242), 1,
      anon_sym_LBRACE,
    STATE(2701), 1,
      sym_statement_block,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [161967] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(5988), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
  [161976] = 3,
    ACTIONS(6732), 1,
      anon_sym_LBRACE,
    STATE(1704), 1,
      sym_class_body,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [161987] = 3,
    ACTIONS(6455), 1,
      anon_sym_COLON,
    STATE(5101), 1,
      sym_type_annotation,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [161998] = 3,
    ACTIONS(8843), 1,
      anon_sym_SEMI,
    ACTIONS(8845), 1,
      sym__automatic_semicolon,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [162009] = 3,
    ACTIONS(6453), 1,
      anon_sym_LPAREN,
    STATE(3989), 1,
      sym_formal_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [162020] = 3,
    ACTIONS(7242), 1,
      anon_sym_LBRACE,
    STATE(2654), 1,
      sym_statement_block,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [162031] = 3,
    ACTIONS(6718), 1,
      anon_sym_LBRACE,
    STATE(2185), 1,
      sym_class_body,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [162042] = 3,
    ACTIONS(6453), 1,
      anon_sym_LPAREN,
    STATE(5651), 1,
      sym_formal_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [162053] = 3,
    ACTIONS(4588), 1,
      anon_sym_LPAREN,
    STATE(2220), 1,
      sym_arguments,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [162064] = 3,
    ACTIONS(4336), 1,
      anon_sym_LBRACE,
    STATE(2187), 1,
      sym_statement_block,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [162075] = 3,
    ACTIONS(6453), 1,
      anon_sym_LPAREN,
    STATE(5858), 1,
      sym_formal_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [162086] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8303), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
  [162095] = 3,
    ACTIONS(8536), 1,
      sym_identifier,
    ACTIONS(8540), 1,
      sym_private_property_identifier,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [162106] = 3,
    ACTIONS(7242), 1,
      anon_sym_LBRACE,
    STATE(2663), 1,
      sym_statement_block,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [162117] = 3,
    ACTIONS(8847), 1,
      sym_identifier,
    ACTIONS(8849), 1,
      sym_private_property_identifier,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [162128] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(4472), 2,
      sym__automatic_semicolon,
      anon_sym_SEMI,
  [162137] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8851), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
  [162146] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8853), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
  [162155] = 3,
    ACTIONS(8855), 1,
      sym_identifier,
    ACTIONS(8857), 1,
      sym_private_property_identifier,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [162166] = 3,
    ACTIONS(6453), 1,
      anon_sym_LPAREN,
    STATE(5704), 1,
      sym_formal_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [162177] = 3,
    ACTIONS(8859), 1,
      sym_identifier,
    ACTIONS(8861), 1,
      sym_private_property_identifier,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [162188] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6012), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
  [162197] = 3,
    ACTIONS(7065), 1,
      anon_sym_LBRACE,
    STATE(3998), 1,
      sym_statement_block,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [162208] = 3,
    ACTIONS(2483), 1,
      anon_sym_LBRACE,
    STATE(5238), 1,
      sym_statement_block,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [162219] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6016), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
  [162228] = 3,
    ACTIONS(7242), 1,
      anon_sym_LBRACE,
    STATE(2707), 1,
      sym_statement_block,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [162239] = 3,
    ACTIONS(6853), 1,
      anon_sym_LBRACE,
    STATE(792), 1,
      sym_class_body,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [162250] = 3,
    ACTIONS(6923), 1,
      anon_sym_LBRACE,
    STATE(898), 1,
      sym_class_body,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [162261] = 3,
    ACTIONS(8863), 1,
      sym_identifier,
    ACTIONS(8865), 1,
      sym_private_property_identifier,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [162272] = 3,
    ACTIONS(6847), 1,
      anon_sym_LBRACE,
    STATE(224), 1,
      sym_class_body,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [162283] = 3,
    ACTIONS(8867), 1,
      anon_sym_SEMI,
    ACTIONS(8869), 1,
      sym__automatic_semicolon,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [162294] = 3,
    ACTIONS(7065), 1,
      anon_sym_LBRACE,
    STATE(796), 1,
      sym_statement_block,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [162305] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8871), 2,
      sym__automatic_semicolon,
      anon_sym_SEMI,
  [162314] = 3,
    ACTIONS(7242), 1,
      anon_sym_LBRACE,
    STATE(2665), 1,
      sym_statement_block,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [162325] = 3,
    ACTIONS(7242), 1,
      anon_sym_LBRACE,
    STATE(2703), 1,
      sym_statement_block,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [162336] = 3,
    ACTIONS(8873), 1,
      sym_identifier,
    ACTIONS(8875), 1,
      anon_sym_STAR,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [162347] = 3,
    ACTIONS(8877), 1,
      sym_identifier,
    ACTIONS(8879), 1,
      sym_private_property_identifier,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [162358] = 3,
    ACTIONS(7065), 1,
      anon_sym_LBRACE,
    STATE(4007), 1,
      sym_statement_block,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [162369] = 3,
    ACTIONS(7242), 1,
      anon_sym_LBRACE,
    STATE(2708), 1,
      sym_statement_block,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [162380] = 3,
    ACTIONS(8677), 1,
      anon_sym_LBRACE,
    STATE(907), 1,
      sym_enum_body,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [162391] = 3,
    ACTIONS(6853), 1,
      anon_sym_LBRACE,
    STATE(797), 1,
      sym_class_body,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [162402] = 3,
    ACTIONS(6718), 1,
      anon_sym_LBRACE,
    STATE(2190), 1,
      sym_class_body,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [162413] = 3,
    ACTIONS(4336), 1,
      anon_sym_LBRACE,
    STATE(2192), 1,
      sym_statement_block,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [162424] = 3,
    ACTIONS(3281), 1,
      anon_sym_LPAREN,
    STATE(3571), 1,
      sym_formal_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [162435] = 3,
    ACTIONS(7242), 1,
      anon_sym_LBRACE,
    STATE(2710), 1,
      sym_statement_block,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [162446] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8881), 2,
      sym__automatic_semicolon,
      anon_sym_SEMI,
  [162455] = 3,
    ACTIONS(6718), 1,
      anon_sym_LBRACE,
    STATE(2197), 1,
      sym_class_body,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [162466] = 3,
    ACTIONS(7242), 1,
      anon_sym_LBRACE,
    STATE(2651), 1,
      sym_statement_block,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [162477] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(5996), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
  [162486] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8883), 2,
      anon_sym_COMMA,
      anon_sym_GT,
  [162495] = 3,
    ACTIONS(6718), 1,
      anon_sym_LBRACE,
    STATE(2230), 1,
      sym_class_body,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [162506] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8885), 2,
      anon_sym_COMMA,
      anon_sym_GT,
  [162515] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6032), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
  [162524] = 3,
    ACTIONS(4336), 1,
      anon_sym_LBRACE,
    STATE(2200), 1,
      sym_statement_block,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [162535] = 3,
    ACTIONS(6853), 1,
      anon_sym_LBRACE,
    STATE(4091), 1,
      sym_class_body,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [162546] = 3,
    ACTIONS(8887), 1,
      anon_sym_SEMI,
    ACTIONS(8889), 1,
      sym__automatic_semicolon,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [162557] = 3,
    ACTIONS(7242), 1,
      anon_sym_LBRACE,
    STATE(2712), 1,
      sym_statement_block,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [162568] = 3,
    ACTIONS(2483), 1,
      anon_sym_LBRACE,
    STATE(5345), 1,
      sym_statement_block,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [162579] = 3,
    ACTIONS(7242), 1,
      anon_sym_LBRACE,
    STATE(2653), 1,
      sym_statement_block,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [162590] = 3,
    ACTIONS(8891), 1,
      sym_identifier,
    ACTIONS(8893), 1,
      sym_private_property_identifier,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [162601] = 3,
    ACTIONS(8895), 1,
      anon_sym_SEMI,
    ACTIONS(8897), 1,
      sym__automatic_semicolon,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [162612] = 3,
    ACTIONS(4336), 1,
      anon_sym_LBRACE,
    STATE(2206), 1,
      sym_statement_block,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [162623] = 3,
    ACTIONS(6718), 1,
      anon_sym_LBRACE,
    STATE(2194), 1,
      sym_class_body,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [162634] = 3,
    ACTIONS(7242), 1,
      anon_sym_LBRACE,
    STATE(2690), 1,
      sym_statement_block,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [162645] = 3,
    ACTIONS(2483), 1,
      anon_sym_LBRACE,
    STATE(5465), 1,
      sym_statement_block,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [162656] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(5988), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
  [162665] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6000), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
  [162674] = 3,
    ACTIONS(2483), 1,
      anon_sym_LBRACE,
    STATE(5348), 1,
      sym_statement_block,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [162685] = 3,
    ACTIONS(7242), 1,
      anon_sym_LBRACE,
    STATE(2705), 1,
      sym_statement_block,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [162696] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8899), 2,
      sym__automatic_semicolon,
      anon_sym_SEMI,
  [162705] = 3,
    ACTIONS(2483), 1,
      anon_sym_LBRACE,
    STATE(5316), 1,
      sym_statement_block,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [162716] = 3,
    ACTIONS(7242), 1,
      anon_sym_LBRACE,
    STATE(2673), 1,
      sym_statement_block,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [162727] = 3,
    ACTIONS(3514), 1,
      anon_sym_LPAREN,
    STATE(1287), 1,
      sym_arguments,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [162738] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6042), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
  [162747] = 3,
    ACTIONS(6066), 1,
      anon_sym_LPAREN,
    STATE(2790), 1,
      sym_arguments,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [162758] = 3,
    ACTIONS(7242), 1,
      anon_sym_LBRACE,
    STATE(2656), 1,
      sym_statement_block,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [162769] = 3,
    ACTIONS(8657), 1,
      anon_sym_LPAREN,
    STATE(65), 1,
      sym_parenthesized_expression,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [162780] = 3,
    ACTIONS(8657), 1,
      anon_sym_LPAREN,
    STATE(70), 1,
      sym_parenthesized_expression,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [162791] = 3,
    ACTIONS(6718), 1,
      anon_sym_LBRACE,
    STATE(2323), 1,
      sym_class_body,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [162802] = 3,
    ACTIONS(7242), 1,
      anon_sym_LBRACE,
    STATE(2655), 1,
      sym_statement_block,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [162813] = 3,
    ACTIONS(4336), 1,
      anon_sym_LBRACE,
    STATE(2324), 1,
      sym_statement_block,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [162824] = 3,
    ACTIONS(6732), 1,
      anon_sym_LBRACE,
    STATE(1663), 1,
      sym_class_body,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [162835] = 3,
    ACTIONS(4336), 1,
      anon_sym_LBRACE,
    STATE(2325), 1,
      sym_statement_block,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [162846] = 3,
    ACTIONS(7242), 1,
      anon_sym_LBRACE,
    STATE(2657), 1,
      sym_statement_block,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [162857] = 3,
    ACTIONS(6718), 1,
      anon_sym_LBRACE,
    STATE(2326), 1,
      sym_class_body,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [162868] = 3,
    ACTIONS(4362), 1,
      anon_sym_LBRACE,
    STATE(1665), 1,
      sym_statement_block,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [162879] = 3,
    ACTIONS(6453), 1,
      anon_sym_LPAREN,
    STATE(5654), 1,
      sym_formal_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [162890] = 3,
    ACTIONS(6453), 1,
      anon_sym_LPAREN,
    STATE(4322), 1,
      sym_formal_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [162901] = 3,
    ACTIONS(6453), 1,
      anon_sym_LPAREN,
    STATE(5670), 1,
      sym_formal_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [162912] = 3,
    ACTIONS(8901), 1,
      anon_sym_SEMI,
    ACTIONS(8903), 1,
      sym__automatic_semicolon,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [162923] = 3,
    ACTIONS(6453), 1,
      anon_sym_LPAREN,
    STATE(4326), 1,
      sym_formal_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [162934] = 3,
    ACTIONS(6453), 1,
      anon_sym_LPAREN,
    STATE(5682), 1,
      sym_formal_parameters,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [162945] = 3,
    ACTIONS(8905), 1,
      anon_sym_SEMI,
    ACTIONS(8907), 1,
      sym__automatic_semicolon,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [162956] = 3,
    ACTIONS(8909), 1,
      anon_sym_SEMI,
    ACTIONS(8911), 1,
      sym__automatic_semicolon,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [162967] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(8913), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
  [162976] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6024), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
  [162985] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6028), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
  [162994] = 2,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
    ACTIONS(6028), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
  [163003] = 2,
    ACTIONS(8915), 1,
      anon_sym_EQ_GT,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [163011] = 2,
    ACTIONS(8917), 1,
      sym_identifier,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [163019] = 2,
    ACTIONS(8282), 1,
      anon_sym_RBRACE,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [163027] = 2,
    ACTIONS(8919), 1,
      anon_sym_EQ_GT,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [163035] = 2,
    ACTIONS(8921), 1,
      anon_sym_RPAREN,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [163043] = 2,
    ACTIONS(8923), 1,
      anon_sym_symbol,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [163051] = 2,
    ACTIONS(8925), 1,
      anon_sym_EQ_GT,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [163059] = 2,
    ACTIONS(8927), 1,
      anon_sym_symbol,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [163067] = 2,
    ACTIONS(8929), 1,
      anon_sym_DOT,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [163075] = 2,
    ACTIONS(8931), 1,
      anon_sym_EQ_GT,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [163083] = 2,
    ACTIONS(5652), 1,
      anon_sym_in,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [163091] = 2,
    ACTIONS(8933), 1,
      anon_sym_EQ_GT,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [163099] = 2,
    ACTIONS(8935), 1,
      anon_sym_EQ_GT,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [163107] = 2,
    ACTIONS(8937), 1,
      anon_sym_EQ_GT,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [163115] = 2,
    ACTIONS(8939), 1,
      anon_sym_EQ_GT,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [163123] = 2,
    ACTIONS(8941), 1,
      anon_sym_EQ_GT,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [163131] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5), 1,
      sym_html_comment,
    ACTIONS(8943), 1,
      sym_regex_pattern,
  [163141] = 2,
    ACTIONS(8945), 1,
      anon_sym_EQ_GT,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [163149] = 2,
    ACTIONS(8118), 1,
      anon_sym_RBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [163157] = 2,
    ACTIONS(8947), 1,
      sym_identifier,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [163165] = 2,
    ACTIONS(8949), 1,
      anon_sym_DOT,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [163173] = 2,
    ACTIONS(5290), 1,
      anon_sym_RBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [163181] = 2,
    ACTIONS(8951), 1,
      anon_sym_function,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [163189] = 2,
    ACTIONS(8953), 1,
      anon_sym_EQ,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [163197] = 2,
    ACTIONS(8955), 1,
      sym_identifier,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [163205] = 2,
    ACTIONS(8957), 1,
      anon_sym_EQ_GT,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [163213] = 2,
    ACTIONS(8959), 1,
      anon_sym_EQ,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [163221] = 2,
    ACTIONS(8961), 1,
      anon_sym_EQ_GT,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [163229] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5), 1,
      sym_html_comment,
    ACTIONS(8963), 1,
      sym_regex_pattern,
  [163239] = 2,
    ACTIONS(8965), 1,
      sym_identifier,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [163247] = 2,
    ACTIONS(8967), 1,
      sym_number,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [163255] = 2,
    ACTIONS(8969), 1,
      anon_sym_RBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [163263] = 2,
    ACTIONS(5288), 1,
      anon_sym_RBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [163271] = 2,
    ACTIONS(8971), 1,
      anon_sym_EQ_GT,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [163279] = 2,
    ACTIONS(5219), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [163287] = 2,
    ACTIONS(6756), 1,
      anon_sym_is,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [163295] = 2,
    ACTIONS(8973), 1,
      anon_sym_RBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [163303] = 2,
    ACTIONS(8975), 1,
      anon_sym_EQ_GT,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [163311] = 2,
    ACTIONS(8026), 1,
      anon_sym_EQ_GT,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [163319] = 2,
    ACTIONS(8977), 1,
      anon_sym_EQ_GT,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [163327] = 2,
    ACTIONS(5459), 1,
      anon_sym_RPAREN,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [163335] = 2,
    ACTIONS(4734), 1,
      anon_sym_in,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [163343] = 2,
    ACTIONS(8979), 1,
      anon_sym_EQ_GT,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [163351] = 2,
    ACTIONS(8981), 1,
      anon_sym_COLON,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [163359] = 2,
    ACTIONS(8983), 1,
      anon_sym_RBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [163367] = 2,
    ACTIONS(5461), 1,
      anon_sym_RPAREN,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [163375] = 2,
    ACTIONS(8985), 1,
      anon_sym_RBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [163383] = 2,
    ACTIONS(4909), 1,
      anon_sym_RPAREN,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [163391] = 2,
    ACTIONS(8987), 1,
      anon_sym_RBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [163399] = 2,
    ACTIONS(8989), 1,
      sym_identifier,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [163407] = 2,
    ACTIONS(8991), 1,
      sym_identifier,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [163415] = 2,
    ACTIONS(8993), 1,
      sym_identifier,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [163423] = 2,
    ACTIONS(8995), 1,
      anon_sym_EQ_GT,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [163431] = 2,
    ACTIONS(8997), 1,
      anon_sym_EQ_GT,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [163439] = 2,
    ACTIONS(8999), 1,
      sym_identifier,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [163447] = 2,
    ACTIONS(9001), 1,
      sym_identifier,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [163455] = 2,
    ACTIONS(7193), 1,
      anon_sym_EQ,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [163463] = 2,
    ACTIONS(9003), 1,
      sym_number,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [163471] = 2,
    ACTIONS(9005), 1,
      sym_identifier,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [163479] = 2,
    ACTIONS(9007), 1,
      anon_sym_from,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [163487] = 2,
    ACTIONS(9009), 1,
      anon_sym_require,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [163495] = 2,
    ACTIONS(9011), 1,
      anon_sym_EQ_GT,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [163503] = 2,
    ACTIONS(5773), 1,
      anon_sym_in,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [163511] = 2,
    ACTIONS(9013), 1,
      anon_sym_EQ_GT,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [163519] = 2,
    ACTIONS(9015), 1,
      anon_sym_meta,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [163527] = 2,
    ACTIONS(9017), 1,
      anon_sym_EQ_GT,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [163535] = 2,
    ACTIONS(9019), 1,
      anon_sym_EQ_GT,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [163543] = 2,
    ACTIONS(9021), 1,
      anon_sym_EQ_GT,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [163551] = 2,
    ACTIONS(9023), 1,
      anon_sym_class,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [163559] = 2,
    ACTIONS(9025), 1,
      anon_sym_DOT,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [163567] = 2,
    ACTIONS(9027), 1,
      anon_sym_EQ,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [163575] = 2,
    ACTIONS(9029), 1,
      sym_identifier,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [163583] = 2,
    ACTIONS(9031), 1,
      anon_sym_new,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [163591] = 2,
    ACTIONS(9033), 1,
      anon_sym_while,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [163599] = 2,
    ACTIONS(9035), 1,
      anon_sym_RBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [163607] = 2,
    ACTIONS(9037), 1,
      anon_sym_EQ,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [163615] = 2,
    ACTIONS(5296), 1,
      anon_sym_RPAREN,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [163623] = 2,
    ACTIONS(9039), 1,
      anon_sym_from,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [163631] = 2,
    ACTIONS(9041), 1,
      anon_sym_EQ,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [163639] = 2,
    ACTIONS(9043), 1,
      anon_sym_RPAREN,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [163647] = 2,
    ACTIONS(9045), 1,
      anon_sym_RBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [163655] = 2,
    ACTIONS(9047), 1,
      anon_sym_EQ_GT,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [163663] = 2,
    ACTIONS(9049), 1,
      sym_identifier,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [163671] = 2,
    ACTIONS(9051), 1,
      anon_sym_EQ_GT,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [163679] = 2,
    ACTIONS(9053), 1,
      anon_sym_RPAREN,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [163687] = 2,
    ACTIONS(5527), 1,
      anon_sym_RPAREN,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [163695] = 2,
    ACTIONS(9055), 1,
      anon_sym_EQ_GT,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [163703] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5), 1,
      sym_html_comment,
    ACTIONS(9057), 1,
      anon_sym_SLASH2,
  [163713] = 2,
    ACTIONS(9059), 1,
      sym_identifier,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [163721] = 2,
    ACTIONS(9061), 1,
      anon_sym_EQ_GT,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [163729] = 2,
    ACTIONS(9063), 1,
      anon_sym_EQ_GT,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [163737] = 2,
    ACTIONS(9065), 1,
      anon_sym_class,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [163745] = 2,
    ACTIONS(9067), 1,
      anon_sym_EQ_GT,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [163753] = 2,
    ACTIONS(9069), 1,
      anon_sym_namespace,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [163761] = 2,
    ACTIONS(9071), 1,
      anon_sym_EQ_GT,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [163769] = 2,
    ACTIONS(5465), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [163777] = 2,
    ACTIONS(5529), 1,
      anon_sym_RPAREN,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [163785] = 2,
    ACTIONS(8544), 1,
      anon_sym_RBRACE,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [163793] = 2,
    ACTIONS(9073), 1,
      anon_sym_symbol,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [163801] = 2,
    ACTIONS(5531), 1,
      anon_sym_RPAREN,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [163809] = 2,
    ACTIONS(9075), 1,
      anon_sym_from,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [163817] = 2,
    ACTIONS(9077), 1,
      anon_sym_DOT,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [163825] = 2,
    ACTIONS(9079), 1,
      sym_identifier,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [163833] = 2,
    ACTIONS(9081), 1,
      anon_sym_EQ_GT,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [163841] = 2,
    ACTIONS(4112), 1,
      anon_sym_is,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [163849] = 2,
    ACTIONS(8506), 1,
      anon_sym_RBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [163857] = 2,
    ACTIONS(9083), 1,
      sym_identifier,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [163865] = 2,
    ACTIONS(9085), 1,
      sym_identifier,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [163873] = 2,
    ACTIONS(5259), 1,
      anon_sym_in,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [163881] = 2,
    ACTIONS(4969), 1,
      anon_sym_RPAREN,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [163889] = 2,
    ACTIONS(9087), 1,
      anon_sym_class,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [163897] = 2,
    ACTIONS(9089), 1,
      anon_sym_EQ_GT,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [163905] = 2,
    ACTIONS(9091), 1,
      anon_sym_EQ_GT,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [163913] = 2,
    ACTIONS(9093), 1,
      anon_sym_as,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [163921] = 2,
    ACTIONS(9095), 1,
      anon_sym_EQ,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [163929] = 2,
    ACTIONS(9097), 1,
      anon_sym_namespace,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [163937] = 2,
    ACTIONS(5187), 1,
      anon_sym_in,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [163945] = 2,
    ACTIONS(9099), 1,
      anon_sym_RBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [163953] = 2,
    ACTIONS(9101), 1,
      sym_identifier,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [163961] = 2,
    ACTIONS(9103), 1,
      anon_sym_EQ_GT,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [163969] = 2,
    ACTIONS(9105), 1,
      anon_sym_EQ_GT,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [163977] = 2,
    ACTIONS(9107), 1,
      sym_identifier,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [163985] = 2,
    ACTIONS(9109), 1,
      anon_sym_RPAREN,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [163993] = 2,
    ACTIONS(9111), 1,
      anon_sym_EQ_GT,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [164001] = 2,
    ACTIONS(9113), 1,
      anon_sym_EQ_GT,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [164009] = 2,
    ACTIONS(9115), 1,
      anon_sym_EQ_GT,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [164017] = 2,
    ACTIONS(9117), 1,
      sym_identifier,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [164025] = 2,
    ACTIONS(9119), 1,
      sym_identifier,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [164033] = 2,
    ACTIONS(9121), 1,
      anon_sym_EQ_GT,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [164041] = 2,
    ACTIONS(9123), 1,
      anon_sym_as,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [164049] = 2,
    ACTIONS(9125), 1,
      anon_sym_RBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [164057] = 2,
    ACTIONS(5372), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [164065] = 2,
    ACTIONS(9127), 1,
      anon_sym_EQ_GT,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [164073] = 2,
    ACTIONS(9129), 1,
      sym_identifier,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [164081] = 2,
    ACTIONS(9131), 1,
      anon_sym_EQ_GT,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [164089] = 2,
    ACTIONS(9133), 1,
      anon_sym_EQ_GT,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [164097] = 2,
    ACTIONS(9135), 1,
      sym_identifier,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [164105] = 2,
    ACTIONS(9137), 1,
      anon_sym_RBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [164113] = 2,
    ACTIONS(9139), 1,
      anon_sym_as,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [164121] = 2,
    ACTIONS(9141), 1,
      anon_sym_RBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [164129] = 2,
    ACTIONS(9143), 1,
      anon_sym_LBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [164137] = 2,
    ACTIONS(9145), 1,
      anon_sym_RBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [164145] = 2,
    ACTIONS(9147), 1,
      anon_sym_from,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [164153] = 2,
    ACTIONS(9149), 1,
      anon_sym_COLON,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [164161] = 2,
    ACTIONS(9151), 1,
      anon_sym_EQ,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [164169] = 2,
    ACTIONS(9153), 1,
      anon_sym_RBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [164177] = 2,
    ACTIONS(9155), 1,
      anon_sym_new,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [164185] = 2,
    ACTIONS(9157), 1,
      anon_sym_RBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [164193] = 2,
    ACTIONS(9159), 1,
      anon_sym_EQ,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [164201] = 2,
    ACTIONS(9161), 1,
      anon_sym_EQ,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [164209] = 2,
    ACTIONS(9163), 1,
      anon_sym_new,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [164217] = 2,
    ACTIONS(9165), 1,
      sym_identifier,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [164225] = 2,
    ACTIONS(9167), 1,
      anon_sym_EQ_GT,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [164233] = 2,
    ACTIONS(9169), 1,
      anon_sym_EQ_GT,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [164241] = 2,
    ACTIONS(9171), 1,
      anon_sym_RPAREN,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [164249] = 2,
    ACTIONS(9173), 1,
      sym_identifier,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [164257] = 2,
    ACTIONS(8236), 1,
      sym_identifier,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [164265] = 2,
    ACTIONS(9175), 1,
      anon_sym_class,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [164273] = 2,
    ACTIONS(9177), 1,
      anon_sym_RBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [164281] = 2,
    ACTIONS(9179), 1,
      anon_sym_readonly,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [164289] = 2,
    ACTIONS(9181), 1,
      anon_sym_EQ,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [164297] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5), 1,
      sym_html_comment,
    ACTIONS(9183), 1,
      sym_regex_pattern,
  [164307] = 2,
    ACTIONS(9185), 1,
      anon_sym_EQ,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [164315] = 2,
    ACTIONS(9187), 1,
      anon_sym_EQ,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [164323] = 2,
    ACTIONS(9189), 1,
      anon_sym_RPAREN,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [164331] = 2,
    ACTIONS(9191), 1,
      anon_sym_RPAREN,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [164339] = 2,
    ACTIONS(9193), 1,
      anon_sym_EQ_GT,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [164347] = 2,
    ACTIONS(9195), 1,
      anon_sym_DOT,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [164355] = 2,
    ACTIONS(4826), 1,
      anon_sym_in,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [164363] = 2,
    ACTIONS(9197), 1,
      anon_sym_RBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [164371] = 2,
    ACTIONS(9199), 1,
      anon_sym_RPAREN,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [164379] = 2,
    ACTIONS(9201), 1,
      anon_sym_EQ,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [164387] = 2,
    ACTIONS(9203), 1,
      anon_sym_RBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [164395] = 2,
    ACTIONS(9205), 1,
      anon_sym_EQ_GT,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [164403] = 2,
    ACTIONS(5326), 1,
      anon_sym_RBRACE,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [164411] = 2,
    ACTIONS(9207), 1,
      anon_sym_RBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [164419] = 2,
    ACTIONS(9209), 1,
      anon_sym_RBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [164427] = 2,
    ACTIONS(5455), 1,
      anon_sym_COLON,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [164435] = 2,
    ACTIONS(9211), 1,
      sym_identifier,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [164443] = 2,
    ACTIONS(9213), 1,
      anon_sym_RBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [164451] = 2,
    ACTIONS(9215), 1,
      anon_sym_EQ_GT,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [164459] = 2,
    ACTIONS(9217), 1,
      anon_sym_EQ_GT,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [164467] = 2,
    ACTIONS(9015), 1,
      anon_sym_target,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [164475] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5), 1,
      sym_html_comment,
    ACTIONS(9219), 1,
      anon_sym_SLASH2,
  [164485] = 2,
    ACTIONS(9221), 1,
      anon_sym_RBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [164493] = 2,
    ACTIONS(9223), 1,
      anon_sym_EQ_GT,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [164501] = 2,
    ACTIONS(9225), 1,
      sym_identifier,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [164509] = 2,
    ACTIONS(9227), 1,
      anon_sym_EQ_GT,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [164517] = 2,
    ACTIONS(9229), 1,
      anon_sym_EQ_GT,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [164525] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5), 1,
      sym_html_comment,
    ACTIONS(9231), 1,
      sym_regex_pattern,
  [164535] = 2,
    ACTIONS(9233), 1,
      anon_sym_COLON,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [164543] = 2,
    ACTIONS(9235), 1,
      ts_builtin_sym_end,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [164551] = 2,
    ACTIONS(9237), 1,
      anon_sym_EQ,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [164559] = 2,
    ACTIONS(9239), 1,
      anon_sym_RBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [164567] = 2,
    ACTIONS(9241), 1,
      anon_sym_RBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [164575] = 2,
    ACTIONS(9243), 1,
      anon_sym_RBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [164583] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5), 1,
      sym_html_comment,
    ACTIONS(9245), 1,
      anon_sym_SLASH2,
  [164593] = 2,
    ACTIONS(9247), 1,
      sym_identifier,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [164601] = 2,
    ACTIONS(5543), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [164609] = 2,
    ACTIONS(9249), 1,
      anon_sym_EQ_GT,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [164617] = 2,
    ACTIONS(9251), 1,
      sym_identifier,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [164625] = 2,
    ACTIONS(9253), 1,
      anon_sym_RBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [164633] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5), 1,
      sym_html_comment,
    ACTIONS(9255), 1,
      sym_regex_pattern,
  [164643] = 2,
    ACTIONS(9257), 1,
      anon_sym_RBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [164651] = 2,
    ACTIONS(9259), 1,
      anon_sym_EQ_GT,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [164659] = 2,
    ACTIONS(9261), 1,
      anon_sym_EQ_GT,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [164667] = 2,
    ACTIONS(9263), 1,
      anon_sym_RBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [164675] = 2,
    ACTIONS(7217), 1,
      anon_sym_is,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [164683] = 2,
    ACTIONS(9265), 1,
      anon_sym_COLON,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [164691] = 2,
    ACTIONS(7059), 1,
      anon_sym_is,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [164699] = 2,
    ACTIONS(9267), 1,
      anon_sym_RBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [164707] = 2,
    ACTIONS(9269), 1,
      anon_sym_RBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [164715] = 2,
    ACTIONS(8334), 1,
      sym_identifier,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [164723] = 2,
    ACTIONS(4920), 1,
      anon_sym_RPAREN,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [164731] = 2,
    ACTIONS(5545), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [164739] = 2,
    ACTIONS(9271), 1,
      anon_sym_RBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [164747] = 2,
    ACTIONS(9273), 1,
      anon_sym_EQ_GT,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [164755] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5), 1,
      sym_html_comment,
    ACTIONS(9275), 1,
      anon_sym_SLASH2,
  [164765] = 2,
    ACTIONS(9277), 1,
      anon_sym_RBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [164773] = 2,
    ACTIONS(9279), 1,
      anon_sym_RBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [164781] = 2,
    ACTIONS(9281), 1,
      anon_sym_RBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [164789] = 2,
    ACTIONS(5431), 1,
      anon_sym_RPAREN,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [164797] = 2,
    ACTIONS(9283), 1,
      anon_sym_LPAREN,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [164805] = 2,
    ACTIONS(9285), 1,
      anon_sym_RBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [164813] = 2,
    ACTIONS(9287), 1,
      anon_sym_from,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [164821] = 2,
    ACTIONS(9289), 1,
      anon_sym_RBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [164829] = 2,
    ACTIONS(9291), 1,
      anon_sym_RBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [164837] = 2,
    ACTIONS(9293), 1,
      anon_sym_EQ_GT,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [164845] = 2,
    ACTIONS(9295), 1,
      anon_sym_RBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [164853] = 2,
    ACTIONS(9297), 1,
      anon_sym_RBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [164861] = 2,
    ACTIONS(9299), 1,
      anon_sym_RBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [164869] = 2,
    ACTIONS(9301), 1,
      anon_sym_RBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [164877] = 2,
    ACTIONS(7745), 1,
      anon_sym_EQ,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [164885] = 2,
    ACTIONS(9303), 1,
      anon_sym_RBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [164893] = 2,
    ACTIONS(9305), 1,
      anon_sym_RBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [164901] = 2,
    ACTIONS(9307), 1,
      anon_sym_RBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [164909] = 2,
    ACTIONS(9309), 1,
      anon_sym_RBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [164917] = 2,
    ACTIONS(9311), 1,
      anon_sym_RBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [164925] = 2,
    ACTIONS(9313), 1,
      anon_sym_EQ_GT,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [164933] = 2,
    ACTIONS(9315), 1,
      anon_sym_target,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [164941] = 2,
    ACTIONS(9317), 1,
      anon_sym_RBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [164949] = 2,
    ACTIONS(9319), 1,
      anon_sym_RBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [164957] = 2,
    ACTIONS(9321), 1,
      anon_sym_EQ,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [164965] = 2,
    ACTIONS(9323), 1,
      anon_sym_EQ_GT,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [164973] = 2,
    ACTIONS(9325), 1,
      sym_identifier,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [164981] = 2,
    ACTIONS(9327), 1,
      anon_sym_EQ_GT,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [164989] = 2,
    ACTIONS(9329), 1,
      anon_sym_RBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [164997] = 2,
    ACTIONS(9331), 1,
      anon_sym_RBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [165005] = 2,
    ACTIONS(9333), 1,
      anon_sym_RBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [165013] = 2,
    ACTIONS(9335), 1,
      anon_sym_RBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [165021] = 2,
    ACTIONS(9337), 1,
      anon_sym_RBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [165029] = 2,
    ACTIONS(9339), 1,
      anon_sym_RBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [165037] = 2,
    ACTIONS(9341), 1,
      anon_sym_RBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [165045] = 2,
    ACTIONS(9343), 1,
      anon_sym_RBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [165053] = 2,
    ACTIONS(9345), 1,
      anon_sym_RBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [165061] = 2,
    ACTIONS(9347), 1,
      anon_sym_RBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [165069] = 2,
    ACTIONS(5457), 1,
      anon_sym_RPAREN,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [165077] = 2,
    ACTIONS(5437), 1,
      anon_sym_RPAREN,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [165085] = 2,
    ACTIONS(6688), 1,
      anon_sym_is,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [165093] = 2,
    ACTIONS(9349), 1,
      anon_sym_RBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [165101] = 2,
    ACTIONS(5439), 1,
      anon_sym_RPAREN,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [165109] = 2,
    ACTIONS(9351), 1,
      anon_sym_RBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [165117] = 2,
    ACTIONS(9353), 1,
      anon_sym_RBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [165125] = 2,
    ACTIONS(9355), 1,
      sym_identifier,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [165133] = 2,
    ACTIONS(9357), 1,
      anon_sym_RPAREN,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [165141] = 2,
    ACTIONS(9359), 1,
      sym_identifier,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [165149] = 2,
    ACTIONS(8154), 1,
      anon_sym_RBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [165157] = 2,
    ACTIONS(9361), 1,
      sym_identifier,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [165165] = 2,
    ACTIONS(9363), 1,
      sym_identifier,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [165173] = 2,
    ACTIONS(9365), 1,
      anon_sym_LBRACE,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [165181] = 2,
    ACTIONS(5215), 1,
      anon_sym_RPAREN,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [165189] = 2,
    ACTIONS(9367), 1,
      anon_sym_RBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [165197] = 2,
    ACTIONS(9315), 1,
      anon_sym_meta,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [165205] = 2,
    ACTIONS(9369), 1,
      sym_identifier,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [165213] = 2,
    ACTIONS(9371), 1,
      anon_sym_RBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [165221] = 2,
    ACTIONS(9373), 1,
      anon_sym_RPAREN,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [165229] = 2,
    ACTIONS(9375), 1,
      anon_sym_RBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [165237] = 2,
    ACTIONS(9377), 1,
      anon_sym_RBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [165245] = 2,
    ACTIONS(9379), 1,
      anon_sym_RBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [165253] = 2,
    ACTIONS(9381), 1,
      anon_sym_RBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [165261] = 2,
    ACTIONS(8162), 1,
      anon_sym_RBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [165269] = 2,
    ACTIONS(4907), 1,
      anon_sym_is,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [165277] = 2,
    ACTIONS(9383), 1,
      anon_sym_from,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [165285] = 2,
    ACTIONS(9385), 1,
      anon_sym_RBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [165293] = 2,
    ACTIONS(7677), 1,
      sym_identifier,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [165301] = 2,
    ACTIONS(5445), 1,
      anon_sym_RPAREN,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [165309] = 2,
    ACTIONS(5600), 1,
      anon_sym_in,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [165317] = 2,
    ACTIONS(9387), 1,
      anon_sym_RBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [165325] = 2,
    ACTIONS(9389), 1,
      anon_sym_RBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [165333] = 2,
    ACTIONS(9391), 1,
      anon_sym_EQ_GT,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [165341] = 2,
    ACTIONS(9393), 1,
      anon_sym_RBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [165349] = 2,
    ACTIONS(9395), 1,
      anon_sym_RBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [165357] = 2,
    ACTIONS(9397), 1,
      anon_sym_EQ,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [165365] = 2,
    ACTIONS(9399), 1,
      anon_sym_RBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [165373] = 2,
    ACTIONS(9401), 1,
      anon_sym_EQ_GT,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [165381] = 2,
    ACTIONS(9403), 1,
      anon_sym_RBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [165389] = 2,
    ACTIONS(9405), 1,
      anon_sym_EQ_GT,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [165397] = 2,
    ACTIONS(9407), 1,
      anon_sym_RBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [165405] = 2,
    ACTIONS(9409), 1,
      anon_sym_EQ_GT,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [165413] = 2,
    ACTIONS(9411), 1,
      anon_sym_RBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [165421] = 2,
    ACTIONS(9413), 1,
      anon_sym_RBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [165429] = 2,
    ACTIONS(9415), 1,
      anon_sym_RBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [165437] = 2,
    ACTIONS(4948), 1,
      anon_sym_in,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [165445] = 2,
    ACTIONS(9417), 1,
      anon_sym_EQ_GT,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [165453] = 2,
    ACTIONS(9419), 1,
      sym_number,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [165461] = 2,
    ACTIONS(9421), 1,
      anon_sym_EQ_GT,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [165469] = 2,
    ACTIONS(9423), 1,
      anon_sym_RBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [165477] = 2,
    ACTIONS(9425), 1,
      anon_sym_EQ,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [165485] = 2,
    ACTIONS(4897), 1,
      anon_sym_in,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [165493] = 2,
    ACTIONS(9427), 1,
      anon_sym_EQ_GT,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [165501] = 2,
    ACTIONS(9429), 1,
      anon_sym_EQ_GT,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [165509] = 2,
    ACTIONS(9431), 1,
      sym_identifier,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [165517] = 2,
    ACTIONS(9433), 1,
      anon_sym_EQ_GT,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [165525] = 2,
    ACTIONS(9435), 1,
      anon_sym_EQ_GT,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [165533] = 2,
    ACTIONS(4871), 1,
      anon_sym_RPAREN,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [165541] = 2,
    ACTIONS(9437), 1,
      anon_sym_RBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [165549] = 2,
    ACTIONS(9439), 1,
      sym_identifier,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [165557] = 2,
    ACTIONS(9441), 1,
      anon_sym_EQ,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [165565] = 2,
    ACTIONS(9443), 1,
      anon_sym_RBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [165573] = 2,
    ACTIONS(9445), 1,
      anon_sym_symbol,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [165581] = 2,
    ACTIONS(9447), 1,
      anon_sym_RBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [165589] = 2,
    ACTIONS(9449), 1,
      sym_number,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [165597] = 2,
    ACTIONS(9451), 1,
      anon_sym_EQ,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [165605] = 2,
    ACTIONS(9453), 1,
      anon_sym_new,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [165613] = 2,
    ACTIONS(5825), 1,
      anon_sym_in,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [165621] = 2,
    ACTIONS(9455), 1,
      anon_sym_RBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [165629] = 2,
    ACTIONS(8590), 1,
      anon_sym_LBRACE,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [165637] = 2,
    ACTIONS(9457), 1,
      sym_identifier,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [165645] = 2,
    ACTIONS(9459), 1,
      anon_sym_RBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [165653] = 2,
    ACTIONS(9461), 1,
      anon_sym_RBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [165661] = 2,
    ACTIONS(9463), 1,
      anon_sym_DOT,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [165669] = 2,
    ACTIONS(9465), 1,
      anon_sym_RBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [165677] = 2,
    ACTIONS(9467), 1,
      anon_sym_RBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [165685] = 2,
    ACTIONS(9469), 1,
      anon_sym_RBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [165693] = 2,
    ACTIONS(9471), 1,
      anon_sym_EQ_GT,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [165701] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5), 1,
      sym_html_comment,
    ACTIONS(9473), 1,
      anon_sym_SLASH2,
  [165711] = 2,
    ACTIONS(9475), 1,
      anon_sym_RBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [165719] = 2,
    ACTIONS(9477), 1,
      anon_sym_EQ,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [165727] = 2,
    ACTIONS(9479), 1,
      anon_sym_RBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [165735] = 2,
    ACTIONS(9481), 1,
      anon_sym_new,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [165743] = 2,
    ACTIONS(9483), 1,
      anon_sym_RBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [165751] = 2,
    ACTIONS(9485), 1,
      anon_sym_RBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [165759] = 2,
    ACTIONS(9487), 1,
      anon_sym_RBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [165767] = 2,
    ACTIONS(9489), 1,
      anon_sym_RBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [165775] = 2,
    ACTIONS(9491), 1,
      anon_sym_RBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [165783] = 2,
    ACTIONS(9493), 1,
      anon_sym_RBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [165791] = 2,
    ACTIONS(7422), 1,
      anon_sym_RPAREN,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [165799] = 2,
    ACTIONS(9495), 1,
      sym_identifier,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [165807] = 2,
    ACTIONS(9497), 1,
      anon_sym_EQ_GT,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [165815] = 2,
    ACTIONS(9499), 1,
      anon_sym_EQ,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [165823] = 2,
    ACTIONS(9501), 1,
      anon_sym_new,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [165831] = 2,
    ACTIONS(7377), 1,
      anon_sym_RPAREN,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [165839] = 2,
    ACTIONS(9503), 1,
      sym_identifier,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [165847] = 2,
    ACTIONS(9505), 1,
      anon_sym_RBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [165855] = 2,
    ACTIONS(9507), 1,
      anon_sym_RBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [165863] = 2,
    ACTIONS(9509), 1,
      anon_sym_EQ_GT,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [165871] = 2,
    ACTIONS(9511), 1,
      sym_identifier,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [165879] = 2,
    ACTIONS(9513), 1,
      anon_sym_EQ,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [165887] = 2,
    ACTIONS(9515), 1,
      sym_number,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [165895] = 2,
    ACTIONS(6104), 1,
      anon_sym_EQ_GT,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [165903] = 2,
    ACTIONS(9517), 1,
      sym_identifier,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [165911] = 2,
    ACTIONS(9519), 1,
      anon_sym_EQ,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [165919] = 2,
    ACTIONS(9521), 1,
      sym_identifier,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [165927] = 2,
    ACTIONS(9523), 1,
      anon_sym_EQ_GT,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [165935] = 2,
    ACTIONS(9525), 1,
      sym_identifier,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [165943] = 2,
    ACTIONS(9527), 1,
      anon_sym_EQ_GT,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [165951] = 2,
    ACTIONS(9529), 1,
      anon_sym_EQ_GT,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [165959] = 2,
    ACTIONS(9531), 1,
      anon_sym_symbol,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [165967] = 2,
    ACTIONS(9533), 1,
      anon_sym_EQ_GT,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [165975] = 2,
    ACTIONS(5370), 1,
      anon_sym_RBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [165983] = 2,
    ACTIONS(9535), 1,
      sym_identifier,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [165991] = 2,
    ACTIONS(5401), 1,
      anon_sym_RBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [165999] = 2,
    ACTIONS(7817), 1,
      sym_identifier,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [166007] = 2,
    ACTIONS(9537), 1,
      anon_sym_function,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [166015] = 2,
    ACTIONS(9539), 1,
      anon_sym_EQ_GT,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [166023] = 2,
    ACTIONS(9541), 1,
      anon_sym_EQ_GT,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [166031] = 2,
    ACTIONS(9543), 1,
      anon_sym_new,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [166039] = 2,
    ACTIONS(9545), 1,
      sym_identifier,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [166047] = 2,
    ACTIONS(8615), 1,
      anon_sym_from,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [166055] = 2,
    ACTIONS(9547), 1,
      anon_sym_COLON,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [166063] = 2,
    ACTIONS(9549), 1,
      anon_sym_RBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [166071] = 2,
    ACTIONS(9551), 1,
      sym_identifier,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [166079] = 2,
    ACTIONS(9553), 1,
      sym_identifier,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [166087] = 2,
    ACTIONS(5519), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [166095] = 2,
    ACTIONS(9555), 1,
      sym_identifier,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [166103] = 2,
    ACTIONS(9557), 1,
      sym_identifier,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [166111] = 2,
    ACTIONS(9559), 1,
      anon_sym_RBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [166119] = 2,
    ACTIONS(8427), 1,
      anon_sym_RBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [166127] = 2,
    ACTIONS(9561), 1,
      sym_identifier,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [166135] = 2,
    ACTIONS(9563), 1,
      sym_identifier,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [166143] = 2,
    ACTIONS(9565), 1,
      sym_identifier,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [166151] = 2,
    ACTIONS(9567), 1,
      sym_identifier,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [166159] = 2,
    ACTIONS(9569), 1,
      anon_sym_EQ_GT,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [166167] = 2,
    ACTIONS(9571), 1,
      anon_sym_EQ_GT,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [166175] = 2,
    ACTIONS(9573), 1,
      sym_identifier,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [166183] = 2,
    ACTIONS(6487), 1,
      anon_sym_is,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [166191] = 2,
    ACTIONS(9575), 1,
      anon_sym_RBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [166199] = 2,
    ACTIONS(9577), 1,
      anon_sym_from,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [166207] = 2,
    ACTIONS(9579), 1,
      anon_sym_RBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [166215] = 2,
    ACTIONS(9581), 1,
      anon_sym_new,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [166223] = 2,
    ACTIONS(9583), 1,
      anon_sym_RBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [166231] = 2,
    ACTIONS(9585), 1,
      anon_sym_EQ,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [166239] = 2,
    ACTIONS(9587), 1,
      sym_identifier,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
  [166247] = 2,
    ACTIONS(9589), 1,
      anon_sym_RBRACK,
    ACTIONS(5), 2,
      sym_html_comment,
      sym_comment,
};

static const uint32_t ts_small_parse_table_map[] = {
  [SMALL_STATE(1193)] = 0,
  [SMALL_STATE(1194)] = 93,
  [SMALL_STATE(1195)] = 186,
  [SMALL_STATE(1196)] = 281,
  [SMALL_STATE(1197)] = 374,
  [SMALL_STATE(1198)] = 445,
  [SMALL_STATE(1199)] = 516,
  [SMALL_STATE(1200)] = 587,
  [SMALL_STATE(1201)] = 658,
  [SMALL_STATE(1202)] = 747,
  [SMALL_STATE(1203)] = 820,
  [SMALL_STATE(1204)] = 913,
  [SMALL_STATE(1205)] = 1004,
  [SMALL_STATE(1206)] = 1077,
  [SMALL_STATE(1207)] = 1148,
  [SMALL_STATE(1208)] = 1219,
  [SMALL_STATE(1209)] = 1308,
  [SMALL_STATE(1210)] = 1397,
  [SMALL_STATE(1211)] = 1488,
  [SMALL_STATE(1212)] = 1577,
  [SMALL_STATE(1213)] = 1648,
  [SMALL_STATE(1214)] = 1722,
  [SMALL_STATE(1215)] = 1812,
  [SMALL_STATE(1216)] = 1902,
  [SMALL_STATE(1217)] = 1992,
  [SMALL_STATE(1218)] = 2062,
  [SMALL_STATE(1219)] = 2150,
  [SMALL_STATE(1220)] = 2220,
  [SMALL_STATE(1221)] = 2308,
  [SMALL_STATE(1222)] = 2394,
  [SMALL_STATE(1223)] = 2480,
  [SMALL_STATE(1224)] = 2572,
  [SMALL_STATE(1225)] = 2660,
  [SMALL_STATE(1226)] = 2750,
  [SMALL_STATE(1227)] = 2838,
  [SMALL_STATE(1228)] = 2928,
  [SMALL_STATE(1229)] = 3018,
  [SMALL_STATE(1230)] = 3110,
  [SMALL_STATE(1231)] = 3198,
  [SMALL_STATE(1232)] = 3290,
  [SMALL_STATE(1233)] = 3380,
  [SMALL_STATE(1234)] = 3470,
  [SMALL_STATE(1235)] = 3557,
  [SMALL_STATE(1236)] = 3644,
  [SMALL_STATE(1237)] = 3731,
  [SMALL_STATE(1238)] = 3818,
  [SMALL_STATE(1239)] = 3905,
  [SMALL_STATE(1240)] = 3992,
  [SMALL_STATE(1241)] = 4079,
  [SMALL_STATE(1242)] = 4174,
  [SMALL_STATE(1243)] = 4263,
  [SMALL_STATE(1244)] = 4354,
  [SMALL_STATE(1245)] = 4445,
  [SMALL_STATE(1246)] = 4534,
  [SMALL_STATE(1247)] = 4613,
  [SMALL_STATE(1248)] = 4704,
  [SMALL_STATE(1249)] = 4790,
  [SMALL_STATE(1250)] = 4880,
  [SMALL_STATE(1251)] = 4966,
  [SMALL_STATE(1252)] = 5052,
  [SMALL_STATE(1253)] = 5130,
  [SMALL_STATE(1254)] = 5216,
  [SMALL_STATE(1255)] = 5306,
  [SMALL_STATE(1256)] = 5392,
  [SMALL_STATE(1257)] = 5478,
  [SMALL_STATE(1258)] = 5564,
  [SMALL_STATE(1259)] = 5654,
  [SMALL_STATE(1260)] = 5740,
  [SMALL_STATE(1261)] = 5818,
  [SMALL_STATE(1262)] = 5908,
  [SMALL_STATE(1263)] = 5988,
  [SMALL_STATE(1264)] = 6078,
  [SMALL_STATE(1265)] = 6170,
  [SMALL_STATE(1266)] = 6248,
  [SMALL_STATE(1267)] = 6334,
  [SMALL_STATE(1268)] = 6420,
  [SMALL_STATE(1269)] = 6506,
  [SMALL_STATE(1270)] = 6580,
  [SMALL_STATE(1271)] = 6666,
  [SMALL_STATE(1272)] = 6752,
  [SMALL_STATE(1273)] = 6820,
  [SMALL_STATE(1274)] = 6898,
  [SMALL_STATE(1275)] = 6984,
  [SMALL_STATE(1276)] = 7076,
  [SMALL_STATE(1277)] = 7156,
  [SMALL_STATE(1278)] = 7229,
  [SMALL_STATE(1279)] = 7304,
  [SMALL_STATE(1280)] = 7393,
  [SMALL_STATE(1281)] = 7480,
  [SMALL_STATE(1282)] = 7569,
  [SMALL_STATE(1283)] = 7638,
  [SMALL_STATE(1284)] = 7727,
  [SMALL_STATE(1285)] = 7796,
  [SMALL_STATE(1286)] = 7873,
  [SMALL_STATE(1287)] = 7956,
  [SMALL_STATE(1288)] = 8023,
  [SMALL_STATE(1289)] = 8090,
  [SMALL_STATE(1290)] = 8175,
  [SMALL_STATE(1291)] = 8244,
  [SMALL_STATE(1292)] = 8313,
  [SMALL_STATE(1293)] = 8390,
  [SMALL_STATE(1294)] = 8479,
  [SMALL_STATE(1295)] = 8564,
  [SMALL_STATE(1296)] = 8639,
  [SMALL_STATE(1297)] = 8728,
  [SMALL_STATE(1298)] = 8803,
  [SMALL_STATE(1299)] = 8892,
  [SMALL_STATE(1300)] = 8965,
  [SMALL_STATE(1301)] = 9044,
  [SMALL_STATE(1302)] = 9117,
  [SMALL_STATE(1303)] = 9202,
  [SMALL_STATE(1304)] = 9281,
  [SMALL_STATE(1305)] = 9354,
  [SMALL_STATE(1306)] = 9437,
  [SMALL_STATE(1307)] = 9515,
  [SMALL_STATE(1308)] = 9587,
  [SMALL_STATE(1309)] = 9659,
  [SMALL_STATE(1310)] = 9743,
  [SMALL_STATE(1311)] = 9809,
  [SMALL_STATE(1312)] = 9875,
  [SMALL_STATE(1313)] = 9947,
  [SMALL_STATE(1314)] = 10019,
  [SMALL_STATE(1315)] = 10095,
  [SMALL_STATE(1316)] = 10169,
  [SMALL_STATE(1317)] = 10243,
  [SMALL_STATE(1318)] = 10309,
  [SMALL_STATE(1319)] = 10389,
  [SMALL_STATE(1320)] = 10465,
  [SMALL_STATE(1321)] = 10537,
  [SMALL_STATE(1322)] = 10603,
  [SMALL_STATE(1323)] = 10673,
  [SMALL_STATE(1324)] = 10757,
  [SMALL_STATE(1325)] = 10829,
  [SMALL_STATE(1326)] = 10895,
  [SMALL_STATE(1327)] = 10969,
  [SMALL_STATE(1328)] = 11057,
  [SMALL_STATE(1329)] = 11135,
  [SMALL_STATE(1330)] = 11207,
  [SMALL_STATE(1331)] = 11273,
  [SMALL_STATE(1332)] = 11339,
  [SMALL_STATE(1333)] = 11405,
  [SMALL_STATE(1334)] = 11487,
  [SMALL_STATE(1335)] = 11557,
  [SMALL_STATE(1336)] = 11623,
  [SMALL_STATE(1337)] = 11707,
  [SMALL_STATE(1338)] = 11779,
  [SMALL_STATE(1339)] = 11859,
  [SMALL_STATE(1340)] = 11927,
  [SMALL_STATE(1341)] = 12011,
  [SMALL_STATE(1342)] = 12087,
  [SMALL_STATE(1343)] = 12161,
  [SMALL_STATE(1344)] = 12239,
  [SMALL_STATE(1345)] = 12305,
  [SMALL_STATE(1346)] = 12373,
  [SMALL_STATE(1347)] = 12461,
  [SMALL_STATE(1348)] = 12527,
  [SMALL_STATE(1349)] = 12593,
  [SMALL_STATE(1350)] = 12664,
  [SMALL_STATE(1351)] = 12731,
  [SMALL_STATE(1352)] = 12804,
  [SMALL_STATE(1353)] = 12877,
  [SMALL_STATE(1354)] = 12948,
  [SMALL_STATE(1355)] = 13017,
  [SMALL_STATE(1356)] = 13088,
  [SMALL_STATE(1357)] = 13163,
  [SMALL_STATE(1358)] = 13246,
  [SMALL_STATE(1359)] = 13319,
  [SMALL_STATE(1360)] = 13392,
  [SMALL_STATE(1361)] = 13463,
  [SMALL_STATE(1362)] = 13540,
  [SMALL_STATE(1363)] = 13609,
  [SMALL_STATE(1364)] = 13682,
  [SMALL_STATE(1365)] = 13751,
  [SMALL_STATE(1366)] = 13826,
  [SMALL_STATE(1367)] = 13897,
  [SMALL_STATE(1368)] = 13964,
  [SMALL_STATE(1369)] = 14035,
  [SMALL_STATE(1370)] = 14104,
  [SMALL_STATE(1371)] = 14181,
  [SMALL_STATE(1372)] = 14254,
  [SMALL_STATE(1373)] = 14333,
  [SMALL_STATE(1374)] = 14410,
  [SMALL_STATE(1375)] = 14481,
  [SMALL_STATE(1376)] = 14552,
  [SMALL_STATE(1377)] = 14625,
  [SMALL_STATE(1378)] = 14702,
  [SMALL_STATE(1379)] = 14779,
  [SMALL_STATE(1380)] = 14851,
  [SMALL_STATE(1381)] = 14971,
  [SMALL_STATE(1382)] = 15043,
  [SMALL_STATE(1383)] = 15163,
  [SMALL_STATE(1384)] = 15233,
  [SMALL_STATE(1385)] = 15303,
  [SMALL_STATE(1386)] = 15373,
  [SMALL_STATE(1387)] = 15493,
  [SMALL_STATE(1388)] = 15561,
  [SMALL_STATE(1389)] = 15635,
  [SMALL_STATE(1390)] = 15755,
  [SMALL_STATE(1391)] = 15829,
  [SMALL_STATE(1392)] = 15903,
  [SMALL_STATE(1393)] = 15977,
  [SMALL_STATE(1394)] = 16053,
  [SMALL_STATE(1395)] = 16173,
  [SMALL_STATE(1396)] = 16293,
  [SMALL_STATE(1397)] = 16363,
  [SMALL_STATE(1398)] = 16429,
  [SMALL_STATE(1399)] = 16497,
  [SMALL_STATE(1400)] = 16569,
  [SMALL_STATE(1401)] = 16639,
  [SMALL_STATE(1402)] = 16705,
  [SMALL_STATE(1403)] = 16774,
  [SMALL_STATE(1404)] = 16843,
  [SMALL_STATE(1405)] = 16912,
  [SMALL_STATE(1406)] = 16981,
  [SMALL_STATE(1407)] = 17050,
  [SMALL_STATE(1408)] = 17119,
  [SMALL_STATE(1409)] = 17188,
  [SMALL_STATE(1410)] = 17259,
  [SMALL_STATE(1411)] = 17326,
  [SMALL_STATE(1412)] = 17399,
  [SMALL_STATE(1413)] = 17468,
  [SMALL_STATE(1414)] = 17541,
  [SMALL_STATE(1415)] = 17612,
  [SMALL_STATE(1416)] = 17681,
  [SMALL_STATE(1417)] = 17750,
  [SMALL_STATE(1418)] = 17819,
  [SMALL_STATE(1419)] = 17888,
  [SMALL_STATE(1420)] = 18004,
  [SMALL_STATE(1421)] = 18072,
  [SMALL_STATE(1422)] = 18140,
  [SMALL_STATE(1423)] = 18208,
  [SMALL_STATE(1424)] = 18324,
  [SMALL_STATE(1425)] = 18440,
  [SMALL_STATE(1426)] = 18508,
  [SMALL_STATE(1427)] = 18624,
  [SMALL_STATE(1428)] = 18692,
  [SMALL_STATE(1429)] = 18760,
  [SMALL_STATE(1430)] = 18828,
  [SMALL_STATE(1431)] = 18896,
  [SMALL_STATE(1432)] = 18964,
  [SMALL_STATE(1433)] = 19080,
  [SMALL_STATE(1434)] = 19196,
  [SMALL_STATE(1435)] = 19264,
  [SMALL_STATE(1436)] = 19332,
  [SMALL_STATE(1437)] = 19448,
  [SMALL_STATE(1438)] = 19564,
  [SMALL_STATE(1439)] = 19632,
  [SMALL_STATE(1440)] = 19748,
  [SMALL_STATE(1441)] = 19816,
  [SMALL_STATE(1442)] = 19932,
  [SMALL_STATE(1443)] = 20048,
  [SMALL_STATE(1444)] = 20164,
  [SMALL_STATE(1445)] = 20232,
  [SMALL_STATE(1446)] = 20300,
  [SMALL_STATE(1447)] = 20368,
  [SMALL_STATE(1448)] = 20438,
  [SMALL_STATE(1449)] = 20506,
  [SMALL_STATE(1450)] = 20574,
  [SMALL_STATE(1451)] = 20690,
  [SMALL_STATE(1452)] = 20758,
  [SMALL_STATE(1453)] = 20826,
  [SMALL_STATE(1454)] = 20894,
  [SMALL_STATE(1455)] = 21010,
  [SMALL_STATE(1456)] = 21126,
  [SMALL_STATE(1457)] = 21192,
  [SMALL_STATE(1458)] = 21258,
  [SMALL_STATE(1459)] = 21326,
  [SMALL_STATE(1460)] = 21392,
  [SMALL_STATE(1461)] = 21508,
  [SMALL_STATE(1462)] = 21576,
  [SMALL_STATE(1463)] = 21692,
  [SMALL_STATE(1464)] = 21808,
  [SMALL_STATE(1465)] = 21873,
  [SMALL_STATE(1466)] = 21938,
  [SMALL_STATE(1467)] = 22003,
  [SMALL_STATE(1468)] = 22068,
  [SMALL_STATE(1469)] = 22133,
  [SMALL_STATE(1470)] = 22198,
  [SMALL_STATE(1471)] = 22263,
  [SMALL_STATE(1472)] = 22328,
  [SMALL_STATE(1473)] = 22393,
  [SMALL_STATE(1474)] = 22458,
  [SMALL_STATE(1475)] = 22570,
  [SMALL_STATE(1476)] = 22682,
  [SMALL_STATE(1477)] = 22794,
  [SMALL_STATE(1478)] = 22906,
  [SMALL_STATE(1479)] = 23018,
  [SMALL_STATE(1480)] = 23130,
  [SMALL_STATE(1481)] = 23242,
  [SMALL_STATE(1482)] = 23361,
  [SMALL_STATE(1483)] = 23472,
  [SMALL_STATE(1484)] = 23583,
  [SMALL_STATE(1485)] = 23694,
  [SMALL_STATE(1486)] = 23805,
  [SMALL_STATE(1487)] = 23924,
  [SMALL_STATE(1488)] = 24043,
  [SMALL_STATE(1489)] = 24162,
  [SMALL_STATE(1490)] = 24273,
  [SMALL_STATE(1491)] = 24384,
  [SMALL_STATE(1492)] = 24495,
  [SMALL_STATE(1493)] = 24606,
  [SMALL_STATE(1494)] = 24725,
  [SMALL_STATE(1495)] = 24836,
  [SMALL_STATE(1496)] = 24947,
  [SMALL_STATE(1497)] = 25058,
  [SMALL_STATE(1498)] = 25160,
  [SMALL_STATE(1499)] = 25262,
  [SMALL_STATE(1500)] = 25364,
  [SMALL_STATE(1501)] = 25466,
  [SMALL_STATE(1502)] = 25544,
  [SMALL_STATE(1503)] = 25646,
  [SMALL_STATE(1504)] = 25748,
  [SMALL_STATE(1505)] = 25815,
  [SMALL_STATE(1506)] = 25880,
  [SMALL_STATE(1507)] = 25947,
  [SMALL_STATE(1508)] = 26056,
  [SMALL_STATE(1509)] = 26113,
  [SMALL_STATE(1510)] = 26180,
  [SMALL_STATE(1511)] = 26291,
  [SMALL_STATE(1512)] = 26348,
  [SMALL_STATE(1513)] = 26410,
  [SMALL_STATE(1514)] = 26466,
  [SMALL_STATE(1515)] = 26528,
  [SMALL_STATE(1516)] = 26596,
  [SMALL_STATE(1517)] = 26652,
  [SMALL_STATE(1518)] = 26708,
  [SMALL_STATE(1519)] = 26764,
  [SMALL_STATE(1520)] = 26820,
  [SMALL_STATE(1521)] = 26914,
  [SMALL_STATE(1522)] = 26974,
  [SMALL_STATE(1523)] = 27030,
  [SMALL_STATE(1524)] = 27088,
  [SMALL_STATE(1525)] = 27146,
  [SMALL_STATE(1526)] = 27204,
  [SMALL_STATE(1527)] = 27260,
  [SMALL_STATE(1528)] = 27320,
  [SMALL_STATE(1529)] = 27377,
  [SMALL_STATE(1530)] = 27432,
  [SMALL_STATE(1531)] = 27487,
  [SMALL_STATE(1532)] = 27550,
  [SMALL_STATE(1533)] = 27605,
  [SMALL_STATE(1534)] = 27660,
  [SMALL_STATE(1535)] = 27717,
  [SMALL_STATE(1536)] = 27780,
  [SMALL_STATE(1537)] = 27835,
  [SMALL_STATE(1538)] = 27890,
  [SMALL_STATE(1539)] = 27945,
  [SMALL_STATE(1540)] = 28008,
  [SMALL_STATE(1541)] = 28063,
  [SMALL_STATE(1542)] = 28118,
  [SMALL_STATE(1543)] = 28173,
  [SMALL_STATE(1544)] = 28228,
  [SMALL_STATE(1545)] = 28283,
  [SMALL_STATE(1546)] = 28338,
  [SMALL_STATE(1547)] = 28393,
  [SMALL_STATE(1548)] = 28448,
  [SMALL_STATE(1549)] = 28503,
  [SMALL_STATE(1550)] = 28562,
  [SMALL_STATE(1551)] = 28619,
  [SMALL_STATE(1552)] = 28674,
  [SMALL_STATE(1553)] = 28731,
  [SMALL_STATE(1554)] = 28786,
  [SMALL_STATE(1555)] = 28843,
  [SMALL_STATE(1556)] = 28898,
  [SMALL_STATE(1557)] = 28953,
  [SMALL_STATE(1558)] = 29014,
  [SMALL_STATE(1559)] = 29071,
  [SMALL_STATE(1560)] = 29126,
  [SMALL_STATE(1561)] = 29181,
  [SMALL_STATE(1562)] = 29242,
  [SMALL_STATE(1563)] = 29299,
  [SMALL_STATE(1564)] = 29354,
  [SMALL_STATE(1565)] = 29409,
  [SMALL_STATE(1566)] = 29464,
  [SMALL_STATE(1567)] = 29519,
  [SMALL_STATE(1568)] = 29574,
  [SMALL_STATE(1569)] = 29629,
  [SMALL_STATE(1570)] = 29684,
  [SMALL_STATE(1571)] = 29739,
  [SMALL_STATE(1572)] = 29794,
  [SMALL_STATE(1573)] = 29849,
  [SMALL_STATE(1574)] = 29904,
  [SMALL_STATE(1575)] = 29961,
  [SMALL_STATE(1576)] = 30016,
  [SMALL_STATE(1577)] = 30071,
  [SMALL_STATE(1578)] = 30126,
  [SMALL_STATE(1579)] = 30181,
  [SMALL_STATE(1580)] = 30238,
  [SMALL_STATE(1581)] = 30293,
  [SMALL_STATE(1582)] = 30354,
  [SMALL_STATE(1583)] = 30409,
  [SMALL_STATE(1584)] = 30464,
  [SMALL_STATE(1585)] = 30519,
  [SMALL_STATE(1586)] = 30574,
  [SMALL_STATE(1587)] = 30629,
  [SMALL_STATE(1588)] = 30684,
  [SMALL_STATE(1589)] = 30743,
  [SMALL_STATE(1590)] = 30798,
  [SMALL_STATE(1591)] = 30853,
  [SMALL_STATE(1592)] = 30908,
  [SMALL_STATE(1593)] = 30969,
  [SMALL_STATE(1594)] = 31026,
  [SMALL_STATE(1595)] = 31081,
  [SMALL_STATE(1596)] = 31138,
  [SMALL_STATE(1597)] = 31193,
  [SMALL_STATE(1598)] = 31248,
  [SMALL_STATE(1599)] = 31303,
  [SMALL_STATE(1600)] = 31358,
  [SMALL_STATE(1601)] = 31413,
  [SMALL_STATE(1602)] = 31468,
  [SMALL_STATE(1603)] = 31523,
  [SMALL_STATE(1604)] = 31578,
  [SMALL_STATE(1605)] = 31633,
  [SMALL_STATE(1606)] = 31694,
  [SMALL_STATE(1607)] = 31755,
  [SMALL_STATE(1608)] = 31810,
  [SMALL_STATE(1609)] = 31871,
  [SMALL_STATE(1610)] = 31926,
  [SMALL_STATE(1611)] = 31981,
  [SMALL_STATE(1612)] = 32036,
  [SMALL_STATE(1613)] = 32095,
  [SMALL_STATE(1614)] = 32150,
  [SMALL_STATE(1615)] = 32205,
  [SMALL_STATE(1616)] = 32266,
  [SMALL_STATE(1617)] = 32327,
  [SMALL_STATE(1618)] = 32386,
  [SMALL_STATE(1619)] = 32441,
  [SMALL_STATE(1620)] = 32502,
  [SMALL_STATE(1621)] = 32557,
  [SMALL_STATE(1622)] = 32612,
  [SMALL_STATE(1623)] = 32667,
  [SMALL_STATE(1624)] = 32722,
  [SMALL_STATE(1625)] = 32779,
  [SMALL_STATE(1626)] = 32834,
  [SMALL_STATE(1627)] = 32889,
  [SMALL_STATE(1628)] = 32948,
  [SMALL_STATE(1629)] = 33003,
  [SMALL_STATE(1630)] = 33058,
  [SMALL_STATE(1631)] = 33115,
  [SMALL_STATE(1632)] = 33170,
  [SMALL_STATE(1633)] = 33225,
  [SMALL_STATE(1634)] = 33284,
  [SMALL_STATE(1635)] = 33345,
  [SMALL_STATE(1636)] = 33400,
  [SMALL_STATE(1637)] = 33455,
  [SMALL_STATE(1638)] = 33510,
  [SMALL_STATE(1639)] = 33565,
  [SMALL_STATE(1640)] = 33620,
  [SMALL_STATE(1641)] = 33675,
  [SMALL_STATE(1642)] = 33730,
  [SMALL_STATE(1643)] = 33785,
  [SMALL_STATE(1644)] = 33846,
  [SMALL_STATE(1645)] = 33903,
  [SMALL_STATE(1646)] = 33964,
  [SMALL_STATE(1647)] = 34019,
  [SMALL_STATE(1648)] = 34078,
  [SMALL_STATE(1649)] = 34137,
  [SMALL_STATE(1650)] = 34198,
  [SMALL_STATE(1651)] = 34253,
  [SMALL_STATE(1652)] = 34309,
  [SMALL_STATE(1653)] = 34363,
  [SMALL_STATE(1654)] = 34417,
  [SMALL_STATE(1655)] = 34471,
  [SMALL_STATE(1656)] = 34525,
  [SMALL_STATE(1657)] = 34579,
  [SMALL_STATE(1658)] = 34633,
  [SMALL_STATE(1659)] = 34687,
  [SMALL_STATE(1660)] = 34741,
  [SMALL_STATE(1661)] = 34795,
  [SMALL_STATE(1662)] = 34849,
  [SMALL_STATE(1663)] = 34903,
  [SMALL_STATE(1664)] = 34957,
  [SMALL_STATE(1665)] = 35011,
  [SMALL_STATE(1666)] = 35065,
  [SMALL_STATE(1667)] = 35119,
  [SMALL_STATE(1668)] = 35173,
  [SMALL_STATE(1669)] = 35227,
  [SMALL_STATE(1670)] = 35281,
  [SMALL_STATE(1671)] = 35341,
  [SMALL_STATE(1672)] = 35395,
  [SMALL_STATE(1673)] = 35449,
  [SMALL_STATE(1674)] = 35503,
  [SMALL_STATE(1675)] = 35557,
  [SMALL_STATE(1676)] = 35611,
  [SMALL_STATE(1677)] = 35665,
  [SMALL_STATE(1678)] = 35719,
  [SMALL_STATE(1679)] = 35773,
  [SMALL_STATE(1680)] = 35827,
  [SMALL_STATE(1681)] = 35881,
  [SMALL_STATE(1682)] = 35935,
  [SMALL_STATE(1683)] = 35989,
  [SMALL_STATE(1684)] = 36043,
  [SMALL_STATE(1685)] = 36097,
  [SMALL_STATE(1686)] = 36151,
  [SMALL_STATE(1687)] = 36205,
  [SMALL_STATE(1688)] = 36259,
  [SMALL_STATE(1689)] = 36313,
  [SMALL_STATE(1690)] = 36367,
  [SMALL_STATE(1691)] = 36421,
  [SMALL_STATE(1692)] = 36475,
  [SMALL_STATE(1693)] = 36529,
  [SMALL_STATE(1694)] = 36583,
  [SMALL_STATE(1695)] = 36637,
  [SMALL_STATE(1696)] = 36691,
  [SMALL_STATE(1697)] = 36765,
  [SMALL_STATE(1698)] = 36819,
  [SMALL_STATE(1699)] = 36873,
  [SMALL_STATE(1700)] = 36927,
  [SMALL_STATE(1701)] = 36981,
  [SMALL_STATE(1702)] = 37035,
  [SMALL_STATE(1703)] = 37089,
  [SMALL_STATE(1704)] = 37143,
  [SMALL_STATE(1705)] = 37197,
  [SMALL_STATE(1706)] = 37253,
  [SMALL_STATE(1707)] = 37309,
  [SMALL_STATE(1708)] = 37369,
  [SMALL_STATE(1709)] = 37423,
  [SMALL_STATE(1710)] = 37477,
  [SMALL_STATE(1711)] = 37537,
  [SMALL_STATE(1712)] = 37591,
  [SMALL_STATE(1713)] = 37645,
  [SMALL_STATE(1714)] = 37699,
  [SMALL_STATE(1715)] = 37753,
  [SMALL_STATE(1716)] = 37807,
  [SMALL_STATE(1717)] = 37861,
  [SMALL_STATE(1718)] = 37947,
  [SMALL_STATE(1719)] = 38033,
  [SMALL_STATE(1720)] = 38119,
  [SMALL_STATE(1721)] = 38205,
  [SMALL_STATE(1722)] = 38291,
  [SMALL_STATE(1723)] = 38368,
  [SMALL_STATE(1724)] = 38425,
  [SMALL_STATE(1725)] = 38480,
  [SMALL_STATE(1726)] = 38561,
  [SMALL_STATE(1727)] = 38618,
  [SMALL_STATE(1728)] = 38671,
  [SMALL_STATE(1729)] = 38750,
  [SMALL_STATE(1730)] = 38805,
  [SMALL_STATE(1731)] = 38868,
  [SMALL_STATE(1732)] = 38945,
  [SMALL_STATE(1733)] = 39006,
  [SMALL_STATE(1734)] = 39059,
  [SMALL_STATE(1735)] = 39138,
  [SMALL_STATE(1736)] = 39201,
  [SMALL_STATE(1737)] = 39278,
  [SMALL_STATE(1738)] = 39341,
  [SMALL_STATE(1739)] = 39420,
  [SMALL_STATE(1740)] = 39483,
  [SMALL_STATE(1741)] = 39592,
  [SMALL_STATE(1742)] = 39701,
  [SMALL_STATE(1743)] = 39780,
  [SMALL_STATE(1744)] = 39889,
  [SMALL_STATE(1745)] = 39998,
  [SMALL_STATE(1746)] = 40107,
  [SMALL_STATE(1747)] = 40190,
  [SMALL_STATE(1748)] = 40263,
  [SMALL_STATE(1749)] = 40360,
  [SMALL_STATE(1750)] = 40459,
  [SMALL_STATE(1751)] = 40512,
  [SMALL_STATE(1752)] = 40603,
  [SMALL_STATE(1753)] = 40696,
  [SMALL_STATE(1754)] = 40791,
  [SMALL_STATE(1755)] = 40868,
  [SMALL_STATE(1756)] = 40947,
  [SMALL_STATE(1757)] = 41034,
  [SMALL_STATE(1758)] = 41135,
  [SMALL_STATE(1759)] = 41244,
  [SMALL_STATE(1760)] = 41353,
  [SMALL_STATE(1761)] = 41462,
  [SMALL_STATE(1762)] = 41571,
  [SMALL_STATE(1763)] = 41680,
  [SMALL_STATE(1764)] = 41789,
  [SMALL_STATE(1765)] = 41898,
  [SMALL_STATE(1766)] = 42007,
  [SMALL_STATE(1767)] = 42060,
  [SMALL_STATE(1768)] = 42137,
  [SMALL_STATE(1769)] = 42194,
  [SMALL_STATE(1770)] = 42273,
  [SMALL_STATE(1771)] = 42350,
  [SMALL_STATE(1772)] = 42403,
  [SMALL_STATE(1773)] = 42482,
  [SMALL_STATE(1774)] = 42559,
  [SMALL_STATE(1775)] = 42612,
  [SMALL_STATE(1776)] = 42691,
  [SMALL_STATE(1777)] = 42762,
  [SMALL_STATE(1778)] = 42831,
  [SMALL_STATE(1779)] = 42940,
  [SMALL_STATE(1780)] = 43019,
  [SMALL_STATE(1781)] = 43073,
  [SMALL_STATE(1782)] = 43131,
  [SMALL_STATE(1783)] = 43239,
  [SMALL_STATE(1784)] = 43311,
  [SMALL_STATE(1785)] = 43385,
  [SMALL_STATE(1786)] = 43445,
  [SMALL_STATE(1787)] = 43497,
  [SMALL_STATE(1788)] = 43555,
  [SMALL_STATE(1789)] = 43613,
  [SMALL_STATE(1790)] = 43721,
  [SMALL_STATE(1791)] = 43829,
  [SMALL_STATE(1792)] = 43911,
  [SMALL_STATE(1793)] = 43983,
  [SMALL_STATE(1794)] = 44039,
  [SMALL_STATE(1795)] = 44147,
  [SMALL_STATE(1796)] = 44199,
  [SMALL_STATE(1797)] = 44259,
  [SMALL_STATE(1798)] = 44315,
  [SMALL_STATE(1799)] = 44391,
  [SMALL_STATE(1800)] = 44447,
  [SMALL_STATE(1801)] = 44519,
  [SMALL_STATE(1802)] = 44579,
  [SMALL_STATE(1803)] = 44675,
  [SMALL_STATE(1804)] = 44773,
  [SMALL_STATE(1805)] = 44851,
  [SMALL_STATE(1806)] = 44941,
  [SMALL_STATE(1807)] = 45033,
  [SMALL_STATE(1808)] = 45127,
  [SMALL_STATE(1809)] = 45203,
  [SMALL_STATE(1810)] = 45281,
  [SMALL_STATE(1811)] = 45345,
  [SMALL_STATE(1812)] = 45431,
  [SMALL_STATE(1813)] = 45531,
  [SMALL_STATE(1814)] = 45589,
  [SMALL_STATE(1815)] = 45659,
  [SMALL_STATE(1816)] = 45767,
  [SMALL_STATE(1817)] = 45883,
  [SMALL_STATE(1818)] = 45991,
  [SMALL_STATE(1819)] = 46099,
  [SMALL_STATE(1820)] = 46207,
  [SMALL_STATE(1821)] = 46315,
  [SMALL_STATE(1822)] = 46369,
  [SMALL_STATE(1823)] = 46423,
  [SMALL_STATE(1824)] = 46531,
  [SMALL_STATE(1825)] = 46603,
  [SMALL_STATE(1826)] = 46719,
  [SMALL_STATE(1827)] = 46771,
  [SMALL_STATE(1828)] = 46825,
  [SMALL_STATE(1829)] = 46933,
  [SMALL_STATE(1830)] = 47005,
  [SMALL_STATE(1831)] = 47113,
  [SMALL_STATE(1832)] = 47181,
  [SMALL_STATE(1833)] = 47297,
  [SMALL_STATE(1834)] = 47369,
  [SMALL_STATE(1835)] = 47431,
  [SMALL_STATE(1836)] = 47493,
  [SMALL_STATE(1837)] = 47601,
  [SMALL_STATE(1838)] = 47709,
  [SMALL_STATE(1839)] = 47761,
  [SMALL_STATE(1840)] = 47869,
  [SMALL_STATE(1841)] = 47977,
  [SMALL_STATE(1842)] = 48085,
  [SMALL_STATE(1843)] = 48167,
  [SMALL_STATE(1844)] = 48239,
  [SMALL_STATE(1845)] = 48335,
  [SMALL_STATE(1846)] = 48433,
  [SMALL_STATE(1847)] = 48511,
  [SMALL_STATE(1848)] = 48601,
  [SMALL_STATE(1849)] = 48693,
  [SMALL_STATE(1850)] = 48787,
  [SMALL_STATE(1851)] = 48863,
  [SMALL_STATE(1852)] = 48941,
  [SMALL_STATE(1853)] = 49027,
  [SMALL_STATE(1854)] = 49127,
  [SMALL_STATE(1855)] = 49235,
  [SMALL_STATE(1856)] = 49343,
  [SMALL_STATE(1857)] = 49451,
  [SMALL_STATE(1858)] = 49559,
  [SMALL_STATE(1859)] = 49667,
  [SMALL_STATE(1860)] = 49775,
  [SMALL_STATE(1861)] = 49883,
  [SMALL_STATE(1862)] = 49991,
  [SMALL_STATE(1863)] = 50053,
  [SMALL_STATE(1864)] = 50115,
  [SMALL_STATE(1865)] = 50231,
  [SMALL_STATE(1866)] = 50287,
  [SMALL_STATE(1867)] = 50395,
  [SMALL_STATE(1868)] = 50455,
  [SMALL_STATE(1869)] = 50563,
  [SMALL_STATE(1870)] = 50637,
  [SMALL_STATE(1871)] = 50715,
  [SMALL_STATE(1872)] = 50767,
  [SMALL_STATE(1873)] = 50875,
  [SMALL_STATE(1874)] = 50945,
  [SMALL_STATE(1875)] = 51021,
  [SMALL_STATE(1876)] = 51129,
  [SMALL_STATE(1877)] = 51197,
  [SMALL_STATE(1878)] = 51280,
  [SMALL_STATE(1879)] = 51331,
  [SMALL_STATE(1880)] = 51382,
  [SMALL_STATE(1881)] = 51433,
  [SMALL_STATE(1882)] = 51484,
  [SMALL_STATE(1883)] = 51535,
  [SMALL_STATE(1884)] = 51592,
  [SMALL_STATE(1885)] = 51643,
  [SMALL_STATE(1886)] = 51698,
  [SMALL_STATE(1887)] = 51805,
  [SMALL_STATE(1888)] = 51912,
  [SMALL_STATE(1889)] = 52019,
  [SMALL_STATE(1890)] = 52102,
  [SMALL_STATE(1891)] = 52209,
  [SMALL_STATE(1892)] = 52290,
  [SMALL_STATE(1893)] = 52363,
  [SMALL_STATE(1894)] = 52474,
  [SMALL_STATE(1895)] = 52583,
  [SMALL_STATE(1896)] = 52654,
  [SMALL_STATE(1897)] = 52749,
  [SMALL_STATE(1898)] = 52846,
  [SMALL_STATE(1899)] = 52923,
  [SMALL_STATE(1900)] = 53012,
  [SMALL_STATE(1901)] = 53103,
  [SMALL_STATE(1902)] = 53196,
  [SMALL_STATE(1903)] = 53307,
  [SMALL_STATE(1904)] = 53382,
  [SMALL_STATE(1905)] = 53459,
  [SMALL_STATE(1906)] = 53570,
  [SMALL_STATE(1907)] = 53655,
  [SMALL_STATE(1908)] = 53708,
  [SMALL_STATE(1909)] = 53807,
  [SMALL_STATE(1910)] = 53860,
  [SMALL_STATE(1911)] = 53917,
  [SMALL_STATE(1912)] = 53970,
  [SMALL_STATE(1913)] = 54021,
  [SMALL_STATE(1914)] = 54128,
  [SMALL_STATE(1915)] = 54235,
  [SMALL_STATE(1916)] = 54288,
  [SMALL_STATE(1917)] = 54339,
  [SMALL_STATE(1918)] = 54422,
  [SMALL_STATE(1919)] = 54473,
  [SMALL_STATE(1920)] = 54580,
  [SMALL_STATE(1921)] = 54637,
  [SMALL_STATE(1922)] = 54696,
  [SMALL_STATE(1923)] = 54763,
  [SMALL_STATE(1924)] = 54838,
  [SMALL_STATE(1925)] = 54945,
  [SMALL_STATE(1926)] = 55002,
  [SMALL_STATE(1927)] = 55059,
  [SMALL_STATE(1928)] = 55166,
  [SMALL_STATE(1929)] = 55219,
  [SMALL_STATE(1930)] = 55288,
  [SMALL_STATE(1931)] = 55395,
  [SMALL_STATE(1932)] = 55446,
  [SMALL_STATE(1933)] = 55553,
  [SMALL_STATE(1934)] = 55606,
  [SMALL_STATE(1935)] = 55665,
  [SMALL_STATE(1936)] = 55724,
  [SMALL_STATE(1937)] = 55783,
  [SMALL_STATE(1938)] = 55838,
  [SMALL_STATE(1939)] = 55889,
  [SMALL_STATE(1940)] = 55940,
  [SMALL_STATE(1941)] = 56051,
  [SMALL_STATE(1942)] = 56108,
  [SMALL_STATE(1943)] = 56165,
  [SMALL_STATE(1944)] = 56276,
  [SMALL_STATE(1945)] = 56387,
  [SMALL_STATE(1946)] = 56498,
  [SMALL_STATE(1947)] = 56605,
  [SMALL_STATE(1948)] = 56688,
  [SMALL_STATE(1949)] = 56743,
  [SMALL_STATE(1950)] = 56806,
  [SMALL_STATE(1951)] = 56869,
  [SMALL_STATE(1952)] = 56922,
  [SMALL_STATE(1953)] = 56975,
  [SMALL_STATE(1954)] = 57058,
  [SMALL_STATE(1955)] = 57123,
  [SMALL_STATE(1956)] = 57188,
  [SMALL_STATE(1957)] = 57245,
  [SMALL_STATE(1958)] = 57302,
  [SMALL_STATE(1959)] = 57359,
  [SMALL_STATE(1960)] = 57466,
  [SMALL_STATE(1961)] = 57535,
  [SMALL_STATE(1962)] = 57588,
  [SMALL_STATE(1963)] = 57661,
  [SMALL_STATE(1964)] = 57712,
  [SMALL_STATE(1965)] = 57763,
  [SMALL_STATE(1966)] = 57814,
  [SMALL_STATE(1967)] = 57865,
  [SMALL_STATE(1968)] = 57916,
  [SMALL_STATE(1969)] = 57989,
  [SMALL_STATE(1970)] = 58058,
  [SMALL_STATE(1971)] = 58109,
  [SMALL_STATE(1972)] = 58182,
  [SMALL_STATE(1973)] = 58251,
  [SMALL_STATE(1974)] = 58302,
  [SMALL_STATE(1975)] = 58355,
  [SMALL_STATE(1976)] = 58406,
  [SMALL_STATE(1977)] = 58467,
  [SMALL_STATE(1978)] = 58520,
  [SMALL_STATE(1979)] = 58571,
  [SMALL_STATE(1980)] = 58630,
  [SMALL_STATE(1981)] = 58687,
  [SMALL_STATE(1982)] = 58742,
  [SMALL_STATE(1983)] = 58799,
  [SMALL_STATE(1984)] = 58852,
  [SMALL_STATE(1985)] = 58903,
  [SMALL_STATE(1986)] = 58954,
  [SMALL_STATE(1987)] = 59005,
  [SMALL_STATE(1988)] = 59058,
  [SMALL_STATE(1989)] = 59109,
  [SMALL_STATE(1990)] = 59160,
  [SMALL_STATE(1991)] = 59213,
  [SMALL_STATE(1992)] = 59264,
  [SMALL_STATE(1993)] = 59321,
  [SMALL_STATE(1994)] = 59372,
  [SMALL_STATE(1995)] = 59423,
  [SMALL_STATE(1996)] = 59474,
  [SMALL_STATE(1997)] = 59525,
  [SMALL_STATE(1998)] = 59576,
  [SMALL_STATE(1999)] = 59627,
  [SMALL_STATE(2000)] = 59680,
  [SMALL_STATE(2001)] = 59731,
  [SMALL_STATE(2002)] = 59786,
  [SMALL_STATE(2003)] = 59849,
  [SMALL_STATE(2004)] = 59912,
  [SMALL_STATE(2005)] = 59963,
  [SMALL_STATE(2006)] = 60072,
  [SMALL_STATE(2007)] = 60125,
  [SMALL_STATE(2008)] = 60176,
  [SMALL_STATE(2009)] = 60227,
  [SMALL_STATE(2010)] = 60278,
  [SMALL_STATE(2011)] = 60329,
  [SMALL_STATE(2012)] = 60380,
  [SMALL_STATE(2013)] = 60431,
  [SMALL_STATE(2014)] = 60482,
  [SMALL_STATE(2015)] = 60555,
  [SMALL_STATE(2016)] = 60606,
  [SMALL_STATE(2017)] = 60657,
  [SMALL_STATE(2018)] = 60708,
  [SMALL_STATE(2019)] = 60759,
  [SMALL_STATE(2020)] = 60814,
  [SMALL_STATE(2021)] = 60877,
  [SMALL_STATE(2022)] = 60928,
  [SMALL_STATE(2023)] = 60979,
  [SMALL_STATE(2024)] = 61030,
  [SMALL_STATE(2025)] = 61081,
  [SMALL_STATE(2026)] = 61144,
  [SMALL_STATE(2027)] = 61195,
  [SMALL_STATE(2028)] = 61258,
  [SMALL_STATE(2029)] = 61331,
  [SMALL_STATE(2030)] = 61382,
  [SMALL_STATE(2031)] = 61435,
  [SMALL_STATE(2032)] = 61486,
  [SMALL_STATE(2033)] = 61537,
  [SMALL_STATE(2034)] = 61588,
  [SMALL_STATE(2035)] = 61651,
  [SMALL_STATE(2036)] = 61714,
  [SMALL_STATE(2037)] = 61771,
  [SMALL_STATE(2038)] = 61822,
  [SMALL_STATE(2039)] = 61873,
  [SMALL_STATE(2040)] = 61924,
  [SMALL_STATE(2041)] = 61981,
  [SMALL_STATE(2042)] = 62088,
  [SMALL_STATE(2043)] = 62145,
  [SMALL_STATE(2044)] = 62202,
  [SMALL_STATE(2045)] = 62255,
  [SMALL_STATE(2046)] = 62308,
  [SMALL_STATE(2047)] = 62367,
  [SMALL_STATE(2048)] = 62418,
  [SMALL_STATE(2049)] = 62469,
  [SMALL_STATE(2050)] = 62520,
  [SMALL_STATE(2051)] = 62571,
  [SMALL_STATE(2052)] = 62622,
  [SMALL_STATE(2053)] = 62673,
  [SMALL_STATE(2054)] = 62724,
  [SMALL_STATE(2055)] = 62775,
  [SMALL_STATE(2056)] = 62826,
  [SMALL_STATE(2057)] = 62877,
  [SMALL_STATE(2058)] = 62928,
  [SMALL_STATE(2059)] = 62979,
  [SMALL_STATE(2060)] = 63030,
  [SMALL_STATE(2061)] = 63081,
  [SMALL_STATE(2062)] = 63132,
  [SMALL_STATE(2063)] = 63183,
  [SMALL_STATE(2064)] = 63234,
  [SMALL_STATE(2065)] = 63287,
  [SMALL_STATE(2066)] = 63360,
  [SMALL_STATE(2067)] = 63429,
  [SMALL_STATE(2068)] = 63480,
  [SMALL_STATE(2069)] = 63549,
  [SMALL_STATE(2070)] = 63600,
  [SMALL_STATE(2071)] = 63671,
  [SMALL_STATE(2072)] = 63744,
  [SMALL_STATE(2073)] = 63795,
  [SMALL_STATE(2074)] = 63846,
  [SMALL_STATE(2075)] = 63899,
  [SMALL_STATE(2076)] = 63982,
  [SMALL_STATE(2077)] = 64033,
  [SMALL_STATE(2078)] = 64084,
  [SMALL_STATE(2079)] = 64135,
  [SMALL_STATE(2080)] = 64186,
  [SMALL_STATE(2081)] = 64247,
  [SMALL_STATE(2082)] = 64354,
  [SMALL_STATE(2083)] = 64461,
  [SMALL_STATE(2084)] = 64568,
  [SMALL_STATE(2085)] = 64675,
  [SMALL_STATE(2086)] = 64782,
  [SMALL_STATE(2087)] = 64863,
  [SMALL_STATE(2088)] = 64934,
  [SMALL_STATE(2089)] = 65029,
  [SMALL_STATE(2090)] = 65126,
  [SMALL_STATE(2091)] = 65203,
  [SMALL_STATE(2092)] = 65292,
  [SMALL_STATE(2093)] = 65383,
  [SMALL_STATE(2094)] = 65476,
  [SMALL_STATE(2095)] = 65551,
  [SMALL_STATE(2096)] = 65628,
  [SMALL_STATE(2097)] = 65713,
  [SMALL_STATE(2098)] = 65812,
  [SMALL_STATE(2099)] = 65919,
  [SMALL_STATE(2100)] = 66026,
  [SMALL_STATE(2101)] = 66133,
  [SMALL_STATE(2102)] = 66240,
  [SMALL_STATE(2103)] = 66347,
  [SMALL_STATE(2104)] = 66454,
  [SMALL_STATE(2105)] = 66561,
  [SMALL_STATE(2106)] = 66668,
  [SMALL_STATE(2107)] = 66737,
  [SMALL_STATE(2108)] = 66812,
  [SMALL_STATE(2109)] = 66919,
  [SMALL_STATE(2110)] = 66986,
  [SMALL_STATE(2111)] = 67037,
  [SMALL_STATE(2112)] = 67101,
  [SMALL_STATE(2113)] = 67161,
  [SMALL_STATE(2114)] = 67221,
  [SMALL_STATE(2115)] = 67285,
  [SMALL_STATE(2116)] = 67343,
  [SMALL_STATE(2117)] = 67401,
  [SMALL_STATE(2118)] = 67463,
  [SMALL_STATE(2119)] = 67525,
  [SMALL_STATE(2120)] = 67587,
  [SMALL_STATE(2121)] = 67649,
  [SMALL_STATE(2122)] = 67759,
  [SMALL_STATE(2123)] = 67821,
  [SMALL_STATE(2124)] = 67883,
  [SMALL_STATE(2125)] = 67993,
  [SMALL_STATE(2126)] = 68047,
  [SMALL_STATE(2127)] = 68157,
  [SMALL_STATE(2128)] = 68211,
  [SMALL_STATE(2129)] = 68265,
  [SMALL_STATE(2130)] = 68319,
  [SMALL_STATE(2131)] = 68369,
  [SMALL_STATE(2132)] = 68429,
  [SMALL_STATE(2133)] = 68535,
  [SMALL_STATE(2134)] = 68641,
  [SMALL_STATE(2135)] = 68691,
  [SMALL_STATE(2136)] = 68797,
  [SMALL_STATE(2137)] = 68903,
  [SMALL_STATE(2138)] = 68969,
  [SMALL_STATE(2139)] = 69033,
  [SMALL_STATE(2140)] = 69139,
  [SMALL_STATE(2141)] = 69245,
  [SMALL_STATE(2142)] = 69325,
  [SMALL_STATE(2143)] = 69435,
  [SMALL_STATE(2144)] = 69505,
  [SMALL_STATE(2145)] = 69615,
  [SMALL_STATE(2146)] = 69709,
  [SMALL_STATE(2147)] = 69805,
  [SMALL_STATE(2148)] = 69881,
  [SMALL_STATE(2149)] = 69969,
  [SMALL_STATE(2150)] = 70059,
  [SMALL_STATE(2151)] = 70151,
  [SMALL_STATE(2152)] = 70225,
  [SMALL_STATE(2153)] = 70301,
  [SMALL_STATE(2154)] = 70385,
  [SMALL_STATE(2155)] = 70483,
  [SMALL_STATE(2156)] = 70589,
  [SMALL_STATE(2157)] = 70695,
  [SMALL_STATE(2158)] = 70761,
  [SMALL_STATE(2159)] = 70867,
  [SMALL_STATE(2160)] = 70973,
  [SMALL_STATE(2161)] = 71079,
  [SMALL_STATE(2162)] = 71185,
  [SMALL_STATE(2163)] = 71291,
  [SMALL_STATE(2164)] = 71345,
  [SMALL_STATE(2165)] = 71399,
  [SMALL_STATE(2166)] = 71453,
  [SMALL_STATE(2167)] = 71563,
  [SMALL_STATE(2168)] = 71669,
  [SMALL_STATE(2169)] = 71723,
  [SMALL_STATE(2170)] = 71797,
  [SMALL_STATE(2171)] = 71851,
  [SMALL_STATE(2172)] = 71915,
  [SMALL_STATE(2173)] = 71991,
  [SMALL_STATE(2174)] = 72043,
  [SMALL_STATE(2175)] = 72153,
  [SMALL_STATE(2176)] = 72213,
  [SMALL_STATE(2177)] = 72269,
  [SMALL_STATE(2178)] = 72333,
  [SMALL_STATE(2179)] = 72399,
  [SMALL_STATE(2180)] = 72465,
  [SMALL_STATE(2181)] = 72517,
  [SMALL_STATE(2182)] = 72569,
  [SMALL_STATE(2183)] = 72623,
  [SMALL_STATE(2184)] = 72729,
  [SMALL_STATE(2185)] = 72781,
  [SMALL_STATE(2186)] = 72833,
  [SMALL_STATE(2187)] = 72887,
  [SMALL_STATE(2188)] = 72941,
  [SMALL_STATE(2189)] = 73051,
  [SMALL_STATE(2190)] = 73101,
  [SMALL_STATE(2191)] = 73153,
  [SMALL_STATE(2192)] = 73205,
  [SMALL_STATE(2193)] = 73259,
  [SMALL_STATE(2194)] = 73309,
  [SMALL_STATE(2195)] = 73361,
  [SMALL_STATE(2196)] = 73411,
  [SMALL_STATE(2197)] = 73475,
  [SMALL_STATE(2198)] = 73525,
  [SMALL_STATE(2199)] = 73575,
  [SMALL_STATE(2200)] = 73629,
  [SMALL_STATE(2201)] = 73679,
  [SMALL_STATE(2202)] = 73729,
  [SMALL_STATE(2203)] = 73787,
  [SMALL_STATE(2204)] = 73851,
  [SMALL_STATE(2205)] = 73901,
  [SMALL_STATE(2206)] = 73967,
  [SMALL_STATE(2207)] = 74017,
  [SMALL_STATE(2208)] = 74067,
  [SMALL_STATE(2209)] = 74177,
  [SMALL_STATE(2210)] = 74229,
  [SMALL_STATE(2211)] = 74279,
  [SMALL_STATE(2212)] = 74329,
  [SMALL_STATE(2213)] = 74439,
  [SMALL_STATE(2214)] = 74497,
  [SMALL_STATE(2215)] = 74571,
  [SMALL_STATE(2216)] = 74635,
  [SMALL_STATE(2217)] = 74701,
  [SMALL_STATE(2218)] = 74775,
  [SMALL_STATE(2219)] = 74851,
  [SMALL_STATE(2220)] = 74961,
  [SMALL_STATE(2221)] = 75011,
  [SMALL_STATE(2222)] = 75063,
  [SMALL_STATE(2223)] = 75113,
  [SMALL_STATE(2224)] = 75189,
  [SMALL_STATE(2225)] = 75295,
  [SMALL_STATE(2226)] = 75405,
  [SMALL_STATE(2227)] = 75461,
  [SMALL_STATE(2228)] = 75571,
  [SMALL_STATE(2229)] = 75621,
  [SMALL_STATE(2230)] = 75679,
  [SMALL_STATE(2231)] = 75729,
  [SMALL_STATE(2232)] = 75839,
  [SMALL_STATE(2233)] = 75893,
  [SMALL_STATE(2234)] = 75951,
  [SMALL_STATE(2235)] = 76001,
  [SMALL_STATE(2236)] = 76065,
  [SMALL_STATE(2237)] = 76125,
  [SMALL_STATE(2238)] = 76235,
  [SMALL_STATE(2239)] = 76345,
  [SMALL_STATE(2240)] = 76413,
  [SMALL_STATE(2241)] = 76487,
  [SMALL_STATE(2242)] = 76593,
  [SMALL_STATE(2243)] = 76659,
  [SMALL_STATE(2244)] = 76713,
  [SMALL_STATE(2245)] = 76779,
  [SMALL_STATE(2246)] = 76829,
  [SMALL_STATE(2247)] = 76883,
  [SMALL_STATE(2248)] = 76937,
  [SMALL_STATE(2249)] = 77003,
  [SMALL_STATE(2250)] = 77111,
  [SMALL_STATE(2251)] = 77221,
  [SMALL_STATE(2252)] = 77271,
  [SMALL_STATE(2253)] = 77335,
  [SMALL_STATE(2254)] = 77401,
  [SMALL_STATE(2255)] = 77455,
  [SMALL_STATE(2256)] = 77505,
  [SMALL_STATE(2257)] = 77563,
  [SMALL_STATE(2258)] = 77627,
  [SMALL_STATE(2259)] = 77677,
  [SMALL_STATE(2260)] = 77731,
  [SMALL_STATE(2261)] = 77781,
  [SMALL_STATE(2262)] = 77835,
  [SMALL_STATE(2263)] = 77885,
  [SMALL_STATE(2264)] = 77949,
  [SMALL_STATE(2265)] = 78011,
  [SMALL_STATE(2266)] = 78061,
  [SMALL_STATE(2267)] = 78111,
  [SMALL_STATE(2268)] = 78163,
  [SMALL_STATE(2269)] = 78227,
  [SMALL_STATE(2270)] = 78337,
  [SMALL_STATE(2271)] = 78401,
  [SMALL_STATE(2272)] = 78457,
  [SMALL_STATE(2273)] = 78567,
  [SMALL_STATE(2274)] = 78677,
  [SMALL_STATE(2275)] = 78741,
  [SMALL_STATE(2276)] = 78851,
  [SMALL_STATE(2277)] = 78915,
  [SMALL_STATE(2278)] = 78965,
  [SMALL_STATE(2279)] = 79023,
  [SMALL_STATE(2280)] = 79073,
  [SMALL_STATE(2281)] = 79123,
  [SMALL_STATE(2282)] = 79173,
  [SMALL_STATE(2283)] = 79223,
  [SMALL_STATE(2284)] = 79273,
  [SMALL_STATE(2285)] = 79323,
  [SMALL_STATE(2286)] = 79433,
  [SMALL_STATE(2287)] = 79483,
  [SMALL_STATE(2288)] = 79593,
  [SMALL_STATE(2289)] = 79703,
  [SMALL_STATE(2290)] = 79813,
  [SMALL_STATE(2291)] = 79923,
  [SMALL_STATE(2292)] = 80033,
  [SMALL_STATE(2293)] = 80143,
  [SMALL_STATE(2294)] = 80197,
  [SMALL_STATE(2295)] = 80251,
  [SMALL_STATE(2296)] = 80305,
  [SMALL_STATE(2297)] = 80359,
  [SMALL_STATE(2298)] = 80423,
  [SMALL_STATE(2299)] = 80489,
  [SMALL_STATE(2300)] = 80547,
  [SMALL_STATE(2301)] = 80613,
  [SMALL_STATE(2302)] = 80723,
  [SMALL_STATE(2303)] = 80781,
  [SMALL_STATE(2304)] = 80847,
  [SMALL_STATE(2305)] = 80897,
  [SMALL_STATE(2306)] = 81007,
  [SMALL_STATE(2307)] = 81071,
  [SMALL_STATE(2308)] = 81137,
  [SMALL_STATE(2309)] = 81247,
  [SMALL_STATE(2310)] = 81301,
  [SMALL_STATE(2311)] = 81351,
  [SMALL_STATE(2312)] = 81461,
  [SMALL_STATE(2313)] = 81567,
  [SMALL_STATE(2314)] = 81633,
  [SMALL_STATE(2315)] = 81687,
  [SMALL_STATE(2316)] = 81755,
  [SMALL_STATE(2317)] = 81811,
  [SMALL_STATE(2318)] = 81861,
  [SMALL_STATE(2319)] = 81911,
  [SMALL_STATE(2320)] = 81961,
  [SMALL_STATE(2321)] = 82011,
  [SMALL_STATE(2322)] = 82085,
  [SMALL_STATE(2323)] = 82161,
  [SMALL_STATE(2324)] = 82211,
  [SMALL_STATE(2325)] = 82261,
  [SMALL_STATE(2326)] = 82311,
  [SMALL_STATE(2327)] = 82361,
  [SMALL_STATE(2328)] = 82411,
  [SMALL_STATE(2329)] = 82521,
  [SMALL_STATE(2330)] = 82631,
  [SMALL_STATE(2331)] = 82741,
  [SMALL_STATE(2332)] = 82795,
  [SMALL_STATE(2333)] = 82869,
  [SMALL_STATE(2334)] = 82919,
  [SMALL_STATE(2335)] = 82995,
  [SMALL_STATE(2336)] = 83059,
  [SMALL_STATE(2337)] = 83169,
  [SMALL_STATE(2338)] = 83279,
  [SMALL_STATE(2339)] = 83335,
  [SMALL_STATE(2340)] = 83391,
  [SMALL_STATE(2341)] = 83455,
  [SMALL_STATE(2342)] = 83565,
  [SMALL_STATE(2343)] = 83615,
  [SMALL_STATE(2344)] = 83701,
  [SMALL_STATE(2345)] = 83775,
  [SMALL_STATE(2346)] = 83829,
  [SMALL_STATE(2347)] = 83905,
  [SMALL_STATE(2348)] = 83967,
  [SMALL_STATE(2349)] = 84029,
  [SMALL_STATE(2350)] = 84083,
  [SMALL_STATE(2351)] = 84135,
  [SMALL_STATE(2352)] = 84187,
  [SMALL_STATE(2353)] = 84253,
  [SMALL_STATE(2354)] = 84359,
  [SMALL_STATE(2355)] = 84421,
  [SMALL_STATE(2356)] = 84483,
  [SMALL_STATE(2357)] = 84535,
  [SMALL_STATE(2358)] = 84601,
  [SMALL_STATE(2359)] = 84651,
  [SMALL_STATE(2360)] = 84756,
  [SMALL_STATE(2361)] = 84831,
  [SMALL_STATE(2362)] = 84914,
  [SMALL_STATE(2363)] = 85011,
  [SMALL_STATE(2364)] = 85116,
  [SMALL_STATE(2365)] = 85221,
  [SMALL_STATE(2366)] = 85326,
  [SMALL_STATE(2367)] = 85431,
  [SMALL_STATE(2368)] = 85536,
  [SMALL_STATE(2369)] = 85641,
  [SMALL_STATE(2370)] = 85746,
  [SMALL_STATE(2371)] = 85851,
  [SMALL_STATE(2372)] = 85956,
  [SMALL_STATE(2373)] = 86007,
  [SMALL_STATE(2374)] = 86112,
  [SMALL_STATE(2375)] = 86181,
  [SMALL_STATE(2376)] = 86240,
  [SMALL_STATE(2377)] = 86291,
  [SMALL_STATE(2378)] = 86396,
  [SMALL_STATE(2379)] = 86465,
  [SMALL_STATE(2380)] = 86524,
  [SMALL_STATE(2381)] = 86583,
  [SMALL_STATE(2382)] = 86634,
  [SMALL_STATE(2383)] = 86685,
  [SMALL_STATE(2384)] = 86744,
  [SMALL_STATE(2385)] = 86821,
  [SMALL_STATE(2386)] = 86872,
  [SMALL_STATE(2387)] = 86977,
  [SMALL_STATE(2388)] = 87036,
  [SMALL_STATE(2389)] = 87141,
  [SMALL_STATE(2390)] = 87246,
  [SMALL_STATE(2391)] = 87351,
  [SMALL_STATE(2392)] = 87456,
  [SMALL_STATE(2393)] = 87561,
  [SMALL_STATE(2394)] = 87640,
  [SMALL_STATE(2395)] = 87709,
  [SMALL_STATE(2396)] = 87802,
  [SMALL_STATE(2397)] = 87897,
  [SMALL_STATE(2398)] = 87972,
  [SMALL_STATE(2399)] = 88031,
  [SMALL_STATE(2400)] = 88106,
  [SMALL_STATE(2401)] = 88193,
  [SMALL_STATE(2402)] = 88252,
  [SMALL_STATE(2403)] = 88341,
  [SMALL_STATE(2404)] = 88432,
  [SMALL_STATE(2405)] = 88499,
  [SMALL_STATE(2406)] = 88572,
  [SMALL_STATE(2407)] = 88677,
  [SMALL_STATE(2408)] = 88742,
  [SMALL_STATE(2409)] = 88815,
  [SMALL_STATE(2410)] = 88890,
  [SMALL_STATE(2411)] = 88973,
  [SMALL_STATE(2412)] = 89078,
  [SMALL_STATE(2413)] = 89175,
  [SMALL_STATE(2414)] = 89280,
  [SMALL_STATE(2415)] = 89347,
  [SMALL_STATE(2416)] = 89420,
  [SMALL_STATE(2417)] = 89525,
  [SMALL_STATE(2418)] = 89590,
  [SMALL_STATE(2419)] = 89695,
  [SMALL_STATE(2420)] = 89800,
  [SMALL_STATE(2421)] = 89905,
  [SMALL_STATE(2422)] = 90010,
  [SMALL_STATE(2423)] = 90063,
  [SMALL_STATE(2424)] = 90168,
  [SMALL_STATE(2425)] = 90273,
  [SMALL_STATE(2426)] = 90378,
  [SMALL_STATE(2427)] = 90483,
  [SMALL_STATE(2428)] = 90588,
  [SMALL_STATE(2429)] = 90647,
  [SMALL_STATE(2430)] = 90728,
  [SMALL_STATE(2431)] = 90785,
  [SMALL_STATE(2432)] = 90844,
  [SMALL_STATE(2433)] = 90899,
  [SMALL_STATE(2434)] = 90954,
  [SMALL_STATE(2435)] = 91013,
  [SMALL_STATE(2436)] = 91120,
  [SMALL_STATE(2437)] = 91175,
  [SMALL_STATE(2438)] = 91234,
  [SMALL_STATE(2439)] = 91303,
  [SMALL_STATE(2440)] = 91408,
  [SMALL_STATE(2441)] = 91467,
  [SMALL_STATE(2442)] = 91572,
  [SMALL_STATE(2443)] = 91629,
  [SMALL_STATE(2444)] = 91688,
  [SMALL_STATE(2445)] = 91747,
  [SMALL_STATE(2446)] = 91816,
  [SMALL_STATE(2447)] = 91907,
  [SMALL_STATE(2448)] = 91980,
  [SMALL_STATE(2449)] = 92035,
  [SMALL_STATE(2450)] = 92088,
  [SMALL_STATE(2451)] = 92193,
  [SMALL_STATE(2452)] = 92244,
  [SMALL_STATE(2453)] = 92303,
  [SMALL_STATE(2454)] = 92354,
  [SMALL_STATE(2455)] = 92461,
  [SMALL_STATE(2456)] = 92520,
  [SMALL_STATE(2457)] = 92577,
  [SMALL_STATE(2458)] = 92646,
  [SMALL_STATE(2459)] = 92705,
  [SMALL_STATE(2460)] = 92764,
  [SMALL_STATE(2461)] = 92821,
  [SMALL_STATE(2462)] = 92880,
  [SMALL_STATE(2463)] = 92937,
  [SMALL_STATE(2464)] = 92996,
  [SMALL_STATE(2465)] = 93049,
  [SMALL_STATE(2466)] = 93154,
  [SMALL_STATE(2467)] = 93213,
  [SMALL_STATE(2468)] = 93318,
  [SMALL_STATE(2469)] = 93423,
  [SMALL_STATE(2470)] = 93528,
  [SMALL_STATE(2471)] = 93585,
  [SMALL_STATE(2472)] = 93690,
  [SMALL_STATE(2473)] = 93741,
  [SMALL_STATE(2474)] = 93810,
  [SMALL_STATE(2475)] = 93915,
  [SMALL_STATE(2476)] = 93974,
  [SMALL_STATE(2477)] = 94029,
  [SMALL_STATE(2478)] = 94084,
  [SMALL_STATE(2479)] = 94173,
  [SMALL_STATE(2480)] = 94252,
  [SMALL_STATE(2481)] = 94307,
  [SMALL_STATE(2482)] = 94376,
  [SMALL_STATE(2483)] = 94469,
  [SMALL_STATE(2484)] = 94564,
  [SMALL_STATE(2485)] = 94623,
  [SMALL_STATE(2486)] = 94728,
  [SMALL_STATE(2487)] = 94833,
  [SMALL_STATE(2488)] = 94938,
  [SMALL_STATE(2489)] = 95043,
  [SMALL_STATE(2490)] = 95148,
  [SMALL_STATE(2491)] = 95227,
  [SMALL_STATE(2492)] = 95296,
  [SMALL_STATE(2493)] = 95389,
  [SMALL_STATE(2494)] = 95484,
  [SMALL_STATE(2495)] = 95559,
  [SMALL_STATE(2496)] = 95646,
  [SMALL_STATE(2497)] = 95735,
  [SMALL_STATE(2498)] = 95826,
  [SMALL_STATE(2499)] = 95899,
  [SMALL_STATE(2500)] = 95974,
  [SMALL_STATE(2501)] = 96057,
  [SMALL_STATE(2502)] = 96154,
  [SMALL_STATE(2503)] = 96259,
  [SMALL_STATE(2504)] = 96364,
  [SMALL_STATE(2505)] = 96469,
  [SMALL_STATE(2506)] = 96574,
  [SMALL_STATE(2507)] = 96679,
  [SMALL_STATE(2508)] = 96784,
  [SMALL_STATE(2509)] = 96889,
  [SMALL_STATE(2510)] = 96994,
  [SMALL_STATE(2511)] = 97053,
  [SMALL_STATE(2512)] = 97108,
  [SMALL_STATE(2513)] = 97183,
  [SMALL_STATE(2514)] = 97234,
  [SMALL_STATE(2515)] = 97301,
  [SMALL_STATE(2516)] = 97374,
  [SMALL_STATE(2517)] = 97479,
  [SMALL_STATE(2518)] = 97544,
  [SMALL_STATE(2519)] = 97631,
  [SMALL_STATE(2520)] = 97720,
  [SMALL_STATE(2521)] = 97779,
  [SMALL_STATE(2522)] = 97836,
  [SMALL_STATE(2523)] = 97887,
  [SMALL_STATE(2524)] = 97944,
  [SMALL_STATE(2525)] = 98003,
  [SMALL_STATE(2526)] = 98051,
  [SMALL_STATE(2527)] = 98111,
  [SMALL_STATE(2528)] = 98169,
  [SMALL_STATE(2529)] = 98273,
  [SMALL_STATE(2530)] = 98377,
  [SMALL_STATE(2531)] = 98481,
  [SMALL_STATE(2532)] = 98585,
  [SMALL_STATE(2533)] = 98663,
  [SMALL_STATE(2534)] = 98731,
  [SMALL_STATE(2535)] = 98823,
  [SMALL_STATE(2536)] = 98917,
  [SMALL_STATE(2537)] = 98991,
  [SMALL_STATE(2538)] = 99077,
  [SMALL_STATE(2539)] = 99165,
  [SMALL_STATE(2540)] = 99255,
  [SMALL_STATE(2541)] = 99327,
  [SMALL_STATE(2542)] = 99401,
  [SMALL_STATE(2543)] = 99483,
  [SMALL_STATE(2544)] = 99579,
  [SMALL_STATE(2545)] = 99683,
  [SMALL_STATE(2546)] = 99787,
  [SMALL_STATE(2547)] = 99891,
  [SMALL_STATE(2548)] = 99995,
  [SMALL_STATE(2549)] = 100099,
  [SMALL_STATE(2550)] = 100203,
  [SMALL_STATE(2551)] = 100307,
  [SMALL_STATE(2552)] = 100411,
  [SMALL_STATE(2553)] = 100517,
  [SMALL_STATE(2554)] = 100621,
  [SMALL_STATE(2555)] = 100675,
  [SMALL_STATE(2556)] = 100729,
  [SMALL_STATE(2557)] = 100801,
  [SMALL_STATE(2558)] = 100855,
  [SMALL_STATE(2559)] = 100909,
  [SMALL_STATE(2560)] = 100963,
  [SMALL_STATE(2561)] = 101017,
  [SMALL_STATE(2562)] = 101065,
  [SMALL_STATE(2563)] = 101119,
  [SMALL_STATE(2564)] = 101167,
  [SMALL_STATE(2565)] = 101221,
  [SMALL_STATE(2566)] = 101271,
  [SMALL_STATE(2567)] = 101321,
  [SMALL_STATE(2568)] = 101375,
  [SMALL_STATE(2569)] = 101429,
  [SMALL_STATE(2570)] = 101497,
  [SMALL_STATE(2571)] = 101567,
  [SMALL_STATE(2572)] = 101623,
  [SMALL_STATE(2573)] = 101727,
  [SMALL_STATE(2574)] = 101777,
  [SMALL_STATE(2575)] = 101827,
  [SMALL_STATE(2576)] = 101877,
  [SMALL_STATE(2577)] = 101927,
  [SMALL_STATE(2578)] = 101993,
  [SMALL_STATE(2579)] = 102065,
  [SMALL_STATE(2580)] = 102169,
  [SMALL_STATE(2581)] = 102233,
  [SMALL_STATE(2582)] = 102299,
  [SMALL_STATE(2583)] = 102367,
  [SMALL_STATE(2584)] = 102431,
  [SMALL_STATE(2585)] = 102491,
  [SMALL_STATE(2586)] = 102555,
  [SMALL_STATE(2587)] = 102615,
  [SMALL_STATE(2588)] = 102719,
  [SMALL_STATE(2589)] = 102823,
  [SMALL_STATE(2590)] = 102927,
  [SMALL_STATE(2591)] = 103031,
  [SMALL_STATE(2592)] = 103135,
  [SMALL_STATE(2593)] = 103239,
  [SMALL_STATE(2594)] = 103303,
  [SMALL_STATE(2595)] = 103363,
  [SMALL_STATE(2596)] = 103467,
  [SMALL_STATE(2597)] = 103517,
  [SMALL_STATE(2598)] = 103567,
  [SMALL_STATE(2599)] = 103617,
  [SMALL_STATE(2600)] = 103667,
  [SMALL_STATE(2601)] = 103731,
  [SMALL_STATE(2602)] = 103835,
  [SMALL_STATE(2603)] = 103895,
  [SMALL_STATE(2604)] = 103945,
  [SMALL_STATE(2605)] = 104049,
  [SMALL_STATE(2606)] = 104103,
  [SMALL_STATE(2607)] = 104207,
  [SMALL_STATE(2608)] = 104271,
  [SMALL_STATE(2609)] = 104375,
  [SMALL_STATE(2610)] = 104434,
  [SMALL_STATE(2611)] = 104497,
  [SMALL_STATE(2612)] = 104598,
  [SMALL_STATE(2613)] = 104655,
  [SMALL_STATE(2614)] = 104714,
  [SMALL_STATE(2615)] = 104773,
  [SMALL_STATE(2616)] = 104832,
  [SMALL_STATE(2617)] = 104891,
  [SMALL_STATE(2618)] = 104950,
  [SMALL_STATE(2619)] = 105009,
  [SMALL_STATE(2620)] = 105066,
  [SMALL_STATE(2621)] = 105125,
  [SMALL_STATE(2622)] = 105190,
  [SMALL_STATE(2623)] = 105243,
  [SMALL_STATE(2624)] = 105304,
  [SMALL_STATE(2625)] = 105361,
  [SMALL_STATE(2626)] = 105418,
  [SMALL_STATE(2627)] = 105477,
  [SMALL_STATE(2628)] = 105536,
  [SMALL_STATE(2629)] = 105595,
  [SMALL_STATE(2630)] = 105654,
  [SMALL_STATE(2631)] = 105717,
  [SMALL_STATE(2632)] = 105774,
  [SMALL_STATE(2633)] = 105831,
  [SMALL_STATE(2634)] = 105888,
  [SMALL_STATE(2635)] = 105945,
  [SMALL_STATE(2636)] = 106002,
  [SMALL_STATE(2637)] = 106059,
  [SMALL_STATE(2638)] = 106116,
  [SMALL_STATE(2639)] = 106165,
  [SMALL_STATE(2640)] = 106222,
  [SMALL_STATE(2641)] = 106279,
  [SMALL_STATE(2642)] = 106336,
  [SMALL_STATE(2643)] = 106385,
  [SMALL_STATE(2644)] = 106434,
  [SMALL_STATE(2645)] = 106535,
  [SMALL_STATE(2646)] = 106592,
  [SMALL_STATE(2647)] = 106641,
  [SMALL_STATE(2648)] = 106698,
  [SMALL_STATE(2649)] = 106746,
  [SMALL_STATE(2650)] = 106792,
  [SMALL_STATE(2651)] = 106838,
  [SMALL_STATE(2652)] = 106884,
  [SMALL_STATE(2653)] = 106932,
  [SMALL_STATE(2654)] = 106978,
  [SMALL_STATE(2655)] = 107024,
  [SMALL_STATE(2656)] = 107070,
  [SMALL_STATE(2657)] = 107116,
  [SMALL_STATE(2658)] = 107162,
  [SMALL_STATE(2659)] = 107208,
  [SMALL_STATE(2660)] = 107254,
  [SMALL_STATE(2661)] = 107300,
  [SMALL_STATE(2662)] = 107346,
  [SMALL_STATE(2663)] = 107392,
  [SMALL_STATE(2664)] = 107438,
  [SMALL_STATE(2665)] = 107484,
  [SMALL_STATE(2666)] = 107530,
  [SMALL_STATE(2667)] = 107576,
  [SMALL_STATE(2668)] = 107624,
  [SMALL_STATE(2669)] = 107670,
  [SMALL_STATE(2670)] = 107716,
  [SMALL_STATE(2671)] = 107762,
  [SMALL_STATE(2672)] = 107808,
  [SMALL_STATE(2673)] = 107854,
  [SMALL_STATE(2674)] = 107900,
  [SMALL_STATE(2675)] = 107946,
  [SMALL_STATE(2676)] = 107994,
  [SMALL_STATE(2677)] = 108042,
  [SMALL_STATE(2678)] = 108090,
  [SMALL_STATE(2679)] = 108136,
  [SMALL_STATE(2680)] = 108182,
  [SMALL_STATE(2681)] = 108228,
  [SMALL_STATE(2682)] = 108276,
  [SMALL_STATE(2683)] = 108324,
  [SMALL_STATE(2684)] = 108382,
  [SMALL_STATE(2685)] = 108428,
  [SMALL_STATE(2686)] = 108474,
  [SMALL_STATE(2687)] = 108522,
  [SMALL_STATE(2688)] = 108568,
  [SMALL_STATE(2689)] = 108614,
  [SMALL_STATE(2690)] = 108662,
  [SMALL_STATE(2691)] = 108708,
  [SMALL_STATE(2692)] = 108754,
  [SMALL_STATE(2693)] = 108800,
  [SMALL_STATE(2694)] = 108846,
  [SMALL_STATE(2695)] = 108896,
  [SMALL_STATE(2696)] = 108942,
  [SMALL_STATE(2697)] = 108988,
  [SMALL_STATE(2698)] = 109036,
  [SMALL_STATE(2699)] = 109084,
  [SMALL_STATE(2700)] = 109134,
  [SMALL_STATE(2701)] = 109184,
  [SMALL_STATE(2702)] = 109230,
  [SMALL_STATE(2703)] = 109276,
  [SMALL_STATE(2704)] = 109322,
  [SMALL_STATE(2705)] = 109368,
  [SMALL_STATE(2706)] = 109414,
  [SMALL_STATE(2707)] = 109462,
  [SMALL_STATE(2708)] = 109508,
  [SMALL_STATE(2709)] = 109554,
  [SMALL_STATE(2710)] = 109602,
  [SMALL_STATE(2711)] = 109648,
  [SMALL_STATE(2712)] = 109704,
  [SMALL_STATE(2713)] = 109750,
  [SMALL_STATE(2714)] = 109801,
  [SMALL_STATE(2715)] = 109852,
  [SMALL_STATE(2716)] = 109897,
  [SMALL_STATE(2717)] = 109942,
  [SMALL_STATE(2718)] = 109987,
  [SMALL_STATE(2719)] = 110032,
  [SMALL_STATE(2720)] = 110081,
  [SMALL_STATE(2721)] = 110126,
  [SMALL_STATE(2722)] = 110171,
  [SMALL_STATE(2723)] = 110238,
  [SMALL_STATE(2724)] = 110283,
  [SMALL_STATE(2725)] = 110336,
  [SMALL_STATE(2726)] = 110389,
  [SMALL_STATE(2727)] = 110437,
  [SMALL_STATE(2728)] = 110497,
  [SMALL_STATE(2729)] = 110553,
  [SMALL_STATE(2730)] = 110597,
  [SMALL_STATE(2731)] = 110655,
  [SMALL_STATE(2732)] = 110715,
  [SMALL_STATE(2733)] = 110787,
  [SMALL_STATE(2734)] = 110845,
  [SMALL_STATE(2735)] = 110903,
  [SMALL_STATE(2736)] = 110963,
  [SMALL_STATE(2737)] = 111035,
  [SMALL_STATE(2738)] = 111093,
  [SMALL_STATE(2739)] = 111141,
  [SMALL_STATE(2740)] = 111194,
  [SMALL_STATE(2741)] = 111247,
  [SMALL_STATE(2742)] = 111300,
  [SMALL_STATE(2743)] = 111353,
  [SMALL_STATE(2744)] = 111406,
  [SMALL_STATE(2745)] = 111459,
  [SMALL_STATE(2746)] = 111512,
  [SMALL_STATE(2747)] = 111565,
  [SMALL_STATE(2748)] = 111618,
  [SMALL_STATE(2749)] = 111671,
  [SMALL_STATE(2750)] = 111724,
  [SMALL_STATE(2751)] = 111777,
  [SMALL_STATE(2752)] = 111830,
  [SMALL_STATE(2753)] = 111883,
  [SMALL_STATE(2754)] = 111936,
  [SMALL_STATE(2755)] = 111989,
  [SMALL_STATE(2756)] = 112042,
  [SMALL_STATE(2757)] = 112095,
  [SMALL_STATE(2758)] = 112148,
  [SMALL_STATE(2759)] = 112201,
  [SMALL_STATE(2760)] = 112254,
  [SMALL_STATE(2761)] = 112307,
  [SMALL_STATE(2762)] = 112356,
  [SMALL_STATE(2763)] = 112409,
  [SMALL_STATE(2764)] = 112462,
  [SMALL_STATE(2765)] = 112515,
  [SMALL_STATE(2766)] = 112568,
  [SMALL_STATE(2767)] = 112631,
  [SMALL_STATE(2768)] = 112694,
  [SMALL_STATE(2769)] = 112747,
  [SMALL_STATE(2770)] = 112801,
  [SMALL_STATE(2771)] = 112881,
  [SMALL_STATE(2772)] = 112945,
  [SMALL_STATE(2773)] = 112999,
  [SMALL_STATE(2774)] = 113063,
  [SMALL_STATE(2775)] = 113123,
  [SMALL_STATE(2776)] = 113177,
  [SMALL_STATE(2777)] = 113231,
  [SMALL_STATE(2778)] = 113285,
  [SMALL_STATE(2779)] = 113339,
  [SMALL_STATE(2780)] = 113393,
  [SMALL_STATE(2781)] = 113447,
  [SMALL_STATE(2782)] = 113507,
  [SMALL_STATE(2783)] = 113561,
  [SMALL_STATE(2784)] = 113615,
  [SMALL_STATE(2785)] = 113695,
  [SMALL_STATE(2786)] = 113775,
  [SMALL_STATE(2787)] = 113839,
  [SMALL_STATE(2788)] = 113919,
  [SMALL_STATE(2789)] = 113999,
  [SMALL_STATE(2790)] = 114056,
  [SMALL_STATE(2791)] = 114097,
  [SMALL_STATE(2792)] = 114154,
  [SMALL_STATE(2793)] = 114211,
  [SMALL_STATE(2794)] = 114268,
  [SMALL_STATE(2795)] = 114319,
  [SMALL_STATE(2796)] = 114376,
  [SMALL_STATE(2797)] = 114429,
  [SMALL_STATE(2798)] = 114486,
  [SMALL_STATE(2799)] = 114543,
  [SMALL_STATE(2800)] = 114596,
  [SMALL_STATE(2801)] = 114653,
  [SMALL_STATE(2802)] = 114710,
  [SMALL_STATE(2803)] = 114751,
  [SMALL_STATE(2804)] = 114808,
  [SMALL_STATE(2805)] = 114849,
  [SMALL_STATE(2806)] = 114906,
  [SMALL_STATE(2807)] = 114947,
  [SMALL_STATE(2808)] = 115004,
  [SMALL_STATE(2809)] = 115061,
  [SMALL_STATE(2810)] = 115118,
  [SMALL_STATE(2811)] = 115159,
  [SMALL_STATE(2812)] = 115216,
  [SMALL_STATE(2813)] = 115259,
  [SMALL_STATE(2814)] = 115316,
  [SMALL_STATE(2815)] = 115366,
  [SMALL_STATE(2816)] = 115416,
  [SMALL_STATE(2817)] = 115464,
  [SMALL_STATE(2818)] = 115512,
  [SMALL_STATE(2819)] = 115560,
  [SMALL_STATE(2820)] = 115608,
  [SMALL_STATE(2821)] = 115656,
  [SMALL_STATE(2822)] = 115704,
  [SMALL_STATE(2823)] = 115752,
  [SMALL_STATE(2824)] = 115800,
  [SMALL_STATE(2825)] = 115848,
  [SMALL_STATE(2826)] = 115896,
  [SMALL_STATE(2827)] = 115944,
  [SMALL_STATE(2828)] = 115992,
  [SMALL_STATE(2829)] = 116040,
  [SMALL_STATE(2830)] = 116090,
  [SMALL_STATE(2831)] = 116138,
  [SMALL_STATE(2832)] = 116186,
  [SMALL_STATE(2833)] = 116234,
  [SMALL_STATE(2834)] = 116282,
  [SMALL_STATE(2835)] = 116330,
  [SMALL_STATE(2836)] = 116378,
  [SMALL_STATE(2837)] = 116426,
  [SMALL_STATE(2838)] = 116474,
  [SMALL_STATE(2839)] = 116522,
  [SMALL_STATE(2840)] = 116570,
  [SMALL_STATE(2841)] = 116618,
  [SMALL_STATE(2842)] = 116666,
  [SMALL_STATE(2843)] = 116714,
  [SMALL_STATE(2844)] = 116764,
  [SMALL_STATE(2845)] = 116812,
  [SMALL_STATE(2846)] = 116860,
  [SMALL_STATE(2847)] = 116908,
  [SMALL_STATE(2848)] = 116958,
  [SMALL_STATE(2849)] = 117006,
  [SMALL_STATE(2850)] = 117054,
  [SMALL_STATE(2851)] = 117104,
  [SMALL_STATE(2852)] = 117154,
  [SMALL_STATE(2853)] = 117202,
  [SMALL_STATE(2854)] = 117252,
  [SMALL_STATE(2855)] = 117300,
  [SMALL_STATE(2856)] = 117348,
  [SMALL_STATE(2857)] = 117396,
  [SMALL_STATE(2858)] = 117446,
  [SMALL_STATE(2859)] = 117494,
  [SMALL_STATE(2860)] = 117542,
  [SMALL_STATE(2861)] = 117590,
  [SMALL_STATE(2862)] = 117638,
  [SMALL_STATE(2863)] = 117688,
  [SMALL_STATE(2864)] = 117736,
  [SMALL_STATE(2865)] = 117784,
  [SMALL_STATE(2866)] = 117834,
  [SMALL_STATE(2867)] = 117882,
  [SMALL_STATE(2868)] = 117930,
  [SMALL_STATE(2869)] = 117980,
  [SMALL_STATE(2870)] = 118028,
  [SMALL_STATE(2871)] = 118078,
  [SMALL_STATE(2872)] = 118126,
  [SMALL_STATE(2873)] = 118176,
  [SMALL_STATE(2874)] = 118224,
  [SMALL_STATE(2875)] = 118272,
  [SMALL_STATE(2876)] = 118307,
  [SMALL_STATE(2877)] = 118348,
  [SMALL_STATE(2878)] = 118389,
  [SMALL_STATE(2879)] = 118430,
  [SMALL_STATE(2880)] = 118458,
  [SMALL_STATE(2881)] = 118486,
  [SMALL_STATE(2882)] = 118514,
  [SMALL_STATE(2883)] = 118542,
  [SMALL_STATE(2884)] = 118570,
  [SMALL_STATE(2885)] = 118598,
  [SMALL_STATE(2886)] = 118626,
  [SMALL_STATE(2887)] = 118654,
  [SMALL_STATE(2888)] = 118682,
  [SMALL_STATE(2889)] = 118710,
  [SMALL_STATE(2890)] = 118738,
  [SMALL_STATE(2891)] = 118766,
  [SMALL_STATE(2892)] = 118794,
  [SMALL_STATE(2893)] = 118822,
  [SMALL_STATE(2894)] = 118850,
  [SMALL_STATE(2895)] = 118878,
  [SMALL_STATE(2896)] = 118906,
  [SMALL_STATE(2897)] = 118934,
  [SMALL_STATE(2898)] = 118962,
  [SMALL_STATE(2899)] = 118990,
  [SMALL_STATE(2900)] = 119018,
  [SMALL_STATE(2901)] = 119046,
  [SMALL_STATE(2902)] = 119074,
  [SMALL_STATE(2903)] = 119102,
  [SMALL_STATE(2904)] = 119130,
  [SMALL_STATE(2905)] = 119158,
  [SMALL_STATE(2906)] = 119186,
  [SMALL_STATE(2907)] = 119214,
  [SMALL_STATE(2908)] = 119242,
  [SMALL_STATE(2909)] = 119270,
  [SMALL_STATE(2910)] = 119298,
  [SMALL_STATE(2911)] = 119326,
  [SMALL_STATE(2912)] = 119354,
  [SMALL_STATE(2913)] = 119382,
  [SMALL_STATE(2914)] = 119409,
  [SMALL_STATE(2915)] = 119436,
  [SMALL_STATE(2916)] = 119462,
  [SMALL_STATE(2917)] = 119492,
  [SMALL_STATE(2918)] = 119518,
  [SMALL_STATE(2919)] = 119544,
  [SMALL_STATE(2920)] = 119570,
  [SMALL_STATE(2921)] = 119596,
  [SMALL_STATE(2922)] = 119646,
  [SMALL_STATE(2923)] = 119676,
  [SMALL_STATE(2924)] = 119708,
  [SMALL_STATE(2925)] = 119736,
  [SMALL_STATE(2926)] = 119774,
  [SMALL_STATE(2927)] = 119800,
  [SMALL_STATE(2928)] = 119826,
  [SMALL_STATE(2929)] = 119852,
  [SMALL_STATE(2930)] = 119880,
  [SMALL_STATE(2931)] = 119906,
  [SMALL_STATE(2932)] = 119944,
  [SMALL_STATE(2933)] = 119978,
  [SMALL_STATE(2934)] = 120016,
  [SMALL_STATE(2935)] = 120041,
  [SMALL_STATE(2936)] = 120066,
  [SMALL_STATE(2937)] = 120091,
  [SMALL_STATE(2938)] = 120122,
  [SMALL_STATE(2939)] = 120149,
  [SMALL_STATE(2940)] = 120178,
  [SMALL_STATE(2941)] = 120203,
  [SMALL_STATE(2942)] = 120227,
  [SMALL_STATE(2943)] = 120261,
  [SMALL_STATE(2944)] = 120285,
  [SMALL_STATE(2945)] = 120319,
  [SMALL_STATE(2946)] = 120353,
  [SMALL_STATE(2947)] = 120377,
  [SMALL_STATE(2948)] = 120401,
  [SMALL_STATE(2949)] = 120433,
  [SMALL_STATE(2950)] = 120461,
  [SMALL_STATE(2951)] = 120485,
  [SMALL_STATE(2952)] = 120519,
  [SMALL_STATE(2953)] = 120543,
  [SMALL_STATE(2954)] = 120567,
  [SMALL_STATE(2955)] = 120591,
  [SMALL_STATE(2956)] = 120615,
  [SMALL_STATE(2957)] = 120639,
  [SMALL_STATE(2958)] = 120663,
  [SMALL_STATE(2959)] = 120687,
  [SMALL_STATE(2960)] = 120711,
  [SMALL_STATE(2961)] = 120735,
  [SMALL_STATE(2962)] = 120759,
  [SMALL_STATE(2963)] = 120783,
  [SMALL_STATE(2964)] = 120807,
  [SMALL_STATE(2965)] = 120831,
  [SMALL_STATE(2966)] = 120855,
  [SMALL_STATE(2967)] = 120879,
  [SMALL_STATE(2968)] = 120903,
  [SMALL_STATE(2969)] = 120937,
  [SMALL_STATE(2970)] = 120961,
  [SMALL_STATE(2971)] = 120985,
  [SMALL_STATE(2972)] = 121011,
  [SMALL_STATE(2973)] = 121035,
  [SMALL_STATE(2974)] = 121059,
  [SMALL_STATE(2975)] = 121091,
  [SMALL_STATE(2976)] = 121115,
  [SMALL_STATE(2977)] = 121139,
  [SMALL_STATE(2978)] = 121173,
  [SMALL_STATE(2979)] = 121197,
  [SMALL_STATE(2980)] = 121219,
  [SMALL_STATE(2981)] = 121241,
  [SMALL_STATE(2982)] = 121267,
  [SMALL_STATE(2983)] = 121301,
  [SMALL_STATE(2984)] = 121325,
  [SMALL_STATE(2985)] = 121359,
  [SMALL_STATE(2986)] = 121393,
  [SMALL_STATE(2987)] = 121415,
  [SMALL_STATE(2988)] = 121439,
  [SMALL_STATE(2989)] = 121463,
  [SMALL_STATE(2990)] = 121487,
  [SMALL_STATE(2991)] = 121511,
  [SMALL_STATE(2992)] = 121535,
  [SMALL_STATE(2993)] = 121559,
  [SMALL_STATE(2994)] = 121583,
  [SMALL_STATE(2995)] = 121607,
  [SMALL_STATE(2996)] = 121631,
  [SMALL_STATE(2997)] = 121663,
  [SMALL_STATE(2998)] = 121687,
  [SMALL_STATE(2999)] = 121711,
  [SMALL_STATE(3000)] = 121735,
  [SMALL_STATE(3001)] = 121769,
  [SMALL_STATE(3002)] = 121793,
  [SMALL_STATE(3003)] = 121827,
  [SMALL_STATE(3004)] = 121849,
  [SMALL_STATE(3005)] = 121871,
  [SMALL_STATE(3006)] = 121895,
  [SMALL_STATE(3007)] = 121929,
  [SMALL_STATE(3008)] = 121953,
  [SMALL_STATE(3009)] = 121987,
  [SMALL_STATE(3010)] = 122009,
  [SMALL_STATE(3011)] = 122033,
  [SMALL_STATE(3012)] = 122057,
  [SMALL_STATE(3013)] = 122081,
  [SMALL_STATE(3014)] = 122103,
  [SMALL_STATE(3015)] = 122127,
  [SMALL_STATE(3016)] = 122151,
  [SMALL_STATE(3017)] = 122183,
  [SMALL_STATE(3018)] = 122207,
  [SMALL_STATE(3019)] = 122231,
  [SMALL_STATE(3020)] = 122255,
  [SMALL_STATE(3021)] = 122277,
  [SMALL_STATE(3022)] = 122301,
  [SMALL_STATE(3023)] = 122325,
  [SMALL_STATE(3024)] = 122349,
  [SMALL_STATE(3025)] = 122373,
  [SMALL_STATE(3026)] = 122395,
  [SMALL_STATE(3027)] = 122429,
  [SMALL_STATE(3028)] = 122453,
  [SMALL_STATE(3029)] = 122477,
  [SMALL_STATE(3030)] = 122499,
  [SMALL_STATE(3031)] = 122523,
  [SMALL_STATE(3032)] = 122547,
  [SMALL_STATE(3033)] = 122579,
  [SMALL_STATE(3034)] = 122603,
  [SMALL_STATE(3035)] = 122635,
  [SMALL_STATE(3036)] = 122669,
  [SMALL_STATE(3037)] = 122703,
  [SMALL_STATE(3038)] = 122737,
  [SMALL_STATE(3039)] = 122761,
  [SMALL_STATE(3040)] = 122785,
  [SMALL_STATE(3041)] = 122819,
  [SMALL_STATE(3042)] = 122843,
  [SMALL_STATE(3043)] = 122867,
  [SMALL_STATE(3044)] = 122910,
  [SMALL_STATE(3045)] = 122953,
  [SMALL_STATE(3046)] = 122996,
  [SMALL_STATE(3047)] = 123041,
  [SMALL_STATE(3048)] = 123070,
  [SMALL_STATE(3049)] = 123109,
  [SMALL_STATE(3050)] = 123138,
  [SMALL_STATE(3051)] = 123177,
  [SMALL_STATE(3052)] = 123216,
  [SMALL_STATE(3053)] = 123255,
  [SMALL_STATE(3054)] = 123284,
  [SMALL_STATE(3055)] = 123309,
  [SMALL_STATE(3056)] = 123338,
  [SMALL_STATE(3057)] = 123363,
  [SMALL_STATE(3058)] = 123406,
  [SMALL_STATE(3059)] = 123449,
  [SMALL_STATE(3060)] = 123474,
  [SMALL_STATE(3061)] = 123517,
  [SMALL_STATE(3062)] = 123546,
  [SMALL_STATE(3063)] = 123589,
  [SMALL_STATE(3064)] = 123632,
  [SMALL_STATE(3065)] = 123675,
  [SMALL_STATE(3066)] = 123718,
  [SMALL_STATE(3067)] = 123761,
  [SMALL_STATE(3068)] = 123804,
  [SMALL_STATE(3069)] = 123843,
  [SMALL_STATE(3070)] = 123886,
  [SMALL_STATE(3071)] = 123929,
  [SMALL_STATE(3072)] = 123972,
  [SMALL_STATE(3073)] = 124015,
  [SMALL_STATE(3074)] = 124058,
  [SMALL_STATE(3075)] = 124101,
  [SMALL_STATE(3076)] = 124130,
  [SMALL_STATE(3077)] = 124159,
  [SMALL_STATE(3078)] = 124188,
  [SMALL_STATE(3079)] = 124217,
  [SMALL_STATE(3080)] = 124260,
  [SMALL_STATE(3081)] = 124303,
  [SMALL_STATE(3082)] = 124346,
  [SMALL_STATE(3083)] = 124389,
  [SMALL_STATE(3084)] = 124432,
  [SMALL_STATE(3085)] = 124452,
  [SMALL_STATE(3086)] = 124488,
  [SMALL_STATE(3087)] = 124510,
  [SMALL_STATE(3088)] = 124548,
  [SMALL_STATE(3089)] = 124570,
  [SMALL_STATE(3090)] = 124592,
  [SMALL_STATE(3091)] = 124614,
  [SMALL_STATE(3092)] = 124638,
  [SMALL_STATE(3093)] = 124660,
  [SMALL_STATE(3094)] = 124682,
  [SMALL_STATE(3095)] = 124704,
  [SMALL_STATE(3096)] = 124732,
  [SMALL_STATE(3097)] = 124756,
  [SMALL_STATE(3098)] = 124792,
  [SMALL_STATE(3099)] = 124828,
  [SMALL_STATE(3100)] = 124850,
  [SMALL_STATE(3101)] = 124874,
  [SMALL_STATE(3102)] = 124896,
  [SMALL_STATE(3103)] = 124918,
  [SMALL_STATE(3104)] = 124940,
  [SMALL_STATE(3105)] = 124962,
  [SMALL_STATE(3106)] = 124998,
  [SMALL_STATE(3107)] = 125022,
  [SMALL_STATE(3108)] = 125042,
  [SMALL_STATE(3109)] = 125062,
  [SMALL_STATE(3110)] = 125082,
  [SMALL_STATE(3111)] = 125102,
  [SMALL_STATE(3112)] = 125138,
  [SMALL_STATE(3113)] = 125158,
  [SMALL_STATE(3114)] = 125178,
  [SMALL_STATE(3115)] = 125198,
  [SMALL_STATE(3116)] = 125218,
  [SMALL_STATE(3117)] = 125238,
  [SMALL_STATE(3118)] = 125258,
  [SMALL_STATE(3119)] = 125278,
  [SMALL_STATE(3120)] = 125298,
  [SMALL_STATE(3121)] = 125318,
  [SMALL_STATE(3122)] = 125338,
  [SMALL_STATE(3123)] = 125358,
  [SMALL_STATE(3124)] = 125378,
  [SMALL_STATE(3125)] = 125404,
  [SMALL_STATE(3126)] = 125424,
  [SMALL_STATE(3127)] = 125444,
  [SMALL_STATE(3128)] = 125464,
  [SMALL_STATE(3129)] = 125484,
  [SMALL_STATE(3130)] = 125512,
  [SMALL_STATE(3131)] = 125532,
  [SMALL_STATE(3132)] = 125552,
  [SMALL_STATE(3133)] = 125572,
  [SMALL_STATE(3134)] = 125592,
  [SMALL_STATE(3135)] = 125612,
  [SMALL_STATE(3136)] = 125648,
  [SMALL_STATE(3137)] = 125668,
  [SMALL_STATE(3138)] = 125688,
  [SMALL_STATE(3139)] = 125708,
  [SMALL_STATE(3140)] = 125728,
  [SMALL_STATE(3141)] = 125748,
  [SMALL_STATE(3142)] = 125768,
  [SMALL_STATE(3143)] = 125788,
  [SMALL_STATE(3144)] = 125824,
  [SMALL_STATE(3145)] = 125860,
  [SMALL_STATE(3146)] = 125888,
  [SMALL_STATE(3147)] = 125916,
  [SMALL_STATE(3148)] = 125952,
  [SMALL_STATE(3149)] = 125980,
  [SMALL_STATE(3150)] = 126008,
  [SMALL_STATE(3151)] = 126032,
  [SMALL_STATE(3152)] = 126058,
  [SMALL_STATE(3153)] = 126094,
  [SMALL_STATE(3154)] = 126122,
  [SMALL_STATE(3155)] = 126150,
  [SMALL_STATE(3156)] = 126176,
  [SMALL_STATE(3157)] = 126196,
  [SMALL_STATE(3158)] = 126233,
  [SMALL_STATE(3159)] = 126258,
  [SMALL_STATE(3160)] = 126291,
  [SMALL_STATE(3161)] = 126328,
  [SMALL_STATE(3162)] = 126365,
  [SMALL_STATE(3163)] = 126402,
  [SMALL_STATE(3164)] = 126439,
  [SMALL_STATE(3165)] = 126476,
  [SMALL_STATE(3166)] = 126497,
  [SMALL_STATE(3167)] = 126520,
  [SMALL_STATE(3168)] = 126549,
  [SMALL_STATE(3169)] = 126570,
  [SMALL_STATE(3170)] = 126607,
  [SMALL_STATE(3171)] = 126644,
  [SMALL_STATE(3172)] = 126675,
  [SMALL_STATE(3173)] = 126712,
  [SMALL_STATE(3174)] = 126745,
  [SMALL_STATE(3175)] = 126768,
  [SMALL_STATE(3176)] = 126797,
  [SMALL_STATE(3177)] = 126834,
  [SMALL_STATE(3178)] = 126873,
  [SMALL_STATE(3179)] = 126910,
  [SMALL_STATE(3180)] = 126931,
  [SMALL_STATE(3181)] = 126968,
  [SMALL_STATE(3182)] = 126993,
  [SMALL_STATE(3183)] = 127030,
  [SMALL_STATE(3184)] = 127067,
  [SMALL_STATE(3185)] = 127096,
  [SMALL_STATE(3186)] = 127133,
  [SMALL_STATE(3187)] = 127162,
  [SMALL_STATE(3188)] = 127199,
  [SMALL_STATE(3189)] = 127232,
  [SMALL_STATE(3190)] = 127263,
  [SMALL_STATE(3191)] = 127296,
  [SMALL_STATE(3192)] = 127333,
  [SMALL_STATE(3193)] = 127370,
  [SMALL_STATE(3194)] = 127391,
  [SMALL_STATE(3195)] = 127424,
  [SMALL_STATE(3196)] = 127457,
  [SMALL_STATE(3197)] = 127488,
  [SMALL_STATE(3198)] = 127519,
  [SMALL_STATE(3199)] = 127550,
  [SMALL_STATE(3200)] = 127587,
  [SMALL_STATE(3201)] = 127610,
  [SMALL_STATE(3202)] = 127631,
  [SMALL_STATE(3203)] = 127664,
  [SMALL_STATE(3204)] = 127697,
  [SMALL_STATE(3205)] = 127718,
  [SMALL_STATE(3206)] = 127755,
  [SMALL_STATE(3207)] = 127776,
  [SMALL_STATE(3208)] = 127799,
  [SMALL_STATE(3209)] = 127836,
  [SMALL_STATE(3210)] = 127873,
  [SMALL_STATE(3211)] = 127906,
  [SMALL_STATE(3212)] = 127943,
  [SMALL_STATE(3213)] = 127966,
  [SMALL_STATE(3214)] = 127999,
  [SMALL_STATE(3215)] = 128028,
  [SMALL_STATE(3216)] = 128048,
  [SMALL_STATE(3217)] = 128072,
  [SMALL_STATE(3218)] = 128092,
  [SMALL_STATE(3219)] = 128112,
  [SMALL_STATE(3220)] = 128134,
  [SMALL_STATE(3221)] = 128156,
  [SMALL_STATE(3222)] = 128178,
  [SMALL_STATE(3223)] = 128202,
  [SMALL_STATE(3224)] = 128220,
  [SMALL_STATE(3225)] = 128238,
  [SMALL_STATE(3226)] = 128256,
  [SMALL_STATE(3227)] = 128274,
  [SMALL_STATE(3228)] = 128292,
  [SMALL_STATE(3229)] = 128312,
  [SMALL_STATE(3230)] = 128332,
  [SMALL_STATE(3231)] = 128350,
  [SMALL_STATE(3232)] = 128368,
  [SMALL_STATE(3233)] = 128388,
  [SMALL_STATE(3234)] = 128408,
  [SMALL_STATE(3235)] = 128426,
  [SMALL_STATE(3236)] = 128444,
  [SMALL_STATE(3237)] = 128462,
  [SMALL_STATE(3238)] = 128480,
  [SMALL_STATE(3239)] = 128498,
  [SMALL_STATE(3240)] = 128518,
  [SMALL_STATE(3241)] = 128538,
  [SMALL_STATE(3242)] = 128558,
  [SMALL_STATE(3243)] = 128582,
  [SMALL_STATE(3244)] = 128602,
  [SMALL_STATE(3245)] = 128626,
  [SMALL_STATE(3246)] = 128646,
  [SMALL_STATE(3247)] = 128666,
  [SMALL_STATE(3248)] = 128684,
  [SMALL_STATE(3249)] = 128706,
  [SMALL_STATE(3250)] = 128726,
  [SMALL_STATE(3251)] = 128746,
  [SMALL_STATE(3252)] = 128770,
  [SMALL_STATE(3253)] = 128790,
  [SMALL_STATE(3254)] = 128808,
  [SMALL_STATE(3255)] = 128830,
  [SMALL_STATE(3256)] = 128850,
  [SMALL_STATE(3257)] = 128886,
  [SMALL_STATE(3258)] = 128906,
  [SMALL_STATE(3259)] = 128926,
  [SMALL_STATE(3260)] = 128946,
  [SMALL_STATE(3261)] = 128966,
  [SMALL_STATE(3262)] = 128986,
  [SMALL_STATE(3263)] = 129012,
  [SMALL_STATE(3264)] = 129032,
  [SMALL_STATE(3265)] = 129052,
  [SMALL_STATE(3266)] = 129072,
  [SMALL_STATE(3267)] = 129092,
  [SMALL_STATE(3268)] = 129116,
  [SMALL_STATE(3269)] = 129140,
  [SMALL_STATE(3270)] = 129160,
  [SMALL_STATE(3271)] = 129180,
  [SMALL_STATE(3272)] = 129200,
  [SMALL_STATE(3273)] = 129222,
  [SMALL_STATE(3274)] = 129242,
  [SMALL_STATE(3275)] = 129262,
  [SMALL_STATE(3276)] = 129286,
  [SMALL_STATE(3277)] = 129310,
  [SMALL_STATE(3278)] = 129330,
  [SMALL_STATE(3279)] = 129352,
  [SMALL_STATE(3280)] = 129378,
  [SMALL_STATE(3281)] = 129398,
  [SMALL_STATE(3282)] = 129418,
  [SMALL_STATE(3283)] = 129438,
  [SMALL_STATE(3284)] = 129460,
  [SMALL_STATE(3285)] = 129480,
  [SMALL_STATE(3286)] = 129500,
  [SMALL_STATE(3287)] = 129520,
  [SMALL_STATE(3288)] = 129537,
  [SMALL_STATE(3289)] = 129556,
  [SMALL_STATE(3290)] = 129573,
  [SMALL_STATE(3291)] = 129608,
  [SMALL_STATE(3292)] = 129643,
  [SMALL_STATE(3293)] = 129676,
  [SMALL_STATE(3294)] = 129711,
  [SMALL_STATE(3295)] = 129746,
  [SMALL_STATE(3296)] = 129779,
  [SMALL_STATE(3297)] = 129810,
  [SMALL_STATE(3298)] = 129845,
  [SMALL_STATE(3299)] = 129880,
  [SMALL_STATE(3300)] = 129901,
  [SMALL_STATE(3301)] = 129936,
  [SMALL_STATE(3302)] = 129955,
  [SMALL_STATE(3303)] = 129978,
  [SMALL_STATE(3304)] = 130001,
  [SMALL_STATE(3305)] = 130022,
  [SMALL_STATE(3306)] = 130041,
  [SMALL_STATE(3307)] = 130066,
  [SMALL_STATE(3308)] = 130101,
  [SMALL_STATE(3309)] = 130136,
  [SMALL_STATE(3310)] = 130153,
  [SMALL_STATE(3311)] = 130188,
  [SMALL_STATE(3312)] = 130207,
  [SMALL_STATE(3313)] = 130238,
  [SMALL_STATE(3314)] = 130267,
  [SMALL_STATE(3315)] = 130298,
  [SMALL_STATE(3316)] = 130319,
  [SMALL_STATE(3317)] = 130354,
  [SMALL_STATE(3318)] = 130371,
  [SMALL_STATE(3319)] = 130399,
  [SMALL_STATE(3320)] = 130415,
  [SMALL_STATE(3321)] = 130443,
  [SMALL_STATE(3322)] = 130471,
  [SMALL_STATE(3323)] = 130487,
  [SMALL_STATE(3324)] = 130515,
  [SMALL_STATE(3325)] = 130543,
  [SMALL_STATE(3326)] = 130559,
  [SMALL_STATE(3327)] = 130587,
  [SMALL_STATE(3328)] = 130603,
  [SMALL_STATE(3329)] = 130619,
  [SMALL_STATE(3330)] = 130635,
  [SMALL_STATE(3331)] = 130655,
  [SMALL_STATE(3332)] = 130671,
  [SMALL_STATE(3333)] = 130687,
  [SMALL_STATE(3334)] = 130715,
  [SMALL_STATE(3335)] = 130743,
  [SMALL_STATE(3336)] = 130765,
  [SMALL_STATE(3337)] = 130781,
  [SMALL_STATE(3338)] = 130797,
  [SMALL_STATE(3339)] = 130817,
  [SMALL_STATE(3340)] = 130835,
  [SMALL_STATE(3341)] = 130859,
  [SMALL_STATE(3342)] = 130891,
  [SMALL_STATE(3343)] = 130919,
  [SMALL_STATE(3344)] = 130947,
  [SMALL_STATE(3345)] = 130963,
  [SMALL_STATE(3346)] = 130985,
  [SMALL_STATE(3347)] = 131001,
  [SMALL_STATE(3348)] = 131019,
  [SMALL_STATE(3349)] = 131047,
  [SMALL_STATE(3350)] = 131079,
  [SMALL_STATE(3351)] = 131107,
  [SMALL_STATE(3352)] = 131123,
  [SMALL_STATE(3353)] = 131139,
  [SMALL_STATE(3354)] = 131165,
  [SMALL_STATE(3355)] = 131187,
  [SMALL_STATE(3356)] = 131203,
  [SMALL_STATE(3357)] = 131225,
  [SMALL_STATE(3358)] = 131241,
  [SMALL_STATE(3359)] = 131267,
  [SMALL_STATE(3360)] = 131283,
  [SMALL_STATE(3361)] = 131309,
  [SMALL_STATE(3362)] = 131329,
  [SMALL_STATE(3363)] = 131361,
  [SMALL_STATE(3364)] = 131377,
  [SMALL_STATE(3365)] = 131403,
  [SMALL_STATE(3366)] = 131435,
  [SMALL_STATE(3367)] = 131451,
  [SMALL_STATE(3368)] = 131477,
  [SMALL_STATE(3369)] = 131503,
  [SMALL_STATE(3370)] = 131531,
  [SMALL_STATE(3371)] = 131557,
  [SMALL_STATE(3372)] = 131573,
  [SMALL_STATE(3373)] = 131591,
  [SMALL_STATE(3374)] = 131607,
  [SMALL_STATE(3375)] = 131633,
  [SMALL_STATE(3376)] = 131651,
  [SMALL_STATE(3377)] = 131679,
  [SMALL_STATE(3378)] = 131695,
  [SMALL_STATE(3379)] = 131711,
  [SMALL_STATE(3380)] = 131739,
  [SMALL_STATE(3381)] = 131769,
  [SMALL_STATE(3382)] = 131801,
  [SMALL_STATE(3383)] = 131819,
  [SMALL_STATE(3384)] = 131835,
  [SMALL_STATE(3385)] = 131857,
  [SMALL_STATE(3386)] = 131883,
  [SMALL_STATE(3387)] = 131899,
  [SMALL_STATE(3388)] = 131927,
  [SMALL_STATE(3389)] = 131949,
  [SMALL_STATE(3390)] = 131981,
  [SMALL_STATE(3391)] = 131997,
  [SMALL_STATE(3392)] = 132025,
  [SMALL_STATE(3393)] = 132053,
  [SMALL_STATE(3394)] = 132081,
  [SMALL_STATE(3395)] = 132109,
  [SMALL_STATE(3396)] = 132141,
  [SMALL_STATE(3397)] = 132173,
  [SMALL_STATE(3398)] = 132201,
  [SMALL_STATE(3399)] = 132217,
  [SMALL_STATE(3400)] = 132243,
  [SMALL_STATE(3401)] = 132271,
  [SMALL_STATE(3402)] = 132287,
  [SMALL_STATE(3403)] = 132315,
  [SMALL_STATE(3404)] = 132343,
  [SMALL_STATE(3405)] = 132375,
  [SMALL_STATE(3406)] = 132403,
  [SMALL_STATE(3407)] = 132419,
  [SMALL_STATE(3408)] = 132451,
  [SMALL_STATE(3409)] = 132479,
  [SMALL_STATE(3410)] = 132495,
  [SMALL_STATE(3411)] = 132511,
  [SMALL_STATE(3412)] = 132543,
  [SMALL_STATE(3413)] = 132565,
  [SMALL_STATE(3414)] = 132597,
  [SMALL_STATE(3415)] = 132625,
  [SMALL_STATE(3416)] = 132653,
  [SMALL_STATE(3417)] = 132685,
  [SMALL_STATE(3418)] = 132711,
  [SMALL_STATE(3419)] = 132739,
  [SMALL_STATE(3420)] = 132767,
  [SMALL_STATE(3421)] = 132783,
  [SMALL_STATE(3422)] = 132815,
  [SMALL_STATE(3423)] = 132843,
  [SMALL_STATE(3424)] = 132871,
  [SMALL_STATE(3425)] = 132903,
  [SMALL_STATE(3426)] = 132931,
  [SMALL_STATE(3427)] = 132959,
  [SMALL_STATE(3428)] = 132985,
  [SMALL_STATE(3429)] = 133013,
  [SMALL_STATE(3430)] = 133041,
  [SMALL_STATE(3431)] = 133057,
  [SMALL_STATE(3432)] = 133073,
  [SMALL_STATE(3433)] = 133089,
  [SMALL_STATE(3434)] = 133111,
  [SMALL_STATE(3435)] = 133143,
  [SMALL_STATE(3436)] = 133175,
  [SMALL_STATE(3437)] = 133193,
  [SMALL_STATE(3438)] = 133209,
  [SMALL_STATE(3439)] = 133241,
  [SMALL_STATE(3440)] = 133257,
  [SMALL_STATE(3441)] = 133285,
  [SMALL_STATE(3442)] = 133317,
  [SMALL_STATE(3443)] = 133345,
  [SMALL_STATE(3444)] = 133363,
  [SMALL_STATE(3445)] = 133379,
  [SMALL_STATE(3446)] = 133395,
  [SMALL_STATE(3447)] = 133423,
  [SMALL_STATE(3448)] = 133445,
  [SMALL_STATE(3449)] = 133461,
  [SMALL_STATE(3450)] = 133489,
  [SMALL_STATE(3451)] = 133507,
  [SMALL_STATE(3452)] = 133535,
  [SMALL_STATE(3453)] = 133563,
  [SMALL_STATE(3454)] = 133579,
  [SMALL_STATE(3455)] = 133595,
  [SMALL_STATE(3456)] = 133611,
  [SMALL_STATE(3457)] = 133627,
  [SMALL_STATE(3458)] = 133643,
  [SMALL_STATE(3459)] = 133671,
  [SMALL_STATE(3460)] = 133699,
  [SMALL_STATE(3461)] = 133727,
  [SMALL_STATE(3462)] = 133755,
  [SMALL_STATE(3463)] = 133783,
  [SMALL_STATE(3464)] = 133799,
  [SMALL_STATE(3465)] = 133820,
  [SMALL_STATE(3466)] = 133843,
  [SMALL_STATE(3467)] = 133864,
  [SMALL_STATE(3468)] = 133885,
  [SMALL_STATE(3469)] = 133908,
  [SMALL_STATE(3470)] = 133933,
  [SMALL_STATE(3471)] = 133956,
  [SMALL_STATE(3472)] = 133975,
  [SMALL_STATE(3473)] = 134004,
  [SMALL_STATE(3474)] = 134029,
  [SMALL_STATE(3475)] = 134058,
  [SMALL_STATE(3476)] = 134083,
  [SMALL_STATE(3477)] = 134108,
  [SMALL_STATE(3478)] = 134133,
  [SMALL_STATE(3479)] = 134158,
  [SMALL_STATE(3480)] = 134183,
  [SMALL_STATE(3481)] = 134208,
  [SMALL_STATE(3482)] = 134237,
  [SMALL_STATE(3483)] = 134252,
  [SMALL_STATE(3484)] = 134267,
  [SMALL_STATE(3485)] = 134292,
  [SMALL_STATE(3486)] = 134315,
  [SMALL_STATE(3487)] = 134344,
  [SMALL_STATE(3488)] = 134363,
  [SMALL_STATE(3489)] = 134386,
  [SMALL_STATE(3490)] = 134401,
  [SMALL_STATE(3491)] = 134416,
  [SMALL_STATE(3492)] = 134441,
  [SMALL_STATE(3493)] = 134466,
  [SMALL_STATE(3494)] = 134483,
  [SMALL_STATE(3495)] = 134500,
  [SMALL_STATE(3496)] = 134523,
  [SMALL_STATE(3497)] = 134552,
  [SMALL_STATE(3498)] = 134575,
  [SMALL_STATE(3499)] = 134598,
  [SMALL_STATE(3500)] = 134619,
  [SMALL_STATE(3501)] = 134640,
  [SMALL_STATE(3502)] = 134665,
  [SMALL_STATE(3503)] = 134686,
  [SMALL_STATE(3504)] = 134703,
  [SMALL_STATE(3505)] = 134732,
  [SMALL_STATE(3506)] = 134755,
  [SMALL_STATE(3507)] = 134770,
  [SMALL_STATE(3508)] = 134796,
  [SMALL_STATE(3509)] = 134822,
  [SMALL_STATE(3510)] = 134844,
  [SMALL_STATE(3511)] = 134866,
  [SMALL_STATE(3512)] = 134888,
  [SMALL_STATE(3513)] = 134910,
  [SMALL_STATE(3514)] = 134936,
  [SMALL_STATE(3515)] = 134958,
  [SMALL_STATE(3516)] = 134980,
  [SMALL_STATE(3517)] = 135002,
  [SMALL_STATE(3518)] = 135024,
  [SMALL_STATE(3519)] = 135046,
  [SMALL_STATE(3520)] = 135068,
  [SMALL_STATE(3521)] = 135090,
  [SMALL_STATE(3522)] = 135108,
  [SMALL_STATE(3523)] = 135126,
  [SMALL_STATE(3524)] = 135148,
  [SMALL_STATE(3525)] = 135166,
  [SMALL_STATE(3526)] = 135184,
  [SMALL_STATE(3527)] = 135206,
  [SMALL_STATE(3528)] = 135224,
  [SMALL_STATE(3529)] = 135246,
  [SMALL_STATE(3530)] = 135268,
  [SMALL_STATE(3531)] = 135290,
  [SMALL_STATE(3532)] = 135312,
  [SMALL_STATE(3533)] = 135334,
  [SMALL_STATE(3534)] = 135356,
  [SMALL_STATE(3535)] = 135378,
  [SMALL_STATE(3536)] = 135400,
  [SMALL_STATE(3537)] = 135422,
  [SMALL_STATE(3538)] = 135444,
  [SMALL_STATE(3539)] = 135466,
  [SMALL_STATE(3540)] = 135488,
  [SMALL_STATE(3541)] = 135514,
  [SMALL_STATE(3542)] = 135536,
  [SMALL_STATE(3543)] = 135556,
  [SMALL_STATE(3544)] = 135582,
  [SMALL_STATE(3545)] = 135604,
  [SMALL_STATE(3546)] = 135630,
  [SMALL_STATE(3547)] = 135656,
  [SMALL_STATE(3548)] = 135670,
  [SMALL_STATE(3549)] = 135692,
  [SMALL_STATE(3550)] = 135708,
  [SMALL_STATE(3551)] = 135730,
  [SMALL_STATE(3552)] = 135752,
  [SMALL_STATE(3553)] = 135774,
  [SMALL_STATE(3554)] = 135796,
  [SMALL_STATE(3555)] = 135818,
  [SMALL_STATE(3556)] = 135844,
  [SMALL_STATE(3557)] = 135866,
  [SMALL_STATE(3558)] = 135888,
  [SMALL_STATE(3559)] = 135914,
  [SMALL_STATE(3560)] = 135928,
  [SMALL_STATE(3561)] = 135950,
  [SMALL_STATE(3562)] = 135972,
  [SMALL_STATE(3563)] = 135994,
  [SMALL_STATE(3564)] = 136020,
  [SMALL_STATE(3565)] = 136042,
  [SMALL_STATE(3566)] = 136064,
  [SMALL_STATE(3567)] = 136086,
  [SMALL_STATE(3568)] = 136108,
  [SMALL_STATE(3569)] = 136130,
  [SMALL_STATE(3570)] = 136152,
  [SMALL_STATE(3571)] = 136178,
  [SMALL_STATE(3572)] = 136196,
  [SMALL_STATE(3573)] = 136222,
  [SMALL_STATE(3574)] = 136244,
  [SMALL_STATE(3575)] = 136270,
  [SMALL_STATE(3576)] = 136296,
  [SMALL_STATE(3577)] = 136314,
  [SMALL_STATE(3578)] = 136340,
  [SMALL_STATE(3579)] = 136366,
  [SMALL_STATE(3580)] = 136388,
  [SMALL_STATE(3581)] = 136410,
  [SMALL_STATE(3582)] = 136436,
  [SMALL_STATE(3583)] = 136458,
  [SMALL_STATE(3584)] = 136480,
  [SMALL_STATE(3585)] = 136502,
  [SMALL_STATE(3586)] = 136524,
  [SMALL_STATE(3587)] = 136546,
  [SMALL_STATE(3588)] = 136560,
  [SMALL_STATE(3589)] = 136582,
  [SMALL_STATE(3590)] = 136600,
  [SMALL_STATE(3591)] = 136626,
  [SMALL_STATE(3592)] = 136648,
  [SMALL_STATE(3593)] = 136662,
  [SMALL_STATE(3594)] = 136688,
  [SMALL_STATE(3595)] = 136714,
  [SMALL_STATE(3596)] = 136736,
  [SMALL_STATE(3597)] = 136758,
  [SMALL_STATE(3598)] = 136776,
  [SMALL_STATE(3599)] = 136794,
  [SMALL_STATE(3600)] = 136820,
  [SMALL_STATE(3601)] = 136846,
  [SMALL_STATE(3602)] = 136864,
  [SMALL_STATE(3603)] = 136886,
  [SMALL_STATE(3604)] = 136908,
  [SMALL_STATE(3605)] = 136926,
  [SMALL_STATE(3606)] = 136952,
  [SMALL_STATE(3607)] = 136970,
  [SMALL_STATE(3608)] = 136984,
  [SMALL_STATE(3609)] = 137002,
  [SMALL_STATE(3610)] = 137028,
  [SMALL_STATE(3611)] = 137054,
  [SMALL_STATE(3612)] = 137076,
  [SMALL_STATE(3613)] = 137098,
  [SMALL_STATE(3614)] = 137120,
  [SMALL_STATE(3615)] = 137134,
  [SMALL_STATE(3616)] = 137152,
  [SMALL_STATE(3617)] = 137178,
  [SMALL_STATE(3618)] = 137200,
  [SMALL_STATE(3619)] = 137220,
  [SMALL_STATE(3620)] = 137246,
  [SMALL_STATE(3621)] = 137272,
  [SMALL_STATE(3622)] = 137298,
  [SMALL_STATE(3623)] = 137320,
  [SMALL_STATE(3624)] = 137342,
  [SMALL_STATE(3625)] = 137366,
  [SMALL_STATE(3626)] = 137384,
  [SMALL_STATE(3627)] = 137402,
  [SMALL_STATE(3628)] = 137420,
  [SMALL_STATE(3629)] = 137442,
  [SMALL_STATE(3630)] = 137464,
  [SMALL_STATE(3631)] = 137486,
  [SMALL_STATE(3632)] = 137504,
  [SMALL_STATE(3633)] = 137522,
  [SMALL_STATE(3634)] = 137540,
  [SMALL_STATE(3635)] = 137566,
  [SMALL_STATE(3636)] = 137588,
  [SMALL_STATE(3637)] = 137614,
  [SMALL_STATE(3638)] = 137632,
  [SMALL_STATE(3639)] = 137658,
  [SMALL_STATE(3640)] = 137684,
  [SMALL_STATE(3641)] = 137702,
  [SMALL_STATE(3642)] = 137724,
  [SMALL_STATE(3643)] = 137750,
  [SMALL_STATE(3644)] = 137776,
  [SMALL_STATE(3645)] = 137790,
  [SMALL_STATE(3646)] = 137816,
  [SMALL_STATE(3647)] = 137838,
  [SMALL_STATE(3648)] = 137862,
  [SMALL_STATE(3649)] = 137888,
  [SMALL_STATE(3650)] = 137906,
  [SMALL_STATE(3651)] = 137932,
  [SMALL_STATE(3652)] = 137954,
  [SMALL_STATE(3653)] = 137980,
  [SMALL_STATE(3654)] = 138002,
  [SMALL_STATE(3655)] = 138018,
  [SMALL_STATE(3656)] = 138040,
  [SMALL_STATE(3657)] = 138062,
  [SMALL_STATE(3658)] = 138084,
  [SMALL_STATE(3659)] = 138106,
  [SMALL_STATE(3660)] = 138124,
  [SMALL_STATE(3661)] = 138140,
  [SMALL_STATE(3662)] = 138160,
  [SMALL_STATE(3663)] = 138176,
  [SMALL_STATE(3664)] = 138202,
  [SMALL_STATE(3665)] = 138224,
  [SMALL_STATE(3666)] = 138246,
  [SMALL_STATE(3667)] = 138272,
  [SMALL_STATE(3668)] = 138286,
  [SMALL_STATE(3669)] = 138300,
  [SMALL_STATE(3670)] = 138322,
  [SMALL_STATE(3671)] = 138348,
  [SMALL_STATE(3672)] = 138370,
  [SMALL_STATE(3673)] = 138392,
  [SMALL_STATE(3674)] = 138414,
  [SMALL_STATE(3675)] = 138436,
  [SMALL_STATE(3676)] = 138462,
  [SMALL_STATE(3677)] = 138488,
  [SMALL_STATE(3678)] = 138514,
  [SMALL_STATE(3679)] = 138536,
  [SMALL_STATE(3680)] = 138558,
  [SMALL_STATE(3681)] = 138580,
  [SMALL_STATE(3682)] = 138602,
  [SMALL_STATE(3683)] = 138624,
  [SMALL_STATE(3684)] = 138646,
  [SMALL_STATE(3685)] = 138660,
  [SMALL_STATE(3686)] = 138686,
  [SMALL_STATE(3687)] = 138708,
  [SMALL_STATE(3688)] = 138722,
  [SMALL_STATE(3689)] = 138748,
  [SMALL_STATE(3690)] = 138774,
  [SMALL_STATE(3691)] = 138796,
  [SMALL_STATE(3692)] = 138818,
  [SMALL_STATE(3693)] = 138840,
  [SMALL_STATE(3694)] = 138866,
  [SMALL_STATE(3695)] = 138880,
  [SMALL_STATE(3696)] = 138906,
  [SMALL_STATE(3697)] = 138922,
  [SMALL_STATE(3698)] = 138938,
  [SMALL_STATE(3699)] = 138956,
  [SMALL_STATE(3700)] = 138978,
  [SMALL_STATE(3701)] = 139000,
  [SMALL_STATE(3702)] = 139022,
  [SMALL_STATE(3703)] = 139036,
  [SMALL_STATE(3704)] = 139058,
  [SMALL_STATE(3705)] = 139080,
  [SMALL_STATE(3706)] = 139102,
  [SMALL_STATE(3707)] = 139124,
  [SMALL_STATE(3708)] = 139138,
  [SMALL_STATE(3709)] = 139160,
  [SMALL_STATE(3710)] = 139186,
  [SMALL_STATE(3711)] = 139208,
  [SMALL_STATE(3712)] = 139228,
  [SMALL_STATE(3713)] = 139250,
  [SMALL_STATE(3714)] = 139266,
  [SMALL_STATE(3715)] = 139284,
  [SMALL_STATE(3716)] = 139306,
  [SMALL_STATE(3717)] = 139332,
  [SMALL_STATE(3718)] = 139358,
  [SMALL_STATE(3719)] = 139380,
  [SMALL_STATE(3720)] = 139406,
  [SMALL_STATE(3721)] = 139432,
  [SMALL_STATE(3722)] = 139454,
  [SMALL_STATE(3723)] = 139470,
  [SMALL_STATE(3724)] = 139496,
  [SMALL_STATE(3725)] = 139518,
  [SMALL_STATE(3726)] = 139540,
  [SMALL_STATE(3727)] = 139562,
  [SMALL_STATE(3728)] = 139584,
  [SMALL_STATE(3729)] = 139606,
  [SMALL_STATE(3730)] = 139628,
  [SMALL_STATE(3731)] = 139648,
  [SMALL_STATE(3732)] = 139668,
  [SMALL_STATE(3733)] = 139688,
  [SMALL_STATE(3734)] = 139708,
  [SMALL_STATE(3735)] = 139730,
  [SMALL_STATE(3736)] = 139752,
  [SMALL_STATE(3737)] = 139774,
  [SMALL_STATE(3738)] = 139796,
  [SMALL_STATE(3739)] = 139818,
  [SMALL_STATE(3740)] = 139844,
  [SMALL_STATE(3741)] = 139858,
  [SMALL_STATE(3742)] = 139880,
  [SMALL_STATE(3743)] = 139898,
  [SMALL_STATE(3744)] = 139912,
  [SMALL_STATE(3745)] = 139938,
  [SMALL_STATE(3746)] = 139960,
  [SMALL_STATE(3747)] = 139982,
  [SMALL_STATE(3748)] = 140004,
  [SMALL_STATE(3749)] = 140026,
  [SMALL_STATE(3750)] = 140044,
  [SMALL_STATE(3751)] = 140061,
  [SMALL_STATE(3752)] = 140078,
  [SMALL_STATE(3753)] = 140101,
  [SMALL_STATE(3754)] = 140124,
  [SMALL_STATE(3755)] = 140141,
  [SMALL_STATE(3756)] = 140164,
  [SMALL_STATE(3757)] = 140181,
  [SMALL_STATE(3758)] = 140198,
  [SMALL_STATE(3759)] = 140217,
  [SMALL_STATE(3760)] = 140234,
  [SMALL_STATE(3761)] = 140247,
  [SMALL_STATE(3762)] = 140270,
  [SMALL_STATE(3763)] = 140283,
  [SMALL_STATE(3764)] = 140302,
  [SMALL_STATE(3765)] = 140321,
  [SMALL_STATE(3766)] = 140338,
  [SMALL_STATE(3767)] = 140357,
  [SMALL_STATE(3768)] = 140372,
  [SMALL_STATE(3769)] = 140395,
  [SMALL_STATE(3770)] = 140414,
  [SMALL_STATE(3771)] = 140431,
  [SMALL_STATE(3772)] = 140446,
  [SMALL_STATE(3773)] = 140459,
  [SMALL_STATE(3774)] = 140480,
  [SMALL_STATE(3775)] = 140503,
  [SMALL_STATE(3776)] = 140526,
  [SMALL_STATE(3777)] = 140539,
  [SMALL_STATE(3778)] = 140556,
  [SMALL_STATE(3779)] = 140577,
  [SMALL_STATE(3780)] = 140590,
  [SMALL_STATE(3781)] = 140613,
  [SMALL_STATE(3782)] = 140636,
  [SMALL_STATE(3783)] = 140659,
  [SMALL_STATE(3784)] = 140676,
  [SMALL_STATE(3785)] = 140699,
  [SMALL_STATE(3786)] = 140718,
  [SMALL_STATE(3787)] = 140735,
  [SMALL_STATE(3788)] = 140758,
  [SMALL_STATE(3789)] = 140781,
  [SMALL_STATE(3790)] = 140794,
  [SMALL_STATE(3791)] = 140811,
  [SMALL_STATE(3792)] = 140830,
  [SMALL_STATE(3793)] = 140847,
  [SMALL_STATE(3794)] = 140864,
  [SMALL_STATE(3795)] = 140881,
  [SMALL_STATE(3796)] = 140896,
  [SMALL_STATE(3797)] = 140913,
  [SMALL_STATE(3798)] = 140930,
  [SMALL_STATE(3799)] = 140953,
  [SMALL_STATE(3800)] = 140970,
  [SMALL_STATE(3801)] = 140987,
  [SMALL_STATE(3802)] = 141004,
  [SMALL_STATE(3803)] = 141027,
  [SMALL_STATE(3804)] = 141044,
  [SMALL_STATE(3805)] = 141067,
  [SMALL_STATE(3806)] = 141080,
  [SMALL_STATE(3807)] = 141097,
  [SMALL_STATE(3808)] = 141114,
  [SMALL_STATE(3809)] = 141131,
  [SMALL_STATE(3810)] = 141148,
  [SMALL_STATE(3811)] = 141165,
  [SMALL_STATE(3812)] = 141178,
  [SMALL_STATE(3813)] = 141201,
  [SMALL_STATE(3814)] = 141218,
  [SMALL_STATE(3815)] = 141235,
  [SMALL_STATE(3816)] = 141252,
  [SMALL_STATE(3817)] = 141275,
  [SMALL_STATE(3818)] = 141294,
  [SMALL_STATE(3819)] = 141317,
  [SMALL_STATE(3820)] = 141334,
  [SMALL_STATE(3821)] = 141351,
  [SMALL_STATE(3822)] = 141374,
  [SMALL_STATE(3823)] = 141397,
  [SMALL_STATE(3824)] = 141420,
  [SMALL_STATE(3825)] = 141439,
  [SMALL_STATE(3826)] = 141452,
  [SMALL_STATE(3827)] = 141475,
  [SMALL_STATE(3828)] = 141494,
  [SMALL_STATE(3829)] = 141517,
  [SMALL_STATE(3830)] = 141536,
  [SMALL_STATE(3831)] = 141559,
  [SMALL_STATE(3832)] = 141582,
  [SMALL_STATE(3833)] = 141601,
  [SMALL_STATE(3834)] = 141624,
  [SMALL_STATE(3835)] = 141641,
  [SMALL_STATE(3836)] = 141660,
  [SMALL_STATE(3837)] = 141683,
  [SMALL_STATE(3838)] = 141706,
  [SMALL_STATE(3839)] = 141725,
  [SMALL_STATE(3840)] = 141742,
  [SMALL_STATE(3841)] = 141765,
  [SMALL_STATE(3842)] = 141788,
  [SMALL_STATE(3843)] = 141811,
  [SMALL_STATE(3844)] = 141834,
  [SMALL_STATE(3845)] = 141851,
  [SMALL_STATE(3846)] = 141874,
  [SMALL_STATE(3847)] = 141897,
  [SMALL_STATE(3848)] = 141914,
  [SMALL_STATE(3849)] = 141931,
  [SMALL_STATE(3850)] = 141950,
  [SMALL_STATE(3851)] = 141965,
  [SMALL_STATE(3852)] = 141988,
  [SMALL_STATE(3853)] = 142007,
  [SMALL_STATE(3854)] = 142030,
  [SMALL_STATE(3855)] = 142053,
  [SMALL_STATE(3856)] = 142070,
  [SMALL_STATE(3857)] = 142093,
  [SMALL_STATE(3858)] = 142112,
  [SMALL_STATE(3859)] = 142135,
  [SMALL_STATE(3860)] = 142158,
  [SMALL_STATE(3861)] = 142181,
  [SMALL_STATE(3862)] = 142200,
  [SMALL_STATE(3863)] = 142213,
  [SMALL_STATE(3864)] = 142236,
  [SMALL_STATE(3865)] = 142253,
  [SMALL_STATE(3866)] = 142276,
  [SMALL_STATE(3867)] = 142299,
  [SMALL_STATE(3868)] = 142322,
  [SMALL_STATE(3869)] = 142339,
  [SMALL_STATE(3870)] = 142360,
  [SMALL_STATE(3871)] = 142377,
  [SMALL_STATE(3872)] = 142400,
  [SMALL_STATE(3873)] = 142423,
  [SMALL_STATE(3874)] = 142446,
  [SMALL_STATE(3875)] = 142469,
  [SMALL_STATE(3876)] = 142486,
  [SMALL_STATE(3877)] = 142499,
  [SMALL_STATE(3878)] = 142518,
  [SMALL_STATE(3879)] = 142541,
  [SMALL_STATE(3880)] = 142558,
  [SMALL_STATE(3881)] = 142581,
  [SMALL_STATE(3882)] = 142594,
  [SMALL_STATE(3883)] = 142617,
  [SMALL_STATE(3884)] = 142640,
  [SMALL_STATE(3885)] = 142657,
  [SMALL_STATE(3886)] = 142674,
  [SMALL_STATE(3887)] = 142687,
  [SMALL_STATE(3888)] = 142704,
  [SMALL_STATE(3889)] = 142727,
  [SMALL_STATE(3890)] = 142744,
  [SMALL_STATE(3891)] = 142767,
  [SMALL_STATE(3892)] = 142784,
  [SMALL_STATE(3893)] = 142797,
  [SMALL_STATE(3894)] = 142814,
  [SMALL_STATE(3895)] = 142837,
  [SMALL_STATE(3896)] = 142854,
  [SMALL_STATE(3897)] = 142871,
  [SMALL_STATE(3898)] = 142894,
  [SMALL_STATE(3899)] = 142917,
  [SMALL_STATE(3900)] = 142936,
  [SMALL_STATE(3901)] = 142953,
  [SMALL_STATE(3902)] = 142971,
  [SMALL_STATE(3903)] = 142987,
  [SMALL_STATE(3904)] = 143005,
  [SMALL_STATE(3905)] = 143021,
  [SMALL_STATE(3906)] = 143037,
  [SMALL_STATE(3907)] = 143057,
  [SMALL_STATE(3908)] = 143073,
  [SMALL_STATE(3909)] = 143089,
  [SMALL_STATE(3910)] = 143105,
  [SMALL_STATE(3911)] = 143117,
  [SMALL_STATE(3912)] = 143133,
  [SMALL_STATE(3913)] = 143149,
  [SMALL_STATE(3914)] = 143165,
  [SMALL_STATE(3915)] = 143177,
  [SMALL_STATE(3916)] = 143193,
  [SMALL_STATE(3917)] = 143209,
  [SMALL_STATE(3918)] = 143221,
  [SMALL_STATE(3919)] = 143233,
  [SMALL_STATE(3920)] = 143245,
  [SMALL_STATE(3921)] = 143257,
  [SMALL_STATE(3922)] = 143269,
  [SMALL_STATE(3923)] = 143281,
  [SMALL_STATE(3924)] = 143299,
  [SMALL_STATE(3925)] = 143311,
  [SMALL_STATE(3926)] = 143323,
  [SMALL_STATE(3927)] = 143335,
  [SMALL_STATE(3928)] = 143347,
  [SMALL_STATE(3929)] = 143359,
  [SMALL_STATE(3930)] = 143371,
  [SMALL_STATE(3931)] = 143383,
  [SMALL_STATE(3932)] = 143395,
  [SMALL_STATE(3933)] = 143407,
  [SMALL_STATE(3934)] = 143419,
  [SMALL_STATE(3935)] = 143431,
  [SMALL_STATE(3936)] = 143443,
  [SMALL_STATE(3937)] = 143459,
  [SMALL_STATE(3938)] = 143475,
  [SMALL_STATE(3939)] = 143491,
  [SMALL_STATE(3940)] = 143511,
  [SMALL_STATE(3941)] = 143527,
  [SMALL_STATE(3942)] = 143539,
  [SMALL_STATE(3943)] = 143555,
  [SMALL_STATE(3944)] = 143567,
  [SMALL_STATE(3945)] = 143587,
  [SMALL_STATE(3946)] = 143599,
  [SMALL_STATE(3947)] = 143611,
  [SMALL_STATE(3948)] = 143627,
  [SMALL_STATE(3949)] = 143643,
  [SMALL_STATE(3950)] = 143659,
  [SMALL_STATE(3951)] = 143675,
  [SMALL_STATE(3952)] = 143695,
  [SMALL_STATE(3953)] = 143711,
  [SMALL_STATE(3954)] = 143723,
  [SMALL_STATE(3955)] = 143735,
  [SMALL_STATE(3956)] = 143747,
  [SMALL_STATE(3957)] = 143763,
  [SMALL_STATE(3958)] = 143779,
  [SMALL_STATE(3959)] = 143795,
  [SMALL_STATE(3960)] = 143811,
  [SMALL_STATE(3961)] = 143827,
  [SMALL_STATE(3962)] = 143847,
  [SMALL_STATE(3963)] = 143865,
  [SMALL_STATE(3964)] = 143881,
  [SMALL_STATE(3965)] = 143901,
  [SMALL_STATE(3966)] = 143917,
  [SMALL_STATE(3967)] = 143933,
  [SMALL_STATE(3968)] = 143949,
  [SMALL_STATE(3969)] = 143965,
  [SMALL_STATE(3970)] = 143981,
  [SMALL_STATE(3971)] = 143997,
  [SMALL_STATE(3972)] = 144013,
  [SMALL_STATE(3973)] = 144029,
  [SMALL_STATE(3974)] = 144045,
  [SMALL_STATE(3975)] = 144061,
  [SMALL_STATE(3976)] = 144077,
  [SMALL_STATE(3977)] = 144097,
  [SMALL_STATE(3978)] = 144113,
  [SMALL_STATE(3979)] = 144129,
  [SMALL_STATE(3980)] = 144141,
  [SMALL_STATE(3981)] = 144161,
  [SMALL_STATE(3982)] = 144175,
  [SMALL_STATE(3983)] = 144187,
  [SMALL_STATE(3984)] = 144205,
  [SMALL_STATE(3985)] = 144217,
  [SMALL_STATE(3986)] = 144229,
  [SMALL_STATE(3987)] = 144249,
  [SMALL_STATE(3988)] = 144269,
  [SMALL_STATE(3989)] = 144285,
  [SMALL_STATE(3990)] = 144301,
  [SMALL_STATE(3991)] = 144317,
  [SMALL_STATE(3992)] = 144333,
  [SMALL_STATE(3993)] = 144345,
  [SMALL_STATE(3994)] = 144361,
  [SMALL_STATE(3995)] = 144373,
  [SMALL_STATE(3996)] = 144385,
  [SMALL_STATE(3997)] = 144397,
  [SMALL_STATE(3998)] = 144411,
  [SMALL_STATE(3999)] = 144425,
  [SMALL_STATE(4000)] = 144437,
  [SMALL_STATE(4001)] = 144449,
  [SMALL_STATE(4002)] = 144469,
  [SMALL_STATE(4003)] = 144481,
  [SMALL_STATE(4004)] = 144497,
  [SMALL_STATE(4005)] = 144509,
  [SMALL_STATE(4006)] = 144527,
  [SMALL_STATE(4007)] = 144543,
  [SMALL_STATE(4008)] = 144557,
  [SMALL_STATE(4009)] = 144573,
  [SMALL_STATE(4010)] = 144593,
  [SMALL_STATE(4011)] = 144613,
  [SMALL_STATE(4012)] = 144625,
  [SMALL_STATE(4013)] = 144645,
  [SMALL_STATE(4014)] = 144665,
  [SMALL_STATE(4015)] = 144681,
  [SMALL_STATE(4016)] = 144697,
  [SMALL_STATE(4017)] = 144709,
  [SMALL_STATE(4018)] = 144721,
  [SMALL_STATE(4019)] = 144733,
  [SMALL_STATE(4020)] = 144749,
  [SMALL_STATE(4021)] = 144761,
  [SMALL_STATE(4022)] = 144777,
  [SMALL_STATE(4023)] = 144793,
  [SMALL_STATE(4024)] = 144805,
  [SMALL_STATE(4025)] = 144825,
  [SMALL_STATE(4026)] = 144837,
  [SMALL_STATE(4027)] = 144849,
  [SMALL_STATE(4028)] = 144861,
  [SMALL_STATE(4029)] = 144877,
  [SMALL_STATE(4030)] = 144889,
  [SMALL_STATE(4031)] = 144901,
  [SMALL_STATE(4032)] = 144921,
  [SMALL_STATE(4033)] = 144933,
  [SMALL_STATE(4034)] = 144945,
  [SMALL_STATE(4035)] = 144957,
  [SMALL_STATE(4036)] = 144969,
  [SMALL_STATE(4037)] = 144981,
  [SMALL_STATE(4038)] = 144993,
  [SMALL_STATE(4039)] = 145013,
  [SMALL_STATE(4040)] = 145033,
  [SMALL_STATE(4041)] = 145045,
  [SMALL_STATE(4042)] = 145057,
  [SMALL_STATE(4043)] = 145077,
  [SMALL_STATE(4044)] = 145089,
  [SMALL_STATE(4045)] = 145101,
  [SMALL_STATE(4046)] = 145113,
  [SMALL_STATE(4047)] = 145131,
  [SMALL_STATE(4048)] = 145143,
  [SMALL_STATE(4049)] = 145155,
  [SMALL_STATE(4050)] = 145171,
  [SMALL_STATE(4051)] = 145183,
  [SMALL_STATE(4052)] = 145195,
  [SMALL_STATE(4053)] = 145207,
  [SMALL_STATE(4054)] = 145227,
  [SMALL_STATE(4055)] = 145243,
  [SMALL_STATE(4056)] = 145255,
  [SMALL_STATE(4057)] = 145271,
  [SMALL_STATE(4058)] = 145289,
  [SMALL_STATE(4059)] = 145301,
  [SMALL_STATE(4060)] = 145317,
  [SMALL_STATE(4061)] = 145333,
  [SMALL_STATE(4062)] = 145345,
  [SMALL_STATE(4063)] = 145365,
  [SMALL_STATE(4064)] = 145377,
  [SMALL_STATE(4065)] = 145393,
  [SMALL_STATE(4066)] = 145409,
  [SMALL_STATE(4067)] = 145425,
  [SMALL_STATE(4068)] = 145437,
  [SMALL_STATE(4069)] = 145449,
  [SMALL_STATE(4070)] = 145461,
  [SMALL_STATE(4071)] = 145473,
  [SMALL_STATE(4072)] = 145485,
  [SMALL_STATE(4073)] = 145497,
  [SMALL_STATE(4074)] = 145509,
  [SMALL_STATE(4075)] = 145521,
  [SMALL_STATE(4076)] = 145537,
  [SMALL_STATE(4077)] = 145549,
  [SMALL_STATE(4078)] = 145565,
  [SMALL_STATE(4079)] = 145577,
  [SMALL_STATE(4080)] = 145593,
  [SMALL_STATE(4081)] = 145609,
  [SMALL_STATE(4082)] = 145625,
  [SMALL_STATE(4083)] = 145641,
  [SMALL_STATE(4084)] = 145653,
  [SMALL_STATE(4085)] = 145665,
  [SMALL_STATE(4086)] = 145683,
  [SMALL_STATE(4087)] = 145699,
  [SMALL_STATE(4088)] = 145715,
  [SMALL_STATE(4089)] = 145727,
  [SMALL_STATE(4090)] = 145739,
  [SMALL_STATE(4091)] = 145751,
  [SMALL_STATE(4092)] = 145763,
  [SMALL_STATE(4093)] = 145781,
  [SMALL_STATE(4094)] = 145797,
  [SMALL_STATE(4095)] = 145817,
  [SMALL_STATE(4096)] = 145833,
  [SMALL_STATE(4097)] = 145849,
  [SMALL_STATE(4098)] = 145865,
  [SMALL_STATE(4099)] = 145881,
  [SMALL_STATE(4100)] = 145897,
  [SMALL_STATE(4101)] = 145913,
  [SMALL_STATE(4102)] = 145929,
  [SMALL_STATE(4103)] = 145945,
  [SMALL_STATE(4104)] = 145961,
  [SMALL_STATE(4105)] = 145979,
  [SMALL_STATE(4106)] = 145995,
  [SMALL_STATE(4107)] = 146011,
  [SMALL_STATE(4108)] = 146029,
  [SMALL_STATE(4109)] = 146047,
  [SMALL_STATE(4110)] = 146063,
  [SMALL_STATE(4111)] = 146079,
  [SMALL_STATE(4112)] = 146095,
  [SMALL_STATE(4113)] = 146113,
  [SMALL_STATE(4114)] = 146129,
  [SMALL_STATE(4115)] = 146145,
  [SMALL_STATE(4116)] = 146161,
  [SMALL_STATE(4117)] = 146177,
  [SMALL_STATE(4118)] = 146193,
  [SMALL_STATE(4119)] = 146209,
  [SMALL_STATE(4120)] = 146225,
  [SMALL_STATE(4121)] = 146241,
  [SMALL_STATE(4122)] = 146257,
  [SMALL_STATE(4123)] = 146273,
  [SMALL_STATE(4124)] = 146289,
  [SMALL_STATE(4125)] = 146305,
  [SMALL_STATE(4126)] = 146321,
  [SMALL_STATE(4127)] = 146337,
  [SMALL_STATE(4128)] = 146353,
  [SMALL_STATE(4129)] = 146369,
  [SMALL_STATE(4130)] = 146387,
  [SMALL_STATE(4131)] = 146403,
  [SMALL_STATE(4132)] = 146419,
  [SMALL_STATE(4133)] = 146437,
  [SMALL_STATE(4134)] = 146453,
  [SMALL_STATE(4135)] = 146469,
  [SMALL_STATE(4136)] = 146485,
  [SMALL_STATE(4137)] = 146503,
  [SMALL_STATE(4138)] = 146521,
  [SMALL_STATE(4139)] = 146537,
  [SMALL_STATE(4140)] = 146553,
  [SMALL_STATE(4141)] = 146569,
  [SMALL_STATE(4142)] = 146585,
  [SMALL_STATE(4143)] = 146601,
  [SMALL_STATE(4144)] = 146619,
  [SMALL_STATE(4145)] = 146635,
  [SMALL_STATE(4146)] = 146651,
  [SMALL_STATE(4147)] = 146667,
  [SMALL_STATE(4148)] = 146687,
  [SMALL_STATE(4149)] = 146699,
  [SMALL_STATE(4150)] = 146715,
  [SMALL_STATE(4151)] = 146735,
  [SMALL_STATE(4152)] = 146755,
  [SMALL_STATE(4153)] = 146771,
  [SMALL_STATE(4154)] = 146791,
  [SMALL_STATE(4155)] = 146811,
  [SMALL_STATE(4156)] = 146827,
  [SMALL_STATE(4157)] = 146843,
  [SMALL_STATE(4158)] = 146863,
  [SMALL_STATE(4159)] = 146879,
  [SMALL_STATE(4160)] = 146895,
  [SMALL_STATE(4161)] = 146915,
  [SMALL_STATE(4162)] = 146935,
  [SMALL_STATE(4163)] = 146951,
  [SMALL_STATE(4164)] = 146969,
  [SMALL_STATE(4165)] = 146981,
  [SMALL_STATE(4166)] = 146997,
  [SMALL_STATE(4167)] = 147013,
  [SMALL_STATE(4168)] = 147029,
  [SMALL_STATE(4169)] = 147045,
  [SMALL_STATE(4170)] = 147061,
  [SMALL_STATE(4171)] = 147077,
  [SMALL_STATE(4172)] = 147097,
  [SMALL_STATE(4173)] = 147117,
  [SMALL_STATE(4174)] = 147137,
  [SMALL_STATE(4175)] = 147157,
  [SMALL_STATE(4176)] = 147177,
  [SMALL_STATE(4177)] = 147197,
  [SMALL_STATE(4178)] = 147209,
  [SMALL_STATE(4179)] = 147229,
  [SMALL_STATE(4180)] = 147241,
  [SMALL_STATE(4181)] = 147259,
  [SMALL_STATE(4182)] = 147271,
  [SMALL_STATE(4183)] = 147283,
  [SMALL_STATE(4184)] = 147299,
  [SMALL_STATE(4185)] = 147319,
  [SMALL_STATE(4186)] = 147339,
  [SMALL_STATE(4187)] = 147351,
  [SMALL_STATE(4188)] = 147363,
  [SMALL_STATE(4189)] = 147379,
  [SMALL_STATE(4190)] = 147399,
  [SMALL_STATE(4191)] = 147419,
  [SMALL_STATE(4192)] = 147439,
  [SMALL_STATE(4193)] = 147455,
  [SMALL_STATE(4194)] = 147475,
  [SMALL_STATE(4195)] = 147491,
  [SMALL_STATE(4196)] = 147507,
  [SMALL_STATE(4197)] = 147527,
  [SMALL_STATE(4198)] = 147547,
  [SMALL_STATE(4199)] = 147563,
  [SMALL_STATE(4200)] = 147579,
  [SMALL_STATE(4201)] = 147599,
  [SMALL_STATE(4202)] = 147619,
  [SMALL_STATE(4203)] = 147637,
  [SMALL_STATE(4204)] = 147657,
  [SMALL_STATE(4205)] = 147673,
  [SMALL_STATE(4206)] = 147689,
  [SMALL_STATE(4207)] = 147705,
  [SMALL_STATE(4208)] = 147725,
  [SMALL_STATE(4209)] = 147745,
  [SMALL_STATE(4210)] = 147761,
  [SMALL_STATE(4211)] = 147775,
  [SMALL_STATE(4212)] = 147791,
  [SMALL_STATE(4213)] = 147807,
  [SMALL_STATE(4214)] = 147823,
  [SMALL_STATE(4215)] = 147839,
  [SMALL_STATE(4216)] = 147855,
  [SMALL_STATE(4217)] = 147871,
  [SMALL_STATE(4218)] = 147891,
  [SMALL_STATE(4219)] = 147909,
  [SMALL_STATE(4220)] = 147925,
  [SMALL_STATE(4221)] = 147937,
  [SMALL_STATE(4222)] = 147953,
  [SMALL_STATE(4223)] = 147973,
  [SMALL_STATE(4224)] = 147985,
  [SMALL_STATE(4225)] = 148005,
  [SMALL_STATE(4226)] = 148025,
  [SMALL_STATE(4227)] = 148037,
  [SMALL_STATE(4228)] = 148049,
  [SMALL_STATE(4229)] = 148069,
  [SMALL_STATE(4230)] = 148089,
  [SMALL_STATE(4231)] = 148105,
  [SMALL_STATE(4232)] = 148121,
  [SMALL_STATE(4233)] = 148137,
  [SMALL_STATE(4234)] = 148153,
  [SMALL_STATE(4235)] = 148169,
  [SMALL_STATE(4236)] = 148185,
  [SMALL_STATE(4237)] = 148201,
  [SMALL_STATE(4238)] = 148217,
  [SMALL_STATE(4239)] = 148233,
  [SMALL_STATE(4240)] = 148249,
  [SMALL_STATE(4241)] = 148265,
  [SMALL_STATE(4242)] = 148281,
  [SMALL_STATE(4243)] = 148297,
  [SMALL_STATE(4244)] = 148313,
  [SMALL_STATE(4245)] = 148329,
  [SMALL_STATE(4246)] = 148345,
  [SMALL_STATE(4247)] = 148361,
  [SMALL_STATE(4248)] = 148379,
  [SMALL_STATE(4249)] = 148399,
  [SMALL_STATE(4250)] = 148419,
  [SMALL_STATE(4251)] = 148439,
  [SMALL_STATE(4252)] = 148451,
  [SMALL_STATE(4253)] = 148463,
  [SMALL_STATE(4254)] = 148483,
  [SMALL_STATE(4255)] = 148501,
  [SMALL_STATE(4256)] = 148513,
  [SMALL_STATE(4257)] = 148533,
  [SMALL_STATE(4258)] = 148545,
  [SMALL_STATE(4259)] = 148565,
  [SMALL_STATE(4260)] = 148577,
  [SMALL_STATE(4261)] = 148597,
  [SMALL_STATE(4262)] = 148609,
  [SMALL_STATE(4263)] = 148621,
  [SMALL_STATE(4264)] = 148637,
  [SMALL_STATE(4265)] = 148653,
  [SMALL_STATE(4266)] = 148665,
  [SMALL_STATE(4267)] = 148677,
  [SMALL_STATE(4268)] = 148689,
  [SMALL_STATE(4269)] = 148705,
  [SMALL_STATE(4270)] = 148721,
  [SMALL_STATE(4271)] = 148733,
  [SMALL_STATE(4272)] = 148745,
  [SMALL_STATE(4273)] = 148757,
  [SMALL_STATE(4274)] = 148777,
  [SMALL_STATE(4275)] = 148789,
  [SMALL_STATE(4276)] = 148801,
  [SMALL_STATE(4277)] = 148815,
  [SMALL_STATE(4278)] = 148831,
  [SMALL_STATE(4279)] = 148843,
  [SMALL_STATE(4280)] = 148863,
  [SMALL_STATE(4281)] = 148875,
  [SMALL_STATE(4282)] = 148887,
  [SMALL_STATE(4283)] = 148899,
  [SMALL_STATE(4284)] = 148911,
  [SMALL_STATE(4285)] = 148923,
  [SMALL_STATE(4286)] = 148935,
  [SMALL_STATE(4287)] = 148947,
  [SMALL_STATE(4288)] = 148959,
  [SMALL_STATE(4289)] = 148971,
  [SMALL_STATE(4290)] = 148989,
  [SMALL_STATE(4291)] = 149007,
  [SMALL_STATE(4292)] = 149027,
  [SMALL_STATE(4293)] = 149047,
  [SMALL_STATE(4294)] = 149067,
  [SMALL_STATE(4295)] = 149079,
  [SMALL_STATE(4296)] = 149095,
  [SMALL_STATE(4297)] = 149113,
  [SMALL_STATE(4298)] = 149129,
  [SMALL_STATE(4299)] = 149149,
  [SMALL_STATE(4300)] = 149165,
  [SMALL_STATE(4301)] = 149181,
  [SMALL_STATE(4302)] = 149201,
  [SMALL_STATE(4303)] = 149217,
  [SMALL_STATE(4304)] = 149229,
  [SMALL_STATE(4305)] = 149249,
  [SMALL_STATE(4306)] = 149269,
  [SMALL_STATE(4307)] = 149289,
  [SMALL_STATE(4308)] = 149301,
  [SMALL_STATE(4309)] = 149321,
  [SMALL_STATE(4310)] = 149335,
  [SMALL_STATE(4311)] = 149347,
  [SMALL_STATE(4312)] = 149359,
  [SMALL_STATE(4313)] = 149371,
  [SMALL_STATE(4314)] = 149387,
  [SMALL_STATE(4315)] = 149403,
  [SMALL_STATE(4316)] = 149415,
  [SMALL_STATE(4317)] = 149427,
  [SMALL_STATE(4318)] = 149443,
  [SMALL_STATE(4319)] = 149455,
  [SMALL_STATE(4320)] = 149475,
  [SMALL_STATE(4321)] = 149495,
  [SMALL_STATE(4322)] = 149511,
  [SMALL_STATE(4323)] = 149527,
  [SMALL_STATE(4324)] = 149547,
  [SMALL_STATE(4325)] = 149559,
  [SMALL_STATE(4326)] = 149575,
  [SMALL_STATE(4327)] = 149591,
  [SMALL_STATE(4328)] = 149603,
  [SMALL_STATE(4329)] = 149619,
  [SMALL_STATE(4330)] = 149639,
  [SMALL_STATE(4331)] = 149651,
  [SMALL_STATE(4332)] = 149667,
  [SMALL_STATE(4333)] = 149683,
  [SMALL_STATE(4334)] = 149699,
  [SMALL_STATE(4335)] = 149715,
  [SMALL_STATE(4336)] = 149735,
  [SMALL_STATE(4337)] = 149751,
  [SMALL_STATE(4338)] = 149767,
  [SMALL_STATE(4339)] = 149783,
  [SMALL_STATE(4340)] = 149795,
  [SMALL_STATE(4341)] = 149807,
  [SMALL_STATE(4342)] = 149819,
  [SMALL_STATE(4343)] = 149831,
  [SMALL_STATE(4344)] = 149843,
  [SMALL_STATE(4345)] = 149859,
  [SMALL_STATE(4346)] = 149875,
  [SMALL_STATE(4347)] = 149891,
  [SMALL_STATE(4348)] = 149907,
  [SMALL_STATE(4349)] = 149927,
  [SMALL_STATE(4350)] = 149943,
  [SMALL_STATE(4351)] = 149959,
  [SMALL_STATE(4352)] = 149975,
  [SMALL_STATE(4353)] = 149991,
  [SMALL_STATE(4354)] = 150007,
  [SMALL_STATE(4355)] = 150027,
  [SMALL_STATE(4356)] = 150047,
  [SMALL_STATE(4357)] = 150063,
  [SMALL_STATE(4358)] = 150079,
  [SMALL_STATE(4359)] = 150095,
  [SMALL_STATE(4360)] = 150115,
  [SMALL_STATE(4361)] = 150131,
  [SMALL_STATE(4362)] = 150147,
  [SMALL_STATE(4363)] = 150163,
  [SMALL_STATE(4364)] = 150179,
  [SMALL_STATE(4365)] = 150195,
  [SMALL_STATE(4366)] = 150211,
  [SMALL_STATE(4367)] = 150227,
  [SMALL_STATE(4368)] = 150243,
  [SMALL_STATE(4369)] = 150259,
  [SMALL_STATE(4370)] = 150275,
  [SMALL_STATE(4371)] = 150291,
  [SMALL_STATE(4372)] = 150303,
  [SMALL_STATE(4373)] = 150319,
  [SMALL_STATE(4374)] = 150335,
  [SMALL_STATE(4375)] = 150347,
  [SMALL_STATE(4376)] = 150359,
  [SMALL_STATE(4377)] = 150375,
  [SMALL_STATE(4378)] = 150391,
  [SMALL_STATE(4379)] = 150407,
  [SMALL_STATE(4380)] = 150423,
  [SMALL_STATE(4381)] = 150440,
  [SMALL_STATE(4382)] = 150457,
  [SMALL_STATE(4383)] = 150474,
  [SMALL_STATE(4384)] = 150489,
  [SMALL_STATE(4385)] = 150506,
  [SMALL_STATE(4386)] = 150521,
  [SMALL_STATE(4387)] = 150538,
  [SMALL_STATE(4388)] = 150555,
  [SMALL_STATE(4389)] = 150572,
  [SMALL_STATE(4390)] = 150585,
  [SMALL_STATE(4391)] = 150602,
  [SMALL_STATE(4392)] = 150619,
  [SMALL_STATE(4393)] = 150636,
  [SMALL_STATE(4394)] = 150653,
  [SMALL_STATE(4395)] = 150670,
  [SMALL_STATE(4396)] = 150687,
  [SMALL_STATE(4397)] = 150704,
  [SMALL_STATE(4398)] = 150721,
  [SMALL_STATE(4399)] = 150738,
  [SMALL_STATE(4400)] = 150755,
  [SMALL_STATE(4401)] = 150772,
  [SMALL_STATE(4402)] = 150789,
  [SMALL_STATE(4403)] = 150806,
  [SMALL_STATE(4404)] = 150819,
  [SMALL_STATE(4405)] = 150836,
  [SMALL_STATE(4406)] = 150853,
  [SMALL_STATE(4407)] = 150870,
  [SMALL_STATE(4408)] = 150887,
  [SMALL_STATE(4409)] = 150904,
  [SMALL_STATE(4410)] = 150921,
  [SMALL_STATE(4411)] = 150938,
  [SMALL_STATE(4412)] = 150955,
  [SMALL_STATE(4413)] = 150972,
  [SMALL_STATE(4414)] = 150989,
  [SMALL_STATE(4415)] = 151004,
  [SMALL_STATE(4416)] = 151021,
  [SMALL_STATE(4417)] = 151036,
  [SMALL_STATE(4418)] = 151051,
  [SMALL_STATE(4419)] = 151066,
  [SMALL_STATE(4420)] = 151081,
  [SMALL_STATE(4421)] = 151098,
  [SMALL_STATE(4422)] = 151111,
  [SMALL_STATE(4423)] = 151128,
  [SMALL_STATE(4424)] = 151143,
  [SMALL_STATE(4425)] = 151160,
  [SMALL_STATE(4426)] = 151173,
  [SMALL_STATE(4427)] = 151188,
  [SMALL_STATE(4428)] = 151203,
  [SMALL_STATE(4429)] = 151220,
  [SMALL_STATE(4430)] = 151237,
  [SMALL_STATE(4431)] = 151254,
  [SMALL_STATE(4432)] = 151269,
  [SMALL_STATE(4433)] = 151286,
  [SMALL_STATE(4434)] = 151303,
  [SMALL_STATE(4435)] = 151320,
  [SMALL_STATE(4436)] = 151337,
  [SMALL_STATE(4437)] = 151354,
  [SMALL_STATE(4438)] = 151371,
  [SMALL_STATE(4439)] = 151388,
  [SMALL_STATE(4440)] = 151405,
  [SMALL_STATE(4441)] = 151416,
  [SMALL_STATE(4442)] = 151433,
  [SMALL_STATE(4443)] = 151450,
  [SMALL_STATE(4444)] = 151467,
  [SMALL_STATE(4445)] = 151484,
  [SMALL_STATE(4446)] = 151495,
  [SMALL_STATE(4447)] = 151510,
  [SMALL_STATE(4448)] = 151527,
  [SMALL_STATE(4449)] = 151544,
  [SMALL_STATE(4450)] = 151561,
  [SMALL_STATE(4451)] = 151576,
  [SMALL_STATE(4452)] = 151591,
  [SMALL_STATE(4453)] = 151608,
  [SMALL_STATE(4454)] = 151625,
  [SMALL_STATE(4455)] = 151642,
  [SMALL_STATE(4456)] = 151657,
  [SMALL_STATE(4457)] = 151674,
  [SMALL_STATE(4458)] = 151689,
  [SMALL_STATE(4459)] = 151704,
  [SMALL_STATE(4460)] = 151719,
  [SMALL_STATE(4461)] = 151734,
  [SMALL_STATE(4462)] = 151751,
  [SMALL_STATE(4463)] = 151766,
  [SMALL_STATE(4464)] = 151783,
  [SMALL_STATE(4465)] = 151798,
  [SMALL_STATE(4466)] = 151815,
  [SMALL_STATE(4467)] = 151832,
  [SMALL_STATE(4468)] = 151843,
  [SMALL_STATE(4469)] = 151860,
  [SMALL_STATE(4470)] = 151871,
  [SMALL_STATE(4471)] = 151888,
  [SMALL_STATE(4472)] = 151905,
  [SMALL_STATE(4473)] = 151922,
  [SMALL_STATE(4474)] = 151939,
  [SMALL_STATE(4475)] = 151956,
  [SMALL_STATE(4476)] = 151973,
  [SMALL_STATE(4477)] = 151990,
  [SMALL_STATE(4478)] = 152007,
  [SMALL_STATE(4479)] = 152024,
  [SMALL_STATE(4480)] = 152041,
  [SMALL_STATE(4481)] = 152056,
  [SMALL_STATE(4482)] = 152073,
  [SMALL_STATE(4483)] = 152090,
  [SMALL_STATE(4484)] = 152103,
  [SMALL_STATE(4485)] = 152120,
  [SMALL_STATE(4486)] = 152137,
  [SMALL_STATE(4487)] = 152154,
  [SMALL_STATE(4488)] = 152167,
  [SMALL_STATE(4489)] = 152180,
  [SMALL_STATE(4490)] = 152197,
  [SMALL_STATE(4491)] = 152214,
  [SMALL_STATE(4492)] = 152229,
  [SMALL_STATE(4493)] = 152246,
  [SMALL_STATE(4494)] = 152263,
  [SMALL_STATE(4495)] = 152280,
  [SMALL_STATE(4496)] = 152297,
  [SMALL_STATE(4497)] = 152314,
  [SMALL_STATE(4498)] = 152331,
  [SMALL_STATE(4499)] = 152348,
  [SMALL_STATE(4500)] = 152363,
  [SMALL_STATE(4501)] = 152380,
  [SMALL_STATE(4502)] = 152397,
  [SMALL_STATE(4503)] = 152414,
  [SMALL_STATE(4504)] = 152431,
  [SMALL_STATE(4505)] = 152448,
  [SMALL_STATE(4506)] = 152463,
  [SMALL_STATE(4507)] = 152478,
  [SMALL_STATE(4508)] = 152495,
  [SMALL_STATE(4509)] = 152512,
  [SMALL_STATE(4510)] = 152529,
  [SMALL_STATE(4511)] = 152546,
  [SMALL_STATE(4512)] = 152563,
  [SMALL_STATE(4513)] = 152580,
  [SMALL_STATE(4514)] = 152597,
  [SMALL_STATE(4515)] = 152614,
  [SMALL_STATE(4516)] = 152629,
  [SMALL_STATE(4517)] = 152639,
  [SMALL_STATE(4518)] = 152649,
  [SMALL_STATE(4519)] = 152659,
  [SMALL_STATE(4520)] = 152669,
  [SMALL_STATE(4521)] = 152679,
  [SMALL_STATE(4522)] = 152689,
  [SMALL_STATE(4523)] = 152699,
  [SMALL_STATE(4524)] = 152711,
  [SMALL_STATE(4525)] = 152725,
  [SMALL_STATE(4526)] = 152735,
  [SMALL_STATE(4527)] = 152745,
  [SMALL_STATE(4528)] = 152755,
  [SMALL_STATE(4529)] = 152765,
  [SMALL_STATE(4530)] = 152775,
  [SMALL_STATE(4531)] = 152785,
  [SMALL_STATE(4532)] = 152799,
  [SMALL_STATE(4533)] = 152809,
  [SMALL_STATE(4534)] = 152823,
  [SMALL_STATE(4535)] = 152833,
  [SMALL_STATE(4536)] = 152843,
  [SMALL_STATE(4537)] = 152853,
  [SMALL_STATE(4538)] = 152867,
  [SMALL_STATE(4539)] = 152877,
  [SMALL_STATE(4540)] = 152887,
  [SMALL_STATE(4541)] = 152901,
  [SMALL_STATE(4542)] = 152915,
  [SMALL_STATE(4543)] = 152929,
  [SMALL_STATE(4544)] = 152943,
  [SMALL_STATE(4545)] = 152957,
  [SMALL_STATE(4546)] = 152971,
  [SMALL_STATE(4547)] = 152981,
  [SMALL_STATE(4548)] = 152991,
  [SMALL_STATE(4549)] = 153001,
  [SMALL_STATE(4550)] = 153011,
  [SMALL_STATE(4551)] = 153021,
  [SMALL_STATE(4552)] = 153031,
  [SMALL_STATE(4553)] = 153045,
  [SMALL_STATE(4554)] = 153059,
  [SMALL_STATE(4555)] = 153073,
  [SMALL_STATE(4556)] = 153087,
  [SMALL_STATE(4557)] = 153097,
  [SMALL_STATE(4558)] = 153107,
  [SMALL_STATE(4559)] = 153117,
  [SMALL_STATE(4560)] = 153127,
  [SMALL_STATE(4561)] = 153137,
  [SMALL_STATE(4562)] = 153147,
  [SMALL_STATE(4563)] = 153157,
  [SMALL_STATE(4564)] = 153167,
  [SMALL_STATE(4565)] = 153179,
  [SMALL_STATE(4566)] = 153189,
  [SMALL_STATE(4567)] = 153201,
  [SMALL_STATE(4568)] = 153211,
  [SMALL_STATE(4569)] = 153225,
  [SMALL_STATE(4570)] = 153235,
  [SMALL_STATE(4571)] = 153245,
  [SMALL_STATE(4572)] = 153255,
  [SMALL_STATE(4573)] = 153265,
  [SMALL_STATE(4574)] = 153275,
  [SMALL_STATE(4575)] = 153285,
  [SMALL_STATE(4576)] = 153295,
  [SMALL_STATE(4577)] = 153309,
  [SMALL_STATE(4578)] = 153319,
  [SMALL_STATE(4579)] = 153333,
  [SMALL_STATE(4580)] = 153343,
  [SMALL_STATE(4581)] = 153353,
  [SMALL_STATE(4582)] = 153363,
  [SMALL_STATE(4583)] = 153373,
  [SMALL_STATE(4584)] = 153383,
  [SMALL_STATE(4585)] = 153393,
  [SMALL_STATE(4586)] = 153403,
  [SMALL_STATE(4587)] = 153417,
  [SMALL_STATE(4588)] = 153431,
  [SMALL_STATE(4589)] = 153445,
  [SMALL_STATE(4590)] = 153455,
  [SMALL_STATE(4591)] = 153469,
  [SMALL_STATE(4592)] = 153483,
  [SMALL_STATE(4593)] = 153493,
  [SMALL_STATE(4594)] = 153503,
  [SMALL_STATE(4595)] = 153517,
  [SMALL_STATE(4596)] = 153531,
  [SMALL_STATE(4597)] = 153545,
  [SMALL_STATE(4598)] = 153559,
  [SMALL_STATE(4599)] = 153569,
  [SMALL_STATE(4600)] = 153583,
  [SMALL_STATE(4601)] = 153593,
  [SMALL_STATE(4602)] = 153603,
  [SMALL_STATE(4603)] = 153617,
  [SMALL_STATE(4604)] = 153627,
  [SMALL_STATE(4605)] = 153637,
  [SMALL_STATE(4606)] = 153647,
  [SMALL_STATE(4607)] = 153657,
  [SMALL_STATE(4608)] = 153667,
  [SMALL_STATE(4609)] = 153677,
  [SMALL_STATE(4610)] = 153687,
  [SMALL_STATE(4611)] = 153697,
  [SMALL_STATE(4612)] = 153707,
  [SMALL_STATE(4613)] = 153717,
  [SMALL_STATE(4614)] = 153727,
  [SMALL_STATE(4615)] = 153737,
  [SMALL_STATE(4616)] = 153747,
  [SMALL_STATE(4617)] = 153757,
  [SMALL_STATE(4618)] = 153767,
  [SMALL_STATE(4619)] = 153777,
  [SMALL_STATE(4620)] = 153787,
  [SMALL_STATE(4621)] = 153801,
  [SMALL_STATE(4622)] = 153815,
  [SMALL_STATE(4623)] = 153829,
  [SMALL_STATE(4624)] = 153839,
  [SMALL_STATE(4625)] = 153849,
  [SMALL_STATE(4626)] = 153859,
  [SMALL_STATE(4627)] = 153869,
  [SMALL_STATE(4628)] = 153879,
  [SMALL_STATE(4629)] = 153889,
  [SMALL_STATE(4630)] = 153899,
  [SMALL_STATE(4631)] = 153909,
  [SMALL_STATE(4632)] = 153919,
  [SMALL_STATE(4633)] = 153929,
  [SMALL_STATE(4634)] = 153939,
  [SMALL_STATE(4635)] = 153949,
  [SMALL_STATE(4636)] = 153959,
  [SMALL_STATE(4637)] = 153973,
  [SMALL_STATE(4638)] = 153983,
  [SMALL_STATE(4639)] = 153997,
  [SMALL_STATE(4640)] = 154011,
  [SMALL_STATE(4641)] = 154021,
  [SMALL_STATE(4642)] = 154031,
  [SMALL_STATE(4643)] = 154041,
  [SMALL_STATE(4644)] = 154055,
  [SMALL_STATE(4645)] = 154069,
  [SMALL_STATE(4646)] = 154079,
  [SMALL_STATE(4647)] = 154093,
  [SMALL_STATE(4648)] = 154107,
  [SMALL_STATE(4649)] = 154117,
  [SMALL_STATE(4650)] = 154131,
  [SMALL_STATE(4651)] = 154145,
  [SMALL_STATE(4652)] = 154157,
  [SMALL_STATE(4653)] = 154167,
  [SMALL_STATE(4654)] = 154181,
  [SMALL_STATE(4655)] = 154195,
  [SMALL_STATE(4656)] = 154205,
  [SMALL_STATE(4657)] = 154219,
  [SMALL_STATE(4658)] = 154229,
  [SMALL_STATE(4659)] = 154239,
  [SMALL_STATE(4660)] = 154249,
  [SMALL_STATE(4661)] = 154259,
  [SMALL_STATE(4662)] = 154273,
  [SMALL_STATE(4663)] = 154283,
  [SMALL_STATE(4664)] = 154297,
  [SMALL_STATE(4665)] = 154307,
  [SMALL_STATE(4666)] = 154317,
  [SMALL_STATE(4667)] = 154327,
  [SMALL_STATE(4668)] = 154337,
  [SMALL_STATE(4669)] = 154351,
  [SMALL_STATE(4670)] = 154361,
  [SMALL_STATE(4671)] = 154371,
  [SMALL_STATE(4672)] = 154385,
  [SMALL_STATE(4673)] = 154399,
  [SMALL_STATE(4674)] = 154409,
  [SMALL_STATE(4675)] = 154419,
  [SMALL_STATE(4676)] = 154429,
  [SMALL_STATE(4677)] = 154439,
  [SMALL_STATE(4678)] = 154449,
  [SMALL_STATE(4679)] = 154463,
  [SMALL_STATE(4680)] = 154473,
  [SMALL_STATE(4681)] = 154483,
  [SMALL_STATE(4682)] = 154497,
  [SMALL_STATE(4683)] = 154507,
  [SMALL_STATE(4684)] = 154519,
  [SMALL_STATE(4685)] = 154533,
  [SMALL_STATE(4686)] = 154547,
  [SMALL_STATE(4687)] = 154561,
  [SMALL_STATE(4688)] = 154575,
  [SMALL_STATE(4689)] = 154589,
  [SMALL_STATE(4690)] = 154599,
  [SMALL_STATE(4691)] = 154609,
  [SMALL_STATE(4692)] = 154619,
  [SMALL_STATE(4693)] = 154633,
  [SMALL_STATE(4694)] = 154647,
  [SMALL_STATE(4695)] = 154657,
  [SMALL_STATE(4696)] = 154667,
  [SMALL_STATE(4697)] = 154677,
  [SMALL_STATE(4698)] = 154691,
  [SMALL_STATE(4699)] = 154705,
  [SMALL_STATE(4700)] = 154715,
  [SMALL_STATE(4701)] = 154729,
  [SMALL_STATE(4702)] = 154739,
  [SMALL_STATE(4703)] = 154749,
  [SMALL_STATE(4704)] = 154759,
  [SMALL_STATE(4705)] = 154769,
  [SMALL_STATE(4706)] = 154779,
  [SMALL_STATE(4707)] = 154789,
  [SMALL_STATE(4708)] = 154799,
  [SMALL_STATE(4709)] = 154813,
  [SMALL_STATE(4710)] = 154823,
  [SMALL_STATE(4711)] = 154833,
  [SMALL_STATE(4712)] = 154843,
  [SMALL_STATE(4713)] = 154857,
  [SMALL_STATE(4714)] = 154871,
  [SMALL_STATE(4715)] = 154885,
  [SMALL_STATE(4716)] = 154895,
  [SMALL_STATE(4717)] = 154909,
  [SMALL_STATE(4718)] = 154919,
  [SMALL_STATE(4719)] = 154929,
  [SMALL_STATE(4720)] = 154939,
  [SMALL_STATE(4721)] = 154949,
  [SMALL_STATE(4722)] = 154963,
  [SMALL_STATE(4723)] = 154973,
  [SMALL_STATE(4724)] = 154983,
  [SMALL_STATE(4725)] = 154993,
  [SMALL_STATE(4726)] = 155003,
  [SMALL_STATE(4727)] = 155013,
  [SMALL_STATE(4728)] = 155023,
  [SMALL_STATE(4729)] = 155033,
  [SMALL_STATE(4730)] = 155043,
  [SMALL_STATE(4731)] = 155057,
  [SMALL_STATE(4732)] = 155067,
  [SMALL_STATE(4733)] = 155077,
  [SMALL_STATE(4734)] = 155091,
  [SMALL_STATE(4735)] = 155105,
  [SMALL_STATE(4736)] = 155117,
  [SMALL_STATE(4737)] = 155131,
  [SMALL_STATE(4738)] = 155141,
  [SMALL_STATE(4739)] = 155151,
  [SMALL_STATE(4740)] = 155161,
  [SMALL_STATE(4741)] = 155175,
  [SMALL_STATE(4742)] = 155185,
  [SMALL_STATE(4743)] = 155195,
  [SMALL_STATE(4744)] = 155205,
  [SMALL_STATE(4745)] = 155219,
  [SMALL_STATE(4746)] = 155233,
  [SMALL_STATE(4747)] = 155247,
  [SMALL_STATE(4748)] = 155257,
  [SMALL_STATE(4749)] = 155267,
  [SMALL_STATE(4750)] = 155277,
  [SMALL_STATE(4751)] = 155287,
  [SMALL_STATE(4752)] = 155297,
  [SMALL_STATE(4753)] = 155307,
  [SMALL_STATE(4754)] = 155317,
  [SMALL_STATE(4755)] = 155327,
  [SMALL_STATE(4756)] = 155337,
  [SMALL_STATE(4757)] = 155347,
  [SMALL_STATE(4758)] = 155357,
  [SMALL_STATE(4759)] = 155367,
  [SMALL_STATE(4760)] = 155377,
  [SMALL_STATE(4761)] = 155387,
  [SMALL_STATE(4762)] = 155397,
  [SMALL_STATE(4763)] = 155407,
  [SMALL_STATE(4764)] = 155417,
  [SMALL_STATE(4765)] = 155427,
  [SMALL_STATE(4766)] = 155437,
  [SMALL_STATE(4767)] = 155447,
  [SMALL_STATE(4768)] = 155457,
  [SMALL_STATE(4769)] = 155467,
  [SMALL_STATE(4770)] = 155477,
  [SMALL_STATE(4771)] = 155487,
  [SMALL_STATE(4772)] = 155497,
  [SMALL_STATE(4773)] = 155507,
  [SMALL_STATE(4774)] = 155517,
  [SMALL_STATE(4775)] = 155527,
  [SMALL_STATE(4776)] = 155537,
  [SMALL_STATE(4777)] = 155547,
  [SMALL_STATE(4778)] = 155557,
  [SMALL_STATE(4779)] = 155567,
  [SMALL_STATE(4780)] = 155577,
  [SMALL_STATE(4781)] = 155591,
  [SMALL_STATE(4782)] = 155601,
  [SMALL_STATE(4783)] = 155611,
  [SMALL_STATE(4784)] = 155625,
  [SMALL_STATE(4785)] = 155639,
  [SMALL_STATE(4786)] = 155653,
  [SMALL_STATE(4787)] = 155663,
  [SMALL_STATE(4788)] = 155677,
  [SMALL_STATE(4789)] = 155687,
  [SMALL_STATE(4790)] = 155701,
  [SMALL_STATE(4791)] = 155715,
  [SMALL_STATE(4792)] = 155725,
  [SMALL_STATE(4793)] = 155739,
  [SMALL_STATE(4794)] = 155749,
  [SMALL_STATE(4795)] = 155759,
  [SMALL_STATE(4796)] = 155769,
  [SMALL_STATE(4797)] = 155779,
  [SMALL_STATE(4798)] = 155793,
  [SMALL_STATE(4799)] = 155803,
  [SMALL_STATE(4800)] = 155813,
  [SMALL_STATE(4801)] = 155823,
  [SMALL_STATE(4802)] = 155833,
  [SMALL_STATE(4803)] = 155847,
  [SMALL_STATE(4804)] = 155857,
  [SMALL_STATE(4805)] = 155867,
  [SMALL_STATE(4806)] = 155877,
  [SMALL_STATE(4807)] = 155891,
  [SMALL_STATE(4808)] = 155901,
  [SMALL_STATE(4809)] = 155915,
  [SMALL_STATE(4810)] = 155925,
  [SMALL_STATE(4811)] = 155939,
  [SMALL_STATE(4812)] = 155949,
  [SMALL_STATE(4813)] = 155963,
  [SMALL_STATE(4814)] = 155975,
  [SMALL_STATE(4815)] = 155985,
  [SMALL_STATE(4816)] = 155999,
  [SMALL_STATE(4817)] = 156009,
  [SMALL_STATE(4818)] = 156019,
  [SMALL_STATE(4819)] = 156029,
  [SMALL_STATE(4820)] = 156039,
  [SMALL_STATE(4821)] = 156049,
  [SMALL_STATE(4822)] = 156059,
  [SMALL_STATE(4823)] = 156069,
  [SMALL_STATE(4824)] = 156079,
  [SMALL_STATE(4825)] = 156089,
  [SMALL_STATE(4826)] = 156099,
  [SMALL_STATE(4827)] = 156109,
  [SMALL_STATE(4828)] = 156119,
  [SMALL_STATE(4829)] = 156129,
  [SMALL_STATE(4830)] = 156143,
  [SMALL_STATE(4831)] = 156153,
  [SMALL_STATE(4832)] = 156163,
  [SMALL_STATE(4833)] = 156173,
  [SMALL_STATE(4834)] = 156183,
  [SMALL_STATE(4835)] = 156193,
  [SMALL_STATE(4836)] = 156203,
  [SMALL_STATE(4837)] = 156213,
  [SMALL_STATE(4838)] = 156223,
  [SMALL_STATE(4839)] = 156233,
  [SMALL_STATE(4840)] = 156243,
  [SMALL_STATE(4841)] = 156253,
  [SMALL_STATE(4842)] = 156263,
  [SMALL_STATE(4843)] = 156273,
  [SMALL_STATE(4844)] = 156283,
  [SMALL_STATE(4845)] = 156293,
  [SMALL_STATE(4846)] = 156303,
  [SMALL_STATE(4847)] = 156313,
  [SMALL_STATE(4848)] = 156323,
  [SMALL_STATE(4849)] = 156333,
  [SMALL_STATE(4850)] = 156343,
  [SMALL_STATE(4851)] = 156353,
  [SMALL_STATE(4852)] = 156363,
  [SMALL_STATE(4853)] = 156373,
  [SMALL_STATE(4854)] = 156383,
  [SMALL_STATE(4855)] = 156393,
  [SMALL_STATE(4856)] = 156403,
  [SMALL_STATE(4857)] = 156413,
  [SMALL_STATE(4858)] = 156423,
  [SMALL_STATE(4859)] = 156433,
  [SMALL_STATE(4860)] = 156443,
  [SMALL_STATE(4861)] = 156453,
  [SMALL_STATE(4862)] = 156463,
  [SMALL_STATE(4863)] = 156473,
  [SMALL_STATE(4864)] = 156483,
  [SMALL_STATE(4865)] = 156493,
  [SMALL_STATE(4866)] = 156503,
  [SMALL_STATE(4867)] = 156513,
  [SMALL_STATE(4868)] = 156523,
  [SMALL_STATE(4869)] = 156533,
  [SMALL_STATE(4870)] = 156547,
  [SMALL_STATE(4871)] = 156557,
  [SMALL_STATE(4872)] = 156567,
  [SMALL_STATE(4873)] = 156577,
  [SMALL_STATE(4874)] = 156587,
  [SMALL_STATE(4875)] = 156597,
  [SMALL_STATE(4876)] = 156607,
  [SMALL_STATE(4877)] = 156617,
  [SMALL_STATE(4878)] = 156627,
  [SMALL_STATE(4879)] = 156641,
  [SMALL_STATE(4880)] = 156655,
  [SMALL_STATE(4881)] = 156665,
  [SMALL_STATE(4882)] = 156677,
  [SMALL_STATE(4883)] = 156687,
  [SMALL_STATE(4884)] = 156697,
  [SMALL_STATE(4885)] = 156707,
  [SMALL_STATE(4886)] = 156717,
  [SMALL_STATE(4887)] = 156727,
  [SMALL_STATE(4888)] = 156741,
  [SMALL_STATE(4889)] = 156751,
  [SMALL_STATE(4890)] = 156761,
  [SMALL_STATE(4891)] = 156775,
  [SMALL_STATE(4892)] = 156787,
  [SMALL_STATE(4893)] = 156797,
  [SMALL_STATE(4894)] = 156807,
  [SMALL_STATE(4895)] = 156817,
  [SMALL_STATE(4896)] = 156827,
  [SMALL_STATE(4897)] = 156841,
  [SMALL_STATE(4898)] = 156855,
  [SMALL_STATE(4899)] = 156865,
  [SMALL_STATE(4900)] = 156879,
  [SMALL_STATE(4901)] = 156889,
  [SMALL_STATE(4902)] = 156899,
  [SMALL_STATE(4903)] = 156909,
  [SMALL_STATE(4904)] = 156919,
  [SMALL_STATE(4905)] = 156929,
  [SMALL_STATE(4906)] = 156943,
  [SMALL_STATE(4907)] = 156953,
  [SMALL_STATE(4908)] = 156963,
  [SMALL_STATE(4909)] = 156977,
  [SMALL_STATE(4910)] = 156987,
  [SMALL_STATE(4911)] = 157001,
  [SMALL_STATE(4912)] = 157011,
  [SMALL_STATE(4913)] = 157021,
  [SMALL_STATE(4914)] = 157031,
  [SMALL_STATE(4915)] = 157041,
  [SMALL_STATE(4916)] = 157051,
  [SMALL_STATE(4917)] = 157061,
  [SMALL_STATE(4918)] = 157071,
  [SMALL_STATE(4919)] = 157081,
  [SMALL_STATE(4920)] = 157091,
  [SMALL_STATE(4921)] = 157101,
  [SMALL_STATE(4922)] = 157111,
  [SMALL_STATE(4923)] = 157121,
  [SMALL_STATE(4924)] = 157131,
  [SMALL_STATE(4925)] = 157141,
  [SMALL_STATE(4926)] = 157155,
  [SMALL_STATE(4927)] = 157165,
  [SMALL_STATE(4928)] = 157179,
  [SMALL_STATE(4929)] = 157189,
  [SMALL_STATE(4930)] = 157199,
  [SMALL_STATE(4931)] = 157211,
  [SMALL_STATE(4932)] = 157221,
  [SMALL_STATE(4933)] = 157231,
  [SMALL_STATE(4934)] = 157241,
  [SMALL_STATE(4935)] = 157251,
  [SMALL_STATE(4936)] = 157261,
  [SMALL_STATE(4937)] = 157271,
  [SMALL_STATE(4938)] = 157281,
  [SMALL_STATE(4939)] = 157291,
  [SMALL_STATE(4940)] = 157305,
  [SMALL_STATE(4941)] = 157315,
  [SMALL_STATE(4942)] = 157325,
  [SMALL_STATE(4943)] = 157335,
  [SMALL_STATE(4944)] = 157345,
  [SMALL_STATE(4945)] = 157355,
  [SMALL_STATE(4946)] = 157365,
  [SMALL_STATE(4947)] = 157379,
  [SMALL_STATE(4948)] = 157389,
  [SMALL_STATE(4949)] = 157399,
  [SMALL_STATE(4950)] = 157413,
  [SMALL_STATE(4951)] = 157427,
  [SMALL_STATE(4952)] = 157437,
  [SMALL_STATE(4953)] = 157447,
  [SMALL_STATE(4954)] = 157457,
  [SMALL_STATE(4955)] = 157467,
  [SMALL_STATE(4956)] = 157481,
  [SMALL_STATE(4957)] = 157495,
  [SMALL_STATE(4958)] = 157505,
  [SMALL_STATE(4959)] = 157519,
  [SMALL_STATE(4960)] = 157533,
  [SMALL_STATE(4961)] = 157547,
  [SMALL_STATE(4962)] = 157561,
  [SMALL_STATE(4963)] = 157575,
  [SMALL_STATE(4964)] = 157585,
  [SMALL_STATE(4965)] = 157599,
  [SMALL_STATE(4966)] = 157613,
  [SMALL_STATE(4967)] = 157627,
  [SMALL_STATE(4968)] = 157641,
  [SMALL_STATE(4969)] = 157651,
  [SMALL_STATE(4970)] = 157665,
  [SMALL_STATE(4971)] = 157675,
  [SMALL_STATE(4972)] = 157689,
  [SMALL_STATE(4973)] = 157703,
  [SMALL_STATE(4974)] = 157717,
  [SMALL_STATE(4975)] = 157731,
  [SMALL_STATE(4976)] = 157745,
  [SMALL_STATE(4977)] = 157755,
  [SMALL_STATE(4978)] = 157769,
  [SMALL_STATE(4979)] = 157779,
  [SMALL_STATE(4980)] = 157789,
  [SMALL_STATE(4981)] = 157799,
  [SMALL_STATE(4982)] = 157813,
  [SMALL_STATE(4983)] = 157825,
  [SMALL_STATE(4984)] = 157835,
  [SMALL_STATE(4985)] = 157847,
  [SMALL_STATE(4986)] = 157857,
  [SMALL_STATE(4987)] = 157867,
  [SMALL_STATE(4988)] = 157881,
  [SMALL_STATE(4989)] = 157891,
  [SMALL_STATE(4990)] = 157903,
  [SMALL_STATE(4991)] = 157917,
  [SMALL_STATE(4992)] = 157927,
  [SMALL_STATE(4993)] = 157937,
  [SMALL_STATE(4994)] = 157949,
  [SMALL_STATE(4995)] = 157963,
  [SMALL_STATE(4996)] = 157973,
  [SMALL_STATE(4997)] = 157987,
  [SMALL_STATE(4998)] = 158001,
  [SMALL_STATE(4999)] = 158015,
  [SMALL_STATE(5000)] = 158029,
  [SMALL_STATE(5001)] = 158043,
  [SMALL_STATE(5002)] = 158057,
  [SMALL_STATE(5003)] = 158067,
  [SMALL_STATE(5004)] = 158079,
  [SMALL_STATE(5005)] = 158091,
  [SMALL_STATE(5006)] = 158105,
  [SMALL_STATE(5007)] = 158119,
  [SMALL_STATE(5008)] = 158129,
  [SMALL_STATE(5009)] = 158143,
  [SMALL_STATE(5010)] = 158155,
  [SMALL_STATE(5011)] = 158165,
  [SMALL_STATE(5012)] = 158179,
  [SMALL_STATE(5013)] = 158189,
  [SMALL_STATE(5014)] = 158199,
  [SMALL_STATE(5015)] = 158213,
  [SMALL_STATE(5016)] = 158223,
  [SMALL_STATE(5017)] = 158237,
  [SMALL_STATE(5018)] = 158247,
  [SMALL_STATE(5019)] = 158261,
  [SMALL_STATE(5020)] = 158273,
  [SMALL_STATE(5021)] = 158287,
  [SMALL_STATE(5022)] = 158297,
  [SMALL_STATE(5023)] = 158311,
  [SMALL_STATE(5024)] = 158325,
  [SMALL_STATE(5025)] = 158335,
  [SMALL_STATE(5026)] = 158345,
  [SMALL_STATE(5027)] = 158359,
  [SMALL_STATE(5028)] = 158373,
  [SMALL_STATE(5029)] = 158383,
  [SMALL_STATE(5030)] = 158397,
  [SMALL_STATE(5031)] = 158411,
  [SMALL_STATE(5032)] = 158421,
  [SMALL_STATE(5033)] = 158435,
  [SMALL_STATE(5034)] = 158449,
  [SMALL_STATE(5035)] = 158459,
  [SMALL_STATE(5036)] = 158469,
  [SMALL_STATE(5037)] = 158479,
  [SMALL_STATE(5038)] = 158489,
  [SMALL_STATE(5039)] = 158503,
  [SMALL_STATE(5040)] = 158515,
  [SMALL_STATE(5041)] = 158525,
  [SMALL_STATE(5042)] = 158537,
  [SMALL_STATE(5043)] = 158547,
  [SMALL_STATE(5044)] = 158557,
  [SMALL_STATE(5045)] = 158567,
  [SMALL_STATE(5046)] = 158577,
  [SMALL_STATE(5047)] = 158587,
  [SMALL_STATE(5048)] = 158597,
  [SMALL_STATE(5049)] = 158607,
  [SMALL_STATE(5050)] = 158617,
  [SMALL_STATE(5051)] = 158627,
  [SMALL_STATE(5052)] = 158637,
  [SMALL_STATE(5053)] = 158651,
  [SMALL_STATE(5054)] = 158661,
  [SMALL_STATE(5055)] = 158671,
  [SMALL_STATE(5056)] = 158681,
  [SMALL_STATE(5057)] = 158691,
  [SMALL_STATE(5058)] = 158701,
  [SMALL_STATE(5059)] = 158711,
  [SMALL_STATE(5060)] = 158721,
  [SMALL_STATE(5061)] = 158731,
  [SMALL_STATE(5062)] = 158741,
  [SMALL_STATE(5063)] = 158755,
  [SMALL_STATE(5064)] = 158765,
  [SMALL_STATE(5065)] = 158775,
  [SMALL_STATE(5066)] = 158785,
  [SMALL_STATE(5067)] = 158795,
  [SMALL_STATE(5068)] = 158805,
  [SMALL_STATE(5069)] = 158815,
  [SMALL_STATE(5070)] = 158825,
  [SMALL_STATE(5071)] = 158835,
  [SMALL_STATE(5072)] = 158845,
  [SMALL_STATE(5073)] = 158855,
  [SMALL_STATE(5074)] = 158865,
  [SMALL_STATE(5075)] = 158875,
  [SMALL_STATE(5076)] = 158887,
  [SMALL_STATE(5077)] = 158899,
  [SMALL_STATE(5078)] = 158909,
  [SMALL_STATE(5079)] = 158919,
  [SMALL_STATE(5080)] = 158929,
  [SMALL_STATE(5081)] = 158943,
  [SMALL_STATE(5082)] = 158953,
  [SMALL_STATE(5083)] = 158963,
  [SMALL_STATE(5084)] = 158973,
  [SMALL_STATE(5085)] = 158983,
  [SMALL_STATE(5086)] = 158993,
  [SMALL_STATE(5087)] = 159003,
  [SMALL_STATE(5088)] = 159013,
  [SMALL_STATE(5089)] = 159023,
  [SMALL_STATE(5090)] = 159033,
  [SMALL_STATE(5091)] = 159043,
  [SMALL_STATE(5092)] = 159053,
  [SMALL_STATE(5093)] = 159063,
  [SMALL_STATE(5094)] = 159073,
  [SMALL_STATE(5095)] = 159083,
  [SMALL_STATE(5096)] = 159093,
  [SMALL_STATE(5097)] = 159105,
  [SMALL_STATE(5098)] = 159115,
  [SMALL_STATE(5099)] = 159125,
  [SMALL_STATE(5100)] = 159135,
  [SMALL_STATE(5101)] = 159145,
  [SMALL_STATE(5102)] = 159155,
  [SMALL_STATE(5103)] = 159165,
  [SMALL_STATE(5104)] = 159175,
  [SMALL_STATE(5105)] = 159185,
  [SMALL_STATE(5106)] = 159195,
  [SMALL_STATE(5107)] = 159207,
  [SMALL_STATE(5108)] = 159217,
  [SMALL_STATE(5109)] = 159231,
  [SMALL_STATE(5110)] = 159241,
  [SMALL_STATE(5111)] = 159251,
  [SMALL_STATE(5112)] = 159261,
  [SMALL_STATE(5113)] = 159271,
  [SMALL_STATE(5114)] = 159281,
  [SMALL_STATE(5115)] = 159291,
  [SMALL_STATE(5116)] = 159305,
  [SMALL_STATE(5117)] = 159319,
  [SMALL_STATE(5118)] = 159329,
  [SMALL_STATE(5119)] = 159339,
  [SMALL_STATE(5120)] = 159349,
  [SMALL_STATE(5121)] = 159359,
  [SMALL_STATE(5122)] = 159373,
  [SMALL_STATE(5123)] = 159383,
  [SMALL_STATE(5124)] = 159393,
  [SMALL_STATE(5125)] = 159403,
  [SMALL_STATE(5126)] = 159413,
  [SMALL_STATE(5127)] = 159422,
  [SMALL_STATE(5128)] = 159433,
  [SMALL_STATE(5129)] = 159444,
  [SMALL_STATE(5130)] = 159453,
  [SMALL_STATE(5131)] = 159464,
  [SMALL_STATE(5132)] = 159475,
  [SMALL_STATE(5133)] = 159484,
  [SMALL_STATE(5134)] = 159495,
  [SMALL_STATE(5135)] = 159504,
  [SMALL_STATE(5136)] = 159515,
  [SMALL_STATE(5137)] = 159526,
  [SMALL_STATE(5138)] = 159537,
  [SMALL_STATE(5139)] = 159548,
  [SMALL_STATE(5140)] = 159559,
  [SMALL_STATE(5141)] = 159568,
  [SMALL_STATE(5142)] = 159579,
  [SMALL_STATE(5143)] = 159590,
  [SMALL_STATE(5144)] = 159601,
  [SMALL_STATE(5145)] = 159612,
  [SMALL_STATE(5146)] = 159623,
  [SMALL_STATE(5147)] = 159634,
  [SMALL_STATE(5148)] = 159643,
  [SMALL_STATE(5149)] = 159654,
  [SMALL_STATE(5150)] = 159665,
  [SMALL_STATE(5151)] = 159676,
  [SMALL_STATE(5152)] = 159687,
  [SMALL_STATE(5153)] = 159696,
  [SMALL_STATE(5154)] = 159707,
  [SMALL_STATE(5155)] = 159718,
  [SMALL_STATE(5156)] = 159729,
  [SMALL_STATE(5157)] = 159740,
  [SMALL_STATE(5158)] = 159751,
  [SMALL_STATE(5159)] = 159762,
  [SMALL_STATE(5160)] = 159771,
  [SMALL_STATE(5161)] = 159780,
  [SMALL_STATE(5162)] = 159791,
  [SMALL_STATE(5163)] = 159802,
  [SMALL_STATE(5164)] = 159813,
  [SMALL_STATE(5165)] = 159824,
  [SMALL_STATE(5166)] = 159835,
  [SMALL_STATE(5167)] = 159846,
  [SMALL_STATE(5168)] = 159857,
  [SMALL_STATE(5169)] = 159868,
  [SMALL_STATE(5170)] = 159877,
  [SMALL_STATE(5171)] = 159888,
  [SMALL_STATE(5172)] = 159899,
  [SMALL_STATE(5173)] = 159908,
  [SMALL_STATE(5174)] = 159919,
  [SMALL_STATE(5175)] = 159930,
  [SMALL_STATE(5176)] = 159941,
  [SMALL_STATE(5177)] = 159952,
  [SMALL_STATE(5178)] = 159963,
  [SMALL_STATE(5179)] = 159972,
  [SMALL_STATE(5180)] = 159983,
  [SMALL_STATE(5181)] = 159994,
  [SMALL_STATE(5182)] = 160005,
  [SMALL_STATE(5183)] = 160016,
  [SMALL_STATE(5184)] = 160027,
  [SMALL_STATE(5185)] = 160038,
  [SMALL_STATE(5186)] = 160049,
  [SMALL_STATE(5187)] = 160060,
  [SMALL_STATE(5188)] = 160071,
  [SMALL_STATE(5189)] = 160082,
  [SMALL_STATE(5190)] = 160093,
  [SMALL_STATE(5191)] = 160104,
  [SMALL_STATE(5192)] = 160115,
  [SMALL_STATE(5193)] = 160126,
  [SMALL_STATE(5194)] = 160135,
  [SMALL_STATE(5195)] = 160144,
  [SMALL_STATE(5196)] = 160153,
  [SMALL_STATE(5197)] = 160162,
  [SMALL_STATE(5198)] = 160173,
  [SMALL_STATE(5199)] = 160184,
  [SMALL_STATE(5200)] = 160193,
  [SMALL_STATE(5201)] = 160204,
  [SMALL_STATE(5202)] = 160215,
  [SMALL_STATE(5203)] = 160226,
  [SMALL_STATE(5204)] = 160237,
  [SMALL_STATE(5205)] = 160248,
  [SMALL_STATE(5206)] = 160259,
  [SMALL_STATE(5207)] = 160270,
  [SMALL_STATE(5208)] = 160279,
  [SMALL_STATE(5209)] = 160290,
  [SMALL_STATE(5210)] = 160301,
  [SMALL_STATE(5211)] = 160312,
  [SMALL_STATE(5212)] = 160323,
  [SMALL_STATE(5213)] = 160334,
  [SMALL_STATE(5214)] = 160345,
  [SMALL_STATE(5215)] = 160354,
  [SMALL_STATE(5216)] = 160365,
  [SMALL_STATE(5217)] = 160376,
  [SMALL_STATE(5218)] = 160387,
  [SMALL_STATE(5219)] = 160398,
  [SMALL_STATE(5220)] = 160409,
  [SMALL_STATE(5221)] = 160420,
  [SMALL_STATE(5222)] = 160429,
  [SMALL_STATE(5223)] = 160440,
  [SMALL_STATE(5224)] = 160451,
  [SMALL_STATE(5225)] = 160462,
  [SMALL_STATE(5226)] = 160471,
  [SMALL_STATE(5227)] = 160482,
  [SMALL_STATE(5228)] = 160493,
  [SMALL_STATE(5229)] = 160504,
  [SMALL_STATE(5230)] = 160515,
  [SMALL_STATE(5231)] = 160524,
  [SMALL_STATE(5232)] = 160535,
  [SMALL_STATE(5233)] = 160546,
  [SMALL_STATE(5234)] = 160557,
  [SMALL_STATE(5235)] = 160568,
  [SMALL_STATE(5236)] = 160579,
  [SMALL_STATE(5237)] = 160590,
  [SMALL_STATE(5238)] = 160601,
  [SMALL_STATE(5239)] = 160610,
  [SMALL_STATE(5240)] = 160621,
  [SMALL_STATE(5241)] = 160632,
  [SMALL_STATE(5242)] = 160643,
  [SMALL_STATE(5243)] = 160654,
  [SMALL_STATE(5244)] = 160665,
  [SMALL_STATE(5245)] = 160674,
  [SMALL_STATE(5246)] = 160683,
  [SMALL_STATE(5247)] = 160694,
  [SMALL_STATE(5248)] = 160705,
  [SMALL_STATE(5249)] = 160716,
  [SMALL_STATE(5250)] = 160727,
  [SMALL_STATE(5251)] = 160738,
  [SMALL_STATE(5252)] = 160749,
  [SMALL_STATE(5253)] = 160760,
  [SMALL_STATE(5254)] = 160771,
  [SMALL_STATE(5255)] = 160782,
  [SMALL_STATE(5256)] = 160793,
  [SMALL_STATE(5257)] = 160804,
  [SMALL_STATE(5258)] = 160815,
  [SMALL_STATE(5259)] = 160826,
  [SMALL_STATE(5260)] = 160835,
  [SMALL_STATE(5261)] = 160844,
  [SMALL_STATE(5262)] = 160855,
  [SMALL_STATE(5263)] = 160864,
  [SMALL_STATE(5264)] = 160873,
  [SMALL_STATE(5265)] = 160884,
  [SMALL_STATE(5266)] = 160895,
  [SMALL_STATE(5267)] = 160906,
  [SMALL_STATE(5268)] = 160917,
  [SMALL_STATE(5269)] = 160928,
  [SMALL_STATE(5270)] = 160939,
  [SMALL_STATE(5271)] = 160950,
  [SMALL_STATE(5272)] = 160961,
  [SMALL_STATE(5273)] = 160970,
  [SMALL_STATE(5274)] = 160981,
  [SMALL_STATE(5275)] = 160992,
  [SMALL_STATE(5276)] = 161003,
  [SMALL_STATE(5277)] = 161014,
  [SMALL_STATE(5278)] = 161023,
  [SMALL_STATE(5279)] = 161032,
  [SMALL_STATE(5280)] = 161043,
  [SMALL_STATE(5281)] = 161054,
  [SMALL_STATE(5282)] = 161065,
  [SMALL_STATE(5283)] = 161076,
  [SMALL_STATE(5284)] = 161087,
  [SMALL_STATE(5285)] = 161096,
  [SMALL_STATE(5286)] = 161105,
  [SMALL_STATE(5287)] = 161116,
  [SMALL_STATE(5288)] = 161127,
  [SMALL_STATE(5289)] = 161138,
  [SMALL_STATE(5290)] = 161149,
  [SMALL_STATE(5291)] = 161158,
  [SMALL_STATE(5292)] = 161169,
  [SMALL_STATE(5293)] = 161180,
  [SMALL_STATE(5294)] = 161191,
  [SMALL_STATE(5295)] = 161202,
  [SMALL_STATE(5296)] = 161213,
  [SMALL_STATE(5297)] = 161224,
  [SMALL_STATE(5298)] = 161233,
  [SMALL_STATE(5299)] = 161244,
  [SMALL_STATE(5300)] = 161255,
  [SMALL_STATE(5301)] = 161266,
  [SMALL_STATE(5302)] = 161277,
  [SMALL_STATE(5303)] = 161288,
  [SMALL_STATE(5304)] = 161299,
  [SMALL_STATE(5305)] = 161310,
  [SMALL_STATE(5306)] = 161319,
  [SMALL_STATE(5307)] = 161328,
  [SMALL_STATE(5308)] = 161337,
  [SMALL_STATE(5309)] = 161348,
  [SMALL_STATE(5310)] = 161357,
  [SMALL_STATE(5311)] = 161368,
  [SMALL_STATE(5312)] = 161379,
  [SMALL_STATE(5313)] = 161390,
  [SMALL_STATE(5314)] = 161399,
  [SMALL_STATE(5315)] = 161408,
  [SMALL_STATE(5316)] = 161419,
  [SMALL_STATE(5317)] = 161428,
  [SMALL_STATE(5318)] = 161439,
  [SMALL_STATE(5319)] = 161450,
  [SMALL_STATE(5320)] = 161459,
  [SMALL_STATE(5321)] = 161470,
  [SMALL_STATE(5322)] = 161481,
  [SMALL_STATE(5323)] = 161492,
  [SMALL_STATE(5324)] = 161503,
  [SMALL_STATE(5325)] = 161514,
  [SMALL_STATE(5326)] = 161525,
  [SMALL_STATE(5327)] = 161536,
  [SMALL_STATE(5328)] = 161547,
  [SMALL_STATE(5329)] = 161558,
  [SMALL_STATE(5330)] = 161567,
  [SMALL_STATE(5331)] = 161576,
  [SMALL_STATE(5332)] = 161585,
  [SMALL_STATE(5333)] = 161596,
  [SMALL_STATE(5334)] = 161605,
  [SMALL_STATE(5335)] = 161614,
  [SMALL_STATE(5336)] = 161625,
  [SMALL_STATE(5337)] = 161636,
  [SMALL_STATE(5338)] = 161647,
  [SMALL_STATE(5339)] = 161658,
  [SMALL_STATE(5340)] = 161669,
  [SMALL_STATE(5341)] = 161680,
  [SMALL_STATE(5342)] = 161691,
  [SMALL_STATE(5343)] = 161702,
  [SMALL_STATE(5344)] = 161713,
  [SMALL_STATE(5345)] = 161724,
  [SMALL_STATE(5346)] = 161733,
  [SMALL_STATE(5347)] = 161744,
  [SMALL_STATE(5348)] = 161755,
  [SMALL_STATE(5349)] = 161764,
  [SMALL_STATE(5350)] = 161775,
  [SMALL_STATE(5351)] = 161786,
  [SMALL_STATE(5352)] = 161797,
  [SMALL_STATE(5353)] = 161808,
  [SMALL_STATE(5354)] = 161819,
  [SMALL_STATE(5355)] = 161830,
  [SMALL_STATE(5356)] = 161839,
  [SMALL_STATE(5357)] = 161848,
  [SMALL_STATE(5358)] = 161859,
  [SMALL_STATE(5359)] = 161870,
  [SMALL_STATE(5360)] = 161879,
  [SMALL_STATE(5361)] = 161890,
  [SMALL_STATE(5362)] = 161901,
  [SMALL_STATE(5363)] = 161912,
  [SMALL_STATE(5364)] = 161923,
  [SMALL_STATE(5365)] = 161934,
  [SMALL_STATE(5366)] = 161945,
  [SMALL_STATE(5367)] = 161956,
  [SMALL_STATE(5368)] = 161967,
  [SMALL_STATE(5369)] = 161976,
  [SMALL_STATE(5370)] = 161987,
  [SMALL_STATE(5371)] = 161998,
  [SMALL_STATE(5372)] = 162009,
  [SMALL_STATE(5373)] = 162020,
  [SMALL_STATE(5374)] = 162031,
  [SMALL_STATE(5375)] = 162042,
  [SMALL_STATE(5376)] = 162053,
  [SMALL_STATE(5377)] = 162064,
  [SMALL_STATE(5378)] = 162075,
  [SMALL_STATE(5379)] = 162086,
  [SMALL_STATE(5380)] = 162095,
  [SMALL_STATE(5381)] = 162106,
  [SMALL_STATE(5382)] = 162117,
  [SMALL_STATE(5383)] = 162128,
  [SMALL_STATE(5384)] = 162137,
  [SMALL_STATE(5385)] = 162146,
  [SMALL_STATE(5386)] = 162155,
  [SMALL_STATE(5387)] = 162166,
  [SMALL_STATE(5388)] = 162177,
  [SMALL_STATE(5389)] = 162188,
  [SMALL_STATE(5390)] = 162197,
  [SMALL_STATE(5391)] = 162208,
  [SMALL_STATE(5392)] = 162219,
  [SMALL_STATE(5393)] = 162228,
  [SMALL_STATE(5394)] = 162239,
  [SMALL_STATE(5395)] = 162250,
  [SMALL_STATE(5396)] = 162261,
  [SMALL_STATE(5397)] = 162272,
  [SMALL_STATE(5398)] = 162283,
  [SMALL_STATE(5399)] = 162294,
  [SMALL_STATE(5400)] = 162305,
  [SMALL_STATE(5401)] = 162314,
  [SMALL_STATE(5402)] = 162325,
  [SMALL_STATE(5403)] = 162336,
  [SMALL_STATE(5404)] = 162347,
  [SMALL_STATE(5405)] = 162358,
  [SMALL_STATE(5406)] = 162369,
  [SMALL_STATE(5407)] = 162380,
  [SMALL_STATE(5408)] = 162391,
  [SMALL_STATE(5409)] = 162402,
  [SMALL_STATE(5410)] = 162413,
  [SMALL_STATE(5411)] = 162424,
  [SMALL_STATE(5412)] = 162435,
  [SMALL_STATE(5413)] = 162446,
  [SMALL_STATE(5414)] = 162455,
  [SMALL_STATE(5415)] = 162466,
  [SMALL_STATE(5416)] = 162477,
  [SMALL_STATE(5417)] = 162486,
  [SMALL_STATE(5418)] = 162495,
  [SMALL_STATE(5419)] = 162506,
  [SMALL_STATE(5420)] = 162515,
  [SMALL_STATE(5421)] = 162524,
  [SMALL_STATE(5422)] = 162535,
  [SMALL_STATE(5423)] = 162546,
  [SMALL_STATE(5424)] = 162557,
  [SMALL_STATE(5425)] = 162568,
  [SMALL_STATE(5426)] = 162579,
  [SMALL_STATE(5427)] = 162590,
  [SMALL_STATE(5428)] = 162601,
  [SMALL_STATE(5429)] = 162612,
  [SMALL_STATE(5430)] = 162623,
  [SMALL_STATE(5431)] = 162634,
  [SMALL_STATE(5432)] = 162645,
  [SMALL_STATE(5433)] = 162656,
  [SMALL_STATE(5434)] = 162665,
  [SMALL_STATE(5435)] = 162674,
  [SMALL_STATE(5436)] = 162685,
  [SMALL_STATE(5437)] = 162696,
  [SMALL_STATE(5438)] = 162705,
  [SMALL_STATE(5439)] = 162716,
  [SMALL_STATE(5440)] = 162727,
  [SMALL_STATE(5441)] = 162738,
  [SMALL_STATE(5442)] = 162747,
  [SMALL_STATE(5443)] = 162758,
  [SMALL_STATE(5444)] = 162769,
  [SMALL_STATE(5445)] = 162780,
  [SMALL_STATE(5446)] = 162791,
  [SMALL_STATE(5447)] = 162802,
  [SMALL_STATE(5448)] = 162813,
  [SMALL_STATE(5449)] = 162824,
  [SMALL_STATE(5450)] = 162835,
  [SMALL_STATE(5451)] = 162846,
  [SMALL_STATE(5452)] = 162857,
  [SMALL_STATE(5453)] = 162868,
  [SMALL_STATE(5454)] = 162879,
  [SMALL_STATE(5455)] = 162890,
  [SMALL_STATE(5456)] = 162901,
  [SMALL_STATE(5457)] = 162912,
  [SMALL_STATE(5458)] = 162923,
  [SMALL_STATE(5459)] = 162934,
  [SMALL_STATE(5460)] = 162945,
  [SMALL_STATE(5461)] = 162956,
  [SMALL_STATE(5462)] = 162967,
  [SMALL_STATE(5463)] = 162976,
  [SMALL_STATE(5464)] = 162985,
  [SMALL_STATE(5465)] = 162994,
  [SMALL_STATE(5466)] = 163003,
  [SMALL_STATE(5467)] = 163011,
  [SMALL_STATE(5468)] = 163019,
  [SMALL_STATE(5469)] = 163027,
  [SMALL_STATE(5470)] = 163035,
  [SMALL_STATE(5471)] = 163043,
  [SMALL_STATE(5472)] = 163051,
  [SMALL_STATE(5473)] = 163059,
  [SMALL_STATE(5474)] = 163067,
  [SMALL_STATE(5475)] = 163075,
  [SMALL_STATE(5476)] = 163083,
  [SMALL_STATE(5477)] = 163091,
  [SMALL_STATE(5478)] = 163099,
  [SMALL_STATE(5479)] = 163107,
  [SMALL_STATE(5480)] = 163115,
  [SMALL_STATE(5481)] = 163123,
  [SMALL_STATE(5482)] = 163131,
  [SMALL_STATE(5483)] = 163141,
  [SMALL_STATE(5484)] = 163149,
  [SMALL_STATE(5485)] = 163157,
  [SMALL_STATE(5486)] = 163165,
  [SMALL_STATE(5487)] = 163173,
  [SMALL_STATE(5488)] = 163181,
  [SMALL_STATE(5489)] = 163189,
  [SMALL_STATE(5490)] = 163197,
  [SMALL_STATE(5491)] = 163205,
  [SMALL_STATE(5492)] = 163213,
  [SMALL_STATE(5493)] = 163221,
  [SMALL_STATE(5494)] = 163229,
  [SMALL_STATE(5495)] = 163239,
  [SMALL_STATE(5496)] = 163247,
  [SMALL_STATE(5497)] = 163255,
  [SMALL_STATE(5498)] = 163263,
  [SMALL_STATE(5499)] = 163271,
  [SMALL_STATE(5500)] = 163279,
  [SMALL_STATE(5501)] = 163287,
  [SMALL_STATE(5502)] = 163295,
  [SMALL_STATE(5503)] = 163303,
  [SMALL_STATE(5504)] = 163311,
  [SMALL_STATE(5505)] = 163319,
  [SMALL_STATE(5506)] = 163327,
  [SMALL_STATE(5507)] = 163335,
  [SMALL_STATE(5508)] = 163343,
  [SMALL_STATE(5509)] = 163351,
  [SMALL_STATE(5510)] = 163359,
  [SMALL_STATE(5511)] = 163367,
  [SMALL_STATE(5512)] = 163375,
  [SMALL_STATE(5513)] = 163383,
  [SMALL_STATE(5514)] = 163391,
  [SMALL_STATE(5515)] = 163399,
  [SMALL_STATE(5516)] = 163407,
  [SMALL_STATE(5517)] = 163415,
  [SMALL_STATE(5518)] = 163423,
  [SMALL_STATE(5519)] = 163431,
  [SMALL_STATE(5520)] = 163439,
  [SMALL_STATE(5521)] = 163447,
  [SMALL_STATE(5522)] = 163455,
  [SMALL_STATE(5523)] = 163463,
  [SMALL_STATE(5524)] = 163471,
  [SMALL_STATE(5525)] = 163479,
  [SMALL_STATE(5526)] = 163487,
  [SMALL_STATE(5527)] = 163495,
  [SMALL_STATE(5528)] = 163503,
  [SMALL_STATE(5529)] = 163511,
  [SMALL_STATE(5530)] = 163519,
  [SMALL_STATE(5531)] = 163527,
  [SMALL_STATE(5532)] = 163535,
  [SMALL_STATE(5533)] = 163543,
  [SMALL_STATE(5534)] = 163551,
  [SMALL_STATE(5535)] = 163559,
  [SMALL_STATE(5536)] = 163567,
  [SMALL_STATE(5537)] = 163575,
  [SMALL_STATE(5538)] = 163583,
  [SMALL_STATE(5539)] = 163591,
  [SMALL_STATE(5540)] = 163599,
  [SMALL_STATE(5541)] = 163607,
  [SMALL_STATE(5542)] = 163615,
  [SMALL_STATE(5543)] = 163623,
  [SMALL_STATE(5544)] = 163631,
  [SMALL_STATE(5545)] = 163639,
  [SMALL_STATE(5546)] = 163647,
  [SMALL_STATE(5547)] = 163655,
  [SMALL_STATE(5548)] = 163663,
  [SMALL_STATE(5549)] = 163671,
  [SMALL_STATE(5550)] = 163679,
  [SMALL_STATE(5551)] = 163687,
  [SMALL_STATE(5552)] = 163695,
  [SMALL_STATE(5553)] = 163703,
  [SMALL_STATE(5554)] = 163713,
  [SMALL_STATE(5555)] = 163721,
  [SMALL_STATE(5556)] = 163729,
  [SMALL_STATE(5557)] = 163737,
  [SMALL_STATE(5558)] = 163745,
  [SMALL_STATE(5559)] = 163753,
  [SMALL_STATE(5560)] = 163761,
  [SMALL_STATE(5561)] = 163769,
  [SMALL_STATE(5562)] = 163777,
  [SMALL_STATE(5563)] = 163785,
  [SMALL_STATE(5564)] = 163793,
  [SMALL_STATE(5565)] = 163801,
  [SMALL_STATE(5566)] = 163809,
  [SMALL_STATE(5567)] = 163817,
  [SMALL_STATE(5568)] = 163825,
  [SMALL_STATE(5569)] = 163833,
  [SMALL_STATE(5570)] = 163841,
  [SMALL_STATE(5571)] = 163849,
  [SMALL_STATE(5572)] = 163857,
  [SMALL_STATE(5573)] = 163865,
  [SMALL_STATE(5574)] = 163873,
  [SMALL_STATE(5575)] = 163881,
  [SMALL_STATE(5576)] = 163889,
  [SMALL_STATE(5577)] = 163897,
  [SMALL_STATE(5578)] = 163905,
  [SMALL_STATE(5579)] = 163913,
  [SMALL_STATE(5580)] = 163921,
  [SMALL_STATE(5581)] = 163929,
  [SMALL_STATE(5582)] = 163937,
  [SMALL_STATE(5583)] = 163945,
  [SMALL_STATE(5584)] = 163953,
  [SMALL_STATE(5585)] = 163961,
  [SMALL_STATE(5586)] = 163969,
  [SMALL_STATE(5587)] = 163977,
  [SMALL_STATE(5588)] = 163985,
  [SMALL_STATE(5589)] = 163993,
  [SMALL_STATE(5590)] = 164001,
  [SMALL_STATE(5591)] = 164009,
  [SMALL_STATE(5592)] = 164017,
  [SMALL_STATE(5593)] = 164025,
  [SMALL_STATE(5594)] = 164033,
  [SMALL_STATE(5595)] = 164041,
  [SMALL_STATE(5596)] = 164049,
  [SMALL_STATE(5597)] = 164057,
  [SMALL_STATE(5598)] = 164065,
  [SMALL_STATE(5599)] = 164073,
  [SMALL_STATE(5600)] = 164081,
  [SMALL_STATE(5601)] = 164089,
  [SMALL_STATE(5602)] = 164097,
  [SMALL_STATE(5603)] = 164105,
  [SMALL_STATE(5604)] = 164113,
  [SMALL_STATE(5605)] = 164121,
  [SMALL_STATE(5606)] = 164129,
  [SMALL_STATE(5607)] = 164137,
  [SMALL_STATE(5608)] = 164145,
  [SMALL_STATE(5609)] = 164153,
  [SMALL_STATE(5610)] = 164161,
  [SMALL_STATE(5611)] = 164169,
  [SMALL_STATE(5612)] = 164177,
  [SMALL_STATE(5613)] = 164185,
  [SMALL_STATE(5614)] = 164193,
  [SMALL_STATE(5615)] = 164201,
  [SMALL_STATE(5616)] = 164209,
  [SMALL_STATE(5617)] = 164217,
  [SMALL_STATE(5618)] = 164225,
  [SMALL_STATE(5619)] = 164233,
  [SMALL_STATE(5620)] = 164241,
  [SMALL_STATE(5621)] = 164249,
  [SMALL_STATE(5622)] = 164257,
  [SMALL_STATE(5623)] = 164265,
  [SMALL_STATE(5624)] = 164273,
  [SMALL_STATE(5625)] = 164281,
  [SMALL_STATE(5626)] = 164289,
  [SMALL_STATE(5627)] = 164297,
  [SMALL_STATE(5628)] = 164307,
  [SMALL_STATE(5629)] = 164315,
  [SMALL_STATE(5630)] = 164323,
  [SMALL_STATE(5631)] = 164331,
  [SMALL_STATE(5632)] = 164339,
  [SMALL_STATE(5633)] = 164347,
  [SMALL_STATE(5634)] = 164355,
  [SMALL_STATE(5635)] = 164363,
  [SMALL_STATE(5636)] = 164371,
  [SMALL_STATE(5637)] = 164379,
  [SMALL_STATE(5638)] = 164387,
  [SMALL_STATE(5639)] = 164395,
  [SMALL_STATE(5640)] = 164403,
  [SMALL_STATE(5641)] = 164411,
  [SMALL_STATE(5642)] = 164419,
  [SMALL_STATE(5643)] = 164427,
  [SMALL_STATE(5644)] = 164435,
  [SMALL_STATE(5645)] = 164443,
  [SMALL_STATE(5646)] = 164451,
  [SMALL_STATE(5647)] = 164459,
  [SMALL_STATE(5648)] = 164467,
  [SMALL_STATE(5649)] = 164475,
  [SMALL_STATE(5650)] = 164485,
  [SMALL_STATE(5651)] = 164493,
  [SMALL_STATE(5652)] = 164501,
  [SMALL_STATE(5653)] = 164509,
  [SMALL_STATE(5654)] = 164517,
  [SMALL_STATE(5655)] = 164525,
  [SMALL_STATE(5656)] = 164535,
  [SMALL_STATE(5657)] = 164543,
  [SMALL_STATE(5658)] = 164551,
  [SMALL_STATE(5659)] = 164559,
  [SMALL_STATE(5660)] = 164567,
  [SMALL_STATE(5661)] = 164575,
  [SMALL_STATE(5662)] = 164583,
  [SMALL_STATE(5663)] = 164593,
  [SMALL_STATE(5664)] = 164601,
  [SMALL_STATE(5665)] = 164609,
  [SMALL_STATE(5666)] = 164617,
  [SMALL_STATE(5667)] = 164625,
  [SMALL_STATE(5668)] = 164633,
  [SMALL_STATE(5669)] = 164643,
  [SMALL_STATE(5670)] = 164651,
  [SMALL_STATE(5671)] = 164659,
  [SMALL_STATE(5672)] = 164667,
  [SMALL_STATE(5673)] = 164675,
  [SMALL_STATE(5674)] = 164683,
  [SMALL_STATE(5675)] = 164691,
  [SMALL_STATE(5676)] = 164699,
  [SMALL_STATE(5677)] = 164707,
  [SMALL_STATE(5678)] = 164715,
  [SMALL_STATE(5679)] = 164723,
  [SMALL_STATE(5680)] = 164731,
  [SMALL_STATE(5681)] = 164739,
  [SMALL_STATE(5682)] = 164747,
  [SMALL_STATE(5683)] = 164755,
  [SMALL_STATE(5684)] = 164765,
  [SMALL_STATE(5685)] = 164773,
  [SMALL_STATE(5686)] = 164781,
  [SMALL_STATE(5687)] = 164789,
  [SMALL_STATE(5688)] = 164797,
  [SMALL_STATE(5689)] = 164805,
  [SMALL_STATE(5690)] = 164813,
  [SMALL_STATE(5691)] = 164821,
  [SMALL_STATE(5692)] = 164829,
  [SMALL_STATE(5693)] = 164837,
  [SMALL_STATE(5694)] = 164845,
  [SMALL_STATE(5695)] = 164853,
  [SMALL_STATE(5696)] = 164861,
  [SMALL_STATE(5697)] = 164869,
  [SMALL_STATE(5698)] = 164877,
  [SMALL_STATE(5699)] = 164885,
  [SMALL_STATE(5700)] = 164893,
  [SMALL_STATE(5701)] = 164901,
  [SMALL_STATE(5702)] = 164909,
  [SMALL_STATE(5703)] = 164917,
  [SMALL_STATE(5704)] = 164925,
  [SMALL_STATE(5705)] = 164933,
  [SMALL_STATE(5706)] = 164941,
  [SMALL_STATE(5707)] = 164949,
  [SMALL_STATE(5708)] = 164957,
  [SMALL_STATE(5709)] = 164965,
  [SMALL_STATE(5710)] = 164973,
  [SMALL_STATE(5711)] = 164981,
  [SMALL_STATE(5712)] = 164989,
  [SMALL_STATE(5713)] = 164997,
  [SMALL_STATE(5714)] = 165005,
  [SMALL_STATE(5715)] = 165013,
  [SMALL_STATE(5716)] = 165021,
  [SMALL_STATE(5717)] = 165029,
  [SMALL_STATE(5718)] = 165037,
  [SMALL_STATE(5719)] = 165045,
  [SMALL_STATE(5720)] = 165053,
  [SMALL_STATE(5721)] = 165061,
  [SMALL_STATE(5722)] = 165069,
  [SMALL_STATE(5723)] = 165077,
  [SMALL_STATE(5724)] = 165085,
  [SMALL_STATE(5725)] = 165093,
  [SMALL_STATE(5726)] = 165101,
  [SMALL_STATE(5727)] = 165109,
  [SMALL_STATE(5728)] = 165117,
  [SMALL_STATE(5729)] = 165125,
  [SMALL_STATE(5730)] = 165133,
  [SMALL_STATE(5731)] = 165141,
  [SMALL_STATE(5732)] = 165149,
  [SMALL_STATE(5733)] = 165157,
  [SMALL_STATE(5734)] = 165165,
  [SMALL_STATE(5735)] = 165173,
  [SMALL_STATE(5736)] = 165181,
  [SMALL_STATE(5737)] = 165189,
  [SMALL_STATE(5738)] = 165197,
  [SMALL_STATE(5739)] = 165205,
  [SMALL_STATE(5740)] = 165213,
  [SMALL_STATE(5741)] = 165221,
  [SMALL_STATE(5742)] = 165229,
  [SMALL_STATE(5743)] = 165237,
  [SMALL_STATE(5744)] = 165245,
  [SMALL_STATE(5745)] = 165253,
  [SMALL_STATE(5746)] = 165261,
  [SMALL_STATE(5747)] = 165269,
  [SMALL_STATE(5748)] = 165277,
  [SMALL_STATE(5749)] = 165285,
  [SMALL_STATE(5750)] = 165293,
  [SMALL_STATE(5751)] = 165301,
  [SMALL_STATE(5752)] = 165309,
  [SMALL_STATE(5753)] = 165317,
  [SMALL_STATE(5754)] = 165325,
  [SMALL_STATE(5755)] = 165333,
  [SMALL_STATE(5756)] = 165341,
  [SMALL_STATE(5757)] = 165349,
  [SMALL_STATE(5758)] = 165357,
  [SMALL_STATE(5759)] = 165365,
  [SMALL_STATE(5760)] = 165373,
  [SMALL_STATE(5761)] = 165381,
  [SMALL_STATE(5762)] = 165389,
  [SMALL_STATE(5763)] = 165397,
  [SMALL_STATE(5764)] = 165405,
  [SMALL_STATE(5765)] = 165413,
  [SMALL_STATE(5766)] = 165421,
  [SMALL_STATE(5767)] = 165429,
  [SMALL_STATE(5768)] = 165437,
  [SMALL_STATE(5769)] = 165445,
  [SMALL_STATE(5770)] = 165453,
  [SMALL_STATE(5771)] = 165461,
  [SMALL_STATE(5772)] = 165469,
  [SMALL_STATE(5773)] = 165477,
  [SMALL_STATE(5774)] = 165485,
  [SMALL_STATE(5775)] = 165493,
  [SMALL_STATE(5776)] = 165501,
  [SMALL_STATE(5777)] = 165509,
  [SMALL_STATE(5778)] = 165517,
  [SMALL_STATE(5779)] = 165525,
  [SMALL_STATE(5780)] = 165533,
  [SMALL_STATE(5781)] = 165541,
  [SMALL_STATE(5782)] = 165549,
  [SMALL_STATE(5783)] = 165557,
  [SMALL_STATE(5784)] = 165565,
  [SMALL_STATE(5785)] = 165573,
  [SMALL_STATE(5786)] = 165581,
  [SMALL_STATE(5787)] = 165589,
  [SMALL_STATE(5788)] = 165597,
  [SMALL_STATE(5789)] = 165605,
  [SMALL_STATE(5790)] = 165613,
  [SMALL_STATE(5791)] = 165621,
  [SMALL_STATE(5792)] = 165629,
  [SMALL_STATE(5793)] = 165637,
  [SMALL_STATE(5794)] = 165645,
  [SMALL_STATE(5795)] = 165653,
  [SMALL_STATE(5796)] = 165661,
  [SMALL_STATE(5797)] = 165669,
  [SMALL_STATE(5798)] = 165677,
  [SMALL_STATE(5799)] = 165685,
  [SMALL_STATE(5800)] = 165693,
  [SMALL_STATE(5801)] = 165701,
  [SMALL_STATE(5802)] = 165711,
  [SMALL_STATE(5803)] = 165719,
  [SMALL_STATE(5804)] = 165727,
  [SMALL_STATE(5805)] = 165735,
  [SMALL_STATE(5806)] = 165743,
  [SMALL_STATE(5807)] = 165751,
  [SMALL_STATE(5808)] = 165759,
  [SMALL_STATE(5809)] = 165767,
  [SMALL_STATE(5810)] = 165775,
  [SMALL_STATE(5811)] = 165783,
  [SMALL_STATE(5812)] = 165791,
  [SMALL_STATE(5813)] = 165799,
  [SMALL_STATE(5814)] = 165807,
  [SMALL_STATE(5815)] = 165815,
  [SMALL_STATE(5816)] = 165823,
  [SMALL_STATE(5817)] = 165831,
  [SMALL_STATE(5818)] = 165839,
  [SMALL_STATE(5819)] = 165847,
  [SMALL_STATE(5820)] = 165855,
  [SMALL_STATE(5821)] = 165863,
  [SMALL_STATE(5822)] = 165871,
  [SMALL_STATE(5823)] = 165879,
  [SMALL_STATE(5824)] = 165887,
  [SMALL_STATE(5825)] = 165895,
  [SMALL_STATE(5826)] = 165903,
  [SMALL_STATE(5827)] = 165911,
  [SMALL_STATE(5828)] = 165919,
  [SMALL_STATE(5829)] = 165927,
  [SMALL_STATE(5830)] = 165935,
  [SMALL_STATE(5831)] = 165943,
  [SMALL_STATE(5832)] = 165951,
  [SMALL_STATE(5833)] = 165959,
  [SMALL_STATE(5834)] = 165967,
  [SMALL_STATE(5835)] = 165975,
  [SMALL_STATE(5836)] = 165983,
  [SMALL_STATE(5837)] = 165991,
  [SMALL_STATE(5838)] = 165999,
  [SMALL_STATE(5839)] = 166007,
  [SMALL_STATE(5840)] = 166015,
  [SMALL_STATE(5841)] = 166023,
  [SMALL_STATE(5842)] = 166031,
  [SMALL_STATE(5843)] = 166039,
  [SMALL_STATE(5844)] = 166047,
  [SMALL_STATE(5845)] = 166055,
  [SMALL_STATE(5846)] = 166063,
  [SMALL_STATE(5847)] = 166071,
  [SMALL_STATE(5848)] = 166079,
  [SMALL_STATE(5849)] = 166087,
  [SMALL_STATE(5850)] = 166095,
  [SMALL_STATE(5851)] = 166103,
  [SMALL_STATE(5852)] = 166111,
  [SMALL_STATE(5853)] = 166119,
  [SMALL_STATE(5854)] = 166127,
  [SMALL_STATE(5855)] = 166135,
  [SMALL_STATE(5856)] = 166143,
  [SMALL_STATE(5857)] = 166151,
  [SMALL_STATE(5858)] = 166159,
  [SMALL_STATE(5859)] = 166167,
  [SMALL_STATE(5860)] = 166175,
  [SMALL_STATE(5861)] = 166183,
  [SMALL_STATE(5862)] = 166191,
  [SMALL_STATE(5863)] = 166199,
  [SMALL_STATE(5864)] = 166207,
  [SMALL_STATE(5865)] = 166215,
  [SMALL_STATE(5866)] = 166223,
  [SMALL_STATE(5867)] = 166231,
  [SMALL_STATE(5868)] = 166239,
  [SMALL_STATE(5869)] = 166247,
};

static const TSParseActionEntry ts_parse_actions[] = {
  [0] = {.entry = {.count = 0, .reusable = false}},
  [1] = {.entry = {.count = 1, .reusable = false}}, RECOVER(),
  [3] = {.entry = {.count = 1, .reusable = false}}, SHIFT_EXTRA(),
  [5] = {.entry = {.count = 1, .reusable = true}}, SHIFT_EXTRA(),
  [7] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_program, 0, 0, 0),
  [9] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1342),
  [11] = {.entry = {.count = 1, .reusable = true}}, SHIFT(30),
  [13] = {.entry = {.count = 1, .reusable = false}}, SHIFT(696),
  [15] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1285),
  [17] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1190),
  [19] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4),
  [21] = {.entry = {.count = 1, .reusable = false}}, SHIFT(482),
  [23] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2921),
  [25] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5444),
  [27] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3692),
  [29] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1192),
  [31] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3469),
  [33] = {.entry = {.count = 1, .reusable = true}}, SHIFT(482),
  [35] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5445),
  [37] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5232),
  [39] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4687),
  [41] = {.entry = {.count = 1, .reusable = true}}, SHIFT(194),
  [43] = {.entry = {.count = 1, .reusable = true}}, SHIFT(810),
  [45] = {.entry = {.count = 1, .reusable = false}}, SHIFT(437),
  [47] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5211),
  [49] = {.entry = {.count = 1, .reusable = false}}, SHIFT(54),
  [51] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5270),
  [53] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5009),
  [55] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4984),
  [57] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5400),
  [59] = {.entry = {.count = 1, .reusable = false}}, SHIFT(297),
  [61] = {.entry = {.count = 1, .reusable = false}}, SHIFT(345),
  [63] = {.entry = {.count = 1, .reusable = false}}, SHIFT(164),
  [65] = {.entry = {.count = 1, .reusable = true}}, SHIFT(229),
  [67] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3290),
  [69] = {.entry = {.count = 1, .reusable = false}}, SHIFT(728),
  [71] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3693),
  [73] = {.entry = {.count = 1, .reusable = false}}, SHIFT(99),
  [75] = {.entry = {.count = 1, .reusable = false}}, SHIFT(486),
  [77] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5655),
  [79] = {.entry = {.count = 1, .reusable = true}}, SHIFT(981),
  [81] = {.entry = {.count = 1, .reusable = true}}, SHIFT(586),
  [83] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4404),
  [85] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4411),
  [87] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3861),
  [89] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2222),
  [91] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5634),
  [93] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2222),
  [95] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2267),
  [97] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4290),
  [99] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1326),
  [101] = {.entry = {.count = 1, .reusable = false}}, SHIFT(707),
  [103] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1191),
  [105] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5557),
  [107] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5602),
  [109] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5490),
  [111] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1275),
  [113] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1260),
  [115] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2970),
  [117] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_pattern, 1, -1, 1), SHIFT(639),
  [120] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_primary_expression, 1, 0, 1),
  [122] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1176),
  [124] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1157),
  [126] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_primary_expression, 1, 0, 1), REDUCE(sym_pattern, 1, -1, 1),
  [129] = {.entry = {.count = 1, .reusable = false}}, SHIFT(284),
  [131] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4421),
  [133] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3039),
  [135] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_primary_expression, 1, 0, 1), SHIFT(560),
  [138] = {.entry = {.count = 1, .reusable = true}}, SHIFT(81),
  [140] = {.entry = {.count = 1, .reusable = false}}, SHIFT(561),
  [142] = {.entry = {.count = 1, .reusable = false}}, SHIFT(172),
  [144] = {.entry = {.count = 1, .reusable = true}}, SHIFT(38),
  [146] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3316),
  [148] = {.entry = {.count = 1, .reusable = false}}, SHIFT(725),
  [150] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3600),
  [152] = {.entry = {.count = 1, .reusable = true}}, SHIFT(330),
  [154] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_primary_expression, 1, 0, 1),
  [156] = {.entry = {.count = 1, .reusable = false}}, SHIFT(98),
  [158] = {.entry = {.count = 1, .reusable = false}}, SHIFT(564),
  [160] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__augmented_assignment_lhs, 1, 0, 1),
  [162] = {.entry = {.count = 1, .reusable = true}}, SHIFT(443),
  [164] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1007),
  [166] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1008),
  [168] = {.entry = {.count = 1, .reusable = false}}, SHIFT(438),
  [170] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_primary_expression, 1, 0, 1), SHIFT(5668),
  [173] = {.entry = {.count = 1, .reusable = false}}, SHIFT(981),
  [175] = {.entry = {.count = 1, .reusable = true}}, SHIFT(560),
  [177] = {.entry = {.count = 1, .reusable = false}}, SHIFT(251),
  [179] = {.entry = {.count = 1, .reusable = false}}, SHIFT(560),
  [181] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_primary_expression, 1, 0, 1), SHIFT(483),
  [184] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4493),
  [186] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4496),
  [188] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3475),
  [190] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2213),
  [192] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5790),
  [194] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2027),
  [196] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1687),
  [198] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2213),
  [200] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2035),
  [202] = {.entry = {.count = 1, .reusable = false}}, SHIFT(176),
  [204] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1012),
  [206] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1286),
  [208] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5538),
  [210] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5818),
  [212] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1013),
  [214] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5471),
  [216] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2935),
  [218] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1380),
  [220] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_pattern, 1, -1, 1), SHIFT(540),
  [223] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_pattern, 1, -1, 1),
  [225] = {.entry = {.count = 1, .reusable = true}}, SHIFT(354),
  [227] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1216),
  [229] = {.entry = {.count = 1, .reusable = false}}, SHIFT(590),
  [231] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2861),
  [233] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1196),
  [235] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1174),
  [237] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1520),
  [239] = {.entry = {.count = 1, .reusable = true}}, SHIFT(206),
  [241] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1163),
  [243] = {.entry = {.count = 1, .reusable = true}}, SHIFT(237),
  [245] = {.entry = {.count = 1, .reusable = false}}, SHIFT(691),
  [247] = {.entry = {.count = 1, .reusable = false}}, SHIFT(73),
  [249] = {.entry = {.count = 1, .reusable = true}}, SHIFT(677),
  [251] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2202),
  [253] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4210),
  [255] = {.entry = {.count = 1, .reusable = false}}, SHIFT(699),
  [257] = {.entry = {.count = 1, .reusable = false}}, SHIFT(704),
  [259] = {.entry = {.count = 1, .reusable = false}}, SHIFT(702),
  [261] = {.entry = {.count = 1, .reusable = false}}, SHIFT(694),
  [263] = {.entry = {.count = 1, .reusable = false}}, SHIFT(716),
  [265] = {.entry = {.count = 1, .reusable = false}}, SHIFT(719),
  [267] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1173),
  [269] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1232),
  [271] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1885),
  [273] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1228),
  [275] = {.entry = {.count = 1, .reusable = false}}, SHIFT(440),
  [277] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1194),
  [279] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1164),
  [281] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1521),
  [283] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1169),
  [285] = {.entry = {.count = 1, .reusable = false}}, SHIFT(692),
  [287] = {.entry = {.count = 1, .reusable = false}}, SHIFT(72),
  [289] = {.entry = {.count = 1, .reusable = false}}, SHIFT(698),
  [291] = {.entry = {.count = 1, .reusable = false}}, SHIFT(703),
  [293] = {.entry = {.count = 1, .reusable = false}}, SHIFT(701),
  [295] = {.entry = {.count = 1, .reusable = false}}, SHIFT(693),
  [297] = {.entry = {.count = 1, .reusable = false}}, SHIFT(717),
  [299] = {.entry = {.count = 1, .reusable = false}}, SHIFT(718),
  [301] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1172),
  [303] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1233),
  [305] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1926),
  [307] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1227),
  [309] = {.entry = {.count = 1, .reusable = false}}, SHIFT(427),
  [311] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1193),
  [313] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1168),
  [315] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1165),
  [317] = {.entry = {.count = 1, .reusable = false}}, SHIFT(690),
  [319] = {.entry = {.count = 1, .reusable = false}}, SHIFT(74),
  [321] = {.entry = {.count = 1, .reusable = false}}, SHIFT(700),
  [323] = {.entry = {.count = 1, .reusable = false}}, SHIFT(705),
  [325] = {.entry = {.count = 1, .reusable = false}}, SHIFT(706),
  [327] = {.entry = {.count = 1, .reusable = false}}, SHIFT(695),
  [329] = {.entry = {.count = 1, .reusable = false}}, SHIFT(722),
  [331] = {.entry = {.count = 1, .reusable = false}}, SHIFT(723),
  [333] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1167),
  [335] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1215),
  [337] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_program_repeat1, 2, 0, 0),
  [339] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_program_repeat1, 2, 0, 0), SHIFT_REPEAT(1342),
  [342] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_program_repeat1, 2, 0, 0), SHIFT_REPEAT(696),
  [345] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_program_repeat1, 2, 0, 0),
  [347] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_program_repeat1, 2, 0, 0), SHIFT_REPEAT(1285),
  [350] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_program_repeat1, 2, 0, 0), SHIFT_REPEAT(1190),
  [353] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_program_repeat1, 2, 0, 0), SHIFT_REPEAT(4),
  [356] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_program_repeat1, 2, 0, 0), SHIFT_REPEAT(482),
  [359] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_program_repeat1, 2, 0, 0), SHIFT_REPEAT(2921),
  [362] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_program_repeat1, 2, 0, 0), SHIFT_REPEAT(5444),
  [365] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_program_repeat1, 2, 0, 0), SHIFT_REPEAT(3692),
  [368] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_program_repeat1, 2, 0, 0), SHIFT_REPEAT(1192),
  [371] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_program_repeat1, 2, 0, 0), SHIFT_REPEAT(3469),
  [374] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_program_repeat1, 2, 0, 0), SHIFT_REPEAT(482),
  [377] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_program_repeat1, 2, 0, 0), SHIFT_REPEAT(5445),
  [380] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_program_repeat1, 2, 0, 0), SHIFT_REPEAT(5232),
  [383] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_program_repeat1, 2, 0, 0), SHIFT_REPEAT(4687),
  [386] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_program_repeat1, 2, 0, 0), SHIFT_REPEAT(194),
  [389] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_program_repeat1, 2, 0, 0), SHIFT_REPEAT(810),
  [392] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_program_repeat1, 2, 0, 0), SHIFT_REPEAT(437),
  [395] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_program_repeat1, 2, 0, 0), SHIFT_REPEAT(5211),
  [398] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_program_repeat1, 2, 0, 0), SHIFT_REPEAT(54),
  [401] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_program_repeat1, 2, 0, 0), SHIFT_REPEAT(5270),
  [404] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_program_repeat1, 2, 0, 0), SHIFT_REPEAT(5009),
  [407] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_program_repeat1, 2, 0, 0), SHIFT_REPEAT(4984),
  [410] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_program_repeat1, 2, 0, 0), SHIFT_REPEAT(5400),
  [413] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_program_repeat1, 2, 0, 0), SHIFT_REPEAT(297),
  [416] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_program_repeat1, 2, 0, 0), SHIFT_REPEAT(345),
  [419] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_program_repeat1, 2, 0, 0), SHIFT_REPEAT(164),
  [422] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_program_repeat1, 2, 0, 0), SHIFT_REPEAT(229),
  [425] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_program_repeat1, 2, 0, 0), SHIFT_REPEAT(3290),
  [428] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_program_repeat1, 2, 0, 0), SHIFT_REPEAT(728),
  [431] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_program_repeat1, 2, 0, 0), SHIFT_REPEAT(3693),
  [434] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_program_repeat1, 2, 0, 0), SHIFT_REPEAT(99),
  [437] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_program_repeat1, 2, 0, 0), SHIFT_REPEAT(486),
  [440] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_program_repeat1, 2, 0, 0), SHIFT_REPEAT(5655),
  [443] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_program_repeat1, 2, 0, 0), SHIFT_REPEAT(981),
  [446] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_program_repeat1, 2, 0, 0), SHIFT_REPEAT(586),
  [449] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_program_repeat1, 2, 0, 0), SHIFT_REPEAT(4404),
  [452] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_program_repeat1, 2, 0, 0), SHIFT_REPEAT(4411),
  [455] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_program_repeat1, 2, 0, 0), SHIFT_REPEAT(3861),
  [458] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_program_repeat1, 2, 0, 0), SHIFT_REPEAT(2222),
  [461] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_program_repeat1, 2, 0, 0), SHIFT_REPEAT(5634),
  [464] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_program_repeat1, 2, 0, 0), SHIFT_REPEAT(2222),
  [467] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_program_repeat1, 2, 0, 0), SHIFT_REPEAT(2267),
  [470] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_program_repeat1, 2, 0, 0), SHIFT_REPEAT(4290),
  [473] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_program_repeat1, 2, 0, 0), SHIFT_REPEAT(1326),
  [476] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_program_repeat1, 2, 0, 0), SHIFT_REPEAT(707),
  [479] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_program_repeat1, 2, 0, 0), SHIFT_REPEAT(1191),
  [482] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_program_repeat1, 2, 0, 0), SHIFT_REPEAT(5557),
  [485] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_program_repeat1, 2, 0, 0), SHIFT_REPEAT(5602),
  [488] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_program_repeat1, 2, 0, 0), SHIFT_REPEAT(5490),
  [491] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_switch_case, 4, 0, 236),
  [493] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_switch_case, 4, 0, 236),
  [495] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_switch_case, 3, 0, 93),
  [497] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_switch_case, 3, 0, 93),
  [499] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_switch_default, 2, 0, 0),
  [501] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_switch_default, 2, 0, 0),
  [503] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_switch_default, 3, 0, 52),
  [505] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_switch_default, 3, 0, 52),
  [507] = {.entry = {.count = 1, .reusable = true}}, SHIFT(753),
  [509] = {.entry = {.count = 1, .reusable = true}}, SHIFT(754),
  [511] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_program, 1, 0, 0),
  [513] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_program, 2, 0, 0),
  [515] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1729),
  [517] = {.entry = {.count = 1, .reusable = true}}, SHIFT(212),
  [519] = {.entry = {.count = 1, .reusable = true}}, SHIFT(236),
  [521] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1724),
  [523] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1579),
  [525] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1534),
  [527] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2698),
  [529] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2697),
  [531] = {.entry = {.count = 1, .reusable = true}}, SHIFT(747),
  [533] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2648),
  [535] = {.entry = {.count = 1, .reusable = true}}, SHIFT(759),
  [537] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2681),
  [539] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1241),
  [541] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1371),
  [543] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2970),
  [545] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1210),
  [547] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1152),
  [549] = {.entry = {.count = 1, .reusable = true}}, SHIFT(249),
  [551] = {.entry = {.count = 1, .reusable = false}}, SHIFT(285),
  [553] = {.entry = {.count = 1, .reusable = true}}, SHIFT(509),
  [555] = {.entry = {.count = 1, .reusable = false}}, SHIFT(510),
  [557] = {.entry = {.count = 1, .reusable = false}}, SHIFT(163),
  [559] = {.entry = {.count = 1, .reusable = true}}, SHIFT(63),
  [561] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1950),
  [563] = {.entry = {.count = 1, .reusable = false}}, SHIFT(738),
  [565] = {.entry = {.count = 1, .reusable = false}}, SHIFT(119),
  [567] = {.entry = {.count = 1, .reusable = false}}, SHIFT(512),
  [569] = {.entry = {.count = 1, .reusable = true}}, SHIFT(156),
  [571] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1130),
  [573] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1131),
  [575] = {.entry = {.count = 1, .reusable = false}}, SHIFT(444),
  [577] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5668),
  [579] = {.entry = {.count = 1, .reusable = false}}, SHIFT(244),
  [581] = {.entry = {.count = 1, .reusable = false}}, SHIFT(509),
  [583] = {.entry = {.count = 1, .reusable = true}}, SHIFT(676),
  [585] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5507),
  [587] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2470),
  [589] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2175),
  [591] = {.entry = {.count = 1, .reusable = false}}, SHIFT(185),
  [593] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1133),
  [595] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1338),
  [597] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5865),
  [599] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5843),
  [601] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1134),
  [603] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1315),
  [605] = {.entry = {.count = 1, .reusable = false}}, SHIFT(697),
  [607] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1292),
  [609] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1184),
  [611] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7),
  [613] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5180),
  [615] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1182),
  [617] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5186),
  [619] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4663),
  [621] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5189),
  [623] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3297),
  [625] = {.entry = {.count = 1, .reusable = false}}, SHIFT(729),
  [627] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3642),
  [629] = {.entry = {.count = 1, .reusable = false}}, SHIFT(106),
  [631] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1316),
  [633] = {.entry = {.count = 1, .reusable = false}}, SHIFT(710),
  [635] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1183),
  [637] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2025),
  [639] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1796),
  [641] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1539),
  [643] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1936),
  [645] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1955),
  [647] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2113),
  [649] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2116),
  [651] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2442),
  [653] = {.entry = {.count = 1, .reusable = true}}, SHIFT(253),
  [655] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1863),
  [657] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1320),
  [659] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1308),
  [661] = {.entry = {.count = 1, .reusable = false}}, SHIFT(419),
  [663] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1181),
  [665] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1497),
  [667] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1726),
  [669] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4389),
  [671] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__property_name, 1, 0, 7), SHIFT(52),
  [674] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5648),
  [676] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3298),
  [678] = {.entry = {.count = 1, .reusable = false}}, SHIFT(730),
  [680] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3577),
  [682] = {.entry = {.count = 1, .reusable = true}}, SHIFT(361),
  [684] = {.entry = {.count = 1, .reusable = false}}, SHIFT(97),
  [686] = {.entry = {.count = 1, .reusable = true}}, SHIFT(483),
  [688] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1961),
  [690] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__property_name, 1, 0, 7),
  [692] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2064),
  [694] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1706),
  [696] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1265),
  [698] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1499),
  [700] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_primary_expression, 1, 0, 1), SHIFT(195),
  [703] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_primary_expression, 1, 0, 1), SHIFT(241),
  [706] = {.entry = {.count = 1, .reusable = false}}, SHIFT(87),
  [708] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_primary_expression, 1, 0, 1), SHIFT(981),
  [711] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_primary_expression, 1, 0, 1), SHIFT(3852),
  [714] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1687),
  [716] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2243),
  [718] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1787),
  [720] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_pattern, 1, -1, 1),
  [722] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1264),
  [724] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1319),
  [726] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1186),
  [728] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1151),
  [730] = {.entry = {.count = 1, .reusable = false}}, SHIFT(290),
  [732] = {.entry = {.count = 1, .reusable = true}}, SHIFT(424),
  [734] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4935),
  [736] = {.entry = {.count = 1, .reusable = false}}, SHIFT(425),
  [738] = {.entry = {.count = 1, .reusable = false}}, SHIFT(166),
  [740] = {.entry = {.count = 1, .reusable = true}}, SHIFT(31),
  [742] = {.entry = {.count = 1, .reusable = false}}, SHIFT(733),
  [744] = {.entry = {.count = 1, .reusable = false}}, SHIFT(101),
  [746] = {.entry = {.count = 1, .reusable = false}}, SHIFT(450),
  [748] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1007),
  [750] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1008),
  [752] = {.entry = {.count = 1, .reusable = false}}, SHIFT(478),
  [754] = {.entry = {.count = 1, .reusable = false}}, SHIFT(255),
  [756] = {.entry = {.count = 1, .reusable = false}}, SHIFT(424),
  [758] = {.entry = {.count = 1, .reusable = true}}, SHIFT(636),
  [760] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3473),
  [762] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2338),
  [764] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5774),
  [766] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2002),
  [768] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2338),
  [770] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2003),
  [772] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2),
  [774] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1012),
  [776] = {.entry = {.count = 1, .reusable = false}}, SHIFT(256),
  [778] = {.entry = {.count = 1, .reusable = false}}, SHIFT(257),
  [780] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1305),
  [782] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2331),
  [784] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2125),
  [786] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2127),
  [788] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2293),
  [790] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2294),
  [792] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2296),
  [794] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2034),
  [796] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3),
  [798] = {.entry = {.count = 1, .reusable = false}}, SHIFT(258),
  [800] = {.entry = {.count = 1, .reusable = false}}, SHIFT(259),
  [802] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1458),
  [804] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1427),
  [806] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1267),
  [808] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1503),
  [810] = {.entry = {.count = 1, .reusable = true}}, SHIFT(195),
  [812] = {.entry = {.count = 1, .reusable = true}}, SHIFT(215),
  [814] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5705),
  [816] = {.entry = {.count = 1, .reusable = false}}, SHIFT(777),
  [818] = {.entry = {.count = 1, .reusable = false}}, SHIFT(145),
  [820] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3852),
  [822] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1528),
  [824] = {.entry = {.count = 1, .reusable = false}}, SHIFT(540),
  [826] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_rest_pattern, 2, 0, 32),
  [828] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_rest_pattern, 2, 0, 32),
  [830] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1301),
  [832] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1299),
  [834] = {.entry = {.count = 1, .reusable = false}}, SHIFT(485),
  [836] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1178),
  [838] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1500),
  [840] = {.entry = {.count = 1, .reusable = true}}, SHIFT(234),
  [842] = {.entry = {.count = 1, .reusable = false}}, SHIFT(726),
  [844] = {.entry = {.count = 1, .reusable = true}}, SHIFT(337),
  [846] = {.entry = {.count = 1, .reusable = false}}, SHIFT(94),
  [848] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1360),
  [850] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1366),
  [852] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1211),
  [854] = {.entry = {.count = 1, .reusable = false}}, SHIFT(741),
  [856] = {.entry = {.count = 1, .reusable = false}}, SHIFT(113),
  [858] = {.entry = {.count = 1, .reusable = false}}, SHIFT(446),
  [860] = {.entry = {.count = 1, .reusable = true}}, SHIFT(52),
  [862] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1313),
  [864] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1337),
  [866] = {.entry = {.count = 1, .reusable = false}}, SHIFT(515),
  [868] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1188),
  [870] = {.entry = {.count = 1, .reusable = false}}, SHIFT(734),
  [872] = {.entry = {.count = 1, .reusable = true}}, SHIFT(346),
  [874] = {.entry = {.count = 1, .reusable = false}}, SHIFT(104),
  [876] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5482),
  [878] = {.entry = {.count = 1, .reusable = true}}, SHIFT(32),
  [880] = {.entry = {.count = 1, .reusable = false}}, SHIFT(639),
  [882] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1406),
  [884] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1415),
  [886] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_pattern, 1, -1, 1), SHIFT(621),
  [889] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1237),
  [891] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1125),
  [893] = {.entry = {.count = 1, .reusable = false}}, SHIFT(767),
  [895] = {.entry = {.count = 1, .reusable = true}}, SHIFT(376),
  [897] = {.entry = {.count = 1, .reusable = false}}, SHIFT(134),
  [899] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_primary_expression, 1, 0, 1), REDUCE(sym_rest_pattern, 2, 0, 32),
  [902] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_primary_expression, 1, 0, 1), SHIFT(322),
  [905] = {.entry = {.count = 1, .reusable = false}}, SHIFT(322),
  [907] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_pattern, 1, -1, 1), SHIFT(485),
  [910] = {.entry = {.count = 1, .reusable = false}}, SHIFT(621),
  [912] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1052),
  [914] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1400),
  [916] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1383),
  [918] = {.entry = {.count = 1, .reusable = false}}, SHIFT(454),
  [920] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1218),
  [922] = {.entry = {.count = 1, .reusable = false}}, SHIFT(748),
  [924] = {.entry = {.count = 1, .reusable = true}}, SHIFT(394),
  [926] = {.entry = {.count = 1, .reusable = false}}, SHIFT(118),
  [928] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1375),
  [930] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1353),
  [932] = {.entry = {.count = 1, .reusable = false}}, SHIFT(567),
  [934] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1209),
  [936] = {.entry = {.count = 1, .reusable = false}}, SHIFT(740),
  [938] = {.entry = {.count = 1, .reusable = true}}, SHIFT(363),
  [940] = {.entry = {.count = 1, .reusable = false}}, SHIFT(125),
  [942] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5494),
  [944] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1408),
  [946] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1418),
  [948] = {.entry = {.count = 1, .reusable = false}}, SHIFT(648),
  [950] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1240),
  [952] = {.entry = {.count = 1, .reusable = false}}, SHIFT(764),
  [954] = {.entry = {.count = 1, .reusable = true}}, SHIFT(382),
  [956] = {.entry = {.count = 1, .reusable = false}}, SHIFT(136),
  [958] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5627),
  [960] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1405),
  [962] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1412),
  [964] = {.entry = {.count = 1, .reusable = false}}, SHIFT(595),
  [966] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1236),
  [968] = {.entry = {.count = 1, .reusable = false}}, SHIFT(763),
  [970] = {.entry = {.count = 1, .reusable = true}}, SHIFT(370),
  [972] = {.entry = {.count = 1, .reusable = false}}, SHIFT(133),
  [974] = {.entry = {.count = 1, .reusable = false}}, SHIFT(665),
  [976] = {.entry = {.count = 1, .reusable = false}}, SHIFT(533),
  [978] = {.entry = {.count = 1, .reusable = false}}, SHIFT(556),
  [980] = {.entry = {.count = 1, .reusable = false}}, SHIFT(415),
  [982] = {.entry = {.count = 1, .reusable = false}}, SHIFT(583),
  [984] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1245),
  [986] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3264),
  [988] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1161),
  [990] = {.entry = {.count = 1, .reusable = false}}, SHIFT(275),
  [992] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3273),
  [994] = {.entry = {.count = 1, .reusable = true}}, SHIFT(76),
  [996] = {.entry = {.count = 1, .reusable = true}}, SHIFT(69),
  [998] = {.entry = {.count = 1, .reusable = false}}, SHIFT(122),
  [1000] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1027),
  [1002] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1028),
  [1004] = {.entry = {.count = 1, .reusable = false}}, SHIFT(449),
  [1006] = {.entry = {.count = 1, .reusable = false}}, SHIFT(242),
  [1008] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3479),
  [1010] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1956),
  [1012] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1958),
  [1014] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1956),
  [1016] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1801),
  [1018] = {.entry = {.count = 1, .reusable = false}}, SHIFT(182),
  [1020] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1030),
  [1022] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1262),
  [1024] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5789),
  [1026] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5830),
  [1028] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1031),
  [1030] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5833),
  [1032] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3193),
  [1034] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1394),
  [1036] = {.entry = {.count = 1, .reusable = false}}, SHIFT(612),
  [1038] = {.entry = {.count = 1, .reusable = false}}, SHIFT(640),
  [1040] = {.entry = {.count = 1, .reusable = false}}, SHIFT(505),
  [1042] = {.entry = {.count = 1, .reusable = false}}, SHIFT(434),
  [1044] = {.entry = {.count = 1, .reusable = false}}, SHIFT(476),
  [1046] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1309),
  [1048] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1304),
  [1050] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1177),
  [1052] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1158),
  [1054] = {.entry = {.count = 1, .reusable = false}}, SHIFT(294),
  [1056] = {.entry = {.count = 1, .reusable = true}}, SHIFT(68),
  [1058] = {.entry = {.count = 1, .reusable = false}}, SHIFT(727),
  [1060] = {.entry = {.count = 1, .reusable = false}}, SHIFT(93),
  [1062] = {.entry = {.count = 1, .reusable = false}}, SHIFT(535),
  [1064] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2564),
  [1066] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2460),
  [1068] = {.entry = {.count = 1, .reusable = false}}, SHIFT(173),
  [1070] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1378),
  [1072] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1340),
  [1074] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1404),
  [1076] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1239),
  [1078] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1153),
  [1080] = {.entry = {.count = 1, .reusable = false}}, SHIFT(276),
  [1082] = {.entry = {.count = 1, .reusable = true}}, SHIFT(668),
  [1084] = {.entry = {.count = 1, .reusable = false}}, SHIFT(669),
  [1086] = {.entry = {.count = 1, .reusable = false}}, SHIFT(170),
  [1088] = {.entry = {.count = 1, .reusable = true}}, SHIFT(56),
  [1090] = {.entry = {.count = 1, .reusable = false}}, SHIFT(766),
  [1092] = {.entry = {.count = 1, .reusable = false}}, SHIFT(126),
  [1094] = {.entry = {.count = 1, .reusable = false}}, SHIFT(670),
  [1096] = {.entry = {.count = 1, .reusable = false}}, SHIFT(678),
  [1098] = {.entry = {.count = 1, .reusable = false}}, SHIFT(272),
  [1100] = {.entry = {.count = 1, .reusable = false}}, SHIFT(668),
  [1102] = {.entry = {.count = 1, .reusable = true}}, SHIFT(538),
  [1104] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3484),
  [1106] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2226),
  [1108] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5528),
  [1110] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2176),
  [1112] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2226),
  [1114] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2523),
  [1116] = {.entry = {.count = 1, .reusable = false}}, SHIFT(192),
  [1118] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1373),
  [1120] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1357),
  [1122] = {.entry = {.count = 1, .reusable = false}}, SHIFT(282),
  [1124] = {.entry = {.count = 1, .reusable = false}}, SHIFT(139),
  [1126] = {.entry = {.count = 1, .reusable = false}}, SHIFT(441),
  [1128] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2571),
  [1130] = {.entry = {.count = 1, .reusable = false}}, SHIFT(193),
  [1132] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1393),
  [1134] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1238),
  [1136] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1160),
  [1138] = {.entry = {.count = 1, .reusable = false}}, SHIFT(281),
  [1140] = {.entry = {.count = 1, .reusable = true}}, SHIFT(53),
  [1142] = {.entry = {.count = 1, .reusable = false}}, SHIFT(511),
  [1144] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3476),
  [1146] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1707),
  [1148] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1670),
  [1150] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1707),
  [1152] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1867),
  [1154] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1276),
  [1156] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1289),
  [1158] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1368),
  [1160] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1208),
  [1162] = {.entry = {.count = 1, .reusable = false}}, SHIFT(283),
  [1164] = {.entry = {.count = 1, .reusable = false}}, SHIFT(739),
  [1166] = {.entry = {.count = 1, .reusable = false}}, SHIFT(107),
  [1168] = {.entry = {.count = 1, .reusable = false}}, SHIFT(430),
  [1170] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2278),
  [1172] = {.entry = {.count = 1, .reusable = false}}, SHIFT(177),
  [1174] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1306),
  [1176] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1336),
  [1178] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1416),
  [1180] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1234),
  [1182] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1159),
  [1184] = {.entry = {.count = 1, .reusable = false}}, SHIFT(292),
  [1186] = {.entry = {.count = 1, .reusable = true}}, SHIFT(644),
  [1188] = {.entry = {.count = 1, .reusable = false}}, SHIFT(645),
  [1190] = {.entry = {.count = 1, .reusable = false}}, SHIFT(171),
  [1192] = {.entry = {.count = 1, .reusable = false}}, SHIFT(762),
  [1194] = {.entry = {.count = 1, .reusable = false}}, SHIFT(128),
  [1196] = {.entry = {.count = 1, .reusable = false}}, SHIFT(646),
  [1198] = {.entry = {.count = 1, .reusable = false}}, SHIFT(617),
  [1200] = {.entry = {.count = 1, .reusable = false}}, SHIFT(260),
  [1202] = {.entry = {.count = 1, .reusable = false}}, SHIFT(644),
  [1204] = {.entry = {.count = 1, .reusable = true}}, SHIFT(684),
  [1206] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5476),
  [1208] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2521),
  [1210] = {.entry = {.count = 1, .reusable = false}}, SHIFT(191),
  [1212] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1370),
  [1214] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1279),
  [1216] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1341),
  [1218] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1185),
  [1220] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1156),
  [1222] = {.entry = {.count = 1, .reusable = false}}, SHIFT(731),
  [1224] = {.entry = {.count = 1, .reusable = false}}, SHIFT(112),
  [1226] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2264),
  [1228] = {.entry = {.count = 1, .reusable = false}}, SHIFT(178),
  [1230] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1333),
  [1232] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1323),
  [1234] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1417),
  [1236] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1235),
  [1238] = {.entry = {.count = 1, .reusable = false}}, SHIFT(295),
  [1240] = {.entry = {.count = 1, .reusable = true}}, SHIFT(615),
  [1242] = {.entry = {.count = 1, .reusable = false}}, SHIFT(616),
  [1244] = {.entry = {.count = 1, .reusable = false}}, SHIFT(169),
  [1246] = {.entry = {.count = 1, .reusable = false}}, SHIFT(761),
  [1248] = {.entry = {.count = 1, .reusable = false}}, SHIFT(132),
  [1250] = {.entry = {.count = 1, .reusable = false}}, SHIFT(618),
  [1252] = {.entry = {.count = 1, .reusable = false}}, SHIFT(591),
  [1254] = {.entry = {.count = 1, .reusable = false}}, SHIFT(274),
  [1256] = {.entry = {.count = 1, .reusable = false}}, SHIFT(615),
  [1258] = {.entry = {.count = 1, .reusable = true}}, SHIFT(683),
  [1260] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5752),
  [1262] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2456),
  [1264] = {.entry = {.count = 1, .reusable = false}}, SHIFT(190),
  [1266] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1361),
  [1268] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1294),
  [1270] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1385),
  [1272] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1220),
  [1274] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1155),
  [1276] = {.entry = {.count = 1, .reusable = false}}, SHIFT(291),
  [1278] = {.entry = {.count = 1, .reusable = true}}, SHIFT(673),
  [1280] = {.entry = {.count = 1, .reusable = true}}, SHIFT(77),
  [1282] = {.entry = {.count = 1, .reusable = false}}, SHIFT(674),
  [1284] = {.entry = {.count = 1, .reusable = false}}, SHIFT(168),
  [1286] = {.entry = {.count = 1, .reusable = true}}, SHIFT(67),
  [1288] = {.entry = {.count = 1, .reusable = false}}, SHIFT(743),
  [1290] = {.entry = {.count = 1, .reusable = false}}, SHIFT(116),
  [1292] = {.entry = {.count = 1, .reusable = false}}, SHIFT(685),
  [1294] = {.entry = {.count = 1, .reusable = false}}, SHIFT(507),
  [1296] = {.entry = {.count = 1, .reusable = false}}, SHIFT(263),
  [1298] = {.entry = {.count = 1, .reusable = false}}, SHIFT(673),
  [1300] = {.entry = {.count = 1, .reusable = true}}, SHIFT(675),
  [1302] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3478),
  [1304] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2476),
  [1306] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5574),
  [1308] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2477),
  [1310] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2476),
  [1312] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2256),
  [1314] = {.entry = {.count = 1, .reusable = false}}, SHIFT(183),
  [1316] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1328),
  [1318] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1280),
  [1320] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1409),
  [1322] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1242),
  [1324] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1154),
  [1326] = {.entry = {.count = 1, .reusable = false}}, SHIFT(286),
  [1328] = {.entry = {.count = 1, .reusable = true}}, SHIFT(66),
  [1330] = {.entry = {.count = 1, .reusable = false}}, SHIFT(768),
  [1332] = {.entry = {.count = 1, .reusable = false}}, SHIFT(129),
  [1334] = {.entry = {.count = 1, .reusable = false}}, SHIFT(445),
  [1336] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3477),
  [1338] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2567),
  [1340] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2557),
  [1342] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2567),
  [1344] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2236),
  [1346] = {.entry = {.count = 1, .reusable = false}}, SHIFT(189),
  [1348] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1318),
  [1350] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1256),
  [1352] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1307),
  [1354] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1189),
  [1356] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1162),
  [1358] = {.entry = {.count = 1, .reusable = false}}, SHIFT(277),
  [1360] = {.entry = {.count = 1, .reusable = true}}, SHIFT(40),
  [1362] = {.entry = {.count = 1, .reusable = false}}, SHIFT(735),
  [1364] = {.entry = {.count = 1, .reusable = false}}, SHIFT(100),
  [1366] = {.entry = {.count = 1, .reusable = false}}, SHIFT(418),
  [1368] = {.entry = {.count = 1, .reusable = false}}, SHIFT(261),
  [1370] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3501),
  [1372] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1980),
  [1374] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1920),
  [1376] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1980),
  [1378] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1921),
  [1380] = {.entry = {.count = 1, .reusable = false}}, SHIFT(175),
  [1382] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1303),
  [1384] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1270),
  [1386] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1312),
  [1388] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1187),
  [1390] = {.entry = {.count = 1, .reusable = false}}, SHIFT(293),
  [1392] = {.entry = {.count = 1, .reusable = true}}, SHIFT(679),
  [1394] = {.entry = {.count = 1, .reusable = false}}, SHIFT(680),
  [1396] = {.entry = {.count = 1, .reusable = false}}, SHIFT(165),
  [1398] = {.entry = {.count = 1, .reusable = false}}, SHIFT(732),
  [1400] = {.entry = {.count = 1, .reusable = false}}, SHIFT(105),
  [1402] = {.entry = {.count = 1, .reusable = false}}, SHIFT(687),
  [1404] = {.entry = {.count = 1, .reusable = false}}, SHIFT(558),
  [1406] = {.entry = {.count = 1, .reusable = false}}, SHIFT(262),
  [1408] = {.entry = {.count = 1, .reusable = false}}, SHIFT(679),
  [1410] = {.entry = {.count = 1, .reusable = true}}, SHIFT(451),
  [1412] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5768),
  [1414] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2046),
  [1416] = {.entry = {.count = 1, .reusable = false}}, SHIFT(174),
  [1418] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1300),
  [1420] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1302),
  [1422] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1355),
  [1424] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1201),
  [1426] = {.entry = {.count = 1, .reusable = false}}, SHIFT(296),
  [1428] = {.entry = {.count = 1, .reusable = true}}, SHIFT(588),
  [1430] = {.entry = {.count = 1, .reusable = false}}, SHIFT(589),
  [1432] = {.entry = {.count = 1, .reusable = false}}, SHIFT(167),
  [1434] = {.entry = {.count = 1, .reusable = false}}, SHIFT(737),
  [1436] = {.entry = {.count = 1, .reusable = false}}, SHIFT(121),
  [1438] = {.entry = {.count = 1, .reusable = false}}, SHIFT(592),
  [1440] = {.entry = {.count = 1, .reusable = false}}, SHIFT(563),
  [1442] = {.entry = {.count = 1, .reusable = false}}, SHIFT(270),
  [1444] = {.entry = {.count = 1, .reusable = false}}, SHIFT(588),
  [1446] = {.entry = {.count = 1, .reusable = true}}, SHIFT(681),
  [1448] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5582),
  [1450] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2299),
  [1452] = {.entry = {.count = 1, .reusable = false}}, SHIFT(187),
  [1454] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1343),
  [1456] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1277),
  [1458] = {.entry = {.count = 1, .reusable = false}}, SHIFT(487),
  [1460] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_yield_expression, 1, 0, 0),
  [1462] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_yield_expression, 1, 0, 0),
  [1464] = {.entry = {.count = 1, .reusable = false}}, SHIFT(95),
  [1466] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1907),
  [1468] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1324),
  [1470] = {.entry = {.count = 1, .reusable = false}}, SHIFT(585),
  [1472] = {.entry = {.count = 1, .reusable = false}}, SHIFT(102),
  [1474] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1329),
  [1476] = {.entry = {.count = 1, .reusable = false}}, SHIFT(516),
  [1478] = {.entry = {.count = 1, .reusable = false}}, SHIFT(103),
  [1480] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2356),
  [1482] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1349),
  [1484] = {.entry = {.count = 1, .reusable = false}}, SHIFT(682),
  [1486] = {.entry = {.count = 1, .reusable = false}}, SHIFT(108),
  [1488] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2472),
  [1490] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1374),
  [1492] = {.entry = {.count = 1, .reusable = false}}, SHIFT(568),
  [1494] = {.entry = {.count = 1, .reusable = false}}, SHIFT(124),
  [1496] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2522),
  [1498] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1384),
  [1500] = {.entry = {.count = 1, .reusable = false}}, SHIFT(455),
  [1502] = {.entry = {.count = 1, .reusable = false}}, SHIFT(120),
  [1504] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2599),
  [1506] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1402),
  [1508] = {.entry = {.count = 1, .reusable = false}}, SHIFT(596),
  [1510] = {.entry = {.count = 1, .reusable = false}}, SHIFT(130),
  [1512] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2642),
  [1514] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1407),
  [1516] = {.entry = {.count = 1, .reusable = false}}, SHIFT(649),
  [1518] = {.entry = {.count = 1, .reusable = false}}, SHIFT(135),
  [1520] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2646),
  [1522] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1403),
  [1524] = {.entry = {.count = 1, .reusable = false}}, SHIFT(622),
  [1526] = {.entry = {.count = 1, .reusable = false}}, SHIFT(131),
  [1528] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2643),
  [1530] = {.entry = {.count = 1, .reusable = false}}, SHIFT(541),
  [1532] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2923),
  [1534] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1380),
  [1536] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3481),
  [1538] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4695),
  [1540] = {.entry = {.count = 1, .reusable = true}}, SHIFT(91),
  [1542] = {.entry = {.count = 1, .reusable = true}}, SHIFT(805),
  [1544] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4413),
  [1546] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5496),
  [1548] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4996),
  [1550] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4453),
  [1552] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4380),
  [1554] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4218),
  [1556] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2994),
  [1558] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3024),
  [1560] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2994),
  [1562] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1011),
  [1564] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1351),
  [1566] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4373),
  [1568] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3579),
  [1570] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1222),
  [1572] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3480),
  [1574] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3300),
  [1576] = {.entry = {.count = 1, .reusable = false}}, SHIFT(749),
  [1578] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3719),
  [1580] = {.entry = {.count = 1, .reusable = false}}, SHIFT(720),
  [1582] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1224),
  [1584] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5576),
  [1586] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5733),
  [1588] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5734),
  [1590] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1359),
  [1592] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1230),
  [1594] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4145),
  [1596] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1221),
  [1598] = {.entry = {.count = 1, .reusable = false}}, SHIFT(750),
  [1600] = {.entry = {.count = 1, .reusable = false}}, SHIFT(721),
  [1602] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1226),
  [1604] = {.entry = {.count = 1, .reusable = false}}, SHIFT(752),
  [1606] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3077),
  [1608] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3264),
  [1610] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1394),
  [1612] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3474),
  [1614] = {.entry = {.count = 1, .reusable = true}}, SHIFT(92),
  [1616] = {.entry = {.count = 1, .reusable = true}}, SHIFT(784),
  [1618] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4430),
  [1620] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1027),
  [1622] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1028),
  [1624] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5824),
  [1626] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4393),
  [1628] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4396),
  [1630] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4046),
  [1632] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3265),
  [1634] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3266),
  [1636] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3265),
  [1638] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1029),
  [1640] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1030),
  [1642] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4504),
  [1644] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1130),
  [1646] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1131),
  [1648] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1132),
  [1650] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1133),
  [1652] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1314),
  [1654] = {.entry = {.count = 1, .reusable = false}}, SHIFT(96),
  [1656] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2314),
  [1658] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2316),
  [1660] = {.entry = {.count = 1, .reusable = false}}, SHIFT(75),
  [1662] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4814),
  [1664] = {.entry = {.count = 1, .reusable = true}}, SHIFT(241),
  [1666] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2349),
  [1668] = {.entry = {.count = 1, .reusable = false}}, SHIFT(82),
  [1670] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3762),
  [1672] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3668),
  [1674] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__module, 1, 0, 5),
  [1676] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__module, 1, 0, 5),
  [1678] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19),
  [1680] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5621),
  [1682] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5485),
  [1684] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3881),
  [1686] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5125),
  [1688] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3805),
  [1690] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_statement_block, 2, 0, 0),
  [1692] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_statement_block, 2, 0, 0),
  [1694] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_object, 2, 0, 0),
  [1696] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_object_pattern, 2, 0, 0),
  [1698] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_object, 2, 0, 0),
  [1700] = {.entry = {.count = 1, .reusable = true}}, SHIFT(755),
  [1702] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3547),
  [1704] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3559),
  [1706] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_declaration, 4, 0, 148),
  [1708] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_declaration, 4, 0, 148),
  [1710] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class, 4, 0, 148),
  [1712] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class, 4, 0, 148),
  [1714] = {.entry = {.count = 1, .reusable = true}}, SHIFT(908),
  [1716] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_statement_block, 4, 0, 0),
  [1718] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_statement_block, 4, 0, 0),
  [1720] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_body, 3, 0, 110),
  [1722] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_body, 3, 0, 110),
  [1724] = {.entry = {.count = 1, .reusable = true}}, SHIFT(235),
  [1726] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_string, 2, 0, 0),
  [1728] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_string, 2, 0, 0),
  [1730] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declaration, 1, 0, 0),
  [1732] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_declaration, 1, 0, 0),
  [1734] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_expression, 1, 0, 0),
  [1736] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_expression, 1, 0, 0),
  [1738] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1376),
  [1740] = {.entry = {.count = 1, .reusable = true}}, SHIFT(250),
  [1742] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1723),
  [1744] = {.entry = {.count = 1, .reusable = false}}, SHIFT(114),
  [1746] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2449),
  [1748] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2558),
  [1750] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__module, 2, 0, 29),
  [1752] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__module, 2, 0, 29),
  [1754] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_string, 3, 0, 0),
  [1756] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_string, 3, 0, 0),
  [1758] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_declaration, 5, 0, 167),
  [1760] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_declaration, 5, 0, 167),
  [1762] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class, 5, 0, 167),
  [1764] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class, 5, 0, 167),
  [1766] = {.entry = {.count = 1, .reusable = true}}, SHIFT(880),
  [1768] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2432),
  [1770] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_declaration, 5, 0, 171),
  [1772] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_declaration, 5, 0, 171),
  [1774] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_expression, 5, 0, 171),
  [1776] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_expression, 5, 0, 171),
  [1778] = {.entry = {.count = 1, .reusable = true}}, SHIFT(883),
  [1780] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_generator_function_declaration, 5, 0, 171),
  [1782] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_generator_function_declaration, 5, 0, 171),
  [1784] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_generator_function, 5, 0, 171),
  [1786] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_generator_function, 5, 0, 171),
  [1788] = {.entry = {.count = 1, .reusable = true}}, SHIFT(885),
  [1790] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_declaration, 4, 0, 111),
  [1792] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_declaration, 4, 0, 111),
  [1794] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class, 4, 0, 111),
  [1796] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class, 4, 0, 111),
  [1798] = {.entry = {.count = 1, .reusable = true}}, SHIFT(861),
  [1800] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_declaration, 4, 0, 112),
  [1802] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_declaration, 4, 0, 112),
  [1804] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class, 4, 0, 112),
  [1806] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class, 4, 0, 112),
  [1808] = {.entry = {.count = 1, .reusable = true}}, SHIFT(871),
  [1810] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_declaration, 4, 0, 121),
  [1812] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_declaration, 4, 0, 121),
  [1814] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_expression, 4, 0, 121),
  [1816] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_expression, 4, 0, 121),
  [1818] = {.entry = {.count = 1, .reusable = true}}, SHIFT(910),
  [1820] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_declaration, 5, 0, 189),
  [1822] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_declaration, 5, 0, 189),
  [1824] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class, 5, 0, 189),
  [1826] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class, 5, 0, 189),
  [1828] = {.entry = {.count = 1, .reusable = true}}, SHIFT(864),
  [1830] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_declaration, 5, 0, 190),
  [1832] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_declaration, 5, 0, 190),
  [1834] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class, 5, 0, 190),
  [1836] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class, 5, 0, 190),
  [1838] = {.entry = {.count = 1, .reusable = true}}, SHIFT(840),
  [1840] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1928),
  [1842] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_declaration, 3, 0, 49),
  [1844] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_declaration, 3, 0, 49),
  [1846] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class, 3, 0, 49),
  [1848] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class, 3, 0, 49),
  [1850] = {.entry = {.count = 1, .reusable = true}}, SHIFT(847),
  [1852] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_internal_module, 2, 0, 6),
  [1854] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_internal_module, 2, 0, 6),
  [1856] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_generator_function_declaration, 6, 0, 217),
  [1858] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_generator_function_declaration, 6, 0, 217),
  [1860] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_generator_function, 6, 0, 217),
  [1862] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_generator_function, 6, 0, 217),
  [1864] = {.entry = {.count = 1, .reusable = true}}, SHIFT(859),
  [1866] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_declaration, 6, 0, 231),
  [1868] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_declaration, 6, 0, 231),
  [1870] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class, 6, 0, 231),
  [1872] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class, 6, 0, 231),
  [1874] = {.entry = {.count = 1, .reusable = true}}, SHIFT(895),
  [1876] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1705),
  [1878] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_statement_block, 3, 0, 0),
  [1880] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_statement_block, 3, 0, 0),
  [1882] = {.entry = {.count = 1, .reusable = true}}, SHIFT(210),
  [1884] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_body, 2, 0, 0),
  [1886] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_body, 2, 0, 0),
  [1888] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_nested_identifier, 3, 0, 75),
  [1890] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_nested_identifier, 3, 0, 75),
  [1892] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_nested_identifier, 3, 0, 88),
  [1894] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_nested_identifier, 3, 0, 88),
  [1896] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1793),
  [1898] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_predefined_type, 1, 0, 0),
  [1900] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_predefined_type, 1, 0, 0),
  [1902] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1372),
  [1904] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1377),
  [1906] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1195),
  [1908] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1498),
  [1910] = {.entry = {.count = 1, .reusable = true}}, SHIFT(254),
  [1912] = {.entry = {.count = 1, .reusable = true}}, SHIFT(216),
  [1914] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4341),
  [1916] = {.entry = {.count = 1, .reusable = false}}, SHIFT(736),
  [1918] = {.entry = {.count = 1, .reusable = false}}, SHIFT(109),
  [1920] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2562),
  [1922] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3687),
  [1924] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1356),
  [1926] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1365),
  [1928] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1203),
  [1930] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1502),
  [1932] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3715),
  [1934] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1204),
  [1936] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3699),
  [1938] = {.entry = {.count = 1, .reusable = true}}, SHIFT(221),
  [1940] = {.entry = {.count = 1, .reusable = false}}, SHIFT(742),
  [1942] = {.entry = {.count = 1, .reusable = false}}, SHIFT(111),
  [1944] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2433),
  [1946] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1391),
  [1948] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1390),
  [1950] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1229),
  [1952] = {.entry = {.count = 1, .reusable = false}}, SHIFT(751),
  [1954] = {.entry = {.count = 1, .reusable = false}}, SHIFT(123),
  [1956] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_array_repeat1, 1, 0, 0), REDUCE(aux_sym_array_pattern_repeat1, 1, 0, 0),
  [1959] = {.entry = {.count = 3, .reusable = true}}, REDUCE(aux_sym_array_repeat1, 1, 0, 0), REDUCE(aux_sym_array_pattern_repeat1, 1, 0, 0), SHIFT(3001),
  [1963] = {.entry = {.count = 3, .reusable = true}}, REDUCE(aux_sym_array_repeat1, 1, 0, 0), REDUCE(aux_sym_array_pattern_repeat1, 1, 0, 0), SHIFT(3260),
  [1967] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_array_pattern_repeat1, 1, 0, 0),
  [1969] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_accessibility_modifier, 1, 0, 0),
  [1971] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_accessibility_modifier, 1, 0, 0),
  [1973] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_override_modifier, 1, 0, 0),
  [1975] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_override_modifier, 1, 0, 0),
  [1977] = {.entry = {.count = 1, .reusable = true}}, SHIFT(289),
  [1979] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3088),
  [1981] = {.entry = {.count = 1, .reusable = true}}, SHIFT(442),
  [1983] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1513),
  [1985] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3223),
  [1987] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3307),
  [1989] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2261),
  [1991] = {.entry = {.count = 1, .reusable = false}}, SHIFT(80),
  [1993] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3506),
  [1995] = {.entry = {.count = 1, .reusable = true}}, SHIFT(988),
  [1997] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1795),
  [1999] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2561),
  [2001] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1231),
  [2003] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1935),
  [2005] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1283),
  [2007] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1535),
  [2009] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1244),
  [2011] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1979),
  [2013] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2128),
  [2015] = {.entry = {.count = 1, .reusable = false}}, SHIFT(84),
  [2017] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_array_repeat1, 1, 0, 0),
  [2019] = {.entry = {.count = 1, .reusable = true}}, SHIFT(480),
  [2021] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1223),
  [2023] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1346),
  [2025] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1258),
  [2027] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1327),
  [2029] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2229),
  [2031] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1263),
  [2033] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2462),
  [2035] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1293),
  [2037] = {.entry = {.count = 1, .reusable = false}}, SHIFT(79),
  [2039] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1261),
  [2041] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1249),
  [2043] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1296),
  [2045] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1247),
  [2047] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1298),
  [2049] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1281),
  [2051] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1254),
  [2053] = {.entry = {.count = 1, .reusable = true}}, SHIFT(917),
  [2055] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2129),
  [2057] = {.entry = {.count = 1, .reusable = false}}, SHIFT(85),
  [2059] = {.entry = {.count = 1, .reusable = false}}, SHIFT(83),
  [2061] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2295),
  [2063] = {.entry = {.count = 1, .reusable = false}}, SHIFT(78),
  [2065] = {.entry = {.count = 1, .reusable = true}}, SHIFT(59),
  [2067] = {.entry = {.count = 1, .reusable = true}}, SHIFT(62),
  [2069] = {.entry = {.count = 1, .reusable = true}}, SHIFT(44),
  [2071] = {.entry = {.count = 1, .reusable = true}}, SHIFT(45),
  [2073] = {.entry = {.count = 1, .reusable = true}}, SHIFT(48),
  [2075] = {.entry = {.count = 1, .reusable = true}}, SHIFT(58),
  [2077] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1411),
  [2079] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1413),
  [2081] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1243),
  [2083] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3899),
  [2085] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1255),
  [2087] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3829),
  [2089] = {.entry = {.count = 1, .reusable = false}}, SHIFT(765),
  [2091] = {.entry = {.count = 1, .reusable = false}}, SHIFT(127),
  [2093] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2622),
  [2095] = {.entry = {.count = 1, .reusable = true}}, SHIFT(42),
  [2097] = {.entry = {.count = 1, .reusable = true}}, SHIFT(51),
  [2099] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8),
  [2101] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5),
  [2103] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1388),
  [2105] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1399),
  [2107] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1214),
  [2109] = {.entry = {.count = 1, .reusable = false}}, SHIFT(744),
  [2111] = {.entry = {.count = 1, .reusable = false}}, SHIFT(117),
  [2113] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1392),
  [2115] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1379),
  [2117] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1225),
  [2119] = {.entry = {.count = 1, .reusable = false}}, SHIFT(746),
  [2121] = {.entry = {.count = 1, .reusable = false}}, SHIFT(115),
  [2123] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6),
  [2125] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1981),
  [2127] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4686),
  [2129] = {.entry = {.count = 1, .reusable = true}}, SHIFT(180),
  [2131] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4797),
  [2133] = {.entry = {.count = 1, .reusable = false}}, SHIFT(413),
  [2135] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5559),
  [2137] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3782),
  [2139] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3296),
  [2141] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5750),
  [2143] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3692),
  [2145] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3596),
  [2147] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3469),
  [2149] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_primary_expression, 1, 0, 1), REDUCE(sym__property_name, 1, 0, 7),
  [2152] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5793),
  [2154] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5488),
  [2156] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5302),
  [2158] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_primary_expression, 1, 0, 1), REDUCE(sym__property_name, 1, 0, 7),
  [2161] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2784),
  [2163] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3812),
  [2165] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5557),
  [2167] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5602),
  [2169] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5490),
  [2171] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1549),
  [2173] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2232),
  [2175] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1252),
  [2177] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1273),
  [2179] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1175),
  [2181] = {.entry = {.count = 1, .reusable = false}}, SHIFT(724),
  [2183] = {.entry = {.count = 1, .reusable = false}}, SHIFT(88),
  [2185] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1813),
  [2187] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2464),
  [2189] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1937),
  [2191] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1430),
  [2193] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1428),
  [2195] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1274),
  [2197] = {.entry = {.count = 1, .reusable = false}}, SHIFT(771),
  [2199] = {.entry = {.count = 1, .reusable = false}}, SHIFT(141),
  [2201] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2652),
  [2203] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1461),
  [2205] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1448),
  [2207] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1266),
  [2209] = {.entry = {.count = 1, .reusable = false}}, SHIFT(781),
  [2211] = {.entry = {.count = 1, .reusable = false}}, SHIFT(148),
  [2213] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2676),
  [2215] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1420),
  [2217] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1425),
  [2219] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1248),
  [2221] = {.entry = {.count = 1, .reusable = false}}, SHIFT(775),
  [2223] = {.entry = {.count = 1, .reusable = false}}, SHIFT(147),
  [2225] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2709),
  [2227] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1440),
  [2229] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1438),
  [2231] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1250),
  [2233] = {.entry = {.count = 1, .reusable = false}}, SHIFT(772),
  [2235] = {.entry = {.count = 1, .reusable = false}}, SHIFT(140),
  [2237] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2667),
  [2239] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1451),
  [2241] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1449),
  [2243] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1251),
  [2245] = {.entry = {.count = 1, .reusable = false}}, SHIFT(779),
  [2247] = {.entry = {.count = 1, .reusable = false}}, SHIFT(142),
  [2249] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2675),
  [2251] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1422),
  [2253] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1421),
  [2255] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1271),
  [2257] = {.entry = {.count = 1, .reusable = false}}, SHIFT(774),
  [2259] = {.entry = {.count = 1, .reusable = false}}, SHIFT(144),
  [2261] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2677),
  [2263] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1431),
  [2265] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1429),
  [2267] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1257),
  [2269] = {.entry = {.count = 1, .reusable = false}}, SHIFT(778),
  [2271] = {.entry = {.count = 1, .reusable = false}}, SHIFT(146),
  [2273] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2682),
  [2275] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1435),
  [2277] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1434),
  [2279] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1259),
  [2281] = {.entry = {.count = 1, .reusable = false}}, SHIFT(773),
  [2283] = {.entry = {.count = 1, .reusable = false}}, SHIFT(137),
  [2285] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2686),
  [2287] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1358),
  [2289] = {.entry = {.count = 1, .reusable = false}}, SHIFT(110),
  [2291] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2422),
  [2293] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1445),
  [2295] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1444),
  [2297] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1253),
  [2299] = {.entry = {.count = 1, .reusable = false}}, SHIFT(776),
  [2301] = {.entry = {.count = 1, .reusable = false}}, SHIFT(149),
  [2303] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2689),
  [2305] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1453),
  [2307] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1452),
  [2309] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1268),
  [2311] = {.entry = {.count = 1, .reusable = false}}, SHIFT(782),
  [2313] = {.entry = {.count = 1, .reusable = false}}, SHIFT(138),
  [2315] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2706),
  [2317] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4488),
  [2319] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4483),
  [2321] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_primary_expression, 1, 0, 1), SHIFT(2817),
  [2324] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_primary_expression, 1, 0, 1), REDUCE(sym__property_name, 1, 0, 7), SHIFT(199),
  [2328] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_primary_expression, 1, 0, 1), SHIFT(417),
  [2331] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3634),
  [2333] = {.entry = {.count = 3, .reusable = false}}, REDUCE(sym_primary_expression, 1, 0, 1), REDUCE(sym__property_name, 1, 0, 7), SHIFT(4996),
  [2337] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3816),
  [2339] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2728),
  [2341] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5678),
  [2343] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3643),
  [2345] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5138),
  [2347] = {.entry = {.count = 1, .reusable = false}}, SHIFT(439),
  [2349] = {.entry = {.count = 1, .reusable = true}}, SHIFT(181),
  [2351] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3779),
  [2353] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2730),
  [2355] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2731),
  [2357] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2741),
  [2359] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2812),
  [2361] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_object_type, 6, 0, 0),
  [2363] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_object_type, 6, 0, 0),
  [2365] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_object_type, 4, 0, 0),
  [2367] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_object_type, 4, 0, 0),
  [2369] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_object_type, 5, 0, 0),
  [2371] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_object_type, 5, 0, 0),
  [2373] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_object_type, 2, 0, 0),
  [2375] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_object_type, 2, 0, 0),
  [2377] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_object_type, 3, 0, 0),
  [2379] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_object_type, 3, 0, 0),
  [2381] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5622),
  [2383] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3871),
  [2385] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5838),
  [2387] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3579),
  [2389] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3595),
  [2391] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3480),
  [2393] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5850),
  [2395] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5839),
  [2397] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5347),
  [2399] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2785),
  [2401] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3676),
  [2403] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5576),
  [2405] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5229),
  [2407] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5733),
  [2409] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5734),
  [2411] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5831),
  [2413] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5829),
  [2415] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_primary_expression, 1, 0, 1), SHIFT(199),
  [2418] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3638),
  [2420] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_primary_expression, 1, 0, 1), SHIFT(4996),
  [2423] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5586),
  [2425] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5555),
  [2427] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5504),
  [2429] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5825),
  [2431] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3650),
  [2433] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3507),
  [2435] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5778),
  [2437] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5776),
  [2439] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5578),
  [2441] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5859),
  [2443] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5480),
  [2445] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5479),
  [2447] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5590),
  [2449] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5589),
  [2451] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5600),
  [2453] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5598),
  [2455] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_try_statement, 2, 0, 11),
  [2457] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_try_statement, 2, 0, 11),
  [2459] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4967),
  [2461] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5295),
  [2463] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3723),
  [2465] = {.entry = {.count = 1, .reusable = true}}, SHIFT(769),
  [2467] = {.entry = {.count = 1, .reusable = true}}, SHIFT(760),
  [2469] = {.entry = {.count = 1, .reusable = true}}, SHIFT(758),
  [2471] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5762),
  [2473] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5760),
  [2475] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5532),
  [2477] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5531),
  [2479] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_try_statement, 3, 0, 46),
  [2481] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_try_statement, 3, 0, 46),
  [2483] = {.entry = {.count = 1, .reusable = true}}, SHIFT(26),
  [2485] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5848),
  [2487] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5860),
  [2489] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3189),
  [2491] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5571),
  [2493] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3281),
  [2495] = {.entry = {.count = 1, .reusable = true}}, SHIFT(159),
  [2497] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5496),
  [2499] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4996),
  [2501] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_do_statement, 4, 0, 105),
  [2503] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_do_statement, 4, 0, 105),
  [2505] = {.entry = {.count = 1, .reusable = true}}, SHIFT(838),
  [2507] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parenthesized_expression, 4, 0, 99),
  [2509] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_parenthesized_expression, 4, 0, 99),
  [2511] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_if_statement, 3, 0, 38),
  [2513] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_if_statement, 3, 0, 38),
  [2515] = {.entry = {.count = 1, .reusable = false}}, SHIFT(33),
  [2517] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5484),
  [2519] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1580),
  [2521] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5746),
  [2523] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3463),
  [2525] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5853),
  [2527] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2004),
  [2529] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parenthesized_expression, 3, 0, 0),
  [2531] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_parenthesized_expression, 3, 0, 0),
  [2533] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5732),
  [2535] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2991),
  [2537] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_catch_clause, 6, 0, 274),
  [2539] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_catch_clause, 6, 0, 274),
  [2541] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_catch_clause, 5, 0, 241),
  [2543] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_catch_clause, 5, 0, 241),
  [2545] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_catch_clause, 2, 0, 11),
  [2547] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_catch_clause, 2, 0, 11),
  [2549] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_empty_statement, 1, 0, 0),
  [2551] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_empty_statement, 1, 0, 0),
  [2553] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_abstract_class_declaration, 4, 0, 140),
  [2555] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_abstract_class_declaration, 4, 0, 140),
  [2557] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_return_statement, 3, 0, 0),
  [2559] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_return_statement, 3, 0, 0),
  [2561] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_export_statement, 4, 0, 85),
  [2563] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_export_statement, 4, 0, 85),
  [2565] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_for_statement, 7, 0, 238),
  [2567] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_for_statement, 7, 0, 238),
  [2569] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_import_statement, 6, 0, 151),
  [2571] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_import_statement, 6, 0, 151),
  [2573] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_for_statement, 7, 0, 239),
  [2575] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_for_statement, 7, 0, 239),
  [2577] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3430),
  [2579] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3327),
  [2581] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_for_statement, 7, 0, 240),
  [2583] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_for_statement, 7, 0, 240),
  [2585] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_abstract_class_declaration, 6, 0, 233),
  [2587] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_abstract_class_declaration, 6, 0, 233),
  [2589] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_try_statement, 4, 0, 106),
  [2591] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_try_statement, 4, 0, 106),
  [2593] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_import_statement, 3, 0, 33),
  [2595] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_import_statement, 3, 0, 33),
  [2597] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_import_statement, 3, 0, 0),
  [2599] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_import_statement, 3, 0, 0),
  [2601] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_for_statement, 8, 0, 271),
  [2603] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_for_statement, 8, 0, 271),
  [2605] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_with_statement, 3, 0, 34),
  [2607] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_with_statement, 3, 0, 34),
  [2609] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_import_statement, 4, 0, 92),
  [2611] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_import_statement, 4, 0, 92),
  [2613] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_import_statement, 4, 0, 0),
  [2615] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_import_statement, 4, 0, 0),
  [2617] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_import_statement, 4, 0, 85),
  [2619] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_import_statement, 4, 0, 85),
  [2621] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_import_statement, 4, 0, 33),
  [2623] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_import_statement, 4, 0, 33),
  [2625] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_do_statement, 5, 0, 105),
  [2627] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_do_statement, 5, 0, 105),
  [2629] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_variable_declaration, 4, 0, 0),
  [2631] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_variable_declaration, 4, 0, 0),
  [2633] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_declaration, 6, 0, 190),
  [2635] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_declaration, 6, 0, 190),
  [2637] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_for_statement, 8, 0, 272),
  [2639] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_for_statement, 8, 0, 272),
  [2641] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_lexical_declaration, 4, 0, 37),
  [2643] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_lexical_declaration, 4, 0, 37),
  [2645] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_for_statement, 8, 0, 273),
  [2647] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_for_statement, 8, 0, 273),
  [2649] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_export_statement, 3, 0, 0),
  [2651] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_export_statement, 3, 0, 0),
  [2653] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_break_statement, 2, 0, 0),
  [2655] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_break_statement, 2, 0, 0),
  [2657] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum_declaration, 4, 0, 96),
  [2659] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_enum_declaration, 4, 0, 96),
  [2661] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_declaration, 4, 0, 49),
  [2663] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_declaration, 4, 0, 49),
  [2665] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2957),
  [2667] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_continue_statement, 2, 0, 0),
  [2669] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_continue_statement, 2, 0, 0),
  [2671] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_variable_declaration, 3, 0, 0),
  [2673] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_variable_declaration, 3, 0, 0),
  [2675] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_interface_declaration, 4, 0, 143),
  [2677] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_interface_declaration, 4, 0, 143),
  [2679] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_throw_statement, 3, 0, 0),
  [2681] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_throw_statement, 3, 0, 0),
  [2683] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_for_statement, 9, 0, 298),
  [2685] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_for_statement, 9, 0, 298),
  [2687] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_if_statement, 4, 0, 97),
  [2689] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_if_statement, 4, 0, 97),
  [2691] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_break_statement, 3, 0, 48),
  [2693] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_break_statement, 3, 0, 48),
  [2695] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_lexical_declaration, 3, 0, 37),
  [2697] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_lexical_declaration, 3, 0, 37),
  [2699] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_signature, 5, 0, 170),
  [2701] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_signature, 5, 0, 170),
  [2703] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_switch_body, 2, 0, 0),
  [2705] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_switch_body, 2, 0, 0),
  [2707] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_generator_function_declaration, 7, 0, 217),
  [2709] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_generator_function_declaration, 7, 0, 217),
  [2711] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_switch_statement, 3, 0, 39),
  [2713] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_switch_statement, 3, 0, 39),
  [2715] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_declaration, 5, 0, 111),
  [2717] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_declaration, 5, 0, 111),
  [2719] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_export_statement, 5, 0, 188),
  [2721] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_export_statement, 5, 0, 188),
  [2723] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_abstract_class_declaration, 6, 0, 232),
  [2725] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_abstract_class_declaration, 6, 0, 232),
  [2727] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_declaration, 6, 0, 189),
  [2729] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_declaration, 6, 0, 189),
  [2731] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_ambient_declaration, 2, 0, 0),
  [2733] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_ambient_declaration, 2, 0, 0),
  [2735] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2032),
  [2737] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_interface_declaration, 4, 0, 144),
  [2739] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_interface_declaration, 4, 0, 144),
  [2741] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum_body, 2, 0, 0),
  [2743] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_enum_body, 2, 0, 0),
  [2745] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_declaration, 5, 0, 112),
  [2747] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_declaration, 5, 0, 112),
  [2749] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_export_statement, 4, 0, 147),
  [2751] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_export_statement, 4, 0, 147),
  [2753] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_for_statement, 6, 0, 199),
  [2755] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_for_statement, 6, 0, 199),
  [2757] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2060),
  [2759] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_ambient_declaration, 3, 0, 0),
  [2761] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_ambient_declaration, 3, 0, 0),
  [2763] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_module, 2, 0, 6),
  [2765] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_module, 2, 0, 6),
  [2767] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_declaration, 6, 0, 167),
  [2769] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_declaration, 6, 0, 167),
  [2771] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_ambient_declaration, 7, 0, 265),
  [2773] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_ambient_declaration, 7, 0, 265),
  [2775] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_declaration, 6, 0, 171),
  [2777] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_declaration, 6, 0, 171),
  [2779] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_for_in_statement, 4, 0, 98),
  [2781] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_for_in_statement, 4, 0, 98),
  [2783] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_generator_function_declaration, 6, 0, 171),
  [2785] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_generator_function_declaration, 6, 0, 171),
  [2787] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum_body, 5, 0, 228),
  [2789] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_enum_body, 5, 0, 228),
  [2791] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum_body, 5, 0, 230),
  [2793] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_enum_body, 5, 0, 230),
  [2795] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2992),
  [2797] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_abstract_class_declaration, 6, 0, 226),
  [2799] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_abstract_class_declaration, 6, 0, 226),
  [2801] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum_body, 4, 0, 87),
  [2803] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_enum_body, 4, 0, 87),
  [2805] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_statement, 1, 0, 0),
  [2807] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_statement, 1, 0, 0),
  [2809] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_export_statement, 5, 0, 151),
  [2811] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_export_statement, 5, 0, 151),
  [2813] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum_body, 4, 0, 228),
  [2815] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_enum_body, 4, 0, 228),
  [2817] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_declaration, 7, 0, 231),
  [2819] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_declaration, 7, 0, 231),
  [2821] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_interface_declaration, 3, 0, 73),
  [2823] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_interface_declaration, 3, 0, 73),
  [2825] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_abstract_class_declaration, 7, 0, 266),
  [2827] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_abstract_class_declaration, 7, 0, 266),
  [2829] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_export_statement, 5, 0, 0),
  [2831] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_export_statement, 5, 0, 0),
  [2833] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3259),
  [2835] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum_body, 4, 0, 0),
  [2837] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_enum_body, 4, 0, 0),
  [2839] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_signature, 4, 0, 120),
  [2841] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_signature, 4, 0, 120),
  [2843] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_debugger_statement, 2, 0, 0),
  [2845] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_debugger_statement, 2, 0, 0),
  [2847] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3232),
  [2849] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum_declaration, 3, 0, 74),
  [2851] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_enum_declaration, 3, 0, 74),
  [2853] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_declaration, 5, 0, 148),
  [2855] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_declaration, 5, 0, 148),
  [2857] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_alias_declaration, 5, 0, 153),
  [2859] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_alias_declaration, 5, 0, 153),
  [2861] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_declaration, 5, 0, 121),
  [2863] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_declaration, 5, 0, 121),
  [2865] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum_body, 3, 0, 0),
  [2867] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_enum_body, 3, 0, 0),
  [2869] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_abstract_class_declaration, 5, 0, 192),
  [2871] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_abstract_class_declaration, 5, 0, 192),
  [2873] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_import_statement, 5, 0, 151),
  [2875] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_import_statement, 5, 0, 151),
  [2877] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_try_statement, 3, 0, 47),
  [2879] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_try_statement, 3, 0, 47),
  [2881] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_finally_clause, 2, 0, 11),
  [2883] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_finally_clause, 2, 0, 11),
  [2885] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_return_statement, 2, 0, 0),
  [2887] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_return_statement, 2, 0, 0),
  [2889] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_import_statement, 5, 0, 92),
  [2891] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_import_statement, 5, 0, 92),
  [2893] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_export_statement, 2, 0, 4),
  [2895] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_export_statement, 2, 0, 4),
  [2897] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_continue_statement, 3, 0, 48),
  [2899] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_continue_statement, 3, 0, 48),
  [2901] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_export_statement, 3, 0, 83),
  [2903] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_export_statement, 3, 0, 83),
  [2905] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_import_statement, 5, 0, 0),
  [2907] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_import_statement, 5, 0, 0),
  [2909] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_import_alias, 5, 0, 0),
  [2911] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_import_alias, 5, 0, 0),
  [2913] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_import_statement, 5, 0, 85),
  [2915] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_import_statement, 5, 0, 85),
  [2917] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_alias_declaration, 6, 0, 194),
  [2919] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_alias_declaration, 6, 0, 194),
  [2921] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum_body, 4, 0, 230),
  [2923] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_enum_body, 4, 0, 230),
  [2925] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_else_clause, 2, 0, 0),
  [2927] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_else_clause, 2, 0, 0),
  [2929] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_expression_statement, 2, 0, 0),
  [2931] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_expression_statement, 2, 0, 0),
  [2933] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_for_in_statement, 3, 0, 40),
  [2935] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_for_in_statement, 3, 0, 40),
  [2937] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_switch_body, 3, 0, 0),
  [2939] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_switch_body, 3, 0, 0),
  [2941] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1551),
  [2943] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_abstract_class_declaration, 5, 0, 180),
  [2945] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_abstract_class_declaration, 5, 0, 180),
  [2947] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1576),
  [2949] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_abstract_class_declaration, 5, 0, 181),
  [2951] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_abstract_class_declaration, 5, 0, 181),
  [2953] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_export_statement, 3, 0, 25),
  [2955] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_export_statement, 3, 0, 25),
  [2957] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_interface_declaration, 5, 0, 184),
  [2959] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_interface_declaration, 5, 0, 184),
  [2961] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_labeled_statement, 3, -1, 27),
  [2963] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_labeled_statement, 3, -1, 27),
  [2965] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum_body, 3, 0, 87),
  [2967] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_enum_body, 3, 0, 87),
  [2969] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_export_statement, 4, 0, 86),
  [2971] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_export_statement, 4, 0, 86),
  [2973] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_while_statement, 3, 0, 45),
  [2975] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_while_statement, 3, 0, 45),
  [2977] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_export_statement, 4, 0, 0),
  [2979] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_export_statement, 4, 0, 0),
  [2981] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3016),
  [2983] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5824),
  [2985] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3207),
  [2987] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3047),
  [2989] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__for_header, 5, 0, 197),
  [2991] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__for_header, 5, 0, 197),
  [2993] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3129),
  [2995] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3431),
  [2997] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1382),
  [2999] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3472),
  [3001] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3453),
  [3003] = {.entry = {.count = 1, .reusable = true}}, SHIFT(86),
  [3005] = {.entry = {.count = 1, .reusable = true}}, SHIFT(795),
  [3007] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4501),
  [3009] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1079),
  [3011] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1080),
  [3013] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5770),
  [3015] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3287),
  [3017] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4390),
  [3019] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4392),
  [3021] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4107),
  [3023] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3437),
  [3025] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3301),
  [3027] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3437),
  [3029] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1081),
  [3031] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1082),
  [3033] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5816),
  [3035] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3078),
  [3037] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5856),
  [3039] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1150),
  [3041] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5473),
  [3043] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1382),
  [3045] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1732),
  [3047] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1931),
  [3049] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1395),
  [3051] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3496),
  [3053] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1916),
  [3055] = {.entry = {.count = 1, .reusable = true}}, SHIFT(90),
  [3057] = {.entry = {.count = 1, .reusable = true}}, SHIFT(800),
  [3059] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4438),
  [3061] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1139),
  [3063] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1140),
  [3065] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5787),
  [3067] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1826),
  [3069] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3923),
  [3071] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1975),
  [3073] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1821),
  [3075] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1975),
  [3077] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1141),
  [3079] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1142),
  [3081] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5616),
  [3083] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3049),
  [3085] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5652),
  [3087] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1145),
  [3089] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5785),
  [3091] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1395),
  [3093] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__for_header, 5, 0, 198),
  [3095] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__for_header, 5, 0, 198),
  [3097] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3306),
  [3099] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1389),
  [3101] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3486),
  [3103] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4428),
  [3105] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1105),
  [3107] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1106),
  [3109] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4509),
  [3111] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4511),
  [3113] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3696),
  [3115] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1107),
  [3117] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1108),
  [3119] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5842),
  [3121] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3061),
  [3123] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5617),
  [3125] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1109),
  [3127] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1389),
  [3129] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__for_header, 7, 0, 269),
  [3131] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__for_header, 7, 0, 269),
  [3133] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2932),
  [3135] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3054),
  [3137] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3055),
  [3139] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3262),
  [3141] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3493),
  [3143] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3075),
  [3145] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1505),
  [3147] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1620),
  [3149] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1386),
  [3151] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3504),
  [3153] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1556),
  [3155] = {.entry = {.count = 1, .reusable = true}}, SHIFT(89),
  [3157] = {.entry = {.count = 1, .reusable = true}}, SHIFT(793),
  [3159] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4470),
  [3161] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1063),
  [3163] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1064),
  [3165] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5523),
  [3167] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1522),
  [3169] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4085),
  [3171] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1632),
  [3173] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1523),
  [3175] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1632),
  [3177] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1065),
  [3179] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1066),
  [3181] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5805),
  [3183] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3053),
  [3185] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5731),
  [3187] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1067),
  [3189] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5564),
  [3191] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1386),
  [3193] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__for_header, 6, 0, 237),
  [3195] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__for_header, 6, 0, 237),
  [3197] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__for_header, 7, 0, 270),
  [3199] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__for_header, 7, 0, 270),
  [3201] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3372),
  [3203] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3359),
  [3205] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2976),
  [3207] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3443),
  [3209] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3087),
  [3211] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3742),
  [3213] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1171),
  [3215] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3179),
  [3217] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1646),
  [3219] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1607),
  [3221] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3378),
  [3223] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3201),
  [3225] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_arguments, 2, 0, 0),
  [3227] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_arguments, 2, 0, 0),
  [3229] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1166),
  [3231] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3357),
  [3233] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_arguments, 3, 0, 0),
  [3235] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_arguments, 3, 0, 0),
  [3237] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_arguments, 4, 0, 0),
  [3239] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_arguments, 4, 0, 0),
  [3241] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1555),
  [3243] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3249),
  [3245] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2037),
  [3247] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1997),
  [3249] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2000),
  [3251] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1512),
  [3253] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1635),
  [3255] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1788),
  [3257] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2047),
  [3259] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3158),
  [3261] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3439),
  [3263] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3412),
  [3265] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1593),
  [3267] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1909),
  [3269] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3214),
  [3271] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1493),
  [3273] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2834),
  [3275] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1962),
  [3277] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1179),
  [3279] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1949),
  [3281] = {.entry = {.count = 1, .reusable = true}}, SHIFT(198),
  [3283] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1479),
  [3285] = {.entry = {.count = 1, .reusable = true}}, SHIFT(243),
  [3287] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1767),
  [3289] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3048),
  [3291] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5625),
  [3293] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3085),
  [3295] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1718),
  [3297] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1769),
  [3299] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1824),
  [3301] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2119),
  [3303] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2120),
  [3305] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5612),
  [3307] = {.entry = {.count = 1, .reusable = true}}, SHIFT(714),
  [3309] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1954),
  [3311] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1934),
  [3313] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3167),
  [3315] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1487),
  [3317] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2112),
  [3319] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1773),
  [3321] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3052),
  [3323] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1720),
  [3325] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1775),
  [3327] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1833),
  [3329] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2347),
  [3331] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2348),
  [3333] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3175),
  [3335] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1486),
  [3337] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2115),
  [3339] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1731),
  [3341] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3051),
  [3343] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1721),
  [3345] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1734),
  [3347] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1792),
  [3349] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2354),
  [3351] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2355),
  [3353] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3186),
  [3355] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1481),
  [3357] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1770),
  [3359] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3050),
  [3361] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1719),
  [3363] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1772),
  [3365] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1829),
  [3367] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2122),
  [3369] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2123),
  [3371] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2020),
  [3373] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3184),
  [3375] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1488),
  [3377] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2430),
  [3379] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1736),
  [3381] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3068),
  [3383] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1717),
  [3385] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1738),
  [3387] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1783),
  [3389] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2117),
  [3391] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2118),
  [3393] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1531),
  [3395] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1180),
  [3397] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1862),
  [3399] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1474),
  [3401] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3277),
  [3403] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1785),
  [3405] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3491),
  [3407] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2028),
  [3409] = {.entry = {.count = 1, .reusable = true}}, SHIFT(245),
  [3411] = {.entry = {.count = 1, .reusable = false}}, SHIFT(200),
  [3413] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4471),
  [3415] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4482),
  [3417] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_arguments, 4, 0, 0),
  [3419] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_arguments, 4, 0, 0),
  [3421] = {.entry = {.count = 1, .reusable = false}}, SHIFT(780),
  [3423] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_arguments, 3, 0, 0),
  [3425] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_arguments, 3, 0, 0),
  [3427] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_arguments, 5, 0, 0),
  [3429] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_arguments, 5, 0, 0),
  [3431] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1615),
  [3433] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3299),
  [3435] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1510),
  [3437] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_object_repeat1, 1, 0, 0), REDUCE(aux_sym_object_pattern_repeat1, 1, 0, 0),
  [3440] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2068),
  [3442] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3171),
  [3444] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1870),
  [3446] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2070),
  [3448] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2111),
  [3450] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2554),
  [3452] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2555),
  [3454] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1606),
  [3456] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5005),
  [3458] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_member_expression, 3, 0, 75),
  [3460] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_member_expression, 3, 0, 75),
  [3462] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_member_expression, 3, 0, 76),
  [3464] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_member_expression, 3, 0, 76),
  [3466] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_member_expression, 3, 0, 77),
  [3468] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_member_expression, 3, 0, 77),
  [3470] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_member_expression, 3, 0, 78),
  [3472] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_member_expression, 3, 0, 78),
  [3474] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__type_query_member_expression_in_type_annotation, 3, 0, 75),
  [3476] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3314),
  [3478] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__type_query_member_expression_in_type_annotation, 3, 0, 76),
  [3480] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_non_null_expression, 2, 0, 0),
  [3482] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_non_null_expression, 2, 0, 0),
  [3484] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_subscript_expression, 4, 0, 145),
  [3486] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_subscript_expression, 4, 0, 145),
  [3488] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_subscript_expression, 5, 0, 186),
  [3490] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_subscript_expression, 5, 0, 186),
  [3492] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_primary_expression, 1, 0, 0),
  [3494] = {.entry = {.count = 1, .reusable = false}}, SHIFT(542),
  [3496] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_primary_expression, 1, 0, 0),
  [3498] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__augmented_assignment_lhs, 1, 0, 0),
  [3500] = {.entry = {.count = 1, .reusable = false}}, SHIFT(420),
  [3502] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_primary_expression, 1, 0, 0), REDUCE(sym__property_name, 1, 0, 7),
  [3505] = {.entry = {.count = 1, .reusable = true}}, SHIFT(359),
  [3507] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_primary_expression, 1, 0, 0), REDUCE(sym__property_name, 1, 0, 7),
  [3510] = {.entry = {.count = 1, .reusable = false}}, SHIFT(488),
  [3512] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_query, 2, 0, 0),
  [3514] = {.entry = {.count = 1, .reusable = true}}, SHIFT(269),
  [3516] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5162),
  [3518] = {.entry = {.count = 1, .reusable = true}}, SHIFT(338),
  [3520] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4533),
  [3522] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_query, 2, 0, 0),
  [3524] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1098),
  [3526] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3499),
  [3528] = {.entry = {.count = 1, .reusable = true}}, SHIFT(264),
  [3530] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5380),
  [3532] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5027),
  [3534] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1001),
  [3536] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_primary_expression, 1, 0, 0), REDUCE(sym_primary_type, 1, 0, 13),
  [3539] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_primary_expression, 1, 0, 0), SHIFT(5593),
  [3542] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_primary_expression, 1, 0, 0), REDUCE(sym_primary_type, 1, 0, 13),
  [3545] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_primary_expression, 1, 0, 0), SHIFT(1098),
  [3548] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_primary_type, 1, 0, 13),
  [3550] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_pattern, 1, -1, 0), SHIFT(488),
  [3553] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_primary_expression, 1, 0, 0), REDUCE(sym_pattern, 1, -1, 0), REDUCE(sym_primary_type, 1, 0, 13),
  [3557] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1006),
  [3559] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_primary_type, 1, 0, 13), SHIFT(5156),
  [3562] = {.entry = {.count = 1, .reusable = false}}, SHIFT(526),
  [3564] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_primary_expression, 1, 0, 0), SHIFT(5587),
  [3567] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_primary_expression, 1, 0, 0), SHIFT(1001),
  [3570] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_decorator, 2, 0, 0),
  [3572] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_decorator, 2, 0, 0),
  [3574] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5813),
  [3576] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1098),
  [3578] = {.entry = {.count = 1, .reusable = false}}, SHIFT(517),
  [3580] = {.entry = {.count = 1, .reusable = true}}, SHIFT(347),
  [3582] = {.entry = {.count = 1, .reusable = false}}, SHIFT(456),
  [3584] = {.entry = {.count = 1, .reusable = true}}, SHIFT(318),
  [3586] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_rest_pattern, 2, 0, 0),
  [3588] = {.entry = {.count = 1, .reusable = true}}, SHIFT(356),
  [3590] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_rest_pattern, 2, 0, 0),
  [3592] = {.entry = {.count = 1, .reusable = false}}, SHIFT(569),
  [3594] = {.entry = {.count = 1, .reusable = true}}, SHIFT(364),
  [3596] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4813),
  [3598] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_primary_expression, 1, 0, 1), SHIFT(245),
  [3601] = {.entry = {.count = 1, .reusable = false}}, SHIFT(397),
  [3603] = {.entry = {.count = 1, .reusable = true}}, SHIFT(332),
  [3605] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_primary_expression, 1, 0, 1), REDUCE(sym_predefined_type, 1, 0, 0),
  [3608] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_primary_expression, 1, 0, 1), REDUCE(sym_predefined_type, 1, 0, 0),
  [3611] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_pattern, 1, -1, 0), SHIFT(397),
  [3614] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_primary_expression, 1, 0, 0), REDUCE(sym_pattern, 1, -1, 0),
  [3617] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_pattern, 1, -1, 0),
  [3619] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_pattern, 1, -1, 0), SHIFT(542),
  [3622] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_pattern, 1, -1, 0),
  [3624] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_export_statement_repeat1, 2, 0, 24),
  [3626] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_export_statement_repeat1, 2, 0, 24),
  [3628] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_export_statement_repeat1, 2, 0, 24), SHIFT_REPEAT(4290),
  [3631] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_decorator_member_expression, 3, 0, 75),
  [3633] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_decorator_member_expression, 3, 0, 75),
  [3635] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_pattern, 1, -1, 0), REDUCE(sym_primary_type, 1, 0, 13),
  [3638] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_primary_expression, 1, 0, 0), REDUCE(sym_primary_type, 1, 0, 13), REDUCE(sym_rest_pattern, 2, 0, 0),
  [3642] = {.entry = {.count = 1, .reusable = false}}, SHIFT(597),
  [3644] = {.entry = {.count = 1, .reusable = true}}, SHIFT(371),
  [3646] = {.entry = {.count = 1, .reusable = false}}, SHIFT(650),
  [3648] = {.entry = {.count = 1, .reusable = true}}, SHIFT(383),
  [3650] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_decorator_call_expression, 3, 0, 79),
  [3652] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_decorator_call_expression, 3, 0, 79),
  [3654] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_decorator_call_expression, 2, 0, 19),
  [3656] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_decorator_call_expression, 2, 0, 19),
  [3658] = {.entry = {.count = 1, .reusable = false}}, SHIFT(623),
  [3660] = {.entry = {.count = 1, .reusable = true}}, SHIFT(377),
  [3662] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_export_statement_repeat1, 2, 0, 24), SHIFT(3294),
  [3665] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_decorator_parenthesized_expression, 3, 0, 0),
  [3667] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_decorator_parenthesized_expression, 3, 0, 0),
  [3669] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_primary_expression, 1, 0, 1), REDUCE(sym_predefined_type, 1, 0, 0), REDUCE(sym_rest_pattern, 2, 0, 32),
  [3673] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_export_statement_repeat1, 1, 0, 2),
  [3675] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_export_statement_repeat1, 1, 0, 2),
  [3677] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5000),
  [3679] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__type_query_member_expression_in_type_annotation, 3, 0, 76),
  [3681] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_primary_expression, 1, 0, 0), SHIFT(328),
  [3684] = {.entry = {.count = 1, .reusable = true}}, SHIFT(328),
  [3686] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_primary_expression, 1, 0, 0), REDUCE(sym_rest_pattern, 2, 0, 0),
  [3689] = {.entry = {.count = 1, .reusable = true}}, SHIFT(322),
  [3691] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__type_query_member_expression_in_type_annotation, 3, 0, 75),
  [3693] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_pattern, 1, -1, 0), SHIFT(623),
  [3696] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1126),
  [3698] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1128),
  [3700] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3227),
  [3702] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1507),
  [3704] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2858),
  [3706] = {.entry = {.count = 1, .reusable = true}}, SHIFT(334),
  [3708] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2235),
  [3710] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3279),
  [3712] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3111),
  [3714] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1892),
  [3716] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2244),
  [3718] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2466),
  [3720] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1933),
  [3722] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2451),
  [3724] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1480),
  [3726] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3337),
  [3728] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1475),
  [3730] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1541),
  [3732] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1478),
  [3734] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3876),
  [3736] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1055),
  [3738] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1476),
  [3740] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1938),
  [3742] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3331),
  [3744] = {.entry = {.count = 1, .reusable = false}}, SHIFT(506),
  [3746] = {.entry = {.count = 1, .reusable = false}}, SHIFT(613),
  [3748] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3772),
  [3750] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3776),
  [3752] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3252),
  [3754] = {.entry = {.count = 1, .reusable = false}}, SHIFT(416),
  [3756] = {.entry = {.count = 1, .reusable = false}}, SHIFT(641),
  [3758] = {.entry = {.count = 1, .reusable = true}}, SHIFT(711),
  [3760] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2009),
  [3762] = {.entry = {.count = 1, .reusable = false}}, SHIFT(666),
  [3764] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1618),
  [3766] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2049),
  [3768] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3386),
  [3770] = {.entry = {.count = 1, .reusable = false}}, SHIFT(557),
  [3772] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3760),
  [3774] = {.entry = {.count = 1, .reusable = true}}, SHIFT(713),
  [3776] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3456),
  [3778] = {.entry = {.count = 1, .reusable = false}}, SHIFT(477),
  [3780] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1564),
  [3782] = {.entry = {.count = 1, .reusable = false}}, SHIFT(584),
  [3784] = {.entry = {.count = 1, .reusable = false}}, SHIFT(534),
  [3786] = {.entry = {.count = 1, .reusable = true}}, SHIFT(712),
  [3788] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1582),
  [3790] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3218),
  [3792] = {.entry = {.count = 1, .reusable = false}}, SHIFT(435),
  [3794] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3241),
  [3796] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2069),
  [3798] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4671),
  [3800] = {.entry = {.count = 1, .reusable = true}}, SHIFT(186),
  [3802] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4672),
  [3804] = {.entry = {.count = 1, .reusable = true}}, SHIFT(414),
  [3806] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5581),
  [3808] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__property_name, 1, 0, 7), SHIFT(1520),
  [3811] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__property_name, 1, 0, 7), SHIFT(2511),
  [3814] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__property_name, 1, 0, 7),
  [3816] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3873),
  [3818] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2867),
  [3820] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1662),
  [3822] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1490),
  [3824] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2268),
  [3826] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3062),
  [3828] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3903),
  [3830] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1725),
  [3832] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1929),
  [3834] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2401),
  [3836] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1728),
  [3838] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2774),
  [3840] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2824),
  [3842] = {.entry = {.count = 1, .reusable = true}}, SHIFT(872),
  [3844] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1485),
  [3846] = {.entry = {.count = 1, .reusable = true}}, SHIFT(756),
  [3848] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1492),
  [3850] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_body_repeat1, 2, 0, 24), SHIFT_REPEAT(3227),
  [3853] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_body_repeat1, 2, 0, 24), SHIFT_REPEAT(2867),
  [3856] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_class_body_repeat1, 2, 0, 24),
  [3858] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_body_repeat1, 2, 0, 24), SHIFT_REPEAT(1485),
  [3861] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_body_repeat1, 2, 0, 24), SHIFT_REPEAT(334),
  [3864] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_body_repeat1, 2, 0, 24), SHIFT_REPEAT(2268),
  [3867] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_body_repeat1, 2, 0, 24), SHIFT_REPEAT(5625),
  [3870] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_body_repeat1, 2, 0, 24), SHIFT_REPEAT(4393),
  [3873] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_body_repeat1, 2, 0, 24), SHIFT_REPEAT(4396),
  [3876] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_body_repeat1, 2, 0, 24), SHIFT_REPEAT(3062),
  [3879] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_body_repeat1, 2, 0, 24), SHIFT_REPEAT(3903),
  [3882] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_body_repeat1, 2, 0, 24), SHIFT_REPEAT(1725),
  [3885] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_body_repeat1, 2, 0, 24), SHIFT_REPEAT(1929),
  [3888] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_body_repeat1, 2, 0, 24), SHIFT_REPEAT(2401),
  [3891] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_body_repeat1, 2, 0, 24), SHIFT_REPEAT(1728),
  [3894] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_body_repeat1, 2, 0, 24), SHIFT_REPEAT(1933),
  [3897] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_body_repeat1, 2, 0, 24), SHIFT_REPEAT(2451),
  [3900] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_body_repeat1, 2, 0, 24), SHIFT_REPEAT(2774),
  [3903] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_body_repeat1, 2, 0, 24), SHIFT_REPEAT(2824),
  [3906] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__property_name, 1, 0, 7), SHIFT(2064),
  [3909] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__property_name, 1, 0, 7), SHIFT(1797),
  [3912] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__property_name, 1, 0, 7), SHIFT(1706),
  [3915] = {.entry = {.count = 1, .reusable = true}}, SHIFT(211),
  [3917] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1678),
  [3919] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1774),
  [3921] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1494),
  [3923] = {.entry = {.count = 1, .reusable = true}}, SHIFT(757),
  [3925] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__property_name, 1, 0, 7), SHIFT(1726),
  [3928] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1766),
  [3930] = {.entry = {.count = 1, .reusable = true}}, SHIFT(865),
  [3932] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1483),
  [3934] = {.entry = {.count = 1, .reusable = true}}, SHIFT(238),
  [3936] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1489),
  [3938] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3374),
  [3940] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2074),
  [3942] = {.entry = {.count = 1, .reusable = true}}, SHIFT(247),
  [3944] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2321),
  [3946] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3648),
  [3948] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2075),
  [3950] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2322),
  [3952] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2438),
  [3954] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2615),
  [3956] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2616),
  [3958] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3370),
  [3960] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2560),
  [3962] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2344),
  [3964] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1953),
  [3966] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2346),
  [3968] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2473),
  [3970] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2617),
  [3972] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2618),
  [3974] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3417),
  [3976] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1799),
  [3978] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2214),
  [3980] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1877),
  [3982] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2218),
  [3984] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2445),
  [3986] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2627),
  [3988] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2628),
  [3990] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3427),
  [3992] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1651),
  [3994] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2169),
  [3996] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1889),
  [3998] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2172),
  [4000] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2378),
  [4002] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2620),
  [4004] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2609),
  [4006] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_new_expression, 2, 0, 12),
  [4008] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_new_expression, 2, 0, 12),
  [4010] = {.entry = {.count = 1, .reusable = true}}, SHIFT(265),
  [4012] = {.entry = {.count = 1, .reusable = true}}, SHIFT(319),
  [4014] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5274),
  [4016] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3680),
  [4018] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1084),
  [4020] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3364),
  [4022] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2448),
  [4024] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2332),
  [4026] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1947),
  [4028] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2334),
  [4030] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2457),
  [4032] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2626),
  [4034] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2629),
  [4036] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3353),
  [4038] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1768),
  [4040] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2217),
  [4042] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1917),
  [4044] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2223),
  [4046] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2374),
  [4048] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2613),
  [4050] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2614),
  [4052] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5269),
  [4054] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_primary_type, 1, 0, 13),
  [4056] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5517),
  [4058] = {.entry = {.count = 1, .reusable = true}}, SHIFT(998),
  [4060] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_query, 2, 0, 59),
  [4062] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_query, 2, 0, 59),
  [4064] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5282),
  [4066] = {.entry = {.count = 1, .reusable = true}}, SHIFT(562),
  [4068] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_query, 2, 0, 58),
  [4070] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_query, 2, 0, 58),
  [4072] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5273),
  [4074] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym__property_name, 1, 0, 7), REDUCE(aux_sym_object_repeat1, 2, 0, 30), REDUCE(aux_sym_object_pattern_repeat1, 2, 0, 31),
  [4078] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type, 1, 0, 16),
  [4080] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type, 1, 0, 16),
  [4082] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5184),
  [4084] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_predefined_type, 2, 0, 67),
  [4086] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_predefined_type, 2, 0, 67),
  [4088] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3525),
  [4090] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2581),
  [4092] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2397),
  [4094] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2582),
  [4096] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2623),
  [4098] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2713),
  [4100] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2714),
  [4102] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1713),
  [4104] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_primary_type, 1, 0, 15),
  [4106] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_primary_type, 1, 0, 15),
  [4108] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_primary_type, 1, 0, 0),
  [4110] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_primary_type, 1, 0, 0),
  [4112] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1000),
  [4114] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_asserts, 2, 0, 0),
  [4116] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_asserts, 2, 0, 0),
  [4118] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__type_query_call_expression_in_type_annotation, 2, 0, 19),
  [4120] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__type_query_call_expression_in_type_annotation, 2, 0, 19),
  [4122] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__type_query_member_expression, 3, 0, 137),
  [4124] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__type_query_member_expression, 3, 0, 137),
  [4126] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_object, 2, 0, 0), REDUCE(sym_object_type, 2, 0, 0),
  [4129] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_object, 2, 0, 0), REDUCE(sym_object_type, 2, 0, 0),
  [4132] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__type_query_member_expression, 3, 0, 175),
  [4134] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__type_query_member_expression, 3, 0, 175),
  [4136] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__type_query_member_expression, 3, 0, 176),
  [4138] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__type_query_member_expression, 3, 0, 176),
  [4140] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_literal_type, 1, 0, 18),
  [4142] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_literal_type, 1, 0, 18),
  [4144] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_array, 2, 0, 0),
  [4146] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_array_pattern, 2, 0, 0),
  [4148] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_array, 2, 0, 0),
  [4150] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array, 2, 0, 0), REDUCE(sym_tuple_type, 2, 0, 0),
  [4153] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_array, 2, 0, 0), REDUCE(sym_tuple_type, 2, 0, 0),
  [4156] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_tuple_type, 2, 0, 0),
  [4158] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__type_query_member_expression, 3, 0, 75),
  [4160] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__type_query_member_expression, 3, 0, 75),
  [4162] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__type_query_member_expression, 3, 0, 138),
  [4164] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__type_query_member_expression, 3, 0, 138),
  [4166] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__type_query_member_expression, 3, 0, 139),
  [4168] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__type_query_member_expression, 3, 0, 139),
  [4170] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type, 1, 0, 0),
  [4172] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type, 1, 0, 0),
  [4174] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_generic_type, 2, 0, 68),
  [4176] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_generic_type, 2, 0, 68),
  [4178] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__type_query_call_expression_in_type_annotation, 2, 0, 69),
  [4180] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__type_query_call_expression_in_type_annotation, 2, 0, 69),
  [4182] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__number, 2, 0, 8),
  [4184] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__number, 2, 0, 8),
  [4186] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_tuple_type, 4, 0, 0),
  [4188] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_tuple_type, 4, 0, 0),
  [4190] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_infer_type, 2, 0, 66),
  [4192] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_infer_type, 2, 0, 66),
  [4194] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1073),
  [4196] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_constructor_type, 4, 0, 178),
  [4198] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_constructor_type, 4, 0, 178),
  [4200] = {.entry = {.count = 1, .reusable = true}}, SHIFT(984),
  [4202] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_infer_type, 4, 0, 66),
  [4204] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_infer_type, 4, 0, 66),
  [4206] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1069),
  [4208] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1070),
  [4210] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1147),
  [4212] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_index_type_query, 2, 0, 0),
  [4214] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_index_type_query, 2, 0, 0),
  [4216] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_lookup_type, 4, 0, 0),
  [4218] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_lookup_type, 4, 0, 0),
  [4220] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_type, 4, 0, 179),
  [4222] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_type, 4, 0, 179),
  [4224] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_query, 2, 0, 60),
  [4226] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_query, 2, 0, 60),
  [4228] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5294),
  [4230] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_query, 2, 0, 61),
  [4232] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_query, 2, 0, 61),
  [4234] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__type_query_subscript_expression, 4, 0, 145),
  [4236] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__type_query_subscript_expression, 4, 0, 145),
  [4238] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__type_query_subscript_expression, 4, 0, 221),
  [4240] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__type_query_subscript_expression, 4, 0, 221),
  [4242] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__type_query_subscript_expression, 4, 0, 222),
  [4244] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__type_query_subscript_expression, 4, 0, 222),
  [4246] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__type_query_subscript_expression, 4, 0, 223),
  [4248] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__type_query_subscript_expression, 4, 0, 223),
  [4250] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type, 1, 0, 17),
  [4252] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type, 1, 0, 17),
  [4254] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5190),
  [4256] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_tuple_type, 5, 0, 0),
  [4258] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_tuple_type, 5, 0, 0),
  [4260] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_constructor_type, 5, 0, 224),
  [4262] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_constructor_type, 5, 0, 224),
  [4264] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_constructor_type, 5, 0, 225),
  [4266] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_constructor_type, 5, 0, 225),
  [4268] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1716),
  [4270] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_tuple_type, 2, 0, 0),
  [4272] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_satisfies_expression, 3, 0, 0),
  [4274] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_satisfies_expression, 3, 0, 0),
  [4276] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__type_query_subscript_expression, 5, 0, 260),
  [4278] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__type_query_subscript_expression, 5, 0, 260),
  [4280] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__type_query_subscript_expression, 5, 0, 261),
  [4282] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__type_query_subscript_expression, 5, 0, 261),
  [4284] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__type_query_subscript_expression, 5, 0, 262),
  [4286] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__type_query_subscript_expression, 5, 0, 262),
  [4288] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_call_expression, 2, 0, 19),
  [4290] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_call_expression, 2, 0, 19),
  [4292] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_readonly_type, 2, 0, 0),
  [4294] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_readonly_type, 2, 0, 0),
  [4296] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_as_expression, 3, 0, 0),
  [4298] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_as_expression, 3, 0, 0),
  [4300] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_intersection_type, 2, 0, 0),
  [4302] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_intersection_type, 2, 0, 0),
  [4304] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_union_type, 2, 0, 0),
  [4306] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_union_type, 2, 0, 0),
  [4308] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__type_query_subscript_expression, 5, 0, 263),
  [4310] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__type_query_subscript_expression, 5, 0, 263),
  [4312] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__type_query_member_expression, 3, 0, 76),
  [4314] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__type_query_member_expression, 3, 0, 76),
  [4316] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_constructor_type, 6, 0, 264),
  [4318] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_constructor_type, 6, 0, 264),
  [4320] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__type_query_call_expression, 2, 0, 19),
  [4322] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__type_query_call_expression, 2, 0, 19),
  [4324] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__type_query_instantiation_expression, 2, 0, 127),
  [4326] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__type_query_instantiation_expression, 2, 0, 127),
  [4328] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__type_query_call_expression, 2, 0, 69),
  [4330] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__type_query_call_expression, 2, 0, 69),
  [4332] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_conditional_type, 7, 0, 295),
  [4334] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_conditional_type, 7, 0, 295),
  [4336] = {.entry = {.count = 1, .reusable = true}}, SHIFT(21),
  [4338] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5868),
  [4340] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5467),
  [4342] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__type_query_instantiation_expression, 2, 0, 128),
  [4344] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__type_query_instantiation_expression, 2, 0, 128),
  [4346] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__type_query_call_expression, 2, 0, 129),
  [4348] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__type_query_call_expression, 2, 0, 129),
  [4350] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__type_query_instantiation_expression, 2, 0, 130),
  [4352] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__type_query_instantiation_expression, 2, 0, 130),
  [4354] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_parenthesized_type, 3, 0, 0),
  [4356] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parenthesized_type, 3, 0, 0),
  [4358] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_tuple_type, 3, 0, 0),
  [4360] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_tuple_type, 3, 0, 0),
  [4362] = {.entry = {.count = 1, .reusable = true}}, SHIFT(23),
  [4364] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5548),
  [4366] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5568),
  [4368] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_existential_type, 1, 0, 0),
  [4370] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_existential_type, 1, 0, 0),
  [4372] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_template_literal_type, 3, 0, 0),
  [4374] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_template_literal_type, 3, 0, 0),
  [4376] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_template_literal_type, 2, 0, 0),
  [4378] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_template_literal_type, 2, 0, 0),
  [4380] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__type_query_member_expression, 3, 0, 136),
  [4382] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__type_query_member_expression, 3, 0, 136),
  [4384] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_nested_type_identifier, 3, 0, 133),
  [4386] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_nested_type_identifier, 3, 0, 133),
  [4388] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_nested_identifier, 3, 0, 75), REDUCE(sym_nested_type_identifier, 3, 0, 133),
  [4391] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_generic_type, 2, 0, 63),
  [4393] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_generic_type, 2, 0, 63),
  [4395] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_new_expression, 3, 0, 56),
  [4397] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_new_expression, 3, 0, 56),
  [4399] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_nested_identifier, 3, 0, 88), REDUCE(sym_nested_type_identifier, 3, 0, 133),
  [4402] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_type, 3, 0, 135),
  [4404] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_type, 3, 0, 135),
  [4406] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_literal_type, 1, 0, 0),
  [4408] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_literal_type, 1, 0, 0),
  [4410] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_instantiation_expression, 2, 0, 21),
  [4412] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_instantiation_expression, 2, 0, 21),
  [4414] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__type_query_member_expression_in_type_annotation, 3, 0, 136),
  [4416] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__type_query_member_expression_in_type_annotation, 3, 0, 136),
  [4418] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__type_query_member_expression_in_type_annotation, 3, 0, 137),
  [4420] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__type_query_member_expression_in_type_annotation, 3, 0, 137),
  [4422] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__type_query_member_expression_in_type_annotation, 3, 0, 138),
  [4424] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__type_query_member_expression_in_type_annotation, 3, 0, 138),
  [4426] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__type_query_member_expression_in_type_annotation, 3, 0, 139),
  [4428] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__type_query_member_expression_in_type_annotation, 3, 0, 139),
  [4430] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_intersection_type, 3, 0, 0),
  [4432] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_intersection_type, 3, 0, 0),
  [4434] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_predicate, 3, 0, 94),
  [4436] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_predicate, 3, 0, 94),
  [4438] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_union_type, 3, 0, 0),
  [4440] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_union_type, 3, 0, 0),
  [4442] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_predicate, 3, 0, 187),
  [4444] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_predicate, 3, 0, 187),
  [4446] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_array_type, 3, 0, 0),
  [4448] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_array_type, 3, 0, 0),
  [4450] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_flow_maybe_type, 2, 0, 0),
  [4452] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_flow_maybe_type, 2, 0, 0),
  [4454] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class, 2, 0, 11),
  [4456] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class, 2, 0, 11),
  [4458] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_template_string, 2, 0, 0),
  [4460] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_template_string, 2, 0, 0),
  [4462] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_update_expression, 2, 0, 20),
  [4464] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_update_expression, 2, 0, 20),
  [4466] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_arrow_function, 3, 0, 28),
  [4468] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_arrow_function, 3, 0, 28),
  [4470] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_object, 3, 0, 0),
  [4472] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_object, 3, 0, 0),
  [4474] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_meta_property, 3, 0, 0),
  [4476] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_meta_property, 3, 0, 0),
  [4478] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_array, 3, 0, 0),
  [4480] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_array, 3, 0, 0),
  [4482] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class, 3, 0, 52),
  [4484] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class, 3, 0, 52),
  [4486] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class, 3, 0, 53),
  [4488] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class, 3, 0, 53),
  [4490] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_expression, 3, 0, 54),
  [4492] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_expression, 3, 0, 54),
  [4494] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_new_expression, 3, 0, 55),
  [4496] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_new_expression, 3, 0, 55),
  [4498] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_template_string, 3, 0, 0),
  [4500] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_template_string, 3, 0, 0),
  [4502] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_arrow_function, 3, 0, 71),
  [4504] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_arrow_function, 3, 0, 71),
  [4506] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_call_expression, 3, 0, 79),
  [4508] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_call_expression, 3, 0, 79),
  [4510] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_primary_expression, 1, 0, 0), REDUCE(sym_primary_type, 1, 0, 15),
  [4513] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_primary_expression, 1, 0, 0), REDUCE(sym_primary_type, 1, 0, 15),
  [4516] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_call_expression, 3, 0, 80),
  [4518] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_call_expression, 3, 0, 80),
  [4520] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_arrow_function, 3, 0, 81),
  [4522] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_arrow_function, 3, 0, 81),
  [4524] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class, 3, 0, 84),
  [4526] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class, 3, 0, 84),
  [4528] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_object, 4, 0, 30),
  [4530] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_object, 4, 0, 30),
  [4532] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_object, 4, 0, 0),
  [4534] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_object, 4, 0, 0),
  [4536] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_array, 4, 0, 0),
  [4538] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_array, 4, 0, 0),
  [4540] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class, 4, 0, 115),
  [4542] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class, 4, 0, 115),
  [4544] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_arrow_function, 4, 0, 116),
  [4546] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_arrow_function, 4, 0, 116),
  [4548] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_expression, 4, 0, 117),
  [4550] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_expression, 4, 0, 117),
  [4552] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_arrow_function, 4, 0, 118),
  [4554] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_arrow_function, 4, 0, 118),
  [4556] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_arrow_function, 4, 0, 119),
  [4558] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_arrow_function, 4, 0, 119),
  [4560] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_generator_function, 4, 0, 117),
  [4562] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_generator_function, 4, 0, 117),
  [4564] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_new_expression, 4, 0, 122),
  [4566] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_new_expression, 4, 0, 122),
  [4568] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_regex, 4, 0, 125),
  [4570] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_regex, 4, 0, 125),
  [4572] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_call_expression, 4, 0, 146),
  [4574] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_call_expression, 4, 0, 146),
  [4576] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class, 4, 0, 149),
  [4578] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class, 4, 0, 149),
  [4580] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class, 4, 0, 150),
  [4582] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class, 4, 0, 150),
  [4584] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_generator_function, 5, 0, 169),
  [4586] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_generator_function, 5, 0, 169),
  [4588] = {.entry = {.count = 1, .reusable = true}}, SHIFT(271),
  [4590] = {.entry = {.count = 1, .reusable = true}}, SHIFT(327),
  [4592] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5404),
  [4594] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3532),
  [4596] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1111),
  [4598] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class, 5, 0, 191),
  [4600] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class, 5, 0, 191),
  [4602] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_object, 3, 0, 30),
  [4604] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_object_pattern, 3, 0, 31),
  [4606] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_object, 3, 0, 30),
  [4608] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_primary_expression, 1, 0, 0), REDUCE(sym_literal_type, 1, 0, 0),
  [4611] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_primary_expression, 1, 0, 0), REDUCE(sym_literal_type, 1, 0, 0),
  [4614] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_template_string, 2, 0, 0), REDUCE(sym_template_literal_type, 2, 0, 0),
  [4617] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_template_string, 2, 0, 0), REDUCE(sym_template_literal_type, 2, 0, 0),
  [4620] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2822),
  [4622] = {.entry = {.count = 1, .reusable = true}}, SHIFT(447),
  [4624] = {.entry = {.count = 1, .reusable = true}}, SHIFT(472),
  [4626] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2263),
  [4628] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3144),
  [4630] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2313),
  [4632] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2428),
  [4634] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_await_expression, 2, 0, 0),
  [4636] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1112),
  [4638] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_await_expression, 2, 0, 0),
  [4640] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1206),
  [4642] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4629),
  [4644] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_await_expression, 2, 0, 0), SHIFT(153),
  [4647] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1656),
  [4649] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1114),
  [4651] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array, 2, 0, 0), REDUCE(sym_array_pattern, 2, 0, 0),
  [4654] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1727),
  [4656] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2869),
  [4658] = {.entry = {.count = 1, .reusable = true}}, SHIFT(25),
  [4660] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2138),
  [4662] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3082),
  [4664] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2157),
  [4666] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2383),
  [4668] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__property_name, 1, 0, 7), SHIFT(5360),
  [4671] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_object, 3, 0, 30), REDUCE(sym_object_pattern, 3, 0, 31),
  [4674] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3360),
  [4676] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2593),
  [4678] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2594),
  [4680] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2829),
  [4682] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2826),
  [4684] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1733),
  [4686] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5264),
  [4688] = {.entry = {.count = 1, .reusable = true}}, SHIFT(417),
  [4690] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3866),
  [4692] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2768),
  [4694] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5495),
  [4696] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1057),
  [4698] = {.entry = {.count = 1, .reusable = true}}, SHIFT(353),
  [4700] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5266),
  [4702] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5271),
  [4704] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_assertion, 2, 0, 0),
  [4706] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_assertion, 2, 0, 0),
  [4708] = {.entry = {.count = 1, .reusable = false}}, SHIFT(153),
  [4710] = {.entry = {.count = 1, .reusable = false}}, SHIFT(490),
  [4712] = {.entry = {.count = 1, .reusable = false}}, SHIFT(489),
  [4714] = {.entry = {.count = 1, .reusable = true}}, SHIFT(492),
  [4716] = {.entry = {.count = 1, .reusable = true}}, SHIFT(493),
  [4718] = {.entry = {.count = 1, .reusable = false}}, SHIFT(494),
  [4720] = {.entry = {.count = 1, .reusable = true}}, SHIFT(494),
  [4722] = {.entry = {.count = 1, .reusable = false}}, SHIFT(495),
  [4724] = {.entry = {.count = 1, .reusable = true}}, SHIFT(496),
  [4726] = {.entry = {.count = 1, .reusable = false}}, SHIFT(497),
  [4728] = {.entry = {.count = 1, .reusable = false}}, SHIFT(498),
  [4730] = {.entry = {.count = 1, .reusable = true}}, SHIFT(490),
  [4732] = {.entry = {.count = 1, .reusable = true}}, SHIFT(499),
  [4734] = {.entry = {.count = 1, .reusable = true}}, SHIFT(489),
  [4736] = {.entry = {.count = 1, .reusable = false}}, SHIFT(500),
  [4738] = {.entry = {.count = 1, .reusable = true}}, SHIFT(500),
  [4740] = {.entry = {.count = 1, .reusable = true}}, SHIFT(501),
  [4742] = {.entry = {.count = 1, .reusable = true}}, SHIFT(519),
  [4744] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_assignment_expression, 3, 0, 26),
  [4746] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3418),
  [4748] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2585),
  [4750] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2586),
  [4752] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2843),
  [4754] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2849),
  [4756] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_yield_expression, 3, 0, 0),
  [4758] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_assignment_expression, 3, 0, 70),
  [4760] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_binary_expression, 3, 0, 72),
  [4762] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_binary_expression, 3, 0, 72),
  [4764] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_binary_expression, 3, 0, 72), SHIFT(153),
  [4767] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_augmented_assignment_expression, 3, 0, 72),
  [4769] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_assignment_expression, 4, 0, 123),
  [4771] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_assignment_expression, 4, 0, 124),
  [4773] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_ternary_expression, 5, 0, 185),
  [4775] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_object, 2, 0, 0), REDUCE(sym_object_pattern, 2, 0, 0),
  [4778] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_unary_expression, 2, 0, 8),
  [4780] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_unary_expression, 2, 0, 8),
  [4782] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_unary_expression, 2, 0, 8), SHIFT(153),
  [4785] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_update_expression, 2, 0, 8),
  [4787] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_update_expression, 2, 0, 8),
  [4789] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_update_expression, 2, 0, 8), SHIFT(153),
  [4792] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_yield_expression, 2, 0, 0),
  [4794] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5338),
  [4796] = {.entry = {.count = 1, .reusable = false}}, SHIFT(432),
  [4798] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1113),
  [4800] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1310),
  [4802] = {.entry = {.count = 1, .reusable = false}}, SHIFT(457),
  [4804] = {.entry = {.count = 1, .reusable = true}}, SHIFT(453),
  [4806] = {.entry = {.count = 1, .reusable = true}}, SHIFT(473),
  [4808] = {.entry = {.count = 1, .reusable = false}}, SHIFT(474),
  [4810] = {.entry = {.count = 1, .reusable = true}}, SHIFT(474),
  [4812] = {.entry = {.count = 1, .reusable = false}}, SHIFT(475),
  [4814] = {.entry = {.count = 1, .reusable = true}}, SHIFT(479),
  [4816] = {.entry = {.count = 1, .reusable = false}}, SHIFT(504),
  [4818] = {.entry = {.count = 1, .reusable = false}}, SHIFT(514),
  [4820] = {.entry = {.count = 1, .reusable = true}}, SHIFT(432),
  [4822] = {.entry = {.count = 1, .reusable = true}}, SHIFT(532),
  [4824] = {.entry = {.count = 1, .reusable = false}}, SHIFT(160),
  [4826] = {.entry = {.count = 1, .reusable = true}}, SHIFT(457),
  [4828] = {.entry = {.count = 1, .reusable = false}}, SHIFT(536),
  [4830] = {.entry = {.count = 1, .reusable = true}}, SHIFT(536),
  [4832] = {.entry = {.count = 1, .reusable = true}}, SHIFT(611),
  [4834] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2211),
  [4836] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1138),
  [4838] = {.entry = {.count = 1, .reusable = true}}, SHIFT(426),
  [4840] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3368),
  [4842] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2583),
  [4844] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2584),
  [4846] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2814),
  [4848] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2821),
  [4850] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_array_pattern, 2, 0, 0),
  [4852] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_sequence_expression_repeat1, 2, 0, 0),
  [4854] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_object_pattern, 3, 0, 31),
  [4856] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_await_expression, 2, 0, 0), SHIFT(160),
  [4859] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_object_pattern, 2, 0, 0),
  [4861] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_binary_expression, 3, 0, 72), SHIFT(160),
  [4864] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_unary_expression, 2, 0, 8), SHIFT(160),
  [4867] = {.entry = {.count = 1, .reusable = false}}, SHIFT(399),
  [4869] = {.entry = {.count = 1, .reusable = true}}, SHIFT(400),
  [4871] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1219),
  [4873] = {.entry = {.count = 1, .reusable = false}}, SHIFT(398),
  [4875] = {.entry = {.count = 1, .reusable = true}}, SHIFT(401),
  [4877] = {.entry = {.count = 1, .reusable = true}}, SHIFT(402),
  [4879] = {.entry = {.count = 1, .reusable = false}}, SHIFT(403),
  [4881] = {.entry = {.count = 1, .reusable = true}}, SHIFT(403),
  [4883] = {.entry = {.count = 1, .reusable = false}}, SHIFT(404),
  [4885] = {.entry = {.count = 1, .reusable = true}}, SHIFT(405),
  [4887] = {.entry = {.count = 1, .reusable = false}}, SHIFT(406),
  [4889] = {.entry = {.count = 1, .reusable = false}}, SHIFT(407),
  [4891] = {.entry = {.count = 1, .reusable = true}}, SHIFT(399),
  [4893] = {.entry = {.count = 1, .reusable = true}}, SHIFT(408),
  [4895] = {.entry = {.count = 1, .reusable = false}}, SHIFT(154),
  [4897] = {.entry = {.count = 1, .reusable = true}}, SHIFT(398),
  [4899] = {.entry = {.count = 1, .reusable = false}}, SHIFT(409),
  [4901] = {.entry = {.count = 1, .reusable = true}}, SHIFT(409),
  [4903] = {.entry = {.count = 1, .reusable = true}}, SHIFT(410),
  [4905] = {.entry = {.count = 1, .reusable = true}}, SHIFT(459),
  [4907] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1058),
  [4909] = {.entry = {.count = 1, .reusable = true}}, SHIFT(803),
  [4911] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_regex, 3, 0, 41),
  [4913] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_regex, 3, 0, 41),
  [4915] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1686),
  [4917] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_update_expression, 2, 0, 8), SHIFT(161),
  [4920] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1335),
  [4922] = {.entry = {.count = 1, .reusable = false}}, SHIFT(161),
  [4924] = {.entry = {.count = 1, .reusable = false}}, SHIFT(520),
  [4926] = {.entry = {.count = 1, .reusable = false}}, SHIFT(518),
  [4928] = {.entry = {.count = 1, .reusable = true}}, SHIFT(521),
  [4930] = {.entry = {.count = 1, .reusable = true}}, SHIFT(522),
  [4932] = {.entry = {.count = 1, .reusable = false}}, SHIFT(523),
  [4934] = {.entry = {.count = 1, .reusable = true}}, SHIFT(523),
  [4936] = {.entry = {.count = 1, .reusable = false}}, SHIFT(524),
  [4938] = {.entry = {.count = 1, .reusable = true}}, SHIFT(525),
  [4940] = {.entry = {.count = 1, .reusable = false}}, SHIFT(689),
  [4942] = {.entry = {.count = 1, .reusable = false}}, SHIFT(527),
  [4944] = {.entry = {.count = 1, .reusable = true}}, SHIFT(520),
  [4946] = {.entry = {.count = 1, .reusable = true}}, SHIFT(528),
  [4948] = {.entry = {.count = 1, .reusable = true}}, SHIFT(518),
  [4950] = {.entry = {.count = 1, .reusable = false}}, SHIFT(529),
  [4952] = {.entry = {.count = 1, .reusable = true}}, SHIFT(529),
  [4954] = {.entry = {.count = 1, .reusable = true}}, SHIFT(530),
  [4956] = {.entry = {.count = 1, .reusable = true}}, SHIFT(688),
  [4958] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_binary_expression, 3, 0, 72), SHIFT(161),
  [4961] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_object, 2, 0, 0), REDUCE(sym_object_pattern, 2, 0, 0), REDUCE(sym_object_type, 2, 0, 0),
  [4965] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_array, 2, 0, 0), REDUCE(sym_array_pattern, 2, 0, 0), REDUCE(sym_tuple_type, 2, 0, 0),
  [4969] = {.entry = {.count = 1, .reusable = true}}, SHIFT(954),
  [4971] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3342),
  [4973] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2600),
  [4975] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2602),
  [4977] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2857),
  [4979] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2859),
  [4981] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_unary_expression, 2, 0, 8), SHIFT(161),
  [4984] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_await_expression, 2, 0, 0), SHIFT(161),
  [4987] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_update_expression, 2, 0, 8), SHIFT(160),
  [4990] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2817),
  [4992] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1797),
  [4994] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1015),
  [4996] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1016),
  [4998] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1143),
  [5000] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2820),
  [5002] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2215),
  [5004] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3147),
  [5006] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2216),
  [5008] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2434),
  [5010] = {.entry = {.count = 1, .reusable = true}}, SHIFT(433),
  [5012] = {.entry = {.count = 1, .reusable = true}}, SHIFT(852),
  [5014] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__initializer, 2, 0, 93),
  [5016] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__initializer, 2, 0, 93), SHIFT(518),
  [5019] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_binary_expression, 3, 0, 72), SHIFT(154),
  [5022] = {.entry = {.count = 1, .reusable = true}}, SHIFT(930),
  [5024] = {.entry = {.count = 1, .reusable = true}}, SHIFT(813),
  [5026] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5339),
  [5028] = {.entry = {.count = 1, .reusable = true}}, SHIFT(997),
  [5030] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_update_expression, 2, 0, 8), SHIFT(154),
  [5033] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_await_expression, 2, 0, 0), SHIFT(154),
  [5036] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_object_assignment_pattern, 3, 0, 89), REDUCE(sym_assignment_expression, 3, 0, 26),
  [5039] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_object_assignment_pattern, 3, 0, 89),
  [5041] = {.entry = {.count = 1, .reusable = true}}, SHIFT(944),
  [5043] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_object_assignment_pattern, 3, 0, 89), REDUCE(sym_assignment_expression, 3, 0, 70),
  [5046] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_object_assignment_pattern, 3, 0, 70), REDUCE(sym_assignment_expression, 3, 0, 70),
  [5049] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_object_assignment_pattern, 3, 0, 70),
  [5051] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2436),
  [5053] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2559),
  [5055] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_unary_expression, 2, 0, 8), SHIFT(154),
  [5058] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3939),
  [5060] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2315),
  [5062] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4340),
  [5064] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5509),
  [5066] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2825),
  [5068] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2297),
  [5070] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3064),
  [5072] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2298),
  [5074] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2452),
  [5076] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2837),
  [5078] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2196),
  [5080] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3066),
  [5082] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2300),
  [5084] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2524),
  [5086] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3067),
  [5088] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2833),
  [5090] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5283),
  [5092] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__parameter_name, 1, 0, 9),
  [5094] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_primary_expression, 1, 0, 0), REDUCE(sym__parameter_name, 1, 0, 9),
  [5097] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_primary_expression, 1, 0, 0), REDUCE(sym__parameter_name, 1, 0, 9), REDUCE(sym_primary_type, 1, 0, 15),
  [5101] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3929),
  [5103] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2818),
  [5105] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2306),
  [5107] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3135),
  [5109] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2307),
  [5111] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2380),
  [5113] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_object_pattern, 2, 0, 0), REDUCE(sym_object_type, 2, 0, 0),
  [5116] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_pattern, 2, 0, 0), REDUCE(sym_tuple_type, 2, 0, 0),
  [5119] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__parameter_name, 2, 0, 41),
  [5121] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__parameter_name, 2, 0, 41),
  [5123] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_primary_type, 1, 0, 15), REDUCE(sym__parameter_name, 2, 0, 41),
  [5126] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4171),
  [5128] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3607),
  [5130] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__parameter_name, 1, 0, 9),
  [5132] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__parameter_name, 1, 0, 9), REDUCE(sym_primary_type, 1, 0, 15),
  [5135] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1018),
  [5137] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2839),
  [5139] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2340),
  [5141] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3071),
  [5143] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2137),
  [5145] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2461),
  [5147] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3083),
  [5149] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2854),
  [5151] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2828),
  [5153] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2270),
  [5155] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3097),
  [5157] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2248),
  [5159] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2440),
  [5161] = {.entry = {.count = 1, .reusable = false}}, SHIFT(162),
  [5163] = {.entry = {.count = 1, .reusable = false}}, SHIFT(571),
  [5165] = {.entry = {.count = 1, .reusable = false}}, SHIFT(570),
  [5167] = {.entry = {.count = 1, .reusable = true}}, SHIFT(572),
  [5169] = {.entry = {.count = 1, .reusable = true}}, SHIFT(573),
  [5171] = {.entry = {.count = 1, .reusable = false}}, SHIFT(574),
  [5173] = {.entry = {.count = 1, .reusable = true}}, SHIFT(574),
  [5175] = {.entry = {.count = 1, .reusable = false}}, SHIFT(575),
  [5177] = {.entry = {.count = 1, .reusable = true}}, SHIFT(576),
  [5179] = {.entry = {.count = 1, .reusable = false}}, SHIFT(577),
  [5181] = {.entry = {.count = 1, .reusable = false}}, SHIFT(578),
  [5183] = {.entry = {.count = 1, .reusable = true}}, SHIFT(571),
  [5185] = {.entry = {.count = 1, .reusable = true}}, SHIFT(579),
  [5187] = {.entry = {.count = 1, .reusable = true}}, SHIFT(570),
  [5189] = {.entry = {.count = 1, .reusable = false}}, SHIFT(580),
  [5191] = {.entry = {.count = 1, .reusable = true}}, SHIFT(580),
  [5193] = {.entry = {.count = 1, .reusable = true}}, SHIFT(581),
  [5195] = {.entry = {.count = 1, .reusable = true}}, SHIFT(593),
  [5197] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_binary_expression, 3, 0, 72), SHIFT(162),
  [5200] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_unary_expression, 2, 0, 8), SHIFT(162),
  [5203] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_await_expression, 2, 0, 0), SHIFT(162),
  [5206] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_update_expression, 2, 0, 8), SHIFT(162),
  [5209] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2844),
  [5211] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3878),
  [5213] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2756),
  [5215] = {.entry = {.count = 1, .reusable = true}}, SHIFT(975),
  [5217] = {.entry = {.count = 1, .reusable = true}}, SHIFT(491),
  [5219] = {.entry = {.count = 1, .reusable = true}}, SHIFT(311),
  [5221] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__parameter_name, 3, 0, 100),
  [5223] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__parameter_name, 3, 0, 100),
  [5225] = {.entry = {.count = 1, .reusable = true}}, SHIFT(280),
  [5227] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1661),
  [5229] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__parameter_name, 3, 0, 104),
  [5231] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__parameter_name, 3, 0, 104),
  [5233] = {.entry = {.count = 1, .reusable = false}}, SHIFT(158),
  [5235] = {.entry = {.count = 1, .reusable = false}}, SHIFT(460),
  [5237] = {.entry = {.count = 1, .reusable = false}}, SHIFT(458),
  [5239] = {.entry = {.count = 1, .reusable = true}}, SHIFT(461),
  [5241] = {.entry = {.count = 1, .reusable = true}}, SHIFT(462),
  [5243] = {.entry = {.count = 1, .reusable = false}}, SHIFT(463),
  [5245] = {.entry = {.count = 1, .reusable = true}}, SHIFT(463),
  [5247] = {.entry = {.count = 1, .reusable = false}}, SHIFT(464),
  [5249] = {.entry = {.count = 1, .reusable = true}}, SHIFT(465),
  [5251] = {.entry = {.count = 1, .reusable = false}}, SHIFT(466),
  [5253] = {.entry = {.count = 1, .reusable = false}}, SHIFT(467),
  [5255] = {.entry = {.count = 1, .reusable = true}}, SHIFT(460),
  [5257] = {.entry = {.count = 1, .reusable = true}}, SHIFT(468),
  [5259] = {.entry = {.count = 1, .reusable = true}}, SHIFT(458),
  [5261] = {.entry = {.count = 1, .reusable = false}}, SHIFT(469),
  [5263] = {.entry = {.count = 1, .reusable = true}}, SHIFT(469),
  [5265] = {.entry = {.count = 1, .reusable = true}}, SHIFT(470),
  [5267] = {.entry = {.count = 1, .reusable = true}}, SHIFT(686),
  [5269] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_assignment_pattern, 3, 0, 70),
  [5271] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2841),
  [5273] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2114),
  [5275] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3057),
  [5277] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2520),
  [5279] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3863),
  [5281] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2765),
  [5283] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1526),
  [5285] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_binary_expression, 3, 0, 72), SHIFT(158),
  [5288] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1207),
  [5290] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1212),
  [5292] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3853),
  [5294] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2753),
  [5296] = {.entry = {.count = 1, .reusable = true}}, SHIFT(64),
  [5298] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2842),
  [5300] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3780),
  [5302] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2763),
  [5304] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2252),
  [5306] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3063),
  [5308] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2455),
  [5310] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2819),
  [5312] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2203),
  [5314] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3105),
  [5316] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2463),
  [5318] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4020),
  [5320] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__extends_clause_single, 1, 0, 50),
  [5322] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4061),
  [5324] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4063),
  [5326] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4445),
  [5328] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4078),
  [5330] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3822),
  [5332] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2740),
  [5334] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_primary_expression, 1, 0, 0), REDUCE(sym__property_name, 1, 0, 0),
  [5337] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__property_name, 1, 0, 0),
  [5339] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_primary_expression, 1, 0, 0), REDUCE(sym__property_name, 1, 0, 0),
  [5342] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__property_name, 1, 0, 0),
  [5344] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2874),
  [5346] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3845),
  [5348] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2752),
  [5350] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2835),
  [5352] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2276),
  [5354] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3152),
  [5356] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2444),
  [5358] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1838),
  [5360] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2210),
  [5362] = {.entry = {.count = 1, .reusable = true}}, SHIFT(991),
  [5364] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3798),
  [5366] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2739),
  [5368] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2525),
  [5370] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1311),
  [5372] = {.entry = {.count = 1, .reusable = true}}, SHIFT(301),
  [5374] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3094),
  [5376] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3781),
  [5378] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2749),
  [5380] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3238),
  [5382] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3489),
  [5384] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_unary_expression, 2, 0, 8), SHIFT(158),
  [5387] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_await_expression, 2, 0, 0), SHIFT(158),
  [5390] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_update_expression, 2, 0, 8), SHIFT(158),
  [5393] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2831),
  [5395] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2274),
  [5397] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3143),
  [5399] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2443),
  [5401] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1347),
  [5403] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2845),
  [5405] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3888),
  [5407] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2760),
  [5409] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3060),
  [5411] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3874),
  [5413] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2744),
  [5415] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__parameter_name, 2, 0, 44),
  [5417] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__parameter_name, 2, 0, 44),
  [5419] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3882),
  [5421] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2764),
  [5423] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_primary_expression, 1, 0, 0), REDUCE(sym_literal_type, 1, 0, 0), REDUCE(sym_rest_pattern, 2, 0, 0),
  [5427] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3804),
  [5429] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2747),
  [5431] = {.entry = {.count = 1, .reusable = true}}, SHIFT(43),
  [5433] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3836),
  [5435] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2743),
  [5437] = {.entry = {.count = 1, .reusable = true}}, SHIFT(46),
  [5439] = {.entry = {.count = 1, .reusable = true}}, SHIFT(47),
  [5441] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3753),
  [5443] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2746),
  [5445] = {.entry = {.count = 1, .reusable = true}}, SHIFT(49),
  [5447] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2838),
  [5449] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3828),
  [5451] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2750),
  [5453] = {.entry = {.count = 1, .reusable = true}}, SHIFT(955),
  [5455] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11),
  [5457] = {.entry = {.count = 1, .reusable = true}}, SHIFT(947),
  [5459] = {.entry = {.count = 1, .reusable = true}}, SHIFT(950),
  [5461] = {.entry = {.count = 1, .reusable = true}}, SHIFT(55),
  [5463] = {.entry = {.count = 1, .reusable = true}}, SHIFT(965),
  [5465] = {.entry = {.count = 1, .reusable = true}}, SHIFT(307),
  [5467] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__parameter_name, 4, 0, 156),
  [5469] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__parameter_name, 4, 0, 156),
  [5471] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__parameter_name, 4, 0, 158),
  [5473] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__parameter_name, 4, 0, 158),
  [5475] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2836),
  [5477] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3898),
  [5479] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2742),
  [5481] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2335),
  [5483] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3074),
  [5485] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2475),
  [5487] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3079),
  [5489] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2193),
  [5491] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array, 3, 0, 0), REDUCE(sym_computed_property_name, 3, 0, 0),
  [5494] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_computed_property_name, 3, 0, 0),
  [5496] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_array, 3, 0, 0), REDUCE(sym_computed_property_name, 3, 0, 0),
  [5499] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_computed_property_name, 3, 0, 0),
  [5501] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3072),
  [5503] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2302),
  [5505] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2856),
  [5507] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3802),
  [5509] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2762),
  [5511] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2257),
  [5513] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3098),
  [5515] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2510),
  [5517] = {.entry = {.count = 1, .reusable = true}}, SHIFT(956),
  [5519] = {.entry = {.count = 1, .reusable = true}}, SHIFT(305),
  [5521] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_spread_element, 2, 0, 0),
  [5523] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4505),
  [5525] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_object_pattern_repeat1, 1, 0, 0),
  [5527] = {.entry = {.count = 1, .reusable = true}}, SHIFT(972),
  [5529] = {.entry = {.count = 1, .reusable = true}}, SHIFT(60),
  [5531] = {.entry = {.count = 1, .reusable = true}}, SHIFT(61),
  [5533] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__parameter_name, 5, 0, 200),
  [5535] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__parameter_name, 5, 0, 200),
  [5537] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2860),
  [5539] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3890),
  [5541] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2751),
  [5543] = {.entry = {.count = 1, .reusable = true}}, SHIFT(308),
  [5545] = {.entry = {.count = 1, .reusable = true}}, SHIFT(310),
  [5547] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3851),
  [5549] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2755),
  [5551] = {.entry = {.count = 1, .reusable = true}}, SHIFT(966),
  [5553] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3618),
  [5555] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2429),
  [5557] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5129),
  [5559] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2569),
  [5561] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3688),
  [5563] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2384),
  [5565] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2570),
  [5567] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2630),
  [5569] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2724),
  [5571] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2725),
  [5573] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2177),
  [5575] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3073),
  [5577] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2459),
  [5579] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3081),
  [5581] = {.entry = {.count = 1, .reusable = true}}, SHIFT(607),
  [5583] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_binary_expression, 3, 0, 72), SHIFT(157),
  [5586] = {.entry = {.count = 1, .reusable = false}}, SHIFT(599),
  [5588] = {.entry = {.count = 1, .reusable = false}}, SHIFT(598),
  [5590] = {.entry = {.count = 1, .reusable = false}}, SHIFT(602),
  [5592] = {.entry = {.count = 1, .reusable = true}}, SHIFT(602),
  [5594] = {.entry = {.count = 1, .reusable = false}}, SHIFT(606),
  [5596] = {.entry = {.count = 1, .reusable = true}}, SHIFT(599),
  [5598] = {.entry = {.count = 1, .reusable = false}}, SHIFT(157),
  [5600] = {.entry = {.count = 1, .reusable = true}}, SHIFT(598),
  [5602] = {.entry = {.count = 1, .reusable = true}}, SHIFT(600),
  [5604] = {.entry = {.count = 1, .reusable = true}}, SHIFT(601),
  [5606] = {.entry = {.count = 1, .reusable = false}}, SHIFT(603),
  [5608] = {.entry = {.count = 1, .reusable = true}}, SHIFT(604),
  [5610] = {.entry = {.count = 1, .reusable = false}}, SHIFT(605),
  [5612] = {.entry = {.count = 1, .reusable = false}}, SHIFT(608),
  [5614] = {.entry = {.count = 1, .reusable = true}}, SHIFT(608),
  [5616] = {.entry = {.count = 1, .reusable = true}}, SHIFT(609),
  [5618] = {.entry = {.count = 1, .reusable = true}}, SHIFT(619),
  [5620] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3787),
  [5622] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3928),
  [5624] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5333),
  [5626] = {.entry = {.count = 1, .reusable = false}}, SHIFT(155),
  [5628] = {.entry = {.count = 1, .reusable = false}}, SHIFT(625),
  [5630] = {.entry = {.count = 1, .reusable = false}}, SHIFT(624),
  [5632] = {.entry = {.count = 1, .reusable = true}}, SHIFT(626),
  [5634] = {.entry = {.count = 1, .reusable = true}}, SHIFT(627),
  [5636] = {.entry = {.count = 1, .reusable = false}}, SHIFT(628),
  [5638] = {.entry = {.count = 1, .reusable = true}}, SHIFT(628),
  [5640] = {.entry = {.count = 1, .reusable = false}}, SHIFT(629),
  [5642] = {.entry = {.count = 1, .reusable = true}}, SHIFT(630),
  [5644] = {.entry = {.count = 1, .reusable = false}}, SHIFT(631),
  [5646] = {.entry = {.count = 1, .reusable = false}}, SHIFT(632),
  [5648] = {.entry = {.count = 1, .reusable = true}}, SHIFT(625),
  [5650] = {.entry = {.count = 1, .reusable = true}}, SHIFT(633),
  [5652] = {.entry = {.count = 1, .reusable = true}}, SHIFT(624),
  [5654] = {.entry = {.count = 1, .reusable = false}}, SHIFT(634),
  [5656] = {.entry = {.count = 1, .reusable = true}}, SHIFT(634),
  [5658] = {.entry = {.count = 1, .reusable = true}}, SHIFT(635),
  [5660] = {.entry = {.count = 1, .reusable = true}}, SHIFT(396),
  [5662] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_binary_expression, 3, 0, 72), SHIFT(155),
  [5665] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_object_repeat1, 2, 0, 30), REDUCE(aux_sym_object_pattern_repeat1, 2, 0, 31),
  [5668] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3399),
  [5670] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_unary_expression, 2, 0, 8), SHIFT(157),
  [5673] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_await_expression, 2, 0, 0), SHIFT(157),
  [5676] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_update_expression, 2, 0, 8), SHIFT(157),
  [5679] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_unary_expression, 2, 0, 8), SHIFT(155),
  [5682] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_await_expression, 2, 0, 0), SHIFT(155),
  [5685] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_update_expression, 2, 0, 8), SHIFT(155),
  [5688] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_pair, 3, 0, 90),
  [5690] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3795),
  [5692] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_object_repeat1, 1, 0, 0),
  [5694] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2610),
  [5696] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2556),
  [5698] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2621),
  [5700] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2683),
  [5702] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2726),
  [5704] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2738),
  [5706] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_array, 2, 0, 0), REDUCE(sym_array_pattern, 2, 0, 0),
  [5709] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4041),
  [5711] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4040),
  [5713] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_object, 3, 0, 30), REDUCE(sym_object_pattern, 3, 0, 31),
  [5716] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3843),
  [5718] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_array_repeat1, 2, 0, 0),
  [5720] = {.entry = {.count = 1, .reusable = true}}, SHIFT(942),
  [5722] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_object, 2, 0, 0), REDUCE(sym_object_pattern, 2, 0, 0),
  [5725] = {.entry = {.count = 1, .reusable = true}}, SHIFT(875),
  [5727] = {.entry = {.count = 1, .reusable = true}}, SHIFT(862),
  [5729] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2832),
  [5731] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2171),
  [5733] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3045),
  [5735] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1971),
  [5737] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1972),
  [5739] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2379),
  [5741] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1742),
  [5743] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2851),
  [5745] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2852),
  [5747] = {.entry = {.count = 1, .reusable = false}}, SHIFT(151),
  [5749] = {.entry = {.count = 1, .reusable = false}}, SHIFT(652),
  [5751] = {.entry = {.count = 1, .reusable = false}}, SHIFT(651),
  [5753] = {.entry = {.count = 1, .reusable = true}}, SHIFT(653),
  [5755] = {.entry = {.count = 1, .reusable = true}}, SHIFT(654),
  [5757] = {.entry = {.count = 1, .reusable = false}}, SHIFT(655),
  [5759] = {.entry = {.count = 1, .reusable = true}}, SHIFT(655),
  [5761] = {.entry = {.count = 1, .reusable = false}}, SHIFT(656),
  [5763] = {.entry = {.count = 1, .reusable = true}}, SHIFT(657),
  [5765] = {.entry = {.count = 1, .reusable = false}}, SHIFT(658),
  [5767] = {.entry = {.count = 1, .reusable = false}}, SHIFT(659),
  [5769] = {.entry = {.count = 1, .reusable = true}}, SHIFT(652),
  [5771] = {.entry = {.count = 1, .reusable = true}}, SHIFT(660),
  [5773] = {.entry = {.count = 1, .reusable = true}}, SHIFT(651),
  [5775] = {.entry = {.count = 1, .reusable = false}}, SHIFT(661),
  [5777] = {.entry = {.count = 1, .reusable = true}}, SHIFT(661),
  [5779] = {.entry = {.count = 1, .reusable = true}}, SHIFT(662),
  [5781] = {.entry = {.count = 1, .reusable = true}}, SHIFT(671),
  [5783] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_binary_expression, 3, 0, 72), SHIFT(151),
  [5786] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_unary_expression, 2, 0, 8), SHIFT(151),
  [5789] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_await_expression, 2, 0, 0), SHIFT(151),
  [5792] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_update_expression, 2, 0, 8), SHIFT(151),
  [5795] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3320),
  [5797] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2863),
  [5799] = {.entry = {.count = 1, .reusable = false}}, SHIFT(152),
  [5801] = {.entry = {.count = 1, .reusable = false}}, SHIFT(544),
  [5803] = {.entry = {.count = 1, .reusable = false}}, SHIFT(543),
  [5805] = {.entry = {.count = 1, .reusable = true}}, SHIFT(545),
  [5807] = {.entry = {.count = 1, .reusable = true}}, SHIFT(546),
  [5809] = {.entry = {.count = 1, .reusable = false}}, SHIFT(547),
  [5811] = {.entry = {.count = 1, .reusable = true}}, SHIFT(547),
  [5813] = {.entry = {.count = 1, .reusable = false}}, SHIFT(548),
  [5815] = {.entry = {.count = 1, .reusable = true}}, SHIFT(549),
  [5817] = {.entry = {.count = 1, .reusable = false}}, SHIFT(550),
  [5819] = {.entry = {.count = 1, .reusable = false}}, SHIFT(551),
  [5821] = {.entry = {.count = 1, .reusable = true}}, SHIFT(544),
  [5823] = {.entry = {.count = 1, .reusable = true}}, SHIFT(552),
  [5825] = {.entry = {.count = 1, .reusable = true}}, SHIFT(543),
  [5827] = {.entry = {.count = 1, .reusable = false}}, SHIFT(553),
  [5829] = {.entry = {.count = 1, .reusable = true}}, SHIFT(553),
  [5831] = {.entry = {.count = 1, .reusable = true}}, SHIFT(554),
  [5833] = {.entry = {.count = 1, .reusable = true}}, SHIFT(565),
  [5835] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_binary_expression, 3, 0, 72), SHIFT(152),
  [5838] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__initializer, 2, 0, 93), SHIFT(651),
  [5841] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3694),
  [5843] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_object_repeat1, 2, 0, 30),
  [5845] = {.entry = {.count = 1, .reusable = true}}, SHIFT(508),
  [5847] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_class, 2, 0, 11), REDUCE(sym_class, 3, 0, 84),
  [5850] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_class, 2, 0, 11), REDUCE(sym_class, 3, 0, 84),
  [5853] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_class, 3, 0, 49), REDUCE(sym_class, 4, 0, 148),
  [5856] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_class, 3, 0, 49), REDUCE(sym_class, 4, 0, 148),
  [5859] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_class, 3, 0, 52), REDUCE(sym_class, 4, 0, 149),
  [5862] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_class, 3, 0, 52), REDUCE(sym_class, 4, 0, 149),
  [5865] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_class, 3, 0, 53), REDUCE(sym_class, 4, 0, 150),
  [5868] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_class, 3, 0, 53), REDUCE(sym_class, 4, 0, 150),
  [5871] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_unary_expression, 2, 0, 8), SHIFT(152),
  [5874] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_await_expression, 2, 0, 0), SHIFT(152),
  [5877] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_update_expression, 2, 0, 8), SHIFT(152),
  [5880] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2647),
  [5882] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2848),
  [5884] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3446),
  [5886] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2639),
  [5888] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3449),
  [5890] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2866),
  [5892] = {.entry = {.count = 1, .reusable = true}}, SHIFT(559),
  [5894] = {.entry = {.count = 1, .reusable = true}}, SHIFT(422),
  [5896] = {.entry = {.count = 1, .reusable = true}}, SHIFT(587),
  [5898] = {.entry = {.count = 1, .reusable = true}}, SHIFT(614),
  [5900] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3253),
  [5902] = {.entry = {.count = 1, .reusable = true}}, SHIFT(642),
  [5904] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2398),
  [5906] = {.entry = {.count = 1, .reusable = true}}, SHIFT(667),
  [5908] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_class, 4, 0, 111), REDUCE(sym_class, 5, 0, 189),
  [5911] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_class, 4, 0, 111), REDUCE(sym_class, 5, 0, 189),
  [5914] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_class, 4, 0, 112), REDUCE(sym_class, 5, 0, 190),
  [5917] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_class, 4, 0, 112), REDUCE(sym_class, 5, 0, 190),
  [5920] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_class, 4, 0, 115), REDUCE(sym_class, 5, 0, 191),
  [5923] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_class, 4, 0, 115), REDUCE(sym_class, 5, 0, 191),
  [5926] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3369),
  [5928] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2640),
  [5930] = {.entry = {.count = 1, .reusable = true}}, SHIFT(481),
  [5932] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3376),
  [5934] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2873),
  [5936] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_class, 5, 0, 167), REDUCE(sym_class, 6, 0, 231),
  [5939] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_class, 5, 0, 167), REDUCE(sym_class, 6, 0, 231),
  [5942] = {.entry = {.count = 1, .reusable = true}}, SHIFT(643),
  [5944] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__extends_clause_single, 2, 0, 113),
  [5946] = {.entry = {.count = 1, .reusable = true}}, SHIFT(537),
  [5948] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3459),
  [5950] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2635),
  [5952] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3419),
  [5954] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3414),
  [5956] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3326),
  [5958] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3403),
  [5960] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3334),
  [5962] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3462),
  [5964] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3367),
  [5966] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3379),
  [5968] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3397),
  [5970] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3428),
  [5972] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3429),
  [5974] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3348),
  [5976] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3343),
  [5978] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3415),
  [5980] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3400),
  [5982] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3358),
  [5984] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2684),
  [5986] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_method_definition, 4, 0, 121),
  [5988] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_method_definition, 4, 0, 121),
  [5990] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_method_definition, 7, 0, 268),
  [5992] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_method_definition, 7, 0, 268),
  [5994] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_method_definition, 6, 0, 234),
  [5996] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_method_definition, 6, 0, 234),
  [5998] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_method_definition, 6, 0, 217),
  [6000] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_method_definition, 6, 0, 217),
  [6002] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_method_definition, 8, 0, 296),
  [6004] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_method_definition, 8, 0, 296),
  [6006] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_method_definition, 8, 0, 297),
  [6008] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_method_definition, 8, 0, 297),
  [6010] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_method_definition, 9, 0, 316),
  [6012] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_method_definition, 9, 0, 316),
  [6014] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_method_definition, 9, 0, 317),
  [6016] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_method_definition, 9, 0, 317),
  [6018] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_method_definition, 10, 0, 332),
  [6020] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_method_definition, 10, 0, 332),
  [6022] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_method_definition, 5, 0, 171),
  [6024] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_method_definition, 5, 0, 171),
  [6026] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_method_definition, 5, 0, 195),
  [6028] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_method_definition, 5, 0, 195),
  [6030] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_method_definition, 7, 0, 267),
  [6032] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_method_definition, 7, 0, 267),
  [6034] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2678),
  [6036] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_method_definition, 3, 0, 91),
  [6038] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_method_definition, 3, 0, 91),
  [6040] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_method_definition, 4, 0, 154),
  [6042] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_method_definition, 4, 0, 154),
  [6044] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2715),
  [6046] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2723),
  [6048] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_class_body_repeat1, 2, 0, 108),
  [6050] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_class_body_repeat1, 2, 0, 108),
  [6052] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_body_repeat1, 2, 0, 108), SHIFT_REPEAT(2720),
  [6055] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2718),
  [6057] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_class_body_repeat1, 1, 0, 0),
  [6059] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_class_body_repeat1, 1, 0, 0),
  [6061] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_body_repeat1, 1, 0, 0), SHIFT_REPEAT(2716),
  [6064] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2716),
  [6066] = {.entry = {.count = 1, .reusable = true}}, SHIFT(273),
  [6068] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5822),
  [6070] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_class_body_repeat1, 2, 0, 0),
  [6072] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_class_body_repeat1, 2, 0, 0),
  [6074] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_static_block, 3, 0, 52),
  [6076] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_static_block, 3, 0, 52),
  [6078] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_class_body_repeat1, 3, 0, 108),
  [6080] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_class_body_repeat1, 3, 0, 108),
  [6082] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_static_block, 2, 0, 11),
  [6084] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_static_block, 2, 0, 11),
  [6086] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2840),
  [6088] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2733),
  [6090] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3752),
  [6092] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2727),
  [6094] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2748),
  [6096] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2846),
  [6098] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2734),
  [6100] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3872),
  [6102] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2754),
  [6104] = {.entry = {.count = 1, .reusable = true}}, SHIFT(336),
  [6106] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3069),
  [6108] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2065),
  [6110] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2066),
  [6112] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1869),
  [6114] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2815),
  [6116] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2816),
  [6118] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2827),
  [6120] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3837),
  [6122] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2759),
  [6124] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2737),
  [6126] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1968),
  [6128] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1969),
  [6130] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1784),
  [6132] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2781),
  [6134] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2855),
  [6136] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3840),
  [6138] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2757),
  [6140] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3860),
  [6142] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3846),
  [6144] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3880),
  [6146] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3841),
  [6148] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3897),
  [6150] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_export_statement_repeat1, 2, 0, 24), SHIFT_REPEAT(3903),
  [6153] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3833),
  [6155] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3458),
  [6157] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2607),
  [6159] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2526),
  [6161] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2870),
  [6163] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2871),
  [6165] = {.entry = {.count = 1, .reusable = true}}, SHIFT(870),
  [6167] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4151),
  [6169] = {.entry = {.count = 1, .reusable = true}}, SHIFT(179),
  [6171] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2071),
  [6173] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3985),
  [6175] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3976),
  [6177] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2014),
  [6179] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2830),
  [6181] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3044),
  [6183] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2431),
  [6185] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2437),
  [6187] = {.entry = {.count = 1, .reusable = true}}, SHIFT(891),
  [6189] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4446),
  [6191] = {.entry = {.count = 1, .reusable = true}}, SHIFT(901),
  [6193] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4068),
  [6195] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4070),
  [6197] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4089),
  [6199] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4090),
  [6201] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2823),
  [6203] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3065),
  [6205] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2375),
  [6207] = {.entry = {.count = 1, .reusable = true}}, SHIFT(886),
  [6209] = {.entry = {.count = 1, .reusable = true}}, SHIFT(888),
  [6211] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2722),
  [6213] = {.entry = {.count = 1, .reusable = true}}, SHIFT(188),
  [6215] = {.entry = {.count = 1, .reusable = true}}, SHIFT(184),
  [6217] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2352),
  [6219] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2745),
  [6221] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3058),
  [6223] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2178),
  [6225] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3043),
  [6227] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2253),
  [6229] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2864),
  [6231] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2758),
  [6233] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3080),
  [6235] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2357),
  [6237] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2179),
  [6239] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2735),
  [6241] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2205),
  [6243] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3070),
  [6245] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2303),
  [6247] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3460),
  [6249] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2625),
  [6251] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3321),
  [6253] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3442),
  [6255] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3451),
  [6257] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2641),
  [6259] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2633),
  [6261] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3452),
  [6263] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3402),
  [6265] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2624),
  [6267] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3422),
  [6269] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2632),
  [6271] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3425),
  [6273] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3461),
  [6275] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2631),
  [6277] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3350),
  [6279] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3392),
  [6281] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2619),
  [6283] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3394),
  [6285] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3423),
  [6287] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2645),
  [6289] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3426),
  [6291] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3391),
  [6293] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2634),
  [6295] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3393),
  [6297] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3405),
  [6299] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2612),
  [6301] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3323),
  [6303] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2636),
  [6305] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3324),
  [6307] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3333),
  [6309] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2637),
  [6311] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3408),
  [6313] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5358),
  [6315] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5609),
  [6317] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5143),
  [6319] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4537),
  [6321] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5191),
  [6323] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4543),
  [6325] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4523),
  [6327] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5595),
  [6329] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3046),
  [6331] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3256),
  [6333] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3177),
  [6335] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_import, 1, 0, 0),
  [6337] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5530),
  [6339] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5323),
  [6341] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4553),
  [6343] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5593),
  [6345] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1001),
  [6347] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5382),
  [6349] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5030),
  [6351] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1099),
  [6353] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5386),
  [6355] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5032),
  [6357] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5200),
  [6359] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5254),
  [6361] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2935),
  [6363] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5696),
  [6365] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5471),
  [6367] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5716),
  [6369] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5720),
  [6371] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5510),
  [6373] = {.entry = {.count = 1, .reusable = true}}, SHIFT(979),
  [6375] = {.entry = {.count = 1, .reusable = true}}, SHIFT(266),
  [6377] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5317),
  [6379] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4596),
  [6381] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1014),
  [6383] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5819),
  [6385] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5669),
  [6387] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5681),
  [6389] = {.entry = {.count = 1, .reusable = true}}, SHIFT(663),
  [6391] = {.entry = {.count = 1, .reusable = true}}, SHIFT(411),
  [6393] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5744),
  [6395] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5692),
  [6397] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5702),
  [6399] = {.entry = {.count = 1, .reusable = true}}, SHIFT(637),
  [6401] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5846),
  [6403] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5852),
  [6405] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5645),
  [6407] = {.entry = {.count = 1, .reusable = true}}, SHIFT(502),
  [6409] = {.entry = {.count = 1, .reusable = true}}, SHIFT(471),
  [6411] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5502),
  [6413] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5866),
  [6415] = {.entry = {.count = 1, .reusable = true}}, SHIFT(582),
  [6417] = {.entry = {.count = 1, .reusable = true}}, SHIFT(555),
  [6419] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5587),
  [6421] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1136),
  [6423] = {.entry = {.count = 1, .reusable = true}}, SHIFT(531),
  [6425] = {.entry = {.count = 1, .reusable = true}}, SHIFT(664),
  [6427] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5308),
  [6429] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4594),
  [6431] = {.entry = {.count = 1, .reusable = true}}, SHIFT(610),
  [6433] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5694),
  [6435] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5784),
  [6437] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5786),
  [6439] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5797),
  [6441] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5311),
  [6443] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4595),
  [6445] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5807),
  [6447] = {.entry = {.count = 1, .reusable = true}}, SHIFT(423),
  [6449] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_public_field_definition, 4, 0, 211),
  [6451] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3686),
  [6453] = {.entry = {.count = 1, .reusable = true}}, SHIFT(199),
  [6455] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1110),
  [6457] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3172),
  [6459] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_public_field_definition, 2, 0, 87),
  [6461] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3531),
  [6463] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3163),
  [6465] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_public_field_definition, 2, 0, 109),
  [6467] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3557),
  [6469] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3162),
  [6471] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4993),
  [6473] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4992),
  [6475] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__import_identifier, 1, 0, 1),
  [6477] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__import_identifier, 1, 0, 1),
  [6479] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3166),
  [6481] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1780),
  [6483] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1525),
  [6485] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3059),
  [6487] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1100),
  [6489] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_public_field_definition, 5, 0, 257),
  [6491] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3727),
  [6493] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3209),
  [6495] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3737),
  [6497] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3169),
  [6499] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3544),
  [6501] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3191),
  [6503] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3549),
  [6505] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_public_field_definition, 1, 0, 5),
  [6507] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3553),
  [6509] = {.entry = {.count = 1, .reusable = true}}, SHIFT(197),
  [6511] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3157),
  [6513] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_public_field_definition, 6, 0, 294),
  [6515] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3665),
  [6517] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3211),
  [6519] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_public_field_definition, 3, 0, 159),
  [6521] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3653),
  [6523] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3187),
  [6525] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3199),
  [6527] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_public_field_definition, 3, 0, 164),
  [6529] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3721),
  [6531] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3205),
  [6533] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3726),
  [6535] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3208),
  [6537] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3602),
  [6539] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3182),
  [6541] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3588),
  [6543] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3178),
  [6545] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3566),
  [6547] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3160),
  [6549] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3690),
  [6551] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3176),
  [6553] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_public_field_definition, 5, 0, 251),
  [6555] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3613),
  [6557] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3180),
  [6559] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_public_field_definition, 4, 0, 209),
  [6561] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3591),
  [6563] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3170),
  [6565] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3503),
  [6567] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5354),
  [6569] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3288),
  [6571] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3628),
  [6573] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3192),
  [6575] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3629),
  [6577] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3185),
  [6579] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3623),
  [6581] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3183),
  [6583] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3161),
  [6585] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3585),
  [6587] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3164),
  [6589] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_property_signature, 1, 0, 5),
  [6591] = {.entry = {.count = 1, .reusable = true}}, SHIFT(143),
  [6593] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3173),
  [6595] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1036),
  [6597] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_primary_type, 1, 0, 13), REDUCE(sym_type_parameter, 1, 0, 14),
  [6600] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1056),
  [6602] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_primary_type, 1, 0, 13), SHIFT(1056),
  [6605] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1068),
  [6607] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1086),
  [6609] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1091),
  [6611] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_property_signature, 3, 0, 159),
  [6613] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3195),
  [6615] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_property_signature, 4, 0, 209),
  [6617] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3202),
  [6619] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_property_signature, 5, 0, 251),
  [6621] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3188),
  [6623] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1097),
  [6625] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3203),
  [6627] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5388),
  [6629] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5033),
  [6631] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5520),
  [6633] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1020),
  [6635] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3210),
  [6637] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3190),
  [6639] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_property_signature, 2, 0, 87),
  [6641] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3194),
  [6643] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3159),
  [6645] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3213),
  [6647] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_public_field_definition, 2, 0, 5),
  [6649] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_property_signature, 3, 0, 87),
  [6651] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_public_field_definition, 5, 0, 211),
  [6653] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_public_field_definition, 3, 0, 87),
  [6655] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_public_field_definition, 3, 0, 109),
  [6657] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_public_field_definition, 6, 0, 257),
  [6659] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_public_field_definition, 5, 0, 209),
  [6661] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_property_signature, 2, 0, 5),
  [6663] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_public_field_definition, 4, 0, 164),
  [6665] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_public_field_definition, 6, 0, 251),
  [6667] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5279),
  [6669] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_public_field_definition, 4, 0, 159),
  [6671] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_property_signature, 6, 0, 251),
  [6673] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_primary_type, 1, 0, 13), SHIFT(5156),
  [6676] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_property_signature, 5, 0, 209),
  [6678] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_property_signature, 4, 0, 159),
  [6680] = {.entry = {.count = 1, .reusable = true}}, SHIFT(268),
  [6682] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1009),
  [6684] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5357),
  [6686] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_public_field_definition, 7, 0, 294),
  [6688] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1137),
  [6690] = {.entry = {.count = 1, .reusable = true}}, SHIFT(994),
  [6692] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1054),
  [6694] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5320),
  [6696] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4597),
  [6698] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1041),
  [6700] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1042),
  [6702] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1146),
  [6704] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5004),
  [6706] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3312),
  [6708] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5563),
  [6710] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5566),
  [6712] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3647),
  [6714] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1039),
  [6716] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3411),
  [6718] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1491),
  [6720] = {.entry = {.count = 1, .reusable = false}}, SHIFT(369),
  [6722] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1124),
  [6724] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3389),
  [6726] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5690),
  [6728] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3349),
  [6730] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3438),
  [6732] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1482),
  [6734] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5543),
  [6736] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4735),
  [6738] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4163),
  [6740] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5468),
  [6742] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4711),
  [6744] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3395),
  [6746] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3381),
  [6748] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3341),
  [6750] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_annotation, 2, 0, 0),
  [6752] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__call_signature, 2, 0, 23),
  [6754] = {.entry = {.count = 1, .reusable = true}}, SHIFT(961),
  [6756] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1021),
  [6758] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1120),
  [6760] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3396),
  [6762] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3434),
  [6764] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3362),
  [6766] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5281),
  [6768] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4989),
  [6770] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4994),
  [6772] = {.entry = {.count = 1, .reusable = true}}, SHIFT(429),
  [6774] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_variable_declarator, 1, 0, 5),
  [6776] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5370),
  [6778] = {.entry = {.count = 1, .reusable = true}}, SHIFT(392),
  [6780] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_variable_declarator, 1, 0, 5), SHIFT(5140),
  [6783] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__call_signature, 1, 0, 3),
  [6785] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3407),
  [6787] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4742),
  [6789] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3700),
  [6791] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3701),
  [6793] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3682),
  [6795] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3683),
  [6797] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3703),
  [6799] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3704),
  [6801] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3705),
  [6803] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3706),
  [6805] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3518),
  [6807] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3519),
  [6809] = {.entry = {.count = 1, .reusable = true}}, SHIFT(959),
  [6811] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3708),
  [6813] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3710),
  [6815] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3712),
  [6817] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3724),
  [6819] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1087),
  [6821] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1088),
  [6823] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1148),
  [6825] = {.entry = {.count = 1, .reusable = true}}, SHIFT(986),
  [6827] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1090),
  [6829] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_annotation, 2, 0, 0),
  [6831] = {.entry = {.count = 1, .reusable = true}}, SHIFT(369),
  [6833] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1124),
  [6835] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3646),
  [6837] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3651),
  [6839] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3681),
  [6841] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3734),
  [6843] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3630),
  [6845] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3635),
  [6847] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1496),
  [6849] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3564),
  [6851] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3565),
  [6853] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1484),
  [6855] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_object_pattern, 3, 0, 0),
  [6857] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_public_field_definition, 6, 0, 287),
  [6859] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3691),
  [6861] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3612),
  [6863] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3509),
  [6865] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_array_pattern, 3, 0, 0),
  [6867] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3550),
  [6869] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3552),
  [6871] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_object_pattern, 4, 0, 31),
  [6873] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3725),
  [6875] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3728),
  [6877] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3641),
  [6879] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3655),
  [6881] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3567),
  [6883] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3583),
  [6885] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3656),
  [6887] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3657),
  [6889] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3584),
  [6891] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3533),
  [6893] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3729),
  [6895] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3738),
  [6897] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_public_field_definition, 7, 0, 315),
  [6899] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3534),
  [6901] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3537),
  [6903] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3671),
  [6905] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3514),
  [6907] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3530),
  [6909] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3536),
  [6911] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3510),
  [6913] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3511),
  [6915] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3512),
  [6917] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3515),
  [6919] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_array_pattern, 4, 0, 0),
  [6921] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_object_pattern, 4, 0, 0),
  [6923] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1495),
  [6925] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3516),
  [6927] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3517),
  [6929] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3658),
  [6931] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3669),
  [6933] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3735),
  [6935] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3736),
  [6937] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3539),
  [6939] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3541),
  [6941] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3745),
  [6943] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3746),
  [6945] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3741),
  [6947] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3520),
  [6949] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3747),
  [6951] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3748),
  [6953] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3569),
  [6955] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3573),
  [6957] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3580),
  [6959] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3603),
  [6961] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3611),
  [6963] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3617),
  [6965] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4976),
  [6967] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3538),
  [6969] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3548),
  [6971] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3582),
  [6973] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3586),
  [6975] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3622),
  [6977] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3664),
  [6979] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3672),
  [6981] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3523),
  [6983] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3528),
  [6985] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3529),
  [6987] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3551),
  [6989] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3554),
  [6991] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3678),
  [6993] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3679),
  [6995] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3673),
  [6997] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3674),
  [6999] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3556),
  [7001] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3560),
  [7003] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3561),
  [7005] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3562),
  [7007] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_adding_type_annotation, 2, 0, 0),
  [7009] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1049),
  [7011] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1050),
  [7013] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1051),
  [7015] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_omitting_type_annotation, 2, 0, 0),
  [7017] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_opting_type_annotation, 2, 0, 0),
  [7019] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5666),
  [7021] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3026),
  [7023] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3220),
  [7025] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3785),
  [7027] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2339),
  [7029] = {.entry = {.count = 1, .reusable = true}}, SHIFT(150),
  [7031] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4487),
  [7033] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2925),
  [7035] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3155),
  [7037] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2233),
  [7039] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1710),
  [7041] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2568),
  [7043] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3764),
  [7045] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2480),
  [7047] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1957),
  [7049] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5515),
  [7051] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2878),
  [7053] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2916),
  [7055] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2271),
  [7057] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3196),
  [7059] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1040),
  [7061] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1730),
  [7063] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1974),
  [7065] = {.entry = {.count = 1, .reusable = true}}, SHIFT(28),
  [7067] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5573),
  [7069] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5599),
  [7071] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1982),
  [7073] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1504),
  [7075] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1550),
  [7077] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4273),
  [7079] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3854),
  [7081] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5396),
  [7083] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_method_signature, 4, 0, 201),
  [7085] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_method_signature, 4, 0, 170),
  [7087] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_parameter, 1, 0, 14),
  [7089] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_optional_chain, 1, 0, 0),
  [7091] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_public_field_definition, 8, 0, 315),
  [7093] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_parameter, 2, 0, 62),
  [7095] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1032),
  [7097] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1033),
  [7099] = {.entry = {.count = 1, .reusable = true}}, SHIFT(999),
  [7101] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5327),
  [7103] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_formal_parameters, 4, 0, 0),
  [7105] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_formal_parameters, 5, 0, 0),
  [7107] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5130),
  [7109] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3491),
  [7111] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5154),
  [7113] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_construct_signature, 3, 0, 173),
  [7115] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5173),
  [7117] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_construct_signature, 3, 0, 174),
  [7119] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4298),
  [7121] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3858),
  [7123] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_method_signature, 3, 0, 120),
  [7125] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_method_signature, 5, 0, 242),
  [7127] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4157),
  [7129] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3867),
  [7131] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_method_signature, 5, 0, 243),
  [7133] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_method_signature, 3, 0, 163),
  [7135] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_construct_signature, 2, 0, 126),
  [7137] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_extends_type_clause, 2, 0, 141),
  [7139] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4398),
  [7141] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5777),
  [7143] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_extends_type_clause, 2, 0, 141),
  [7145] = {.entry = {.count = 1, .reusable = true}}, SHIFT(412),
  [7147] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_required_parameter, 1, 0, 10),
  [7149] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3778),
  [7151] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_method_signature, 6, 0, 280),
  [7153] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_method_signature, 6, 0, 279),
  [7155] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_method_signature, 7, 0, 299),
  [7157] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_method_signature, 7, 0, 300),
  [7159] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4348),
  [7161] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3821),
  [7163] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_method_signature, 8, 0, 320),
  [7165] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4174),
  [7167] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3823),
  [7169] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_method_signature, 8, 0, 325),
  [7171] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4147),
  [7173] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3894),
  [7175] = {.entry = {.count = 1, .reusable = true}}, SHIFT(780),
  [7177] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5826),
  [7179] = {.entry = {.count = 1, .reusable = true}}, SHIFT(278),
  [7181] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4292),
  [7183] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_method_signature, 9, 0, 334),
  [7185] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4160),
  [7187] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3761),
  [7189] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4678),
  [7191] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4410),
  [7193] = {.entry = {.count = 1, .reusable = true}}, SHIFT(542),
  [7195] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_construct_signature, 4, 0, 220),
  [7197] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1038),
  [7199] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5321),
  [7201] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_formal_parameters, 2, 0, 0),
  [7203] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3499),
  [7205] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5854),
  [7207] = {.entry = {.count = 1, .reusable = true}}, SHIFT(672),
  [7209] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_public_field_definition, 7, 0, 287),
  [7211] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3987),
  [7213] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3831),
  [7215] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5427),
  [7217] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1121),
  [7219] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3314),
  [7221] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_formal_parameters, 3, 0, 0),
  [7223] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_method_signature, 2, 0, 107),
  [7225] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3313),
  [7227] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4217),
  [7229] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3859),
  [7231] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_pattern, 1, -1, 0), SHIFT(542),
  [7234] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4224),
  [7236] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3865),
  [7238] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3535),
  [7240] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1460),
  [7242] = {.entry = {.count = 1, .reusable = true}}, SHIFT(29),
  [7244] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4203),
  [7246] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4010),
  [7248] = {.entry = {.count = 1, .reusable = true}}, SHIFT(977),
  [7250] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3382),
  [7252] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_implements_clause_repeat1, 2, 0, 0),
  [7254] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4176),
  [7256] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1116),
  [7258] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1117),
  [7260] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1149),
  [7262] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3832),
  [7264] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2189),
  [7266] = {.entry = {.count = 1, .reusable = true}}, SHIFT(393),
  [7268] = {.entry = {.count = 1, .reusable = true}}, SHIFT(963),
  [7270] = {.entry = {.count = 1, .reusable = true}}, SHIFT(990),
  [7272] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3351),
  [7274] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1119),
  [7276] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__tuple_type_member, 1, 0, 0),
  [7278] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5160),
  [7280] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2787),
  [7282] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3293),
  [7284] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5534),
  [7286] = {.entry = {.count = 1, .reusable = true}}, SHIFT(989),
  [7288] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1170),
  [7290] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1441),
  [7292] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3892),
  [7294] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_optional_parameter, 2, 0, 10),
  [7296] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4042),
  [7298] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4256),
  [7300] = {.entry = {.count = 1, .reusable = true}}, SHIFT(996),
  [7302] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1884),
  [7304] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1667),
  [7306] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1450),
  [7308] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4291),
  [7310] = {.entry = {.count = 1, .reusable = true}}, SHIFT(993),
  [7312] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1590),
  [7314] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4829),
  [7316] = {.entry = {.count = 1, .reusable = true}}, SHIFT(252),
  [7318] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_sequence_expression, 2, 0, 0),
  [7320] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1423),
  [7322] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1455),
  [7324] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1432),
  [7326] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3906),
  [7328] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4258),
  [7330] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1424),
  [7332] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4228),
  [7334] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_sequence_expression_repeat1, 2, 0, 0), SHIFT_REPEAT(491),
  [7337] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1462),
  [7339] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1433),
  [7341] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1963),
  [7343] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1439),
  [7345] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3390),
  [7347] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_asserts_annotation, 2, 0, 0),
  [7349] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1442),
  [7351] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1454),
  [7353] = {.entry = {.count = 1, .reusable = true}}, SHIFT(715),
  [7355] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4260),
  [7357] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_switch_body_repeat1, 2, 0, 0), SHIFT_REPEAT(5845),
  [7360] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_switch_body_repeat1, 2, 0, 0),
  [7362] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_switch_body_repeat1, 2, 0, 0), SHIFT_REPEAT(320),
  [7365] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_extends_type_clause, 2, 0, 142),
  [7367] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_extends_type_clause, 2, 0, 142),
  [7369] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4038),
  [7371] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4184),
  [7373] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4185),
  [7375] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__call_signature, 2, 0, 22),
  [7377] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2804),
  [7379] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5813),
  [7381] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5845),
  [7383] = {.entry = {.count = 1, .reusable = true}}, SHIFT(858),
  [7385] = {.entry = {.count = 1, .reusable = true}}, SHIFT(320),
  [7387] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4012),
  [7389] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4813),
  [7391] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2788),
  [7393] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3308),
  [7395] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4354),
  [7397] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_template_string_repeat1, 2, 0, 0), SHIFT_REPEAT(3832),
  [7400] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_template_string_repeat1, 2, 0, 0),
  [7402] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_template_string_repeat1, 2, 0, 0), SHIFT_REPEAT(393),
  [7405] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4189),
  [7407] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_object_type_repeat1, 2, 0, 0), SHIFT_REPEAT(1477),
  [7410] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_object_type_repeat1, 2, 0, 0),
  [7412] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_constraint, 2, 0, 0),
  [7414] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4009),
  [7416] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4359),
  [7418] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4305),
  [7420] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4335),
  [7422] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1332),
  [7424] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4329),
  [7426] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1426),
  [7428] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3245),
  [7430] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4178),
  [7432] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4253),
  [7434] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4193),
  [7436] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1654),
  [7438] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4173),
  [7440] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4207),
  [7442] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_implements_clause, 2, 0, 0),
  [7444] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1019),
  [7446] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4279),
  [7448] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4225),
  [7450] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4013),
  [7452] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2342),
  [7454] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_predicate_annotation, 2, 0, 0),
  [7456] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4308),
  [7458] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4229),
  [7460] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3986),
  [7462] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4175),
  [7464] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1463),
  [7466] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_extends_type_clause_repeat1, 2, 0, 141),
  [7468] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_extends_type_clause_repeat1, 2, 0, 141),
  [7470] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4293),
  [7472] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4024),
  [7474] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1437),
  [7476] = {.entry = {.count = 1, .reusable = true}}, SHIFT(932),
  [7478] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4196),
  [7480] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4031),
  [7482] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4001),
  [7484] = {.entry = {.count = 1, .reusable = true}}, SHIFT(983),
  [7486] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3165),
  [7488] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1443),
  [7490] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__call_signature, 3, 0, 82),
  [7492] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1436),
  [7494] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1601),
  [7496] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4197),
  [7498] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4320),
  [7500] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4161),
  [7502] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1419),
  [7504] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4200),
  [7506] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4094),
  [7508] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4431),
  [7510] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1986),
  [7512] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1034),
  [7514] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4136),
  [7516] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_public_field_definition, 4, 0, 215),
  [7518] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2711),
  [7520] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4685),
  [7522] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_public_field_definition, 6, 0, 293),
  [7524] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_public_field_definition, 5, 0, 253),
  [7526] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_public_field_definition, 5, 0, 255),
  [7528] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_call_signature, 1, 0, 57),
  [7530] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_public_field_definition, 6, 0, 289),
  [7532] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_construct_signature, 4, 0, 218),
  [7534] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2008),
  [7536] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3901),
  [7538] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3941),
  [7540] = {.entry = {.count = 1, .reusable = true}}, SHIFT(904),
  [7542] = {.entry = {.count = 1, .reusable = true}}, SHIFT(902),
  [7544] = {.entry = {.count = 1, .reusable = true}}, SHIFT(903),
  [7546] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__call_signature, 1, 0, 3), SHIFT(946),
  [7549] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3955),
  [7551] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3953),
  [7553] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3954),
  [7555] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4004),
  [7557] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1042),
  [7559] = {.entry = {.count = 1, .reusable = true}}, SHIFT(866),
  [7561] = {.entry = {.count = 1, .reusable = true}}, SHIFT(879),
  [7563] = {.entry = {.count = 1, .reusable = true}}, SHIFT(857),
  [7565] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__call_signature, 1, 0, 3), SHIFT(1053),
  [7568] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__call_signature, 2, 0, 23), SHIFT(964),
  [7571] = {.entry = {.count = 1, .reusable = true}}, SHIFT(503),
  [7573] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2777),
  [7575] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4035),
  [7577] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4018),
  [7579] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4016),
  [7581] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4017),
  [7583] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4048),
  [7585] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__call_signature, 2, 0, 23), SHIFT(1059),
  [7588] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_public_field_definition, 2, 0, 36),
  [7590] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4088),
  [7592] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_property_signature, 6, 0, 283),
  [7594] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_property_signature, 6, 0, 286),
  [7596] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3285),
  [7598] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4057),
  [7600] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_property_signature, 4, 0, 205),
  [7602] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_index_signature, 7, 0, 302),
  [7604] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_index_signature, 7, 0, 303),
  [7606] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_public_field_definition, 7, 0, 305),
  [7608] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_public_field_definition, 7, 0, 308),
  [7610] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3263),
  [7612] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_property_signature, 4, 0, 207),
  [7614] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_public_field_definition, 4, 0, 213),
  [7616] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_public_field_definition, 7, 0, 311),
  [7618] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_construct_signature, 4, 0, 219),
  [7620] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_public_field_definition, 7, 0, 314),
  [7622] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_property_signature, 2, 0, 36),
  [7624] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1622),
  [7626] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4092),
  [7628] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__call_signature, 1, 0, 3), SHIFT(953),
  [7631] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1621),
  [7633] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_public_field_definition, 5, 0, 245),
  [7635] = {.entry = {.count = 1, .reusable = true}}, SHIFT(881),
  [7637] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3398),
  [7639] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4112),
  [7641] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3011),
  [7643] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3332),
  [7645] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5353),
  [7647] = {.entry = {.count = 1, .reusable = true}}, SHIFT(827),
  [7649] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__call_signature, 1, 0, 3), SHIFT(1096),
  [7652] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__call_signature, 2, 0, 23), SHIFT(973),
  [7655] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_rest_type, 2, 0, 0),
  [7657] = {.entry = {.count = 1, .reusable = true}}, SHIFT(828),
  [7659] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5863),
  [7661] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4952),
  [7663] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_template_literal_type_repeat1, 2, 0, 0),
  [7665] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_template_literal_type_repeat1, 2, 0, 0), SHIFT_REPEAT(1034),
  [7668] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_template_literal_type_repeat1, 2, 0, 0), SHIFT_REPEAT(4136),
  [7671] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_default_type, 2, 0, 0),
  [7673] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_extends_type_clause_repeat1, 2, 0, 142),
  [7675] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_extends_type_clause_repeat1, 2, 0, 142),
  [7677] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5629),
  [7679] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_parameters, 4, 0, 0),
  [7681] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2775),
  [7683] = {.entry = {.count = 1, .reusable = true}}, SHIFT(941),
  [7685] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4881),
  [7687] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_parameters, 3, 0, 0),
  [7689] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3592),
  [7691] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5307),
  [7693] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_property_signature, 7, 0, 305),
  [7695] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_index_signature, 8, 0, 318),
  [7697] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_index_signature, 8, 0, 319),
  [7699] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_public_field_definition, 8, 0, 323),
  [7701] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_public_field_definition, 8, 0, 328),
  [7703] = {.entry = {.count = 1, .reusable = true}}, SHIFT(925),
  [7705] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_public_field_definition, 8, 0, 331),
  [7707] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_variable_declarator, 2, 0, 35),
  [7709] = {.entry = {.count = 1, .reusable = true}}, SHIFT(389),
  [7711] = {.entry = {.count = 1, .reusable = true}}, SHIFT(390),
  [7713] = {.entry = {.count = 1, .reusable = true}}, SHIFT(391),
  [7715] = {.entry = {.count = 1, .reusable = true}}, SHIFT(316),
  [7717] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3042),
  [7719] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4108),
  [7721] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3291),
  [7723] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5623),
  [7725] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_public_field_definition, 3, 0, 161),
  [7727] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_public_field_definition, 5, 0, 249),
  [7729] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_public_field_definition, 3, 0, 94),
  [7731] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_public_field_definition, 3, 0, 166),
  [7733] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5385),
  [7735] = {.entry = {.count = 1, .reusable = true}}, SHIFT(909),
  [7737] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_construct_signature, 3, 0, 172),
  [7739] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_property_signature, 3, 0, 161),
  [7741] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_public_field_definition, 9, 0, 337),
  [7743] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_property_signature, 3, 0, 94),
  [7745] = {.entry = {.count = 1, .reusable = true}}, SHIFT(488),
  [7747] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__call_signature, 2, 0, 23), SHIFT(1002),
  [7750] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_property_signature, 5, 0, 245),
  [7752] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_index_signature, 5, 0, 250),
  [7754] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_property_signature, 5, 0, 249),
  [7756] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_construct_signature, 5, 0, 259),
  [7758] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_parameters, 5, 0, 0),
  [7760] = {.entry = {.count = 1, .reusable = true}}, SHIFT(836),
  [7762] = {.entry = {.count = 1, .reusable = true}}, SHIFT(835),
  [7764] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1246),
  [7766] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4740),
  [7768] = {.entry = {.count = 1, .reusable = true}}, SHIFT(916),
  [7770] = {.entry = {.count = 1, .reusable = true}}, SHIFT(913),
  [7772] = {.entry = {.count = 1, .reusable = true}}, SHIFT(833),
  [7774] = {.entry = {.count = 1, .reusable = true}}, SHIFT(834),
  [7776] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5836),
  [7778] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5729),
  [7780] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1101),
  [7782] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_mapped_type_clause, 3, 0, 202),
  [7784] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_index_signature, 4, 0, 203),
  [7786] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_pattern, 1, -1, 0), SHIFT(397),
  [7789] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_public_field_definition, 4, 0, 205),
  [7791] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_public_field_definition, 4, 0, 207),
  [7793] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_index_signature, 6, 0, 275),
  [7795] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_index_signature, 6, 0, 277),
  [7797] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__call_signature, 1, 0, 3), SHIFT(962),
  [7800] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_index_signature, 6, 0, 278),
  [7802] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__call_signature, 1, 0, 3), SHIFT(1037),
  [7805] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__call_signature, 2, 0, 23), SHIFT(967),
  [7808] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__call_signature, 2, 0, 23), SHIFT(1043),
  [7811] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_public_field_definition, 6, 0, 283),
  [7813] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_public_field_definition, 6, 0, 286),
  [7815] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_variable_declarator, 2, 0, 36),
  [7817] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5626),
  [7819] = {.entry = {.count = 1, .reusable = false}}, SHIFT(708),
  [7821] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4466),
  [7823] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1519),
  [7825] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4495),
  [7827] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_required_parameter, 2, 0, 43),
  [7829] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3568),
  [7831] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4342),
  [7833] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3488),
  [7835] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3258),
  [7837] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1084),
  [7839] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3346),
  [7841] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4394),
  [7843] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1129),
  [7845] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4395),
  [7847] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2913),
  [7849] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4476),
  [7851] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3352),
  [7853] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4494),
  [7855] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4478),
  [7857] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1613),
  [7859] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3869),
  [7861] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_extends_type_clause, 3, 0, 182),
  [7863] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_extends_type_clause, 3, 0, 182),
  [7865] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_extends_type_clause, 3, 0, 183),
  [7867] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_extends_type_clause, 3, 0, 183),
  [7869] = {.entry = {.count = 1, .reusable = false}}, SHIFT(219),
  [7871] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1511),
  [7873] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4412),
  [7875] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1984),
  [7877] = {.entry = {.count = 1, .reusable = true}}, SHIFT(431),
  [7879] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3371),
  [7881] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3526),
  [7883] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5663),
  [7885] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4651),
  [7887] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3310),
  [7889] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1559),
  [7891] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3620),
  [7893] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4456),
  [7895] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1508),
  [7897] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_parameter, 3, 0, 132),
  [7899] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1078),
  [7901] = {.entry = {.count = 1, .reusable = true}}, SHIFT(856),
  [7903] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_extends_clause, 3, 0, 114),
  [7905] = {.entry = {.count = 1, .reusable = true}}, SHIFT(355),
  [7907] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1004),
  [7909] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5738),
  [7911] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3505),
  [7913] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_implements_clause_repeat1, 2, 0, 0), SHIFT_REPEAT(1019),
  [7916] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3465),
  [7918] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_pattern, 1, -1, 0), SHIFT(488),
  [7921] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4661),
  [7923] = {.entry = {.count = 1, .reusable = true}}, SHIFT(844),
  [7925] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3294),
  [7927] = {.entry = {.count = 1, .reusable = true}}, SHIFT(436),
  [7929] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2998),
  [7931] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1104),
  [7933] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2999),
  [7935] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3269),
  [7937] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_mapped_type_clause, 5, 0, 276),
  [7939] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1062),
  [7941] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3497),
  [7943] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3498),
  [7945] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4288),
  [7947] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_template_substitution, 3, 0, 0),
  [7949] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_enum_body_repeat1, 2, 0, 87),
  [7951] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1045),
  [7953] = {.entry = {.count = 1, .reusable = true}}, SHIFT(850),
  [7955] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4343),
  [7957] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3483),
  [7959] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4465),
  [7961] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1048),
  [7963] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_variable_declaration_repeat1, 2, 0, 0), SHIFT_REPEAT(3568),
  [7966] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_variable_declaration_repeat1, 2, 0, 0),
  [7968] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_sequence_expression_repeat1, 2, 0, 0), SHIFT_REPEAT(433),
  [7971] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3943),
  [7973] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3945),
  [7975] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4330),
  [7977] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2038),
  [7979] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_extends_clause, 2, 0, 51),
  [7981] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4891),
  [7983] = {.entry = {.count = 1, .reusable = false}}, SHIFT(709),
  [7985] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_import_require_clause, 6, 0, 235),
  [7987] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__from_clause, 2, 0, 33),
  [7989] = {.entry = {.count = 1, .reusable = false}}, SHIFT(213),
  [7991] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4402),
  [7993] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1144),
  [7995] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4148),
  [7997] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2914),
  [7999] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3322),
  [8001] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3614),
  [8003] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_extends_clause_repeat1, 2, 0, 168),
  [8005] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_extends_clause_repeat1, 2, 0, 168), SHIFT_REPEAT(355),
  [8008] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2770),
  [8010] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4443),
  [8012] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_extends_type_clause_repeat1, 2, 0, 227),
  [8014] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_extends_type_clause_repeat1, 2, 0, 227), SHIFT_REPEAT(4398),
  [8017] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_extends_type_clause_repeat1, 2, 0, 227),
  [8019] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3444),
  [8021] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_template_string_repeat1, 1, 0, 0),
  [8023] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_template_string_repeat1, 1, 0, 0), REDUCE(aux_sym_template_literal_type_repeat1, 1, 0, 0),
  [8026] = {.entry = {.count = 1, .reusable = true}}, SHIFT(342),
  [8028] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1071),
  [8030] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1095),
  [8032] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_optional_parameter, 3, 0, 102),
  [8034] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1074),
  [8036] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1517),
  [8038] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4512),
  [8040] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_string_repeat1, 2, 0, 0),
  [8042] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_string_repeat1, 2, 0, 0), SHIFT_REPEAT(4494),
  [8045] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_string_repeat2, 2, 0, 0),
  [8047] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_string_repeat2, 2, 0, 0), SHIFT_REPEAT(4495),
  [8050] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4381),
  [8052] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1083),
  [8054] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1025),
  [8056] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_parameter, 2, 0, 65),
  [8058] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1111),
  [8060] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_object_pattern_repeat1, 2, 0, 31),
  [8062] = {.entry = {.count = 1, .reusable = true}}, SHIFT(842),
  [8064] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3482),
  [8066] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4513),
  [8068] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1135),
  [8070] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4452),
  [8072] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3485),
  [8074] = {.entry = {.count = 1, .reusable = true}}, SHIFT(839),
  [8076] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_public_field_definition, 5, 0, 252),
  [8078] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_public_field_definition, 4, 0, 216),
  [8080] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_public_field_definition, 7, 0, 310),
  [8082] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_public_field_definition, 7, 0, 312),
  [8084] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_public_field_definition, 6, 0, 290),
  [8086] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5121),
  [8088] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__import_identifier, 1, 0, 0),
  [8090] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1348),
  [8092] = {.entry = {.count = 1, .reusable = true}}, SHIFT(362),
  [8094] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1330),
  [8096] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_public_field_definition, 6, 0, 292),
  [8098] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_public_field_definition, 7, 0, 309),
  [8100] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5176),
  [8102] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2889),
  [8104] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2948),
  [8106] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2890),
  [8108] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_public_field_definition, 6, 0, 288),
  [8110] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2912),
  [8112] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2968),
  [8114] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2895),
  [8116] = {.entry = {.count = 1, .reusable = true}}, SHIFT(933),
  [8118] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1614),
  [8120] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1069),
  [8122] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1070),
  [8124] = {.entry = {.count = 1, .reusable = true}}, SHIFT(987),
  [8126] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2899),
  [8128] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2982),
  [8130] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2900),
  [8132] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_public_field_definition, 7, 0, 313),
  [8134] = {.entry = {.count = 1, .reusable = true}}, SHIFT(935),
  [8136] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2907),
  [8138] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3008),
  [8140] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2908),
  [8142] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2563),
  [8144] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3366),
  [8146] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_public_field_definition, 4, 0, 212),
  [8148] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4011),
  [8150] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_public_field_definition, 5, 0, 244),
  [8152] = {.entry = {.count = 1, .reusable = true}}, SHIFT(848),
  [8154] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3001),
  [8156] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2317),
  [8158] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5275),
  [8160] = {.entry = {.count = 1, .reusable = true}}, SHIFT(820),
  [8162] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3325),
  [8164] = {.entry = {.count = 1, .reusable = true}}, SHIFT(980),
  [8166] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3107),
  [8168] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3032),
  [8170] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3108),
  [8172] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3112),
  [8174] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2942),
  [8176] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3113),
  [8178] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3116),
  [8180] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2944),
  [8182] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3084),
  [8184] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3119),
  [8186] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2945),
  [8188] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3120),
  [8190] = {.entry = {.count = 1, .reusable = true}}, SHIFT(821),
  [8192] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_public_field_definition, 5, 0, 254),
  [8194] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3099),
  [8196] = {.entry = {.count = 1, .reusable = true}}, SHIFT(876),
  [8198] = {.entry = {.count = 1, .reusable = true}}, SHIFT(204),
  [8200] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5013),
  [8202] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_public_field_definition, 5, 0, 246),
  [8204] = {.entry = {.count = 1, .reusable = true}}, SHIFT(978),
  [8206] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_public_field_definition, 5, 0, 256),
  [8208] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3247),
  [8210] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2778),
  [8212] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4036),
  [8214] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1518),
  [8216] = {.entry = {.count = 1, .reusable = true}}, SHIFT(889),
  [8218] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5325),
  [8220] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_parameters, 4, 0, 0),
  [8222] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3490),
  [8224] = {.entry = {.count = 1, .reusable = true}}, SHIFT(248),
  [8226] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5222),
  [8228] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4407),
  [8230] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5106),
  [8232] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_public_field_definition, 5, 0, 247),
  [8234] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4132),
  [8236] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5000),
  [8238] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5166),
  [8240] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_type_parameters_repeat1, 2, 0, 0), SHIFT_REPEAT(4958),
  [8243] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_type_parameters_repeat1, 2, 0, 0),
  [8245] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3826),
  [8247] = {.entry = {.count = 1, .reusable = true}}, SHIFT(246),
  [8249] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5168),
  [8251] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2776),
  [8253] = {.entry = {.count = 1, .reusable = true}}, SHIFT(911),
  [8255] = {.entry = {.count = 1, .reusable = true}}, SHIFT(982),
  [8257] = {.entry = {.count = 1, .reusable = true}}, SHIFT(41),
  [8259] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1871),
  [8261] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_array_repeat1, 2, 0, 0), SHIFT_REPEAT(289),
  [8264] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_export_clause, 2, 0, 0),
  [8266] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2779),
  [8268] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4069),
  [8270] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4444),
  [8272] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3587),
  [8274] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2780),
  [8276] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4071),
  [8278] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1659),
  [8280] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3318),
  [8282] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4882),
  [8284] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1199),
  [8286] = {.entry = {.count = 1, .reusable = true}}, SHIFT(331),
  [8288] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1200),
  [8290] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4247),
  [8292] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_export_specifier, 1, 0, 5),
  [8294] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3842),
  [8296] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_public_field_definition, 2, 0, 35),
  [8298] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_export_clause, 4, 0, 0),
  [8300] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_export_clause_repeat1, 2, 0, 0), SHIFT_REPEAT(3492),
  [8303] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_export_clause_repeat1, 2, 0, 0),
  [8305] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_public_field_definition, 8, 0, 321),
  [8307] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_public_field_definition, 8, 0, 322),
  [8309] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_public_field_definition, 8, 0, 324),
  [8311] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_public_field_definition, 8, 0, 326),
  [8313] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_public_field_definition, 8, 0, 327),
  [8315] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_public_field_definition, 8, 0, 329),
  [8317] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_public_field_definition, 8, 0, 330),
  [8319] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_public_field_definition, 6, 0, 291),
  [8321] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_public_field_definition, 5, 0, 258),
  [8323] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5329),
  [8325] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5330),
  [8327] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_named_imports_repeat1, 2, 0, 0), SHIFT_REPEAT(3380),
  [8330] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_named_imports_repeat1, 2, 0, 0),
  [8332] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1674),
  [8334] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5005),
  [8336] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3644),
  [8338] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3667),
  [8340] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2286),
  [8342] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1675),
  [8344] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5140),
  [8346] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3377),
  [8348] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5349),
  [8350] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_public_field_definition, 5, 0, 248),
  [8352] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_public_field_definition, 3, 0, 160),
  [8354] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_abstract_method_signature, 3, 0, 120),
  [8356] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_public_field_definition, 3, 0, 162),
  [8358] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_public_field_definition, 3, 0, 95),
  [8360] = {.entry = {.count = 1, .reusable = true}}, SHIFT(202),
  [8362] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1677),
  [8364] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_public_field_definition, 3, 0, 165),
  [8366] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4180),
  [8368] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_export_specifier, 2, 0, 87),
  [8370] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_export_clause, 3, 0, 0),
  [8372] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3440),
  [8374] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3702),
  [8376] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_parameters, 5, 0, 0),
  [8378] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_extends_clause_repeat1, 2, 0, 51),
  [8380] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_formal_parameters_repeat1, 2, 0, 0), SHIFT_REPEAT(218),
  [8383] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_formal_parameters_repeat1, 2, 0, 0),
  [8385] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_sequence_expression_repeat1, 2, 0, 0), SHIFT_REPEAT(400),
  [8388] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_public_field_definition, 9, 0, 333),
  [8390] = {.entry = {.count = 1, .reusable = true}}, SHIFT(205),
  [8392] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3789),
  [8394] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_public_field_definition, 9, 0, 335),
  [8396] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_public_field_definition, 9, 0, 336),
  [8398] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_implements_clause, 3, 0, 0),
  [8400] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4475),
  [8402] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4164),
  [8404] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_public_field_definition, 9, 0, 338),
  [8406] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5383),
  [8408] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_pair_pattern, 3, 0, 90),
  [8410] = {.entry = {.count = 1, .reusable = true}}, SHIFT(207),
  [8412] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3707),
  [8414] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_public_field_definition, 10, 0, 339),
  [8416] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_tuple_type_repeat1, 2, 0, 0), SHIFT_REPEAT(945),
  [8419] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_tuple_type_repeat1, 2, 0, 0),
  [8421] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5352),
  [8423] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_template_type, 3, 0, 0),
  [8425] = {.entry = {.count = 1, .reusable = true}}, SHIFT(868),
  [8427] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1985),
  [8429] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_public_field_definition, 7, 0, 301),
  [8431] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3410),
  [8433] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5194),
  [8435] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5195),
  [8437] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2782),
  [8439] = {.entry = {.count = 1, .reusable = true}}, SHIFT(894),
  [8441] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_abstract_method_signature, 5, 0, 242),
  [8443] = {.entry = {.count = 1, .reusable = true}}, SHIFT(208),
  [8445] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2310),
  [8447] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2783),
  [8449] = {.entry = {.count = 1, .reusable = true}}, SHIFT(927),
  [8451] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3791),
  [8453] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_abstract_method_signature, 5, 0, 243),
  [8455] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_object_repeat1, 2, 0, 0), SHIFT_REPEAT(2429),
  [8458] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_object_repeat1, 2, 0, 0),
  [8460] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_enum_body_repeat1, 2, 0, 229), SHIFT_REPEAT(2794),
  [8463] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_enum_body_repeat1, 2, 0, 229),
  [8465] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_object_pattern_repeat1, 2, 0, 0), SHIFT_REPEAT(2315),
  [8468] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_object_pattern_repeat1, 2, 0, 0),
  [8470] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_export_clause, 5, 0, 0),
  [8472] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1015),
  [8474] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1016),
  [8476] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_array_pattern_repeat1, 2, 0, 0),
  [8478] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_public_field_definition, 7, 0, 304),
  [8480] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5359),
  [8482] = {.entry = {.count = 1, .reusable = true}}, SHIFT(849),
  [8484] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2134),
  [8486] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_public_field_definition, 7, 0, 306),
  [8488] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4783),
  [8490] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3409),
  [8492] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_public_field_definition, 7, 0, 307),
  [8494] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5526),
  [8496] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5462),
  [8498] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_array_repeat1, 2, 0, 0), SHIFT_REPEAT(280),
  [8501] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_array_pattern_repeat1, 2, 0, 0), SHIFT_REPEAT(254),
  [8504] = {.entry = {.count = 1, .reusable = true}}, SHIFT(900),
  [8506] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3260),
  [8508] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1026),
  [8510] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__module_export_name, 1, 0, 0),
  [8512] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1010),
  [8514] = {.entry = {.count = 1, .reusable = true}}, SHIFT(985),
  [8516] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5356),
  [8518] = {.entry = {.count = 1, .reusable = true}}, SHIFT(845),
  [8520] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_public_field_definition, 4, 0, 204),
  [8522] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_public_field_definition, 4, 0, 206),
  [8524] = {.entry = {.count = 1, .reusable = true}}, SHIFT(196),
  [8526] = {.entry = {.count = 1, .reusable = true}}, SHIFT(995),
  [8528] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_public_field_definition, 4, 0, 208),
  [8530] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5313),
  [8532] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3295),
  [8534] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_abstract_method_signature, 7, 0, 299),
  [8536] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2987),
  [8538] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3034),
  [8540] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2960),
  [8542] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3292),
  [8544] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5608),
  [8546] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2950),
  [8548] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3035),
  [8550] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2952),
  [8552] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_public_field_definition, 6, 0, 281),
  [8554] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3014),
  [8556] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3036),
  [8558] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3017),
  [8560] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3031),
  [8562] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3040),
  [8564] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3033),
  [8566] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_public_field_definition, 6, 0, 282),
  [8568] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4463),
  [8570] = {.entry = {.count = 1, .reusable = true}}, SHIFT(923),
  [8572] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_abstract_method_signature, 4, 0, 170),
  [8574] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_abstract_method_signature, 4, 0, 201),
  [8576] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_public_field_definition, 6, 0, 284),
  [8578] = {.entry = {.count = 1, .reusable = true}}, SHIFT(906),
  [8580] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_public_field_definition, 6, 0, 285),
  [8582] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_abstract_method_signature, 6, 0, 279),
  [8584] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_abstract_method_signature, 6, 0, 280),
  [8586] = {.entry = {.count = 1, .reusable = true}}, SHIFT(992),
  [8588] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_public_field_definition, 4, 0, 210),
  [8590] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_heritage, 1, 0, 0),
  [8592] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_pattern, 1, -1, 0), SHIFT(623),
  [8595] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_variable_declarator, 3, 0, 94),
  [8597] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_variable_declarator, 3, 0, 95),
  [8599] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_parameters, 3, 0, 0),
  [8601] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5039),
  [8603] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5688),
  [8605] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_public_field_definition, 4, 0, 214),
  [8607] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1202),
  [8609] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1205),
  [8611] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_optional_parameter, 3, 0, 101),
  [8613] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4419),
  [8615] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_import_clause, 1, 0, 0),
  [8617] = {.entry = {.count = 1, .reusable = true}}, SHIFT(323),
  [8619] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3827),
  [8621] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2879),
  [8623] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2892),
  [8625] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_optional_parameter, 4, 0, 157),
  [8627] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1397),
  [8629] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1401),
  [8631] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_tuple_parameter, 2, 0, 36),
  [8633] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_optional_type, 2, 0, 0),
  [8635] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3995),
  [8637] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3994),
  [8639] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2926),
  [8641] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2927),
  [8643] = {.entry = {.count = 1, .reusable = true}}, SHIFT(312),
  [8645] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3996),
  [8647] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1282),
  [8649] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1284),
  [8651] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1628),
  [8653] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1629),
  [8655] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_parameter, 3, 0, 134),
  [8657] = {.entry = {.count = 1, .reusable = true}}, SHIFT(335),
  [8659] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2772),
  [8661] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1638),
  [8663] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1639),
  [8665] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1640),
  [8667] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1641),
  [8669] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2896),
  [8671] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2897),
  [8673] = {.entry = {.count = 1, .reusable = true}}, SHIFT(938),
  [8675] = {.entry = {.count = 1, .reusable = true}}, SHIFT(929),
  [8677] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2769),
  [8679] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2928),
  [8681] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2915),
  [8683] = {.entry = {.count = 1, .reusable = true}}, SHIFT(896),
  [8685] = {.entry = {.count = 1, .reusable = true}}, SHIFT(893),
  [8687] = {.entry = {.count = 1, .reusable = true}}, SHIFT(899),
  [8689] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5039),
  [8691] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2930),
  [8693] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2919),
  [8695] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_parameter, 4, 0, 177),
  [8697] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2010),
  [8699] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2011),
  [8701] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2012),
  [8703] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2013),
  [8705] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1540),
  [8707] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1599),
  [8709] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2017),
  [8711] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2018),
  [8713] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_required_parameter, 2, 0, 42),
  [8715] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1623),
  [8717] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1625),
  [8719] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1197),
  [8721] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1198),
  [8723] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3230),
  [8725] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3231),
  [8727] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_optional_tuple_parameter, 3, 0, 94),
  [8729] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3234),
  [8731] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3235),
  [8733] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3236),
  [8735] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3237),
  [8737] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1532),
  [8739] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1533),
  [8741] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2023),
  [8743] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2024),
  [8745] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_enum_body_repeat1, 2, 0, 0),
  [8747] = {.entry = {.count = 1, .reusable = true}}, SHIFT(317),
  [8749] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum_assignment, 2, 0, 35),
  [8751] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1542),
  [8753] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1543),
  [8755] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4201),
  [8757] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5739),
  [8759] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_export_specifier, 4, 0, 193),
  [8761] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3109),
  [8763] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3110),
  [8765] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_import_specifier, 3, 0, 152),
  [8767] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3114),
  [8769] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3115),
  [8771] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_required_parameter, 3, 0, 103),
  [8773] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3117),
  [8775] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3118),
  [8777] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1369),
  [8779] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1354),
  [8781] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2901),
  [8783] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2905),
  [8785] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1988),
  [8787] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1989),
  [8789] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1350),
  [8791] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1367),
  [8793] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_import_specifier, 4, 0, 196),
  [8795] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_import_specifier, 4, 0, 193),
  [8797] = {.entry = {.count = 1, .reusable = true}}, SHIFT(918),
  [8799] = {.entry = {.count = 1, .reusable = true}}, SHIFT(922),
  [8801] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1993),
  [8803] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1994),
  [8805] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1995),
  [8807] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1996),
  [8809] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4154),
  [8811] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5847),
  [8813] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4564),
  [8815] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3092),
  [8817] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3093),
  [8819] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2343),
  [8821] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3101),
  [8823] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3102),
  [8825] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_import_specifier, 2, 0, 87),
  [8827] = {.entry = {.count = 1, .reusable = true}}, SHIFT(855),
  [8829] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3103),
  [8831] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3104),
  [8833] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1126),
  [8835] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1103),
  [8837] = {.entry = {.count = 1, .reusable = true}}, SHIFT(920),
  [8839] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4172),
  [8841] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5855),
  [8843] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3927),
  [8845] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3926),
  [8847] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3005),
  [8849] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3012),
  [8851] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_import_specifier, 1, 0, 5),
  [8853] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_export_specifier, 3, 0, 152),
  [8855] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2953),
  [8857] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2954),
  [8859] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3027),
  [8861] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3028),
  [8863] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1339),
  [8865] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1345),
  [8867] = {.entry = {.count = 1, .reusable = true}}, SHIFT(926),
  [8869] = {.entry = {.count = 1, .reusable = true}}, SHIFT(924),
  [8871] = {.entry = {.count = 1, .reusable = true}}, SHIFT(905),
  [8873] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4248),
  [8875] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5516),
  [8877] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1321),
  [8879] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1325),
  [8881] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_import_attribute, 2, 0, 0),
  [8883] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_parameter, 2, 0, 64),
  [8885] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_parameter, 3, 0, 131),
  [8887] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3933),
  [8889] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3932),
  [8891] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1290),
  [8893] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1291),
  [8895] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3935),
  [8897] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3934),
  [8899] = {.entry = {.count = 1, .reusable = true}}, SHIFT(837),
  [8901] = {.entry = {.count = 1, .reusable = true}}, SHIFT(816),
  [8903] = {.entry = {.count = 1, .reusable = true}}, SHIFT(814),
  [8905] = {.entry = {.count = 1, .reusable = true}}, SHIFT(829),
  [8907] = {.entry = {.count = 1, .reusable = true}}, SHIFT(817),
  [8909] = {.entry = {.count = 1, .reusable = true}}, SHIFT(822),
  [8911] = {.entry = {.count = 1, .reusable = true}}, SHIFT(818),
  [8913] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_import_specifier, 3, 0, 155),
  [8915] = {.entry = {.count = 1, .reusable = true}}, SHIFT(321),
  [8917] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1709),
  [8919] = {.entry = {.count = 1, .reusable = true}}, SHIFT(973),
  [8921] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1217),
  [8923] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2940),
  [8925] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1017),
  [8927] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3309),
  [8929] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5524),
  [8931] = {.entry = {.count = 1, .reusable = true}}, SHIFT(953),
  [8933] = {.entry = {.count = 1, .reusable = true}}, SHIFT(378),
  [8935] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1118),
  [8937] = {.entry = {.count = 1, .reusable = true}}, SHIFT(379),
  [8939] = {.entry = {.count = 1, .reusable = true}}, SHIFT(380),
  [8941] = {.entry = {.count = 1, .reusable = true}}, SHIFT(381),
  [8943] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5553),
  [8945] = {.entry = {.count = 1, .reusable = true}}, SHIFT(948),
  [8947] = {.entry = {.count = 1, .reusable = true}}, SHIFT(240),
  [8949] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5572),
  [8951] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5403),
  [8953] = {.entry = {.count = 1, .reusable = true}}, SHIFT(641),
  [8955] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5407),
  [8957] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1072),
  [8959] = {.entry = {.count = 1, .reusable = true}}, SHIFT(526),
  [8961] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1002),
  [8963] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5801),
  [8965] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1987),
  [8967] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2988),
  [8969] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1591),
  [8971] = {.entry = {.count = 1, .reusable = true}}, SHIFT(951),
  [8973] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1650),
  [8975] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1022),
  [8977] = {.entry = {.count = 1, .reusable = true}}, SHIFT(971),
  [8979] = {.entry = {.count = 1, .reusable = true}}, SHIFT(339),
  [8981] = {.entry = {.count = 1, .reusable = true}}, SHIFT(287),
  [8983] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2888),
  [8985] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2894),
  [8987] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1596),
  [8989] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5182),
  [8991] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4190),
  [8993] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1624),
  [8995] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1096),
  [8997] = {.entry = {.count = 1, .reusable = true}}, SHIFT(976),
  [8999] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3228),
  [9001] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3233),
  [9003] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1598),
  [9005] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2929),
  [9007] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_namespace_import, 3, 0, 0),
  [9009] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5688),
  [9011] = {.entry = {.count = 1, .reusable = true}}, SHIFT(949),
  [9013] = {.entry = {.count = 1, .reusable = true}}, SHIFT(384),
  [9015] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2245),
  [9017] = {.entry = {.count = 1, .reusable = true}}, SHIFT(385),
  [9019] = {.entry = {.count = 1, .reusable = true}}, SHIFT(386),
  [9021] = {.entry = {.count = 1, .reusable = true}}, SHIFT(387),
  [9023] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5857),
  [9025] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5592),
  [9027] = {.entry = {.count = 1, .reusable = true}}, SHIFT(448),
  [9029] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1990),
  [9031] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4507),
  [9033] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5289),
  [9035] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2891),
  [9037] = {.entry = {.count = 1, .reusable = true}}, SHIFT(666),
  [9039] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_named_imports, 5, 0, 0),
  [9041] = {.entry = {.count = 1, .reusable = true}}, SHIFT(397),
  [9043] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4467),
  [9045] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1597),
  [9047] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1003),
  [9049] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1714),
  [9051] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1092),
  [9053] = {.entry = {.count = 1, .reusable = true}}, SHIFT(952),
  [9055] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1093),
  [9057] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2221),
  [9059] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5525),
  [9061] = {.entry = {.count = 1, .reusable = true}}, SHIFT(340),
  [9063] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1075),
  [9065] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5782),
  [9067] = {.entry = {.count = 1, .reusable = true}}, SHIFT(333),
  [9069] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5851),
  [9071] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1076),
  [9073] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1516),
  [9075] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_named_imports, 2, 0, 0),
  [9077] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5537),
  [9079] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1715),
  [9081] = {.entry = {.count = 1, .reusable = true}}, SHIFT(974),
  [9083] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1630),
  [9085] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3740),
  [9087] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5644),
  [9089] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1053),
  [9091] = {.entry = {.count = 1, .reusable = true}}, SHIFT(352),
  [9093] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4784),
  [9095] = {.entry = {.count = 1, .reusable = true}}, SHIFT(456),
  [9097] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5710),
  [9099] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2898),
  [9101] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3421),
  [9103] = {.entry = {.count = 1, .reusable = true}}, SHIFT(365),
  [9105] = {.entry = {.count = 1, .reusable = true}}, SHIFT(341),
  [9107] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3091),
  [9109] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5209),
  [9111] = {.entry = {.count = 1, .reusable = true}}, SHIFT(366),
  [9113] = {.entry = {.count = 1, .reusable = true}}, SHIFT(367),
  [9115] = {.entry = {.count = 1, .reusable = true}}, SHIFT(368),
  [9117] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3100),
  [9119] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2924),
  [9121] = {.entry = {.count = 1, .reusable = true}}, SHIFT(315),
  [9123] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5554),
  [9125] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3121),
  [9127] = {.entry = {.count = 1, .reusable = true}}, SHIFT(324),
  [9129] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3743),
  [9131] = {.entry = {.count = 1, .reusable = true}}, SHIFT(325),
  [9133] = {.entry = {.count = 1, .reusable = true}}, SHIFT(326),
  [9135] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3652),
  [9137] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3122),
  [9139] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5018),
  [9141] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3495),
  [9143] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2875),
  [9145] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3123),
  [9147] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_named_imports, 3, 0, 0),
  [9149] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1102),
  [9151] = {.entry = {.count = 1, .reusable = true}}, SHIFT(477),
  [9153] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3156),
  [9155] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4484),
  [9157] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3468),
  [9159] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1115),
  [9161] = {.entry = {.count = 1, .reusable = true}}, SHIFT(584),
  [9163] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4474),
  [9165] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3771),
  [9167] = {.entry = {.count = 1, .reusable = true}}, SHIFT(964),
  [9169] = {.entry = {.count = 1, .reusable = true}}, SHIFT(962),
  [9171] = {.entry = {.count = 1, .reusable = true}}, SHIFT(970),
  [9173] = {.entry = {.count = 1, .reusable = true}}, SHIFT(239),
  [9175] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5584),
  [9177] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2881),
  [9179] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5606),
  [9181] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5351),
  [9183] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5683),
  [9185] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1035),
  [9187] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5218),
  [9189] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1331),
  [9191] = {.entry = {.count = 1, .reusable = true}}, SHIFT(958),
  [9193] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1023),
  [9195] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5828),
  [9197] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3125),
  [9199] = {.entry = {.count = 1, .reusable = true}}, SHIFT(969),
  [9201] = {.entry = {.count = 1, .reusable = true}}, SHIFT(421),
  [9203] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3126),
  [9205] = {.entry = {.count = 1, .reusable = true}}, SHIFT(968),
  [9207] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2902),
  [9209] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3127),
  [9211] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3424),
  [9213] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1587),
  [9215] = {.entry = {.count = 1, .reusable = true}}, SHIFT(957),
  [9217] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1037),
  [9219] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1827),
  [9221] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3128),
  [9223] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1122),
  [9225] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2044),
  [9227] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1123),
  [9229] = {.entry = {.count = 1, .reusable = true}}, SHIFT(967),
  [9231] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5662),
  [9233] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1005),
  [9235] = {.entry = {.count = 1, .reusable = true}},  ACCEPT_INPUT(),
  [9237] = {.entry = {.count = 1, .reusable = true}}, SHIFT(435),
  [9239] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3130),
  [9241] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3131),
  [9243] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2903),
  [9245] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2209),
  [9247] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3535),
  [9249] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1094),
  [9251] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5198),
  [9253] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2904),
  [9255] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5649),
  [9257] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2072),
  [9259] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1043),
  [9261] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1044),
  [9263] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2050),
  [9265] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1046),
  [9267] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2906),
  [9269] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2051),
  [9271] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2073),
  [9273] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1047),
  [9275] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2638),
  [9277] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2076),
  [9279] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2052),
  [9281] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2053),
  [9283] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4787),
  [9285] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2909),
  [9287] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_named_imports, 4, 0, 0),
  [9289] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2077),
  [9291] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2078),
  [9293] = {.entry = {.count = 1, .reusable = true}}, SHIFT(343),
  [9295] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3132),
  [9297] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2887),
  [9299] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3133),
  [9301] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2079),
  [9303] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3134),
  [9305] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2054),
  [9307] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1878),
  [9309] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1879),
  [9311] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1880),
  [9313] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1127),
  [9315] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1660),
  [9317] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1881),
  [9319] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2055),
  [9321] = {.entry = {.count = 1, .reusable = true}}, SHIFT(506),
  [9323] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1059),
  [9325] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5172),
  [9327] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1060),
  [9329] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2883),
  [9331] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2885),
  [9333] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2886),
  [9335] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3136),
  [9337] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3137),
  [9339] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3138),
  [9341] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1589),
  [9343] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3139),
  [9345] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3140),
  [9347] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3141),
  [9349] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2056),
  [9351] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2057),
  [9353] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3142),
  [9355] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3435),
  [9357] = {.entry = {.count = 1, .reusable = true}}, SHIFT(960),
  [9359] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1552),
  [9361] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3677),
  [9363] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5239),
  [9365] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_heritage, 2, 0, 0),
  [9367] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2995),
  [9369] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4249),
  [9371] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3038),
  [9373] = {.entry = {.count = 1, .reusable = true}}, SHIFT(787),
  [9375] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2993),
  [9377] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2058),
  [9379] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2880),
  [9381] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2943),
  [9383] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_import_clause, 3, 0, 0),
  [9385] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2882),
  [9387] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2946),
  [9389] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2983),
  [9391] = {.entry = {.count = 1, .reusable = true}}, SHIFT(372),
  [9393] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2911),
  [9395] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2989),
  [9397] = {.entry = {.count = 1, .reusable = true}}, SHIFT(416),
  [9399] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1565),
  [9401] = {.entry = {.count = 1, .reusable = true}}, SHIFT(373),
  [9403] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1566),
  [9405] = {.entry = {.count = 1, .reusable = true}}, SHIFT(374),
  [9407] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1567),
  [9409] = {.entry = {.count = 1, .reusable = true}}, SHIFT(375),
  [9411] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2990),
  [9413] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2997),
  [9415] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3022),
  [9417] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1089),
  [9419] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3455),
  [9421] = {.entry = {.count = 1, .reusable = true}}, SHIFT(348),
  [9423] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2059),
  [9425] = {.entry = {.count = 1, .reusable = true}}, SHIFT(517),
  [9427] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1061),
  [9429] = {.entry = {.count = 1, .reusable = true}}, SHIFT(349),
  [9431] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4350),
  [9433] = {.entry = {.count = 1, .reusable = true}}, SHIFT(350),
  [9435] = {.entry = {.count = 1, .reusable = true}}, SHIFT(351),
  [9437] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1568),
  [9439] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3413),
  [9441] = {.entry = {.count = 1, .reusable = true}}, SHIFT(613),
  [9443] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2956),
  [9445] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1786),
  [9447] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2958),
  [9449] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2007),
  [9451] = {.entry = {.count = 1, .reusable = true}}, SHIFT(534),
  [9453] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4449),
  [9455] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2959),
  [9457] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3441),
  [9459] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2961),
  [9461] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1569),
  [9463] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5521),
  [9465] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2963),
  [9467] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1570),
  [9469] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2941),
  [9471] = {.entry = {.count = 1, .reusable = true}}, SHIFT(357),
  [9473] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2385),
  [9475] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1571),
  [9477] = {.entry = {.count = 1, .reusable = true}}, SHIFT(569),
  [9479] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1572),
  [9481] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4472),
  [9483] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2965),
  [9485] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2966),
  [9487] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1573),
  [9489] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2967),
  [9491] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1575),
  [9493] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2969),
  [9495] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1272),
  [9497] = {.entry = {.count = 1, .reusable = true}}, SHIFT(388),
  [9499] = {.entry = {.count = 1, .reusable = true}}, SHIFT(597),
  [9501] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4503),
  [9503] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3106),
  [9505] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2893),
  [9507] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3470),
  [9509] = {.entry = {.count = 1, .reusable = true}}, SHIFT(329),
  [9511] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2729),
  [9513] = {.entry = {.count = 1, .reusable = true}}, SHIFT(623),
  [9515] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3284),
  [9517] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5656),
  [9519] = {.entry = {.count = 1, .reusable = true}}, SHIFT(650),
  [9521] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4351),
  [9523] = {.entry = {.count = 1, .reusable = true}}, SHIFT(358),
  [9525] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3219),
  [9527] = {.entry = {.count = 1, .reusable = true}}, SHIFT(395),
  [9529] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1077),
  [9531] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3204),
  [9533] = {.entry = {.count = 1, .reusable = true}}, SHIFT(360),
  [9535] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3365),
  [9537] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5364),
  [9539] = {.entry = {.count = 1, .reusable = true}}, SHIFT(946),
  [9541] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1085),
  [9543] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4439),
  [9545] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3662),
  [9547] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12),
  [9549] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1583),
  [9551] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4319),
  [9553] = {.entry = {.count = 1, .reusable = true}}, SHIFT(789),
  [9555] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3404),
  [9557] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5207),
  [9559] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1584),
  [9561] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5674),
  [9563] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4323),
  [9565] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3339),
  [9567] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3416),
  [9569] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1024),
  [9571] = {.entry = {.count = 1, .reusable = true}}, SHIFT(344),
  [9573] = {.entry = {.count = 1, .reusable = true}}, SHIFT(802),
  [9575] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1585),
  [9577] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_namespace_export, 3, 0, 0),
  [9579] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1586),
  [9581] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4508),
  [9583] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2910),
  [9585] = {.entry = {.count = 1, .reusable = true}}, SHIFT(557),
  [9587] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1708),
  [9589] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2884),
};

enum ts_external_scanner_symbol_identifiers {
  ts_external_token__automatic_semicolon = 0,
  ts_external_token__template_chars = 1,
  ts_external_token__ternary_qmark = 2,
  ts_external_token_html_comment = 3,
  ts_external_token_PIPE_PIPE = 4,
  ts_external_token_escape_sequence = 5,
  ts_external_token_regex_pattern = 6,
  ts_external_token_jsx_text = 7,
  ts_external_token__function_signature_automatic_semicolon = 8,
  ts_external_token___error_recovery = 9,
};

static const TSSymbol ts_external_scanner_symbol_map[EXTERNAL_TOKEN_COUNT] = {
  [ts_external_token__automatic_semicolon] = sym__automatic_semicolon,
  [ts_external_token__template_chars] = sym__template_chars,
  [ts_external_token__ternary_qmark] = sym__ternary_qmark,
  [ts_external_token_html_comment] = sym_html_comment,
  [ts_external_token_PIPE_PIPE] = anon_sym_PIPE_PIPE,
  [ts_external_token_escape_sequence] = sym_escape_sequence,
  [ts_external_token_regex_pattern] = sym_regex_pattern,
  [ts_external_token_jsx_text] = sym_jsx_text,
  [ts_external_token__function_signature_automatic_semicolon] = sym__function_signature_automatic_semicolon,
  [ts_external_token___error_recovery] = sym___error_recovery,
};

static const bool ts_external_scanner_states[11][EXTERNAL_TOKEN_COUNT] = {
  [1] = {
    [ts_external_token__automatic_semicolon] = true,
    [ts_external_token__template_chars] = true,
    [ts_external_token__ternary_qmark] = true,
    [ts_external_token_html_comment] = true,
    [ts_external_token_PIPE_PIPE] = true,
    [ts_external_token_escape_sequence] = true,
    [ts_external_token_jsx_text] = true,
    [ts_external_token__function_signature_automatic_semicolon] = true,
    [ts_external_token___error_recovery] = true,
  },
  [2] = {
    [ts_external_token_html_comment] = true,
  },
  [3] = {
    [ts_external_token__ternary_qmark] = true,
    [ts_external_token_html_comment] = true,
    [ts_external_token_PIPE_PIPE] = true,
  },
  [4] = {
    [ts_external_token__automatic_semicolon] = true,
    [ts_external_token__ternary_qmark] = true,
    [ts_external_token_html_comment] = true,
    [ts_external_token_PIPE_PIPE] = true,
  },
  [5] = {
    [ts_external_token__automatic_semicolon] = true,
    [ts_external_token_html_comment] = true,
  },
  [6] = {
    [ts_external_token__automatic_semicolon] = true,
    [ts_external_token_html_comment] = true,
    [ts_external_token__function_signature_automatic_semicolon] = true,
  },
  [7] = {
    [ts_external_token__template_chars] = true,
    [ts_external_token_html_comment] = true,
    [ts_external_token_escape_sequence] = true,
  },
  [8] = {
    [ts_external_token__template_chars] = true,
    [ts_external_token_html_comment] = true,
  },
  [9] = {
    [ts_external_token_html_comment] = true,
    [ts_external_token_escape_sequence] = true,
  },
  [10] = {
    [ts_external_token_html_comment] = true,
    [ts_external_token_regex_pattern] = true,
  },
};

#ifdef __cplusplus
extern "C" {
#endif
void *tree_sitter_typescript_external_scanner_create(void);
void tree_sitter_typescript_external_scanner_destroy(void *);
bool tree_sitter_typescript_external_scanner_scan(void *, TSLexer *, const bool *);
unsigned tree_sitter_typescript_external_scanner_serialize(void *, char *);
void tree_sitter_typescript_external_scanner_deserialize(void *, const char *, unsigned);

#ifdef TREE_SITTER_HIDE_SYMBOLS
#define TS_PUBLIC
#elif defined(_WIN32)
#define TS_PUBLIC __declspec(dllexport)
#else
#define TS_PUBLIC __attribute__((visibility("default")))
#endif

TS_PUBLIC const TSLanguage *tree_sitter_typescript(void) {
  static const TSLanguage language = {
    .version = LANGUAGE_VERSION,
    .symbol_count = SYMBOL_COUNT,
    .alias_count = ALIAS_COUNT,
    .token_count = TOKEN_COUNT,
    .external_token_count = EXTERNAL_TOKEN_COUNT,
    .state_count = STATE_COUNT,
    .large_state_count = LARGE_STATE_COUNT,
    .production_id_count = PRODUCTION_ID_COUNT,
    .field_count = FIELD_COUNT,
    .max_alias_sequence_length = MAX_ALIAS_SEQUENCE_LENGTH,
    .parse_table = &ts_parse_table[0][0],
    .small_parse_table = ts_small_parse_table,
    .small_parse_table_map = ts_small_parse_table_map,
    .parse_actions = ts_parse_actions,
    .symbol_names = ts_symbol_names,
    .field_names = ts_field_names,
    .field_map_slices = ts_field_map_slices,
    .field_map_entries = ts_field_map_entries,
    .symbol_metadata = ts_symbol_metadata,
    .public_symbol_map = ts_symbol_map,
    .alias_map = ts_non_terminal_alias_map,
    .alias_sequences = &ts_alias_sequences[0][0],
    .lex_modes = ts_lex_modes,
    .lex_fn = ts_lex,
    .keyword_lex_fn = ts_lex_keywords,
    .keyword_capture_token = sym_identifier,
    .external_scanner = {
      &ts_external_scanner_states[0][0],
      ts_external_scanner_symbol_map,
      tree_sitter_typescript_external_scanner_create,
      tree_sitter_typescript_external_scanner_destroy,
      tree_sitter_typescript_external_scanner_scan,
      tree_sitter_typescript_external_scanner_serialize,
      tree_sitter_typescript_external_scanner_deserialize,
    },
    .primary_state_ids = ts_primary_state_ids,
  };
  return &language;
}
#ifdef __cplusplus
}
#endif
